(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   6758586,     223967]*)
(*NotebookOutlinePosition[   6795530,     225273]*)
(*  CellTagsIndexPosition[   6795486,     225269]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Duffing Equation", "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "from ",
  StyleBox[ButtonBox["Essential Mathematica for Students of Science",
    Active->False,
    ButtonData:>{
      URL[ 
      "http://www.physics.umd.edu/courses/CourseWare/EssentialMathematica/"], 
      None},
    Active->False,
    ButtonStyle->"Hyperlink"],
    Active->False],
  "\n\[Copyright] James J. Kelly, 1998\nLast revised: January, 2006"
}], "Author",
  Active->True,
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
  "\tThe ",
  StyleBox["Duffing equation",
    FontSlant->"Italic"],
  " (Georg Duffing, 1918)"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[\(\[PartialD]\^2 x\), \(\[PartialD]t\^2\),
            MultilineFunction->None], " ", "+", " ", 
          RowBox[{"2", "\[Gamma]", " ", 
            FractionBox[\(\[PartialD]x\), \(\[PartialD]t\),
              MultilineFunction->None]}], " ", "+", " ", \(k\ x\), " ", 
          "+", \(\[Alpha]\ x\^3\)}], " ", 
        "\[Equal]", \(f\ Cos[\[Omega]\ t]\)}], 
      TraditionalForm]], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "can be used to describe a driven anharmonic oscillator with linear \
damping.  The anharmonicity parameter is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ", the damping parameter is \[Gamma], the driving amplitude is ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ", and the driving frequency is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  ".   In the absence of damping or anharmonicity the natural oscillation \
frequency would be ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_0 = \@k\)]],
  ".  The solutions to this equation display a dazzling variety of patterns \
depending upon the values of these parameters.  In this notebook we present \
relatively elegant functions which solve this equation and produce phase \
diagrams.  We also introduce the ",
  StyleBox["Poincar\[EAcute] map",
    FontSlant->"Italic"],
  ", which provides a tool for analyzing structures that are sometimes hidden \
within chaotic trajectories.  The basic idea is strobe the phase trajectory \
at the frequency of the driving force.  Thus, we examine the set of points"
}], "Text"],

Cell[BoxData[{
    \(TraditionalForm\`P\  = {\ {x[t\_k], \(x\^\[Prime]\)[t\_k]}, \ 
        k = 1, \[Infinity]}\), "\[IndentingNewLine]", 
    \(TraditionalForm\`t\_k = 
      t\_0\  + \ \(2  \[Pi]\ k\)\/\[Omega]\)}], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)]],
  " is an arbitrary offset.  Although the points within such sets usually \
depend strongly upon both ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)]],
  " and the initial conditions, the qualitative structure or topology of the \
Poincar\[EAcute] map depends primarily upon the dynamical parameters, here ",
  Cell[BoxData[
      \(TraditionalForm\`{k, \[Alpha], \[Gamma], f, \[Omega]}\)]],
  ", and often provides considerable insight into the behavior of the system. \
 We will use a few representative examples to illustrate some of the possible \
behaviors but will not attempt an exhaustive study of this very rich system."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[BoxData[{
    \(\(ClearAll["\<Global`*\>"];\)\), "\n", 
    \(Off[General::spell, \ General::spell1]\)}], "Input"],

Cell["\<\
$DefaultFont={\"Times\", 12}; 
$TextStyle={FontFamily\[Rule]\"Times\", FontSize\[Rule]12, \
FontSlant\[Rule]\"Italic\"}; \
\>", "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Utilities`Notation`\>"];\)\), "\n", 
    \(Needs["\<Utilities`FilterOptions`\>"]\)}], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Symbolize", "[", 
        TagBox[\(\[Omega]\_0\),
          NotationBoxTag,
          Editable->True], "]"}], ";", " ", 
      RowBox[{"Symbolize", "[", 
        TagBox[\(x\_0\),
          NotationBoxTag,
          Editable->True], "]"}], ";", " ", 
      RowBox[{"Symbolize", "[", 
        TagBox[\(v\_0\),
          NotationBoxTag,
          Editable->True], "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Implementation", "Section"],

Cell["\<\
In this section we construct functions which define and solve the Duffing \
equation given its parameters and initial conditions.  \
\>", "Text"],

Cell[BoxData[{
    \(\(duffingEq::usage\  = \ \
\*"\"\<duffingEq[k,\[Alpha],\[Gamma],f,\[Omega]] defines the Duffing equation \
for x[t], \\n \!\(x\^\[DoublePrime]\) + 2\[Gamma] \!\(x\^\[Prime]\) + k x + \
\[Alpha] \!\(x\^3\)) \[Equal] f Cos[\[Omega] t], \\n given elasticity \
parameter k, nonlinearity parameter \[Alpha], damping rate \[Gamma], driving \
amplitude f, and driving frequency \[Omega].\>\"";\)\n\), "\n", 
    \(duffingEq[k_, \[Alpha]_, \[Gamma]_, 
        f_, \[Omega]_]\  := \(x\^\[DoublePrime]\)[t]\  + \ 
          2  \[Gamma]\ \(x\^\[Prime]\)[t]\  + \ 
          k\ x[t] + \[Alpha]\ x[t]\^3 \[Equal] 
        f\ Cos[\[Omega]\ t]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[duffingEq[k, 0, \[Gamma], f, \[Omega]], x, t]\)], "Input"],

Cell[BoxData[
    \({{x \[Rule] 
          Function[{t}, \[ExponentialE]\^\(t\ \((\(-\[Gamma]\) - \@\(\(-k\) + \
\[Gamma]\^2\))\)\)\ C[
                  1] + \[ExponentialE]\^\(t\ \((\(-\[Gamma]\) + \@\(\(-k\) + \
\[Gamma]\^2\))\)\)\ C[
                  2] + \(\(-f\)\ k\ Cos[t\ \[Omega]] + f\ \[Omega]\^2\ Cos[t\ \
\[Omega]] - 2\ f\ \[Gamma]\ \[Omega]\ Sin[t\ \[Omega]]\)\/\(\((k - 2\ \
\[Gamma]\^2 + 2\ \[Gamma]\ \@\(\(-k\) + \[Gamma]\^2\) - \[Omega]\^2)\)\ \
\((\(-k\) + 2\ \[Gamma]\^2 + 2\ \[Gamma]\ \@\(\(-k\) + \[Gamma]\^2\) + \
\[Omega]\^2)\)\)]}}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "It is useful to provide a place for optional parameters when constructing \
a function which invokes a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " command to perform a task which may require some attention by the user.  \
For example, in this case it may be necessary to increase ",
  StyleBox["MaxSteps", "InlineInput",
    FontWeight->"Bold"],
  " if the range of integration is large enough to exceed the default value \
for ",
  StyleBox["NDSolve", "InlineInput",
    FontWeight->"Bold"],
  ".  Placing ",
  StyleBox["opts___Rule", "InlineInput",
    FontWeight->"Bold"],
  " last in the argument list with the triple-underscore pattern indicates \
that zero or more replacement rules may be included there."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[duffingSol];\)\), "\[IndentingNewLine]", 
    \(\(duffingSol::usage\  = \
\*"\"\<duffingSol[k,\[Alpha],\[Gamma],f,\[Omega],\!\(x\_0\),\!\(v\_0\),tmax,\
opts] uses NDSolve to produce a numerical solution to the Duffing equation \
given initial conditions x[0]\[Equal]\!\(x\_0\) and \!\(x\^\[Prime]\)[0]\
\[Equal]\!\(v\_0\) for {t,0,tmax}.  See duffingEq for other parameter \
definitions.  The optional parameters opts are passed to NDSolve.\>\"";\)\n\t\
\t\), "\n", 
    \(\(duffingSol[k_, \[Alpha]_, \[Gamma]_, 
          f_, \[Omega]_, \(x\_0\) : _, \(v\_0\) : _, tmax_, opts___Rule]\)[
        t_Symbol]\  := {x[t], \(x\^\[Prime]\)[
            t]} /. \(NDSolve[{duffingEq[k, \[Alpha], \[Gamma], f, \[Omega]], 
              x[0] \[Equal] x\_0, \(x\^\[Prime]\)[0] \[Equal] v\_0}, 
            x, {t, 0, tmax}, 
            opts]\)\[LeftDoubleBracket]1\[RightDoubleBracket]\)}], "Input"],

Cell[TextData[{
  "Since ",
  StyleBox["duffingPlot", "InlineInput",
    FontWeight->"Bold"],
  " calls ",
  StyleBox["duffingSol", "InlineInput",
    FontWeight->"Bold"],
  " to produce the solution it seeks to plot, and both may benefit from \
options, it is convenient to employ ",
  StyleBox["FilterOptions", "InlineInput",
    FontWeight->"Bold"],
  ", found in the package  ",
  ButtonBox["Utilities`FilterOptions`",
    ButtonData:>{"Utilities`FilterOptions`", "1.3"},
    ButtonStyle->"AddOnsLink"],
  ", to choose those options appropriate to ",
  StyleBox["NDSolve", "InlineInput",
    FontWeight->"Bold"],
  " and those appropriate to ",
  StyleBox["ParametricPlot", "InlineInput",
    FontWeight->"Bold"],
  ".  The ",
  ButtonBox["With",
    ButtonStyle->"RefGuideLink"],
  " statement makes local assignments based upon the output of ",
  StyleBox["FilterOptions", "InlineInput",
    FontWeight->"Bold"],
  " and then passes those option lists to the appropriate commands.  However, \
those lists are not defined outside this context.  (Check for yourself that \
",
  StyleBox["optPlot", "InlineInput",
    FontWeight->"Bold"],
  " and ",
  StyleBox["optND", "InlineInput",
    FontWeight->"Bold"],
  " remain undefined after executing ",
  StyleBox["duffingPlot", "InlineInput",
    FontWeight->"Bold"],
  ".)  Thus, this method allows options for both commands to be included at \
the end of the argument list.  Note that the options may occur in any order \
and need not be grouped by command.  Also note that options are applied in \
order but only once.  Therefore, by placing the user-defined options first in \
",
  StyleBox["ParametricPlot", "InlineInput",
    FontWeight->"Bold"],
  " defaults for labels can be included at the end without overriding the \
user's selections, if present."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[duffingPlot];\)\), "\[IndentingNewLine]", 
    \(\(duffingPlot::usage\  = \ \*"\"\<duffingPlot[k,\[Alpha],\[Gamma],f,\
\[Omega],\!\(x\_0\),\!\(v\_0\),tmin,tmax,opts] produces a phase diagram for \
the Duffing equation.  The equation is solved for {t,0,tmax}, but the plot \
may be restricted to {t,tmin,tmax}.  The optional parameters opts can \
regulate either NDSolve or ParametricPlot as appropriate.  See duffingEq and \
duffingSol for parameter definitions.\>\"";\)\n\), "\n", 
    \(duffingPlot[k_, \[Alpha]_, \[Gamma]_, 
        f_, \[Omega]_, \(x\_0\) : _, \(v\_0\) : _, tmin_, tmax_, 
        opts___Rule]\  := \ 
      With[{optPlot\  = \ FilterOptions[ParametricPlot, opts]\ , 
          optND\  = FilterOptions[NDSolve, opts]}, \ 
        ParametricPlot[
          Evaluate[\(duffingSol[k, \[Alpha], \[Gamma], f, \[Omega], x\_0, 
                v\_0, tmax, optND]\)[t]], {t, tmin, tmax}, \ optPlot, 
          AspectRatio \[Rule] 1, \ Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<position\>", \ "\<velocity\>"}, \ 
          PlotLabel \[Rule] "\<Duffing Equation\>"]]\)}], "Input"],

Cell["\<\
Finally, the following function constructs a Poincar\[EAcute] set from a \
phase trajectory given as a pair of functions.  The user must choose the \
proper strobe frequency.\
\>", "Text"],

Cell[BoxData[
    \(poincare[{x_[t_], v_[t_]}, \[Omega]_, tmin_, tmax_] := 
      Table[{x[t], v[t]}, {t, tmin, tmax, \(2  \[Pi]\)\/\[Omega]}]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Section"],

Cell[CellGroupData[{

Cell["Conservative systems", "Subsection"],

Cell["\<\
In the absence of damping or driving forces, the Duffing equation describes \
the motion of a particle in a potential well which conserves energy.  The \
behavior can then be understood using energy diagrams.  The shape of the \
potential is obtained by integrating the restoring force.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[Nu][k_, \[Alpha]_]\)[
        x_]\  = \[Integral]\_0\%x\((k\ x + \[Alpha]\ x\^3)\) \
\[DifferentialD]x\ \  // Expand\)], "Input"],

Cell[BoxData[
    \(\(k\ x\^2\)\/2 + \(x\^4\ \[Alpha]\)\/4\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Below we plot three cases for ",
  Cell[BoxData[
      \(TraditionalForm\`k > 0\)]],
  ".  The red curve with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 0\)]],
  " represents the harmonic potential, the blue curve with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \(+1\)\)]],
  " is more strongly confining for large displacements, while the green curve \
with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \(-1\)\)]],
  " is less strongly confining for moderate displacements and becomes \
repulsive for large displacements.  The motion for the strictly confining \
potentials will be periodic between the turning points determined by the \
condition that the total energy is potential, whereas character of the motion \
for potentials with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] < 0\)]],
  " depends upon both the initial position and total energy.  If the system \
begins with total energy and position within the confined region the motion \
will be periodic, but if the energy is too large or the position is outside \
the well the particle escapes to infinity."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
        Evaluate[
          Table[\(\[Nu][1, \[Alpha]]\)[x], {\[Alpha], \(-1\), 
              1}]], {x, \(-2\), 2}, 
        PlotRange \[Rule] {Automatic, {\(-1\), 1}}, 
        PlotStyle \[Rule] {RGBColor[0, 1, 0], RGBColor[1, 0, 0], 
            RGBColor[0, 0, 1]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.309017 0.309017 [
[.02381 .29652 -9.34375 -15.6875 ]
[.02381 .29652 9.34375 0 ]
[.2619 .29652 -9.34375 -15.6875 ]
[.2619 .29652 9.34375 0 ]
[.7381 .29652 -5 -15.6875 ]
[.7381 .29652 5 0 ]
[.97619 .29652 -5 -15.6875 ]
[.97619 .29652 5 0 ]
[.4875 0 -18.6875 -7.84375 ]
[.4875 0 0 7.84375 ]
[.4875 .07725 -33.6875 -7.84375 ]
[.4875 .07725 0 7.84375 ]
[.4875 .15451 -27.6875 -7.84375 ]
[.4875 .15451 0 7.84375 ]
[.4875 .23176 -33.6875 -7.84375 ]
[.4875 .23176 0 7.84375 ]
[.4875 .38627 -25 -7.84375 ]
[.4875 .38627 0 7.84375 ]
[.4875 .46353 -19 -7.84375 ]
[.4875 .46353 0 7.84375 ]
[.4875 .54078 -25 -7.84375 ]
[.4875 .54078 0 7.84375 ]
[.4875 .61803 -10 -7.84375 ]
[.4875 .61803 0 7.84375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
gsave
.4875 0 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -94.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -94.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
.5 Mabswid
.07222 0 m
.08426 .06195 L
.10458 .14747 L
.12414 .2143 L
.14264 .26502 L
.16305 .3086 L
.18163 .3383 L
.19132 .35047 L
.2016 .36111 L
.21123 .36914 L
.22004 .37497 L
.22945 .37972 L
.23464 .38174 L
.23958 .38329 L
.24412 .38441 L
.24833 .38521 L
.25075 .38556 L
.25295 .38582 L
.25417 .38593 L
.25549 .38604 L
.25674 .38612 L
.25788 .38618 L
.2591 .38623 L
.26025 .38626 L
.26147 .38627 L
.26216 .38627 L
.26279 .38627 L
.26385 .38625 L
.26502 .38622 L
.26624 .38617 L
.26738 .38611 L
.27 .38593 L
.2724 .3857 L
.27782 .38498 L
.28272 .38411 L
.28808 .38294 L
.29888 .37993 L
.31849 .37272 L
.33944 .3633 L
.38094 .34282 L
.40174 .33309 L
.42092 .32512 L
.4408 .31828 L
.45939 .31345 L
.46843 .31171 L
.47815 .31031 L
.48368 .30974 L
.48641 .30952 L
.48894 .30935 L
.49141 .30922 L
Mistroke
.49365 .30913 L
.49493 .30909 L
.49614 .30906 L
.49742 .30904 L
.49813 .30903 L
.49879 .30902 L
.50006 .30902 L
.50126 .30902 L
.50234 .30903 L
.50351 .30905 L
.50478 .30908 L
.50613 .30912 L
.50855 .30922 L
.51079 .30933 L
.51288 .30947 L
.51765 .30986 L
.52285 .31043 L
.52761 .31108 L
.53833 .31297 L
.55729 .3177 L
.57801 .32471 L
.61862 .34261 L
.65772 .36194 L
.67767 .3711 L
.68817 .37538 L
.69927 .37934 L
.7092 .38226 L
.71446 .38352 L
.72011 .38464 L
.72277 .38507 L
.7253 .38543 L
.72776 .38571 L
.73003 .38593 L
.73218 .38609 L
.73327 .38615 L
.73447 .3862 L
.73567 .38624 L
.73696 .38626 L
.73818 .38627 L
.7393 .38626 L
.74058 .38624 L
.74178 .3862 L
.74286 .38615 L
.74403 .38607 L
.74666 .38586 L
.74909 .38558 L
.75351 .38489 L
.7582 .38388 L
.76329 .38244 L
.76805 .38074 L
Mistroke
.77889 .37558 L
.78928 .36875 L
.79916 .3604 L
.81769 .33923 L
.83751 .30756 L
.8559 .26856 L
.87644 .21253 L
.89505 .14888 L
Mfstroke
.89505 .14888 m
.9272 0 L
s
1 0 0 r
.16382 .61803 m
.18221 .58427 L
.22272 .51857 L
.26171 .46378 L
.30316 .41463 L
.34309 .37613 L
.3815 .34729 L
.40095 .33576 L
.42237 .32544 L
.44268 .31797 L
.45178 .31535 L
.46172 .31301 L
.4671 .31197 L
.4721 .31114 L
.47727 .31042 L
.48196 .3099 L
.48658 .30951 L
.4887 .30937 L
.49093 .30924 L
.49332 .30914 L
.49438 .3091 L
.49552 .30907 L
.49675 .30905 L
.49789 .30903 L
.49859 .30902 L
.49925 .30902 L
.50049 .30902 L
.50163 .30902 L
.50286 .30904 L
.50401 .30906 L
.50508 .30909 L
.50754 .30917 L
.51014 .3093 L
.51268 .30946 L
.51504 .30963 L
.5204 .31015 L
.5293 .31136 L
.53882 .31312 L
.54906 .31558 L
.56016 .31888 L
.58032 .3266 L
.60019 .33638 L
.62123 .34908 L
.65912 .37803 L
.69946 .41745 L
.73829 .46377 L
.77956 .52203 L
.81932 .58693 L
s
.81932 .58693 m
.83618 .61803 L
s
0 0 1 r
.23664 .61803 m
.26171 .54129 L
.28158 .49375 L
.30316 .45072 L
.34309 .3907 L
.36292 .36872 L
.38395 .35008 L
.40349 .33649 L
.42179 .32659 L
.43217 .32207 L
.44203 .31845 L
.45175 .31549 L
.46056 .31332 L
.47014 .31147 L
.47505 .31072 L
.48036 .31007 L
.4853 .30961 L
.48746 .30945 L
.48983 .3093 L
.49208 .30919 L
.49417 .30911 L
.49533 .30908 L
.49638 .30905 L
.4976 .30903 L
.49875 .30902 L
.49989 .30902 L
.50112 .30902 L
.50228 .30903 L
.50334 .30905 L
.50452 .30907 L
.50581 .30911 L
.50841 .30921 L
.51097 .30935 L
.51372 .30953 L
.51866 .30997 L
.52363 .31055 L
.52831 .31122 L
.53708 .31281 L
.5468 .3151 L
.55709 .31816 L
.57555 .32536 L
.59512 .33565 L
.61343 .34807 L
.65226 .38512 L
.67343 .41275 L
.69354 .44483 L
.73178 .52482 L
s
.73178 .52482 m
.76364 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00b03oool00`3ookl0M000000000020000000304RLg`3oool0oooo0>00oooo003:0?ooo`03
0?noM0000000M;oo0><0oooo003:0?ooo`030?oog`2LB00007Bo0><0oooo003;0?ooo`030=nLB000
B9`0gooo0>80oooo002k0?ooo`030?oog`2LB000000000L0000000<0B9cO0?ooo`3oool00`3oool0
0`3ogi`0B01809cOo`3R0?ooo`00<P3oool00`00o`00oooo0?ooo`2F0?ooo`030?oo_`1d0000M;oo
00/0oooo1000002T0?ooo`03003o003oool0oooo02`0oooo000b0?ooo`03003o003oool0oooo09L0
oooo00<0_g@0001d_`3oool02P3oool00`000000oooo0?ooo`2U0?ooo`03003o003oool0oooo02`0
oooo000b0?ooo`03003o003oool0oooo09L0oooo00<0gia80018W03Oool02P3oool00`000000oooo
0?ooo`2U0?ooo`03003o003oool0oooo02`0oooo000b0?ooo`03003o003oool0oooo09L0oooo00<0
omnL04P0B02Lgol02P3oool00`000000oooo0?ooo`2T0?ooo`03003o003oool0oooo02d0oooo000c
0?ooo`03003o003oool0oooo09H0oooo00<0oono07@0001d_ol02P3oool00`000000oooo0?ooo`2T
0?ooo`03003o003oool0oooo02d0oooo000c0?ooo`03003o003oool0oooo09L0oooo00<0_g@0001d
_`3oool02@3oool00`000000oooo0?ooo`2T0?ooo`03003o003oool0oooo02d0oooo000c0?ooo`03
003o003oool0oooo09D0oooo00D0oono07@000000000001d0;ooo`090?ooo`<00000Y03oool00`00
o`00oooo0?ooo`0]0?ooo`00<`3oool00`00o`00oooo0?ooo`2S0?ooo`030000003oool0oooo0:<0
oooo00<00?l00?ooo`3oool0;P3oool003<0oooo00<00?l00?ooo`3oool0X`3oool00`000000oooo
0?ooo`2S0?ooo`03003o003oool0oooo02h0oooo000c0?ooo`03003o003oool0oooo0:<0oooo00<0
00000?ooo`3oool0X`3oool00`00o`00oooo0?ooo`0^0?ooo`00=03oool00`00o`00oooo0?ooo`2R
0?ooo`030000003oool0oooo0:<0oooo00<00?l00?ooo`3oool0;P3oool003@0oooo00<00?l00?oo
o`3oool0XP3oool00`000000oooo0?ooo`2S0?ooo`03003o003oool0oooo02h0oooo000d0?ooo`03
003o003oool0oooo0:80oooo00<000000?ooo`3oool0XP3oool00`00o`00oooo0?ooo`0_0?ooo`00
=03oool00`00o`00oooo0?ooo`2R0?ooo`<00000XP3oool00`00o`00oooo0?ooo`0_0?ooo`00=03o
ool00`00o`00oooo0?ooo`2R0?ooo`030000003oool0oooo0:80oooo00<00?l00?ooo`3oool0;`3o
ool003@0oooo00<00?l00?ooo`3oool0XP3oool00`000000oooo0?ooo`2R0?ooo`03003o003oool0
oooo02l0oooo000e0?ooo`03003o003oool0oooo0:40oooo00<000000?ooo`3oool0X@3oool00`00
o`00oooo0?ooo`0`0?ooo`00=@3oool00`00o`00oooo0?ooo`2Q0?ooo`030000003oool0oooo0:40
oooo00<00?l00?ooo`3oool0<03oool003D0oooo00<00?l00?ooo`3oool0X@3oool00`000000oooo
0?ooo`2Q0?ooo`03003o003oool0oooo0300oooo000e0?ooo`03003o003oool0oooo0:40oooo0`00
002Q0?ooo`03003o003oool0oooo0300oooo000e0?ooo`03003o003oool0oooo0:40oooo00<00000
0?ooo`3oool0X@3oool00`00o`00oooo0?ooo`0`0?ooo`00=@3oool00`00o`00oooo0?ooo`2Q0?oo
o`030000003oool0oooo0:00oooo00<00?l00?ooo`3oool0<@3oool003H0oooo00<00?l00?ooo`3o
ool0X03oool00`000000oooo0?ooo`2P0?ooo`03003o003oool0oooo0340oooo000f0?ooo`03003o
003oool0oooo0:00oooo00<000000?ooo`3oool0X03oool00`00o`00oooo0?ooo`0a0?ooo`00=P3o
ool00`00o`00oooo0?ooo`2P0?ooo`030000003oool0oooo0:00oooo00<00?l00?ooo`3oool0<@3o
ool003H0oooo00<00?l00?ooo`3oool0X03oool3000009l0oooo00<00?l00?ooo`3oool0<P3oool0
03H0oooo00<00?l00?ooo`3oool0N`3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000
M;oo00<0oooo00<0oono07A8W03Oool01@3oool01P3ogi`0B00000000000000004RL0=ooo`X0oooo
00<000000?ooo`3oool0W`3oool00`00o`00oooo0?ooo`0b0?ooo`00=P3oool00`00o`00oooo0?oo
o`1j0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`040?ooo`03
0=nLB018W=l0oooo00@0oooo00H0okmd0000001d_ol0oooo0?oOW018M;l:0?ooo`030000003oool0
oooo09l0oooo00<00?l00?ooo`3oool0<P3oool003L0oooo00<00?l00?ooo`3oool0N03oool00`3o
oml0W4P004RLg`020?ooo`030?noM00004P0W=oo00P0oooo00<0oono07@0M02oool02@3oool00`3o
_g@0B9cO0?ooo`080?ooo`030000003oool0oooo09l0oooo00<00?l00?ooo`3oool0<P3oool003L0
oooo00<00?l00?ooo`3oool0N03oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=oo
o`P0oooo00<0okmd001d_`3oool0203oool00`3ookl0M01d0;ooo`080?ooo`030000003oool0oooo
09l0oooo00<00?l00?ooo`3oool0<P3oool003L0oooo00<00?l00?ooo`3oool0J`3oool00`3ooml0
W4P0000000070000000604RLg`3oool0oooo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`08
0?ooo`030?oog`2LB4P0W=oo00P0oooo00<0oooO09a8001d_ol0203oool00`000000oooo0?ooo`2N
0?ooo`03003o003oool0oooo03<0oooo000g0?ooo`03003o003oool0oooo07T0oooo00<0_g@00018
W03Oool00P3oool00`3ogi`0B00004RLg`090?ooo`030?oOW018M;l0oooo00L0oooo00<0oono07@0
0018W=l0203oool4000009d0oooo00<00?l00?ooo`3oool0<`3oool003P0oooo00<00?l00?ooo`3o
ool0N03oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00X0oooo00<0_g@007Boo`3o
ool01P3oool00`3o_g@0000007Boo`080?ooo`030000003oool0oooo09h0oooo00<00?l00?ooo`3o
ool0<`3oool003P0oooo00<00?l00?ooo`3oool0N03oool00`3ogi`0B00004RLg`030?ooo`030;md
0000B9`0gooo00T0oooo00<0omnL04Q8W03Oool00`3oool01P3ogml0gooo0?noM0000000001d0;oo
o`P0oooo00<000000?ooo`3oool0WP3oool00`00o`00oooo0?ooo`0c0?ooo`00>03oool00`00o`00
oooo0?ooo`1h0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool02P3oool00`3O
W4P0B9cO0?ooo`020?ooo`050?oo_`1d000000000000B02Lgol02@3oool00`000000oooo0?ooo`2N
0?ooo`03003o003oool0oooo03<0oooo000h0?ooo`03003o003oool0oooo07T0oooo00<0omnL04P0
001d_ol00P3oool00`3OW4P007Bo0?ooo`050?ooo`030?oog`3Ogol0oooo0080oooo00<0oono07@0
M02oool00`3oool00`3OW9`0_ooo0?ooo`0:0?ooo`030000003oool0oooo09d0oooo00<00?l00?oo
o`3oool0=03oool003T0oooo00<00?l00?ooo`3oool0N@3oool01P3OW4P0001d0;ooo`3ooml0W4P0
04RLg`L0oooo00<0_gAd0;ooo`3oool00P3oool00`3o_g@007Bo0?ooo`020?ooo`030?oOW01dW=l0
oooo00X0oooo00<000000?ooo`3oool0W@3oool00`00o`00oooo0?ooo`0d0?ooo`00>@3oool00`00
o`00oooo0?ooo`1j0?ooo`040=nLB00000000000001d_`P0oooo00<0oono07@0000000000`000000
0`0004P0W=oo0?ooo`020?ooo`050;md00000000000000000018W=l01`3oool3000009d0oooo00<0
0?l00?ooo`3oool0=03oool003T0oooo00<00?l00?ooo`3oool0W@3oool00`000000oooo0?ooo`2M
0?ooo`03003o003oool0oooo03@0oooo000i0?ooo`03003o003oool0oooo09d0oooo00<000000?oo
o`3oool0W03oool00`00o`00oooo0?ooo`0e0?ooo`00>P3oool00`00o`00oooo0?ooo`2L0?ooo`03
0000003oool0oooo09`0oooo00<00?l00?ooo`3oool0=@3oool003X0oooo00<00?l00?ooo`3oool0
W03oool00`000000oooo0?ooo`2L0?ooo`03003o003oool0oooo03D0oooo000j0?ooo`03003o003o
ool0oooo09`0oooo00<000000?ooo`3oool0W03oool00`00o`00oooo0?ooo`0e0?ooo`00>P3oool0
0`00o`00oooo0?ooo`2L0?ooo`<00000W03oool00`00o`00oooo0?ooo`0e0?ooo`00>`3oool00`00
o`00oooo0?ooo`2K0?ooo`030000003oool0oooo09/0oooo00<00?l00?ooo`3oool0=P3oool003/0
oooo00<00?l00?ooo`3oool0V`3oool00`000000oooo0?ooo`2K0?ooo`03003o003oool0oooo03H0
oooo000k0?ooo`03003o003oool0oooo09/0oooo00<000000?ooo`3oool0V`3oool00`00o`00oooo
0?ooo`0f0?ooo`00>`3oool00`00o`00oooo0?ooo`2K0?ooo`030000003oool0oooo09/0oooo00<0
0?l00?ooo`3oool0=P3oool003`0oooo00<00?l00?ooo`3oool0VP3oool00`000000oooo0?ooo`2J
0?ooo`03003o003oool0oooo03L0oooo000l0?ooo`03003o003oool0oooo09X0oooo0`00002J0?oo
o`03003o003oool0oooo03L0oooo000l0?ooo`03003o003oool0oooo09X0oooo00<000000?ooo`3o
ool0VP3oool00`00o`00oooo0?ooo`0g0?ooo`00?03oool00`00o`00oooo0?ooo`2J0?ooo`030000
003oool0oooo09X0oooo00<00?l00?ooo`3oool0=`3oool003d0oooo00<00?l00?ooo`3oool0V@3o
ool00`000000oooo0?ooo`2J0?ooo`03003o003oool0oooo03L0oooo000m0?ooo`03003o003oool0
oooo09T0oooo00<000000?ooo`3oool0V@3oool00`00o`00oooo0?ooo`0h0?ooo`00?@3oool00`00
o`00oooo0?ooo`2I0?ooo`030000003oool0oooo09T0oooo00<00?l00?ooo`3oool0>03oool003d0
oooo00<00?l00?ooo`3oool0V@3oool3000009T0oooo00<00?l00?ooo`3oool0>03oool003h0oooo
00<00?l00?ooo`3oool0O03oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080
oooo00H0omnL04P00000000000000018W03Oool:0?ooo`030000003oool0oooo09T0oooo00<00?l0
0?ooo`3oool0>03oool003h0oooo00<00?l00?ooo`3oool0N`3oool01P3OW4P007Bo0?ooo`3ogi`0
B00004RLg`80oooo00<0omnL04P0001d_ol00P3oool01P3o_g@0000007Boo`3oool0omnL04Qd_`X0
oooo00<000000?ooo`3oool0V03oool00`00o`00oooo0?ooo`0i0?ooo`00?P3oool00`00o`00oooo
0?ooo`1j0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol02`3oool00`3o_g@0B9cO
0?ooo`080?ooo`030000003oool0oooo09P0oooo00<00?l00?ooo`3oool0>@3oool003h0oooo00<0
0?l00?ooo`3oool0NP3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`X0oooo
00<0oono07@0M02oool0203oool00`000000oooo0?ooo`2H0?ooo`03003o003oool0oooo03T0oooo
000o0?ooo`03003o003oool0oooo06`0oooo00<0oooO09a8000000001`0000001P18W=l0oooo0?oo
o`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol02P3oool00`3ooml0W4P007Boo`080?ooo`03
0000003oool0oooo09P0oooo00<00?l00?ooo`3oool0>@3oool003l0oooo00<00?l00?ooo`3oool0
NP3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00X0oooo00<0oono07@00018W=l0
203oool4000009H0oooo00<00?l00?ooo`3oool0>P3oool003l0oooo00<00?l00?ooo`3oool0NP3o
ool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00X0oooo00<0okmd0000001d_ol0203o
ool00`000000oooo0?ooo`2G0?ooo`03003o003oool0oooo03X0oooo00100?ooo`03003o003oool0
oooo07T0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`060?ooo`060?oOg`3Oool0
okmd0000000007@0_ooo203oool00`000000oooo0?ooo`2G0?ooo`03003o003oool0oooo03X0oooo
00100?ooo`03003o003oool0oooo07T0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL
0=ooo`060?ooo`050?oo_`1d000000000000B02Lgol02@3oool00`000000oooo0?ooo`2G0?ooo`03
003o003oool0oooo03X0oooo00100?ooo`03003o003oool0oooo07X0oooo00<0omnL04P0001d_ol0
0P3oool00`3OW4P007Bo0?ooo`070?ooo`030=nLW02oool0oooo00X0oooo00<000000?ooo`3oool0
UP3oool00`00o`00oooo0?ooo`0k0?ooo`00@03oool00`00o`00oooo0?ooo`1k0?ooo`060=nLB000
07@0_ooo0?oog`2LB000B9cO203oool00`3ogi`0M9cO0?ooo`0:0?ooo`030000003oool0oooo09H0
oooo00<00?l00?ooo`3oool0>`3oool00440oooo00<00?l00?ooo`3oool0N`3oool0103OW4P00000
00000000M;l:0?ooo`050;md00000000000000000018W=l01`3oool3000009H0oooo00<00?l00?oo
o`3oool0>`3oool00440oooo00<00?l00?ooo`3oool0U@3oool00`000000oooo0?ooo`2E0?ooo`03
003o003oool0oooo03`0oooo00110?ooo`03003o003oool0oooo09D0oooo00<000000?ooo`3oool0
U@3oool00`00o`00oooo0?ooo`0l0?ooo`00@P3oool00`00o`00oooo0?ooo`2D0?ooo`030000003o
ool0oooo09D0oooo00<00?l00?ooo`3oool0?03oool00480oooo00<00?l00?ooo`3oool0U03oool0
0`000000oooo0?ooo`2E0?ooo`03003o003oool0oooo03`0oooo00120?ooo`03003o003oool0oooo
09@0oooo00<000000?ooo`3oool0U03oool00`00o`00oooo0?ooo`0m0?ooo`00@`3oool00`00o`00
oooo0?ooo`2C0?ooo`<00000U03oool00`00o`00oooo0?ooo`0m0?ooo`00@`3oool00`00o`00oooo
0?ooo`2C0?ooo`030000003oool0oooo09@0oooo00<00?l00?ooo`3oool0?@3oool004<0oooo00<0
0?l00?ooo`3oool0T`3oool00`000000oooo0?ooo`2D0?ooo`03003o003oool0oooo03d0oooo0014
0?ooo`03003o003oool0oooo0980oooo00<000000?ooo`3oool0T`3oool00`00o`00oooo0?ooo`0n
0?ooo`00A03oool00`00o`00oooo0?ooo`2B0?ooo`030000003oool0oooo09<0oooo00<00?l00?oo
o`3oool0?P3oool004@0oooo00<00?l00?ooo`3oool0TP3oool00`000000oooo0?ooo`2C0?ooo`03
003o003oool0oooo03h0oooo00140?ooo`03003o003oool0oooo0980oooo0`00002B0?ooo`03003o
003oool0oooo03l0oooo00150?ooo`03003o003oool0oooo0940oooo00<000000?ooo`3oool0TP3o
ool00`00o`00oooo0?ooo`0o0?ooo`00A@3oool00`00o`00oooo0?ooo`2A0?ooo`030000003oool0
oooo0980oooo00<00?l00?ooo`3oool0?`3oool004D0oooo00<00?l00?ooo`3oool0T@3oool00`00
0000oooo0?ooo`2B0?ooo`03003o003oool0oooo03l0oooo00160?ooo`03003o003oool0oooo0900
oooo00<000000?ooo`3oool0T@3oool00`00o`00oooo0?ooo`100?ooo`00AP3oool00`00o`00oooo
0?ooo`2@0?ooo`030000003oool0oooo0940oooo00<00?l00?ooo`3oool0@03oool004H0oooo00<0
0?l00?ooo`3oool0T03oool300000940oooo00<00?l00?ooo`3oool0@03oool004L0oooo00<00?l0
0?ooo`3oool0JP3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00<0
gia80000000000000`0000001@18W=l0oooo0?ooo`3ogi`0B0000080000000<004RL0=ooo`3oool0
2@3oool00`000000oooo0?ooo`2@0?ooo`03003o003oool0oooo0440oooo00170?ooo`03003o003o
ool0oooo06T0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00<0
oooo00<0okmd001d_`3oool00P3oool02@2oM7@0_ooo0?ooo`3o_g@0000007Boo`3oool0omnL04Qd
_`0:0?ooo`030000003oool0oooo0900oooo00<00?l00?ooo`3oool0@@3oool004L0oooo00<00?l0
0?ooo`3oool0J03oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00P0oooo00<0okmd
001d_`3oool02@3oool00`3o_g@0B9cO0?ooo`080?ooo`030000003oool0oooo0900oooo00<00?l0
0?ooo`3oool0@@3oool004P0oooo00<00?l00?ooo`3oool0I`3oool00`3ooml0W4P004RLg`020?oo
o`040?oog`2LB00004RL0=ooo`P0oooo00<0okmd001d_`3oool0203oool00`3ookl0M01d0;ooo`08
0?ooo`030000003oool0oooo08l0oooo00<00?l00?ooo`3oool0@P3oool004P0oooo00<00?l00?oo
o`3oool0FP3oool00`3ooml0W4P0000000070000000604RLg`3oool0oooo0?oog`2LB00007Bo0`3o
ool00`3OW4P0001809cOo`090?ooo`030?noM018W=l0oooo00L0oooo00<0oooO09a8001d_ol0203o
ool00`000000oooo0?ooo`2?0?ooo`03003o003oool0oooo0480oooo00180?ooo`03003o003oool0
oooo06P0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?ooo`030=nLB018W=l0
oooo00H0oooo00<0oono07@00018W=l0203oool4000008d0oooo00<00?l00?ooo`3oool0@`3oool0
04T0oooo00<00?l00?ooo`3oool0I`3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo
00/0oooo00<0_g@007Boo`3oool01@3oool00`3o_g@0000007Boo`080?ooo`030000003oool0oooo
08h0oooo00<00?l00?ooo`3oool0@`3oool004T0oooo00<00?l00?ooo`3oool0I`3oool00`3ogi`0
B00004RLg`030?ooo`030;md0000B9`0gooo00X0oooo00<0omnL04P0M02oool00P3oool01P3ogml0
gooo0?noM0000000001d0;ooo`P0oooo00<000000?ooo`3oool0SP3oool00`00o`00oooo0?ooo`13
0?ooo`00B@3oool00`00o`00oooo0?ooo`1W0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia8
0018W03Oool02P3oool00`3ooml0W4P007Boo`020?ooo`050?oo_`1d000000000000B02Lgol02@3o
ool00`000000oooo0?ooo`2=0?ooo`03003o003oool0oooo04@0oooo001:0?ooo`03003o003oool0
oooo06L0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`0:0?ooo`030?oo_`1d0000
B9cO00<0oooo00<0gibL0;ooo`3oool02P3oool00`000000oooo0?ooo`2=0?ooo`03003o003oool0
oooo04@0oooo001:0?ooo`03003o003oool0oooo06P0oooo00H0gia80000M02oool0oooO09a80018
W=l70?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cOo`030?ooo`030?oOW01dW=l0oooo00X0
oooo00<000000?ooo`3oool0S@3oool00`00o`00oooo0?ooo`140?ooo`00B`3oool00`00o`00oooo
0?ooo`1X0?ooo`040=nLB00000000000001d_`T0oooo00D0omnL04P000000000000007Boo`050?oo
o`050;md00000000000000000018W=l01`3oool3000008`0oooo00<00?l00?ooo`3oool0A@3oool0
04/0oooo00<00?l00?ooo`3oool0R`3oool00`000000oooo0?ooo`2<0?ooo`03003o003oool0oooo
04D0oooo001;0?ooo`03003o003oool0oooo08/0oooo00<000000?ooo`3oool0S03oool00`00o`00
oooo0?ooo`150?ooo`008@3oool00`3OW4P00000000000030000000304RLg`3oool0oooo0280oooo
00<00?l00?ooo`3oool0;`3oool00`3ookl0M000000000020000000304RLg`3oool0oooo05<0oooo
00<000000?ooo`3oool0EP3oool00`3ookl0M000000000020000000304RLg`3oool0oooo02d0oooo
00<00?l00?ooo`3oool09P3oool00`3OW4P00000000000030000000304RLg`3oool0oooo01L0oooo
000R0?ooo`030?noM000M;l0oooo0080oooo00<0_gAd0;ooo`3oool08P3oool00`00o`00oooo0?oo
o`0a0?ooo`030?noM0000000M;oo05H0oooo00<000000?ooo`3oool0F03oool00`3o_g@0000007Bo
o`0`0?ooo`03003o003oool0oooo02L0oooo00<0okmd001d_`3oool00P3oool00`2oM7@0_ooo0?oo
o`0G0?ooo`008`3oool00`3o_g@007Bo0?ooo`0V0?ooo`03003o003oool0oooo0340oooo00<0oooO
09a80000M;l0EP3oool00`000000oooo0?ooo`1H0?ooo`030?oog`2LB00007Bo02l0oooo00<00?l0
0?ooo`3oool0:@3oool00`3o_g@007Bo0?ooo`0K0?ooo`00903oool00`3o_g@007Bo0?ooo`0V0?oo
o`03003o003oool0oooo0340oooo00<0gia80018W03Oool0E@3oool3000005T0oooo00<0gia80018
W03Oool0;P3oool00`00o`00oooo0?ooo`0Z0?ooo`030?noM000M;l0oooo01X0oooo000D0?ooo`03
0?oog`2LB000000000L0000000<0B9cO0?ooo`3oool0103oool00`3o_g@0B9cO0?ooo`0U0?ooo`03
003o003oool0oooo0240oooo00<0oooO09a8000000001`0000000`18W=l0oooo0?ooo`030?ooo`03
0?oOW01804P0W=oo05D0oooo00<000000?ooo`3oool0F@3oool00`3ogi`0B01809cOo`0^0?ooo`03
003o003oool0oooo02/0oooo00<0okmd04RLg`3oool06@3oool002H0oooo00<0gia804RLg`3oool0
903oool00`00o`00oooo0?ooo`0a0?ooo`030?oo_`1d0000M;oo05D0oooo00<000000?ooo`3oool0
F@3oool00`3ookl0M00007Boo`0]0?ooo`03003o003oool0oooo02d0oooo00<0gia804RLg`3oool0
603oool002L0oooo00<0_g@007Boo`3oool0903oool00`00o`00oooo0?ooo`0a0?ooo`030;md0000
M;l0oooo05@0oooo00<000000?ooo`3oool0FP3oool00`2oM00007Bo0?ooo`0/0?ooo`03003o003o
ool0oooo02h0oooo00<0_g@007Boo`3oool05`3oool002L0oooo00<0omnL04P0M02oool0903oool0
0`00o`00oooo0?ooo`0a0?ooo`030=nLB000B9`0gooo05@0oooo00<000000?ooo`3oool0FP3oool0
0`3OW4P004RL0=ooo`0/0?ooo`03003o003oool0oooo02h0oooo00<0omnL04P0M02oool05`3oool0
02L0oooo00<0oooO09a8001d_ol09@3oool00`00o`00oooo0?ooo`0`0?ooo`030?oOW01804P0W=oo
05@0oooo00<000000?ooo`3oool0FP3oool00`3ogi`0B01809cOo`0[0?ooo`03003o003oool0oooo
02l0oooo00<0oooO09a8001d_ol05`3oool002L0oooo00<0oono07@00018W=l09@3oool00`00o`00
oooo0?ooo`0`0?ooo`030?oo_`1d0000M;oo05@0oooo0`00001J0?ooo`030?oo_`1d0000M;oo02/0
oooo00<00?l00?ooo`3oool0;`3oool00`3ookl0M00004RLg`0G0?ooo`008`3oool01`3o_g@004RL
0=ooo`3oool0gia80000B02Lgol09P3oool00`00o`00oooo0?ooo`0`0?ooo`030;md0000M;l0oooo
05<0oooo00<000000?ooo`3oool0F`3oool00`2oM00007Bo0?ooo`0Y0?ooo`03003o003oool0oooo
02`0oooo00L0okmd0018W03Oool0oooo0=nLB00004P0W=oo01L0oooo000T0?ooo`050?oOW0180000
00000000001d_ol09`3oool00`00o`00oooo0?ooo`0^0?ooo`050?oo_`1d000000000000M02oool0
D`3oool00`000000oooo0?ooo`1I0?ooo`050?oo_`1d000000000000M02oool0:@3oool00`00o`00
oooo0?ooo`0]0?ooo`050?oOW018000000000000001d_ol0603oool00540oooo00<00?l00?ooo`3o
ool0Q@3oool00`000000oooo0?ooo`260?ooo`03003o003oool0oooo04/0oooo001A0?ooo`03003o
003oool0oooo08D0oooo00<000000?ooo`3oool0QP3oool00`00o`00oooo0?ooo`1;0?ooo`00DP3o
ool00`00o`00oooo0?ooo`240?ooo`030000003oool0oooo08D0oooo00<00?l00?ooo`3oool0C03o
ool00580oooo00<00?l00?ooo`3oool0Q03oool00`000000oooo0?ooo`250?ooo`03003o003oool0
oooo04`0oooo001C0?ooo`03003o003oool0oooo08<0oooo0`0000240?ooo`03003o003oool0oooo
04d0oooo001C0?ooo`03003o003oool0oooo08<0oooo00<000000?ooo`3oool0Q03oool00`00o`00
oooo0?ooo`1=0?ooo`00E03oool00`00o`00oooo0?ooo`220?ooo`030000003oool0oooo08<0oooo
00<00?l00?ooo`3oool0CP3oool005@0oooo00<00?l00?ooo`3oool0PP3oool00`000000oooo0?oo
o`230?ooo`03003o003oool0oooo04h0oooo001E0?ooo`03003o003oool0oooo0840oooo00<00000
0?ooo`3oool0PP3oool00`00o`00oooo0?ooo`1?0?ooo`00E@3oool00`00o`00oooo0?ooo`210?oo
o`030000003oool0oooo0880oooo00<00?l00?ooo`3oool0C`3oool001D0oooo@@0000000`00o`00
00000000001e00000080o`005P000?l00`3o000000000000001d00000003003o00000000000003h0
00004P3oool001l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00l0oooo00<00?l00000003oool0403oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0100oooo00<00000003o00000?l01P000?l90?ooo`030000003oool0oooo00X0oooo
10000?l00`3o0000oooo0000000B0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
403oool00`0000000?l00?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0I0?ooo`007`3oool00`000000oooo0?ooo`0e0?ooo`03003o003o
ool0oooo0280oooo00<000000?ooo`3oool0A@3oool00`00o`00003o0000o`020000oa00oooo00<0
00000?ooo`3oool03P3oool40000o`030?l0003oool0oooo04H0oooo00<000000?ooo`3oool08P3o
ool00`00o`00oooo0?ooo`0e0?ooo`030000003oool0oooo01T0oooo001H0?ooo`03003o003oool0
oooo06H0oooo00@00?l00?l000000?l0003o503oool00`000000oooo0?ooo`0B0?ooo`@0003o00<0
o`000?ooo`3oool0IP3oool00`00o`00oooo0?ooo`1B0?ooo`00F03oool00`00o`00oooo0?ooo`1T
0?ooo`04003o003o0000003o0000oaH0oooo00<000000?ooo`3oool05P3oool20000o`030?l0003o
ool0oooo06@0oooo00<00?l00?ooo`3oool0DP3oool005T0oooo00<00?l00?ooo`3oool0H03oool0
0`00o`00o`000000o`020000oaP0oooo00<000000?ooo`3oool0603oool20000o`80o`00HP3oool0
0`00o`00oooo0?ooo`1C0?ooo`00FP3oool00`00o`00oooo0?ooo`1L0?ooo`800?l00`000?lK0?oo
o`<000006P3oool20000o`80o`00G`3oool00`00o`00oooo0?ooo`1D0?ooo`00FP3oool00`00o`00
oooo0?ooo`1J0?ooo`800?l00P000?lN0?ooo`030000003oool0oooo01`0oooo0P000?l20?l005d0
oooo00<00?l00?ooo`3oool0E03oool005/0oooo00<00?l00?ooo`3oool0E`3oool2003o0080003o
803oool00`000000oooo0?ooo`0N0?ooo`80003o0P3o001J0?ooo`03003o003oool0oooo05D0oooo
001L0?ooo`03003o003oool0oooo05@0oooo0P00o`020000ob80oooo00<000000?ooo`3oool0803o
ool20000o`80o`00E`3oool00`00o`00oooo0?ooo`1F0?ooo`00G03oool00`00o`00oooo0?ooo`1B
0?ooo`800?l00P000?lT0?ooo`030000003oool0oooo0280oooo0P000?l20?l00003003o003oool0
oooo0580oooo00<00?l00?ooo`3oool0EP3oool005d0oooo00<00?l00?ooo`3oool0C`3oool2003o
00030?l000000?l0oooo02D0oooo00<000000?ooo`3oool0903oool20000o`80o`0000<00?l00?oo
o`3oool0C`3oool00`00o`00oooo0?ooo`1G0?ooo`00GP3oool00`00o`00oooo0?ooo`1<0?ooo`80
0?l000<0oooo0?l000000?l09`3oool3000002H0oooo00<0003o0?ooo`3o00000P00o`1>0?ooo`03
003o003oool0oooo05P0oooo001N0?ooo`03003o003oool0oooo04T0oooo0`00o`00103oool0o`00
0000o`000?lX0?ooo`030000003oool0oooo02L0oooo00@0003o0?ooo`3o0000o`000`00o`1:0?oo
o`03003o003oool0oooo05T0oooo001O0?ooo`03003o003oool0oooo04H0oooo0P00o`020?ooo`80
o`0000<0003o0?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`80003o00@0oooo0?l0003o
0000oooo0P00o`180?ooo`03003o003oool0oooo05T0oooo001O0?ooo`03003o003oool0oooo04@0
oooo0P00o`030?ooo`030?l0003oool0003o02/0oooo00<000000?ooo`3oool0:P3oool010000?l0
oooo0?ooo`3o00020?ooo`800?l0A@3oool00`00o`00oooo0?ooo`1J0?ooo`00H03oool00`00o`00
oooo0?ooo`110?ooo`800?l00`3oool20?l000030?ooo`000?l0oooo02/0oooo00<000000?ooo`3o
ool0:`3oool010000?l0oooo0?ooo`3o00030?ooo`800?l0@P3oool00`00o`00oooo0?ooo`1K0?oo
o`00H@3oool00`00o`00oooo0?ooo`0n0?ooo`800?l0103oool0103o0000oooo0?ooo`000?l]0?oo
o`030000003oool0oooo02`0oooo00<0003o0?ooo`3oool00P3o00030?ooo`800?l0?`3oool00`00
o`00oooo0?ooo`1L0?ooo`00HP3oool00`00o`00oooo0?ooo`0k0?ooo`800?l01@3oool0103o0000
oooo0?ooo`000?l^0?ooo`<00000;@3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo0P00o`0m
0?ooo`03003o003oool0oooo05`0oooo001S0?ooo`03003o003oool0oooo03P0oooo0P00o`050?oo
o`80o`000P3oool00`000?l0oooo0?ooo`0]0?ooo`030000003oool0oooo02h0oooo00D0003o0?oo
o`3oool0oooo0?l000050?ooo`800?l0>P3oool00`00o`00oooo0?ooo`1M0?ooo`00I03oool00`00
o`00oooo0?ooo`0e0?ooo`800?l01P3oool00`3o0000oooo0?ooo`020000oc00oooo00<000000?oo
o`3oool0;`3oool01@000?l0oooo0?ooo`3oool0o`0000H0oooo0P00o`0g0?ooo`03003o003oool0
oooo05h0oooo001U0?ooo`03003o003oool0oooo0380oooo0P00o`070?ooo`040?l0003oool0oooo
0000oc80oooo00<000000?ooo`3oool0<03oool010000?l0oooo0?ooo`3oool20?l000H0oooo0P00
o`0d0?ooo`03003o003oool0oooo05l0oooo001V0?ooo`800?l0<03oool2003o00L0oooo0P3o0002
0?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0<@3oool20000o`<0oooo00<0o`00
0?ooo`3oool01@3oool2003o0300oooo0P00o`1R0?ooo`00J03oool00`00o`00oooo0?ooo`0[0?oo
o`800?l0203oool01@3o0000oooo0?ooo`3oool0003o03@0oooo00<000000?ooo`3oool0<`3oool0
1@000?l0oooo0?ooo`3oool0o`0000P0oooo0P00o`0]0?ooo`03003o003oool0oooo0680oooo001Y
0?ooo`800?l0:@3oool2003o00T0oooo00D0o`000?ooo`3oool0oooo0000o`0e0?ooo`<00000=03o
ool01@000?l0oooo0?ooo`3oool0o`0000T0oooo0P00o`0Z0?ooo`03003o003oool0oooo06<0oooo
001[0?ooo`800?l0903oool3003o00T0oooo0P3o00030?ooo`030000o`3oool0oooo00l0oooo00@0
_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB0000000000000<00000
00D0B9cO0?ooo`3oool0omnL04P00002000000030018W03Oool0oooo00T0oooo00<000000?ooo`3o
ool0=@3oool010000?l0oooo0?ooo`3oool20?l000T0oooo0P00o`0V0?ooo`800?l0IP3oool006d0
oooo0P00o`0N0?ooo`@00?l02`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00l0
oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00<0oooo00<0okmd
001d_`3oool00P3oool02@2oM7@0_ooo0?ooo`3o_g@0000007Boo`3oool0omnL04Qd_`0:0?ooo`03
0000003oool0oooo03H0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`080?ooo`<0
0?l08@3oool2003o06P0oooo001_0?ooo`03003o003oool0oooo01P0oooo0`00o`0>0?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool03`3oool00`3ooml0W4P004RLg`020?ooo`030?no
M00004P0W=oo00P0oooo00<0okmd001d_`3oool02@3oool00`3o_g@0B9cO0?ooo`080?ooo`030000
003oool0oooo03L0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0:0?ooo`@00?l0
6`3oool2003o06X0oooo001`0?ooo`800?l05P3oool2003o0100oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`0?0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo
203oool00`3o_g@007Bo0?ooo`080?ooo`030?oo_`1d07@0_ooo00P0oooo00<000000?ooo`3oool0
>03oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00d0oooo0`00o`0E0?ooo`<00?l0
K03oool00780oooo1P00o`0:0?ooo`H00?l04@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo0100oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`090?ooo`030?noM018
W=l0oooo00L0oooo00<0oooO09a8001d_ol0203oool00`000000oooo0?ooo`0i0?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool03`3oool6003o00/0oooo1000o`1_0?ooo`00N03oool:
003o01H0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0B0?ooo`030;md0000B9`0
gooo0080oooo00<0omnL04P00018W=l02P3oool00`3OW4P0B9cO0?ooo`060?ooo`030?oo_`1d0000
B9cO00P0oooo1000000i0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0503oool;
003o07<0oooo002G0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool04`3oool00`3O
W4P0001809cOo`020?ooo`030?oog`2LB00007Bo00/0oooo00<0_g@007Boo`3oool01@3oool00`3o
_g@0000007Boo`080?ooo`030000003oool0oooo03X0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`2A0?ooo`00UP3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo01@0
oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`0:0?ooo`030?oOW01807@0_ooo0080
oooo00H0omoO0=ooo`3o_g@000000000M02oool80?ooo`030000003oool0oooo03/0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`2@0?ooo`00U@3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo01D0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`0:
0?ooo`030?oog`2LB000M;oo0080oooo00D0oono07@000000000001809cOo`090?ooo`030000003o
ool0oooo03`0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`2?0?ooo`00T`3oool2
0?l000H0oooo00<0003o0?ooo`3oool05P3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0
oooo00X0oooo00<0oono07@00018W=l00`3oool00`3OW9`0_ooo0?ooo`0:0?ooo`030000003oool0
oooo03d0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`2>0?ooo`00TP3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo01P0oooo00H0gia80000M02oool0oooO09a80018
W=l70?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cOo`030?ooo`030?oOW01dW=l0oooo00X0
oooo00<000000?ooo`3oool0?@3oool00`000?l0oooo0?ooo`040?ooo`80o`00SP3oool00940oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0J0?ooo`040=nLB00000000000001d_`T0
oooo00D0omnL04P000000000000007Boo`050?ooo`050;md00000000000000000018W=l01`3oool3
000003h0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`2;0?ooo`00T03oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo03d0oooo00<000000?ooo`3oool0?`3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo08X0oooo002?0?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool0?P3oool00`000000oooo0?ooo`100?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0R@3oool008h0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`0o0?ooo`030000003oool0oooo0400oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`280?ooo`00S@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo0400oooo00<0
00000?ooo`3oool0@@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo08L0oooo002<
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0@03oool00`000000oooo0?ooo`12
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0QP3oool008/0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`110?ooo`<00000@P3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo08D0oooo002:0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool0@P3oool00`000000oooo0?ooo`130?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool0Q03oool008T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`120?ooo`030000
003oool0oooo04<0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`230?ooo`00R@3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0A03o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo08<0oooo00280?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool0A03oool00`000000oooo0?ooo`150?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool0PP3oool008L0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`140?ooo`030000003oool0oooo04D0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`210?ooo`00QP3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo04D0
oooo0`0000160?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0P03oool008D0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo04L0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`1o0?ooo`00Q03oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo04L0oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo07h0oooo00240?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool0A`3oool00`000000oooo0?ooo`180?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool0OP3oool008<0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`180?oo
o`030000003oool0oooo04P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`1m0?oo
o`00PP3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo04T0oooo00<000000?ooo`3o
ool0B@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo07`0oooo00210?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool0B@3oool3000004T0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`1k0?ooo`00P03oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo02h0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`060?oO
W0180000000000000000B9`0gooo2P3oool00`000000oooo0?ooo`1:0?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`3oool0NP3oool007l0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0]0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`02
0?ooo`060?noM0000000M;oo0?ooo`3ogi`0B7Bo2P3oool00`000000oooo0?ooo`1:0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0N@3oool007l0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`0]0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol02`3o
ool00`3o_g@0B9cO0?ooo`080?ooo`030000003oool0oooo04/0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`1i0?ooo`00OP3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo02d0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool:0?ooo`030?oo_`1d
07@0_ooo00P0oooo00<000000?ooo`3oool0B`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo07P0oooo001m0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0;P3oool0
0`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00X0oooo00<0oooO09a8001d_ol0203oool0
0`000000oooo0?ooo`1<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0M`3oool0
07`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0_0?ooo`030;md0000B9`0gooo
0080oooo00<0omnL04P00018W=l02P3oool00`3ookl0M00004RLg`080?ooo`@00000B`3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo07H0oooo001k0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool0<03oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00X0
oooo00<0okmd0000001d_ol0203oool00`000000oooo0?ooo`1=0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0M@3oool007/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0`0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01P3oool01P3ogml0gooo
0?noM0000000001d0;ooo`P0oooo00<000000?ooo`3oool0C@3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo07D0oooo001j0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool0<@3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00H0oooo00D0oono07@0
00000000001809cOo`090?ooo`030000003oool0oooo04h0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`1d0?ooo`00N@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
0380oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`070?ooo`030=nLW02oool0oooo
00X0oooo00<000000?ooo`3oool0CP3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo
07<0oooo001i0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0=03oool01P3OW4P0
001d0;ooo`3ooml0W4P004RLg`P0oooo00<0omnL07BLg`3oool02P3oool00`000000oooo0?ooo`1?
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0L`3oool007P0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0e0?ooo`040=nLB00000000000001d_`X0oooo00D0_g@0
000000000000000004RLg`070?ooo`<00000C`3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo0780oooo001g0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0D03oool0
0`000000oooo0?ooo`1@0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0L@3oool0
07L0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`1@0?ooo`030000003oool0oooo
0500oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`1`0?ooo`00MP3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo0540oooo00<000000?ooo`3oool0D@3oool00`000?l0
oooo0?ooo`0=0?ooo`030?l0003oool0oooo0700oooo001e0?ooo`030?l0003oool0oooo00d0oooo
00<0003o0?ooo`3oool0D@3oool00`000000oooo0?ooo`1A0?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool0K`3oool007@0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`1B0?ooo`030000003oool0oooo0580oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?oo
o`1^0?ooo`00M03oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo0580oooo0`00001B
0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0KP3oool007<0oooo00<0o`000?oo
o`3oool03P3oool00`000?l0oooo0?ooo`1B0?ooo`030000003oool0oooo05<0oooo00<0003o0?oo
o`3oool03P3oool00`3o0000oooo0?ooo`1]0?ooo`00LP3oool00`3o0000oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo05<0oooo00<000000?ooo`3oool0D`3oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo06`0oooo001b0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0
D`3oool00`000000oooo0?ooo`1D0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0
K03oool00740oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`1D0?ooo`030000003o
ool0oooo05@0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`1[0?ooo`00L03oool0
0`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo05@0oooo00<000000?ooo`3oool0E@3oool0
0`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo06X0oooo001`0?ooo`030?l0003oool0oooo
00h0oooo00<0003o0?ooo`3oool0E@3oool3000005D0oooo00<0003o0?ooo`3oool0403oool00`3o
0000oooo0?ooo`1Y0?ooo`00K`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo05D0
oooo00<000000?ooo`3oool0EP3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo06T0
oooo001^0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0E@3oool00`000000oooo
0?ooo`1F0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0J03oool006h0oooo00<0
o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`1F0?ooo`030000003oool0oooo05L0oooo00<0
003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`1W0?ooo`00K@3oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo05H0oooo00<000000?ooo`3oool0E`3oool00`000?l0oooo0?ooo`0@
0?ooo`030?l0003oool0oooo06L0oooo001/0?ooo`030?l0003oool0oooo0100oooo00<0003o0?oo
o`3oool0E`3oool00`000000oooo0?ooo`1H0?ooo`030000o`3oool0oooo0100oooo00<0o`000?oo
o`3oool0IP3oool006`0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1G0?ooo`<0
0000F03oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo06D0oooo001[0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool0<P3oool0102oM00000000000001d_ol30?ooo`03
0?oOW0180000M;oo00<0oooo00<0oono07A8W03Oool01@3oool01P3ogi`0B00000000000000004RL
0=ooo`X0oooo00<000000?ooo`3oool0F03oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo06D0oooo001Z0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0<P3oool01P3O
W4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol0103oool00`3OW4P0B9cO0?oo
o`040?ooo`060?noM0000000M;oo0?ooo`3ogi`0B7Bo2P3oool00`000000oooo0?ooo`1I0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0I03oool006X0oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0a0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0
203oool00`3ookl0M01d0;ooo`090?ooo`030?noM018W=l0oooo00P0oooo00<000000?ooo`3oool0
F@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo06@0oooo001Y0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool0<P3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2L
B00004RL0=ooo`P0oooo00<0okmd001d_`3oool0203oool00`3ookl0M01d0;ooo`080?ooo`030000
003oool0oooo05T0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`1S0?ooo`00J@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0380oooo00<0oooO09a80000M;l00`3o
ool00`3OW4P0001809cOo`080?ooo`030?oog`2LB4P0W=oo00P0oooo00<0oooO09a8001d_ol0203o
ool00`000000oooo0?ooo`1J0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool0HP3o
ool006P0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0d0?ooo`030;md0000B9`0
gooo0080oooo00<0omnL04P00018W=l02@3oool00`3ogi`0B7Bo0?ooo`070?ooo`030?oo_`1d0000
B9cO00P0oooo1000001I0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool0HP3oool0
06L0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0d0?ooo`030=nLB00004P0W=oo
0080oooo00<0oooO09a80000M;l02P3oool00`2oM000M;oo0?ooo`060?ooo`030?noM0000000M;oo
00P0oooo00<000000?ooo`3oool0FP3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo
0640oooo001W0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0=03oool00`3ogi`0
B00004RLg`030?ooo`030;md0000B9`0gooo00T0oooo00<0omnL04Q8W03Oool00`3oool01P3ogml0
gooo0?noM0000000001d0;ooo`P0oooo00<000000?ooo`3oool0F`3oool00`000?l0oooo0?ooo`0C
0?ooo`030?l0003oool0oooo0600oooo001V0?ooo`030?l0003oool0oooo0180oooo00<0003o0?oo
o`3oool0=@3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00X0oooo00<0gia8
04RLg`3oool00P3oool01@3ookl0M0000000000004P0W=oo00T0oooo00<000000?ooo`3oool0F`3o
ool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo0600oooo001U0?ooo`030?l0003oool0
oooo01<0oooo00<0003o0?ooo`3oool0=P3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0
oooo00D0oooo00<0oooO0=oOo`3oool00P3oool00`3ookl0M01d0;ooo`030?ooo`030=nLW02oool0
oooo00X0oooo00<000000?ooo`3oool0G03oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0
oooo05l0oooo001U0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0=`3oool01P3O
W4P0001d0;ooo`3ooml0W4P004RLg`L0oooo00<0_gAd0;ooo`3oool00P3oool00`3o_g@007Bo0?oo
o`020?ooo`030?oOW01dW=l0oooo00X0oooo00<000000?ooo`3oool0G03oool00`000?l0oooo0?oo
o`0C0?ooo`030?l0003oool0oooo05l0oooo001T0?ooo`030?l0003oool0oooo01<0oooo00<0003o
0?ooo`3oool0>@3oool0103OW4P0000000000000M;l80?ooo`030?oo_`1d0000000000<0000000<0
001809cOo`3oool00P3oool01@2oM0000000000000000000B9cO00L0oooo0`00001L0?ooo`030000
o`3oool0oooo01@0oooo00<0o`000?ooo`3oool0GP3oool006<0oooo00<0o`000?ooo`3oool0503o
ool00`000?l0oooo0?ooo`1L0?ooo`030000003oool0oooo05d0oooo00<0003o0?ooo`3oool0503o
ool00`3o0000oooo0?ooo`1M0?ooo`00H`3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0
oooo05`0oooo00<000000?ooo`3oool0G@3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0
oooo05d0oooo001R0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0G@3oool00`00
0000oooo0?ooo`1M0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool0G03oool00640
oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`1M0?ooo`030000003oool0oooo05h0
oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`1L0?ooo`00H@3oool00`3o0000oooo
0?ooo`0E0?ooo`030000o`3oool0oooo05d0oooo00<000000?ooo`3oool0GP3oool00`000?l0oooo
0?ooo`0E0?ooo`030?l0003oool0oooo05/0oooo001P0?ooo`030?l0003oool0oooo01D0oooo00<0
003o0?ooo`3oool0GP3oool00`000000oooo0?ooo`1N0?ooo`030000o`3oool0oooo01H0oooo00<0
o`000?ooo`3oool0FP3oool00600oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`1N
0?ooo`<00000G`3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo05X0oooo001O0?oo
o`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool0GP3oool00`000000oooo0?ooo`1O0?oo
o`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool0F@3oool005h0oooo00<0o`000?ooo`3o
ool05P3oool00`000?l0oooo0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<0003o0?ooo`3o
ool05`3oool00`3o0000oooo0?ooo`1H0?ooo`00GP3oool00`3o0000oooo0?ooo`0F0?ooo`030000
o`3oool0oooo05l0oooo00<000000?ooo`3oool0H03oool00`000?l0oooo0?ooo`0F0?ooo`030?l0
003oool0oooo05P0oooo001M0?ooo`030?l0003oool0oooo01L0oooo00<0003o0?ooo`3oool0G`3o
ool00`000000oooo0?ooo`1P0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool0E`3o
ool005`0oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`1P0?ooo`030000003oool0
oooo0600oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`1G0?ooo`00G03oool00`3o
0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo0600oooo0`00001Q0?ooo`030000o`3oool0oooo
01L0oooo00<0o`000?ooo`3oool0EP3oool005/0oooo00<0o`000?ooo`3oool0603oool00`000?l0
oooo0?ooo`1P0?ooo`030000003oool0oooo0640oooo00<0003o0?ooo`3oool05`3oool00`3o0000
oooo0?ooo`1F0?ooo`00F`3oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo0640oooo
00<000000?ooo`3oool0H@3oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo05D0oooo
001J0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool0H@3oool00`000000oooo0?oo
o`1R0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool0E@3oool005X0oooo00<0o`00
0?ooo`3oool0603oool00`000?l0oooo0?ooo`1Q0?ooo`030000003oool0oooo0680oooo00<0003o
0?ooo`3oool0603oool00`3o0000oooo0?ooo`1D0?ooo`00F@3oool00`3o0000oooo0?ooo`0H0?oo
o`030000o`3oool0oooo0680oooo00<000000?ooo`3oool0H`3oool00`000?l0oooo0?ooo`0G0?oo
o`030?l0003oool0oooo05@0oooo001I0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3o
ool0HP3oool3000006<0oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`1C0?ooo`00
F03oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo0540oooo00<0oono07@000000000
0P0000000`18W=l0oooo0?ooo`090?ooo`030000003oool0oooo06<0oooo00<0003o0?ooo`3oool0
603oool00`3o0000oooo0?ooo`1C0?ooo`00F03oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3o
ool0oooo05@0oooo00<0okmd0000001d_ol0303oool00`000000oooo0?ooo`1T0?ooo`030000o`3o
ool0oooo01P0oooo00<0o`000?ooo`3oool0DP3oool005L0oooo00<0o`000?ooo`3oool06@3oool0
0`000?l0oooo0?ooo`1D0?ooo`030?oog`2LB00007Bo00`0oooo00<000000?ooo`3oool0I03oool0
0`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo0580oooo001G0?ooo`030?l0003oool0oooo
01T0oooo00<0003o0?ooo`3oool0E@3oool00`3OW4P004RL0=ooo`0;0?ooo`030000003oool0oooo
06@0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`1A0?ooo`00EP3oool00`3o0000
oooo0?ooo`0I0?ooo`030000o`3oool0oooo05H0oooo00<0omnL04P0B02Lgol02`3oool00`000000
oooo0?ooo`1U0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool0D@3oool005H0oooo
00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?ooo`1F0?ooo`030?oo_`1d0000M;oo00/0oooo
1000001T0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0D03oool00<`0oooo00<0
_g@0001d_`3oool0h@3oool00<`0oooo00<0gia80018W03Oool0h@3oool00<`0oooo00<0omnL04P0
B02Lgol0h@3oool00<`0oooo00<0oono07@0001d_ol0h@3oool00<d0oooo00<0_g@0001d_`3oool0
h03oool00</0oooo00D0oono07@000000000001d0;ooo`3P0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.33329, -1.09711, \
0.0160666, 0.0123792}}]
}, Closed]],

Cell[TextData[{
  "The phase diagram for simple harmonic motion in a parabolic well is \
circular as both position and velocity are represented by complementary \
sinusoidal functions (circular functions), but for nonparabolic wells the \
phase diagrams are slightly deformed and the periods differ from ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]/\[Omega]\_0\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(plot1\  = \ 
        duffingPlot[1, 0, 0.0, 0, 0, 0.5, 0, 0, 10, \ 
          PlotLabel \[Rule] "\<Free Conservative Oscillations\>", 
          PlotStyle \[Rule] RGBColor[1, 0, 0], 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(plot2\  = \ 
        duffingPlot[1, 1, 0.0, 0, 0, 0.5, 0, 0, 10, 
          PlotStyle \[Rule] RGBColor[0, 0, 1], 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(plot3\  = \ 
        duffingPlot[1, \(-1\), 0.0, 0, 0, 0.5, 0, 0, 10, 
          PlotStyle \[Rule] RGBColor[0, 1, 0], 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[{plot1, plot2, plot3}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.952382 0.500001 0.897917 [
[.11905 -0.0125 -13.8438 -15.6875 ]
[.11905 -0.0125 13.8438 0 ]
[.30952 -0.0125 -13.8438 -15.6875 ]
[.30952 -0.0125 13.8438 0 ]
[.5 -0.0125 -5 -15.6875 ]
[.5 -0.0125 5 0 ]
[.69048 -0.0125 -9.5 -15.6875 ]
[.69048 -0.0125 9.5 0 ]
[.88095 -0.0125 -9.5 -15.6875 ]
[.88095 -0.0125 9.5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.9688 -31.375 ]
[.5 -0.0125 21.9688 -15.6875 ]
[-0.0125 .14083 -27.6875 -7.84375 ]
[-0.0125 .14083 0 7.84375 ]
[-0.0125 .32042 -27.6875 -7.84375 ]
[-0.0125 .32042 0 7.84375 ]
[-0.0125 .5 -10 -7.84375 ]
[-0.0125 .5 0 7.84375 ]
[-0.0125 .67958 -19 -7.84375 ]
[-0.0125 .67958 0 7.84375 ]
[-0.0125 .85917 -19 -7.84375 ]
[-0.0125 .85917 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -43.375 -20.4688 ]
[-0.01875 .5 -27.6875 20.4688 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -76.6875 0 ]
[.5 1.0125 76.6875 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
gsave
.11905 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.30952 0 m
.30952 .00625 L
s
gsave
.30952 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.69048 0 m
.69048 .00625 L
s
gsave
.69048 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.88095 0 m
.88095 .00625 L
s
gsave
.88095 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.9688 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
102.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .14083 m
.00625 .14083 L
s
gsave
-0.0125 .14083 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .32042 m
.00625 .32042 L
s
gsave
-0.0125 .32042 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .67958 m
.00625 .67958 L
s
gsave
-0.0125 .67958 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .85917 m
.00625 .85917 L
s
gsave
-0.0125 .85917 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .18573 m
.00375 .18573 L
s
0 .23063 m
.00375 .23063 L
s
0 .27552 m
.00375 .27552 L
s
0 .36531 m
.00375 .36531 L
s
0 .41021 m
.00375 .41021 L
s
0 .4551 m
.00375 .4551 L
s
0 .5449 m
.00375 .5449 L
s
0 .58979 m
.00375 .58979 L
s
0 .63469 m
.00375 .63469 L
s
0 .72448 m
.00375 .72448 L
s
0 .76938 m
.00375 .76938 L
s
0 .81427 m
.00375 .81427 L
s
0 .09594 m
.00375 .09594 L
s
0 .05104 m
.00375 .05104 L
s
0 .00615 m
.00375 .00615 L
s
0 .90406 m
.00375 .90406 L
s
0 .94896 m
.00375 .94896 L
s
0 .99386 m
.00375 .99386 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -117 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
81.4688 11.8438 translate
90 rotate
-81.4688 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(velocity) show
99.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11905 .99375 m
.11905 1 L
s
.30952 .99375 m
.30952 1 L
s
.5 .99375 m
.5 1 L
s
.69048 .99375 m
.69048 1 L
s
.88095 .99375 m
.88095 1 L
s
.125 Mabswid
.16667 .99625 m
.16667 1 L
s
.21429 .99625 m
.21429 1 L
s
.2619 .99625 m
.2619 1 L
s
.35714 .99625 m
.35714 1 L
s
.40476 .99625 m
.40476 1 L
s
.45238 .99625 m
.45238 1 L
s
.54762 .99625 m
.54762 1 L
s
.59524 .99625 m
.59524 1 L
s
.64286 .99625 m
.64286 1 L
s
.7381 .99625 m
.7381 1 L
s
.78571 .99625 m
.78571 1 L
s
.83333 .99625 m
.83333 1 L
s
.07143 .99625 m
.07143 1 L
s
.02381 .99625 m
.02381 1 L
s
.92857 .99625 m
.92857 1 L
s
.97619 .99625 m
.97619 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .14083 m
1 .14083 L
s
.99375 .32042 m
1 .32042 L
s
.99375 .5 m
1 .5 L
s
.99375 .67958 m
1 .67958 L
s
.99375 .85917 m
1 .85917 L
s
.125 Mabswid
.99625 .18573 m
1 .18573 L
s
.99625 .23063 m
1 .23063 L
s
.99625 .27552 m
1 .27552 L
s
.99625 .36531 m
1 .36531 L
s
.99625 .41021 m
1 .41021 L
s
.99625 .4551 m
1 .4551 L
s
.99625 .5449 m
1 .5449 L
s
.99625 .58979 m
1 .58979 L
s
.99625 .63469 m
1 .63469 L
s
.99625 .72448 m
1 .72448 L
s
.99625 .76938 m
1 .76938 L
s
.99625 .81427 m
1 .81427 L
s
.99625 .09594 m
1 .09594 L
s
.99625 .05104 m
1 .05104 L
s
.99625 .00615 m
1 .00615 L
s
.99625 .90406 m
1 .90406 L
s
.99625 .94896 m
1 .94896 L
s
.99625 .99386 m
1 .99386 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .5 m
1 .5 L
s
.5 0 m
.5 1 L
s
gsave
.5 1.0125 -137.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Free) show
88.563 15.813 moveto
(Conservative) show
154.563 15.813 moveto
(Oscillations) show
212.375 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.97619 .5 m
.97615 .49446 L
.97606 .48942 L
.97587 .4836 L
.97562 .4781 L
.975 .46834 L
.97408 .45775 L
.97275 .44612 L
.97099 .43383 L
.96694 .41191 L
.96155 .38952 L
.9554 .3688 L
.93754 .32283 L
.91396 .2781 L
.88789 .23957 L
.85239 .19803 L
.81496 .16327 L
.738 .11114 L
.69332 .0897 L
.66756 .07975 L
.64335 .07187 L
.61979 .06548 L
.59356 .05979 L
.5669 .0555 L
.55224 .05375 L
.54567 .05311 L
.5385 .05251 L
.53173 .05204 L
.52546 .05168 L
.51946 .05142 L
.51308 .05121 L
.50739 .0511 L
.50205 .05105 L
.49619 .05106 L
.48987 .05114 L
.48354 .05131 L
.47996 .05144 L
.47662 .05158 L
.46932 .05197 L
.46269 .05242 L
.45067 .05346 L
.43787 .05488 L
.41393 .05844 L
.38882 .06345 L
.34466 .0756 L
.29878 .09309 L
.25083 .11741 L
.20903 .1446 L
.17372 .17299 L
.13644 .21005 L
Mistroke
.10606 .24777 L
.08023 .28802 L
.06081 .32648 L
.04388 .37103 L
.03673 .39611 L
.03142 .42003 L
.02783 .44178 L
.0263 .45418 L
.02519 .46578 L
.02473 .47209 L
.02438 .47806 L
.02413 .48343 L
.02395 .48926 L
.02388 .49228 L
.02383 .49561 L
.02381 .49909 L
.02382 .50235 L
.02389 .50817 L
.02396 .51144 L
.02406 .51443 L
.02426 .51952 L
.02454 .52495 L
.02523 .5347 L
.02635 .54628 L
.02763 .55676 L
.03133 .57948 L
.03594 .60071 L
.04929 .64489 L
.06852 .68993 L
.08895 .72665 L
.11542 .76475 L
.18049 .8329 L
.22304 .86521 L
.26505 .89051 L
.30928 .91138 L
.35209 .92675 L
.37694 .93371 L
.40062 .93907 L
.4256 .94345 L
.43896 .94526 L
.45343 .94681 L
.46534 .94777 L
.47202 .94818 L
.4781 .94848 L
.48378 .9487 L
.48994 .94886 L
.49576 .94894 L
.50113 .94896 L
.50738 .94891 L
.51322 .94879 L
Mistroke
.51963 .94858 L
.52652 .94826 L
.53371 .94783 L
.54054 .94733 L
.55333 .94614 L
.57923 .9427 L
.60305 .93832 L
.62888 .9322 L
.65596 .9242 L
.7036 .90586 L
.75241 .8807 L
.79534 .85218 L
.83166 .82216 L
.89235 .75442 L
.92011 .71138 L
.94125 .66881 L
.95006 .64669 L
.95822 .62218 L
.96417 .60024 L
.9692 .57667 L
.97257 .55529 L
.97399 .54306 L
.97453 .53746 L
.97501 .53156 L
.97536 .52653 L
.97567 .52102 L
.97589 .51601 L
.97604 .51135 L
.97615 .50583 L
.97619 .50081 L
.97616 .49501 L
.97606 .48955 L
.97589 .48411 L
.97563 .47827 L
.97531 .47275 L
.97496 .46773 L
.97384 .45544 L
.97245 .44382 L
.96873 .42086 L
.96326 .39608 L
.94985 .35275 L
.93336 .31391 L
.90874 .26966 L
.88097 .23064 L
.81819 .16598 L
.78012 .13694 L
.73677 .11047 L
.69754 .09149 L
.65262 .07472 L
.62746 .06742 L
Mistroke
.60332 .06174 L
.5814 .05765 L
.5574 .05432 L
.54491 .05304 L
.53111 .052 L
.52416 .05162 L
.52032 .05145 L
.51667 .05132 L
.51329 .05122 L
.5096 .05113 L
.50313 .05105 L
.49652 .05105 L
.49052 .05113 L
.48719 .0512 L
.4836 .05131 L
.47708 .05156 L
.47096 .05188 L
.4645 .05229 L
.45295 .05324 L
.44031 .05458 L
.42838 .05615 L
.40613 .05985 L
.38242 .06494 L
.35697 .07177 L
.31236 .08737 L
.27273 .10547 L
.19563 .15472 L
.15676 .18881 L
.12413 .22435 L
.09602 .26231 L
.07107 .30501 L
.05375 .34331 L
.03921 .38675 L
.03326 .411 L
.02896 .43416 L
.02749 .44432 L
.0262 .4551 L
.0251 .46696 L
.0247 .47258 L
.02438 .47793 L
.02411 .48404 L
.02394 .48962 L
.02383 .49564 L
.02381 .49905 L
.02381 .5022 L
.02388 .50798 L
.02402 .51321 L
.02425 .51924 L
.02454 .52492 L
.02496 .53121 L
Mistroke
.0255 .53784 L
.02673 .54969 L
.02843 .56241 L
.03073 .57629 L
.03563 .59941 L
.04144 .62103 L
.05536 .6607 L
.07465 .70184 L
.10044 .74424 L
Mfstroke
0 0 1 r
.97619 .5 m
.97615 .49307 L
.97603 .48677 L
.97579 .4795 L
.97548 .47264 L
.97471 .46044 L
.97355 .44724 L
.97189 .43277 L
.9697 .41751 L
.96465 .39042 L
.95796 .36295 L
.95035 .33775 L
.92836 .28284 L
.89962 .23109 L
.86821 .18818 L
.82655 .14447 L
.78225 .10906 L
.73905 .08243 L
.69017 .05958 L
.66556 .05053 L
.64195 .04322 L
.61879 .03727 L
.59692 .0327 L
.57259 .02877 L
.55963 .02714 L
.54569 .02576 L
.53868 .02521 L
.53104 .02471 L
.52382 .02434 L
.51713 .02408 L
.51112 .02392 L
.50449 .02383 L
.49756 .02381 L
.49105 .02388 L
.48533 .02401 L
.47907 .02422 L
.47255 .02451 L
.46648 .02486 L
.45561 .02565 L
.44402 .02675 L
.41765 .0302 L
.39388 .0345 L
.3689 .04029 L
.34282 .04778 L
.29731 .06479 L
.25055 .08824 L
.20247 .12022 L
.16145 .15585 L
.12775 .19312 L
.09395 .24139 L
Mistroke
.06747 .29189 L
.0479 .34313 L
.03941 .37298 L
.03328 .4006 L
.0289 .42689 L
.02702 .44183 L
.02568 .45562 L
.02479 .46777 L
.02442 .47467 L
.02415 .48112 L
.02395 .48794 L
.02384 .49414 L
.02381 .50131 L
.02387 .5081 L
.02402 .51484 L
.02427 .52209 L
.0246 .52893 L
.02498 .53519 L
.02615 .54969 L
.02781 .56488 L
.03213 .59329 L
.03862 .62383 L
.04566 .64964 L
.05462 .67651 L
.07439 .72285 L
.10276 .77256 L
.13956 .82095 L
.17948 .86093 L
.22008 .89256 L
.26406 .91924 L
.30753 .9395 L
.3573 .95657 L
.38595 .96381 L
.41245 .96895 L
.4376 .97254 L
.45037 .97389 L
.45775 .97452 L
.46452 .97502 L
.47026 .97537 L
.47655 .97568 L
.48288 .97592 L
.48955 .97609 L
.49544 .97617 L
.50174 .97619 L
.50769 .97614 L
.51309 .97603 L
.51994 .97582 L
.52339 .97568 L
.52719 .9755 L
.54019 .97468 L
Mistroke
.54749 .97408 L
.55533 .97332 L
.56946 .97166 L
.597 .96728 L
.62192 .96199 L
.67187 .9473 L
.71653 .92896 L
.76311 .90358 L
.80926 .87049 L
.84963 .83283 L
.88805 .78599 L
.91868 .73641 L
.94148 .68679 L
.95061 .66145 L
.95889 .63358 L
.96478 .60897 L
.96981 .58177 L
.97217 .56502 L
.97387 .54944 L
.97507 .53448 L
.97551 .52691 L
.9757 .52284 L
.97586 .51855 L
.97608 .51103 L
.97617 .50414 L
.97618 .49672 L
.97614 .49251 L
.97607 .4886 L
.97587 .48148 L
.9756 .47502 L
.9752 .46757 L
.97472 .46055 L
.97348 .44652 L
.97198 .43345 L
.96736 .40398 L
.96127 .37572 L
.95301 .34602 L
.93366 .29443 L
.9113 .25027 L
.88127 .20473 L
.84919 .1667 L
.80978 .12994 L
.76367 .09677 L
.71576 .07068 L
.68947 .0593 L
.66106 .04903 L
.63562 .04148 L
.60731 .03475 L
.58125 .03003 L
.55677 .02683 L
Mistroke
.54297 .02554 L
.5302 .02466 L
.52352 .02432 L
.51616 .02405 L
.51246 .02395 L
.50847 .02388 L
.50471 .02383 L
.50126 .02381 L
.49458 .02384 L
.48837 .02393 L
.48157 .02413 L
.47776 .02427 L
.47431 .02442 L
.46114 .02522 L
.44875 .02627 L
.42431 .0292 L
.40198 .03291 L
.3777 .0381 L
.35237 .04486 L
.30519 .06146 L
.25684 .08468 L
.2139 .11178 L
.17748 .14084 L
.14226 .176 L
.10906 .21812 L
.07825 .26947 L
.05547 .32118 L
.03949 .37267 L
.03289 .40261 L
.03038 .41701 L
.0284 .43051 L
.02684 .44349 L
.0257 .45533 L
.02475 .46852 L
.02436 .47579 L
.02409 .48266 L
.02392 .48935 L
.02382 .49644 L
.02381 .50249 L
.02389 .50916 L
.02406 .51631 L
.02435 .52399 L
.02473 .53123 L
.02517 .53785 L
.02643 .55253 L
.02792 .56578 L
.03249 .59521 L
.03819 .62206 L
.04484 .64687 L
.06414 .70053 L
Mistroke
.09147 .75448 L
.12081 .79803 L
.15801 .84073 L
.2018 .87926 L
.24652 .90942 L
.29579 .93456 L
.32101 .94472 L
.34481 .95284 L
.39031 .96475 L
.41471 .96933 L
.44083 .97291 L
.45185 .97402 L
Mfstroke
0 1 0 r
.97619 .5 m
.97616 .49584 L
.97609 .49206 L
.97595 .4877 L
.97577 .48357 L
.9753 .47624 L
.9746 .46828 L
.97361 .45952 L
.97228 .45024 L
.96923 .43362 L
.96517 .41651 L
.96052 .40053 L
.94691 .36444 L
.92876 .3282 L
.90845 .29576 L
.85025 .22669 L
.78669 .17348 L
.74602 .14735 L
.70563 .12629 L
.66053 .10784 L
.63766 .10038 L
.61627 .09449 L
.59692 .09005 L
.57545 .08609 L
.5537 .0831 L
.54175 .08189 L
.53057 .08103 L
.52469 .08068 L
.51843 .0804 L
.51309 .08022 L
.50718 .08009 L
.50389 .08005 L
.50086 .08004 L
.49754 .08004 L
.49405 .08008 L
.48816 .08019 L
.48482 .08028 L
.48172 .08039 L
.47569 .08066 L
.47001 .08099 L
.45938 .08179 L
.44797 .08291 L
.43563 .08444 L
.41402 .0879 L
.39136 .09264 L
.35149 .10376 L
.31063 .11905 L
.26872 .13914 L
.19949 .18363 L
.16537 .21194 L
Mistroke
.13196 .24514 L
.10397 .27862 L
.08209 .31009 L
.06373 .3421 L
.04773 .37733 L
.04065 .39694 L
.03522 .41505 L
.03105 .4323 L
.02915 .44181 L
.02762 .45082 L
.0264 .45946 L
.02534 .46885 L
.02496 .473 L
.02461 .47739 L
.02435 .48151 L
.02415 .48529 L
.024 .48909 L
.02388 .49319 L
.02383 .4968 L
.02381 .50059 L
.02384 .50477 L
.02393 .50866 L
.02407 .51292 L
.02429 .51746 L
.0246 .52239 L
.02495 .52693 L
.02599 .53717 L
.02717 .5462 L
.02871 .55573 L
.03205 .57222 L
.03671 .59029 L
.04897 .62578 L
.06365 .65776 L
.08495 .69437 L
.10856 .72731 L
.16315 .78604 L
.19904 .81603 L
.23589 .84168 L
.31112 .88116 L
.35408 .89707 L
.37878 .90424 L
.40214 .90976 L
.42332 .91371 L
.44616 .91689 L
.45926 .9182 L
.46572 .91872 L
.47167 .91911 L
.47699 .9194 L
.48284 .91965 L
.48872 .91983 L
Mistroke
.49194 .91989 L
.49496 .91994 L
.50105 .91996 L
.50449 .91994 L
.50769 .9199 L
.51355 .91977 L
.51682 .91966 L
.51978 .91955 L
.52539 .91928 L
.53146 .91892 L
.54243 .91806 L
.5553 .91672 L
.56884 .91493 L
.59292 .91077 L
.61549 .90571 L
.63579 .90018 L
.68026 .88471 L
.71971 .86688 L
.7552 .84721 L
.82665 .79513 L
.8816 .73942 L
.92509 .67816 L
.94405 .64194 L
.95791 .60738 L
.96779 .57293 L
.97133 .55552 L
.97292 .54553 L
.9741 .53644 L
.97495 .52801 L
.97556 .52006 L
.9758 .51569 L
.97598 .51166 L
.97611 .50723 L
.97615 .505 L
.97618 .50255 L
.97619 .49844 L
.97615 .49469 L
.97604 .49036 L
.97589 .48626 L
.97571 .48247 L
.97549 .47897 L
.97487 .47103 L
.97387 .46164 L
.97271 .45303 L
.96924 .43363 L
.96519 .41659 L
.95992 .39867 L
.94836 .3678 L
.93221 .33442 L
.88901 .26962 L
Mistroke
.85878 .2353 L
.82772 .2058 L
.75948 .15542 L
.71655 .13154 L
.67455 .11304 L
.63211 .09875 L
.61122 .09325 L
.59112 .08888 L
.56725 .08484 L
.55661 .08344 L
.54523 .08221 L
.53876 .08163 L
.53289 .08118 L
.52691 .08081 L
.5214 .08052 L
.51496 .08028 L
.51156 .08018 L
.50798 .08011 L
.50194 .08004 L
.49852 .08004 L
.49532 .08006 L
.48943 .08016 L
.48645 .08023 L
.48317 .08034 L
.47738 .08058 L
.47194 .08087 L
.45973 .08176 L
.4466 .08306 L
.42271 .08639 L
.401 .09048 L
.36029 .101 L
.31875 .11569 L
.27886 .13385 L
.23855 .15664 L
.17314 .20506 L
.14122 .2353 L
.11063 .27008 L
.06646 .3369 L
.06264 .34422 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00g03oool00`3ooml0W4P0000000020000000307Bo
o`3oool0oooo0<`0oooo003N0?ooo`030?noM00007@0_ooo0<l0oooo003N0?ooo`030?oo_`1d0000
M;oo0<l0oooo003N0?ooo`030?oog`2LB000B9cO0<l0oooo003O0?ooo`030=nLB000000000000080
000000<0M;oo0?ooo`3oool00P3oool01@3o_g@000000000000004P0W=oo0080oooo00<0oono07@0
000000000P0000003@18W=l0oooo0?ooo`3oool0_g@00000000004P0W=oo0?ooo`3o_g@000000000
B02Lgol00P3oool0102oM00000000000B02Lgol20?ooo`050?noM000000000000000B02Lgol00`3o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000000007Bo09H0oooo003O0?ooo`070?noM00004P0
W=oo0?ooo`3ooml0W4P0001d_`020?ooo`0?0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`3oool0
oooO09a8001d_ol0oooo0?oOW0180000M;oo0080oooo01L0gia80018W03Ooml0W7BL0=ooo`3o_g@0
001809cOg`2LM9`0gooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0
B000001d_`020?ooo`030?noM00007@0_ooo0080oooo00@0gia80018W03O_g@0M;ooU@3oool00=l0
oooo00<0oono07@0001d_ol00P3oool01`3ooml0W4P004RLg`3oool0gia80018W03Oool00P3oool0
2P3ogi`0B00004RLg`3oool0_gAd0;ooo`3oool0oono07@0001d_ol20?ooo`030?noM00004P0W=oo
0080oooo00<0oono07@0001d_ol00`3oool00`3o_g@0001809cOo`020?ooo`030=nLB000B9`0gooo
0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol0UP3o
ool00=l0oooo00<0oooO09a80018W=l00`3oool01P3ogi`0B01809cOo`3o_g@0001d0;ooo`<0oooo
00<0gia80000M02oool00`3oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo
00<0_g@0001d_`3oool00P3oool00`3ookl0M00004RLg`020?ooo`030?noM00007@0_ooo00<0oooo
00/0gia80000M02oool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`2F0?ooo`00h03oool0
0`3OW4P0001d0;ooo`020?ooo`060?oog`2LB000B9cO0?oo_`1d0000M;oo0`3oool00`3ogi`0B018
09cOo`020?ooo`030?noM00004P0W=oo00@0oooo00<0_g@00018W03Oool00P3oool00`3OW4P004RL
0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3ookl0M00007Boo`030?ooo`070?oOW01804P0W=oo
0?ooo`3OW4P004Q804Qd_`020?ooo`030;md0000M;l0oooo09D0oooo003P0?ooo`040?noM0000000
04RL0=ooo`80oooo00H0gia8001d_`3oool0gia80000M02oool20?ooo`0:0?oo_`1d0000M;oo0?oo
o`3ogi`0B01809cOo`3oool0giad09cOo`80oooo00<0gia80000B02Lgol00P3oool00`3ogi`0B018
09cOo`030?ooo`030=nLB00004P0W=oo0080oooo00<0gia80000M02oool00P3oool0303ookl0M000
07Boo`3oool0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;oooiD0oooo003P0?ooo`080?oo_`1d
0000M9bL04P0M02oool0oooO09a80000M;l20?ooo`0>0;md000007@0_ooo0?ooo`3o_g@0001d0;oo
o`3oool0omnL04P0B02Lgol0oooO09a8001d_ol20?ooo`030?oOW0180000B9cO0080oooo00<0oooO
09a80018W=l00`3oool00`3ogi`0B00004RLg`030?ooo`0@0;md000007@0_ooo0?ooo`3o_g@0001d
0;ooo`3oool0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOoiD0oooo003O0?ooo`090?oOW018
0000000004RLg`3ookl0M0000000000007@0_ooo00<0oooo00D0okmd000000000000000007Boo`03
0?ooo`070;md00000000000000000018W=l0oooo0?noM002000000040018W03Oool0oono07@000<0
000000H0M;oo0?noM000000000000018W03Oool30?ooo`0?0?noM000000000000000001d_ol0oooo
0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo09D0oooo003o0?ooo`40oooo00<0okmd
0000M02oool0[@3oool00?l0oooo0P3oool00`3OW7@0W=oo0?ooo`2/0?ooo`00n`3oool0103ookl0
M0000018W03Oool70?ooo`040?oo_`1d000004RL0=ooojH0oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo001b0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol0
1@3oool00`3ooml0W4P004RLg`0a0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d
_ol00P3oool00`3OW4P00000000000030000000304RLg`3oool0oooo02h0oooo00@0_g@000000000
0000M;oo>03oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00<0gia8
0000000000000`0000000`18W=l0oooo0?ooo`0^0?ooo`040;md00000000000007Boo`<0oooo00<0
omnL04P0001d_ol01@3oool00`3ooml0W4P004RLg`0W0?ooo`00L@3oool01P3OW4P007Bo0?ooo`3o
gi`0B00004RLg`80oooo00<0omnL04P0001d_ol01P3oool00`3OW4P004RL0=ooo`0_0?ooo`060=nL
B000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`030?ooo`030?noM000M;l0oooo
0080oooo00<0_gAd0;ooo`3oool0;@3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLgcH0oooo00H0
gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00<0oooo00<0okmd001d_`3o
ool00P3oool00`2oM7@0_ooo0?ooo`0]0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool0
0`3ogi`0B00007Boo`060?ooo`030=nLB000B9`0gooo02H0oooo001`0?ooo`030?oog`2LB000B9cO
0080oooo00<0okmd0000B02Lgol02P3oool00`3ogi`0B01809cOo`0^0?ooo`030?oog`2LB000B9cO
0080oooo00<0okmd0000B02Lgol0203oool00`3o_g@007Bo0?ooo`0`0?ooo`030?oog`2LB000B9cO
0080oooo00<0okmd0000B02Lgol0=03oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo
00P0oooo00<0okmd001d_`3oool0<03oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo
00X0oooo00<0omnL04P0B02Lgol09P3oool00700oooo00<0oooO09a80018W=l00P3oool0103ooml0
W4P00018W03Oool50?ooo`030?noM0000000000000@0000000<004RL0=ooo`3oool0:`3oool00`3o
oml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<0okmd001d_`3oool0;`3oool0
0`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=oooc<0oooo00<0oooO09a80018W=l00P3o
ool0103ooml0W4P00018W03Oool80?ooo`030?noM000M;l0oooo02l0oooo00<0oooO09a80018W=l0
0P3oool0103ooml0W4P00018W03Oool50?ooo`030?noM0000000000000@0000000<004RL0=ooo`3o
ool08`3oool006<0oooo00<0oooO09a8000000001`0000001P18W=l0oooo0?ooo`3ooml0W4P0001d
_`<0oooo00<0gia80000B02Lgol01@3oool00`3ooml0W4Q809cOo`020?ooo`030;md0000M;l0oooo
0200oooo00<0oooO09a8000000001`0000001P18W=l0oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0
gia80000B02Lgol02@3oool00`3o_g@0B9cO0?ooo`0^0?ooo`030?oog`2LB00007Bo00<0oooo00<0
gia80000B02Lgol0<`3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00T0oooo00<0
okmd04RLg`3oool0;P3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00D0oooo00<0
oooO09a8B02Lgol00P3oool00`2oM00007Bo0?ooo`0U0?ooo`00L@3oool00`2oM00004RL0=ooo`02
0?ooo`030?oOW0180000B9cO00H0oooo00L0oono07@0M02oool0oooo0?noM000B9`0gooo02h0oooo
00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?ooo`030=nLB018W=l0oooo02h0oooo
00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0d0?ooo`030;md0000B9`0gooo0080oooo
00<0omnL04P00018W=l02P3oool00`3OW4P0B9cO0?ooo`0^0?ooo`030;md0000B9`0gooo0080oooo
00<0omnL04P00018W=l01P3oool01`3ookl0M01d0;ooo`3oool0okmd0018W03Oool09@3oool00740
oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`070?ooo`060?oOW018B9`0gooo0?oO
W01804P0W=oo;P3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00/0oooo00<0_g@0
07Boo`3oool0;@3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo03@0oooo00<0gia8
0000B02Lgol00P3oool00`3ooml0W4P0001d_`0;0?ooo`030;md001d_ol0oooo02d0oooo00<0gia8
0000B02Lgol00P3oool00`3ooml0W4P0001d_`070?ooo`060?oOW018B9`0gooo0?oOW01804P0W=oo
9@3oool00740oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`070?ooo`050?noM000
M;l0oooO09a80018W=l0;P3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00X0oooo
00<0omnL04P0M02oool0;@3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo03<0oooo
00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`0:0?ooo`030?oOW01807@0_ooo02d0oooo
00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`070?ooo`050?noM000M;l0oooO09a80018
W=l09@3oool00740oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`080?ooo`04
0=nLB018W=l0_g@0001d_bh0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`0:
0?ooo`030?oog`2LB000M;oo02d0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=oo
o`0c0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool02P3oool00`3ooml0W4P0
07Boo`0]0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0203oool0103OW4P0
B9cO0;md0000M;lU0?ooo`00LP3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00T0
oooo00@0gia807AdM00007@0_ooo;P3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo
00X0oooo00<0oono07@00018W=l0;P3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo
03@0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`0:0?ooo`030?oo_`1d0000B9cO
02h0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`090?ooo`040=nLB01dM7@0001d
0;ooob@0oooo001c0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO2`3oool00`2oM000001809cO
o`0_0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO1`3oool01`3o_g@004RL0=ooo`3oool0gia8
0000B02Lgol0;`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLgcH0oooo00H0gia80000M02oool0
oooO09a80018W=l70?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cOo`0_0?ooo`060=nLB000
07@0_ooo0?oog`2LB000B9cO2`3oool00`2oM000001809cOo`0T0?ooo`00M03oool0103OW4P00000
00000000M;l<0?ooo`030?oog`2LB000B9cO0300oooo00@0gia800000000000007Bo2@3oool01@3o
gi`0B000000000000000M;oo0340oooo00@0gia800000000000007Bo>03oool0103OW4P000000000
0000M;l90?ooo`050?oOW018000000000000001d_ol0<@3oool0103OW4P0000000000000M;l<0?oo
o`030?oog`2LB000B9cO02@0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo001;0?ooool00000HP0000040?ooo`00B`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo001;0?ooo`800000:03oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo02D0oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`2]0?ooo`030000003o
ool0oooo0:d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0[@3oool0
0`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
0:d0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo0:D0oooo3`000?nY0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo09L0oooo3P000?l80?ooo`030000003oool0oooo00@0oooo3`000?nJ
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0940oooo1P000?lF0?oo
o`030000003oool0oooo0100oooo2`000?nB0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo08`0oooo1`000?lJ0?ooo`030000003oool0oooo01L0oooo2P000?n<0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo08H0oooo1`000?lP0?ooo`030000
003oool0oooo01h0oooo1`000?n80?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo0840oooo1P000?lV0?ooo`030000003oool0oooo02@0oooo1@000?n40?ooo`030000003o
ool0oooo0080oooo001;0?ooo`030000003oool0oooo07h0oooo10000?l[0?ooo`030000003oool0
oooo02L0oooo1P000?n00?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
07/0oooo0`000?l_0?ooo`030000003oool0oooo02/0oooo1P000?ml0?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo07L0oooo10000?lb0?ooo`030000003oool0oooo02l0
oooo10000?mj0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo07@0oooo
10000?le0?ooo`030000003oool0oooo03<0oooo10000?mf0?ooo`030000003oool0oooo0080oooo
001;0?ooo`800000L`3oool30000obT0oooo7P3o000Z0?ooo`<0003oLP3oool3000000@0oooo001;
0?ooo`030000003oool0oooo06l0oooo0`000?lS0?ooo`X0o`003P3oool00`000000oooo0?ooo`0;
0?ooo``0o`008P3oool30000og40oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool0K03oool40000ob40oooo1P3o000F0?ooo`030000003oool0oooo01D0oooo1`3o000P0?oo
o`<0003oKP3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1Z0?ooo`<0
003o7@3oool70?l001`0oooo00<000000?ooo`3oool06`3oool60?l001d0oooo10000?m[0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo06L0oooo0`000?lK0?ooo`H0o`00
8P3oool00`000000oooo0?ooo`0O0?ooo`H0o`00703oool30000ofT0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool0I@3oool20000oaX0oooo1@3o000W0?ooo`030000003o
ool0oooo02@0oooo1@3o000J0?ooo`<0003oI`3oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`1S0?ooo`80003o603oool50?l002/0oooo00<000000?ooo`3oool0:03oool5
0?l001T0oooo0P000?mU0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
0640oooo0P000?lF0?ooo`H0o`00;P3oool00`000000oooo0?ooo`0/0?ooo`D0o`005`3oool20000
of<0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0G`3oool20000oaH0
oooo103o000b0?ooo`030000003oool0oooo0300oooo103o000F0?ooo`80003oH@3oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1M0?ooo`80003o5@3oool40?l003D0oooo
00<000000?ooo`3oool0=03oool30?l001D0oooo0P000?mO0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo05/0oooo0P000?lE0?ooo`<0o`00;03ooolH003o02d0oooo103o
000D0?ooo`80003oG@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1I
0?ooo`80003o503oool40?l002@0oooo2`00o`0;0?ooo`030000003oool0oooo00L0oooo3@00o`0U
0?ooo`@0o`004`3oool20000oe/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool0E`3oool20000oa@0oooo0`3o000Q0?ooo`P00?l0503oool00`000000oooo0?ooo`0C0?oo
o`H00?l08`3oool40?l00140oooo0`000?mI0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo05D0oooo0P000?lC0?ooo`<0o`00803oool6003o01X0oooo00<000000?ooo`3o
ool06@3oool6003o01l0oooo103o000A0?ooo`<0003oE`3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`1C0?ooo`80003o4`3oool30?l001d0oooo1P00o`0O0?ooo`030000
003oool0oooo01d0oooo1P00o`0N0?ooo`<0o`004@3oool20000oeH0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool0DP3oool00`000?l0oooo0?ooo`0@0?ooo`<0o`00703o
ool6003o02<0oooo00<000000?ooo`3oool08`3oool5003o01/0oooo0`3o000A0?ooo`80003oE03o
ool00`000000oooo0?ooo`020?ooo`00B`3oool200000540oooo0P000?lA0?ooo`<0o`006@3oool6
003o02P0oooo00<000000?ooo`3oool09P3oool6003o01T0oooo0`3o000A0?ooo`80003oD03oool3
000000@0oooo001;0?ooo`030000003oool0oooo04h0oooo0P000?lA0?ooo`80o`00603oool6003o
02`0oooo00<000000?ooo`3oool0:P3oool5003o01P0oooo0`3o000@0?ooo`80003oD@3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1=0?ooo`80003o403oool20?l001L0
oooo1000o`0a0?ooo`030000003oool0oooo02d0oooo1000o`0H0?ooo`<0o`00403oool20000odl0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0B`3oool20000oa00oooo
0P3o000G0?ooo`<00?l0=03oool00`000000oooo0?ooo`0`0?ooo`@00?l05`3oool30?l000l0oooo
0`000?m=0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo04T0oooo0P00
0?l@0?ooo`80o`005P3oool3003o03L0oooo00<000000?ooo`3oool0<`3oool4003o01H0oooo0`3o
000>0?ooo`<0003oC03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`18
0?ooo`80003o3`3oool20?l001H0oooo0`00o`0i0?ooo`030000003oool0oooo03H0oooo0`00o`0F
0?ooo`80o`003`3oool20000od/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool0A`3oool00`000?l0oooo0?ooo`0=0?ooo`<0o`00503oool3003o03`0oooo00<000000?oo
o`3oool0>@3oool3003o01D0oooo0P3o000>0?ooo`<0003oB@3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`150?ooo`80003o3P3oool30?l001@0oooo0`00o`0n0?ooo`03
0000003oool0oooo03`0oooo0`00o`0D0?ooo`80o`003P3oool20000odP0oooo00<000000?ooo`3o
ool00P3oool004/0oooo00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`0<0?ooo`<0o`00
4`3oool3003o0440oooo00<000000?ooo`3oool0?P3oool3003o01<0oooo0P3o000>0?ooo`80003o
A`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`130?ooo`030000o`3o
ool0oooo00`0oooo0`3o000B0?ooo`<00?l0@`3oool00`000000oooo0?ooo`110?ooo`<00?l04P3o
ool20?l000h0oooo00<0003o0?ooo`3oool0A03oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`110?ooo`80003o3@3oool30?l00180oooo0`00o`150?ooo`030000003oool0
oooo04<0oooo0`00o`0A0?ooo`<0o`003@3oool00`000?l0oooo0?ooo`130?ooo`030000003oool0
oooo0080oooo000_0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol01@3oool0
0`3ooml0W4P004RLg`0:0?ooo`030000003oool0oooo0400oooo0P000?l=0?ooo`<0o`004@3oool2
003o04P0oooo00<000000?ooo`3oool0AP3oool2003o0140oooo0P3o000=0?ooo`80003o@`3oool0
0`000000oooo0?ooo`020?ooo`00;P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0
omnL04P0001d_ol01P3oool00`3OW4P004RL0=ooo`090?ooo`030000003oool0oooo03l0oooo0P00
0?l<0?ooo`<0o`004@3oool2003o04X0oooo00<000000?ooo`3oool0B03oool2003o0100oooo0`3o
000=0?ooo`030000o`3oool0oooo0400oooo00<000000?ooo`3oool00P3oool002d0oooo00<0oooO
09a80018W=l00P3oool00`3o_g@0001809cOo`0:0?ooo`030?oOW01804P0W=oo00T0oooo00<00000
0?ooo`3oool0?@3oool30000o``0oooo0P3o000A0?ooo`800?l0C03oool00`000000oooo0?ooo`1:
0?ooo`800?l0403oool30?l000`0oooo00<0003o0?ooo`3oool0?`3oool00`000000oooo0?ooo`02
0?ooo`00;@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`D0oooo00<0okmd
000000000000100000000`00B9`0gooo0?ooo`060?ooo`030000003oool0oooo03`0oooo00<0003o
0?ooo`000?l02`3oool30?l00100oooo0P00o`1>0?ooo`030000003oool0oooo04`0oooo0P00o`0?
0?ooo`<0o`00303oool00`000?l0oooo0?ooo`0n0?ooo`030000003oool0oooo0080oooo000P0?oo
o`030?oog`2LB000000000L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`030=nLB000
04P0W=oo00D0oooo00<0oooO09a8B02Lgol00P3oool00`2oM00007Bo0?ooo`080?ooo`<00000>`3o
ool30000o`/0oooo0P3o000@0?ooo`800?l0D03oool00`000000oooo0?ooo`1=0?ooo`800?l0403o
ool30?l000/0oooo0P000?lk0?ooo`@00000103oool002h0oooo00<0_g@00018W03Oool00P3oool0
0`3ogi`0B00004RLg`060?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@004RL0=ooo`080?ooo`030000
003oool0oooo03X0oooo0P000?l;0?ooo`<0o`003`3oool2003o0580oooo00<000000?ooo`3oool0
C`3oool2003o00l0oooo0`3o000;0?ooo`80003o?@3oool00`000000oooo0?ooo`020?ooo`00;P3o
ool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00L0oooo00H0omnL04Q8W03Oool0omnL
04P0B02Lgol80?ooo`030000003oool0oooo03T0oooo0P000?l;0?ooo`80o`00403oool00`00o`00
oooo0?ooo`1B0?ooo`030000003oool0oooo0540oooo0P00o`0?0?ooo`80o`002`3oool20000oc`0
oooo00<000000?ooo`3oool00P3oool002h0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL
0=ooo`070?ooo`050?noM000M;l0oooO09a80018W=l0203oool00`000000oooo0?ooo`0h0?ooo`80
003o2`3oool00`3o0000oooo0?ooo`0>0?ooo`800?l0E@3oool00`000000oooo0?ooo`1C0?ooo`03
003o003oool0oooo00d0oooo0`3o000:0?ooo`80003o>`3oool00`000000oooo0?ooo`020?ooo`00
;P3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00P0oooo00@0gia804RLg`2o
M00007Bo203oool00`000000oooo0?ooo`0g0?ooo`80003o2P3oool20?l000l0oooo0P00o`1G0?oo
o`030000003oool0oooo05@0oooo0P00o`0?0?ooo`80o`002P3oool20000ocX0oooo00<000000?oo
o`3oool00P3oool002l0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`090?ooo`04
0=nLB01dM7@0001d0;ooo`L0oooo00<000000?ooo`3oool0=P3oool20000o`X0oooo0P3o000>0?oo
o`<00?l0F03oool00`000000oooo0?ooo`1F0?ooo`800?l03P3oool30?l000X0oooo00<0003o0?oo
o`3oool0=`3oool00`000000oooo0?ooo`020?ooo`00<03oool01P3OW4P0001d0;ooo`3ooml0W4P0
04RLg`/0oooo00<0_g@00000B02Lgol01`3oool00`000000oooo0?ooo`0e0?ooo`80003o2P3oool0
0`3o0000oooo0?ooo`0=0?ooo`800?l0FP3oool00`000000oooo0?ooo`1H0?ooo`03003o003oool0
oooo00d0oooo0P3o000:0?ooo`030000o`3oool0oooo03H0oooo00<000000?ooo`3oool00P3oool0
0340oooo00@0gia800000000000007Bo303oool00`3ooml0W4P004RLg`070?ooo`030000003oool0
oooo03D0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0<0?ooo`<00?l0F`3oool0
0`000000oooo0?ooo`1I0?ooo`800?l03P3oool20?l000X0oooo00<0003o0?ooo`3oool0=@3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo
00L0oooo0P3o000>0?ooo`800?l0G@3oool00`000000oooo0?ooo`1K0?ooo`800?l03P3oool20?l0
00T0oooo00<0003o0?ooo`3oool0=03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`0c0?ooo`030000o`3oool0oooo00L0oooo0P3o000>0?ooo`800?l0GP3oool00`000000
oooo0?ooo`1L0?ooo`800?l03P3oool20?l000T0oooo00<0003o0?ooo`3oool0<`3oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0b0?ooo`030000o`3oool0oooo00L0oooo
0P3o000=0?ooo`800?l0H03oool00`000000oooo0?ooo`1M0?ooo`<00?l03@3oool20?l000P0oooo
0P000?ld0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0340oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0<0?ooo`800?l0H@3oool00`000000oooo0?oo
o`1O0?ooo`<00?l0303oool20?l000P0oooo0P000?lc0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo0300oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0<
0?ooo`03003o003oool0oooo0640oooo00<000000?ooo`3oool0H03oool3003o00`0oooo0P3o0008
0?ooo`80003o<P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0_0?oo
o`80003o203oool00`3o0000oooo0?ooo`0;0?ooo`800?l0I03oool00`000000oooo0?ooo`1R0?oo
o`800?l0303oool20?l000P0oooo0P000?la0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo02h0oooo0P000?l70?ooo`80o`003@3oool00`00o`00oooo0?ooo`1T0?ooo`03
0000003oool0oooo06<0oooo0P00o`0<0?ooo`80o`00203oool00`000?l0oooo0?ooo`0_0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02d0oooo0P000?l70?ooo`80o`00
303oool2003o06L0oooo00<000000?ooo`3oool0I03oool3003o00/0oooo0P3o00080?ooo`030000
o`3oool0oooo02h0oooo00<000000?ooo`3oool00P3oool004/0oooo0P00000^0?ooo`030000o`3o
ool0oooo00D0oooo0P3o000<0?ooo`800?l0J03oool00`000000oooo0?ooo`1V0?ooo`800?l0303o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo02/0oooo0`0000040?ooo`00B`3oool0
0`000000oooo0?ooo`0/0?ooo`030000o`3oool0oooo00D0oooo0P3o000<0?ooo`03003o003oool0
oooo06P0oooo00<000000?ooo`3oool0I`3oool2003o00`0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`0/0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
02/0oooo00<0003o0?ooo`3oool01@3oool20?l000/0oooo0P00o`1[0?ooo`030000003oool0oooo
06T0oooo00<00?l00?ooo`3oool02P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
02/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0:P3oool00`000?l0
oooo0?ooo`050?ooo`80o`002`3oool2003o06`0oooo00<000000?ooo`3oool0JP3oool2003o00/0
oooo00<0o`000?ooo`3oool01@3oool20000ob`0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`050?ooo`80o`002`3oool00`00o`00oooo
0?ooo`1/0?ooo`030000003oool0oooo06/0oooo0P00o`0;0?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0:P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`0Y0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0203oool2003o06l0oooo00<0
00000?ooo`3oool0K03oool2003o00X0oooo0P3o00070?ooo`030000o`3oool0oooo02T0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00P0oooo0P00o`1`0?ooo`030000003oool0oooo06d0oooo0`00o`09
0?ooo`80o`001`3oool00`000?l0oooo0?ooo`0X0?ooo`030000003oool0oooo0080oooo001;0?oo
o`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`080?oo
o`03003o003oool0oooo0700oooo00<000000?ooo`3oool0K`3oool2003o00T0oooo0P3o00060?oo
o`80003o:@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0V0?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool2003o07<0oooo00<000000?ooo`3o
ool0L03oool2003o00T0oooo0P3o00060?ooo`80003o:03oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0U0?ooo`80003o1P3oool00`3o0000oooo0?ooo`070?ooo`800?l0
M03oool00`000000oooo0?ooo`1a0?ooo`800?l02@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo02H0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool09@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00L0oooo0P00o`1e0?ooo`030000003o
ool0oooo0780oooo0P00o`090?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool09@3o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0
oooo00@0oooo0P3o00080?ooo`800?l0MP3oool00`000000oooo0?ooo`1c0?ooo`800?l02@3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo02D0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool08`3oool20000o`D0oooo0P3o00080?ooo`800?l0M`3oool00`00
0000oooo0?ooo`1d0?ooo`800?l02@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
02@0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool08P3oool20000o`H0
oooo00<0o`000?ooo`3oool01P3oool2003o07P0oooo00<000000?ooo`3oool0MP3oool00`00o`00
oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool08`3oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool01P3oool2003o07T0oooo00<000000?ooo`3oool0M`3oool00`00o`00oooo
0?ooo`070?ooo`030?l0003oool0oooo00<0oooo0P000?lT0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo0240oooo0P000?l50?ooo`030?l0003oool0oooo00H0oooo0P00
o`1j0?ooo`030000003oool0oooo07P0oooo00<00?l00?ooo`3oool01`3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo0280oooo00<000000?ooo`3oool00P3oool004/0oooo0P00000R
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01P3oool2003o07/0oooo00<00000
0?ooo`3oool0N@3oool00`00o`00oooo0?ooo`060?ooo`80o`001@3oool00`000?l0oooo0?ooo`0O
0?ooo`<00000103oool004/0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`030?oo
o`80o`001`3oool2003o07`0oooo00<000000?ooo`3oool0NP3oool00`00o`00oooo0?ooo`060?oo
o`80o`00103oool20000ob80oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool07`3oool00`000?l0oooo0?ooo`030?ooo`80o`001`3oool2003o07d0oooo00<000000?ooo`3o
ool0NP3oool2003o00P0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0P0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`050?ooo`800?l0OP3oool00`000000oooo0?ooo`1k0?ooo`800?l0
203oool00`3o0000oooo0?ooo`020?ooo`80003o8@3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3o
ool2003o07l0oooo00<000000?ooo`3oool0O03oool2003o00P0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0O0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo01d0oooo00<0003o0?ooo`3oool00`3oool20?l000H0oooo0P00o`200?ooo`030000003oool0
oooo07d0oooo0P00o`070?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool07P3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo
0080oooo0P3o00060?ooo`800?l0P@3oool00`000000oooo0?ooo`1n0?ooo`800?l01`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo01h0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`020?ooo`80o`001P3oool2003o0880
oooo00<000000?ooo`3oool0O`3oool2003o00H0oooo0P3o00040?ooo`030000o`3oool0oooo01d0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0703oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo00@0oooo0P00o`230?ooo`030000003oool0oooo07l0oooo
0P00o`070?ooo`030?l0003oool0oooo0080oooo0P000?lN0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool00P3oool20?l000H0oooo0P00
o`230?ooo`030000003oool0oooo0800oooo0P00o`070?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0J
0?ooo`80003o0`3oool20?l000H0oooo0P00o`240?ooo`030000003oool0oooo0840oooo0P00o`06
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool06`3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`0J0?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool0103oool2003o08D0oooo00<000000?ooo`3oool0PP3oool2003o00H0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo01T0oooo0P000?l30?ooo`030?l0003oool0oooo00@0oooo0P00o`260?ooo`03
0000003oool0oooo08<0oooo0P00o`060?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool06P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0I0?ooo`040000
o`3oool0oooo0?ooo`80o`001@3oool2003o08L0oooo00<000000?ooo`3oool0Q03oool2003o00D0
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0J0?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo01P0oooo0P000?l30?ooo`030?l0003oool0oooo00<0oooo
0P00o`280?ooo`030000003oool0oooo08@0oooo00<00?l00?ooo`00o`001@3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo01T0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool0603oool010000?l0oooo0?ooo`3oool20?l000D0oooo00<00?l00?ooo`3oool0
Q`3oool00`000000oooo0?ooo`250?ooo`03003o003oool00?l000D0oooo00D0o`000?ooo`3oool0
oooo0000o`0K0?ooo`030000003oool0oooo0080oooo001;0?ooo`800000603oool20000o`<0oooo
00<0o`000?ooo`3oool00`3oool2003o08T0oooo00<000000?ooo`3oool0QP3oool2003o00D0oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0F0?ooo`<00000103oool004/0oooo00<0
00000?ooo`3oool05`3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo0P00o`2:0?ooo`030000
003oool0oooo08L0oooo0P00o`050?ooo`050?l0003oool0oooo0?ooo`000?l06P3oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0F0?ooo`80003o0P3oool20?l000@0oooo
0P00o`2;0?ooo`030000003oool0oooo08P0oooo0P00o`040?ooo`80o`000`3oool00`000?l0oooo
0?ooo`0G0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01H0oooo00D0
003o0?ooo`3oool0oooo0?l000050?ooo`800?l0R`3oool00`000000oooo0?ooo`290?ooo`03003o
003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`0I0?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo01D0oooo0P000?l20?ooo`80o`00103oool2003o08`0oooo
00<000000?ooo`3oool0R@3oool2003o00D0oooo00D0o`000?ooo`3oool0oooo0000o`0H0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3oool0
0P3o00040?ooo`800?l0S@3oool00`000000oooo0?ooo`2:0?ooo`800?l0103oool01@3o0000oooo
0?ooo`3oool0003o01P0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
503oool20000o`80oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`2<0?ooo`030000
003oool0oooo08/0oooo00<00?l00?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0003o01L0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0503oool20000o`030?oo
o`3o0000o`0000@0oooo0P00o`2>0?ooo`030000003oool0oooo08`0oooo00<00?l00?ooo`3oool0
0P3oool20?l00080oooo00<0003o0?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`0D0?ooo`040000o`3oool0oooo0?l000D0oooo00<00?l00?ooo`3oool0
S@3oool00`000000oooo0?ooo`2=0?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool0
0P000?lF0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01<0oooo0P00
0?l00`3oool0o`000?l000040?ooo`03003o003oool0oooo08h0oooo00<000000?ooo`3oool0S@3o
ool00`00o`00oooo0?ooo`030?ooo`040?l0003oool0oooo0000oaH0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool04`3oool010000?l0oooo0?ooo`3o00040?ooo`800?l0
T03oool00`000000oooo0?ooo`2>0?ooo`03003o003oool0oooo0080oooo00@0o`000?ooo`3oool0
003o5P3oool00`000000oooo0?ooo`020?ooo`00;`3oool0102oM00000000000001d_ol30?ooo`03
0?oOW0180000M;oo0080oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`070?ooo`03
0000003oool0oooo0180oooo0P000?l00`3oool0o`000?l000040?ooo`03003o003oool0oooo08l0
oooo00<000000?ooo`3oool0SP3oool2003o00@0oooo00@0o`000?ooo`3oool0003o5@3oool00`00
0000oooo0?ooo`020?ooo`00;P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL
04P0001d_ol00`3oool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02oool0oooo00L0oooo00<00000
0?ooo`3oool04P3oool20000o`030?ooo`3o0000oooo00<0oooo00<00?l00?ooo`3oool0T03oool0
0`000000oooo0?ooo`2?0?ooo`03003o003oool0oooo0080oooo0P3o00000`3oool0003o0?ooo`0D
0?ooo`030000003oool0oooo0080oooo000]0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000
B02Lgol0203oool00`3o_g@007Bo0?ooo`0;0?ooo`030000003oool0oooo0140oooo0P000?l00`3o
ool0o`000?l000030?ooo`800?l0TP3oool00`000000oooo0?ooo`2@0?ooo`03003o003oool0oooo
0080oooo00@0o`000?ooo`000?l0003o503oool00`000000oooo0?ooo`020?ooo`00;@3oool00`3o
oml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<0okmd001d_`3oool02P3oool0
0`000000oooo0?ooo`0A0?ooo`80003o00<0oooo0?l0003oool00`3oool00`00o`00oooo0?ooo`2A
0?ooo`030000003oool0oooo0900oooo00<00?l00?ooo`3oool00P3oool20?l000030?ooo`000?l0
oooo01<0oooo00<000000?ooo`3oool00P3oool00200oooo00<0oooO09a8000000001`0000001P18
W=l0oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol02@3oool00`3o_g@0B9cO0?oo
o`090?ooo`030000003oool0oooo0100oooo0P000?l00`3oool0o`000?l000030?ooo`03003o003o
ool0oooo0980oooo00<000000?ooo`3oool0T@3oool00`00o`00oooo0?ooo`020?ooo`030?l0003o
ool0003o01@0oooo00<000000?ooo`3oool00P3oool002h0oooo00<0_g@00018W03Oool00P3oool0
0`3ogi`0B00004RLg`0:0?ooo`030=nLB018W=l0oooo00P0oooo0`00000@0?ooo`80003o00<0oooo
0?l0003oool00P3oool00`00o`00oooo0?ooo`2C0?ooo`030000003oool0oooo0980oooo00@00?l0
0?ooo`3oool0oooo0P3o00000`3oool0003o0?ooo`0?0?ooo`@00000103oool002h0oooo00<0gia8
0000B02Lgol00P3oool00`3ooml0W4P0001d_`0;0?ooo`030;md001d_ol0oooo00L0oooo00<00000
0?ooo`3oool0403oool20000o`80o`000`3oool00`00o`00oooo0?ooo`2C0?ooo`030000003oool0
oooo0980oooo00<00?l00?ooo`3oool00P3oool00`3o0000oooo0000o`0C0?ooo`030000003oool0
oooo0080oooo000^0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool02P3oool00`3o
gi`0B01d0;ooo`070?ooo`030000003oool0oooo00l0oooo0P000?l00`3oool0o`000?l000020?oo
o`03003o003oool0oooo09@0oooo00<000000?ooo`3oool0T`3oool01000o`00oooo0?ooo`3oool2
0?l000030000o`3oool0oooo0140oooo00<000000?ooo`3oool00P3oool002h0oooo00@0oooO09a8
0000B9`0gooo0P3oool00`3OW4P004RL0=ooo`0:0?ooo`030?oog`2LB000M;oo00L0oooo00<00000
0?ooo`3oool03`3oool20000o`040?ooo`3o0000oooo0?ooo`800?l0UP3oool00`000000oooo0?oo
o`2D0?ooo`07003o003oool0oooo0?ooo`3o0000oooo0000o`0B0?ooo`030000003oool0oooo0080
oooo000_0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool02P3oool00`3ookl0M000
04RLg`070?ooo`030000003oool0oooo00l0oooo0P000?l20?l00080oooo00<00?l00?ooo`3oool0
U@3oool00`000000oooo0?ooo`2D0?ooo`07003o003oool0oooo0?ooo`3o0000oooo0000o`0B0?oo
o`030000003oool0oooo0080oooo000`0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO1`3oool0
1`3o_g@004RL0=ooo`3oool0gia80000B02Lgol01`3oool00`000000oooo0?ooo`0?0?ooo`030000
o`3oool0o`000080oooo00<00?l00?ooo`3oool0UP3oool00`000000oooo0?ooo`2E0?ooo`03003o
003oool0oooo0080o`0000<0oooo0000o`3oool0403oool00`000000oooo0?ooo`020?ooo`00<@3o
ool0103OW4P0000000000000M;l90?ooo`050?oOW018000000000000001d_ol0203oool00`000000
oooo0?ooo`0>0?ooo`80003o0P3o00020?ooo`03003o003oool0oooo09H0oooo00<000000?ooo`3o
ool0U@3oool01`00o`00oooo0?ooo`3oool0o`000?ooo`000?l04@3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`0>0?ooo`030000o`3oool0o`000080oooo00<00?l00?oo
o`3oool0U`3oool00`000000oooo0?ooo`2F0?ooo`06003o003oool0oooo0?l0003oool0003o4@3o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0>0?ooo`030000o`3oool0
o`000080oooo00<00?l00?ooo`3oool0U`3oool00`000000oooo0?ooo`2F0?ooo`07003o003oool0
oooo0?ooo`3o0000oooo0000o`0@0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo00d0oooo0P000?l20?l000030?ooo`00o`00oooo09T0oooo00<000000?ooo`3oool0U`3o
ool01P00o`00oooo0?ooo`3o0000oooo0000oa00oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool03@3oool00`000?l0oooo0?l000020?ooo`03003o003oool0oooo09P0oooo
00<000000?ooo`3oool0U`3oool01P00o`00oooo0?ooo`3oool0o`000000oa00oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool03@3oool01@000?l0o`000?l0003oool00?l0
09/0oooo00<000000?ooo`3oool0V03oool01P00o`00oooo0?ooo`3o0000oooo0000o`l0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool03@3oool01@000?l0o`000?l0003o
ool00?l009/0oooo00<000000?ooo`3oool0V03oool01P00o`00oooo0?ooo`3o0000oooo0000o`l0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0303oool00`000?l0oooo
0?l000020?ooo`03003o003oool0oooo09T0oooo00<000000?ooo`3oool0V@3oool01@00o`00oooo
0?ooo`3o0000003o00l0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
303oool01@000?l0o`000?l0003oool00?l009`0oooo00<000000?ooo`3oool0V@3oool01000o`00
oooo0?ooo`3o00020000o`h0oooo00<000000?ooo`3oool00P3oool004/0oooo0P00000=0?ooo`05
0000o`3o0000o`000?ooo`00o`00W03oool00`000000oooo0?ooo`2J0?ooo`05003o003oool0o`00
0?ooo`000?l0303oool3000000@0oooo001;0?ooo`030000003oool0oooo00`0oooo00D0003o0?l0
003oool0oooo003o002L0?ooo`030000003oool0oooo09X0oooo00D00?l00?ooo`3oool0o`000000
o`0>0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00/0oooo00D0003o
0?l0003o0000oooo003o002M0?ooo`030000003oool0oooo09X0oooo0P00o`000`3oool0o`000000
o`0>0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00/0oooo00D0003o
0?l0003o0000oooo003o002M0?ooo`030000003oool0oooo09/0oooo00D00?l00?ooo`3o0000oooo
0000o`0=0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00/0oooo00@0
003o0?l0003oool00?l0WP3oool00`000000oooo0?ooo`2K0?ooo`800?l000<0oooo0?l000000?l0
3@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0:0?ooo`80003o00<0
o`000?ooo`00o`00WP3oool00`000000oooo0?ooo`2K0?ooo`800?l000<0oooo0?l000000?l03@3o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0:0?ooo`050000o`3o0000
o`000?ooo`00o`00WP3oool00`000000oooo0?ooo`2L0?ooo`04003o003oool0o`000000o`d0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02P3oool010000?l0o`000?oo
o`00o`2O0?ooo`030000003oool0oooo09`0oooo0P00o`020?l000030000o`3oool0oooo00X0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02P3oool010000?l0o`000?oo
o`00o`2O0?ooo`030000003oool0oooo09d0oooo00@00?l00?ooo`3o0000003o303oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`090?ooo`80003o00<0o`00003o003oool0
W`3oool00`000000oooo0?ooo`2M0?ooo`04003o003oool0o`000000o``0oooo00<000000?ooo`3o
ool00P3oool004/0oooo00<000000?ooo`3oool02@3oool20000o`030?ooo`00o`00oooo09l0oooo
00<000000?ooo`3oool0W@3oool2003o00030?l000000?l0oooo00/0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool02@3oool00`000?l0o`00003o002Q0?ooo`030000003o
ool0oooo09h0oooo00<00?l00?l000000?l0303oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`090?ooo`030000o`3o00000?l00:40oooo00<000000?ooo`3oool0WP3oool2
003o00030?l000000?l0oooo00X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool0203oool20000o`030?l00000o`00oooo0:00oooo00<000000?ooo`3oool0WP3oool2003o
00030?l000000?l0oooo00X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool0203oool20000o`03003o003oool0oooo0:00oooo00<000000?ooo`3oool0W`3oool00`00o`00
o`000000o`0;0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00P0oooo
0P000?l00`00o`00oooo0?ooo`2P0?ooo`030000003oool0oooo09l0oooo00<00?l00?l000000?l0
2`3oool00`000000oooo0?ooo`020?ooo`00B`3oool2000000T0oooo00<0003o0?l00000o`00XP3o
ool00`000000oooo0?ooo`2O0?ooo`800?l000<0003o0?ooo`3oool01`3oool3000000@0oooo001;
0?ooo`030000003oool0oooo00P0oooo00<0003o003o003oool0XP3oool00`000000oooo0?ooo`2P
0?ooo`03003o003o0000003o00X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool0203oool00`000?l00?l00?ooo`2R0?ooo`030000003oool0oooo0:00oooo00<00?l00?l0
00000?l02P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`080?ooo`03
0000o`00o`00oooo0:80oooo00<000000?ooo`3oool0X03oool00`00o`00o`000000o`0:0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00L0oooo0P000?l00`00o`00oooo
0?ooo`2Q0?ooo`030000003oool0oooo0:40oooo00<00?l00000o`3oool02@3oool00`000000oooo
0?ooo`020?ooo`00303oool00`3ookl0M7Bo0?ooo`0l0?ooo`030000003oool0oooo00L0oooo00<0
003o003o003oool0X`3oool00`000000oooo0?ooo`2Q0?ooo`03003o00000?l0oooo00T0oooo00<0
00000?ooo`3oool00P3oool000`0oooo00@0omnL04P0000004P0W=oo>`3oool00`000000oooo0?oo
o`070?ooo`030000o`00o`00oooo0:<0oooo00<000000?ooo`3oool0X@3oool00`00o`00o`000000
o`090?ooo`030000003oool0oooo0080oooo000>0?ooo`030;md00000000000000<0000000<0001d
0;ooo`3oool0=03oool00`000000oooo0?ooo`070?ooo`030000o`00o`00oooo0:<0oooo00<00000
0?ooo`3oool0XP3oool00`00o`00003o0?ooo`080?ooo`030000003oool0oooo0080oooo000B0?oo
o`030?oOW0180000M;oo03H0oooo00<000000?ooo`3oool01`3oool00`000?l00?l00?ooo`2S0?oo
o`030000003oool0oooo0:80oooo00<00?l00000o`3oool0203oool00`000000oooo0?ooo`020?oo
o`004@3oool00`3OW4P0001d0;ooo`0g0?ooo`030000003oool0oooo00H0oooo0P000?l00`00o`00
oooo0?ooo`2R0?ooo`030000003oool0oooo0:80oooo00<00?l00000o`3oool0203oool00`000000
oooo0?ooo`020?ooo`00303oool01P3ogi`0B01809cOo`3o_g@0000004RLgcT0oooo00<000000?oo
o`3oool01P3oool00`000?l00?l00?ooo`2T0?ooo`030000003oool0oooo0:80oooo00<00?l00000
o`3oool0203oool00`000000oooo0?ooo`020?ooo`00303oool0103ogi`0B00000000000M;lk0?oo
o`030000003oool0oooo00H0oooo00<0003o003o003oool0Y03oool00`000000oooo0?ooo`2R0?oo
o`03003o00000?l0oooo00P0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool01P3oool00`000?l00?l00?ooo`2T0?ooo`030000003oool0oooo0:<0oooo00<00?l00?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`060?ooo`030000
o`00o`00oooo0:@0oooo00<000000?ooo`3oool0X`3oool00`00o`00oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo000?0?ooo`060=nLB000000000000000000004P0W=oo=P3oool00`000000
oooo0?ooo`060?ooo`030000o`00o`00oooo0:@0oooo00<000000?ooo`3oool0X`3oool00`00o`00
oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000=0?ooo`090?oo_`1d0000B9cO0?oOW02L
_ol0oooo0=nLB000B9`0gooo03D0oooo00<000000?ooo`3oool01P3oool00`000?l00?l00?ooo`2T
0?ooo`030000003oool0oooo0:<0oooo00<00?l00?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`003@3oool02@2oM7@0_ooo0?ooo`3o_i`0W=oo0?ooo`3ookl0M01d0;ooo`0e0?ooo`800000
1`3oool00`00o`00oooo0?ooo`2T0?ooo`030000003oool0oooo0:<0oooo00<00?l00000o`3oool0
1@3oool3000000@0oooo000<0?ooo`090?oOW02L_ol0oooo0?oog`2LM9`0gooo0?ooo`3ogi`0B7Bo
03H0oooo00<000000?ooo`3oool01P3oool00`00o`00oooo0?ooo`2T0?ooo`030000003oool0oooo
0:<0oooo00<00?l00000o`3oool01`3oool00`000000oooo0?ooo`020?ooo`00303oool02@3o_i`0
W=oo0?ooo`2oM000M;oo0?ooo`3OW4P0001d0;ooo`0f0?ooo`030000003oool0oooo00H0oooo00<0
0?l00?ooo`3oool0Y03oool00`000000oooo0?ooo`2S0?ooo`03003o00000?l0oooo00L0oooo00<0
00000?ooo`3oool00P3oool000`0oooo00@0oono07@000000000M;oo>`3oool00`000000oooo0?oo
o`060?ooo`03003o003oool0oooo0:@0oooo00<000000?ooo`3oool0X`3oool00`00o`00003o0?oo
o`070?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00H0oooo00<00?l0
0?ooo`3oool0Y03oool00`000000oooo0?ooo`2S0?ooo`800?l0203oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`060?ooo`03003o003oool0oooo0:@0oooo00<000000?oo
o`3oool0Y03oool00`00o`00oooo0?ooo`060?ooo`030000003oool0oooo0080oooo000@0?ooo`06
0?noM000000000000000000007@0_ooo=@3oool00`000000oooo0?ooo`050?ooo`030000o`00o`00
oooo0:D0oooo00<000000?ooo`3oool0Y03oool00`00o`00oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00080?ooo`060;nLW03Oool0oooo0?ooo`3ogi`0B0000`0000001000B9`0gooo0?oo
_`1dM;lf0?ooo`030000003oool0oooo00D0oooo00<0003o003o003oool0Y@3oool00`000000oooo
0?ooo`2T0?ooo`03003o003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000L0oooo00<0
oooO09a8000000000`0000000`00M;l0oooo0?ooo`020?ooo`030?noM00007@0_ooo03H0oooo00<0
00000?ooo`3oool01@3oool00`000?l00?l00?ooo`2U0?ooo`030000003oool0oooo0:@0oooo00<0
0?l00?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`001`3oool00`3ookl0M00004RLg`11
0?ooo`030000003oool0oooo00D0oooo00<00?l00?ooo`3oool0Y@3oool00`000000oooo0?ooo`2T
0?ooo`03003o003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool01@3oool00`00o`00oooo0?ooo`2U0?ooo`030000003oool0oooo0:@0oooo00<00?l00?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`003`3oool01P3ogi`0B0000000000000000018
09cOobP0oooo00@0_g@0000000000000M;oo2P3oool00`000000oooo0?ooo`050?ooo`03003o003o
ool0oooo0:D0oooo00<000000?ooo`3oool0Y03oool00`00o`00oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo000>0?ooo`030;md00000000M;oo0080oooo00<0oooO09adW03Oool09P3oool0
1P3OW4P007Bo0?ooo`3ogi`0B00004RLg`T0oooo00<000000?ooo`3oool01@3oool00`00o`00oooo
0?ooo`2U0?ooo`030000003oool0oooo0:@0oooo00<00?l00?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`003@3oool00`3OW4P0B9cO0?ooo`040?ooo`030=nLW02oool0oooo02@0oooo00<0
oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030000003oool0oooo00D0oooo00<0
0?l00?ooo`3oool0Y@3oool00`000000oooo0?ooo`2T0?ooo`03003o003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool000`0oooo00<0omnL07BLg`3oool0103oool00`3ooml0W7BL0=ooo`0U
0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo1`3oool00`000000oooo0?oo
o`050?ooo`03003o003oool0oooo0:D0oooo00<000000?ooo`3oool0Y03oool00`00o`00oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo000<0?ooo`030?noW02Lgol0oooo00<0oooo00<0oooO
09a8001d_ol09P3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00L0oooo00<00000
0?ooo`3oool01@3oool00`00o`00oooo0?ooo`2U0?ooo`030000003oool0oooo0:@0oooo00<00?l0
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00303oool00`3ogi`0B7Bo0?ooo`020?oo
o`030=nLB0000000B9cO02P0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`070?oo
o`P0000000<00?l0000000000000o`00001=00000003003o00000000000000L00000103oool000d0
oooo00H0okmd00000000000000000018W03OoolY0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO
09a80000M;l01`3oool00`000000oooo0?ooo`050?ooo`03003o003oool0oooo0:D0oooo00<00000
0?ooo`3oool0Y03oool00`00o`00oooo0?ooo`060?ooo`030000003oool0oooo0080oooo000l0?oo
o`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01P3oool00`000000oooo0?ooo`050?oo
o`03003o003oool0oooo0:D0oooo00<000000?ooo`3oool0Y03oool00`00o`00oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo000l0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018
W03Oool01P3oool00`000000oooo0?ooo`050?ooo`03003o003oool0oooo0:D0oooo00<000000?oo
o`3oool0Y03oool00`00o`00oooo0?ooo`060?ooo`030000003oool0oooo0080oooo000?0?ooo`06
0?oOW018000000000000000004P0W=oo:03oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`00o`00oooo0?ooo`2U0?ooo`030000003oool0
oooo0:@0oooo00<00?l00?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`003@3oool0103o
oml0W4P00018W03Oool20?ooo`030?noM000B9`0gooo02P0oooo00H0gia80000M02oool0oooO09a8
0018W=l70?ooo`030000003oool0oooo00D0oooo00<00?l00?ooo`3oool0Y@3oool00`000000oooo
0?ooo`2T0?ooo`03003o003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000d0oooo00<0
_gA809cOo`3oool00`3oool00`3ooml0W4Qd0;ooo`0Y0?ooo`040=nLB00000000000001d_`P0oooo
00<000000?ooo`3oool01@3oool00`00o`00oooo0?ooo`2U0?ooo`030000003oool0oooo0:@0oooo
00<00?l00?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00303oool00`3ogi`0W;oo0?oo
o`040?ooo`030?oOW018M;l0oooo03D0oooo00<000000?ooo`3oool01@3oool00`00o`00oooo0?oo
o`2U0?ooo`030000003oool0oooo0:@0oooo00<00?l00?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`00303oool00`3o_i`0W=oo0?ooo`030?ooo`030?oOW018B9`0gooo03H0oooo00<00000
0?ooo`3oool01@3oool00`000?l00?l00?ooo`2U0?ooo`030000003oool0oooo0:@0oooo00<00?l0
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00303oool0103ookl0M0000000001d_olk
0?ooo`030000003oool0oooo00D0oooo00<0003o003o003oool0Y@3oool00`000000oooo0?ooo`2T
0?ooo`03003o003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool01P3oool00`00o`00oooo0?ooo`2T0?ooo`030000003oool0oooo0:@0oooo00<00?l00?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`060?ooo`03
003o003oool0oooo0:@0oooo00<000000?ooo`3oool0Y03oool00`00o`00oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo000<0?ooo`030?oo_`2LW=l0oooo00<0oooo00@0okmd0000000007@0
_ooo=@3oool00`000000oooo0?ooo`060?ooo`03003o003oool0oooo0:@0oooo00<000000?ooo`3o
ool0X`3oool00`00o`00003o0?ooo`070?ooo`030000003oool0oooo0080oooo000<0?ooo`040?oo
_`2LW=l0oono07@000@0000000<004RL0=ooo`3oool0=03oool00`000000oooo0?ooo`060?ooo`03
003o003oool0oooo0:@0oooo00<000000?ooo`3oool0X`3oool00`00o`00003o0?ooo`070?ooo`03
0000003oool0oooo0080oooo000<0?ooo`090?oOW018000000000000B02Lgol0oooo0?oog`2LB7@0
_ooo03H0oooo00<000000?ooo`3oool01P3oool00`00o`00oooo0?ooo`2T0?ooo`030000003oool0
oooo0:<0oooo00<00?l00000o`3oool01`3oool00`000000oooo0?ooo`020?ooo`00203oool0103o
oml0W4P00000M02ooolo0?ooo`030000003oool0oooo00H0oooo00<00?l00?ooo`3oool0Y03oool0
0`000000oooo0?ooo`2S0?ooo`03003o003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
04/0oooo0P0000070?ooo`03003o003oool0oooo0:@0oooo00<000000?ooo`3oool0X`3oool00`00
o`00oooo0?ooo`050?ooo`<00000103oool000`0oooo00D0omno0;oOo`3oool0oooo0;md00030000
00030000M02oool0oooo03@0oooo00<000000?ooo`3oool01P3oool00`00o`00oooo0?ooo`2T0?oo
o`030000003oool0oooo0:<0oooo00<00?l00?ooo`3oool01`3oool00`000000oooo0?ooo`020?oo
o`00303oool00`2oM000000000000002000000050000M02oool0oooo0;nLW03Oool0=@3oool00`00
0000oooo0?ooo`060?ooo`030000o`00o`00oooo0:@0oooo00<000000?ooo`3oool0XP3oool00`00
o`00003o0?ooo`080?ooo`030000003oool0oooo0080oooo000:0?ooo`050;md0000000000000018
W03Oool00`3oool00`3ooml0W4P007Boo`020?ooo`030;md0000B9`0gooo0340oooo00<000000?oo
o`3oool01P3oool00`000?l00?l00?ooo`2T0?ooo`030000003oool0oooo0:80oooo00<00?l00000
o`3oool0203oool00`000000oooo0?ooo`020?ooo`00303oool00`3o_i`0W=oo0?ooo`080?ooo`03
0?oOW018M;l0oooo0340oooo00<000000?ooo`3oool01P3oool00`000?l00?l00?ooo`2T0?ooo`03
0000003oool0oooo0:80oooo00<00?l00000o`3oool0203oool00`000000oooo0?ooo`020?ooo`00
303oool00`3ookl0M7Bo0?ooo`070?ooo`030?noM000B9`0gooo0380oooo00<000000?ooo`3oool0
1`3oool00`00o`00oooo0?ooo`2S0?ooo`030000003oool0oooo0:80oooo00<00?l00000o`3oool0
203oool00`000000oooo0?ooo`020?ooo`00303oool0103ogi`0B0000000M02oool50?ooo`030=nL
B000M;l0oooo03<0oooo00<000000?ooo`3oool01`3oool00`00o`00oooo0?ooo`2S0?ooo`030000
003oool0oooo0:40oooo00<00?l00?ooo`000?l02@3oool00`000000oooo0?ooo`020?ooo`003@3o
ool00`3ogi`0B000000000050000000304RLg`3oool0oooo03<0oooo00<000000?ooo`3oool01`3o
ool00`000?l00?l00?ooo`2S0?ooo`030000003oool0oooo0:40oooo00<00?l00?l000000?l02@3o
ool00`000000oooo0?ooo`020?ooo`004P3oool00`3o_g@0001809cOo`0f0?ooo`030000003oool0
oooo00L0oooo00<0003o003o003oool0X`3oool00`000000oooo0?ooo`2Q0?ooo`03003o003o0000
003o00T0oooo00<000000?ooo`3oool00P3oool00140oooo00<0_g@0001d_`3oool0=`3oool00`00
0000oooo0?ooo`070?ooo`030000o`00o`00oooo0:<0oooo00<000000?ooo`3oool0X@3oool00`00
o`00o`000000o`090?ooo`030000003oool0oooo0080oooo000<0?ooo`060?oOW0180000M;oo0?no
M0000000M;oo>@3oool00`000000oooo0?ooo`070?ooo`030000o`00o`00oooo0:<0oooo00<00000
0?ooo`3oool0X@3oool00`00o`00003o0?ooo`090?ooo`030000003oool0oooo0080oooo000<0?oo
o`040?oOW01800000000001d_c/0oooo00<000000?ooo`3oool01`3oool00`000?l0o`00003o002S
0?ooo`030000003oool0oooo0:40oooo00<00?l00000o`3oool02@3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`070?ooo`030000o`3o00000?l00:<0oooo00<000000?oo
o`3oool0X03oool00`00o`00oooo0000o`0:0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo00P0oooo00<0003o003o003oool0XP3oool00`000000oooo0?ooo`2P0?ooo`03
003o003o0000003o00X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
203oool00`000?l00?l00?ooo`2R0?ooo`030000003oool0oooo0:00oooo00<00?l00?l000000?l0
2P3oool00`000000oooo0?ooo`020?ooo`00B`3oool2000000T0oooo00<0003o0?l00000o`00XP3o
ool00`000000oooo0?ooo`2P0?ooo`03003o003o0000003o00P0oooo0`0000040?ooo`00B`3oool0
0`000000oooo0?ooo`080?ooo`030000o`3o00000?l00:80oooo00<000000?ooo`3oool0W`3oool0
0`00o`00oooo0000o`0;0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
00P0oooo00<0003o0?l00000o`00XP3oool00`000000oooo0?ooo`2O0?ooo`03003o003o0000003o
00/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0203oool010000?l0
o`000?l00000o`2Q0?ooo`030000003oool0oooo09l0oooo00<00?l00?l000000?l02`3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`080?ooo`80003o00<0o`00003o003o
ool0X03oool00`000000oooo0?ooo`2O0?ooo`03003o003o0000003o00/0oooo00<000000?ooo`3o
ool00P3oool004/0oooo00<000000?ooo`3oool02@3oool00`000?l0o`00003o002Q0?ooo`030000
003oool0oooo09h0oooo00<00?l00?ooo`000?l0303oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`090?ooo`040000o`3o0000oooo003o0:00oooo00<000000?ooo`3oool0
WP3oool00`00o`00o`000000o`0<0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo00T0oooo00@0003o0?l0003o00000?l0X03oool00`000000oooo0?ooo`2N0?ooo`03003o
003o0000003o00`0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02@3o
ool20000o`030?l00000o`00oooo09l0oooo00<000000?ooo`3oool0WP3oool00`00o`00o`000000
o`0<0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00T0oooo0P000?l0
0`3o0000oooo003o002O0?ooo`030000003oool0oooo09d0oooo00@00?l00?ooo`3o0000003o303o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0:0?ooo`040000o`3o0000
o`00003o09l0oooo00<000000?ooo`3oool0W@3oool00`00o`00o`000000o`0=0?ooo`030000003o
ool0oooo0080oooo001;0?ooo`030000003oool0oooo00X0oooo0P000?l00`3o00000?l00?ooo`2N
0?ooo`030000003oool0oooo09`0oooo00@00?l00?ooo`3o0000003o3@3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`0:0?ooo`80003o00<0o`000?ooo`00o`00WP3oool0
0`000000oooo0?ooo`2L0?ooo`04003o003oool0o`000000o`d0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool02P3oool20000o`80o`0000<00?l00?ooo`3oool0W03oool0
0`000000oooo0?ooo`2K0?ooo`05003o003oool0oooo0?l000000?l03@3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`0;0?ooo`040000o`3o0000o`00003o09h0oooo00<0
00000?ooo`3oool0V`3oool01000o`00oooo0?l000000?l>0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo00/0oooo0P000?l00`3o0000oooo003o002M0?ooo`030000003o
ool0oooo09/0oooo00@00?l00?ooo`3o0000003o3P3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool2000000`0oooo0P000?l00`3o0000oooo003o002M0?ooo`030000003oool0oooo09X0oooo00D0
0?l00?ooo`3o0000oooo0000o`0<0?ooo`<00000103oool004/0oooo00<000000?ooo`3oool0303o
ool01@000?l0o`000?l0003oool00?l009`0oooo00<000000?ooo`3oool0VP3oool01@00o`00oooo
0?l0003oool0003o00h0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
303oool01@000?l0o`000?l0003oool00?l009`0oooo00<000000?ooo`3oool0V@3oool01@00o`00
oooo0?ooo`3o0000003o00l0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool03@3oool01@000?l0o`000?ooo`3oool00?l009/0oooo00<000000?ooo`3oool0V@3oool01@00
o`00oooo0?l0003oool0003o00l0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool03@3oool01@000?l0o`000?l0003oool00?l009/0oooo00<000000?ooo`3oool0V03oool0
1P00o`00oooo0?ooo`3o0000oooo0000o`l0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool03@3oool00`000?l0o`000?l000020?ooo`03003o003oool0oooo09P0oooo00<0
00000?ooo`3oool0V03oool01@00o`00oooo0?ooo`3o0000003o0100oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool03@3oool20000o`040?l0003oool0oooo003o09X0oooo
00<000000?ooo`3oool0U`3oool01P00o`00oooo0?ooo`3o0000oooo0000oa00oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool03P3oool00`000?l0o`000?ooo`020?ooo`03
003o003oool0oooo09L0oooo00<000000?ooo`3oool0U`3oool01P00o`00oooo0?ooo`3o0000oooo
0000oa00oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool03P3oool00`00
0?l0oooo0?l000020?ooo`03003o003oool0oooo09L0oooo00<000000?ooo`3oool0UP3oool01000
o`00oooo0?ooo`3o00020?ooo`030000o`3oool0oooo00h0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool03P3oool20000o`050?l0003oool0oooo0?ooo`00o`00V03oool0
0`000000oooo0?ooo`2E0?ooo`07003o003oool0oooo0?ooo`3o0000oooo0000o`0A0?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00h0oooo0P000?l20?l00080oooo00<0
0?l00?ooo`3oool0UP3oool00`000000oooo0?ooo`2E0?ooo`07003o003oool0oooo0?ooo`3o0000
oooo0000o`0A0?ooo`030000003oool0oooo0080oooo000_0?ooo`040;md00000000000007Boo`<0
oooo00<0omnL04P0001d_ol00P3oool00`3OW4P00000000000030000000304RLg`3oool0oooo00L0
oooo00<000000?ooo`3oool03`3oool00`000?l0oooo0?l000030?ooo`03003o003oool0oooo09D0
oooo00<000000?ooo`3oool0U03oool01@00o`00oooo0?ooo`3oool0o`000080oooo00<0003o0?oo
o`3oool03`3oool00`000000oooo0?ooo`020?ooo`00;P3oool01P3OW4P007Bo0?ooo`3ogi`0B000
04RLg`80oooo00<0omnL04P0001d_ol00`3oool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02oool0
oooo00L0oooo00<000000?ooo`3oool03`3oool20000o`050?l0003oool0oooo0?ooo`00o`00U`3o
ool00`000000oooo0?ooo`2D0?ooo`07003o003oool0oooo0?ooo`3o0000oooo0000o`0B0?ooo`03
0000003oool0oooo0080oooo000]0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0
203oool00`3o_g@007Bo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo0P000?l00`3oool0o`00
0?ooo`020?ooo`03003o003oool0oooo09@0oooo00<000000?ooo`3oool0T`3oool01@00o`00oooo
0?ooo`3oool0o`000080oooo00<0003o0?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`00
;@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<0okmd001d_`3o
ool02P3oool00`000000oooo0?ooo`0@0?ooo`030000o`3oool0o`0000@0oooo00<00?l00?ooo`3o
ool0T`3oool00`000000oooo0?ooo`2C0?ooo`07003o003oool0oooo0?ooo`3o0000oooo0000o`0C
0?ooo`030000003oool0oooo0080oooo000]0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000
B02Lgol02@3oool00`3o_g@0B9cO0?ooo`090?ooo`030000003oool0oooo0100oooo00@0003o0?oo
o`3oool0o`000`3oool00`00o`00oooo0?ooo`2C0?ooo`030000003oool0oooo0980oooo00D00?l0
0?ooo`3oool0oooo0?l000020?ooo`030000o`3oool0oooo0140oooo00<000000?ooo`3oool00P3o
ool002h0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?ooo`030=nLB018W=l0
oooo00P0oooo0`00000@0?ooo`80003o00<0oooo0?l0003oool00`3oool00`00o`00oooo0?ooo`2B
0?ooo`030000003oool0oooo0940oooo00<00?l00?ooo`3oool00P3oool0103o0000oooo0?ooo`00
0?l@0?ooo`@00000103oool002h0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0;
0?ooo`030;md001d_ol0oooo00L0oooo00<000000?ooo`3oool04@3oool010000?l0oooo0?ooo`3o
00040?ooo`03003o003oool0oooo0940oooo00<000000?ooo`3oool0T@3oool01@00o`00oooo0?oo
o`3oool0o`000080oooo00<0003o0?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`00;P3o
ool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00X0oooo00<0omnL04P0M02oool01`3o
ool00`000000oooo0?ooo`0A0?ooo`040000o`3oool0oooo0?l000@0oooo00<00?l00?ooo`3oool0
T@3oool00`000000oooo0?ooo`2@0?ooo`03003o003oool0oooo0080oooo00@0o`000?ooo`3oool0
003o503oool00`000000oooo0?ooo`020?ooo`00;P3oool0103ooml0W4P00018W03Oool20?ooo`03
0=nLB000B9`0gooo00X0oooo00<0oooO09a8001d_ol01`3oool00`000000oooo0?ooo`0B0?ooo`04
0000o`3oool0oooo0?l000@0oooo00<00?l00?ooo`3oool0T03oool00`000000oooo0?ooo`2?0?oo
o`03003o003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`0D0?ooo`030000003oool0
oooo0080oooo000_0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool02P3oool00`3o
okl0M00004RLg`070?ooo`030000003oool0oooo0180oooo00@0003o0?ooo`3oool0o`00103oool0
0`00o`00oooo0?ooo`2@0?ooo`030000003oool0oooo08l0oooo00<00?l00?ooo`3oool00P3oool0
103o0000oooo0?ooo`000?lE0?ooo`030000003oool0oooo0080oooo000`0?ooo`060=nLB00007@0
_ooo0?oog`2LB000B9cO1`3oool01`3o_g@004RL0=ooo`3oool0gia80000B02Lgol01`3oool00`00
0000oooo0?ooo`0B0?ooo`80003o0P3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo
08l0oooo00<000000?ooo`3oool0SP3oool00`00o`00oooo0?ooo`020?ooo`050?l0003oool0oooo
0?ooo`000?l05@3oool00`000000oooo0?ooo`020?ooo`00<@3oool0103OW4P0000000000000M;l9
0?ooo`050?oOW018000000000000001d_ol0203oool00`000000oooo0?ooo`0C0?ooo`040000o`3o
ool0oooo0?l000D0oooo00<00?l00?ooo`3oool0SP3oool00`000000oooo0?ooo`2=0?ooo`03003o
003oool0oooo00<0oooo00@0o`000?ooo`3oool0003o5P3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0C0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`00o`00
oooo0?ooo`2>0?ooo`030000003oool0oooo08d0oooo00<00?l00?ooo`3oool00P3oool01@3o0000
oooo0?ooo`3oool0003o01H0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool0503oool010000?l0oooo0?ooo`3o00050?ooo`03003o003oool0oooo08d0oooo00<000000?oo
o`3oool0S03oool00`00o`00oooo0?ooo`030?ooo`040?l0003oool0oooo0000oaL0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0503oool01@000?l0oooo0?ooo`3oool0
o`0000D0oooo00<00?l00?ooo`3oool0S03oool00`000000oooo0?ooo`2;0?ooo`03003o003oool0
oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`0G0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo01D0oooo00@0003o0?ooo`3oool0o`001@3oool00`00o`00oooo0?oo
o`2<0?ooo`030000003oool0oooo08X0oooo00<00?l00?ooo`3oool0103oool0103o0000oooo0?oo
o`000?lH0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01D0oooo00D0
003o0?ooo`3oool0oooo0?l000050?ooo`03003o003oool0oooo08/0oooo00<000000?ooo`3oool0
RP3oool00`00o`00oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l0603oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0F0?ooo`030000o`3oool0oooo0080o`00
1@3oool00`00o`00oooo0?ooo`2:0?ooo`030000003oool0oooo08T0oooo00<00?l00?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo01H0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool05P3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo
00<00?l00?ooo`3oool0RP3oool00`000000oooo0?ooo`280?ooo`03003o003oool0oooo00@0oooo
00D0o`000?ooo`3oool0oooo0000o`0I0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo01L0oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`03003o003oool0oooo08T0
oooo00<000000?ooo`3oool0R03oool00`00o`00oooo0?ooo`030?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool05`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`0G0?ooo`050000o`3oool0oooo0?ooo`3o00001P3oool00`00o`00oooo0?ooo`280?ooo`03
0000003oool0oooo08L0oooo00<00?l00?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0003o
01X0oooo00<000000?ooo`3oool00P3oool004/0oooo0P00000I0?ooo`050000o`3oool0oooo0?oo
o`3o00001@3oool00`00o`00oooo0?ooo`280?ooo`030000003oool0oooo08H0oooo00<00?l00?oo
o`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo01H0oooo0`0000040?oo
o`00B`3oool00`000000oooo0?ooo`0H0?ooo`040000o`3oool0oooo0?ooo`80o`001@3oool00`00
o`00oooo0?ooo`270?ooo`030000003oool0oooo08H0oooo00<00?l00?ooo`3oool00`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo01T0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool06@3oool01@000?l0oooo0?ooo`3oool0o`0000H0oooo00<00?l00?oo
o`3oool0QP3oool00`000000oooo0?ooo`250?ooo`03003o003oool0oooo00@0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo01T0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`03
003o003oool0oooo08D0oooo00<000000?ooo`3oool0Q03oool00`00o`00oooo0?ooo`040?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool06P3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0J0?ooo`040000o`3oool0oooo0?ooo`80o`001P3oool00`00o`00
oooo0?ooo`240?ooo`030000003oool0oooo08@0oooo00<00?l00?ooo`3oool0103oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo01X0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool06P3oool00`000?l0oooo0?ooo`020?ooo`80o`001P3oool00`00o`00oooo
0?ooo`230?ooo`030000003oool0oooo08<0oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo01/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool06`3oool010000?l0oooo0?ooo`3oool20?l000L0oooo00<00?l00?ooo`3oool0
PP3oool00`000000oooo0?ooo`220?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo01/0oooo00<0003o0?ooo`3oool00P3oool20?l000L0oooo00<00?l00?ooo`3oool0P@3o
ool00`000000oooo0?ooo`210?ooo`03003o003oool0oooo00D0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo01`0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`03003o003oool0
oooo0800oooo00<000000?ooo`3oool0P03oool00`00o`00oooo0?ooo`050?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`00
0000oooo0?ooo`0L0?ooo`80003o103oool00`3o0000oooo0?ooo`060?ooo`03003o003oool0oooo
07l0oooo00<000000?ooo`3oool0O`3oool00`00o`00oooo0?ooo`060?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`0M0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01P3oool00`00o`00
oooo0?ooo`1n0?ooo`030000003oool0oooo07h0oooo00<00?l00?ooo`3oool01P3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo01h0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo
00<00?l00?ooo`3oool0OP3oool00`000000oooo0?ooo`1m0?ooo`03003o003oool0oooo00H0oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0O0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`050?ooo`03003o003oool0oooo07d0oooo00<000000?ooo`3oool0O03oool00`00o`00oooo0?oo
o`060?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool07`3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool01P3oool00`00o`00oooo0?ooo`1l0?ooo`030000003oool0oooo07/0oooo00<00?l0
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0200oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00H0oooo00<00?l00?ooo`3oool0N`3oool00`000000oooo0?ooo`1j0?oo
o`03003o003oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0P0?oo
o`030000003oool0oooo0080oooo001;0?ooo`8000008@3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00H0oooo00<00?l00?ooo`3oool0NP3oool00`000000oooo0?ooo`1i0?ooo`03
003o003oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0O0?ooo`<0
0000103oool004/0oooo00<000000?ooo`3oool0803oool20000o`H0oooo00<0o`000?ooo`3oool0
1P3oool00`00o`00oooo0?ooo`1i0?ooo`030000003oool0oooo07T0oooo00<00?l00?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0280oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo00<00?l00?ooo`3oool0N03oool00`000000oooo0?ooo`1h0?ooo`03003o003o
ool0oooo00H0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0R0?ooo`030000003o
ool0oooo0080oooo001;0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`03003o003oool0oooo07L0oooo00<000000?ooo`3oool0M`3oool0
0`00o`00oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool08`3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`1f0?ooo`030000003oool0oooo
07H0oooo00<00?l00?ooo`3oool01P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
02@0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool08`3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00L0oooo00<00?l00?ooo`3oool0M@3oool00`000000
oooo0?ooo`1e0?ooo`03003o003oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo07@0oooo
00<000000?ooo`3oool0M03oool00`00o`00oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`0T0?ooo`80003o1`3oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo07<0oooo00<0
00000?ooo`3oool0L`3oool00`00o`00oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool09P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0U
0?ooo`80003o1`3oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo0780oooo00<00000
0?ooo`3oool0LP3oool00`00o`00oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0V0?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool2003o0780oooo00<000000?oo
o`3oool0L@3oool00`00o`00oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool09`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0V0?ooo`80
003o203oool00`3o0000oooo0?ooo`080?ooo`03003o003oool0oooo06l0oooo00<000000?ooo`3o
ool0L03oool00`00o`00oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool0:03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0W0?ooo`80003o
203oool00`3o0000oooo0?ooo`080?ooo`03003o003oool0oooo06h0oooo00<000000?ooo`3oool0
KP3oool2003o00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0Y0?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02P0oooo0P000?l80?ooo`030?l0003o
ool0oooo00P0oooo00<00?l00?ooo`3oool0K@3oool00`000000oooo0?ooo`1]0?ooo`03003o003o
ool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0Z0?ooo`030000003o
ool0oooo0080oooo001;0?ooo`030000003oool0oooo02T0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`080?ooo`03003o003oool0oooo06`0oooo00<000000?ooo`3oool0J`3oool2
003o00T0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0Z0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`080?ooo`800?l0K03oool00`000000oooo0?ooo`1Z0?ooo`03003o003oool0oooo
00T0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0[0?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo02X0oooo0P000?l90?ooo`030?l0003oool0oooo00T0
oooo00<00?l00?ooo`3oool0J@3oool00`000000oooo0?ooo`1Y0?ooo`03003o003oool0oooo00T0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0/0?ooo`030000003oool0oooo0080
oooo001;0?ooo`800000;03oool20000o`T0oooo00<0o`000?ooo`3oool02@3oool00`00o`00oooo
0?ooo`1X0?ooo`030000003oool0oooo06L0oooo0P00o`0;0?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool0:`3oool3000000@0oooo001;0?ooo`030000003oool0oooo02`0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0:0?ooo`03003o003oool0oooo06L0oooo00<0
00000?ooo`3oool0IP3oool00`00o`00oooo0?ooo`0:0?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool0;@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0]
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02P3oool2003o06L0oooo00<00000
0?ooo`3oool0I03oool2003o00`0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0^
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02h0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool0oooo06@0oooo00<000000?oo
o`3oool0H`3oool00`00o`00oooo0?ooo`0;0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool0;`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0_0?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02`3oool2003o06@0oooo00<000000?ooo`3o
ool0H@3oool2003o00d0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0`0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0300oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo0640oooo00<000000?ooo`3oool0
H03oool00`00o`00oooo0?ooo`0<0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
<03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0a0?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo0?ooo`1P0?ooo`030000003o
ool0oooo05h0oooo0P00o`0>0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0<@3o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0a0?ooo`80003o2@3oool0
0`3o0000oooo0?ooo`0<0?ooo`800?l0H03oool00`000000oooo0?ooo`1M0?ooo`03003o003oool0
oooo00d0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0b0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo0380oooo0P000?l90?ooo`80o`003P3oool00`00
o`00oooo0?ooo`1M0?ooo`030000003oool0oooo05`0oooo00<00?l00?ooo`3oool03@3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo03<0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool0<`3oool20000o`X0oooo00<0o`000?ooo`3oool0303oool2003o05d0
oooo00<000000?ooo`3oool0FP3oool2003o00h0oooo0P3o000:0?ooo`030000o`3oool0oooo03@0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0=03oool20000o`X0oooo
00<0o`000?ooo`3oool03@3oool00`00o`00oooo0?ooo`1J0?ooo`030000003oool0oooo05T0oooo
00<00?l00?ooo`3oool03@3oool00`3o0000oooo0?ooo`080?ooo`80003o=`3oool00`000000oooo
0?ooo`020?ooo`00;`3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo00D0oooo
00<0oooO09a80018W=l02P3oool00`000000oooo0?ooo`0e0?ooo`80003o2P3oool20?l000h0oooo
0P00o`1J0?ooo`030000003oool0oooo05L0oooo0P00o`0?0?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool0=`3oool00`000000oooo0?ooo`020?ooo`00;P3oool01P3OW4P007Bo0?oo
o`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol01P3oool00`3OW4P004RL0=ooo`090?ooo`03
0000003oool0oooo03H0oooo0P000?l;0?ooo`030?l0003oool0oooo00d0oooo0P00o`1H0?ooo`03
0000003oool0oooo05H0oooo00<00?l00?ooo`3oool03P3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo03P0oooo00<000000?ooo`3oool00P3oool002d0oooo00<0oooO09a80018W=l0
0P3oool00`3o_g@0001809cOo`0:0?ooo`030?oOW01804P0W=oo00T0oooo00<000000?ooo`3oool0
>03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00h0oooo0P00o`1F0?ooo`030000
003oool0oooo05@0oooo0P00o`0@0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
>@3oool00`000000oooo0?ooo`020?ooo`00;@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2L
B00004RL0=ooo`D0oooo00<0okmd000000000000100000000`00B9`0gooo0?ooo`060?ooo`030000
003oool0oooo03T0oooo00<0003o0?ooo`3oool02@3oool20?l00100oooo0P00o`1D0?ooo`030000
003oool0oooo0580oooo0P00o`0A0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
>P3oool00`000000oooo0?ooo`020?ooo`00;@3oool00`3ooml0W4P0001d_`030?ooo`030=nLB000
04P0W=oo00D0oooo00<0oooO09a8B02Lgol00P3oool00`2oM00007Bo0?ooo`080?ooo`030000003o
ool0oooo03X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0?0?ooo`800?l0DP3o
ool00`000000oooo0?ooo`1A0?ooo`03003o003oool0oooo00l0oooo0P3o000:0?ooo`030000o`3o
ool0oooo03/0oooo00<000000?ooo`3oool00P3oool002h0oooo00<0_g@00018W03Oool00P3oool0
0`3ogi`0B00004RLg`060?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@004RL0=ooo`080?ooo`<00000
>`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo0100oooo0P00o`1@0?ooo`030000
003oool0oooo04l0oooo0P00o`0A0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
>@3oool4000000@0oooo000^0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l01`3o
ool01P3ogi`0B4RL0=ooo`3ogi`0B01809cOo`P0oooo00<000000?ooo`3oool0?03oool20000o`/0
oooo0P3o000B0?ooo`03003o003oool0oooo04d0oooo00<000000?ooo`3oool0C@3oool2003o0140
oooo0P3o000:0?ooo`80003o?`3oool00`000000oooo0?ooo`020?ooo`00;P3oool00`3ogi`0B000
04RLg`030?ooo`030;md0000B9`0gooo00L0oooo00D0okmd001d_`3ooml0W4P004RLg`080?ooo`03
0000003oool0oooo03d0oooo0P000?l<0?ooo`030?l0003oool0oooo0100oooo0P00o`1=0?ooo`03
0000003oool0oooo04/0oooo0P00o`0A0?ooo`80o`002`3oool00`000?l0oooo0?ooo`0o0?ooo`03
0000003oool0oooo0080oooo000^0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03O
ool0203oool0103OW4P0B9cO0;md0000M;l80?ooo`030000003oool0oooo03h0oooo0P000?l<0?oo
o`80o`004P3oool2003o04/0oooo00<000000?ooo`3oool0B@3oool2003o0180oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo0080oooo000_0?ooo`03
0?oOW0180000M;oo0080oooo00<0gia8001d_`3oool02@3oool0103OW4P0M7Ad0000M02oool70?oo
o`030000003oool0oooo0400oooo00<0003o0?ooo`3oool02`3oool20?l00180oooo0P00o`190?oo
o`030000003oool0oooo04L0oooo0P00o`0B0?ooo`80o`00303oool00`000?l0oooo0?ooo`110?oo
o`030000003oool0oooo0080oooo000`0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO2`3oool0
0`2oM000001809cOo`070?ooo`030000003oool0oooo0440oooo0P000?l=0?ooo`030?l0003oool0
oooo0140oooo0P00o`170?ooo`030000003oool0oooo04D0oooo0P00o`0C0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`020?ooo`00<@3oool0103O
W4P0000000000000M;l<0?ooo`030?oog`2LB000B9cO00L0oooo00<000000?ooo`3oool0@P3oool2
0000o`d0oooo0P3o000C0?ooo`800?l0A@3oool00`000000oooo0?ooo`120?ooo`<00?l04`3oool2
0?l000`0oooo0P000?m50?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
04<0oooo0P000?l>0?ooo`80o`004`3oool2003o04<0oooo00<000000?ooo`3oool0@03oool2003o
01@0oooo0P3o000=0?ooo`030000o`3oool0oooo04D0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool0A@3oool20000o`h0oooo00<0o`000?ooo`3oool04P3oool2003o0440
oooo00<000000?ooo`3oool0?P3oool2003o01@0oooo0P3o000>0?ooo`030000o`3oool0oooo04H0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0AP3oool20000o`h0oooo
0P3o000D0?ooo`<00?l0?P3oool00`000000oooo0?ooo`0k0?ooo`<00?l0503oool20?l000h0oooo
0P000?m90?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo04L0oooo0`00
0?l>0?ooo`80o`005@3oool3003o03/0oooo00<000000?ooo`3oool0>03oool3003o01D0oooo0P3o
000?0?ooo`030000o`3oool0oooo04T0oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool0B@3oool20000o`l0oooo0P3o000F0?ooo`<00?l0>03oool00`000000oooo0?ooo`0e
0?ooo`<00?l05P3oool20?l00100oooo00<0003o0?ooo`3oool0BP3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`1:0?ooo`80003o403oool20?l001L0oooo0`00o`0e0?oo
o`030000003oool0oooo0340oooo1000o`0G0?ooo`80o`00403oool20000odd0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool0B`3oool30000oa00oooo0P3o000H0?ooo`<0
0?l0<P3oool00`000000oooo0?ooo`0^0?ooo`<00?l06@3oool20?l00140oooo00<0003o0?ooo`3o
ool0C@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1=0?ooo`80003o
4@3oool20?l001T0oooo0`00o`0_0?ooo`030000003oool0oooo02/0oooo0`00o`0J0?ooo`80o`00
4P3oool00`000?l0oooo0?ooo`1>0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo04l0oooo0P000?lA0?ooo`<0o`006@3oool3003o02`0oooo00<000000?ooo`3oool09`3o
ool4003o01/0oooo0P3o000B0?ooo`80003oD@3oool00`000000oooo0?ooo`020?ooo`00B`3oool2
00000580oooo00<0003o0?ooo`3oool04@3oool20?l001X0oooo0`00o`0Y0?ooo`030000003oool0
oooo02@0oooo0`00o`0L0?ooo`<0o`004`3oool00`000?l0oooo0?ooo`1?0?ooo`<00000103oool0
04/0oooo00<000000?ooo`3oool0DP3oool20000oa<0oooo0P3o000K0?ooo`@00?l09@3oool00`00
0000oooo0?ooo`0P0?ooo`@00?l07@3oool20?l001@0oooo0P000?mD0?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo05@0oooo0P000?lC0?ooo`<0o`00703oool6003o01l0
oooo00<000000?ooo`3oool0703oool4003o01l0oooo0P3o000D0?ooo`80003oEP3oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1E0?ooo`<0003o503oool20?l00200oooo
2000o`0G0?ooo`030000003oool0oooo01P0oooo1000o`0Q0?ooo`80o`00503oool20000oeP0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0E`3oool30000oa@0oooo0`3o
000U0?ooo`H00?l04@3oool00`000000oooo0?ooo`0?0?ooo`T00?l08P3oool30?l001D0oooo00<0
003o0?ooo`3oool0F03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1I
0?ooo`<0003o5@3oool20?l002T0oooo8`00o`0Y0?ooo`80o`005P3oool20000oe/0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0F`3oool30000oaD0oooo0`3o000g0?oo
o`030000003oool0oooo03H0oooo0P3o000F0?ooo`80003oG@3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`1M0?ooo`<0003o5P3oool20?l003D0oooo00<000000?ooo`3o
ool0<`3oool30?l001H0oooo0P000?mO0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo05l0oooo0`000?lF0?ooo`<0o`00<P3oool00`000000oooo0?ooo`0`0?ooo`<0o`00
5`3oool20000of40oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0H@3o
ool30000oaL0oooo103o000^0?ooo`030000003oool0oooo02`0oooo103o000H0?ooo`80003oH`3o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1S0?ooo`<0003o6@3oool5
0?l002T0oooo00<000000?ooo`3oool0:03oool40?l001X0oooo0P000?mU0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo06D0oooo0`000?lL0?ooo`@0o`009@3oool00`00
0000oooo0?ooo`0T0?ooo`@0o`006`3oool30000ofL0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool0I`3oool40000oad0oooo1@3o000P0?ooo`030000003oool0oooo01h0
oooo1P3o000L0?ooo`<0003oJP3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`1Z0?ooo`@0003o7`3oool40?l001`0oooo00<000000?ooo`3oool05`3oool70?l00200oooo
0P000?m]0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo06d0oooo1000
0?lP0?ooo`T0o`004`3oool00`000000oooo0?ooo`0B0?ooo`D0o`00903oool30000ofl0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0L03oool40000obH0oooo303o0007
0?ooo`030000003oool0oooo00<0oooo3`3o000V0?ooo`<0003oLP3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool2000007<0oooo1@000?l_0?ooo`d0o`00<@3oool40000og<0oooo0`0000040?oo
o`00B`3oool00`000000oooo0?ooo`1e0?ooo`D0003o<`3oool00`000000oooo0?ooo`0a0?ooo`<0
003oN@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1h0?ooo`D0003o
<03oool00`000000oooo0?ooo`0^0?ooo`<0003oO03oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`1l0?ooo`@0003o;@3oool00`000000oooo0?ooo`0Z0?ooo`@0003oO`3o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`200?ooo`@0003o:@3oool0
0`000000oooo0?ooo`0V0?ooo`@0003oP`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`00
0000oooo0?ooo`240?ooo`D0003o903oool00`000000oooo0?ooo`0R0?ooo`@0003oQ`3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`280?ooo`D0003o803oool00`000000
oooo0?ooo`0M0?ooo`D0003oR`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`2<0?ooo`P0003o6@3oool00`000000oooo0?ooo`0H0?ooo`D0003oT03oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`2C0?ooo`X0003o403oool00`000000oooo0?oo
o`0=0?ooo`/0003oU@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`2M
0?ooob00003oX03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`2]0?oo
o`030000003oool0oooo0:d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool0[@3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo0:d0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0
oooo0080oooo001;0?ooo`800000:03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
02D0oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004/0ooooo`00
001R000000@0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo002:0?ooo`060=nLB000000000000000000004P0W=oo1P3oool00`2oM00007Bo
0?ooo`050?ooo`050=nLB000000000000000001d_ol00`3oool01@3OW4P00000000000000000M;oo
00T0oooo00<0gia80000000000000P0000000`00M;l0oooo0?ooo`020?ooo`050?noM00000000000
0000B02Lgol00`3oool00`3OW4P004RL0=ooo`020?ooo`050;md0000000007Bo0?oo_`1d00000`00
00001@18W=l0oooo0?ooo`3oool0gia800<0000000D0M;oo0?ooo`3oool0_g@0001d_`070?ooo`03
0?noM000M;l0oooo00<0oooo00d0omnL04P000000000000007Boo`3OW4P000000018W03Oool0okmd
0000000004P0W=oo0080oooo00@0_g@00000000004P0W=oo0`3oool00`3o_g@007Bo0?ooo`040?oo
o`050=nLB000000000000000001d_ol01`3oool00`3ookl0M00000000002000000030018W03Oool0
oooo0080oooo00<0oono07@0000000000P0000001@18W=l0oooo0?ooo`3oool0gia80080000000<0
001809cOo`3oool00P3oool04@2oM00000000000B02Lgol0oooo0?noM0000000001d0;ooo`3oool0
okmd0000000007@0_ooo0?ooo`3ogi`0B0000080000000T0M;oo0=nLB000000004RL0=ooo`3o_g@0
00000000B02Lgol00P3oool0102oM00000000000B02Lgol20?ooo`050?noM000000000000000B02L
gol00`3oool00`3OW4P004RL0=ooo`020?ooo`050;md0000000007Bo0?oo_`1d00000`0000000`18
W=l0oooo0?ooo`130?ooo`00R`3oool0103ooml0W4P00018W03Oool70?ooo`030?noM00007@0_ooo
00@0oooo00<0omnL04P0001d_ol00P3oool01P2oM00007Bo0?ooo`3ogi`0B00007Boo`80oooo00<0
_g@0001d_`3oool01@3oool0103ooml0W4P000000018W=l30?ooo`0;0?noM00007@0_ooo0?ooo`3o
gi`0B01809cOo`3oool0omnL04P00000M;l00P3oool00`3o_g@0001d0;ooo`020?ooo`0>0=nLB000
B9`0gkmd07Bog`2LB000M;oo0?ooo`3ogi`0B00007Boo`3oool0omnL04P0001d_ol20?ooo`060;md
0000M;l0oooo0?noM00007@0_ooo1P3oool0103o_g@000000018W03Oool20?ooo`0D0;md0000B9`0
gooo0?ooo`2oM000M7Ad0000M02ogi`0W;oo0?noM00004P0W=oO09adW03Oool0oooo0=nLB000B9`0
gooO09adW03Oool20?ooo`040?noM000000004RL0=ooo`80oooo00<0omnL04P0001d_ol00P3oool0
0`2oM00007Bo0?ooo`040?ooo`040?oOW018000004RL0=ooo`80oooo00<0_g@000000018W=l00P3o
ool03`3ooml0W4P007Boo`3oool0omnL04P0001d_ol0oooo0?noM0000000M;oo0?ooo`3ooml0W4P0
04RLg`020?ooo`0Z0=nLB000B9`0gooO09adW03Oool0omnL04P0M02ookl0W9cO0?ooo`3ogi`0B01d
0;oo_`2LW=l0oooo0;md0000B9`0gooo0?ooo`2oM000M7Ad0000M02ogi`0W;oo0?noM00004P0W=oO
09adW03Oool0oooo0=nLB000B9`0gooO09adW03Oool0omnL04P0B02Lgol0oooo0?oOW018000007Bo
0P3oool00`3o_g@0001d0;ooo`020?ooo`0:0=nLB000B9`0gkmd07Bog`2LB000M;oo0?ooo`3ogi`0
B00007Bood@0oooo002<0?ooo`030?noM00004P0W=oo00L0oooo00<0omnL04P0001d_ol0103oool0
0`3OW4P004RL0=ooo`030?ooo`050=nLW02oool0gia80018W03Oool00`3oool00`3OW9`0_ooo0?oo
o`040?ooo`030=nLB0000000B9cO00D0oooo00H0oono07Ad_`3oool0gia80018W03Oool20?ooo`07
0?oOW0180000B9cO0?ooo`3ookl0M00004RLg`020?ooo`0>0?oOW01804P0W=oo0?ooo`2oM7@0_ooo
0?ooo`3ookl0M00007Boo`3oool0gia80018W03Oool30?ooo`050=nLW02oool0omnL04P0001d_ol0
1P3oool0103OW4P0001d0;oOW018M;l20?ooo`030;md0000M;l0oooo0080oooo00L0_g@00000001d
_ol0oooo0?oo_`1d0000M;oo00<0oooo00<0okmd0000B02Lgol0103oool0103OW4P0001d0;oOW018
M;l20?ooo`030=nLB000B9`0gooo00<0oooo00<0gibL0;ooo`3oool00`3oool00`2oM000001809cO
o`040?ooo`030?noM000000007Bo0080oooo00X0_gAd0;ooo`3oool0oono07@0001d_ol0oooo0=nL
B000B9`0gooo0`3oool01P3Ogml0oooo0?ooo`3o_g@0001809cOo`80oooo00`0oono07@0001d_ol0
gibL0;ooo`3ookl0M00007Boo`3OW9`0_ooo0;md0000M;l30?ooo`070;md00000000M;oo0?ooo`3o
okl0M00007Boo`030?ooo`030?noM00004P0W=oo0080oooo00<0gia80018W03Oool00P3oool01`3o
gi`0B00004RLg`3oool0oono07@00018W=l00P3oool02P3ogi`0B01809cOo`3oool0_gAd0;ooo`3o
ool0oono07@0001d_om40?ooo`00S03oool00`3ogi`0B00007Boo`070?ooo`040?oog`2LB00004RL
0=ooo`<0oooo00D0okmd000000000000000004RLg`030?ooo`050?noM0000000000000000018W=l0
1`3oool0103ooml0W4P00000M02oool80?ooo`030?noM00007@0_ooo00<0oooo00/0gia80000M02o
ool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`040?ooo`050=nLB00007@0_ooo0?ooo`3o
_g@00`0000002018W=l0oooo0?ooo`3oool0oooO09a80000B9`0gooo1@3oool02@3OW4P004RL0=oo
o`3o_g@0M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`030?oo_`1d0000B9cO0080oooo00<0_g@0001d
_`3oool00P3oool00`3ookl0M00004RLg`040?ooo`070=nLB000B9`0gooo0?noM01d_ol0oooo0?no
M0030000000304RLg`3oool0oooo00@0oooo00@0oooO09a80000B9`0gooo1@3oool00`3OW4P00000
04RLg`040?ooo`070=nLB00007@0_ooo0?ooo`3o_g@0001d0;ooo`060?ooo`030?oo_`1d0000B9cO
00<0oooo00<0_g@004RLg`3oool00P3oool01`2oM000B9cO0?ooo`3oool0okmd0000M02oool00P3o
ool00`3ookl0M00004RLg`020?ooo`030;md0000M;l0oooo0080oooo00<0oono07@00018W=l00P3o
ool00`3o_g@0001d0;ooo`030?ooo`0;0=nLB00007@0_ooo0?oog`2LB000001d0;ooo`3oool0oooO
09a80018W=l0103oool00`3OW4P0001d0;ooo`140?ooo`00S03oool00`3ooml0W4P0001d_`030?oo
o`030;nLW03Oool0oooo0080oooo00<0_g@004QdM01dW=l00`3oool03`3ookl0M01809cOo`3oool0
gia800000018W=l0oooo0?oo_`1d04P0W=oo0?ooo`3OW4P0000004RLg`050?ooo`040?oo_`1d0000
04RL0=ooo`P0oooo00<0oono07@0001d_ol00`3oool01`3ogi`0B01809cOo`3oool0gia80018B018
M;l00P3oool00`2oM00007Bo0?ooo`020?ooo`030?noM00004P0W=oo0080oooo00L0oono07@0B02L
gol0oooo0=nLB0000000B9cO0080oooo00<0_g@004QdM01dW=l01@3oool02@2oM00004RL0=ooo`3o
ool0_gAd0;ooo`3ookl0M00007Boo`030?ooo`070;md0000B9`0gooo0?ooo`3OW4P004RL0=ooo`03
0?ooo`030;md0000B9`0gooo00<0oooo00d0_g@00018W03Oool0oooo0;mdM02oool0oono07@0B02L
gol0oooo0=nLB0000000B9cO00@0oooo00@0oono07@00000B9`0gooo1@3oool0103ookl0M0000000
M02oool20?ooo`030?noM00004P0W=oo0080oooo00<0oono07@0001d_ol01`3oool00`2oM00004RL
0=ooo`020?ooo`030=nLB000B9`0gooo0080oooo00L0gia80018W03Oool0oooo0?oo_`1d0000M;oo
00<0oooo00L0_g@00018W03Oool0oooo0=nLB000B9`0gooo00<0oooo00L0_g@00018W03Oool0oooo
0?oo_`1d0000M;oo00<0oooo00L0omnL04P0B02Lgol0oooo0=nLB000B4P0B7Bo0080oooo00<0_g@0
001d_`3oool00P3oool00`3o_g@0001809cOo`150?ooo`00S@3oool01`2oM00004RL0=ooo`3oool0
oooO09a8B02Lgol00`3oool0103o_g@004RL0;nLB01d_ol30?ooo`0?0?noM000B9`0gooo0?ooo`3o
okl0M00004RLg`3oool0okmd0018W03Oool0oooo0?oo_`1d0000B9cO00@0oooo00@0oooO09a80000
07@0_ooo2@3oool00`3OW4P0001d0;ooo`020?ooo`0P0?oo_`1d0000M;oo0?ooo`3o_g@0001d0;no
M018W=l0oooo0?noM00007@0_ooo0?ooo`3ogi`0B01809cOo`3oool0giad09cOo`3oool0okmd0018
W03Oool0oooo0?oo_`1d0000B9cO0?ooo`3o_g@004RL0;nLB01d_ol30?ooo`030?oog`2LB00007Bo
0080oooo00H0omnL07BLg`3oool0okmd0000M02oool20?ooo`070=nLB00007@0_ooo0?ooo`3ogi`0
B01809cOo`030?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l00P3oool02P3ogi`0
M9cO0?ooo`3o_g@004RL0=ooo`3oool0oono07@00018W=l30?ooo`040?oog`2LB000001809cOo`H0
oooo0180gia800000018W=l0oooo0?oOW01804P0W=oo0?ooo`3OW7@0W=oo0?ooo`3OW4P0001d0;oo
o`3oool0oono07@0001d_ol20?ooo`030=nLB00004P0W=oo0080oooo00<0omnL04P0M02oool00P3o
ool00`3ogi`0B01d0;ooo`020?ooo`030?noM00007@0_ooo0080oooo00L0gia80000M02oool0oooo
0?oOW01804P0W=oo00<0oooo00<0gia80000B02Lgol00P3oool00`3OW4P0001d0;ooo`020?ooo`0C
0?oo_`1d0000M;oo0?ooo`3o_g@0001d0;noM018W=l0oooo0?noM00007@0_ooo0?ooo`3ogi`0B018
09cOo`3oool0giad09cOo`130?ooo`00S@3oool00`3o_g@00000000000030000000K07Boo`3oool0
oooo0?ooo`3ookl0M01809cOo`2oM000M7Ad0018W03Oool0oooo0=nLB00007@0_ooo0?ooo`3OW4P0
04RL0=ooo`3oool0gia80000M02oool0oooo0=nLB000B9`0gooo00@0oooo00<0_g@00000B02Lgol0
2P3oool05`2oM000001d0;ooo`3oool0okmd0000M02oool0oooo0?oog`2LB000M;oo0=nLB000M;l0
omnL04P0B02Lgol0oooo0?oOW01804P0W=oo0?oog`2LB000M;oo0080oooo0140gia80000M02oool0
oooo0=nLB000B9`0gooo0?oo_`1d04P0W=oo0;md001dM7@004RL0=ooo`3ogi`0B00004RLg`020?oo
o`0?0?noM000B9`0gooo0?ooo`3OW4P0001d0;ooo`3oool0_g@00000B02Lgol0oooo0?oog`2LB000
B9cO00<0oooo00<0omnL04P00018W=l00P3oool00`3ogi`0B00004RLg`020?ooo`0;0?noM000B9`0
gooo0?ooo`3OW4P0001d0;ooo`3oool0gia80018W03Oool00`3oool00`3OW4P0000004RLg`060?oo
o`0:0?oOW018000004RL0=ooo`3ogi`0B01809cOo`3ooml0W4P007Boo`80oooo00H0_g@00000M02o
ool0oooo0=nLB018W=l20?ooo`030?oOW0180000B9cO0080oooo00<0oono07@0001d_ol00P3oool0
0`3ookl0M00007Boo`030?ooo`0;0=nLB00007@0_ooo0?ooo`2oM000001809cOo`3oool0oooO09a8
0018W=l00`3oool00`3ogi`0B00004RLg`030?ooo`0G0;md000007@0_ooo0?ooo`3o_g@0001d0;oo
o`3oool0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOo`3oool0omnL04P0B02Lgol0oooO09a8
001d_ol0@`3oool008d0oooo00<0oono07@0001d_ol00P3oool0303OW4P0B9cO0?ooo`3oool0omnL
04P000000000M;oo0?ooo`2oM000001d0;ooo`80oooo00D0omnL04P000000000000007Boo`030?oo
o`050?oOW018000000000000001d_ol01@3oool00`3o_g@00000001d_`0;0?ooo`0?0?noM0000000
00000000001d_ol0oooo0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo0080oooo00D0
_g@0000000000000000004RLg`030?ooo`0E0?oOW018000000000000001d_ol0omnL04P000000000
M;oo0?ooo`2oM000001d07Ad00000000001809cOo`3oool0oooO09a80000B9`0gooo0080oooo00P0
omnL04P000000000B9bL07@00018W=l0oono07@000<0000000l0M;oo0?noM000000000000018W03O
ool0_g@00000000004P0W=oo0?ooo`3ooml0W4P00018W03Oool00P3oool01@3ogi`0B00000000000
0000M;oo00@0oooo00@0oono07@00000B9`0gooo1@3oool01P3ooml0W4P00018W03Oool0oooo0;md
00<0000000/0B9cO0?ooo`3oool0oooo0?oOW018000000000000B02Lgol0oooo0?noM00200000006
0018W03Oool0oooo0?ooo`2oM000B9cO0`3oool00`2oM000B9cO0?ooo`030?ooo`080?oOW0180000
000004RLW01d0000B9cO0?oo_`1d00030000000607Boo`3o_g@0000000000000B9`0gooo0`3oool0
3`3o_g@00000000000000000M;oo0?ooo`3ookl0M00000000018W=l0oooo0?noM0000000001809cO
o`020?ooo`050;md00000000000000000018W=l0@`3oool008d0oooo00<0oooO09a80000M;l00P3o
ool00`3ooml0W7BL0=ooo`0N0?ooo`030;md000004P0W=oo00D0oooo00<0oono07Ad_`3oool0>P3o
ool00`3o_g@0001d0;ooo`0K0?ooo`030?noM0000000B9cO00D0oooo00@0oooO09a80000B9`0gooo
5P3oool00`3OW4P004RL0=ooo`020?ooo`030=nLB000B9`0gooo00/0oooo00<0okmd0000M02oool0
HP3oool008h0oooo00<0gia80018W03Oool0103oool00`3ogi`0W;oo0?ooo`0K0?ooo`040?oo_`1d
0000001d0;ooo`@0oooo00<0omnL04Q8W03Oool0>`3oool00`3OW7@0W=oo0?ooo`0K0?ooo`030=nL
B0000000M;oo00@0oooo00<0oono07@00000M;l05`3oool00`3ogi`0B01d0;ooo`020?ooo`030?oO
W01807@0_ooo00`0oooo00<0giad09cOo`3oool0H@3oool008h0oooo00<0okmd0000B02Lgol0103o
ool00`3OW4P007Bo0?ooo`0L0?ooo`040?oog`2LB000000007Boo`80oooo00@0oooO09a8000004P0
W=oo@03oool0103ookl0M0000018W03OoolF0?ooo`030?noM000000007Bo0080oooo00@0oooO09a8
000004P0W=oo4P3oool0203ookl0M0000018W03Oool0oooo0?oog`2LB000M;oo0P3oool00`3ooml0
W4P007Boo`0A0?ooo`040?oo_`1d000004RL0=oooe/0oooo002=0?ooo`030;md00000000000000H0
000000<0001d0;ooo`3oool07@3oool0203ookl0M000000000000000001809cOo`3o_g@0M;ooG03o
ool01P2oM0000000000000000000001d0;oooaT0oooo00<0gia804RLg`3oool00P3oool00`3OW4P0
B9cO0?ooo`1_0?ooo`00o`3ooolh0?ooo`090?oog`2LB0000000001d_`3oool0oooO09a800000000
07Bo0700oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000
\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-0.750245, -0.719837, \
0.00447936, 0.00475106}}]
}, Closed]],

Cell[TextData[{
  "It is also of interest to consider the case ",
  Cell[BoxData[
      \(TraditionalForm\`k < 0, \[Alpha] > 0\)]],
  ", which produces double-well potentials.  The motion is still confined and \
periodic, but the phase trajectory is more interesting."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
        Evaluate[
          Table[\(\[Nu][\(-1\), \[Alpha]]\)[x], {\[Alpha], 1\/3, 1, 
              1\/3}]], {x, \(-3\), 3}, 
        PlotRange \[Rule] {Automatic, {\(-1\), 1}}, 
        PlotStyle \[Rule] {RGBColor[0, 1, 0], RGBColor[1, 0, 0], 
            RGBColor[0, 0, 1]}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.309017 [
[.02381 .29652 -9.34375 -15.6875 ]
[.02381 .29652 9.34375 0 ]
[.18254 .29652 -9.34375 -15.6875 ]
[.18254 .29652 9.34375 0 ]
[.34127 .29652 -9.34375 -15.6875 ]
[.34127 .29652 9.34375 0 ]
[.65873 .29652 -5 -15.6875 ]
[.65873 .29652 5 0 ]
[.81746 .29652 -5 -15.6875 ]
[.81746 .29652 5 0 ]
[.97619 .29652 -5 -15.6875 ]
[.97619 .29652 5 0 ]
[.4875 0 -18.6875 -7.84375 ]
[.4875 0 0 7.84375 ]
[.4875 .07725 -33.6875 -7.84375 ]
[.4875 .07725 0 7.84375 ]
[.4875 .15451 -27.6875 -7.84375 ]
[.4875 .15451 0 7.84375 ]
[.4875 .23176 -33.6875 -7.84375 ]
[.4875 .23176 0 7.84375 ]
[.4875 .38627 -25 -7.84375 ]
[.4875 .38627 0 7.84375 ]
[.4875 .46353 -19 -7.84375 ]
[.4875 .46353 0 7.84375 ]
[.4875 .54078 -25 -7.84375 ]
[.4875 .54078 0 7.84375 ]
[.4875 .61803 -10 -7.84375 ]
[.4875 .61803 0 7.84375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.18254 .30902 m
.18254 .31527 L
s
gsave
.18254 .29652 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.34127 .30902 m
.34127 .31527 L
s
gsave
.34127 .29652 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.65873 .30902 m
.65873 .31527 L
s
gsave
.65873 .29652 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.81746 .30902 m
.81746 .31527 L
s
gsave
.81746 .29652 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
gsave
.4875 0 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .07725 m
.50625 .07725 L
s
gsave
.4875 .07725 -94.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.5 .15451 m
.50625 .15451 L
s
gsave
.4875 .15451 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .23176 m
.50625 .23176 L
s
gsave
.4875 .23176 -94.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.5 .38627 m
.50625 .38627 L
s
gsave
.4875 .38627 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.5 .46353 m
.50625 .46353 L
s
gsave
.4875 .46353 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .54078 m
.50625 .54078 L
s
gsave
.4875 .54078 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.5 .61803 m
.50625 .61803 L
s
gsave
.4875 .61803 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
.5 Mabswid
.06297 .61803 m
.08426 .46095 L
.10458 .34191 L
.12297 .25702 L
.14264 .18747 L
.15285 .15913 L
.16394 .13384 L
.17353 .11624 L
.18408 .10105 L
.18902 .09536 L
.19432 .09018 L
.19891 .08647 L
.20392 .08317 L
.20684 .08161 L
.20955 .08038 L
.21236 .07933 L
.2149 .07857 L
.2174 .078 L
.21976 .07761 L
.22106 .07745 L
.22225 .07735 L
.22356 .07728 L
.22422 .07726 L
.22495 .07725 L
.22625 .07727 L
.22746 .07732 L
.22809 .07736 L
.22878 .07742 L
.23019 .07757 L
.23142 .07774 L
.23275 .07796 L
.23515 .07846 L
.24001 .07984 L
.24446 .08154 L
.25465 .08686 L
.26537 .09436 L
.28511 .11234 L
.30348 .13269 L
.34253 .18189 L
.38402 .23387 L
.40483 .2568 L
.42401 .27495 L
.44269 .28931 L
.45223 .29523 L
.46247 .30046 L
.46772 .30267 L
.4727 .30447 L
.47755 .30594 L
.48205 .30704 L
.48629 .30787 L
Mistroke
.48846 .3082 L
.49081 .3085 L
.49215 .30864 L
.49339 .30875 L
.49455 .30883 L
.49582 .30891 L
.49696 .30896 L
.49803 .30899 L
.49915 .30901 L
.50036 .30902 L
.50158 .309 L
.50228 .30899 L
.50293 .30896 L
.50425 .30891 L
.50566 .30882 L
.50822 .3086 L
.51056 .30833 L
.51596 .30746 L
.52164 .30615 L
.53126 .30306 L
.54177 .29844 L
.56142 .28646 L
.58239 .26926 L
.62394 .22439 L
.66397 .17346 L
.70249 .12577 L
.72201 .10531 L
.73236 .09617 L
.74346 .08805 L
.74893 .08478 L
.75412 .08217 L
.75918 .08013 L
.7614 .07939 L
.76386 .0787 L
.76598 .0782 L
.76828 .07778 L
.76954 .0776 L
.7707 .07747 L
.77181 .07737 L
.77298 .0773 L
.77417 .07726 L
.77544 .07726 L
.77663 .07729 L
.77772 .07735 L
.779 .07746 L
.78039 .07763 L
.7817 .07783 L
.78291 .07806 L
.78758 .07931 L
.7902 .08027 L
Mistroke
.79259 .08133 L
.80165 .08689 L
.80671 .09112 L
.81223 .09672 L
.82229 .1097 L
.83261 .12708 L
.84197 .14665 L
.86295 .20514 L
.88221 .27888 L
.90304 .38326 L
.92299 .51043 L
Mfstroke
.92299 .51043 m
.93659 .61803 L
s
1 0 0 r
.16856 .61803 m
.18466 .50146 L
.20597 .38526 L
.21574 .34322 L
.22611 .30556 L
.23561 .27678 L
.24608 .2509 L
.25553 .2323 L
.26452 .21843 L
.26937 .21237 L
.27466 .20682 L
.27952 .20263 L
.28393 .19955 L
.28917 .19673 L
.29205 .19555 L
.29476 .19466 L
.29727 .19402 L
.29958 .19359 L
.3008 .19343 L
.30212 .19329 L
.30279 .19323 L
.30351 .19319 L
.30481 .19314 L
.30603 .19314 L
.30672 .19315 L
.30737 .19317 L
.30868 .19325 L
.30942 .19331 L
.31009 .19338 L
.31247 .1937 L
.31498 .19416 L
.31772 .19483 L
.32027 .19558 L
.32605 .19774 L
.33578 .20264 L
.34617 .20933 L
.38767 .24455 L
.40847 .26333 L
.42765 .27914 L
.44752 .29274 L
.45724 .29807 L
.46611 .30208 L
.47516 .30526 L
.48015 .30661 L
.48488 .30762 L
.48736 .30804 L
.49 .3084 L
.4925 .30867 L
.49475 .30885 L
.49614 .30893 L
Mistroke
.49742 .30898 L
.49809 .30899 L
.49882 .30901 L
.49959 .30902 L
.5003 .30902 L
.50162 .309 L
.50282 .30897 L
.50348 .30894 L
.50421 .30891 L
.50552 .30883 L
.50786 .30864 L
.51038 .30836 L
.51494 .30765 L
.52037 .30649 L
.52533 .30512 L
.53558 .30138 L
.54635 .29622 L
.56613 .28375 L
.58451 .26936 L
.62361 .23426 L
.64356 .21709 L
.65406 .20917 L
.66516 .20211 L
.67509 .19727 L
.67781 .19623 L
.68073 .19527 L
.68326 .19457 L
.686 .19396 L
.6873 .19373 L
.68868 .19353 L
.68995 .19337 L
.69115 .19326 L
.69227 .19319 L
.69347 .19315 L
.69412 .19314 L
.69481 .19314 L
.69604 .19317 L
.69713 .19323 L
.6983 .19333 L
.6994 .19345 L
.70041 .19359 L
.70287 .19405 L
.70519 .19464 L
.70981 .19628 L
.7149 .19885 L
.72021 .20242 L
.72518 .20667 L
.73407 .21657 L
.74363 .23085 L
.75374 .25051 L
Mistroke
.76478 .27786 L
.78487 .34567 L
.80456 .43824 L
.82554 .5703 L
Mfstroke
.82554 .5703 m
.83134 .61803 L
s
0 0 1 r
.21499 .61803 m
.2212 .56762 L
.24035 .44874 L
.25024 .40005 L
.26113 .35532 L
.27069 .32306 L
.28097 .29491 L
.29183 .27181 L
.302 .25565 L
.3121 .2442 L
.31782 .23954 L
.32313 .23627 L
.32576 .23501 L
.32823 .23402 L
.33048 .23329 L
.33286 .23268 L
.33409 .23242 L
.33545 .23219 L
.33668 .23203 L
.33784 .23191 L
.33853 .23186 L
.33919 .23182 L
.34043 .23177 L
.34113 .23176 L
.34177 .23177 L
.34247 .23178 L
.34322 .23181 L
.34436 .23188 L
.3456 .23199 L
.3469 .23214 L
.34811 .23231 L
.35259 .23322 L
.35515 .23392 L
.35748 .23466 L
.36269 .23666 L
.38097 .24656 L
.42095 .27545 L
.43927 .28806 L
.44968 .29427 L
.45942 .29925 L
.46981 .30353 L
.4793 .30641 L
.4845 .30755 L
.48944 .30833 L
.49215 .30864 L
.49344 .30875 L
.49466 .30884 L
.49535 .30888 L
.4961 .30892 L
.49741 .30898 L
Mistroke
.49815 .309 L
.49894 .30901 L
.49961 .30902 L
.50034 .30902 L
.50165 .309 L
.50286 .30897 L
.50349 .30894 L
.50419 .30891 L
.5056 .30883 L
.50816 .30861 L
.51057 .30833 L
.51506 .30763 L
.51989 .30661 L
.52521 .30517 L
.53081 .3033 L
.54082 .29914 L
.5606 .28814 L
.57898 .2755 L
.61807 .24718 L
.62834 .24102 L
.63375 .23826 L
.63946 .23578 L
.64446 .23404 L
.64711 .2333 L
.64996 .23266 L
.6513 .23241 L
.65257 .23221 L
.65381 .23205 L
.65495 .23193 L
.65604 .23185 L
.65719 .23179 L
.65835 .23176 L
.65962 .23177 L
.66084 .23182 L
.66197 .23189 L
.66321 .23202 L
.66453 .23219 L
.66724 .2327 L
.6697 .23334 L
.67445 .2351 L
.67895 .23743 L
.68415 .24101 L
.68895 .24519 L
.69979 .25814 L
.70947 .27424 L
.71853 .29371 L
.72911 .32245 L
.73917 .35642 L
.75943 .44754 L
.77796 .56166 L
Mistroke
Mfstroke
.77796 .56166 m
.78492 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00b03oool00`3ookl0M000000000020000000304RLg`3oool0oooo0>00oooo003:0?ooo`03
0?noM0000000M;oo0><0oooo003:0?ooo`030?oog`2LB00007Bo0><0oooo003;0?ooo`030=nLB000
B9`0gooo0>80oooo002k0?ooo`030?oog`2LB000000000L0000000<0B9cO0?ooo`3oool00`3oool0
0`3ogi`0B01809cOo`3R0?ooo`00b`3oool00`3ookl0M00007Boo`0;0?ooo`@00000d`3oool00<`0
oooo00<0_g@0001d_`3oool02P3oool00`000000oooo0?ooo`3D0?ooo`00c03oool00`3OW4P004RL
0=ooo`0:0?ooo`030000003oool0oooo0=@0oooo003<0?ooo`030?oOW01804P0W=oo00X0oooo00<0
00000?ooo`3oool0e03oool00<`0oooo00<0oono07@0001d_ol02P3oool00`000000oooo0?ooo`3D
0?ooo`00c@3oool00`2oM00007Bo0?ooo`090?ooo`030000003oool0oooo0=@0oooo003;0?ooo`05
0?oo_`1d000000000000M02oool02@3oool300000=@0oooo003I0?ooo`030000003oool0oooo0=@0
oooo003I0?ooo`030000003oool0oooo0=@0oooo003I0?ooo`030000003oool0oooo0=@0oooo003I
0?ooo`030000003oool0oooo0=@0oooo003I0?ooo`030000003oool0oooo0=@0oooo003I0?ooo`03
0000003oool0oooo0=@0oooo003I0?ooo`<00000e03oool00=T0oooo00<000000?ooo`3oool0e03o
ool00=T0oooo00<000000?ooo`3oool0e03oool00=T0oooo00<000000?ooo`3oool0e03oool00=T0
oooo00<000000?ooo`3oool0e03oool00=T0oooo00<000000?ooo`3oool0e03oool00=T0oooo0`00
003D0?ooo`00f@3oool00`000000oooo0?ooo`3D0?ooo`00f@3oool00`000000oooo0?ooo`3D0?oo
o`00f@3oool00`000000oooo0?ooo`3D0?ooo`00f@3oool00`000000oooo0?ooo`3D0?ooo`00f@3o
ool00`000000oooo0?ooo`3D0?ooo`00f@3oool300000=@0oooo002d0?ooo`040;md000000000000
07Boo`<0oooo00<0omnL04P0001d_ol00`3oool00`3ookl0M4RL0=ooo`050?ooo`060?oOW0180000
000000000000B9`0gooo2P3oool00`000000oooo0?ooo`3D0?ooo`00/`3oool01P3OW4P007Bo0?oo
o`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol0103oool00`3OW4P0B9cO0?ooo`040?ooo`06
0?noM0000000M;oo0?ooo`3ogi`0B7Bo2P3oool00`000000oooo0?ooo`3D0?ooo`00/P3oool00`3o
oml0W4P004RLg`020?ooo`030?noM00004P0W=oo00P0oooo00<0oono07@0M02oool02@3oool00`3o
_g@0B9cO0?ooo`080?ooo`030000003oool0oooo0=@0oooo002b0?ooo`030?oog`2LB000B9cO0080
oooo00@0oooO09a80000B9`0gooo203oool00`3o_g@007Bo0?ooo`080?ooo`030?oo_`1d07@0_ooo
00P0oooo00<000000?ooo`3oool0e03oool00:D0oooo00<0oooO09a8000000001`0000001P18W=l0
oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol0203oool00`3ooml0W4Q809cOo`08
0?ooo`030?oog`2LB000M;oo00P0oooo00<000000?ooo`3oool0e03oool006T0oooo2@00o`110?oo
o`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l02@3oool00`3ogi`0B7Bo0?ooo`070?oo
o`030?oo_`1d0000B9cO00P0oooo1000001T0?ooo`X00?l0I@3oool006H0oooo0`00o`090?ooo`@0
0?l0?@3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00X0oooo00<0_g@007Boo`3o
ool01P3oool00`3o_g@0000007Boo`080?ooo`030000003oool0oooo06<0oooo0P00o`0:0?ooo`80
0?l0H`3oool006D0oooo00<00?l00?ooo`3oool03P3oool2003o03/0oooo00<0omnL04P00018W=l0
0`3oool00`2oM00004RL0=ooo`090?ooo`030?oOW018B9`0gooo00<0oooo00H0omoO0=ooo`3o_g@0
00000000M02oool80?ooo`030000003oool0oooo0640oooo0P00o`0>0?ooo`800?l0H@3oool006<0
oooo0P00o`0C0?ooo`800?l0>@3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo
00X0oooo00<0gia804RLg`3oool00P3oool01@3ookl0M0000000000004P0W=oo00T0oooo00<00000
0?ooo`3oool0G`3oool2003o0180oooo0P00o`1O0?ooo`00HP3oool00`00o`00oooo0?ooo`0E0?oo
o`03003o003oool0oooo03L0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`050?oo
o`030?oog`3Ogol0oooo0080oooo00<0oono07@0M02oool00`3oool00`3OW9`0_ooo0?ooo`0:0?oo
o`030000003oool0oooo05d0oooo0P00o`0F0?ooo`03003o003oool0oooo05`0oooo001Q0?ooo`03
003o003oool0oooo01L0oooo0P00o`0h0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO1`3oool0
0`2oM7@0_ooo0?ooo`020?ooo`030?noM000M;l0oooo0080oooo00<0omnL07BLg`3oool02P3oool0
0`000000oooo0?ooo`1K0?ooo`800?l06@3oool00`00o`00oooo0?ooo`1K0?ooo`00H03oool00`00
o`00oooo0?ooo`0J0?ooo`03003o003oool0oooo03H0oooo00@0gia800000000000007Bo203oool0
0`3ookl0M00000000003000000030000B02Lgol0oooo0080oooo00D0_g@0000000000000000004RL
g`070?ooo`<00000F@3oool2003o01`0oooo00<00?l00?ooo`3oool0FP3oool005l0oooo00<00?l0
0?ooo`3oool0703oool00`00o`00oooo0?ooo`1H0?ooo`030000003oool0oooo05P0oooo00<00?l0
0?ooo`3oool07@3oool00`00o`00oooo0?ooo`1I0?ooo`00GP3oool00`00o`00oooo0?ooo`0N0?oo
o`03003o003oool0oooo05L0oooo00<000000?ooo`3oool0E`3oool00`00o`00oooo0?ooo`0O0?oo
o`03003o003oool0oooo05P0oooo001M0?ooo`03003o003oool0oooo0200oooo00<00?l00?ooo`3o
ool0EP3oool00`000000oooo0?ooo`1F0?ooo`03003o003oool0oooo0240oooo00<00?l00?ooo`3o
ool0E`3oool005`0oooo00<00?l00?ooo`3oool08P3oool2003o05H0oooo00<000000?ooo`3oool0
E@3oool00`00o`00oooo0?ooo`0R0?ooo`03003o003oool0oooo05L0oooo001L0?ooo`03003o003o
ool0oooo02@0oooo00<00?l00?ooo`3oool0D`3oool00`000000oooo0?ooo`1D0?ooo`03003o003o
ool0oooo02@0oooo00<00?l00?ooo`3oool0EP3oool005/0oooo00<00?l00?ooo`3oool09P3oool0
0`00o`00oooo0?ooo`1B0?ooo`<00000D`3oool00`00o`00oooo0?ooo`0V0?ooo`03003o003oool0
oooo05D0oooo001J0?ooo`03003o003oool0oooo02P0oooo00<00?l00?ooo`3oool0D@3oool00`00
0000oooo0?ooo`1B0?ooo`03003o003oool0oooo02P0oooo00<00?l00?ooo`3oool0E03oool005X0
oooo00<00?l00?ooo`3oool0:@3oool00`00o`00oooo0?ooo`1@0?ooo`030000003oool0oooo0540
oooo00<00?l00?ooo`3oool0:@3oool00`00o`00oooo0?ooo`1D0?ooo`00F@3oool00`00o`00oooo
0?ooo`0[0?ooo`03003o003oool0oooo04l0oooo00<000000?ooo`3oool0D03oool00`00o`00oooo
0?ooo`0[0?ooo`03003o003oool0oooo05<0oooo001I0?ooo`03003o003oool0oooo02`0oooo00<0
0?l00?ooo`3oool0CP3oool00`000000oooo0?ooo`1@0?ooo`03003o003oool0oooo02/0oooo00<0
0?l00?ooo`3oool0D`3oool005P0oooo00<00?l00?ooo`3oool0;@3oool00`00o`00oooo0?ooo`1>
0?ooo`030000003oool0oooo04l0oooo00<00?l00?ooo`3oool0;@3oool00`00o`00oooo0?ooo`1B
0?ooo`00F03oool00`00o`00oooo0?ooo`0^0?ooo`03003o003oool0oooo04d0oooo0`00001>0?oo
o`03003o003oool0oooo02h0oooo00<00?l00?ooo`3oool0DP3oool005L0oooo00<00?l00?ooo`3o
ool0<03oool00`00o`00oooo0?ooo`1<0?ooo`030000003oool0oooo04d0oooo00<00?l00?ooo`3o
ool0<03oool00`00o`00oooo0?ooo`1A0?ooo`00E`3oool00`00o`00oooo0?ooo`0a0?ooo`03003o
003oool0oooo04/0oooo00<000000?ooo`3oool0C03oool00`00o`00oooo0?ooo`0a0?ooo`03003o
003oool0oooo0540oooo001F0?ooo`03003o003oool0oooo03<0oooo00<00?l00?ooo`3oool0BP3o
ool00`000000oooo0?ooo`1;0?ooo`03003o003oool0oooo03<0oooo00<00?l00?ooo`3oool0D03o
ool005H0oooo00<00?l00?ooo`3oool0=03oool00`00o`00oooo0?ooo`190?ooo`030000003oool0
oooo04X0oooo00<00?l00?ooo`3oool0=03oool00`00o`00oooo0?ooo`1@0?ooo`00E@3oool00`00
o`00oooo0?ooo`0f0?ooo`03003o003oool0oooo04P0oooo00<000000?ooo`3oool0BP3oool00`00
o`00oooo0?ooo`0d0?ooo`03003o003oool0oooo0500oooo001E0?ooo`03003o003oool0oooo03H0
oooo00<00?l00?ooo`3oool0B03oool3000004T0oooo00<00?l00?ooo`3oool0=P3oool00`00o`00
oooo0?ooo`1?0?ooo`00E03oool00`00o`00oooo0?ooo`0h0?ooo`03003o003oool0oooo02/0oooo
00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`060?oOW018000000000000
0000B9`0gooo2P3oool00`000000oooo0?ooo`180?ooo`03003o003oool0oooo03L0oooo00<00?l0
0?ooo`3oool0C`3oool005@0oooo00<00?l00?ooo`3oool0>@3oool00`00o`00oooo0?ooo`0Y0?oo
o`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`020?ooo`060?noM000
0000M;oo0?ooo`3ogi`0B7Bo2P3oool00`000000oooo0?ooo`170?ooo`03003o003oool0oooo03T0
oooo00<00?l00?ooo`3oool0CP3oool005<0oooo00<00?l00?ooo`3oool0>`3oool00`00o`00oooo
0?ooo`0W0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol02`3oool00`3o_g@0B9cO
0?ooo`080?ooo`030000003oool0oooo04H0oooo00<00?l00?ooo`3oool0>P3oool00`00o`00oooo
0?ooo`1>0?ooo`00D`3oool00`00o`00oooo0?ooo`0l0?ooo`03003o003oool0oooo02H0oooo00<0
oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool:0?ooo`030?oo_`1d07@0_ooo00P0oooo
00<000000?ooo`3oool0A@3oool00`00o`00oooo0?ooo`0k0?ooo`03003o003oool0oooo04h0oooo
001B0?ooo`03003o003oool0oooo03d0oooo00<00?l00?ooo`3oool06@3oool00`3ooml0W4P00000
00070000000604RLg`3oool0oooo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`0:0?ooo`03
0?oog`2LB000M;oo00P0oooo00<000000?ooo`3oool0A@3oool00`00o`00oooo0?ooo`0l0?ooo`03
003o003oool0oooo04d0oooo001B0?ooo`03003o003oool0oooo03h0oooo00<00?l00?ooo`3oool0
9P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00X0oooo00<0oono07@00018W=l0
203oool4000004<0oooo00<00?l00?ooo`3oool0?@3oool00`00o`00oooo0?ooo`1=0?ooo`00D@3o
ool00`00o`00oooo0?ooo`100?ooo`03003o003oool0oooo02D0oooo00<0gia80000B02Lgol00P3o
ool00`3ooml0W4P0001d_`0:0?ooo`030?noM0000000M;oo00P0oooo00<000000?ooo`3oool0@`3o
ool00`00o`00oooo0?ooo`0o0?ooo`03003o003oool0oooo04`0oooo001A0?ooo`03003o003oool0
oooo0440oooo00<00?l00?ooo`3oool0903oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0
gooo00H0oooo00H0omoO0=ooo`3o_g@000000000M02oool80?ooo`030000003oool0oooo0480oooo
00<00?l00?ooo`3oool0@03oool00`00o`00oooo0?ooo`1<0?ooo`00D@3oool00`00o`00oooo0?oo
o`120?ooo`03003o003oool0oooo02<0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL
0=ooo`060?ooo`050?oo_`1d000000000000B02Lgol02@3oool00`000000oooo0?ooo`110?ooo`03
003o003oool0oooo0440oooo00<00?l00?ooo`3oool0C03oool00500oooo00<00?l00?ooo`3oool0
@`3oool00`00o`00oooo0?ooo`0T0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0
1`3oool00`3OW9`0_ooo0?ooo`0:0?ooo`030000003oool0oooo0400oooo00<00?l00?ooo`3oool0
@`3oool00`00o`00oooo0?ooo`1;0?ooo`00D03oool00`00o`00oooo0?ooo`140?ooo`03003o003o
ool0oooo02@0oooo00H0gia80000M02oool0oooO09a80018W=l80?ooo`030?oOW01dW=l0oooo00X0
oooo00<000000?ooo`3oool0@03oool00`00o`00oooo0?ooo`130?ooo`03003o003oool0oooo04/0
oooo001@0?ooo`03003o003oool0oooo04D0oooo00<00?l00?ooo`3oool0903oool0103OW4P00000
00000000M;l:0?ooo`050;md00000000000000000018W=l01`3oool3000003l0oooo00<00?l00?oo
o`3oool0A@3oool00`00o`00oooo0?ooo`1:0?ooo`00C`3oool00`00o`00oooo0?ooo`170?ooo`03
003o003oool0oooo03d0oooo00<000000?ooo`3oool0?P3oool00`00o`00oooo0?ooo`160?ooo`03
003o003oool0oooo04X0oooo001?0?ooo`03003o003oool0oooo04P0oooo00<00?l00?ooo`3oool0
?03oool00`000000oooo0?ooo`0m0?ooo`03003o003oool0oooo04L0oooo00<00?l00?ooo`3oool0
BP3oool004h0oooo00<00?l00?ooo`3oool0B@3oool00`00o`00oooo0?ooo`0l0?ooo`030000003o
ool0oooo03`0oooo00<00?l00?ooo`3oool0B@3oool00`00o`00oooo0?ooo`190?ooo`00CP3oool0
0`00o`00oooo0?ooo`1:0?ooo`03003o003oool0oooo03/0oooo00<000000?ooo`3oool0?03oool0
0`00o`00oooo0?ooo`190?ooo`03003o003oool0oooo04T0oooo001>0?ooo`03003o003oool0oooo
04/0oooo00<00?l00?ooo`3oool0>P3oool00`000000oooo0?ooo`0k0?ooo`03003o003oool0oooo
04X0oooo00<00?l00?ooo`3oool0B@3oool004d0oooo00<00?l00?ooo`3oool0C@3oool00`00o`00
oooo0?ooo`0i0?ooo`<00000>P3oool00`00o`00oooo0?ooo`1<0?ooo`03003o003oool0oooo04P0
oooo001=0?ooo`03003o003oool0oooo04h0oooo00<00?l00?ooo`3oool0>03oool00`000000oooo
0?ooo`0i0?ooo`03003o003oool0oooo04d0oooo00<00?l00?ooo`3oool0B03oool004d0oooo00<0
0?l00?ooo`3oool0CP3oool00`00o`00oooo0?ooo`0h0?ooo`030000003oool0oooo03P0oooo00<0
0?l00?ooo`3oool0C`3oool00`00o`00oooo0?ooo`170?ooo`00C03oool00`00o`00oooo0?ooo`0k
0?ooo`L0o`003P3oool00`00o`00oooo0?ooo`0g0?ooo`030000003oool0oooo03P0oooo00<00?l0
0?ooo`3oool02`3oool80?l003`0oooo00<00?l00?ooo`3oool0A`3oool004`0oooo00<00?l00?oo
o`3oool0>@3oool20?l000L0oooo0`3o000<0?ooo`03003o003oool0oooo03H0oooo00<000000?oo
o`3oool0=`3oool00`00o`00oooo0?ooo`090?ooo`<0o`00203oool30?l003T0oooo00<00?l00?oo
o`3oool0A`3oool004`0oooo00<00?l00?ooo`3oool0>03oool00`3o0000oooo0?ooo`0:0?ooo`80
o`002`3oool00`00o`00oooo0?ooo`0e0?ooo`030000003oool0oooo03H0oooo00<00?l00?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`0<0?ooo`80o`00>03oool00`00o`00oooo0?ooo`160?ooo`00
C03oool00`00o`00oooo0?ooo`0f0?ooo`80o`003`3oool20?l000X0oooo00<00?l00?ooo`3oool0
=03oool3000003D0oooo00<00?l00?ooo`3oool0203oool20?l00140oooo00<0o`000?ooo`3oool0
=@3oool00`00o`00oooo0?ooo`160?ooo`00B`3oool00`00o`00oooo0?ooo`0e0?ooo`80o`004`3o
ool20?l000P0oooo00<00?l00?ooo`3oool0=03oool00`000000oooo0?ooo`0d0?ooo`03003o003o
ool0oooo00L0oooo0P3o000D0?ooo`030?l0003oool0oooo03D0oooo00<00?l00?ooo`3oool0A@3o
ool004/0oooo00<00?l00?ooo`3oool0<`3oool20?l001L0oooo0P3o00070?ooo`03003o003oool0
oooo03<0oooo00<000000?ooo`3oool0=03oool00`00o`00oooo0?ooo`050?ooo`80o`005`3oool2
0?l003D0oooo00<00?l00?ooo`3oool0A@3oool004/0oooo00<00?l00?ooo`3oool0<P3oool00`3o
0000oooo0?ooo`0I0?ooo`80o`001P3oool00`00o`00oooo0?ooo`0b0?ooo`030000003oool0oooo
03<0oooo00<00?l00?ooo`3oool0103oool20?l001/0oooo00<0o`000?ooo`3oool0<P3oool00`00
o`00oooo0?ooo`150?ooo`00B`3oool00`00o`00oooo0?ooo`0b0?ooo`030?l0003oool0oooo01/0
oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`0a0?ooo`030000003oool0oooo0380
oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo0380
oooo00<00?l00?ooo`3oool0A@3oool004X0oooo00<00?l00?ooo`3oool0<P3oool00`3o0000oooo
0?ooo`0M0?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3oool0<03oool00`000000oooo
0?ooo`0a0?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo
0?ooo`0b0?ooo`03003o003oool0oooo04@0oooo001:0?ooo`03003o003oool0oooo0340oooo00<0
o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo0300oooo0`00
000`0?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?oo
o`0a0?ooo`03003o003oool0oooo04@0oooo001:0?ooo`03003o003oool0oooo0300oooo00<0o`00
0?ooo`3oool08@3oool20?l000@0oooo00<00?l00?ooo`3oool02P3oool0102oM00000000000001d
_ol30?ooo`030?oOW0180000M;oo0080oooo00<0gia80000000000000`0000001@18W=l0oooo0?oo
o`3ogi`0B0000080000000<004RL0=ooo`3oool02@3oool00`000000oooo0?ooo`0`0?ooo`03003o
003oool0oooo00<0oooo00<0o`000?ooo`3oool08@3oool00`3o0000oooo0?ooo`0`0?ooo`03003o
003oool0oooo04@0oooo001:0?ooo`03003o003oool0oooo02l0oooo00<0o`000?ooo`3oool0903o
ool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo00P0oooo00H0gia8001d_`3oool0omnL
04P00018W=l20?ooo`030?oOW0180000M;oo00<0oooo00<0okmd001d_`3oool00P3oool02@2oM7@0
_ooo0?ooo`3o_g@0000007Boo`3oool0omnL04Qd_`0:0?ooo`030000003oool0oooo02l0oooo00<0
0?l00?ooo`3oool00`3oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo0300oooo00<0
0?l00?ooo`3oool0A03oool004T0oooo00<00?l00?ooo`3oool0;`3oool00`3o0000oooo0?ooo`0V
0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool01P3oool00`3ooml0W4P004RLg`02
0?ooo`030?noM00004P0W=oo00P0oooo00<0okmd001d_`3oool02@3oool00`3o_g@0B9cO0?ooo`08
0?ooo`030000003oool0oooo02h0oooo00<00?l00?ooo`3oool00P3oool20?l002H0oooo00<0o`00
0?ooo`3oool0<03oool00`00o`00oooo0?ooo`130?ooo`00B@3oool00`00o`00oooo0?ooo`0_0?oo
o`030?l0003oool0oooo02L0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`050?oo
o`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo203oool00`3o_g@007Bo0?ooo`08
0?ooo`030?oo_`1d07@0_ooo00P0oooo00<000000?ooo`3oool0;@3oool00`00o`00oooo0?ooo`02
0?ooo`030?l0003oool0oooo02L0oooo00<0o`000?ooo`3oool0;`3oool00`00o`00oooo0?ooo`13
0?ooo`00B@3oool00`00o`00oooo0?ooo`0^0?ooo`030?l0003oool0oooo02P0oooo00<0oooO0?l0
000000000P0000000`00o`000000000000020000000604RLg`3oool0oooo0?oog`2LB00007Bo0`3o
ool00`3OW4P0001809cOo`090?ooo`030?noM018W=l0oooo00L0oooo00<0oooO09a8001d_ol0203o
ool00`000000oooo0?ooo`0/0?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool0:03o
ool00`3o0000oooo0?ooo`0_0?ooo`03003o003oool0oooo04<0oooo00190?ooo`03003o003oool0
oooo02d0oooo00<0o`000?ooo`3oool07@3oool60000o`P0oooo00D0o`000?ooo`3oool0oooo003o
00070?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l02P3oool00`3OW4P0B9cO0?oo
o`060?ooo`030?oo_`1d0000B9cO00P0oooo1000000Z0?ooo`04003o003oool0oooo0?ooo`80o`00
203oool60000oah0oooo00<0o`000?ooo`3oool0;P3oool00`00o`00oooo0?ooo`130?ooo`00B03o
ool00`00o`00oooo0?ooo`0^0?ooo`030?l0003oool0oooo01X0oooo0`000?l60?ooo`<0003o1P3o
ool01@3o0000oooo0?ooo`3oool00?l000H0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0
001d_`0;0?ooo`030;md001d_ol0oooo00D0oooo00<0okmd0000001d_ol0203oool00`000000oooo
0?ooo`0Z0?ooo`05003o003oool0oooo0?ooo`3o00001`3oool40000o`D0oooo0P000?lL0?ooo`03
0?l0003oool0oooo02l0oooo00<00?l00?ooo`3oool0@P3oool004P0oooo00<00?l00?ooo`3oool0
;@3oool00`3o0000oooo0?ooo`0I0?ooo`80003o303oool20000o`D0oooo0P3o00020?ooo`03003o
003oool0oooo00<0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`0:0?ooo`030?oO
W01807@0_ooo0080oooo00H0omoO0=ooo`3o_g@000000000M02oool80?ooo`030000003oool0oooo
02X0oooo00@00?l00?ooo`3oool0o`001P3oool20000o`/0oooo10000?lI0?ooo`030?l0003oool0
oooo02h0oooo00<00?l00?ooo`3oool0@P3oool004P0oooo00<00?l00?ooo`3oool0;@3oool00`3o
0000oooo0?ooo`0G0?ooo`80003o403oool20000o`D0oooo00@0o`000?ooo`3oool00?l0103oool0
103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00X0oooo00<0oooO09a8001d_ol00P3o
ool01@3ookl0M0000000000004P0W=oo00T0oooo00<000000?ooo`3oool0:@3oool01000o`00oooo
0?ooo`3o00050?ooo`80003o4@3oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo02h0
oooo00<00?l00?ooo`3oool0@P3oool004P0oooo00<00?l00?ooo`3oool0;03oool00`3o0000oooo
0?ooo`0G0?ooo`030000o`3oool0oooo0180oooo0P000?l40?ooo`040?l0003oool0oooo003o00@0
oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`0:0?ooo`030?oo_`1d0000B9cO00<0
oooo00<0gibL0;ooo`3oool02P3oool00`000000oooo0?ooo`0X0?ooo`04003o003oool0oooo0?l0
00@0oooo0P000?lD0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool0;@3oool00`00
o`00oooo0?ooo`120?ooo`00A`3oool00`00o`00oooo0?ooo`0]0?ooo`030?l0003oool0oooo01H0
oooo00<0003o0?ooo`3oool05@3oool20000o`<0oooo00@0o`000?ooo`3oool00?l0103oool01P3O
W4P0001d0;ooo`3ooml0W4P004RLg`L0oooo00L0okmd0018W03Oool0oooo0=nLB00004P0W=oo00<0
oooo00<0omnL07BLg`3oool02P3oool00`000000oooo0?ooo`0W0?ooo`04003o003oool0o`000?l0
00<0oooo0P000?lF0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool0;P3oool00`00
o`00oooo0?ooo`110?ooo`00A`3oool00`00o`00oooo0?ooo`0]0?ooo`030?l0003oool0oooo01D0
oooo00<0003o0?ooo`3oool0603oool20000o`80oooo00<0o`000?ooo`00o`001@3oool0103OW4P0
000000000000M;l90?ooo`050?oOW018000000000000001d_ol01@3oool01@2oM000000000000000
0000B9cO00L0oooo0`00000V0?ooo`03003o003oool0o`0000<0oooo0P000?lI0?ooo`030000o`3o
ool0oooo01H0oooo00<0o`000?ooo`3oool0;@3oool00`00o`00oooo0?ooo`110?ooo`00A`3oool0
0`00o`00oooo0?ooo`0/0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool06`3oool2
0000o`040?ooo`3o0000oooo003o02L0oooo00<000000?ooo`3oool09@3oool00`00o`00oooo0?l0
00020?ooo`80003o703oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo02d0oooo00<0
0?l00?ooo`3oool0@@3oool004L0oooo00<00?l00?ooo`3oool0;03oool00`3o0000oooo0?ooo`0E
0?ooo`030000o`3oool0oooo01d0oooo00D0003o0?ooo`3o0000oooo003o000V0?ooo`030000003o
ool0oooo02@0oooo00<00?l00?ooo`3o00000P3oool00`000?l0oooo0?ooo`0M0?ooo`030000o`3o
ool0oooo01D0oooo00<0o`000?ooo`3oool0;03oool00`00o`00oooo0?ooo`110?ooo`008@3oool0
0`3ookl0M000000000020000000307Boo`3oool0oooo01d0oooo00<00?l00?ooo`3oool05P3oool0
0`3OW4P00000000000030000000304RLg`3oool0oooo00h0oooo00<0o`000?ooo`3oool0503oool0
0`000?l0oooo0?ooo`0=0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool02P3oool0
1@000?l0oooo0?l0003oool00?l002D0oooo00<000000?ooo`3oool08`3oool01000o`00oooo0?l0
003oool20000o`h0oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`0;0?ooo`030000
o`3oool0oooo01@0oooo00<0o`000?ooo`3oool04@3oool00`3OW4P00000000000030000000304RL
g`3oool0oooo01<0oooo00<00?l00?ooo`3oool0803oool00`3ookl0M000000000020000000307Bo
o`3oool0oooo01P0oooo000Q0?ooo`030?noM000000007Bo0080oooo00<0_gA809cOo`3oool07@3o
ool00`00o`00oooo0?ooo`0G0?ooo`030?noM000M;l0oooo0080oooo00<0_gAd0;ooo`3oool03@3o
ool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo0100oooo00<0okmd0000001d_ol03P3o
ool20000o`030?l0003oool00?l002@0oooo00<000000?ooo`3oool08P3oool01@00o`00oooo0?l0
003oool0003o0180oooo00<0okmd0000001d_ol03`3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0
003oool0oooo0140oooo00<0okmd001d_`3oool00P3oool00`2oM7@0_ooo0?ooo`0C0?ooo`03003o
003oool0oooo0200oooo00<0okmd00000000M;l00P3oool00`2oM4P0W=oo0?ooo`0H0?ooo`009P3o
ool00`3ogi`0B4RL0=ooo`0M0?ooo`03003o003oool0oooo01P0oooo00<0okmd001d_`3oool04@3o
ool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo0140oooo00<0oooO09a80000M;l0403o
ool010000?l0o`000?ooo`00o`0S0?ooo`030000003oool0oooo0280oooo00@00?l00?l0003oool0
003o4`3oool00`3ooml0W4P0001d_`0@0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3o
ool04P3oool00`3o_g@007Bo0?ooo`0G0?ooo`03003o003oool0oooo02D0oooo00<0omnL04Q8W03O
ool0603oool002H0oooo00<0oono07@0001d_ol07@3oool00`00o`00oooo0?ooo`0I0?ooo`030?no
M000M;l0oooo00l0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0B0?ooo`030=nL
B000B9`0gooo0100oooo00@0003o0?l0003oool00?l08P3oool300000240oooo0P3o00020000oaD0
oooo00<0gia80018W03Oool03`3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0180
oooo00<0okmd001d_`3oool05P3oool00`00o`00oooo0?ooo`0U0?ooo`030?oo_`1d0000M;oo01P0
oooo000D0?ooo`030?oog`2LB000000000L0000000<0B9cO0?ooo`3oool01@3oool00`3ogi`0B000
07Boo`0L0?ooo`03003o003oool0oooo00X0oooo00<0oooO09a8000000001`0000000`18W=l0oooo
0?ooo`040?ooo`030?noM018W=l0oooo00h0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo
0?ooo`030?ooo`030?oog`2LB000000000L0000000<0B9cO0?ooo`3oool00`3oool00`3ogi`0B018
09cOo`0A0?ooo`80003o00<0oooo003o003oool0803oool00`000000oooo0?ooo`0P0?ooo`030?l0
003oool0003o01L0oooo00<0omnL04P0B02Lgol0403oool00`000?l0oooo0?ooo`0C0?ooo`030?l0
003oool0oooo01<0oooo00<0okmd04RLg`3oool05P3oool00`00o`00oooo0?ooo`0T0?ooo`030?oO
W0180000M;oo01P0oooo000U0?ooo`040?oOW0180000001809cOoa`0oooo00<00?l00?ooo`3oool0
703oool00`3OW4P0B9cO0?ooo`0=0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0
503oool00`3ookl0M00007Boo`0C0?ooo`040000o`3oool00?l0003o01l0oooo00<000000?ooo`3o
ool07`3oool00`3o0000003o0000o`0H0?ooo`030?oo_`1d0000M;oo0100oooo00<0003o0?ooo`3o
ool04`3oool00`3o0000oooo0?ooo`0D0?ooo`030=nLB018W=l0oooo01D0oooo00<00?l00?ooo`3o
ool08`3oool0103ogi`0B0000000B02LgolH0?ooo`008`3oool01@3ogi`0B000000000000000M;oo
01d0oooo00<00?l00?ooo`3oool07@3oool00`2oM000M;oo0?ooo`0;0?ooo`030?l0003oool0oooo
01<0oooo00<0003o0?ooo`3oool05@3oool00`2oM00007Bo0?ooo`0C0?ooo`040000o`3o0000oooo
003o01h0oooo00<000000?ooo`3oool07P3oool00`3o0000003o0?ooo`0J0?ooo`030;md0000M;l0
oooo0100oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0D0?ooo`030;md001d_ol0
oooo01@0oooo00<00?l00?ooo`3oool08@3oool01@3ogi`0B000000000000000M;oo01T0oooo000U
0?ooo`030?oo_`1d000007Bo01d0oooo00<00?l00?ooo`3oool07@3oool00`3ogi`0B01d0;ooo`0;
0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool05P3oool00`3OW4P004RL0=ooo`0D
0?ooo`80003o00<0oooo003o003oool0703oool00`000000oooo0?ooo`0M0?ooo`80003o703oool0
0`3OW4P004RL0=ooo`0@0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0503oool0
0`3ogi`0B01d0;ooo`0D0?ooo`03003o003oool0oooo02<0oooo00<0oono07@00000M;l06@3oool0
02L0oooo00<0gia8001d_`3oool06P3oool00`00o`00oooo0?ooo`0N0?ooo`030?oog`2LB000M;oo
00X0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0G0?ooo`030?oOW01804P0W=oo
01H0oooo00<0003o0?ooo`00o`00703oool00`000000oooo0?ooo`0K0?ooo`03003o00000?l0oooo
01d0oooo00<0omnL04P0B02Lgol04@3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo
01<0oooo00<0oooO09a8001d_ol05@3oool00`00o`00oooo0?ooo`0T0?ooo`030=nLB000M;l0oooo
01L0oooo000W0?ooo`030?oOW01804P0W=oo01X0oooo00<00?l00?ooo`3oool07P3oool00`3ookl0
M00004RLg`0:0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool05`3oool00`3ookl0
M00007Boo`0G0?ooo`80003o00<00?l00?ooo`3oool06@3oool3000001X0oooo0P000?lO0?ooo`03
0?oo_`1d0000M;oo0140oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0C0?ooo`03
0?oo_`1d0000B9cO01D0oooo00<00?l00?ooo`3oool0903oool00`3ogi`0B01809cOo`0G0?ooo`00
903oool01P2oM000M;oo0?ooo`3OW4P0001809cOoaX0oooo00<00?l00?ooo`3oool06P3oool01`3o
_g@004RL0=ooo`3oool0gia80000B02Lgol02P3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo01T0oooo00<0_g@0001d_`3oool0603oool00`000?l00?l00?ooo`0I0?ooo`030000003o
ool0oooo01T0oooo00<0003o0?ooo`3oool0803oool00`2oM00007Bo0?ooo`0A0?ooo`030000o`3o
ool0oooo0180oooo00<0o`000?ooo`3oool03`3oool01`3o_g@004RL0=ooo`3oool0gia80000B02L
gol05@3oool00`00o`00oooo0?ooo`0Q0?ooo`060;md001d_ol0oooo0=nLB00004P0W=oo5`3oool0
02D0oooo00@0_g@0000000000000B9cO6`3oool00`00o`00oooo0?ooo`0K0?ooo`050?oOW0180000
00000000001d_ol02P3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo01L0oooo00D0
oono07@000000000001d0;ooo`0I0?ooo`80003o00<00?l00?ooo`3oool05P3oool00`000000oooo
0?ooo`0G0?ooo`03003o00000?l0oooo0200oooo00D0oono07@000000000001d0;ooo`0A0?ooo`03
0000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool03`3oool01@3ogi`0B000000000000000M;oo
01H0oooo00<00?l00?ooo`3oool08P3oool0102oM000000000000018W=lH0?ooo`00@`3oool00`00
o`00oooo0?ooo`0[0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0>03oool20000
oaL0oooo00<000000?ooo`3oool05P3oool20000ocT0oooo00<0003o0?ooo`3oool04P3oool00`3o
0000oooo0?ooo`0Z0?ooo`03003o003oool0oooo03h0oooo00130?ooo`03003o003oool0oooo02/0
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0i0?ooo`030?l000000?l0oooo01D0
oooo00<000000?ooo`3oool05@3oool00`000?l0o`000?ooo`0i0?ooo`030000o`3oool0oooo0180
oooo00<0o`000?ooo`3oool0:`3oool00`00o`00oooo0?ooo`0m0?ooo`00@`3oool00`00o`00oooo
0?ooo`0Z0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0?03oool00`000?l0o`00
0?ooo`0C0?ooo`030000003oool0oooo01<0oooo0P000?lm0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool0:`3oool00`00o`00oooo0?ooo`0m0?ooo`00@`3oool00`00o`00oooo0?oo
o`0Z0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0?@3oool20000oa<0oooo00<0
00000?ooo`3oool04@3oool00`00o`00003o0?l0000n0?ooo`030000o`3oool0oooo0180oooo00<0
o`000?ooo`3oool0:P3oool00`00o`00oooo0?ooo`0m0?ooo`00@P3oool00`00o`00oooo0?ooo`0Z
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0@03oool00`000?l0o`000?ooo`0@
0?ooo`<000003`3oool01000o`00003o0000o`3o00100?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool0:P3oool00`00o`00oooo0?ooo`0m0?ooo`00@P3oool00`00o`00oooo0?ooo`0Z
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0@@3oool20000o`030?l0003oool0
oooo00d0oooo00<000000?ooo`3oool03P3oool20000o`030?l0003oool0oooo0400oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0Z0?ooo`03003o003oool0oooo03d0oooo00120?oo
o`03003o003oool0oooo02X0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`140?oo
o`<0003o3@3oool00`000000oooo0?ooo`0<0?ooo`80003o00<0o`000?ooo`3oool0@`3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo02X0oooo00<00?l00?ooo`3oool0?03oool00480
oooo00<00?l00?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo04L0
oooo0`000?l:0?ooo`030000003oool0oooo00T0oooo0`000?l00`3o0000oooo0?ooo`150?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0:P3oool00`00o`00oooo0?ooo`0l0?ooo`00
@@3oool00`00o`00oooo0?ooo`0Z0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
B@3oool0103o0000003o0000o`00o`070?ooo`030000003oool0oooo00H0oooo00@00?l00000o`00
0?l0o`00BP3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo02X0oooo00<00?l00?oo
o`3oool0?03oool00440oooo00<00?l00?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo04d0oooo1`000?l0103oool000000?ooo`3oool70000odh0oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0Y0?ooo`03003o003oool0oooo03`0oooo000E0?ooob`0
000000<00?l0000000000000:@0000000`3o000000000000000A000000030000o`000000000005@0
000010000?mE000000030000o`00000000000140000000<0o`00000000000000:@0000000`00o`00
00000000000Z00000180oooo000O0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`060?ooo`04003o003oool0oooo000000/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`3o0000203oool00`00
0000oooo0?ooo`070?ooo`030000o`3oool0000000`0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0000o`0:0?ooo`030000003oool0oooo00D0oooo00D0o`000?ooo`3oool0oooo0000000<
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00
o`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0I0?ooo`007`3oool00`000000oooo0?ooo`0N0?ooo`03003o003oool0oooo01X0oooo00<00000
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo01P0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01L0oooo00<0003o
0?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`030000003oool0oooo01T0oooo00<00?l0
0?ooo`3oool07`3oool00`000000oooo0?ooo`0I0?ooo`00@03oool00`00o`00oooo0?ooo`0Z0?oo
o`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0EP3oool00`000000oooo0?ooo`1F0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0:@3oool00`00o`00oooo0?ooo`0k0?oo
o`00@03oool00`00o`00oooo0?ooo`0Y0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool0E`3oool00`000000oooo0?ooo`1G0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3o
ool0:@3oool00`00o`00oooo0?ooo`0k0?ooo`00@03oool00`00o`00oooo0?ooo`0Y0?ooo`030?l0
003oool0oooo0100oooo00<0003o0?ooo`3oool0E`3oool00`000000oooo0?ooo`1G0?ooo`030000
o`3oool0oooo0100oooo00<0o`000?ooo`3oool0:@3oool00`00o`00oooo0?ooo`0k0?ooo`00?`3o
ool00`00o`00oooo0?ooo`0Z0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0E`3o
ool3000005L0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0Y0?ooo`03003o003o
ool0oooo03X0oooo000o0?ooo`03003o003oool0oooo02X0oooo00<0o`000?ooo`3oool0403oool0
0`000?l0oooo0?ooo`1G0?ooo`030000003oool0oooo05P0oooo00<0003o0?ooo`3oool0403oool0
0`3o0000oooo0?ooo`0Y0?ooo`03003o003oool0oooo03X0oooo000o0?ooo`03003o003oool0oooo
02T0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1H0?ooo`030000003oool0oooo
05P0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0Y0?ooo`03003o003oool0oooo
03X0oooo000o0?ooo`03003o003oool0oooo02T0oooo00<0o`000?ooo`3oool0403oool00`000?l0
oooo0?ooo`1H0?ooo`030000003oool0oooo05P0oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0X0?ooo`03003o003oool0oooo03X0oooo000n0?ooo`03003o003oool0oooo02X0oooo
00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1H0?ooo`030000003oool0oooo05T0oooo
00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo03X0oooo
000n0?ooo`03003o003oool0oooo02X0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?oo
o`1H0?ooo`030000003oool0oooo05T0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0X0?ooo`03003o003oool0oooo03X0oooo000n0?ooo`03003o003oool0oooo02T0oooo00<0o`00
0?ooo`3oool0403oool00`000?l0oooo0?ooo`1I0?ooo`<00000F@3oool00`000?l0oooo0?ooo`0@
0?ooo`030?l0003oool0oooo02T0oooo00<00?l00?ooo`3oool0>@3oool003h0oooo00<00?l00?oo
o`3oool0:@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo05T0oooo00<000000?oo
o`3oool0F@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?oo
o`3oool0>@3oool003h0oooo00<00?l00?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo05T0oooo00<000000?ooo`3oool0FP3oool00`000?l0oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo02P0oooo00<00?l00?ooo`3oool0>@3oool003d0oooo00<00?l00?ooo`3oool0
:@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo05T0oooo00<000000?ooo`3oool0
FP3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?ooo`3oool0
>@3oool003d0oooo00<00?l00?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo05X0oooo00<000000?ooo`3oool0FP3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo02P0oooo00<00?l00?ooo`3oool0>@3oool003d0oooo00<00?l00?ooo`3oool0:@3oool0
0`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo05X0oooo00<000000?ooo`3oool0F`3oool0
0`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?ooo`3oool0>03oool0
03d0oooo00<00?l00?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo
05X0oooo0`00001K0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0:03oool00`00
o`00oooo0?ooo`0h0?ooo`00?@3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool0FP3oool00`000000oooo0?ooo`1K0?ooo`030000o`3oool0oooo0100
oooo00<0o`000?ooo`3oool0:03oool00`00o`00oooo0?ooo`0h0?ooo`00?@3oool00`00o`00oooo
0?ooo`0X0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo
0?ooo`1K0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0:03oool00`00o`00oooo
0?ooo`0h0?ooo`00?03oool00`00o`00oooo0?ooo`0Y0?ooo`030?l0003oool0oooo0100oooo00<0
003o0?ooo`3oool0F`3oool00`000000oooo0?ooo`1L0?ooo`030000o`3oool0oooo0100oooo00<0
o`000?ooo`3oool09`3oool00`00o`00oooo0?ooo`0h0?ooo`00?03oool00`00o`00oooo0?ooo`0Y
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo0?ooo`1L
0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0:03oool00`00o`00oooo0?ooo`0g
0?ooo`00?03oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool0F`3oool00`000000oooo0?ooo`1L0?ooo`030000o`3oool0oooo0100oooo00<0o`000?oo
o`3oool0:03oool00`00o`00oooo0?ooo`0g0?ooo`00?03oool00`00o`00oooo0?ooo`0X0?ooo`03
0?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0G03oool3000005`0oooo00<0003o0?ooo`3o
ool0403oool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo03L0oooo000l0?ooo`03003o
003oool0oooo02P0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0g0?ooo`040;md
00000000000007Boo`<0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P000000000000300000005
04RLg`3oool0oooo0?oOW01800000P0000000`00B9`0gooo0?ooo`090?ooo`030000003oool0oooo
05d0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo
03L0oooo000l0?ooo`03003o003oool0oooo02P0oooo00<0o`000?ooo`3oool0403oool00`000?l0
oooo0?ooo`0f0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`03
0?ooo`030?noM000M;l0oooo0080oooo00T0_gAd0;ooo`3oool0okmd0000001d_ol0oooo0?oOW018
M;l02P3oool00`000000oooo0?ooo`1M0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3o
ool09`3oool00`00o`00oooo0?ooo`0g0?ooo`00>`3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0
003oool0oooo0100oooo00<0003o0?ooo`3oool0=P3oool00`3ooml0W4P004RLg`020?ooo`030?no
M00004P0W=oo00P0oooo00<0okmd001d_`3oool02@3oool00`3o_g@0B9cO0?ooo`080?ooo`030000
003oool0oooo05d0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0X0?ooo`03003o
003oool0oooo03H0oooo000k0?ooo`03003o003oool0oooo02P0oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`0f0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo
203oool00`3o_g@007Bo0?ooo`080?ooo`030?oo_`1d07@0_ooo00P0oooo00<000000?ooo`3oool0
G@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?ooo`3oool0
=P3oool003/0oooo00<00?l00?ooo`3oool0:03oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo03H0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`090?ooo`030?noM018
W=l0oooo00L0oooo00<0oooO09a8001d_ol0203oool00`000000oooo0?ooo`1M0?ooo`030000o`3o
ool0oooo0100oooo00<0o`000?ooo`3oool0:03oool00`00o`00oooo0?ooo`0f0?ooo`00>`3oool0
0`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0>03oool0
0`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00X0oooo00<0gia804RLg`3oool01P3oool0
0`3ookl0M00004RLg`080?ooo`@00000G@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0
oooo02L0oooo00<00?l00?ooo`3oool0=P3oool003/0oooo00<00?l00?ooo`3oool0:03oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo03P0oooo00<0gia80000B02Lgol00P3oool00`3o
oml0W4P0001d_`0;0?ooo`030;md001d_ol0oooo00D0oooo00<0okmd0000001d_ol0203oool00`00
0000oooo0?ooo`1N0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool09`3oool00`00
o`00oooo0?ooo`0f0?ooo`00>`3oool00`00o`00oooo0?ooo`0W0?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool0>03oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00X0
oooo00<0omnL04P0M02oool00P3oool01P3ogml0gooo0?noM0000000001d0;ooo`P0oooo00<00000
0?ooo`3oool0GP3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02L0oooo00<00?l0
0?ooo`3oool0=P3oool003X0oooo00<00?l00?ooo`3oool0:03oool00`3o0000oooo0?ooo`0@0?oo
o`030000o`3oool0oooo03P0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`0:
0?ooo`030?oog`2LB000M;oo0080oooo00D0oono07@000000000001809cOo`090?ooo`030000003o
ool0oooo05h0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0X0?ooo`03003o003o
ool0oooo03D0oooo000j0?ooo`03003o003oool0oooo02P0oooo00<0o`000?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`0j0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool02P3oool0
0`3ookl0M00004RLg`030?ooo`030=nLW02oool0oooo00X0oooo00<000000?ooo`3oool0G`3oool0
0`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?ooo`3oool0=@3oool0
03X0oooo00<00?l00?ooo`3oool0:03oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
03/0oooo00H0gia80000M02oool0oooO09a80018W=l70?ooo`070?noM000B9`0gooo0?ooo`3OW4P0
001809cOo`030?ooo`030?oOW01dW=l0oooo00X0oooo00<000000?ooo`3oool0G`3oool00`000?l0
oooo0?ooo`0@0?ooo`030?l0003oool0oooo02L0oooo00<00?l00?ooo`3oool0=@3oool003X0oooo
00<00?l00?ooo`3oool0:03oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo03`0oooo
00@0gia800000000000007Bo2@3oool01@3ogi`0B000000000000000M;oo00D0oooo00D0_g@00000
00000000000004RLg`070?ooo`<00000G`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0
oooo02L0oooo00<00?l00?ooo`3oool0=@3oool003X0oooo00<00?l00?ooo`3oool0:03oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo05l0oooo00<000000?ooo`3oool0G`3oool00`00
0?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02L0oooo00<00?l00?ooo`3oool0=@3oool003X0
oooo00<00?l00?ooo`3oool09`3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo05l0
oooo00<000000?ooo`3oool0G`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02L0
oooo00<00?l00?ooo`3oool0=@3oool003T0oooo00<00?l00?ooo`3oool0:03oool00`3o0000oooo
0?ooo`0?0?ooo`030000o`3oool0oooo0600oooo00<000000?ooo`3oool0H03oool00`000?l0oooo
0?ooo`0@0?ooo`030?l0003oool0oooo02L0oooo00<00?l00?ooo`3oool0=03oool003T0oooo00<0
0?l00?ooo`3oool0:03oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0600oooo00<0
00000?ooo`3oool0H03oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02L0oooo00<0
0?l00?ooo`3oool0=03oool003T0oooo00<00?l00?ooo`3oool0:03oool00`3o0000oooo0?ooo`0?
0?ooo`030000o`3oool0oooo0600oooo00<000000?ooo`3oool0H03oool00`000?l0oooo0?ooo`0@
0?ooo`030?l0003oool0oooo02L0oooo00<00?l00?ooo`3oool0=03oool003T0oooo00<00?l00?oo
o`3oool0:03oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0600oooo0`00001P0?oo
o`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool09`3oool00`00o`00oooo0?ooo`0d0?oo
o`00>@3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3o
ool0H03oool00`000000oooo0?ooo`1Q0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3o
ool09`3oool00`00o`00oooo0?ooo`0d0?ooo`00>@3oool00`00o`00oooo0?ooo`0W0?ooo`030?l0
003oool0oooo0100oooo00<0003o0?ooo`3oool0H03oool00`000000oooo0?ooo`1Q0?ooo`030000
o`3oool0oooo0100oooo00<0o`000?ooo`3oool09P3oool00`00o`00oooo0?ooo`0d0?ooo`00>03o
ool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0H@3o
ool00`000000oooo0?ooo`1Q0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool09`3o
ool00`00o`00oooo0?ooo`0c0?ooo`00>03oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool0H@3oool00`000000oooo0?ooo`1Q0?ooo`030000o`3oool0
oooo0100oooo00<0o`000?ooo`3oool09`3oool00`00o`00oooo0?ooo`0c0?ooo`00>03oool00`00
o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0H@3oool00`00
0000oooo0?ooo`1Q0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool09`3oool00`00
o`00oooo0?ooo`0c0?ooo`00>03oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo00l0
oooo00<0003o0?ooo`3oool0H@3oool300000680oooo00<0003o0?ooo`3oool0403oool00`3o0000
oooo0?ooo`0V0?ooo`03003o003oool0oooo03<0oooo000h0?ooo`03003o003oool0oooo02P0oooo
00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`1Q0?ooo`030000003oool0oooo0680oooo
00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0V0?ooo`03003o003oool0oooo03<0oooo
000h0?ooo`03003o003oool0oooo02L0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?oo
o`1Q0?ooo`030000003oool0oooo0680oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0V0?ooo`03003o003oool0oooo03<0oooo000g0?ooo`03003o003oool0oooo02P0oooo00<0o`00
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`1R0?ooo`030000003oool0oooo0680oooo00<0003o
0?ooo`3oool0403oool00`3o0000oooo0?ooo`0W0?ooo`03003o003oool0oooo0380oooo000g0?oo
o`03003o003oool0oooo02P0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`1R0?oo
o`030000003oool0oooo06<0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0W0?oo
o`03003o003oool0oooo0380oooo000g0?ooo`03003o003oool0oooo02P0oooo00<0o`000?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`1R0?ooo`030000003oool0oooo06<0oooo00<0003o0?ooo`3o
ool03`3oool00`3o0000oooo0?ooo`0W0?ooo`03003o003oool0oooo0380oooo000g0?ooo`03003o
003oool0oooo02P0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`1R0?ooo`<00000
H`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02H0oooo00<00?l00?ooo`3oool0
<P3oool003L0oooo00<00?l00?ooo`3oool09`3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo04H0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`060?oO
W0180000000000000000B9`0gooo2P3oool00`000000oooo0?ooo`1S0?ooo`030000o`3oool0oooo
0100oooo00<0o`000?ooo`3oool09P3oool00`00o`00oooo0?ooo`0b0?ooo`00=`3oool00`00o`00
oooo0?ooo`0W0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0A@3oool01P3OW4P0
07Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00P3oool01P3o_g@0000007Boo`3o
ool0omnL04Qd_`X0oooo00<000000?ooo`3oool0H`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0
003oool0oooo02H0oooo00<00?l00?ooo`3oool0<P3oool003H0oooo00<00?l00?ooo`3oool0:03o
ool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo04D0oooo00<0oooO09a80018W=l00P3o
ool00`3o_g@0001809cOo`0;0?ooo`030?noM018W=l0oooo00P0oooo00<000000?ooo`3oool0H`3o
ool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02H0oooo00<00?l00?ooo`3oool0<P3o
ool003H0oooo00<00?l00?ooo`3oool0:03oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0
oooo04D0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool:0?ooo`030?oo_`1d
07@0_ooo00P0oooo00<000000?ooo`3oool0I03oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo02L0oooo00<00?l00?ooo`3oool0<@3oool003H0oooo00<00?l00?ooo`3oool0:03oool0
0`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo04D0oooo00<0oooO09a80000M;l00`3oool0
0`3OW4P0001809cOo`0:0?ooo`030?oog`2LB000M;oo00P0oooo00<000000?ooo`3oool0I03oool0
0`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo02L0oooo00<00?l00?ooo`3oool0<@3oool0
03H0oooo00<00?l00?ooo`3oool0:03oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
04H0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?ooo`030?oo_`1d0000B9cO
00P0oooo1000001S0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool09P3oool00`00
o`00oooo0?ooo`0a0?ooo`00=P3oool00`00o`00oooo0?ooo`0W0?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool0AP3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00X0
oooo00<0okmd0000001d_ol0203oool00`000000oooo0?ooo`1T0?ooo`030000o`3oool0oooo0100
oooo00<0o`000?ooo`3oool09P3oool00`00o`00oooo0?ooo`0a0?ooo`00=P3oool00`00o`00oooo
0?ooo`0W0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0AP3oool00`3ogi`0B000
04RLg`030?ooo`030;md0000B9`0gooo00H0oooo00H0omoO0=ooo`3o_g@000000000M02oool80?oo
o`030000003oool0oooo06@0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0V0?oo
o`03003o003oool0oooo0340oooo000e0?ooo`03003o003oool0oooo02P0oooo00<0o`000?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`170?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018
W03Oool01P3oool01@3ookl0M0000000000004P0W=oo00T0oooo00<000000?ooo`3oool0I03oool0
0`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02H0oooo00<00?l00?ooo`3oool0<@3oool0
03D0oooo00<00?l00?ooo`3oool0:03oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
04P0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`070?ooo`030=nLW02oool0oooo
00X0oooo00<000000?ooo`3oool0I@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo
02L0oooo00<00?l00?ooo`3oool0<03oool003D0oooo00<00?l00?ooo`3oool0:03oool00`3o0000
oooo0?ooo`0?0?ooo`030000o`3oool0oooo04T0oooo00H0gia80000M02oool0oooO09a80018W=l8
0?ooo`030?oOW01dW=l0oooo00X0oooo00<000000?ooo`3oool0I@3oool00`000?l0oooo0?ooo`0?
0?ooo`030?l0003oool0oooo02L0oooo00<00?l00?ooo`3oool0<03oool003D0oooo00<00?l00?oo
o`3oool0:03oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo04X0oooo00@0gia80000
0000000007Bo2P3oool01@2oM0000000000000000000B9cO00L0oooo0`00001U0?ooo`030000o`3o
ool0oooo00l0oooo00<0o`000?ooo`3oool09`3oool00`00o`00oooo0?ooo`0`0?ooo`00=@3oool0
0`00o`00oooo0?ooo`0W0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0I03oool0
0`000000oooo0?ooo`1U0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool09P3oool0
0`00o`00oooo0?ooo`0`0?ooo`00=@3oool00`00o`00oooo0?ooo`0W0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool0I03oool00`000000oooo0?ooo`1U0?ooo`030000o`3oool0oooo
0100oooo00<0o`000?ooo`3oool09P3oool00`00o`00oooo0?ooo`0`0?ooo`00=@3oool00`00o`00
oooo0?ooo`0W0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0I@3oool00`000000
oooo0?ooo`1U0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool09P3oool00`00o`00
oooo0?ooo`0`0?ooo`00=@3oool00`00o`00oooo0?ooo`0W0?ooo`030?l0003oool0oooo00l0oooo
00<0003o0?ooo`3oool0I@3oool00`000000oooo0?ooo`1U0?ooo`030000o`3oool0oooo0100oooo
00<0o`000?ooo`3oool09`3oool00`00o`00oooo0?ooo`0_0?ooo`00=03oool00`00o`00oooo0?oo
o`0X0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0I@3oool00`000000oooo0?oo
o`1V0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool09`3oool00`00o`00oooo0?oo
o`0_0?ooo`00=03oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool0I@3oool3000006H0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0W
0?ooo`03003o003oool0oooo02l0oooo000d0?ooo`03003o003oool0oooo02L0oooo00<0o`000?oo
o`3oool0403oool00`000?l0oooo0?ooo`1U0?ooo`030000003oool0oooo06H0oooo00<0003o0?oo
o`3oool0403oool00`3o0000oooo0?ooo`0V0?ooo`03003o003oool0oooo02l0oooo000d0?ooo`03
003o003oool0oooo02L0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1U0?ooo`03
0000003oool0oooo06H0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0V0?ooo`03
003o003oool0oooo02l0oooo000d0?ooo`03003o003oool0oooo02L0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo06H0oooo00<0003o0?ooo`3oool0
403oool00`3o0000oooo0?ooo`0V0?ooo`03003o003oool0oooo02l0oooo000d0?ooo`03003o003o
ool0oooo02L0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`1V0?ooo`030000003o
ool0oooo06H0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0W0?ooo`03003o003o
ool0oooo02h0oooo000d0?ooo`03003o003oool0oooo02L0oooo00<0o`000?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo06L0oooo00<0003o0?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`0W0?ooo`03003o003oool0oooo02h0oooo000d0?ooo`03003o003oool0oooo
02L0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`1V0?ooo`<00000I`3oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo02L0oooo00<00?l00?ooo`3oool0;P3oool003<0
oooo00<00?l00?ooo`3oool09`3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo06H0
oooo00<000000?ooo`3oool0I`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo02L0
oooo00<00?l00?ooo`3oool0;P3oool003<0oooo00<00?l00?ooo`3oool09`3oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo06H0oooo00<000000?ooo`3oool0I`3oool00`000?l0oooo
0?ooo`0@0?ooo`030?l0003oool0oooo02H0oooo00<00?l00?ooo`3oool0;P3oool003<0oooo00<0
0?l00?ooo`3oool09`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo06L0oooo00<0
00000?ooo`3oool0I`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02H0oooo00<0
0?l00?ooo`3oool0;P3oool003<0oooo00<00?l00?ooo`3oool09`3oool00`3o0000oooo0?ooo`0?
0?ooo`030000o`3oool0oooo06L0oooo00<000000?ooo`3oool0I`3oool00`000?l0oooo0?ooo`0@
0?ooo`030?l0003oool0oooo02H0oooo00<00?l00?ooo`3oool0;P3oool003<0oooo00<00?l00?oo
o`3oool09`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo06L0oooo00<000000?oo
o`3oool0J03oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo02L0oooo00<00?l00?oo
o`3oool0;@3oool003<0oooo00<00?l00?ooo`3oool09`3oool00`3o0000oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo06L0oooo0`00001X0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3o
ool09`3oool00`00o`00oooo0?ooo`0]0?ooo`00<`3oool00`00o`00oooo0?ooo`0V0?ooo`030?l0
003oool0oooo0100oooo00<0003o0?ooo`3oool0@P3oool0102oM00000000000001d_ol30?ooo`03
0?oOW0180000M;oo00<0oooo00<0oono07A8W03Oool01@3oool01P3ogi`0B00000000000000004RL
0=ooo`X0oooo00<000000?ooo`3oool0J03oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0
oooo02L0oooo00<00?l00?ooo`3oool0;@3oool003<0oooo00<00?l00?ooo`3oool09P3oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0440oooo00H0gia8001d_`3oool0omnL04P00018
W=l20?ooo`030?oOW0180000M;oo00@0oooo00<0gia804RLg`3oool0103oool01P3o_g@0000007Bo
o`3oool0omnL04Qd_`X0oooo00<000000?ooo`3oool0J03oool00`000?l0oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo02H0oooo00<00?l00?ooo`3oool0;@3oool00380oooo00<00?l00?ooo`3oool0
9`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0440oooo00<0oooO09a80018W=l0
0P3oool00`3o_g@0001809cOo`080?ooo`030?oo_`1d07@0_ooo00T0oooo00<0okmd04RLg`3oool0
203oool00`000000oooo0?ooo`1X0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0
9P3oool00`00o`00oooo0?ooo`0]0?ooo`00<P3oool00`00o`00oooo0?ooo`0W0?ooo`030?l0003o
ool0oooo00l0oooo00<0003o0?ooo`3oool0@@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2L
B00004RL0=ooo`P0oooo00<0okmd001d_`3oool0203oool00`3ookl0M01d0;ooo`080?ooo`030000
003oool0oooo06P0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0V0?ooo`03003o
003oool0oooo02d0oooo000b0?ooo`03003o003oool0oooo02L0oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`110?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol0203o
ool00`3ooml0W4Q809cOo`080?ooo`030?oog`2LB000M;oo00P0oooo00<000000?ooo`3oool0J03o
ool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02H0oooo00<00?l00?ooo`3oool0;@3o
ool00380oooo00<00?l00?ooo`3oool09`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0
oooo0480oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`090?ooo`030?oOW018M;l0
oooo00L0oooo00<0oono07@00018W=l0203oool4000006P0oooo00<0003o0?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`0W0?ooo`03003o003oool0oooo02`0oooo000b0?ooo`03003o003oool0oooo
02L0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`120?ooo`030=nLB00004P0W=oo
0080oooo00<0oooO09a80000M;l02P3oool00`2oM000M;oo0?ooo`060?ooo`030?noM0000000M;oo
00P0oooo00<000000?ooo`3oool0J@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo
02L0oooo00<00?l00?ooo`3oool0;03oool00380oooo00<00?l00?ooo`3oool09P3oool00`3o0000
oooo0?ooo`0@0?ooo`030000o`3oool0oooo0480oooo00<0omnL04P00018W=l00`3oool00`2oM000
04RL0=ooo`090?ooo`030?oOW018B9`0gooo00<0oooo00H0omoO0=ooo`3o_g@000000000M02oool8
0?ooo`030000003oool0oooo06T0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0W
0?ooo`03003o003oool0oooo02`0oooo000b0?ooo`03003o003oool0oooo02H0oooo00<0o`000?oo
o`3oool03`3oool00`000?l0oooo0?ooo`130?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia8
0018W03Oool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`050?oo_`1d000000000000B02Lgol02@3o
ool00`000000oooo0?ooo`1Y0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool09P3o
ool00`00o`00oooo0?ooo`0/0?ooo`00<@3oool00`00o`00oooo0?ooo`0W0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool0A03oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0
oooo00D0oooo00<0oooO0=oOo`3oool00P3oool00`3ookl0M01d0;ooo`030?ooo`030=nLW02oool0
oooo00X0oooo00<000000?ooo`3oool0J@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0
oooo02H0oooo00<00?l00?ooo`3oool0;03oool00340oooo00<00?l00?ooo`3oool09`3oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo04D0oooo00H0gia80000M02oool0oooO09a80018
W=l70?ooo`030;mdM02oool0oooo0080oooo00<0okmd001d_`3oool00P3oool00`3ogi`0M9cO0?oo
o`0:0?ooo`030000003oool0oooo06T0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0V0?ooo`03003o003oool0oooo02`0oooo000a0?ooo`03003o003oool0oooo02L0oooo00<0o`00
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`160?ooo`040=nLB00000000000001d_`P0oooo00<0
oono07@0000000000`0000000`0004P0W=oo0?ooo`020?ooo`050;md00000000000000000018W=l0
1`3oool3000006X0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0V0?ooo`03003o
003oool0oooo02`0oooo000a0?ooo`03003o003oool0oooo02L0oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`1Y0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool03`3o
ool00`3o0000oooo0?ooo`0W0?ooo`03003o003oool0oooo02/0oooo000a0?ooo`03003o003oool0
oooo02H0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1Y0?ooo`030000003oool0
oooo06X0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0W0?ooo`03003o003oool0
oooo02/0oooo000a0?ooo`03003o003oool0oooo02H0oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`1Z0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool0403oool00`3o
0000oooo0?ooo`0V0?ooo`03003o003oool0oooo02/0oooo000a0?ooo`03003o003oool0oooo02H0
oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`1Z0?ooo`030000003oool0oooo06X0
oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0V0?ooo`03003o003oool0oooo02/0
oooo000a0?ooo`03003o003oool0oooo02H0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo
0?ooo`1Z0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo
0?ooo`0V0?ooo`03003o003oool0oooo02/0oooo000`0?ooo`03003o003oool0oooo02L0oooo00<0
o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`1Z0?ooo`030000003oool0oooo06X0oooo00<0
003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0V0?ooo`03003o003oool0oooo02/0oooo000`
0?ooo`03003o003oool0oooo02L0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`1Z
0?ooo`<00000J`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo02H0oooo00<00?l0
0?ooo`3oool0:`3oool00300oooo00<00?l00?ooo`3oool09`3oool00`3o0000oooo0?ooo`0?0?oo
o`030000o`3oool0oooo06X0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo02L0oooo00<00?l00?ooo`3oool0:P3oool00300oooo00<00?l00?ooo`3o
ool09P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo06X0oooo00<000000?ooo`3o
ool0J`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo02L0oooo00<00?l00?ooo`3o
ool0:P3oool00300oooo00<00?l00?ooo`3oool09P3oool00`3o0000oooo0?ooo`0?0?ooo`030000
o`3oool0oooo06/0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0
003oool0oooo02L0oooo00<00?l00?ooo`3oool0:P3oool00300oooo00<00?l00?ooo`3oool09P3o
ool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo06/0oooo00<000000?ooo`3oool0J`3o
ool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02H0oooo00<00?l00?ooo`3oool0:P3o
ool00300oooo00<00?l00?ooo`3oool09P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0
oooo06/0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0
oooo02H0oooo00<00?l00?ooo`3oool0:P3oool00300oooo00<00?l00?ooo`3oool09P3oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo06/0oooo0`00001[0?ooo`030000o`3oool0oooo
0100oooo00<0o`000?ooo`3oool09P3oool00`00o`00oooo0?ooo`0Z0?ooo`00;`3oool00`00o`00
oooo0?ooo`0W0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0J`3oool00`000000
oooo0?ooo`1[0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool09P3oool00`00o`00
oooo0?ooo`0Z0?ooo`00;`3oool00`00o`00oooo0?ooo`0W0?ooo`030?l0003oool0oooo00l0oooo
00<0003o0?ooo`3oool0J`3oool00`000000oooo0?ooo`1/0?ooo`030000o`3oool0oooo00l0oooo
00<0o`000?ooo`3oool09`3oool00`00o`00oooo0?ooo`0Y0?ooo`00;`3oool00`00o`00oooo0?oo
o`0V0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0J`3oool00`000000oooo0?oo
o`1/0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool09`3oool00`00o`00oooo0?oo
o`0Y0?ooo`00;`3oool00`00o`00oooo0?ooo`0V0?ooo`030?l0003oool0oooo0100oooo00<0003o
0?ooo`3oool0J`3oool00`000000oooo0?ooo`1/0?ooo`030000o`3oool0oooo00l0oooo00<0o`00
0?ooo`3oool09`3oool00`00o`00oooo0?ooo`0Y0?ooo`00;`3oool00`00o`00oooo0?ooo`0V0?oo
o`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0J`3oool00`000000oooo0?ooo`1/0?oo
o`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool09`3oool00`00o`00oooo0?ooo`0Y0?oo
o`00;`3oool00`00o`00oooo0?ooo`0V0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool0J`3oool3000006`0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0W0?ooo`03
003o003oool0oooo02T0oooo000_0?ooo`03003o003oool0oooo02H0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`1K0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0
2@3oool00`000000oooo0?ooo`1/0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0
9`3oool00`00o`00oooo0?ooo`0Y0?ooo`00;`3oool00`00o`00oooo0?ooo`0V0?ooo`030?l0003o
ool0oooo00l0oooo00<0003o0?ooo`3oool0G@3oool00`3o_g@0000007Boo`0<0?ooo`030000003o
ool0oooo06`0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0V0?ooo`03003o003o
ool0oooo02T0oooo000^0?ooo`03003o003oool0oooo02H0oooo00<0o`000?ooo`3oool0403oool0
0`000?l0oooo0?ooo`1M0?ooo`030?oog`2LB00007Bo00`0oooo00<000000?ooo`3oool0K@3oool0
0`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo02L0oooo00<00?l00?ooo`3oool0:03oool0
02h0oooo00<00?l00?ooo`3oool09P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo
05h0oooo00<0gia80018W03Oool02`3oool00`000000oooo0?ooo`1]0?ooo`030000o`3oool0oooo
00l0oooo00<0o`000?ooo`3oool09`3oool00`00o`00oooo0?ooo`0X0?ooo`00;P3oool00`00o`00
oooo0?ooo`0V0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0GP3oool00`3ogi`0
B01809cOo`0;0?ooo`030000003oool0oooo06d0oooo00<0003o0?ooo`3oool03`3oool00`3o0000
oooo0?ooo`0W0?ooo`03003o003oool0oooo02P0oooo000^0?ooo`03003o003oool0oooo02H0oooo
00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1N0?ooo`030?oo_`1d0000M;oo00/0oooo
1000001/0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool09`3oool00`00o`00oooo
0?ooo`0X0?ooo`00c03oool00`2oM00007Bo0?ooo`3Q0?ooo`00c03oool00`3OW4P004RL0=ooo`3Q
0?ooo`00c03oool00`3ogi`0B01809cOo`3Q0?ooo`00c03oool00`3ookl0M00007Boo`3Q0?ooo`00
c@3oool00`2oM00007Bo0?ooo`3P0?ooo`00b`3oool01@3ookl0M0000000000007@0_ooo0>00oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-3.49993, -1.09711, \
0.0240998, 0.0123792}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(plot1\  = \ 
        duffingPlot[\(-1\), 1\/3, 0.0, 0, 0, 0, 1, 0, 10, \ 
          PlotLabel \[Rule] "\<Free Conservative Oscillations\>", 
          PlotStyle \[Rule] RGBColor[0, 1, 0], 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(plot2\  = \ 
        duffingPlot[\(-1\), 2\/3, 0.0, 0, 0, 0, 1, 0, 10, 
          PlotStyle \[Rule] RGBColor[1, 0, 0], 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(plot3\  = \ 
        duffingPlot[\(-1\), 1, 0.0, 0, 0, 0, 1, 0, 10, 
          PlotStyle \[Rule] RGBColor[0, 0, 1], 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[{plot1, plot2, plot3}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.181639 0.499996 0.301173 [
[.13672 -0.0125 -9.34375 -15.6875 ]
[.13672 -0.0125 9.34375 0 ]
[.31836 -0.0125 -9.34375 -15.6875 ]
[.31836 -0.0125 9.34375 0 ]
[.5 -0.0125 -5 -15.6875 ]
[.5 -0.0125 5 0 ]
[.68164 -0.0125 -5 -15.6875 ]
[.68164 -0.0125 5 0 ]
[.86328 -0.0125 -5 -15.6875 ]
[.86328 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.9688 -31.375 ]
[.5 -0.0125 21.9688 -15.6875 ]
[-0.0125 .04824 -27.6875 -7.84375 ]
[-0.0125 .04824 0 7.84375 ]
[-0.0125 .19882 -18.6875 -7.84375 ]
[-0.0125 .19882 0 7.84375 ]
[-0.0125 .34941 -27.6875 -7.84375 ]
[-0.0125 .34941 0 7.84375 ]
[-0.0125 .5 -10 -7.84375 ]
[-0.0125 .5 0 7.84375 ]
[-0.0125 .65058 -19 -7.84375 ]
[-0.0125 .65058 0 7.84375 ]
[-0.0125 .80117 -10 -7.84375 ]
[-0.0125 .80117 0 7.84375 ]
[-0.0125 .95176 -19 -7.84375 ]
[-0.0125 .95176 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -43.375 -20.4688 ]
[-0.01875 .5 -27.6875 20.4688 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -76.6875 0 ]
[.5 1.0125 76.6875 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13672 0 m
.13672 .00625 L
s
gsave
.13672 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.31836 0 m
.31836 .00625 L
s
gsave
.31836 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.68164 0 m
.68164 .00625 L
s
gsave
.68164 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.86328 0 m
.86328 .00625 L
s
gsave
.86328 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.17305 0 m
.17305 .00375 L
s
.20938 0 m
.20938 .00375 L
s
.24571 0 m
.24571 .00375 L
s
.28203 0 m
.28203 .00375 L
s
.35469 0 m
.35469 .00375 L
s
.39102 0 m
.39102 .00375 L
s
.42734 0 m
.42734 .00375 L
s
.46367 0 m
.46367 .00375 L
s
.53633 0 m
.53633 .00375 L
s
.57266 0 m
.57266 .00375 L
s
.60898 0 m
.60898 .00375 L
s
.64531 0 m
.64531 .00375 L
s
.71797 0 m
.71797 .00375 L
s
.75429 0 m
.75429 .00375 L
s
.79062 0 m
.79062 .00375 L
s
.82695 0 m
.82695 .00375 L
s
.1004 0 m
.1004 .00375 L
s
.06407 0 m
.06407 .00375 L
s
.02774 0 m
.02774 .00375 L
s
.8996 0 m
.8996 .00375 L
s
.93593 0 m
.93593 .00375 L
s
.97226 0 m
.97226 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.9688 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
102.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .04824 m
.00625 .04824 L
s
gsave
-0.0125 .04824 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .19882 m
.00625 .19882 L
s
gsave
-0.0125 .19882 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .34941 m
.00625 .34941 L
s
gsave
-0.0125 .34941 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .65058 m
.00625 .65058 L
s
gsave
-0.0125 .65058 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .80117 m
.00625 .80117 L
s
gsave
-0.0125 .80117 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .95176 m
.00625 .95176 L
s
gsave
-0.0125 .95176 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07835 m
.00375 .07835 L
s
0 .10847 m
.00375 .10847 L
s
0 .13859 m
.00375 .13859 L
s
0 .16871 m
.00375 .16871 L
s
0 .22894 m
.00375 .22894 L
s
0 .25906 m
.00375 .25906 L
s
0 .28918 m
.00375 .28918 L
s
0 .31929 m
.00375 .31929 L
s
0 .37953 m
.00375 .37953 L
s
0 .40964 m
.00375 .40964 L
s
0 .43976 m
.00375 .43976 L
s
0 .46988 m
.00375 .46988 L
s
0 .53011 m
.00375 .53011 L
s
0 .56023 m
.00375 .56023 L
s
0 .59035 m
.00375 .59035 L
s
0 .62047 m
.00375 .62047 L
s
0 .6807 m
.00375 .6807 L
s
0 .71082 m
.00375 .71082 L
s
0 .74093 m
.00375 .74093 L
s
0 .77105 m
.00375 .77105 L
s
0 .83129 m
.00375 .83129 L
s
0 .8614 m
.00375 .8614 L
s
0 .89152 m
.00375 .89152 L
s
0 .92164 m
.00375 .92164 L
s
0 .01812 m
.00375 .01812 L
s
0 .98187 m
.00375 .98187 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -117 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
81.4688 11.8438 translate
90 rotate
-81.4688 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(velocity) show
99.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.13672 .99375 m
.13672 1 L
s
.31836 .99375 m
.31836 1 L
s
.5 .99375 m
.5 1 L
s
.68164 .99375 m
.68164 1 L
s
.86328 .99375 m
.86328 1 L
s
.125 Mabswid
.17305 .99625 m
.17305 1 L
s
.20938 .99625 m
.20938 1 L
s
.24571 .99625 m
.24571 1 L
s
.28203 .99625 m
.28203 1 L
s
.35469 .99625 m
.35469 1 L
s
.39102 .99625 m
.39102 1 L
s
.42734 .99625 m
.42734 1 L
s
.46367 .99625 m
.46367 1 L
s
.53633 .99625 m
.53633 1 L
s
.57266 .99625 m
.57266 1 L
s
.60898 .99625 m
.60898 1 L
s
.64531 .99625 m
.64531 1 L
s
.71797 .99625 m
.71797 1 L
s
.75429 .99625 m
.75429 1 L
s
.79062 .99625 m
.79062 1 L
s
.82695 .99625 m
.82695 1 L
s
.1004 .99625 m
.1004 1 L
s
.06407 .99625 m
.06407 1 L
s
.02774 .99625 m
.02774 1 L
s
.8996 .99625 m
.8996 1 L
s
.93593 .99625 m
.93593 1 L
s
.97226 .99625 m
.97226 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .04824 m
1 .04824 L
s
.99375 .19882 m
1 .19882 L
s
.99375 .34941 m
1 .34941 L
s
.99375 .5 m
1 .5 L
s
.99375 .65058 m
1 .65058 L
s
.99375 .80117 m
1 .80117 L
s
.99375 .95176 m
1 .95176 L
s
.125 Mabswid
.99625 .07835 m
1 .07835 L
s
.99625 .10847 m
1 .10847 L
s
.99625 .13859 m
1 .13859 L
s
.99625 .16871 m
1 .16871 L
s
.99625 .22894 m
1 .22894 L
s
.99625 .25906 m
1 .25906 L
s
.99625 .28918 m
1 .28918 L
s
.99625 .31929 m
1 .31929 L
s
.99625 .37953 m
1 .37953 L
s
.99625 .40964 m
1 .40964 L
s
.99625 .43976 m
1 .43976 L
s
.99625 .46988 m
1 .46988 L
s
.99625 .53011 m
1 .53011 L
s
.99625 .56023 m
1 .56023 L
s
.99625 .59035 m
1 .59035 L
s
.99625 .62047 m
1 .62047 L
s
.99625 .6807 m
1 .6807 L
s
.99625 .71082 m
1 .71082 L
s
.99625 .74093 m
1 .74093 L
s
.99625 .77105 m
1 .77105 L
s
.99625 .83129 m
1 .83129 L
s
.99625 .8614 m
1 .8614 L
s
.99625 .89152 m
1 .89152 L
s
.99625 .92164 m
1 .92164 L
s
.99625 .01812 m
1 .01812 L
s
.99625 .98187 m
1 .98187 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .5 m
1 .5 L
s
.5 0 m
.5 1 L
s
gsave
.5 1.0125 -137.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Free) show
88.563 15.813 moveto
(Conservative) show
154.563 15.813 moveto
(Oscillations) show
212.375 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 1 0 r
.5 Mabswid
.5 .80117 m
.50224 .80119 L
.50428 .80125 L
.50664 .80137 L
.50887 .80153 L
.51283 .80192 L
.51714 .80251 L
.5219 .80335 L
.52697 .80446 L
.5361 .80702 L
.55465 .81431 L
.57569 .82557 L
.62271 .8591 L
.6716 .89952 L
.72077 .93785 L
.75051 .95666 L
.76514 .96404 L
.77911 .96967 L
.7868 .9721 L
.79086 .97317 L
.79515 .97414 L
.79878 .97482 L
.80277 .97541 L
.8064 .97581 L
.80979 .97606 L
.81183 .97615 L
.81405 .97619 L
.81615 .97618 L
.81809 .97612 L
.82176 .97589 L
.82566 .97546 L
.82766 .97517 L
.82982 .97479 L
.83372 .97395 L
.84258 .97124 L
.84983 .96813 L
.85771 .96379 L
.8733 .95179 L
.88731 .93656 L
.89986 .9186 L
.91288 .89469 L
.92604 .86355 L
.93739 .82919 L
.94679 .7934 L
.9549 .75478 L
.9614 .71573 L
.967 .67237 L
.96963 .64661 L
.97168 .62216 L
.97335 .59724 L
Mistroke
.97472 .57031 L
.9753 .55478 L
.97553 .54713 L
.97571 .5401 L
.97598 .52687 L
.97607 .5199 L
.97614 .51255 L
.97619 .49994 L
.97614 .48645 L
.97599 .47372 L
.97577 .46216 L
.97541 .44861 L
.97489 .43396 L
.97363 .40756 L
.97217 .3845 L
.97018 .3595 L
.96499 .31062 L
.95885 .26787 L
.95201 .23041 L
.93276 .15581 L
.92147 .12471 L
.9081 .09582 L
.8959 .07522 L
.88228 .05742 L
.86897 .04439 L
.85661 .03553 L
.84976 .03182 L
.84219 .02861 L
.83835 .02732 L
.83423 .02617 L
.83065 .02537 L
.82676 .02469 L
.82289 .02421 L
.81931 .02393 L
.81588 .02381 L
.81224 .02383 L
.80899 .02398 L
.80594 .02422 L
.8026 .0246 L
.79899 .02514 L
.79142 .02669 L
.78316 .02898 L
.76666 .03527 L
.73781 .05081 L
.68446 .08991 L
.63295 .13262 L
.58889 .16599 L
.56719 .17932 L
.55566 .18521 L
.54504 .1898 L
Mistroke
.53495 .19333 L
.52581 .19581 L
.52064 .19689 L
.51574 .1977 L
.51324 .19802 L
.51058 .19831 L
.50905 .19845 L
.50767 .19856 L
.50638 .19864 L
.50496 .19871 L
.50267 .19879 L
.50025 .19882 L
.49801 .19881 L
.49591 .19875 L
.49344 .19863 L
.49119 .19847 L
.48858 .19823 L
.48612 .19795 L
.48169 .1973 L
.47758 .19654 L
.46824 .19428 L
.45922 .19139 L
.44939 .1875 L
.43125 .17845 L
.38749 .14888 L
.34151 .11141 L
.28555 .06668 L
.25769 .04806 L
.24191 .03933 L
.22678 .03251 L
.21247 .02769 L
.20853 .02668 L
.20435 .02576 L
.20074 .0251 L
.19685 .02453 L
.19332 .02415 L
.1901 .02393 L
.18687 .02381 L
.18379 .02382 L
.18023 .02396 L
.17692 .02423 L
.1733 .02468 L
.16945 .02534 L
.1657 .02619 L
.1616 .02733 L
.15336 .03039 L
.14578 .03415 L
.13878 .0385 L
.12325 .05152 L
.11477 .06086 L
Mistroke
.10722 .0707 L
.09402 .09188 L
.08053 .11991 L
.06874 .15124 L
.05882 .18428 L
.05005 .22064 L
.04186 .26357 L
.03543 .30731 L
.03072 .34965 L
.02845 .37618 L
.02673 .4013 L
.0253 .42929 L
.02471 .44509 L
.02449 .45208 L
.0243 .45949 L
.02402 .4733 L
.02387 .48603 L
.02381 .49975 L
.02383 .50754 L
.02387 .51481 L
.02404 .52796 L
.02428 .53994 L
.02467 .55372 L
.02514 .56672 L
.02632 .59158 L
.02777 .61462 L
.02991 .64155 L
.03227 .66571 L
.03819 .71297 L
.04618 .76042 L
.05372 .79558 L
.06303 .83059 L
.08464 .88941 L
.09811 .91527 L
.11155 .93512 L
.1241 .94931 L
.13811 .96103 L
.1455 .96569 L
.15371 .96976 L
.15787 .9714 L
.16236 .97289 L
.16624 .97394 L
.17049 .97485 L
.17252 .9752 L
.17469 .97551 L
.1786 .97592 L
.18068 .97606 L
.18264 .97615 L
.18631 .97619 L
.18993 .97607 L
Mistroke
.19326 .97584 L
.19692 .97545 L
.20077 .97489 L
.20844 .97334 L
.21566 .97137 L
.22911 .96654 L
.24341 .9599 L
.2587 .95133 L
.3091 .91527 L
.35766 .87511 L
.40585 .83761 L
.42631 .82438 L
.44752 .81332 L
.45706 .80939 L
.46698 .80608 L
.47537 .80392 L
.4801 .80297 L
.48448 .80226 L
.48693 .80195 L
.48952 .80167 L
.49173 .80148 L
.49416 .80132 L
.49552 .80126 L
.49676 .80122 L
.4982 .80118 L
.49956 .80117 L
.50198 .80119 L
.50335 .80122 L
.50461 .80127 L
.50686 .80138 L
.50898 .80154 L
.51131 .80175 L
.51382 .80204 L
.51893 .8028 L
.52364 .8037 L
.53198 .80578 L
.54119 .80875 L
.56008 .81693 L
.58103 .82887 L
.60084 .84237 L
.64865 .88036 L
.74192 .9517 L
Mfstroke
1 0 0 r
.5 .80117 m
.50224 .80119 L
.50428 .80125 L
.50664 .80137 L
.50887 .80153 L
.51283 .80192 L
.51714 .8025 L
.5219 .80334 L
.52697 .80445 L
.5361 .80698 L
.55464 .81411 L
.57565 .82485 L
.61911 .8523 L
.64467 .86888 L
.67003 .88336 L
.68194 .88894 L
.69481 .89374 L
.70227 .89584 L
.70907 .89724 L
.71236 .89774 L
.7141 .89795 L
.71593 .89812 L
.71753 .89825 L
.7193 .89834 L
.7224 .89841 L
.72565 .89834 L
.72873 .89813 L
.7315 .89782 L
.73451 .89735 L
.73777 .89668 L
.74123 .89576 L
.74741 .89359 L
.75307 .89095 L
.75835 .88789 L
.77019 .87864 L
.78128 .86653 L
.79293 .84941 L
.80443 .82698 L
.81438 .80183 L
.82997 .74649 L
.83722 .71011 L
.84276 .67409 L
.84748 .63305 L
.84938 .61149 L
.85107 .58724 L
.85218 .56621 L
.85267 .55451 L
.85304 .54334 L
.85331 .53294 L
.85352 .52158 L
Mistroke
.85363 .51122 L
.85367 .50161 L
.85363 .4893 L
.85357 .48237 L
.85348 .47601 L
.85324 .46433 L
.85289 .45204 L
.85205 .43087 L
.85077 .40796 L
.849 .38389 L
.84666 .35877 L
.84132 .3156 L
.83443 .27477 L
.82691 .24062 L
.8175 .20745 L
.80637 .17745 L
.79593 .15584 L
.78558 .1392 L
.77372 .12481 L
.76687 .1184 L
.76051 .11353 L
.75449 .1098 L
.74877 .10698 L
.74558 .10569 L
.74213 .1045 L
.73924 .10368 L
.73607 .10294 L
.73306 .1024 L
.73025 .10202 L
.72728 .10175 L
.72409 .1016 L
.72112 .10159 L
.71831 .1017 L
.71579 .10188 L
.71305 .10217 L
.70983 .10262 L
.70681 .10316 L
.69995 .10475 L
.69329 .10674 L
.68615 .10933 L
.66186 .12096 L
.6165 .14942 L
.59394 .16413 L
.57083 .17782 L
.54929 .18819 L
.53933 .19195 L
.53023 .19472 L
.52116 .1968 L
.5164 .1976 L
.51398 .19793 L
Mistroke
.51138 .19823 L
.5091 .19845 L
.50702 .1986 L
.50493 .19871 L
.50295 .19878 L
.50065 .19882 L
.49852 .19881 L
.49618 .19876 L
.49368 .19864 L
.49131 .19848 L
.4887 .19824 L
.48343 .19758 L
.47854 .19674 L
.47396 .19576 L
.46356 .1929 L
.45229 .18884 L
.43118 .1789 L
.41128 .16739 L
.36575 .13774 L
.34448 .12456 L
.33288 .11813 L
.32017 .11197 L
.30779 .10711 L
.30232 .10538 L
.29632 .10382 L
.29356 .10323 L
.29061 .10269 L
.28806 .10231 L
.28529 .10198 L
.28215 .10173 L
.27919 .1016 L
.2763 .10159 L
.27364 .10169 L
.27077 .10191 L
.26769 .10228 L
.26478 .10277 L
.26213 .10334 L
.25567 .10523 L
.24957 .10773 L
.24333 .11106 L
.2376 .11487 L
.22487 .12629 L
.21303 .14119 L
.20087 .16189 L
.19012 .18601 L
.18102 .21213 L
.16614 .27183 L
.16005 .30648 L
.15456 .34749 L
.1523 .36922 L
Mistroke
.15024 .39348 L
.14868 .41691 L
.14808 .42823 L
.14759 .4389 L
.1472 .44934 L
.1469 .45893 L
.14664 .46962 L
.14645 .48115 L
.14635 .4922 L
.14633 .50427 L
.14641 .51567 L
.14656 .52624 L
.14683 .53854 L
.14724 .55179 L
.14773 .56424 L
.14828 .57562 L
.15125 .61913 L
.15331 .64101 L
.15597 .66432 L
.16254 .70873 L
.1701 .74681 L
.17838 .77907 L
.18672 .80493 L
.19635 .82871 L
.20754 .85021 L
.21847 .86621 L
.23071 .87947 L
.23785 .8853 L
.24465 .88971 L
.25067 .89277 L
.25631 .89498 L
.26253 .89675 L
.26603 .89745 L
.26921 .89791 L
.27083 .89809 L
.27256 .89824 L
.27565 .89839 L
.27897 .8984 L
.28086 .89834 L
.28263 .89824 L
.28582 .89795 L
.28874 .89759 L
.29209 .89704 L
.29528 .8964 L
.30676 .89323 L
.31732 .88925 L
.34077 .87756 L
.38416 .85013 L
.42746 .82311 L
.44991 .81213 L
Mistroke
.45953 .80843 L
.46997 .80522 L
.4747 .80406 L
.47975 .80303 L
.4845 .80226 L
.48882 .80174 L
.49135 .80151 L
.49369 .80135 L
.49491 .80129 L
.49626 .80123 L
.49766 .80119 L
.49898 .80117 L
.50139 .80118 L
.50361 .80123 L
.50603 .80134 L
.50726 .80141 L
.50859 .80151 L
.51345 .80199 L
.51619 .80236 L
.51873 .80276 L
.52834 .80478 L
.53714 .80731 L
.54653 .81069 L
.56646 .81985 L
.58912 .83285 L
.6356 .86313 L
.65906 .87747 L
.68156 .88877 L
.69301 .89316 L
.69892 .89497 L
.70532 .89653 L
.70866 .89717 L
.71173 .89765 L
.71466 .89801 L
.71776 .89826 L
.7194 .89835 L
.72116 .8984 L
.72433 .89839 L
.72627 .89831 L
.7281 .89819 L
.72974 .89803 L
.73153 .89782 L
.73448 .89736 L
.73725 .8968 L
.74352 .89504 L
.7496 .89265 L
.7561 .88927 L
.76767 .88091 L
.778 .8705 L
.78897 .8558 L
Mistroke
.80012 .83614 L
.80999 .81368 L
.81831 .79002 L
.82722 .75813 L
.83561 .71904 L
.84221 .67816 L
.84488 .65728 L
.84703 .63765 L
.84885 .61792 L
.85051 .59598 L
.85189 .57236 L
.85238 .56161 L
.85284 .54967 L
.85317 .53865 L
.8534 .52827 L
.85357 .51728 L
.85366 .50542 L
.85366 .49498 L
.85359 .48399 L
.85346 .47462 L
.85324 .4644 L
.85287 .45137 L
.85242 .43913 L
.85129 .41646 L
.84968 .39245 L
.84749 .36704 L
.8424 .32326 L
.83648 .28571 L
.83092 .25776 L
.82422 .23021 L
.81042 .18741 L
.80109 .16584 L
.79171 .14854 L
.773 .12407 L
Mfstroke
0 0 1 r
.5 .80117 m
.50224 .80119 L
.50428 .80125 L
.50664 .80137 L
.50887 .80153 L
.51283 .80192 L
.51714 .8025 L
.5219 .80334 L
.52697 .80443 L
.5361 .80694 L
.55464 .81391 L
.57562 .82413 L
.61881 .84815 L
.63071 .85428 L
.64393 .86024 L
.65005 .8626 L
.6566 .86478 L
.66278 .86647 L
.66849 .86766 L
.67158 .86814 L
.67485 .86853 L
.67655 .86867 L
.67814 .86877 L
.67988 .86883 L
.68175 .86886 L
.68336 .86883 L
.68511 .86876 L
.68676 .86866 L
.68828 .86851 L
.69117 .86814 L
.69424 .86759 L
.69698 .86695 L
.69993 .86609 L
.70526 .86411 L
.71155 .86096 L
.71726 .85727 L
.72727 .84864 L
.7379 .83592 L
.74851 .81871 L
.75783 .79891 L
.76699 .77379 L
.77594 .74181 L
.7833 .70727 L
.78904 .67203 L
.79326 .63779 L
.79679 .59793 L
.79811 .57719 L
.79871 .56561 L
.79918 .55453 L
.79954 .54419 L
Mistroke
.79985 .53288 L
.80005 .52255 L
.80017 .51296 L
.80023 .50127 L
.80022 .49538 L
.80019 .48893 L
.80005 .47752 L
.79985 .46691 L
.79968 .46048 L
.7995 .45442 L
.79909 .4431 L
.79784 .41796 L
.79638 .39643 L
.79473 .37697 L
.78999 .33487 L
.78505 .30245 L
.77862 .26968 L
.77092 .23914 L
.76288 .21413 L
.75402 .19237 L
.74366 .17278 L
.73224 .1568 L
.72661 .15069 L
.72121 .14578 L
.71612 .14192 L
.71056 .13847 L
.70589 .13616 L
.70074 .13416 L
.69512 .1326 L
.69204 .13199 L
.68916 .13158 L
.68646 .13131 L
.684 .13118 L
.68116 .13114 L
.67846 .13121 L
.67581 .13138 L
.67295 .13167 L
.67026 .13204 L
.66778 .13246 L
.66206 .1337 L
.65605 .13538 L
.64482 .13939 L
.63268 .14476 L
.59251 .16656 L
.5699 .17884 L
.54925 .18834 L
.54042 .19164 L
.53117 .19449 L
.52637 .1957 L
.5211 .19681 L
Mistroke
.51633 .19761 L
.51187 .19818 L
.50948 .19841 L
.50727 .19858 L
.50484 .19872 L
.50349 .19877 L
.50226 .1988 L
.5 .19882 L
.49756 .1988 L
.49525 .19872 L
.49313 .19861 L
.49108 .19846 L
.48916 .19829 L
.48479 .19777 L
.48052 .19711 L
.47594 .19622 L
.46544 .19352 L
.45541 .19015 L
.43626 .1819 L
.39839 .1614 L
.37572 .14896 L
.36434 .14336 L
.35375 .13882 L
.34308 .13511 L
.33768 .13364 L
.33175 .13238 L
.32861 .13188 L
.32575 .13153 L
.32417 .13138 L
.32245 .13126 L
.32083 .13118 L
.31934 .13114 L
.31667 .13116 L
.31373 .1313 L
.31066 .1316 L
.3078 .13202 L
.30477 .13262 L
.30148 .13347 L
.29551 .13556 L
.28973 .13831 L
.28443 .14154 L
.27262 .15147 L
.26619 .1587 L
.26049 .16637 L
.2504 .18334 L
.24039 .20547 L
.23248 .22787 L
.22457 .25608 L
.21708 .29064 L
.21041 .33196 L
Mistroke
.20771 .35342 L
.20551 .37445 L
.20371 .39537 L
.20232 .41543 L
.20126 .43498 L
.20083 .44514 L
.20044 .4563 L
.20026 .46263 L
.20012 .46852 L
.19991 .48018 L
.1998 .49081 L
.19977 .50215 L
.1998 .50843 L
.19984 .5142 L
.19992 .52054 L
.20003 .52723 L
.20029 .53845 L
.20068 .55071 L
.20167 .57316 L
.20292 .59379 L
.20627 .63322 L
.21031 .6673 L
.21607 .70388 L
.22254 .73541 L
.22979 .76328 L
.23867 .79005 L
.24878 .81347 L
.25893 .8313 L
.26883 .84443 L
.27821 .85372 L
.28875 .86113 L
.29412 .86384 L
.2972 .8651 L
.30004 .86609 L
.30284 .8669 L
.30593 .86762 L
.30904 .86817 L
.31074 .8684 L
.31233 .86858 L
.31527 .86878 L
.31795 .86885 L
.31943 .86885 L
.32104 .8688 L
.32398 .86863 L
.32685 .86834 L
.32945 .86799 L
.33526 .86692 L
.34063 .86559 L
.34566 .86407 L
.36859 .85462 L
Mistroke
.39259 .84187 L
.43353 .81943 L
.4443 .81438 L
.45564 .80976 L
.46614 .80627 L
.47575 .80382 L
.4805 .80289 L
.48552 .80212 L
.48795 .80183 L
.49055 .80158 L
.49205 .80146 L
.49341 .80137 L
.49471 .8013 L
.49609 .80124 L
.49841 .80118 L
.50056 .80117 L
.50188 .80119 L
.50312 .80121 L
.50544 .8013 L
.5079 .80145 L
.51017 .80164 L
.51529 .80223 L
.51961 .80291 L
.52366 .80369 L
.53292 .80599 L
.54201 .80891 L
.55187 .81273 L
.59226 .83329 L
.6147 .84592 L
.62736 .85261 L
.63947 .85835 L
.65116 .863 L
.66201 .86628 L
.66791 .86755 L
.67089 .86804 L
.67415 .86846 L
.67587 .86862 L
.67744 .86873 L
.67925 .86881 L
.68096 .86885 L
.684 .86881 L
.68572 .86873 L
.6873 .86861 L
.68987 .86833 L
.69263 .8679 L
.69523 .86737 L
.6976 .86678 L
.70338 .86488 L
.70885 .86242 L
.71443 .8592 L
Mistroke
.71956 .85554 L
.73096 .84467 L
.74183 .83014 L
.75297 .80986 L
.76277 .78617 L
.77104 .76043 L
.77834 .73158 L
.78434 .7016 L
.78967 .66747 L
.79434 .62711 L
.79626 .60513 L
.7977 .5843 L
.79892 .56101 L
.79938 .54911 L
.79978 .5359 L
.80002 .52434 L
.80016 .51372 L
.80023 .50203 L
.80022 .49616 L
.80019 .48973 L
.80007 .47887 L
.79985 .4673 L
.79956 .45642 L
.79922 .44657 L
.79826 .42543 L
.79709 .40622 L
.79347 .36422 L
.78922 .32926 L
.7837 .29484 L
.77676 .26157 L
.76956 .23449 L
.76035 .20738 L
.75085 .1858 L
.74156 .16945 L
.73257 .15719 L
.72236 .14676 L
.71654 .14221 L
.71122 .13884 L
.70586 .13614 L
.69994 .1339 L
.69695 .13304 L
.69374 .1323 L
.6907 .13178 L
.68793 .13144 L
.68517 .13123 L
.68262 .13114 L
.67982 .13116 L
.67685 .1313 L
.67427 .13152 L
.67186 .13181 L
Mistroke
.66638 .13273 L
.66015 .1342 L
.65425 .13595 L
.64325 .14003 L
.61901 .15173 L
.57958 .17374 L
.5586 .18432 L
.5401 .19175 L
.53226 .19418 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00g03oool00`3ooml0W4P0000000020000000307Bo
o`3oool0oooo0<`0oooo003N0?ooo`030?noM00007@0_ooo0<l0oooo003N0?ooo`030?oo_`1d0000
M;oo0<l0oooo003N0?ooo`030?oog`2LB000B9cO0<l0oooo003O0?ooo`030=nLB000000000000080
000000<0M;oo0?ooo`3oool00P3oool01@3o_g@000000000000004P0W=oo0080oooo00<0oono07@0
000000000P0000003@18W=l0oooo0?ooo`3oool0_g@00000000004P0W=oo0?ooo`3o_g@000000000
B02Lgol00P3oool0102oM00000000000B02Lgol20?ooo`050?noM000000000000000B02Lgol00`3o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000000007Bo09H0oooo003O0?ooo`070?noM00004P0
W=oo0?ooo`3ooml0W4P0001d_`020?ooo`0?0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`3oool0
oooO09a8001d_ol0oooo0?oOW0180000M;oo0080oooo01L0gia80018W03Ooml0W7BL0=ooo`3o_g@0
001809cOg`2LM9`0gooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0
B000001d_`020?ooo`030?noM00007@0_ooo0080oooo00@0gia80018W03O_g@0M;ooU@3oool00=l0
oooo00<0oono07@0001d_ol00P3oool01`3ooml0W4P004RLg`3oool0gia80018W03Oool00P3oool0
2P3ogi`0B00004RLg`3oool0_gAd0;ooo`3oool0oono07@0001d_ol20?ooo`030?noM00004P0W=oo
0080oooo00<0oono07@0001d_ol00`3oool00`3o_g@0001809cOo`020?ooo`030=nLB000B9`0gooo
0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol0UP3o
ool00=l0oooo00<0oooO09a80018W=l00`3oool01P3ogi`0B01809cOo`3o_g@0001d0;ooo`<0oooo
00<0gia80000M02oool00`3oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo
00<0_g@0001d_`3oool00P3oool00`3ookl0M00004RLg`020?ooo`030?noM00007@0_ooo00<0oooo
00/0gia80000M02oool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`2F0?ooo`00h03oool0
0`3OW4P0001d0;ooo`020?ooo`060?oog`2LB000B9cO0?oo_`1d0000M;oo0`3oool00`3ogi`0B018
09cOo`020?ooo`030?noM00004P0W=oo00@0oooo00<0_g@00018W03Oool00P3oool00`3OW4P004RL
0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3ookl0M00007Boo`030?ooo`070?oOW01804P0W=oo
0?ooo`3OW4P004Q804Qd_`020?ooo`030;md0000M;l0oooo09D0oooo003P0?ooo`040?noM0000000
04RL0=ooo`80oooo00H0gia8001d_`3oool0gia80000M02oool20?ooo`0:0?oo_`1d0000M;oo0?oo
o`3ogi`0B01809cOo`3oool0giad09cOo`80oooo00<0gia80000B02Lgol00P3oool00`3ogi`0B018
09cOo`030?ooo`030=nLB00004P0W=oo0080oooo00<0gia80000M02oool00P3oool0303ookl0M000
07Boo`3oool0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;oooiD0oooo003P0?ooo`080?oo_`1d
0000M9bL04P0M02oool0oooO09a80000M;l20?ooo`0>0;md000007@0_ooo0?ooo`3o_g@0001d0;oo
o`3oool0omnL04P0B02Lgol0oooO09a8001d_ol20?ooo`030?oOW0180000B9cO0080oooo00<0oooO
09a80018W=l00`3oool00`3ogi`0B00004RLg`030?ooo`0@0;md000007@0_ooo0?ooo`3o_g@0001d
0;ooo`3oool0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOoiD0oooo003O0?ooo`090?oOW018
0000000004RLg`3ookl0M0000000000007@0_ooo00<0oooo00D0okmd000000000000000007Boo`03
0?ooo`070;md00000000000000000018W=l0oooo0?noM002000000040018W03Oool0oono07@000<0
000000H0M;oo0?noM000000000000018W03Oool30?ooo`0?0?noM000000000000000001d_ol0oooo
0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo09D0oooo003o0?ooo`40oooo00<0okmd
0000M02oool0[@3oool00?l0oooo0P3oool00`3OW7@0W=oo0?ooo`2/0?ooo`00n`3oool0103ookl0
M0000018W03Oool70?ooo`040?oo_`1d000004RL0=ooojH0oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo001m0?ooo`030=nLB0000000000000<0000000<0B9cO0?ooo`3oool0=`3o
ool00`3ookl0M000000000020000000304RLg`3oool0oooo03<0oooo00@0_g@0000000000000M;oo
>P3oool00`3ookl0M000000000020000000304RLg`3oool0oooo03P0oooo00<0gia8000000000000
0`0000000`18W=l0oooo0?ooo`0a0?ooo`00OP3oool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02o
ool0oooo03T0oooo00<0okmd0000001d_ol0=@3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLgc/0
oooo00<0okmd0000001d_ol0?03oool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02oool0oooo0340
oooo001o0?ooo`030?noM000M;l0oooo03d0oooo00<0oooO09a80000M;l0=03oool00`3ooml0W4P0
04RLg`020?ooo`030?noM00004P0W=oo03X0oooo00<0oooO09a80000M;l0?@3oool00`3o_g@007Bo
0?ooo`0e0?ooo`00P03oool00`3o_g@007Bo0?ooo`0m0?ooo`030=nLB000B9`0gooo03<0oooo00<0
oooO09a80018W=l00P3oool0103ooml0W4P00018W03Ooolj0?ooo`030=nLB000B9`0gooo03d0oooo
00<0okmd001d_`3oool0=03oool00700oooo00<0oooO09a8000000001`0000000`18W=l0oooo0?oo
o`040?ooo`030?noM018W=l0oooo02`0oooo00<0oooO09a8000000001`0000000`18W=l0oooo0?oo
o`030?ooo`030?oOW01804P0W=oo03<0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cO
o`0j0?ooo`030?oOW01804P0W=oo03h0oooo00<0okmd04RLg`3oool0<`3oool00880oooo00<0gia8
04RLg`3oool0>`3oool00`3ookl0M00007Boo`0d0?ooo`030;md0000B9`0gooo0080oooo00<0omnL
04P00018W=l0>P3oool00`3ookl0M00007Boo`0o0?ooo`030=nLB018W=l0oooo0380oooo00230?oo
o`030;md001d_ol0oooo03/0oooo00<0_g@0001d_`3oool0<`3oool00`3OW4P0001809cOo`020?oo
o`030?oog`2LB00007Bo03/0oooo00<0_g@0001d_`3oool0?`3oool00`2oM000M;oo0?ooo`0a0?oo
o`00P`3oool00`3ogi`0B01d0;ooo`0k0?ooo`030=nLB000B9`0gooo03<0oooo00<0omnL04P00018
W=l00`3oool00`2oM00004RL0=ooo`0j0?ooo`030=nLB000B9`0gooo03l0oooo00<0omnL04P0M02o
ool0<@3oool008<0oooo00<0oooO09a8001d_ol0>`3oool00`3ogi`0B01809cOo`0c0?ooo`040?oo
g`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0>P3oool00`3ogi`0B01809cOo`0o0?ooo`03
0?oog`2LB000M;oo0340oooo00230?ooo`030?oo_`1d0000B9cO03/0oooo00<0oono07@0001d_ol0
=03oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo03X0oooo00<0oono07@0001d_ol0
?`3oool00`3ookl0M00004RLg`0a0?ooo`00O`3oool01`3o_g@004RL0=ooo`3oool0gia80000B02L
gol0?03oool00`2oM00007Bo0?ooo`0d0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO?03oool0
0`2oM00007Bo0?ooo`0j0?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cOo`0a0?ooo`00P03o
ool01@3ogi`0B000000000000000M;oo03/0oooo00D0oono07@000000000001d0;ooo`0e0?ooo`04
0=nLB00000000000001d_c/0oooo00D0oono07@000000000001d0;ooo`0k0?ooo`050?oOW0180000
00000000001d_ol0<P3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool004/0ooooo`00001R000000@0oooo001;0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool0[@3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo0:d0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool00P3o
ool004/0oooo0P00002^0?ooo`030000003oool0oooo0:/0oooo0`0000040?ooo`00B`3oool00`00
0000oooo0?ooo`2]0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool0>`3oool7003o06/0oooo00<000000?ooo`3oool0J03oool7003o03h0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0=`3oool4003o00L0oooo
1@00o`1V0?ooo`030000003oool0oooo0680oooo1P00o`070?ooo`@00?l0>P3oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0e0?ooo`800?l0403oool4003o0680oooo00<0
00000?ooo`3oool0G`3oool3003o0140oooo1000o`0f0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo0380oooo0`00o`0F0?ooo`<00?l0G`3oool00`000000oooo0?ooo`1L
0?ooo`<00?l0603oool2003o03@0oooo00<000000?ooo`3oool00P3oool002d0oooo00<0oono07@0
000000000P0000001`18W=l0oooo0?ooo`3oool0omnL04P0001d_ol00P3oool01P3ogi`0B0000000
0000000004RL0=ooo`X0oooo00<000000?ooo`3oool0<03oool2003o01`0oooo0P00o`1M0?ooo`03
0000003oool0oooo05X0oooo0P00o`0M0?ooo`800?l0<P3oool00`000000oooo0?ooo`020?ooo`00
;`3oool00`3o_g@0000007Boo`040?ooo`030?oOW0180000M;oo0080oooo00H0okmd0000001d_ol0
oooo0?oOW018M;l:0?ooo`030000003oool0oooo02h0oooo0P00o`0P0?ooo`800?l0F`3oool00`00
0000oooo0?ooo`1H0?ooo`800?l08@3oool00`00o`00oooo0?ooo`0_0?ooo`030000003oool0oooo
0080oooo000_0?ooo`030?oog`2LB00007Bo00h0oooo00<0okmd04RLg`3oool0203oool00`000000
oooo0?ooo`0]0?ooo`03003o003oool0oooo0280oooo00<00?l00?ooo`3oool0F03oool00`000000
oooo0?ooo`1F0?ooo`800?l0903oool00`00o`00oooo0?ooo`0^0?ooo`030000003oool0oooo0080
oooo000`0?ooo`030=nLB000B9`0gooo00d0oooo00<0oono07@0M02oool0203oool00`000000oooo
0?ooo`0/0?ooo`03003o003oool0oooo02@0oooo0P00o`1H0?ooo`030000003oool0oooo05D0oooo
00<00?l00?ooo`3oool09@3oool00`00o`00oooo0?ooo`0]0?ooo`030000003oool0oooo0080oooo
000P0?ooo`030?oog`2LB000000000L0000000<0B9cO0?ooo`3oool00`3oool00`3ogi`0B01809cO
o`0=0?ooo`030?oog`2LB000M;oo00P0oooo00<000000?ooo`3oool0:P3oool2003o02T0oooo0P00
o`1F0?ooo`030000003oool0oooo05<0oooo0P00o`0Y0?ooo`03003o003oool0oooo02`0oooo00<0
00000?ooo`3oool00P3oool00300oooo00<0oono07@0001d_ol03@3oool00`3ookl0M00004RLg`08
0?ooo`<00000:@3oool00`00o`00oooo0?ooo`0[0?ooo`800?l0E03oool00`000000oooo0?ooo`1A
0?ooo`800?l0;03oool00`00o`00oooo0?ooo`0X0?ooo`@00000103oool00340oooo00<0_g@0001d
_`3oool0303oool00`3o_g@0000007Boo`080?ooo`030000003oool0oooo02P0oooo00<00?l00?oo
o`3oool0;P3oool2003o0580oooo00<000000?ooo`3oool0D03oool00`00o`00oooo0?ooo`0]0?oo
o`800?l0:`3oool00`000000oooo0?ooo`020?ooo`00<@3oool00`3OW4P004RL0=ooo`090?ooo`06
0?oOg`3Oool0okmd0000000007@0_ooo203oool00`000000oooo0?ooo`0W0?ooo`03003o003oool0
oooo0340oooo00<00?l00?ooo`3oool0C`3oool00`000000oooo0?ooo`1?0?ooo`03003o003oool0
oooo0300oooo00<00?l00?ooo`3oool0:03oool00`000000oooo0?ooo`020?ooo`00<@3oool00`3o
gi`0B01809cOo`090?ooo`050?oo_`1d000000000000B02Lgol02@3oool00`000000oooo0?ooo`0V
0?ooo`03003o003oool0oooo03<0oooo0P00o`1?0?ooo`030000003oool0oooo04d0oooo0P00o`0d
0?ooo`03003o003oool0oooo02L0oooo00<000000?ooo`3oool00P3oool00340oooo00<0oono07@0
001d_ol02P3oool00`3OW9`0_ooo0?ooo`0:0?ooo`030000003oool0oooo02D0oooo00<00?l00?oo
o`3oool0=P3oool00`00o`00oooo0?ooo`1<0?ooo`030000003oool0oooo04`0oooo00<00?l00?oo
o`3oool0=@3oool00`00o`00oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo000b0?ooo`03
0;md0000M;l0oooo00T0oooo00<0omnL07BLg`3oool02P3oool00`000000oooo0?ooo`0T0?ooo`03
003o003oool0oooo03P0oooo0P00o`1<0?ooo`030000003oool0oooo04/0oooo00<00?l00?ooo`3o
ool0=`3oool00`00o`00oooo0?ooo`0U0?ooo`030000003oool0oooo0080oooo000`0?ooo`050?oo
_`1d000000000000M02oool02P3oool01@2oM0000000000000000000B9cO00L0oooo00<000000?oo
o`3oool0903oool00`00o`00oooo0?ooo`0j0?ooo`03003o003oool0oooo04T0oooo00<000000?oo
o`3oool0B@3oool2003o03X0oooo00<00?l00?ooo`3oool09@3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`0S0?ooo`03003o003oool0oooo03`0oooo00<00?l00?ooo`3o
ool0B03oool00`000000oooo0?ooo`180?ooo`03003o003oool0oooo03/0oooo00<00?l00?ooo`3o
ool0903oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0S0?ooo`03003o
003oool0oooo03d0oooo0P00o`180?ooo`030000003oool0oooo04L0oooo00<00?l00?ooo`3oool0
?@3oool00`00o`00oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo0280oooo00<00?l00?ooo`3oool0@03oool00`00o`00oooo0?ooo`150?ooo`030000003o
ool0oooo04H0oooo00<00?l00?ooo`3oool0?`3oool00`00o`00oooo0?ooo`0R0?ooo`030000003o
ool0oooo0080oooo001;0?ooo`030000003oool0oooo0280oooo00<00?l00?ooo`3oool0@@3oool0
0`00o`00oooo0?ooo`140?ooo`030000003oool0oooo04@0oooo0P00o`120?ooo`03003o003oool0
oooo0280oooo00<000000?ooo`3oool00P3oool004/0oooo0P00000R0?ooo`03003o003oool0oooo
04<0oooo00<00?l00?ooo`3oool0@`3oool00`000000oooo0?ooo`130?ooo`03003o003oool0oooo
04<0oooo00<00?l00?ooo`3oool07`3oool3000000@0oooo001;0?ooo`030000003oool0oooo0200
oooo00<00?l00?ooo`3oool0A@3oool2003o04<0oooo00<000000?ooo`3oool0@P3oool00`00o`00
oooo0?ooo`140?ooo`03003o003oool0oooo0240oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool07`3oool00`00o`00oooo0?ooo`180?ooo`03003o003oool0oooo0400oooo
00<000000?ooo`3oool0@03oool2003o04P0oooo00<00?l00?ooo`3oool0803oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0O0?ooo`03003o003oool0oooo04T0oooo00<0
0?l00?ooo`3oool0?`3oool00`000000oooo0?ooo`0o0?ooo`03003o003oool0oooo04P0oooo00<0
0?l00?ooo`3oool0803oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0N
0?ooo`03003o003oool0oooo04/0oooo00<00?l00?ooo`3oool0?P3oool00`000000oooo0?ooo`0n
0?ooo`03003o003oool0oooo04X0oooo00<00?l00?ooo`3oool07`3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`0M0?ooo`03003o003oool0oooo04d0oooo0P00o`0n0?oo
o`030000003oool0oooo03d0oooo00<00?l00?ooo`3oool0B`3oool00`00o`00oooo0?ooo`0O0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01d0oooo00<00?l00?ooo`3o
ool0C`3oool00`00o`00oooo0?ooo`0k0?ooo`030000003oool0oooo03/0oooo0P00o`1?0?ooo`03
003o003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
703oool00`00o`00oooo0?ooo`1A0?ooo`03003o003oool0oooo03X0oooo00<000000?ooo`3oool0
>P3oool00`00o`00oooo0?ooo`1?0?ooo`03003o003oool0oooo01h0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool0703oool00`00o`00oooo0?ooo`0j0?ooo`d0o`002`3o
ool00`00o`00oooo0?ooo`0i0?ooo`030000003oool0oooo03T0oooo00<00?l00?ooo`3oool02@3o
ool=0?l003/0oooo00<00?l00?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`0K0?ooo`03003o003oool0oooo03T0oooo0P3o000=0?ooo`80o`002P3oool2
003o03T0oooo00<000000?ooo`3oool0>03oool00`00o`00oooo0?ooo`050?ooo`D0o`003@3oool2
0?l003T0oooo00<00?l00?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`00B`3oool20000
01`0oooo00<00?l00?ooo`3oool0=P3oool30?l00140oooo103o00080?ooo`03003o003oool0oooo
03H0oooo00<000000?ooo`3oool0=P3oool2003o00H0oooo0P3o000D0?ooo`030?l0003oool0oooo
03L0oooo00<00?l00?ooo`3oool06P3oool3000000@0oooo001;0?ooo`030000003oool0oooo01X0
oooo00<00?l00?ooo`3oool0=@3oool20?l001P0oooo0`3o00060?ooo`03003o003oool0oooo03D0
oooo00<000000?ooo`3oool0=@3oool00`00o`00oooo0?ooo`040?ooo`80o`005`3oool20?l003L0
oooo00<00?l00?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`0J0?ooo`03003o003oool0oooo03<0oooo0P3o000M0?ooo`80o`001@3oool00`00o`00oooo
0?ooo`0d0?ooo`030000003oool0oooo03@0oooo00<00?l00?ooo`3oool00`3oool20?l001/0oooo
0P3o000f0?ooo`03003o003oool0oooo01/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool06@3oool00`00o`00oooo0?ooo`0c0?ooo`030?l0003oool0oooo01l0oooo0P3o
00040?ooo`800?l0=03oool00`000000oooo0?ooo`0b0?ooo`800?l0103oool20?l001l0oooo0P3o
000d0?ooo`03003o003oool0oooo01/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool06@3oool00`00o`00oooo0?ooo`0b0?ooo`030?l0003oool0oooo0280oooo00<0o`00
0?ooo`3oool00`3oool00`00o`00oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo00<00?l0
0?ooo`3oool00P3oool20?l002<0oooo00<0o`000?ooo`3oool0<P3oool00`00o`00oooo0?ooo`0J
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01T0oooo00<00?l00?oo
o`3oool0<@3oool00`3o0000oooo0?ooo`0T0?ooo`80o`00103oool00`00o`00oooo0?ooo`0`0?oo
o`030000003oool0oooo0300oooo00@00?l00?ooo`3oool0oooo0P3o000V0?ooo`030?l0003oool0
oooo0340oooo00<00?l00?ooo`3oool06P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`00
0000oooo0?ooo`0H0?ooo`03003o003oool0oooo0340oooo00<0o`000?ooo`3oool09`3oool00`3o
0000oooo0?ooo`020?ooo`03003o003oool0oooo02l0oooo00<000000?ooo`3oool0;`3oool01@00
o`00oooo0?ooo`3oool0o`0002T0oooo00<0o`000?ooo`3oool0<@3oool00`00o`00oooo0?ooo`0I
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01P0oooo00<00?l00?oo
o`3oool0<03oool00`3o0000oooo0?ooo`0Y0?ooo`80o`000`3oool00`00o`00oooo0?ooo`0^0?oo
o`030000003oool0oooo02d0oooo0P00o`020?ooo`80o`00:`3oool00`3o0000oooo0?ooo`0`0?oo
o`03003o003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool0603oool00`00o`00oooo0?ooo`0`0?ooo`030?l0003oool0oooo01/0oooo20000?l80?ooo`80
o`000P3oool2003o02h0oooo00<000000?ooo`3oool0;03oool00`00o`00oooo0?ooo`020?l000P0
oooo2@000?lL0?ooo`80o`00<P3oool00`00o`00oooo0?ooo`0H0?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo01L0oooo00<00?l00?ooo`3oool0<03oool00`3o0000oooo
0?ooo`0J0?ooo`80003o203oool60000o`@0oooo0P3o00020?ooo`03003o003oool0oooo02/0oooo
00<000000?ooo`3oool0:`3oool01000o`00oooo0?ooo`3o00060?ooo`@0003o203oool30000oa/0
oooo00<0o`000?ooo`3oool0<03oool00`00o`00oooo0?ooo`0H0?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo01L0oooo00<00?l00?ooo`3oool0;`3oool00`3o0000oooo
0?ooo`0I0?ooo`80003o403oool20000o`@0oooo0P3o00000`3oool00?l00?ooo`0[0?ooo`030000
003oool0oooo02T0oooo0P00o`000`3oool0o`000?l000040?ooo`@0003o3P3oool20000oaX0oooo
00<0o`000?ooo`3oool0;`3oool00`00o`00oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo
001;0?ooo`8000005`3oool00`00o`00oooo0?ooo`0`0?ooo`030?l0003oool0oooo01L0oooo0P00
0?lD0?ooo`80003o103oool20?l00003003o003oool0oooo02T0oooo00<000000?ooo`3oool0:03o
ool01000o`00oooo0?ooo`3o00030?ooo`@0003o4`3oool20000oaT0oooo00<0o`000?ooo`3oool0
;`3oool00`00o`00oooo0?ooo`0E0?ooo`<00000103oool004/0oooo00<000000?ooo`3oool05P3o
ool00`00o`00oooo0?ooo`0_0?ooo`030?l0003oool0oooo01H0oooo0P000?lH0?ooo`<0003o0`3o
ool00`3o00000?l0003o000Y0?ooo`030000003oool0oooo02L0oooo00@00?l00?ooo`3o0000o`00
0P3oool20000oaT0oooo0P000?lG0?ooo`80o`00<03oool00`00o`00oooo0?ooo`0G0?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01H0oooo00<00?l00?ooo`3oool0;P3o
ool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo01/0oooo0P000?l20?ooo`80o`0000<0
0?l00?ooo`3oool09P3oool00`000000oooo0?ooo`0U0?ooo`800?l00P3o00020?ooo`80003o7@3o
ool20000oaH0oooo00<0o`000?ooo`3oool0;`3oool00`00o`00oooo0?ooo`0F0?ooo`030000003o
ool0oooo0080oooo001;0?ooo`030000003oool0oooo01D0oooo00<00?l00?ooo`3oool0;`3oool0
0`3o0000oooo0?ooo`0D0?ooo`80003o803oool20000o`80oooo00<0o`00003o003oool09P3oool0
0`000000oooo0?ooo`0T0?ooo`03003o003oool0o`000080oooo0P000?lP0?ooo`030000o`3oool0
oooo01D0oooo00<0o`000?ooo`3oool0;P3oool00`00o`00oooo0?ooo`0F0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo01D0oooo00<00?l00?ooo`3oool0;P3oool00`3o
0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo0280oooo0P000?l0103oool0o`00003o0000o`0U
0?ooo`030000003oool0oooo02<0oooo00@00?l00?ooo`3o0000oooo0P000?lS0?ooo`030000o`3o
ool0oooo01D0oooo00<0o`000?ooo`3oool0;@3oool00`00o`00oooo0?ooo`0F0?ooo`030000003o
ool0oooo0080oooo001;0?ooo`030000003oool0oooo01D0oooo00<00?l00?ooo`3oool0;P3oool0
0`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo02D0oooo00D0003o0?ooo`3o0000o`00003o
000T0?ooo`030000003oool0oooo0240oooo0P00o`020?l00080003o9P3oool20000oaD0oooo00<0
o`000?ooo`3oool0;P3oool00`00o`00oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo01@0oooo00<00?l00?ooo`3oool0;P3oool00`3o0000oooo0?ooo`0D
0?ooo`030000o`3oool0oooo02H0oooo0P000?l0103oool0o`00003o0000o`0R0?ooo`030000003o
ool0oooo0200oooo00<00?l00?ooo`3o00000P000?lY0?ooo`80003o5@3oool00`3o0000oooo0?oo
o`0]0?ooo`03003o003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool0503oool00`00o`00oooo0?ooo`0^0?ooo`030?l0003oool0oooo01<0oooo00<0003o
0?ooo`3oool0:@3oool20000o`80o`0000<00?l00?ooo`3oool07`3oool00`000000oooo0?ooo`0O
0?ooo`03003o003oool0003o0080003o:`3oool20000oa@0oooo0P3o000^0?ooo`03003o003oool0
oooo01D0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0503oool00`00
o`00oooo0?ooo`0]0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0;03oool01000
0?l0oooo0?l00000o`0P0?ooo`030000003oool0oooo01d0oooo0P00o`000`3o0000003o0000o`0]
0?ooo`80003o5@3oool00`3o0000oooo0?ooo`0]0?ooo`03003o003oool0oooo01@0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0503oool00`00o`00oooo0?ooo`0/0?oo
o`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0;P3oool20000o`80o`0000<00?l00?oo
o`3oool0703oool00`000000oooo0?ooo`0L0?ooo`04003o003oool0003o0000oc00oooo0P000?lD
0?ooo`80o`00;P3oool00`00o`00oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo001;0?oo
o`800000503oool00`00o`00oooo0?ooo`0]0?ooo`030?l0003oool0oooo0180oooo00<0003o0?oo
o`3oool0<@3oool20000o`030?l00000o`00oooo01`0oooo00<000000?ooo`3oool06P3oool2003o
0080003o<`3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo02`0oooo00<00?l00?oo
o`3oool04P3oool3000000@0oooo001;0?ooo`030000003oool0oooo01<0oooo00<00?l00?ooo`3o
ool0;03oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo03<0oooo0P000?l00`3o0000
0?l00?ooo`0J0?ooo`030000003oool0oooo01T0oooo00@00?l00000o`000?l0003o=03oool20000
oa@0oooo0P3o000]0?ooo`03003o003oool0oooo01@0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool04`3oool00`00o`00oooo0?ooo`0/0?ooo`030?l0003oool0oooo0180
oooo00<0003o0?ooo`3oool0=P3oool20000o`030?l0003oool0oooo01P0oooo00<000000?ooo`3o
ool05`3oool01000o`00o`000000o`000?lg0?ooo`80003o503oool00`3o0000oooo0?ooo`0/0?oo
o`03003o003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool04`3oool00`00o`00oooo0?ooo`0[0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3o
ool0>@3oool20000o`030?l0003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool01000o`00
o`000000o`000?lj0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool0;03oool00`00
o`00oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0180
oooo00<00?l00?ooo`3oool0;03oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo03/0
oooo0P000?l00`3o0000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo0`000?ll0?ooo`80
003o4`3oool20?l002d0oooo00<00?l00?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0B0?ooo`03003o003oool0oooo02/0oooo00<0o`000?ooo`3oool0
4P3oool00`000?l0oooo0?ooo`0n0?ooo`80003o00<0o`000?ooo`3oool04P3oool00`000000oooo
0?ooo`0B0?ooo`<0003o?`3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo02/0oooo
00<00?l00?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`00>`3oool00`3ookl0M0000000
00020000000304RLg`3oool0oooo00P0oooo00<000000?ooo`3oool04P3oool00`00o`00oooo0?oo
o`0[0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0@@3oool20000o`030?l0003o
ool0oooo0100oooo00<000000?ooo`3oool0403oool30000od40oooo0P000?lC0?ooo`80o`00;@3o
ool00`00o`00oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo000m0?ooo`030?noM0000000
M;oo00/0oooo00<000000?ooo`3oool04P3oool00`00o`00oooo0?ooo`0[0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool0@`3oool20000o`030?l0003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool30000odD0oooo00<0003o0?ooo`3oool04@3oool20?l002d0oooo00<00?l0
0?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`00?@3oool00`3ooml0W4P0001d_`0;0?oo
o`030000003oool0oooo0180oooo00<00?l00?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo04H0oooo0`000?l00`00o`00oooo0?ooo`0;0?ooo`030000003oool0oooo
00X0oooo0`000?l00`00o`00oooo0?ooo`150?ooo`80003o4`3oool00`3o0000oooo0?ooo`0[0?oo
o`03003o003oool0oooo0180oooo00<000000?ooo`3oool00P3oool003h0oooo00<0gia80018W03O
ool02P3oool00`000000oooo0?ooo`0A0?ooo`03003o003oool0oooo02/0oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`190?ooo`@0003o00<00?l00?ooo`3oool01`3oool00`000000
oooo0?ooo`060?ooo`80o`000P000?l2003o04X0oooo00<0003o0?ooo`3oool04@3oool20?l002`0
oooo00<00?l00?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`00;P3oool00`3ooml0W4P0
000000070000000304RLg`3oool0oooo00<0oooo00<0omnL04P0B02Lgol02P3oool00`000000oooo
0?ooo`0A0?ooo`03003o003oool0oooo02/0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`1=0?ooo`030?l000000?l0003o00<0003o1@3oool00`000000oooo0?ooo`020?ooo`H0003o
CP3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo02/0oooo00<00?l00?ooo`3oool0
4@3oool00`000000oooo0?ooo`020?ooo`00?P3oool00`3ookl0M00007Boo`0:0?ooo`<000004@3o
ool00`00o`00oooo0?ooo`0Z0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0DP3o
ool00`00o`00003o0000o`080000o`030?l0003oool0oooo0580oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0[0?ooo`03003o003oool0oooo00h0oooo100000040?ooo`00?`3oool0
0`2oM00007Bo0?ooo`090?ooo`030000003oool0oooo0140oooo00<00?l00?ooo`3oool0:P3oool0
0`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo05T0oooo00<000000?ooo`3oool0E`3oool0
0`000?l0oooo0?ooo`0A0?ooo`80o`00;03oool00`00o`00oooo0?ooo`0A0?ooo`030000003oool0
oooo0080oooo000o0?ooo`030=nLB000B9`0gooo00T0oooo00<000000?ooo`3oool0403oool00`00
o`00oooo0?ooo`0[0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0F@3oool00`00
0000oooo0?ooo`1H0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0:`3oool00`00
o`00oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo000o0?ooo`030?oOW01804P0W=oo00T0
oooo00<000000?ooo`3oool0403oool00`00o`00oooo0?ooo`0[0?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool0F@3oool00`000000oooo0?ooo`1H0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool0:`3oool00`00o`00oooo0?ooo`0@0?ooo`030000003oool0oooo0080
oooo000o0?ooo`030?oo_`1d0000M;oo00T0oooo00<000000?ooo`3oool0403oool00`00o`00oooo
0?ooo`0Z0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0FP3oool00`000000oooo
0?ooo`1H0?ooo`80003o4P3oool20?l002`0oooo00<00?l00?ooo`3oool0403oool00`000000oooo
0?ooo`020?ooo`00@03oool00`2oM00007Bo0?ooo`080?ooo`030000003oool0oooo0100oooo00<0
0?l00?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo05X0oooo00<0
00000?ooo`3oool0F@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo02X0oooo00<0
0?l00?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`00?P3oool01@3ookl0M00000000000
07@0_ooo00P0oooo00<000000?ooo`3oool03`3oool00`00o`00oooo0?ooo`0[0?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`3oool0FP3oool00`000000oooo0?ooo`1I0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool0:`3oool00`00o`00oooo0?ooo`0?0?ooo`030000003o
ool0oooo0080oooo001;0?ooo`030000003oool0oooo00l0oooo00<00?l00?ooo`3oool0:P3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo05X0oooo00<000000?ooo`3oool0FP3oool0
0`000?l0oooo0?ooo`0@0?ooo`80o`00;03oool00`00o`00oooo0?ooo`0?0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo00l0oooo00<00?l00?ooo`3oool0:P3oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo05/0oooo00<000000?ooo`3oool0FP3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo02X0oooo00<00?l00?ooo`3oool03`3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0?0?ooo`03003o003oool0oooo02X0
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1K0?ooo`030000003oool0oooo05X0
oooo0P000?lB0?ooo`030?l0003oool0oooo02X0oooo00<00?l00?ooo`3oool03`3oool00`000000
oooo0?ooo`020?ooo`00B`3oool200000100oooo00<00?l00?ooo`3oool0:P3oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo05/0oooo00<000000?ooo`3oool0F`3oool00`000?l0oooo
0?ooo`0@0?ooo`80o`00;03oool00`00o`00oooo0?ooo`0<0?ooo`<00000103oool004/0oooo00<0
00000?ooo`3oool03P3oool00`00o`00oooo0?ooo`0Z0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool0F`3oool00`000000oooo0?ooo`1K0?ooo`80003o4P3oool00`3o0000oooo0?oo
o`0Z0?ooo`03003o003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool03P3oool00`00o`00oooo0?ooo`0Z0?ooo`030?l0003oool0oooo0100oooo00<0003o
0?ooo`3oool0G03oool00`000000oooo0?ooo`1K0?ooo`80003o4P3oool00`3o0000oooo0?ooo`0Z
0?ooo`03003o003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool03P3oool00`00o`00oooo0?ooo`0Z0?ooo`030?l0003oool0oooo0100oooo00<0003o0?oo
o`3oool0G03oool00`000000oooo0?ooo`1L0?ooo`030000o`3oool0oooo0100oooo00<0o`000?oo
o`3oool0:P3oool00`00o`00oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo00h0oooo00<00?l00?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo05`0oooo00<000000?ooo`3oool0G03oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo02T0oooo00<00?l00?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0>0?ooo`03003o003oool0oooo02T0oooo00<0o`000?ooo`3oool0
403oool00`000?l0oooo0?ooo`1M0?ooo`030000003oool0oooo05`0oooo0P000?lB0?ooo`030?l0
003oool0oooo02X0oooo00<00?l00?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`0=0?ooo`03003o003oool0oooo02X0oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`1M0?ooo`030000003oool0oooo05d0oooo00<0003o0?ooo`3oool0403o
ool00`3o0000oooo0?ooo`0Z0?ooo`03003o003oool0oooo00d0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool03@3oool00`00o`00oooo0?ooo`0Z0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool0G@3oool00`000000oooo0?ooo`1M0?ooo`030000o`3oool0
oooo0100oooo00<0o`000?ooo`3oool0:P3oool00`00o`00oooo0?ooo`0=0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo00d0oooo00<00?l00?ooo`3oool0:@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo05d0oooo00<000000?ooo`3oool0G@3oool00`00
0?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02X0oooo00<00?l00?ooo`3oool03@3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0=0?ooo`03003o003oool0oooo02T0
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1N0?ooo`030000003oool0oooo05d0
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0Y0?ooo`03003o003oool0oooo00d0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool03@3oool00`00o`00oooo
0?ooo`0Y0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0GP3oool00`000000oooo
0?ooo`1N0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0:@3oool00`00o`00oooo
0?ooo`0=0?ooo`030000003oool0oooo0080oooo001;0?ooo`8000003@3oool00`00o`00oooo0?oo
o`0Y0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0GP3oool00`000000oooo0?oo
o`1N0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0:P3oool00`00o`00oooo0?oo
o`0:0?ooo`<00000103oool004/0oooo00<000000?ooo`3oool0303oool00`00o`00oooo0?ooo`0Y
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0G`3oool00`000000oooo0?ooo`1N
0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0:P3oool00`00o`00oooo0?ooo`0<
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00`0oooo00<00?l00?oo
o`3oool0:@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo05l0oooo00<000000?oo
o`3oool0GP3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02X0oooo00<00?l00?oo
o`3oool0303oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0<0?ooo`03
003o003oool0oooo02T0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1O0?ooo`03
0000003oool0oooo05h0oooo0P000?lA0?ooo`80o`00:`3oool00`00o`00oooo0?ooo`0<0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00`0oooo00<00?l00?ooo`3oool0
:03oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo05l0oooo00<000000?ooo`3oool0
GP3oool20000oa80oooo00<0o`000?ooo`3oool0:@3oool00`00o`00oooo0?ooo`0<0?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00/0oooo00<00?l00?ooo`3oool0:@3o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0600oooo00<000000?ooo`3oool0G`3o
ool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02T0oooo00<00?l00?ooo`3oool0303o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0;0?ooo`03003o003oool0
oooo02T0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1P0?ooo`030000003oool0
oooo05l0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0Y0?ooo`03003o003oool0
oooo00`0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02`3oool00`00
o`00oooo0?ooo`0Y0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0H03oool00`00
0000oooo0?ooo`1O0?ooo`80003o4@3oool20?l002/0oooo00<00?l00?ooo`3oool02`3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0;0?ooo`03003o003oool0oooo02P0
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`1P0?ooo`030000003oool0oooo05l0
oooo0P000?lA0?ooo`80o`00:`3oool00`00o`00oooo0?ooo`0;0?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo00/0oooo00<00?l00?ooo`3oool0:03oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo0640oooo00<000000?ooo`3oool0G`3oool20000oa80oooo
00<0o`000?ooo`3oool0:@3oool00`00o`00oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo00X0oooo00<00?l00?ooo`3oool0:@3oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo0640oooo00<000000?ooo`3oool0G`3oool20000oa80oooo00<0
o`000?ooo`3oool0:@3oool00`00o`00oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo001;
0?ooo`8000002`3oool00`00o`00oooo0?ooo`0Y0?ooo`030?l0003oool0oooo0100oooo00<0003o
0?ooo`3oool0H@3oool00`000000oooo0?ooo`1P0?ooo`030000o`3oool0oooo0100oooo00<0o`00
0?ooo`3oool0:@3oool00`00o`00oooo0?ooo`090?ooo`<00000103oool004/0oooo00<000000?oo
o`3oool02P3oool00`00o`00oooo0?ooo`0Y0?ooo`030?l0003oool0oooo0100oooo00<0003o0?oo
o`3oool0H@3oool00`000000oooo0?ooo`1P0?ooo`030000o`3oool0oooo0100oooo00<0o`000?oo
o`3oool0:@3oool00`00o`00oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo00X0oooo00<00?l00?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo0640oooo00<000000?ooo`3oool0H03oool20000oa40oooo0P3o000Z0?ooo`03
003o003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
2P3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
H@3oool00`000000oooo0?ooo`1P0?ooo`80003o4P3oool00`3o0000oooo0?ooo`0X0?ooo`03003o
003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02@3o
ool00`00o`00oooo0?ooo`0Y0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0HP3o
ool00`000000oooo0?ooo`1P0?ooo`80003o4P3oool00`3o0000oooo0?ooo`0Y0?ooo`03003o003o
ool0oooo00X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02@3oool0
0`00o`00oooo0?ooo`0Y0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0HP3oool0
0`000000oooo0?ooo`1P0?ooo`80003o4P3oool00`3o0000oooo0?ooo`0Y0?ooo`03003o003oool0
oooo00X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02@3oool00`00
o`00oooo0?ooo`0Y0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0HP3oool00`00
0000oooo0?ooo`1Q0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0:@3oool00`00
o`00oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00T0
oooo00<00?l00?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0680
oooo00<000000?ooo`3oool0H@3oool00`000?l0oooo0?ooo`0@0?ooo`80o`00:P3oool00`00o`00
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00T0oooo
00<00?l00?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0680oooo
00<000000?ooo`3oool0H@3oool20000oa40oooo0P3o000Z0?ooo`03003o003oool0oooo00X0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02@3oool00`00o`00oooo0?oo
o`0Y0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0HP3oool00`000000oooo0?oo
o`1Q0?ooo`80003o4P3oool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo00X0oooo00<0
00000?ooo`3oool00P3oool004/0oooo0P00000:0?ooo`03003o003oool0oooo02P0oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`1R0?ooo`030000003oool0oooo0640oooo0P000?lB
0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?ooo`3oool0203oool3000000@0oooo001;0?oo
o`030000003oool0oooo00T0oooo00<00?l00?ooo`3oool0:03oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0680oooo00<000000?ooo`3oool0H@3oool20000oa80oooo00<0o`000?oo
o`3oool0:03oool00`00o`00oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo00T0oooo00<00?l00?ooo`3oool0:03oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo06<0oooo00<000000?ooo`3oool0HP3oool00`000?l0oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo02T0oooo00<00?l00?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`090?ooo`03003o003oool0oooo02P0oooo00<0o`000?ooo`3oool0
403oool00`000?l0oooo0?ooo`1S0?ooo`030000003oool0oooo0680oooo00<0003o0?ooo`3oool0
403oool20?l002X0oooo00<00?l00?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`080?ooo`03003o003oool0oooo02T0oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`1S0?ooo`030000003oool0oooo0680oooo0P000?lA0?ooo`80o`00:P3o
ool00`00o`00oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo00P0oooo00<00?l00?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo06<0oooo00<000000?ooo`3oool0HP3oool20000oa40oooo0P3o000Z0?ooo`03003o003oool0
oooo00T0oooo00<000000?ooo`3oool00P3oool002l0oooo00@0_g@0000000000000M;oo0`3oool0
0`3ogi`0B00007Boo`020?ooo`060?oOW0180000000000000000B9`0gooo2P3oool00`000000oooo
0?ooo`080?ooo`03003o003oool0oooo02T0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`1S0?ooo`030000003oool0oooo0680oooo0P000?lB0?ooo`030?l0003oool0oooo02P0oooo
00<00?l00?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00;P3oool01P3OW4P007Bo0?oo
o`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00P3oool01P3o_g@0000007Boo`3oool0omnL
04Qd_`X0oooo00<000000?ooo`3oool0203oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool0H`3oool00`000000oooo0?ooo`1R0?ooo`80003o4P3oool0
0`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool0
02d0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`0;0?ooo`030?noM018W=l0oooo
00P0oooo00<000000?ooo`3oool0203oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool0H`3oool00`000000oooo0?ooo`1S0?ooo`030000o`3oool0oooo
0100oooo00<0o`000?ooo`3oool0:03oool00`00o`00oooo0?ooo`090?ooo`030000003oool0oooo
0080oooo000]0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo2P3oool00`3o
okl0M01d0;ooo`080?ooo`030000003oool0oooo00P0oooo00<00?l00?ooo`3oool0:03oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo06@0oooo00<000000?ooo`3oool0H`3oool00`00
0?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?ooo`3oool02@3oool00`00
0000oooo0?ooo`020?ooo`00803oool00`3ooml0W4P0000000070000000604RLg`3oool0oooo0?oo
g`2LB00007Bo0`3oool00`3OW4P0001809cOo`0:0?ooo`030?oog`2LB000M;oo00P0oooo00<00000
0?ooo`3oool0203oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo0100oooo00<0003o
0?ooo`3oool0I03oool00`000000oooo0?ooo`1S0?ooo`030000o`3oool0oooo0100oooo00<0o`00
0?ooo`3oool0:@3oool00`00o`00oooo0?ooo`080?ooo`030000003oool0oooo0080oooo000^0?oo
o`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l02P3oool00`3ookl0M00004RLg`080?oo
o`<00000203oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo0100oooo00<0003o0?oo
o`3oool0I03oool00`000000oooo0?ooo`1S0?ooo`030000o`3oool0oooo0100oooo0P3o000Z0?oo
o`03003o003oool0oooo00D0oooo100000040?ooo`00;P3oool00`3OW4P0001809cOo`020?ooo`03
0?oog`2LB00007Bo00X0oooo00<0okmd0000001d_ol0203oool00`000000oooo0?ooo`080?ooo`03
003o003oool0oooo02P0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1T0?ooo`03
0000003oool0oooo06<0oooo00<0003o0?ooo`3oool0403oool20?l002X0oooo00<00?l00?ooo`3o
ool0203oool00`000000oooo0?ooo`020?ooo`00;P3oool00`3ogi`0B00004RLg`030?ooo`030;md
0000B9`0gooo00H0oooo00H0omoO0=ooo`3o_g@000000000M02oool80?ooo`030000003oool0oooo
00P0oooo00<00?l00?ooo`3oool0:03oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo
06@0oooo00<000000?ooo`3oool0H`3oool00`000?l0oooo0?ooo`0@0?ooo`80o`00:P3oool00`00
o`00oooo0?ooo`080?ooo`030000003oool0oooo0080oooo000^0?ooo`040?oog`2LB00004RL0=oo
o`80oooo00<0gia80018W03Oool01P3oool01@3ookl0M0000000000004P0W=oo00T0oooo00<00000
0?ooo`3oool0203oool00`00o`00oooo0?ooo`0W0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool0I03oool00`000000oooo0?ooo`1T0?ooo`030000o`3oool0oooo0100oooo00<0o`00
0?ooo`3oool0:03oool00`00o`00oooo0?ooo`080?ooo`030000003oool0oooo0080oooo000_0?oo
o`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01`3oool00`3OW9`0_ooo0?ooo`0:0?oo
o`030000003oool0oooo00P0oooo00<00?l00?ooo`3oool09`3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo06@0oooo00<000000?ooo`3oool0I03oool00`000?l0oooo0?ooo`0@0?oo
o`030?l0003oool0oooo02P0oooo00<00?l00?ooo`3oool0203oool00`000000oooo0?ooo`020?oo
o`00<03oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`P0oooo00<0omnL07BLg`3oool02P3oool0
0`000000oooo0?ooo`070?ooo`03003o003oool0oooo02P0oooo00<0o`000?ooo`3oool0403oool0
0`000?l0oooo0?ooo`1U0?ooo`030000003oool0oooo06@0oooo00<0003o0?ooo`3oool0403oool0
0`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool0
0340oooo00@0gia800000000000007Bo2P3oool01@2oM0000000000000000000B9cO00L0oooo00<0
00000?ooo`3oool01`3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo0100oooo00<0
003o0?ooo`3oool0I@3oool00`000000oooo0?ooo`1T0?ooo`030000o`3oool0oooo0100oooo00<0
o`000?ooo`3oool0:03oool00`00o`00oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo00L0oooo00<00?l00?ooo`3oool0:03oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo06D0oooo00<000000?ooo`3oool0I03oool00`000?l0oooo0?ooo`0@
0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`070?ooo`03003o003oool0oooo02P0oooo00<0o`000?oo
o`3oool0403oool00`000?l0oooo0?ooo`1U0?ooo`030000003oool0oooo06@0oooo00<0003o0?oo
o`3oool0403oool00`3o0000oooo0?ooo`0Y0?ooo`03003o003oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool01`3oool00`00o`00oooo0?ooo`0X0?ooo`03
0?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0I@3oool00`000000oooo0?ooo`1T0?ooo`03
0000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0:@3oool00`00o`00oooo0?ooo`070?ooo`03
0000003oool0oooo0080oooo001;0?ooo`800000203oool00`00o`00oooo0?ooo`0X0?ooo`030?l0
003oool0oooo0100oooo00<0003o0?ooo`3oool0I@3oool00`000000oooo0?ooo`1T0?ooo`030000
o`3oool0oooo0100oooo00<0o`000?ooo`3oool0:@3oool00`00o`00oooo0?ooo`050?ooo`<00000
103oool004/0oooo00<000000?ooo`3oool01`3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`3oool0I@3oool00`000000oooo0?ooo`1T0?ooo`030000o`3o
ool0oooo0100oooo0P3o000Z0?ooo`03003o003oool0oooo00L0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool01`3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool0I@3oool00`000000oooo0?ooo`1T0?ooo`030000o`3oool0
oooo0100oooo0P3o000Z0?ooo`03003o003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool01`3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool0I@3oool00`000000oooo0?ooo`1T0?ooo`80003o4@3oool20?l0
02X0oooo00<00?l00?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`060?ooo`03003o003oool0oooo02T0oooo00<0o`000?ooo`3oool0403oool00`000?l0
oooo0?ooo`1U0?ooo`030000003oool0oooo06D0oooo00<0003o0?ooo`3oool03`3oool20?l002X0
oooo00<00?l00?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`060?ooo`03003o003oool0oooo02T0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`1U0?ooo`030000003oool0oooo06D0oooo00<0003o0?ooo`3oool03`3oool20?l002X0oooo
00<00?l00?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`060?ooo`03003o003oool0oooo02T0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?oo
o`1U0?ooo`030000003oool0oooo06D0oooo00<0003o0?ooo`3oool03`3oool20?l002X0oooo00<0
0?l00?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`06
0?ooo`03003o003oool0oooo02T0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1U
0?ooo`030000003oool0oooo06D0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0X
0?ooo`03003o003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool01P3oool00`00o`00oooo0?ooo`0Y0?ooo`030?l0003oool0oooo0100oooo00<0003o0?oo
o`3oool0I@3oool00`000000oooo0?ooo`1U0?ooo`030000o`3oool0oooo0100oooo00<0o`000?oo
o`3oool0:03oool00`00o`00oooo0?ooo`070?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo00H0oooo00<00?l00?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo06D0oooo00<000000?ooo`3oool0I@3oool00`000?l0oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo02P0oooo00<00?l00?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`060?ooo`03003o003oool0oooo02P0oooo00<0o`000?ooo`3oool0
403oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo06D0oooo00<0003o0?ooo`3oool0
403oool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo00L0oooo00<000000?ooo`3oool0
0P3oool004/0oooo0P0000070?ooo`03003o003oool0oooo02P0oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo06D0oooo00<0003o0?ooo`3oool0403o
ool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo00D0oooo0`0000040?ooo`00B`3oool0
0`000000oooo0?ooo`060?ooo`03003o003oool0oooo02P0oooo00<0o`000?ooo`3oool0403oool0
0`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo06D0oooo00<0003o0?ooo`3oool0403oool0
0`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool01P3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool0IP3oool00`000000oooo0?ooo`1U0?ooo`030000o`3oool0oooo
0100oooo00<0o`000?ooo`3oool0:03oool00`00o`00oooo0?ooo`070?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo00H0oooo00<00?l00?ooo`3oool0:03oool00`3o0000
oooo0?ooo`0@0?ooo`030000o`3oool0oooo06H0oooo00<000000?ooo`3oool0I@3oool20000oa40
oooo00<0o`000?ooo`3oool0:03oool00`00o`00oooo0?ooo`070?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo00H0oooo00<00?l00?ooo`3oool0:03oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo06H0oooo00<000000?ooo`3oool0I@3oool20000oa40oooo
0P3o000Y0?ooo`03003o003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool000`0oooo00<0
oono07Ad_`3oool0?03oool00`000000oooo0?ooo`060?ooo`03003o003oool0oooo02P0oooo00<0
o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo06D0oooo0P00
0?lA0?ooo`80o`00:P3oool00`00o`00oooo0?ooo`060?ooo`030000003oool0oooo0080oooo000<
0?ooo`040?oOW0180000001809cOoc/0oooo00<000000?ooo`3oool01P3oool00`00o`00oooo0?oo
o`0X0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0IP3oool00`000000oooo0?oo
o`1U0?ooo`80003o4@3oool20?l002X0oooo00<00?l00?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`003P3oool00`2oM000000000000003000000030000M02oool0oooo03@0oooo00<00000
0?ooo`3oool01P3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo0100oooo00<0003o
0?ooo`3oool0IP3oool00`000000oooo0?ooo`1U0?ooo`80003o4P3oool00`3o0000oooo0?ooo`0X
0?ooo`03003o003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00180oooo00<0omnL04P0
001d_ol0=P3oool00`000000oooo0?ooo`060?ooo`03003o003oool0oooo02P0oooo00<0o`000?oo
o`3oool0403oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo06H0oooo00<0003o0?oo
o`3oool0403oool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool00140oooo00<0gia80000M02oool0=`3oool00`000000oooo0?ooo`060?ooo`03
003o003oool0oooo02P0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1V0?ooo`03
0000003oool0oooo06H0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0X0?ooo`03
003o003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000`0oooo00H0omnL04P0B02Lgol0
okmd00000018W=li0?ooo`030000003oool0oooo00H0oooo00<00?l00?ooo`3oool0:03oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo06H0oooo00<000000?ooo`3oool0IP3oool00`00
0?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`00303oool0103ogi`0B00000000000M;lk0?ooo`8000001`3oool00`00
o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0IP3oool00`00
0000oooo0?ooo`1V0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0:03oool00`00
o`00oooo0?ooo`040?ooo`<00000103oool004/0oooo00<000000?ooo`3oool01P3oool00`00o`00
oooo0?ooo`0X0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0IP3oool00`000000
oooo0?ooo`1V0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0:03oool00`00o`00
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00H0oooo
00<00?l00?ooo`3oool0:03oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo06H0oooo
00<000000?ooo`3oool0IP3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02P0oooo
00<00?l00?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`003`3oool01P3OW4P000000000
00000000001809cOocH0oooo00<000000?ooo`3oool01P3oool00`00o`00oooo0?ooo`0X0?ooo`03
0?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0I`3oool00`000000oooo0?ooo`1V0?ooo`03
0000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0:03oool00`00o`00oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo000=0?ooo`090?oo_`1d0000B9cO0?oOW02L_ol0oooo0=nLB000B9`0
gooo03D0oooo00<000000?ooo`3oool01P3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool0I`3oool00`000000oooo0?ooo`1V0?ooo`030000o`3oool0
oooo0100oooo00<0o`000?ooo`3oool0:03oool00`00o`00oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo000=0?ooo`090;mdM02oool0oooo0?noW02Lgol0oooo0?oo_`1d07@0_ooo03D0oooo
00<000000?ooo`3oool01P3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo00l0oooo
00<0003o0?ooo`3oool0I`3oool00`000000oooo0?ooo`1V0?ooo`030000o`3oool0oooo0100oooo
00<0o`000?ooo`3oool0:03oool00`00o`00oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
000<0?ooo`090?oOW02L_ol0oooo0?oog`2LM9`0gooo0?ooo`3ogi`0B7Bo03H0oooo00<000000?oo
o`3oool01@3oool00`00o`00oooo0?ooo`0Y0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?oo
o`3oool0I`3oool00`000000oooo0?ooo`1V0?ooo`030000o`3oool0oooo0100oooo00<0o`000?oo
o`3oool0:03oool00`00o`00oooo0?ooo`060?ooo`030000003oool0oooo0080oooo000<0?ooo`09
0?noW02Lgol0oooo0;md001d_ol0oooo0=nLB00007@0_ooo03H0oooo00<000000?ooo`3oool01@3o
ool00`00o`00oooo0?ooo`0Y0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0I`3o
ool00`000000oooo0?ooo`1V0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0:03o
ool00`00o`00oooo0?ooo`060?ooo`030000003oool0oooo0080oooo000<0?ooo`040?oo_`1d0000
000007Booc/0oooo00<000000?ooo`3oool01@3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`3oool0I`3oool00`000000oooo0?ooo`1V0?ooo`030000o`3o
ool0oooo0100oooo00<0o`000?ooo`3oool0:03oool00`00o`00oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo001;0?ooo`030000003oool0oooo00D0oooo00<00?l00?ooo`3oool0:03oool0
0`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo06L0oooo00<000000?ooo`3oool0IP3oool0
0`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool2000000H0oooo00<00?l00?ooo`3oool0:03oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo06L0oooo00<000000?ooo`3oool0IP3oool00`00
0?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?ooo`3oool0103oool30000
00@0oooo000@0?ooo`060?noM000000000000000000007@0_ooo=@3oool00`000000oooo0?ooo`05
0?ooo`03003o003oool0oooo02P0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1W
0?ooo`030000003oool0oooo06H0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0X
0?ooo`03003o003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000P0oooo00H0_ibL0=oo
o`3oool0oooo0?oOW0180003000000040018W03Oool0oono07Ad_cH0oooo00<000000?ooo`3oool0
1@3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0
I`3oool00`000000oooo0?ooo`1V0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0
:03oool00`00o`00oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00070?ooo`030?oog`2L
B000000000<0000000<007Bo0?ooo`3oool00P3oool00`3o_g@0001d0;ooo`0f0?ooo`030000003o
ool0oooo00D0oooo00<00?l00?ooo`3oool0:03oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo06L0oooo00<000000?ooo`3oool0IP3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo02P0oooo00<00?l00?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`001`3oool0
0`3ookl0M00004RLg`110?ooo`030000003oool0oooo00D0oooo00<00?l00?ooo`3oool0:03oool0
0`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo06L0oooo00<000000?ooo`3oool0IP3oool0
0`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`050?ooo`03003o003oool0oooo
02P0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1W0?ooo`030000003oool0oooo
06H0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool000l0oooo00H0omnL04P00000000000000000B02LgolX
0?ooo`040;md00000000000007Boo`X0oooo00<000000?ooo`3oool01@3oool00`00o`00oooo0?oo
o`0X0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0I`3oool00`000000oooo0?oo
o`1V0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0:03oool00`00o`00oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo000>0?ooo`030;md00000000M;oo0080oooo00<0oooO
09adW03Oool09P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`T0oooo00<000000?ooo`3oool0
1@3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0
I`3oool00`000000oooo0?ooo`1V0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0
:03oool00`00o`00oooo0?ooo`060?ooo`030000003oool0oooo0080oooo000=0?ooo`030=nLB018
W=l0oooo00@0oooo00<0gibL0;ooo`3oool0903oool00`3ooml0W4P004RLg`020?ooo`030?noM000
04P0W=oo00P0oooo00<000000?ooo`3oool01@3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`3oool0I`3oool00`000000oooo0?ooo`1V0?ooo`030000o`3o
ool0oooo0100oooo00<0o`000?ooo`3oool0:03oool00`00o`00oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo000<0?ooo`030?oOW01dW=l0oooo00@0oooo00<0oooO09adW03Oool09@3oool0
0`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`L0oooo00<000000?ooo`3oool01@3o
ool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0I`3o
ool00`000000oooo0?ooo`1V0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0:03o
ool00`00o`00oooo0?ooo`060?ooo`030000003oool0oooo0080oooo000<0?ooo`030?noW02Lgol0
oooo00<0oooo00<0oooO09a8001d_ol09P3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0
W=oo00L0oooo00<000000?ooo`3oool01@3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool0I`3oool00`000000oooo0?ooo`1V0?ooo`030000o`3oool0
oooo0100oooo00<0o`000?ooo`3oool0:03oool00`00o`00oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo000<0?ooo`030?oOW018M;l0oooo0080oooo00<0gia800000018W=l0:03oool00`2o
M00004RL0=ooo`020?ooo`030?oOW0180000B9cO00L0oooo200000000`00o`0000000000000X0000
00030?l00000000000000100000000<0003o000000000000d00000000`000?l000000000000@0000
00030?l000000000000002P0000000<00?l00000000000001`0000040?ooo`003@3oool01P3o_g@0
000000000000000004RL0=ooobT0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`07
0?ooo`030000003oool0oooo00D0oooo00<00?l00?ooo`3oool0:03oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo06L0oooo00<000000?ooo`3oool0IP3oool00`000?l0oooo0?ooo`0@
0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`00?03oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00H0oooo00<000000?oo
o`3oool01@3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo0100oooo00<0003o0?oo
o`3oool0I`3oool00`000000oooo0?ooo`1V0?ooo`030000o`3oool0oooo0100oooo00<0o`000?oo
o`3oool0:03oool00`00o`00oooo0?ooo`060?ooo`030000003oool0oooo0080oooo000l0?ooo`04
0?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool01P3oool00`000000oooo0?ooo`050?oo
o`03003o003oool0oooo02P0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1W0?oo
o`030000003oool0oooo06H0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0X0?oo
o`03003o003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000l0oooo00H0omnL04P00000
000000000000B02LgolX0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`03003o003oool0oooo02P0oooo00<0o`000?ooo`3oool0403oool0
0`000?l0oooo0?ooo`1W0?ooo`030000003oool0oooo06H0oooo00<0003o0?ooo`3oool0403oool0
0`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
00d0oooo00@0oooO09a80000B9`0gooo0P3oool00`3o_g@004RL0=ooo`0X0?ooo`060=nLB00007@0
_ooo0?oog`2LB000B9cO1`3oool00`000000oooo0?ooo`050?ooo`03003o003oool0oooo02P0oooo
00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1W0?ooo`030000003oool0oooo06H0oooo
00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool000d0oooo00<0_gA809cOo`3oool00`3oool00`3ooml0W4Qd0;oo
o`0Y0?ooo`040=nLB00000000000001d_`P0oooo00<000000?ooo`3oool01@3oool00`00o`00oooo
0?ooo`0X0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0I`3oool00`000000oooo
0?ooo`1V0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0:03oool00`00o`00oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo000<0?ooo`030?oOW02L_ol0oooo00@0oooo00<0
omnL04Qd_`3oool0=@3oool00`000000oooo0?ooo`050?ooo`03003o003oool0oooo02P0oooo00<0
o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1W0?ooo`030000003oool0oooo06H0oooo00<0
003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool000`0oooo00<0oknL09cOo`3oool00`3oool00`3ogi`0B4RL0=ooo`0f
0?ooo`030000003oool0oooo00D0oooo00<00?l00?ooo`3oool0:03oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo06L0oooo00<000000?ooo`3oool0IP3oool00`000?l0oooo0?ooo`0@
0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`00303oool0103ookl0M0000000001d_olk0?ooo`030000003oool0oooo00D0oooo00<00?l0
0?ooo`3oool0:03oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo06L0oooo00<00000
0?ooo`3oool0IP3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02P0oooo00<00?l0
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00B`3oool2000000H0oooo00<00?l00?oo
o`3oool0:03oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo06L0oooo00<000000?oo
o`3oool0IP3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?oo
o`3oool0103oool3000000@0oooo001;0?ooo`030000003oool0oooo00D0oooo00<00?l00?ooo`3o
ool0:03oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo06L0oooo00<000000?ooo`3o
ool0IP3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`00303oool00`3ookl0W9cO0?ooo`030?ooo`040?no
M0000000001d0;ooocD0oooo00<000000?ooo`3oool01@3oool00`00o`00oooo0?ooo`0Y0?ooo`03
0?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0I`3oool00`000000oooo0?ooo`1V0?ooo`03
0000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0:03oool00`00o`00oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo000<0?ooo`040?oo_`2LW=l0oono07@000@0000000<004RL0=ooo`3o
ool0=03oool00`000000oooo0?ooo`050?ooo`03003o003oool0oooo02T0oooo00<0o`000?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`1W0?ooo`030000003oool0oooo06H0oooo00<0003o0?ooo`3o
ool0403oool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool000`0oooo00T0omnL04P000000000001809cOo`3oool0oooO09a8M02oool0=P3oool0
0`000000oooo0?ooo`050?ooo`03003o003oool0oooo02T0oooo00<0o`000?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`1W0?ooo`030000003oool0oooo06H0oooo00<0003o0?ooo`3oool0403oool0
0`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
00P0oooo00@0oooO09a8000007@0_ooo?`3oool00`000000oooo0?ooo`050?ooo`03003o003oool0
oooo02T0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`1W0?ooo`030000003oool0
oooo06H0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01@3oool00`00
o`00oooo0?ooo`0Y0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0I`3oool00`00
0000oooo0?ooo`1V0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0:03oool00`00
o`00oooo0?ooo`060?ooo`030000003oool0oooo0080oooo000<0?ooo`050?oO_`2ogol0oooo0?oo
o`2oM0000`0000000`0007@0_ooo0?ooo`0d0?ooo`030000003oool0oooo00H0oooo00<00?l00?oo
o`3oool0:03oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo06L0oooo00<000000?oo
o`3oool0IP3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`00303oool00`2oM00000000000000200000005
0000M02oool0oooo0;nLW03Oool0=@3oool00`000000oooo0?ooo`060?ooo`03003o003oool0oooo
02P0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`1W0?ooo`030000003oool0oooo
06H0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool000X0oooo00D0_g@000000000000004RL0=ooo`030?oo
o`030?oog`2LB000M;oo0080oooo00<0_g@00018W03Oool0<@3oool00`000000oooo0?ooo`060?oo
o`03003o003oool0oooo02P0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`1W0?oo
o`030000003oool0oooo06H0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0X0?oo
o`03003o003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000`0oooo00<0oknL09cOo`3o
ool0203oool00`3ogi`0B7Bo0?ooo`0a0?ooo`030000003oool0oooo00H0oooo00<00?l00?ooo`3o
ool0:03oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo06L0oooo00<000000?ooo`3o
ool0IP3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`00303oool00`3ookl0M7Bo0?ooo`070?ooo`030?no
M000B9`0gooo0380oooo0P0000070?ooo`03003o003oool0oooo02P0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`1W0?ooo`030000003oool0oooo06H0oooo00<0003o0?ooo`3oool0
403oool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo00@0oooo0`0000040?ooo`00303o
ool0103ogi`0B0000000M02oool50?ooo`030=nLB000M;l0oooo03<0oooo00<000000?ooo`3oool0
1P3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0
IP3oool00`000000oooo0?ooo`1V0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0
:03oool00`00o`00oooo0?ooo`060?ooo`030000003oool0oooo0080oooo000=0?ooo`030?oOW018
0000000000D0000000<0B9cO0?ooo`3oool0<`3oool00`000000oooo0?ooo`060?ooo`03003o003o
ool0oooo02P0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1V0?ooo`030000003o
ool0oooo06H0oooo00<0003o0?ooo`3oool03`3oool20?l002X0oooo00<00?l00?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`004P3oool00`3o_g@0001809cOo`0f0?ooo`030000003oool0
oooo00H0oooo00<00?l00?ooo`3oool0:03oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo06H0oooo00<000000?ooo`3oool0IP3oool00`000?l0oooo0?ooo`0?0?ooo`80o`00:P3oool0
0`00o`00oooo0?ooo`060?ooo`030000003oool0oooo0080oooo000A0?ooo`030;md0000M;l0oooo
03L0oooo00<000000?ooo`3oool01P3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool0IP3oool00`000000oooo0?ooo`1U0?ooo`80003o4@3oool20?l0
02X0oooo00<00?l00?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00303oool01P3ogi`0
B00007Boo`3o_g@0000007BoocT0oooo00<000000?ooo`3oool01P3oool00`00o`00oooo0?ooo`0X
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0IP3oool00`000000oooo0?ooo`1U
0?ooo`80003o4@3oool20?l002X0oooo00<00?l00?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`00303oool0103ogi`0B00000000000M;lk0?ooo`030000003oool0oooo00H0oooo00<00?l0
0?ooo`3oool0:03oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo06H0oooo00<00000
0?ooo`3oool0I@3oool20000oa40oooo00<0o`000?ooo`3oool0:@3oool00`00o`00oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00H0oooo00<00?l00?oo
o`3oool0:03oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo06H0oooo00<000000?oo
o`3oool0I@3oool20000oa40oooo00<0o`000?ooo`3oool0:@3oool00`00o`00oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00H0oooo00<00?l00?ooo`3o
ool0:03oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo06H0oooo00<000000?ooo`3o
ool0I@3oool20000oa40oooo00<0o`000?ooo`3oool0:03oool00`00o`00oooo0?ooo`070?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00H0oooo00<00?l00?ooo`3oool0
:03oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo06H0oooo00<000000?ooo`3oool0
I@3oool20000oa40oooo00<0o`000?ooo`3oool0:03oool00`00o`00oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00H0oooo00<00?l00?ooo`3oool0:03o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo06H0oooo00<000000?ooo`3oool0I@3o
ool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?ooo`3oool01`3o
ool00`000000oooo0?ooo`020?ooo`00B`3oool2000000L0oooo00<00?l00?ooo`3oool0:03oool0
0`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo06H0oooo00<000000?ooo`3oool0I@3oool0
0`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?ooo`3oool01@3oool3
000000@0oooo001;0?ooo`030000003oool0oooo00H0oooo00<00?l00?ooo`3oool0:03oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo06H0oooo00<000000?ooo`3oool0I@3oool00`00
0?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?ooo`3oool01`3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`060?ooo`03003o003oool0oooo02P0
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo06D0
oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01P3oool00`00o`00oooo
0?ooo`0Y0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0IP3oool00`000000oooo
0?ooo`1U0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0:03oool00`00o`00oooo
0?ooo`070?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00H0oooo00<0
0?l00?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo06H0oooo00<0
00000?ooo`3oool0I@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02P0oooo00<0
0?l00?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`07
0?ooo`03003o003oool0oooo02P0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`1V
0?ooo`030000003oool0oooo06D0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0X
0?ooo`03003o003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool01`3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?oo
o`3oool0IP3oool00`000000oooo0?ooo`1U0?ooo`030000o`3oool0oooo00l0oooo0P3o000Z0?oo
o`03003o003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool01`3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3o
ool0IP3oool00`000000oooo0?ooo`1U0?ooo`030000o`3oool0oooo00l0oooo0P3o000Z0?ooo`03
003o003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
1`3oool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0
IP3oool00`000000oooo0?ooo`1U0?ooo`030000o`3oool0oooo00l0oooo0P3o000Z0?ooo`03003o
003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01`3o
ool00`00o`00oooo0?ooo`0X0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0I@3o
ool00`000000oooo0?ooo`1T0?ooo`030000o`3oool0oooo0100oooo0P3o000Z0?ooo`03003o003o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool004/0oooo0P0000080?ooo`03003o003oool0
oooo02P0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1U0?ooo`030000003oool0
oooo06@0oooo00<0003o0?ooo`3oool0403oool20?l002X0oooo00<00?l00?ooo`3oool01@3oool3
000000@0oooo001;0?ooo`030000003oool0oooo00L0oooo00<00?l00?ooo`3oool0:03oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo06D0oooo00<000000?ooo`3oool0I03oool00`00
0?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02T0oooo00<00?l00?ooo`3oool01`3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`070?ooo`03003o003oool0oooo02P0
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1U0?ooo`030000003oool0oooo06@0
oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0Y0?ooo`03003o003oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01`3oool00`00o`00oooo
0?ooo`0X0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0I@3oool00`000000oooo
0?ooo`1T0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0:@3oool00`00o`00oooo
0?ooo`070?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00L0oooo00<0
0?l00?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo06D0oooo00<0
00000?ooo`3oool0I03oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02T0oooo00<0
0?l00?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`07
0?ooo`03003o003oool0oooo02T0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`1U
0?ooo`030000003oool0oooo06@0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0X
0?ooo`03003o003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool002l0oooo00@0_g@00000
00000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`060?oOW0180000000000000000B9`0gooo
2P3oool00`000000oooo0?ooo`070?ooo`03003o003oool0oooo02T0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`1U0?ooo`030000003oool0oooo06@0oooo00<0003o0?ooo`3oool0
403oool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo00P0oooo00<000000?ooo`3oool0
0P3oool002h0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo0080
oooo00H0okmd0000001d_ol0oooo0?oOW018M;l:0?ooo`030000003oool0oooo00L0oooo00<00?l0
0?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo06D0oooo00<00000
0?ooo`3oool0I03oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02P0oooo00<00?l0
0?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00;@3oool00`3ooml0W4P004RLg`020?oo
o`030?noM00004P0W=oo00/0oooo00<0okmd04RLg`3oool0203oool00`000000oooo0?ooo`070?oo
o`03003o003oool0oooo02T0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`1U0?oo
o`030000003oool0oooo06@0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0X0?oo
o`03003o003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool002d0oooo00<0oooO09a80018
W=l00P3oool0103ooml0W4P00018W03Oool:0?ooo`030?oo_`1d07@0_ooo00P0oooo00<000000?oo
o`3oool01`3oool00`00o`00oooo0?ooo`0Y0?ooo`030?l0003oool0oooo0100oooo00<0003o0?oo
o`3oool0I03oool00`000000oooo0?ooo`1S0?ooo`80003o4@3oool20?l002X0oooo00<00?l00?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`00;@3oool00`3ooml0W4P0001d_`030?ooo`03
0=nLB00004P0W=oo00X0oooo00<0oooO09a8001d_ol0203oool00`000000oooo0?ooo`070?ooo`03
003o003oool0oooo02T0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1T0?ooo`03
0000003oool0oooo06<0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0Y0?ooo`03
003o003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool002h0oooo00<0_g@00018W03Oool0
0P3oool00`3ogi`0B00004RLg`0:0?ooo`030?oo_`1d0000B9cO00P0oooo0`0000070?ooo`03003o
003oool0oooo02T0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1T0?ooo`030000
003oool0oooo06<0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0Y0?ooo`03003o
003oool0oooo00D0oooo100000040?ooo`00;P3oool00`3OW4P0001809cOo`020?ooo`030?oog`2L
B00007Bo00X0oooo00<0okmd0000001d_ol0203oool00`000000oooo0?ooo`070?ooo`03003o003o
ool0oooo02X0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`1T0?ooo`030000003o
ool0oooo06<0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0Y0?ooo`03003o003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool002h0oooo00<0omnL04P00018W=l00`3oool0
0`2oM00004RL0=ooo`060?ooo`060?oOg`3Oool0okmd0000000007@0_ooo203oool00`000000oooo
0?ooo`080?ooo`03003o003oool0oooo02T0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo
0?ooo`1T0?ooo`030000003oool0oooo06<0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo
0?ooo`0Y0?ooo`03003o003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool002h0oooo00@0
oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`060?ooo`050?oo_`1d000000000000B02L
gol02@3oool00`000000oooo0?ooo`080?ooo`03003o003oool0oooo02T0oooo00<0o`000?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`1T0?ooo`030000003oool0oooo06<0oooo00<0003o0?ooo`3o
ool0403oool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo00T0oooo00<000000?ooo`3o
ool00P3oool002l0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`070?ooo`030=nL
W02oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`00o`00oooo0?ooo`0Y0?ooo`030?l0
003oool0oooo0100oooo00<0003o0?ooo`3oool0H`3oool00`000000oooo0?ooo`1R0?ooo`80003o
4P3oool00`3o0000oooo0?ooo`0X0?ooo`03003o003oool0oooo00T0oooo00<000000?ooo`3oool0
0P3oool00300oooo00H0gia80000M02oool0oooO09a80018W=l80?ooo`030?oOW01dW=l0oooo00X0
oooo00<000000?ooo`3oool0203oool00`00o`00oooo0?ooo`0Y0?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool0H`3oool00`000000oooo0?ooo`1R0?ooo`80003o4@3oool20?l002X0
oooo00<00?l00?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00<@3oool0103OW4P00000
00000000M;l:0?ooo`050;md00000000000000000018W=l01`3oool00`000000oooo0?ooo`080?oo
o`03003o003oool0oooo02T0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1S0?oo
o`030000003oool0oooo0680oooo0P000?lA0?ooo`030?l0003oool0oooo02T0oooo00<00?l00?oo
o`3oool02@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`080?ooo`03
003o003oool0oooo02T0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1S0?ooo`03
0000003oool0oooo0680oooo0P000?lA0?ooo`030?l0003oool0oooo02T0oooo00<00?l00?ooo`3o
ool02@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`080?ooo`03003o
003oool0oooo02T0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1S0?ooo`030000
003oool0oooo0680oooo0P000?lA0?ooo`030?l0003oool0oooo02T0oooo00<00?l00?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`080?ooo`03003o003o
ool0oooo02X0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`1S0?ooo`030000003o
ool0oooo0680oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0Y0?ooo`03003o003o
ool0oooo00T0oooo00<000000?ooo`3oool00P3oool004/0oooo0P00000:0?ooo`03003o003oool0
oooo02T0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1R0?ooo`030000003oool0
oooo0680oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0Y0?ooo`03003o003oool0
oooo00L0oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`090?ooo`03003o003oool0oooo
02T0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1R0?ooo`030000003oool0oooo
0640oooo0P000?lB0?ooo`030?l0003oool0oooo02P0oooo00<00?l00?ooo`3oool02P3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`090?ooo`03003o003oool0oooo02T0
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1R0?ooo`030000003oool0oooo0640
oooo0P000?lA0?ooo`80o`00:P3oool00`00o`00oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo00T0oooo00<00?l00?ooo`3oool0:@3oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo0680oooo00<000000?ooo`3oool0H@3oool20000oa40oooo
00<0o`000?ooo`3oool0:@3oool00`00o`00oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo00T0oooo00<00?l00?ooo`3oool0:@3oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo0680oooo00<000000?ooo`3oool0H@3oool20000oa40oooo00<0
o`000?ooo`3oool0:@3oool00`00o`00oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo00T0oooo00<00?l00?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo0680oooo00<000000?ooo`3oool0H@3oool00`000?l0oooo0?ooo`0@
0?ooo`030?l0003oool0oooo02T0oooo00<00?l00?ooo`3oool02P3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`090?ooo`03003o003oool0oooo02T0oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`1Q0?ooo`030000003oool0oooo0640oooo00<0003o0?oo
o`3oool0403oool00`3o0000oooo0?ooo`0Y0?ooo`03003o003oool0oooo00X0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool02@3oool00`00o`00oooo0?ooo`0Z0?ooo`03
0?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0H@3oool00`000000oooo0?ooo`1P0?ooo`80
003o4P3oool00`3o0000oooo0?ooo`0Y0?ooo`03003o003oool0oooo00X0oooo00<000000?ooo`3o
ool00P3oool004/0oooo00<000000?ooo`3oool02P3oool00`00o`00oooo0?ooo`0Y0?ooo`030?l0
003oool0oooo0100oooo00<0003o0?ooo`3oool0H@3oool00`000000oooo0?ooo`1P0?ooo`80003o
4@3oool20?l002/0oooo00<00?l00?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`0:0?ooo`03003o003oool0oooo02T0oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`1Q0?ooo`030000003oool0oooo0600oooo0P000?lA0?ooo`80o`00:P3o
ool00`00o`00oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo00X0oooo00<00?l00?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo0640oooo00<000000?ooo`3oool0H03oool20000oa40oooo0P3o000Z0?ooo`03003o003oool0
oooo00/0oooo00<000000?ooo`3oool00P3oool004/0oooo0P00000;0?ooo`03003o003oool0oooo
02T0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1Q0?ooo`030000003oool0oooo
0600oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0Y0?ooo`03003o003oool0oooo
00T0oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`0:0?ooo`03003o003oool0oooo02T0
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`1P0?ooo`030000003oool0oooo0600
oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0Y0?ooo`03003o003oool0oooo00/0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02P3oool00`00o`00oooo
0?ooo`0Z0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0H03oool00`000000oooo
0?ooo`1O0?ooo`80003o4P3oool00`3o0000oooo0?ooo`0Y0?ooo`03003o003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02P3oool00`00o`00oooo0?oo
o`0Z0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0H03oool00`000000oooo0?oo
o`1O0?ooo`80003o4@3oool20?l002/0oooo00<00?l00?ooo`3oool02`3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`0;0?ooo`03003o003oool0oooo02T0oooo00<0o`00
0?ooo`3oool0403oool00`000?l0oooo0?ooo`1P0?ooo`030000003oool0oooo05l0oooo0P000?lA
0?ooo`80o`00:`3oool00`00o`00oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo001;0?oo
o`030000003oool0oooo00/0oooo00<00?l00?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0@0?oo
o`030000o`3oool0oooo0600oooo00<000000?ooo`3oool0G`3oool00`000?l0oooo0?ooo`0@0?oo
o`80o`00:`3oool00`00o`00oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo00/0oooo00<00?l00?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo0600oooo00<000000?ooo`3oool0G`3oool00`000?l0oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo02T0oooo00<00?l00?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0;0?ooo`03003o003oool0oooo02X0oooo00<0o`000?ooo`3oool0
403oool00`000?l0oooo0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<0003o0?ooo`3oool0
403oool00`3o0000oooo0?ooo`0Y0?ooo`03003o003oool0oooo00`0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool02`3oool00`00o`00oooo0?ooo`0Z0?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`3oool0G`3oool00`000000oooo0?ooo`1N0?ooo`80003o4P3o
ool00`3o0000oooo0?ooo`0Y0?ooo`03003o003oool0oooo00`0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool02`3oool00`00o`00oooo0?ooo`0Z0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool0G`3oool00`000000oooo0?ooo`1N0?ooo`030000o`3oool0
oooo0100oooo0P3o000[0?ooo`03003o003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool0
04/0oooo0P00000=0?ooo`03003o003oool0oooo02T0oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`1O0?ooo`030000003oool0oooo05h0oooo00<0003o0?ooo`3oool0403oool00`3o
0000oooo0?ooo`0Z0?ooo`03003o003oool0oooo00X0oooo0`0000040?ooo`00B`3oool00`000000
oooo0?ooo`0<0?ooo`03003o003oool0oooo02X0oooo00<0o`000?ooo`3oool0403oool00`000?l0
oooo0?ooo`1N0?ooo`030000003oool0oooo05h0oooo00<0003o0?ooo`3oool0403oool00`3o0000
oooo0?ooo`0Z0?ooo`03003o003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool0303oool00`00o`00oooo0?ooo`0Z0?ooo`030?l0003oool0oooo0100oooo
00<0003o0?ooo`3oool0GP3oool00`000000oooo0?ooo`1M0?ooo`80003o4P3oool00`3o0000oooo
0?ooo`0Y0?ooo`03003o003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool0303oool00`00o`00oooo0?ooo`0Z0?ooo`030?l0003oool0oooo0100oooo00<0
003o0?ooo`3oool0GP3oool00`000000oooo0?ooo`1M0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool0:@3oool00`00o`00oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo00`0oooo00<00?l00?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo05d0oooo00<000000?ooo`3oool0G@3oool00`000?l0oooo0?ooo`0@
0?ooo`80o`00:`3oool00`00o`00oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo001;0?oo
o`030000003oool0oooo00d0oooo00<00?l00?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0@0?oo
o`030000o`3oool0oooo05d0oooo00<000000?ooo`3oool0G@3oool00`000?l0oooo0?ooo`0@0?oo
o`030?l0003oool0oooo02X0oooo00<00?l00?ooo`3oool03@3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`0=0?ooo`03003o003oool0oooo02X0oooo00<0o`000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`1M0?ooo`030000003oool0oooo05`0oooo0P000?lB0?ooo`03
0?l0003oool0oooo02X0oooo00<00?l00?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0=0?ooo`03003o003oool0oooo02X0oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`1L0?ooo`030000003oool0oooo05`0oooo00<0003o0?ooo`3oool0
403oool20?l002`0oooo00<00?l00?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`0=0?ooo`03003o003oool0oooo02X0oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`1L0?ooo`030000003oool0oooo05`0oooo00<0003o0?ooo`3oool0403o
ool20?l002/0oooo00<00?l00?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`0=0?ooo`03003o003oool0oooo02/0oooo00<0o`000?ooo`3oool0403oool0
0`000?l0oooo0?ooo`1L0?ooo`030000003oool0oooo05/0oooo0P000?lB0?ooo`030?l0003oool0
oooo02X0oooo00<00?l00?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`00
0000oooo0?ooo`0>0?ooo`03003o003oool0oooo02X0oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`1K0?ooo`030000003oool0oooo05/0oooo0P000?lB0?ooo`030?l0003oool0oooo
02X0oooo00<00?l00?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`00B`3oool2000000l0
oooo00<00?l00?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo05/0
oooo00<000000?ooo`3oool0F`3oool00`000?l0oooo0?ooo`0@0?ooo`80o`00;03oool00`00o`00
oooo0?ooo`0<0?ooo`<00000103oool004/0oooo00<000000?ooo`3oool03P3oool00`00o`00oooo
0?ooo`0Z0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo
0?ooo`1J0?ooo`80003o4P3oool20?l002/0oooo00<00?l00?ooo`3oool03`3oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0>0?ooo`03003o003oool0oooo02/0oooo00<0
o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1K0?ooo`030000003oool0oooo05X0oooo0P00
0?lB0?ooo`030?l0003oool0oooo02X0oooo00<00?l00?ooo`3oool03`3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`0?0?ooo`03003o003oool0oooo02X0oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`1J0?ooo`030000003oool0oooo05X0oooo00<0003o
0?ooo`3oool0403oool20?l002`0oooo00<00?l00?ooo`3oool03`3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`0?0?ooo`03003o003oool0oooo02X0oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`1J0?ooo`030000003oool0oooo05T0oooo0P000?lB0?oo
o`80o`00;03oool00`00o`00oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo00l0oooo00<00?l00?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo05X0oooo00<000000?ooo`3oool0F@3oool00`000?l0oooo0?ooo`0A0?ooo`80
o`00;03oool00`00o`00oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo000k0?ooo`030?oo
_`1d000000000080000000<0B9cO0?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`03003o
003oool0oooo02/0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`1I0?ooo`030000
003oool0oooo05T0oooo00<0003o0?ooo`3oool0403oool20?l002`0oooo00<00?l00?ooo`3oool0
403oool00`000000oooo0?ooo`020?ooo`00?@3oool00`3o_g@0000007Boo`0;0?ooo`030000003o
ool0oooo0100oooo00<00?l00?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo05T0oooo00<000000?ooo`3oool0F03oool00`000?l0oooo0?ooo`0A0?ooo`80o`00;03o
ool00`00o`00oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo000m0?ooo`030?oog`2LB000
07Bo00/0oooo00<000000?ooo`3oool0403oool00`00o`00oooo0?ooo`0[0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool0F@3oool00`000000oooo0?ooo`1H0?ooo`030000o`3oool0
oooo0140oooo0P3o000/0?ooo`03003o003oool0oooo0100oooo00<000000?ooo`3oool00P3oool0
03h0oooo00<0gia80018W03Oool02P3oool00`000000oooo0?ooo`0@0?ooo`03003o003oool0oooo
02/0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`1H0?ooo`030000003oool0oooo
05L0oooo0P000?lC0?ooo`030?l0003oool0oooo02/0oooo00<00?l00?ooo`3oool0403oool00`00
0000oooo0?ooo`020?ooo`00?P3oool00`3ogi`0B01809cOo`0:0?ooo`030000003oool0oooo0100
oooo00<00?l00?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo05P0
oooo00<000000?ooo`3oool0E`3oool00`000?l0oooo0?ooo`0A0?ooo`80o`00;@3oool00`00o`00
oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo000n0?ooo`030?oo_`1d0000M;oo00X0oooo
0`00000@0?ooo`03003o003oool0oooo02`0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`1A0?ooo`l0003oDP3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo02/0oooo
00<00?l00?ooo`3oool03P3oool4000000@0oooo000o0?ooo`030;md0000M;l0oooo00T0oooo00<0
00000?ooo`3oool04@3oool00`00o`00oooo0?ooo`0[0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool0B`3oool50000o`L0oooo00<000000?ooo`3oool0103oool00`00o`00003o0000
o`030000od`0oooo0P000?lC0?ooo`030?l0003oool0oooo02/0oooo00<00?l00?ooo`3oool04@3o
ool00`000000oooo0?ooo`020?ooo`00?`3oool00`3OW4P004RL0=ooo`090?ooo`030000003oool0
oooo0140oooo00<00?l00?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo04T0oooo0P000?l<0?ooo`030000003oool0oooo00P0oooo1@000?m90?ooo`030000o`3oool0
oooo0140oooo0P3o000]0?ooo`03003o003oool0oooo0140oooo00<000000?ooo`3oool00P3oool0
03l0oooo00<0omnL04P0B02Lgol02@3oool00`000000oooo0?ooo`0A0?ooo`03003o003oool0oooo
02`0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`150?ooo`<0003o3P3oool00`00
0000oooo0?ooo`0;0?ooo`@0003oAP3oool20000oa<0oooo00<0o`000?ooo`3oool0;03oool00`00
o`00oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo000o0?ooo`030?oo_`1d0000M;oo00T0
oooo00<000000?ooo`3oool04@3oool00`00o`00oooo0?ooo`0/0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool0@P3oool30000o`030?l0003oool0oooo00h0oooo00<000000?ooo`3o
ool03`3oool20000od@0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0[0?ooo`03
003o003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00400oooo00<0_g@0001d_`3oool0
203oool00`000000oooo0?ooo`0B0?ooo`03003o003oool0oooo02/0oooo00<0o`000?ooo`3oool0
4P3oool00`000?l0oooo0?ooo`0o0?ooo`80003o00<0o`000?ooo`3oool04@3oool00`000000oooo
0?ooo`0@0?ooo`<0003o@@3oool20000oa<0oooo00<0o`000?ooo`3oool0;03oool00`00o`00oooo
0?ooo`0B0?ooo`030000003oool0oooo0080oooo000n0?ooo`050?oo_`1d000000000000M02oool0
203oool00`000000oooo0?ooo`0B0?ooo`03003o003oool0oooo02`0oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0m0?ooo`80003o00<0o`000?ooo`3oool04`3oool00`000000oooo
0?ooo`0B0?ooo`<0003o?`3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo02`0oooo
00<00?l00?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`0B0?ooo`03003o003oool0oooo02`0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?oo
o`0j0?ooo`80003o00<00?l00?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`<0003o?03o
ool20000oa<0oooo0P3o000^0?ooo`03003o003oool0oooo0180oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool04P3oool00`00o`00oooo0?ooo`0]0?ooo`030?l0003oool0
oooo0180oooo00<0003o0?ooo`3oool0=`3oool20000o`03003o003oool0oooo01L0oooo00<00000
0?ooo`3oool05P3oool20000o`03003o003oool0oooo03P0oooo00<0003o0?ooo`3oool04P3oool0
0`3o0000oooo0?ooo`0/0?ooo`03003o003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool04`3oool00`00o`00oooo0?ooo`0/0?ooo`030?l0003oool0oooo
0180oooo00<0003o0?ooo`3oool0=@3oool20000o`800?l06P3oool00`000000oooo0?ooo`0H0?oo
o`80003o>03oool20000oa<0oooo0P3o000^0?ooo`03003o003oool0oooo01<0oooo00<000000?oo
o`3oool00P3oool004/0oooo0P00000D0?ooo`03003o003oool0oooo02`0oooo00<0o`000?ooo`3o
ool04`3oool00`000?l0oooo0?ooo`0c0?ooo`030000o`3o00000?l001`0oooo00<000000?ooo`3o
ool06P3oool20000ocD0oooo0P000?lD0?ooo`030?l0003oool0oooo02d0oooo00<00?l00?ooo`3o
ool04@3oool3000000@0oooo001;0?ooo`030000003oool0oooo01<0oooo00<00?l00?ooo`3oool0
;@3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo0300oooo0P000?l00`00o`00oooo
0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<0o`000000o`000?l0<`3oool00`000?l0oooo
0?ooo`0B0?ooo`80o`00;`3oool00`00o`00oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo01@0oooo00<00?l00?ooo`3oool0;03oool00`3o0000oooo0?oo
o`0C0?ooo`030000o`3oool0oooo02h0oooo0P000?l00`3o0000oooo0?ooo`0N0?ooo`030000003o
ool0oooo01`0oooo00@00?l00?l000000?l0003o<03oool00`000?l0oooo0?ooo`0C0?ooo`030?l0
003oool0oooo02d0oooo00<00?l00?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`0D0?ooo`03003o003oool0oooo02d0oooo00<0o`000?ooo`3oool04`3o
ool00`000?l0oooo0?ooo`0[0?ooo`80003o00<0o`00003o003oool0803oool00`000000oooo0?oo
o`0N0?ooo`04003o003o0000003o0000obd0oooo0P000?lD0?ooo`80o`00;`3oool00`00o`00oooo
0?ooo`0D0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01D0oooo00<0
0?l00?ooo`3oool0;03oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo02X0oooo00@0
003o0?l0003o00000?l08P3oool00`000000oooo0?ooo`0O0?ooo`03003o003o0000o`000080003o
:P3oool20000oaD0oooo00<0o`000?ooo`3oool0;P3oool00`00o`00oooo0?ooo`0D0?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01D0oooo00<00?l00?ooo`3oool0;@3o
ool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo02L0oooo0P000?l00`3o00000?l00?oo
o`0S0?ooo`030000003oool0oooo0240oooo00<00?l00?l0003o00000P000?lX0?ooo`030000o`3o
ool0oooo01<0oooo0P3o000_0?ooo`03003o003oool0oooo01D0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool05@3oool00`00o`00oooo0?ooo`0]0?ooo`030?l0003oool0
oooo01@0oooo00<0003o0?ooo`3oool0903oool20000o`80o`0000<00?l00?ooo`3oool08`3oool0
0`000000oooo0?ooo`0R0?ooo`04003o003o0000o`000?ooo`80003o9@3oool00`000?l0oooo0?oo
o`0D0?ooo`030?l0003oool0oooo02h0oooo00<00?l00?ooo`3oool05@3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`0F0?ooo`03003o003oool0oooo02d0oooo00<0o`00
0?ooo`3oool0503oool20000ob80oooo0P000?l0103oool0o`000?ooo`00o`0V0?ooo`030000003o
ool0oooo02@0oooo00@00?l00?l0003o0000oooo0P000?lR0?ooo`030000o`3oool0oooo01@0oooo
0P3o000`0?ooo`03003o003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool05P3oool00`00o`00oooo0?ooo`0^0?ooo`030?l0003oool0oooo01D0oooo00<0
003o0?ooo`3oool0703oool30000o`050?ooo`3o0000o`000?ooo`00o`009`3oool00`000000oooo
0?ooo`0U0?ooo`03003o003oool0o`000080oooo0P000?lN0?ooo`80003o5`3oool00`3o0000oooo
0?ooo`0^0?ooo`03003o003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool05P3oool00`00o`00oooo0?ooo`0^0?ooo`030?l0003oool0oooo01H0oooo00<0
003o0?ooo`3oool06@3oool20000o`<0oooo00@0o`000?ooo`00o`000?l0:03oool00`000000oooo
0?ooo`0V0?ooo`800?l00P3o0000103oool0003o0000o`000?lK0?ooo`80003o5`3oool20?l00300
oooo00<00?l00?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`0G0?ooo`03003o003oool0oooo02h0oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo
0?ooo`0F0?ooo`80003o0`3oool20?l000030?ooo`00o`00oooo02T0oooo00<000000?ooo`3oool0
9`3oool2003o00040?ooo`3o0000o`000?ooo`<0003o603oool20000oaL0oooo0P3o000a0?ooo`03
003o003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool004/0oooo0P00000H0?ooo`03003o
003oool0oooo02l0oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0C0?ooo`80003o
103oool0103o0000oooo0?ooo`00o`0[0?ooo`030000003oool0oooo02P0oooo0P00o`020?ooo`80
o`000P3oool30000oa<0oooo0P000?lH0?ooo`80o`00<@3oool00`00o`00oooo0?ooo`0E0?ooo`<0
0000103oool004/0oooo00<000000?ooo`3oool0603oool00`00o`00oooo0?ooo`0^0?ooo`030?l0
003oool0oooo01L0oooo10000?l>0?ooo`<0003o103oool20?l00080oooo00<00?l00?ooo`3oool0
:P3oool00`000000oooo0?ooo`0Z0?ooo`800?l000@0oooo0?l0003o0000o`000`3oool20000o`h0
oooo10000?lI0?ooo`80o`00<@3oool00`00o`00oooo0?ooo`0G0?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo01P0oooo00<00?l00?ooo`3oool0;`3oool00`3o0000oooo
0?ooo`0J0?ooo`h0003o1P3oool01@3o0000oooo0?ooo`3oool00?l002d0oooo00<000000?ooo`3o
ool0:`3oool2003o0080oooo0P3o00040?ooo`l0003o6`3oool20?l00380oooo00<00?l00?ooo`3o
ool05`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0H0?ooo`03003o
003oool0oooo0300oooo00<0o`000?ooo`3oool0:`3oool20?l00080oooo0P00o`0^0?ooo`030000
003oool0oooo02`0oooo0P00o`030?ooo`80o`00:`3oool20?l00380oooo00<00?l00?ooo`3oool0
603oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0I0?ooo`03003o003o
ool0oooo0300oooo00<0o`000?ooo`3oool0:@3oool01@3o0000oooo0?ooo`3oool00?l00300oooo
00<000000?ooo`3oool0;@3oool2003o00@0oooo0P3o000X0?ooo`80o`00<`3oool00`00o`00oooo
0?ooo`0H0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01T0oooo00<0
0?l00?ooo`3oool0<@3oool00`3o0000oooo0?ooo`0V0?ooo`80o`000`3oool00`00o`00oooo0?oo
o`0_0?ooo`030000003oool0oooo02h0oooo0P00o`040?ooo`80o`009P3oool20?l003<0oooo00<0
0?l00?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0I
0?ooo`03003o003oool0oooo0380oooo00<0o`000?ooo`3oool0903oool00`3o0000oooo0?ooo`02
0?ooo`03003o003oool0oooo0300oooo00<000000?ooo`3oool0<03oool2003o00@0oooo0P3o000T
0?ooo`030?l0003oool0oooo0380oooo00<00?l00?ooo`3oool06@3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`0J0?ooo`03003o003oool0oooo0380oooo0P3o000R0?oo
o`80o`000`3oool2003o03<0oooo00<000000?ooo`3oool0<@3oool2003o00@0oooo0`3o000Q0?oo
o`030?l0003oool0oooo0380oooo00<00?l00?ooo`3oool06P3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`0J0?ooo`03003o003oool0oooo03@0oooo00<0o`000?ooo`3o
ool07@3oool20?l000@0oooo00<00?l00?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`80
0?l01@3oool30?l001d0oooo0P3o000e0?ooo`03003o003oool0oooo01X0oooo00<000000?ooo`3o
ool00P3oool004/0oooo00<000000?ooo`3oool06`3oool00`00o`00oooo0?ooo`0d0?ooo`030?l0
003oool0oooo01X0oooo0P3o00050?ooo`03003o003oool0oooo03@0oooo00<000000?ooo`3oool0
<`3oool2003o00D0oooo103o000J0?ooo`80o`00=@3oool00`00o`00oooo0?ooo`0K0?ooo`030000
003oool0oooo0080oooo001;0?ooo`800000703oool00`00o`00oooo0?ooo`0e0?ooo`030?l0003o
ool0oooo01H0oooo0`3o00060?ooo`03003o003oool0oooo03D0oooo00<000000?ooo`3oool0=@3o
ool00`00o`00oooo0?ooo`040?ooo`@0o`005P3oool20?l003L0oooo00<00?l00?ooo`3oool06@3o
ool3000000@0oooo001;0?ooo`030000003oool0oooo01/0oooo00<00?l00?ooo`3oool0=P3oool2
0?l00180oooo103o00080?ooo`03003o003oool0oooo03H0oooo00<000000?ooo`3oool0=P3oool2
003o00L0oooo103o000A0?ooo`80o`00>03oool00`00o`00oooo0?ooo`0L0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo01`0oooo00<00?l00?ooo`3oool0=`3oool40?l0
00X0oooo103o000:0?ooo`800?l0>@3oool00`000000oooo0?ooo`0g0?ooo`800?l02@3oool50?l0
00P0oooo1@3o000j0?ooo`03003o003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool0703oool00`00o`00oooo0?ooo`0k0?ooo`X0o`003@3oool00`00o`00
oooo0?ooo`0i0?ooo`030000003oool0oooo03T0oooo00<00?l00?ooo`3oool02`3oool80?l003h0
oooo00<00?l00?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`0M0?ooo`03003o003oool0oooo0500oooo00<00?l00?ooo`3oool0>P3oool00`000000oooo
0?ooo`0j0?ooo`03003o003oool0oooo0500oooo00<00?l00?ooo`3oool07@3oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0M0?ooo`03003o003oool0oooo04l0oooo00<0
0?l00?ooo`3oool0>`3oool00`000000oooo0?ooo`0k0?ooo`800?l0C`3oool00`00o`00oooo0?oo
o`0N0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01h0oooo00<00?l0
0?ooo`3oool0C@3oool00`00o`00oooo0?ooo`0l0?ooo`030000003oool0oooo03d0oooo00<00?l0
0?ooo`3oool0B`3oool00`00o`00oooo0?ooo`0O0?ooo`030000003oool0oooo0080oooo001;0?oo
o`030000003oool0oooo01h0oooo00<00?l00?ooo`3oool0B`3oool2003o03l0oooo00<000000?oo
o`3oool0?P3oool00`00o`00oooo0?ooo`1:0?ooo`03003o003oool0oooo01l0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool07`3oool00`00o`00oooo0?ooo`190?ooo`03
003o003oool0oooo03l0oooo00<000000?ooo`3oool0?`3oool2003o04T0oooo00<00?l00?ooo`3o
ool0803oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0O0?ooo`03003o
003oool0oooo04P0oooo00<00?l00?ooo`3oool0@03oool00`000000oooo0?ooo`100?ooo`800?l0
B03oool00`00o`00oooo0?ooo`0P0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo0200oooo00<00?l00?ooo`3oool0A@3oool2003o04<0oooo00<000000?ooo`3oool0@@3o
ool2003o04H0oooo00<00?l00?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`00B`3oool2
00000240oooo00<00?l00?ooo`3oool0A03oool00`00o`00oooo0?ooo`130?ooo`030000003oool0
oooo04<0oooo0P00o`130?ooo`03003o003oool0oooo0200oooo0`0000040?ooo`00B`3oool00`00
0000oooo0?ooo`0Q0?ooo`03003o003oool0oooo0440oooo0P00o`160?ooo`030000003oool0oooo
04@0oooo0P00o`120?ooo`03003o003oool0oooo0280oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool08P3oool00`00o`00oooo0?ooo`0o0?ooo`03003o003oool0oooo04H0
oooo00<000000?ooo`3oool0A@3oool2003o0400oooo00<00?l00?ooo`3oool08`3oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0S0?ooo`03003o003oool0oooo03`0oooo
0P00o`190?ooo`030000003oool0oooo04H0oooo0`00o`0m0?ooo`03003o003oool0oooo02@0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool08`3oool00`00o`00oooo0?oo
o`0k0?ooo`03003o003oool0oooo04T0oooo00<000000?ooo`3oool0A`3oool3003o03`0oooo00<0
0?l00?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0T
0?ooo`03003o003oool0oooo03P0oooo0P00o`1<0?ooo`030000003oool0oooo04T0oooo0P00o`0j
0?ooo`03003o003oool0oooo02D0oooo00<000000?ooo`3oool00P3oool002d0oooo00<0oono07@0
000000000P0000001`18W=l0oooo0?ooo`3oool0omnL04P0001d_ol00P3oool01P3ogi`0B0000000
0000000004RL0=ooo`X0oooo00<000000?ooo`3oool09@3oool00`00o`00oooo0?ooo`0f0?ooo`03
003o003oool0oooo04`0oooo00<000000?ooo`3oool0BP3oool3003o03L0oooo00<00?l00?ooo`3o
ool09P3oool00`000000oooo0?ooo`020?ooo`00;`3oool00`3o_g@0000007Boo`040?ooo`030?oO
W0180000M;oo0080oooo00H0okmd0000001d_ol0oooo0?oOW018M;l:0?ooo`030000003oool0oooo
02H0oooo00<00?l00?ooo`3oool0<`3oool2003o04l0oooo00<000000?ooo`3oool0B`3oool3003o
03D0oooo00<00?l00?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`00;`3oool00`3ooml0
W4P0001d_`0>0?ooo`030?noM018W=l0oooo00P0oooo00<000000?ooo`3oool09`3oool00`00o`00
oooo0?ooo`0a0?ooo`03003o003oool0oooo04l0oooo00<000000?ooo`3oool0C@3oool2003o03<0
oooo00<00?l00?ooo`3oool0:03oool00`000000oooo0?ooo`020?ooo`00<03oool00`3OW4P004RL
0=ooo`0=0?ooo`030?oo_`1d07@0_ooo00P0oooo00<000000?ooo`3oool0:03oool00`00o`00oooo
0?ooo`0^0?ooo`800?l0DP3oool00`000000oooo0?ooo`1?0?ooo`800?l0<@3oool00`00o`00oooo
0?ooo`0X0?ooo`030000003oool0oooo0080oooo000`0?ooo`030?oOW01804P0W=oo00d0oooo00<0
oooO09a8001d_ol0203oool00`000000oooo0?ooo`0Y0?ooo`03003o003oool0oooo02`0oooo00<0
0?l00?ooo`3oool0DP3oool00`000000oooo0?ooo`1A0?ooo`800?l0;P3oool00`00o`00oooo0?oo
o`0Y0?ooo`030000003oool0oooo0080oooo000`0?ooo`030?oo_`1d0000M;oo00d0oooo00<0oono
07@00018W=l0203oool3000002X0oooo00<00?l00?ooo`3oool0:@3oool2003o05D0oooo00<00000
0?ooo`3oool0DP3oool3003o02/0oooo00<00?l00?ooo`3oool09`3oool4000000@0oooo000a0?oo
o`030;md0000M;l0oooo00`0oooo00<0okmd0000001d_ol0203oool00`000000oooo0?ooo`0[0?oo
o`03003o003oool0oooo02H0oooo0P00o`1G0?ooo`030000003oool0oooo05D0oooo00<00?l00?oo
o`3oool09`3oool00`00o`00oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo000a0?ooo`03
0=nLB000B9`0gooo00T0oooo00H0omoO0=ooo`3o_g@000000000M02oool80?ooo`030000003oool0
oooo02`0oooo00<00?l00?ooo`3oool0903oool00`00o`00oooo0?ooo`1G0?ooo`030000003oool0
oooo05H0oooo0P00o`0U0?ooo`800?l0;P3oool00`000000oooo0?ooo`020?ooo`00<@3oool00`3o
gi`0B01809cOo`090?ooo`050?oo_`1d000000000000B02Lgol02@3oool00`000000oooo0?ooo`0]
0?ooo`03003o003oool0oooo0240oooo0P00o`1J0?ooo`030000003oool0oooo05P0oooo0P00o`0R
0?ooo`03003o003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool00340oooo00<0oono07@0
001d_ol02P3oool00`3OW9`0_ooo0?ooo`0:0?ooo`030000003oool0oooo02h0oooo0P00o`0O0?oo
o`800?l0G03oool00`000000oooo0?ooo`1J0?ooo`800?l07P3oool2003o0340oooo00<000000?oo
o`3oool00P3oool00380oooo00<0_g@0001d_`3oool02@3oool00`3ogi`0M9cO0?ooo`0:0?ooo`03
0000003oool0oooo0300oooo0P00o`0K0?ooo`800?l0GP3oool00`000000oooo0?ooo`1L0?ooo`80
0?l06@3oool3003o03<0oooo00<000000?ooo`3oool00P3oool00300oooo00D0oono07@000000000
001d0;ooo`0:0?ooo`050;md00000000000000000018W=l01`3oool00`000000oooo0?ooo`0b0?oo
o`800?l05`3oool2003o0600oooo00<000000?ooo`3oool0GP3oool3003o01<0oooo0`00o`0f0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo03@0oooo1000o`0>0?ooo`D0
0?l0HP3oool00`000000oooo0?ooo`1Q0?ooo`D00?l0303oool2003o03T0oooo00<000000?ooo`3o
ool00P3oool004/0oooo00<000000?ooo`3oool0>03oool>003o06L0oooo00<000000?ooo`3oool0
IP3oool<003o03/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0[@3o
ool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0080oooo001;0?ooo`800000[P3oool0
0`000000oooo0?ooo`2[0?ooo`<00000103oool004/0oooo00<000000?ooo`3oool0[@3oool00`00
0000oooo0?ooo`2]0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0:d0
oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`2]0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo001;0?ooool0
0000HP0000040?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00RP3oool01P3OW4P00000000000000000001809cOo`H0oooo00<0_g@0001d
_`3oool01@3oool01@3OW4P00000000000000000M;oo00<0oooo00D0gia8000000000000000007Bo
o`090?ooo`030=nLB000000000000080000000<007Bo0?ooo`3oool00P3oool01@3o_g@000000000
000004P0W=oo00<0oooo00<0gia80018W03Oool00P3oool01@2oM0000000001d_`3ookl0M00000<0
000000D0B9cO0?ooo`3oool0oooo0=nLB0030000000507Boo`3oool0oooo0;md0000M;l01`3oool0
0`3o_g@007Bo0?ooo`030?ooo`0=0?oOW018000000000000001d_ol0gia800000000B9`0gooo0?no
M0000000001809cOo`020?ooo`040;md00000000001809cOo`<0oooo00<0okmd001d_`3oool0103o
ool01@3OW4P00000000000000000M;oo00L0oooo00<0oono07@0000000000P0000000`00B9`0gooo
0?ooo`020?ooo`030?oo_`1d000000000080000000D0B9cO0?ooo`3oool0oooo0=nLB00200000003
0000B02Lgol0oooo0080oooo0140_g@00000000004P0W=oo0?ooo`3o_g@000000000M02oool0oooo
0?noM0000000001d0;ooo`3oool0omnL04P000020000000907Boo`3OW4P000000018W03Oool0okmd
0000000004P0W=oo0080oooo00@0_g@00000000004P0W=oo0P3oool01@3o_g@000000000000004P0
W=oo00<0oooo00<0gia80018W03Oool00P3oool01@2oM0000000001d_`3ookl0M00000<0000000<0
B9cO0?ooo`3oool0@`3oool008/0oooo00@0oooO09a80000B9`0gooo1`3oool00`3o_g@0001d0;oo
o`040?ooo`030?oOW0180000M;oo0080oooo00H0_g@0001d_`3oool0omnL04P0001d_ol20?ooo`03
0;md0000M;l0oooo00D0oooo00@0oooO09a800000000B9cO0`3oool02`3o_g@0001d0;ooo`3oool0
omnL04P0B02Lgol0oooo0?oOW018000007Bo0080oooo00<0okmd0000M02oool00P3oool03P3OW4P0
04RL0=noM01d_ml0W4P007Boo`3oool0omnL04P0001d_ol0oooo0?oOW0180000M;oo0P3oool01P2o
M00007Bo0?ooo`3o_g@0001d0;ooo`H0oooo00@0okmd00000000B9`0gooo0P3oool0502oM00004RL
0=ooo`3oool0_g@007AdM00007@0_mnL09boo`3o_g@0001809cOg`2LM9`0gooo0?ooo`3OW4P004RL
0=oog`2LM9`0gooo0P3oool0103o_g@000000018W03Oool20?ooo`030?oOW0180000M;oo0080oooo
00<0_g@0001d_`3oool0103oool0103ogi`0B0000018W03Oool20?ooo`030;md00000000B9cO0080
oooo00l0oooO09a8001d_ol0oooo0?oOW0180000M;oo0?ooo`3o_g@0000007Boo`3oool0oooO09a8
0018W=l00P3oool0:P3OW4P004RL0=oog`2LM9`0gooo0?oOW01807@0_ono09bLg`3oool0omnL04P0
M02ookl0W9cO0?ooo`2oM00004RL0=ooo`3oool0_g@007AdM00007@0_mnL09boo`3o_g@0001809cO
g`2LM9`0gooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0B000001d
_`80oooo00<0okmd0000M02oool00P3oool02P3OW4P004RL0=noM01d_ml0W4P007Boo`3oool0omnL
04P0001d_om40?ooo`00S03oool00`3o_g@0001809cOo`070?ooo`030?oOW0180000M;oo00@0oooo
00<0gia80018W03Oool00`3oool01@3OW9`0_ooo0=nLB000B9`0gooo00<0oooo00<0gibL0;ooo`3o
ool0103oool00`3OW4P0000004RLg`050?ooo`060?oo_`1dM;l0oooo0=nLB000B9`0gooo0P3oool0
1`3ogi`0B00004RLg`3oool0oono07@00018W=l00P3oool03P3ogi`0B01809cOo`3oool0_gAd0;oo
o`3oool0oono07@0001d_ol0oooo0=nLB000B9`0gooo0`3oool01@3OW9`0_ooo0?oOW0180000M;oo
00H0oooo00@0gia80000M02ogi`0B7Bo0P3oool00`2oM00007Bo0?ooo`020?ooo`070;md00000000
M;oo0?ooo`3ookl0M00007Boo`030?ooo`030?noM00004P0W=oo00@0oooo00@0gia80000M02ogi`0
B7Bo0P3oool00`3OW4P004RL0=ooo`030?ooo`030=nLW02oool0oooo00<0oooo00<0_g@00000B02L
gol0103oool00`3o_g@00000001d_`020?ooo`0:0;mdM02oool0oooo0?oo_`1d0000M;oo0?ooo`3O
W4P004RL0=ooo`<0oooo00H0gmoO0?ooo`3oool0okmd0000B02Lgol20?ooo`0<0?oo_`1d0000M;oo
0=nLW02oool0oono07@0001d_ol0gibL0;ooo`2oM00007Bo0`3oool01`2oM000000007Boo`3oool0
oono07@0001d_ol00`3oool00`3o_g@0001809cOo`020?ooo`030=nLB000B9`0gooo0080oooo00L0
omnL04P00018W=l0oooo0?oo_`1d0000B9cO0080oooo00X0omnL04P0B02Lgol0oooo0;mdM02oool0
oooo0?oo_`1d0000M;ooA03oool008`0oooo00<0omnL04P0001d_ol01`3oool0103ooml0W4P00018
W03Oool30?ooo`050?noM0000000000000000018W=l00`3oool01@3o_g@00000000000000000B9cO
00L0oooo00@0oooO09a8000007@0_ooo203oool00`3o_g@0001d0;ooo`030?ooo`0;0=nLB00007@0
_ooo0?oog`2LB000001d0;ooo`3oool0oooO09a80018W=l0103oool01@3OW4P0001d0;ooo`3oool0
okmd00<0000000P0B9cO0?ooo`3oool0oooo0?oog`2LB00004RL0=ooo`D0oooo00T0gia80018W03O
ool0okmd07Boo`3oool0okmd0000M02oool00P3oool00`3ookl0M00004RLg`020?ooo`030;md0000
M;l0oooo0080oooo00<0oono07@00018W=l0103oool01`3OW4P004RL0=ooo`3o_g@0M;oo0?ooo`3o
_g@00`0000000`18W=l0oooo0?ooo`040?ooo`040?oog`2LB00004RL0=ooo`D0oooo00<0gia80000
0018W=l0103oool01`3OW4P0001d0;ooo`3oool0okmd0000M02oool01P3oool00`3ookl0M00004RL
g`030?ooo`030;md0018W=l0oooo0080oooo00L0_g@004RLg`3oool0oooo0?noM00007@0_ooo0080
oooo00<0oono07@00018W=l00P3oool00`2oM00007Bo0?ooo`020?ooo`030?oo_`1d0000B9cO0080
oooo00<0okmd0000M02oool00`3oool02`3OW4P0001d0;ooo`3ooml0W4P00000M02oool0oooo0?oo
g`2LB000B9cO00@0oooo00<0gia80000M02oool0A03oool008`0oooo00<0oooO09a80000M;l00`3o
ool00`2oW9`0gooo0?ooo`020?ooo`030;md0018M7@0M9cO00<0oooo00l0oono07@0B02Lgol0oooo
0=nLB0000000B9cO0?ooo`3ookl0M01809cOo`3oool0gia800000018W=l01@3oool0103ookl0M000
0018W03Oool80?ooo`030?oo_`1d0000M;oo00<0oooo00L0omnL04P0B02Lgol0oooo0=nLB000B4P0
B7Bo0080oooo00<0_g@0001d_`3oool00P3oool00`3o_g@0001809cOo`020?ooo`070?oo_`1d04P0
W=oo0?ooo`3OW4P0000004RLg`020?ooo`030;md0018M7@0M9cO00D0oooo00T0_g@00018W03Oool0
oooo0;mdM02oool0oono07@0001d_ol00`3oool01`2oM00004RL0=ooo`3oool0gia80018W03Oool0
0`3oool00`2oM00004RL0=ooo`030?ooo`0=0;md0000B9`0gooo0?ooo`2oM7@0_ooo0?oo_`1d04P0
W=oo0?ooo`3OW4P0000004RLg`040?ooo`040?oo_`1d000004RL0=ooo`D0oooo00@0oono07@00000
07@0_ooo0P3oool00`3o_g@0001809cOo`020?ooo`030?oo_`1d0000M;oo00L0oooo00<0_g@00018
W03Oool00P3oool00`3OW4P004RL0=ooo`020?ooo`070=nLB000B9`0gooo0?ooo`3ookl0M00007Bo
o`030?ooo`070;md0000B9`0gooo0?ooo`3OW4P004RL0=ooo`030?ooo`070;md0000B9`0gooo0?oo
o`3ookl0M00007Boo`030?ooo`070?oOW01804P0W=oo0?ooo`3OW4P004Q804Qd_`020?ooo`030;md
0000M;l0oooo0080oooo00<0okmd0000B02Lgol0A@3oool008d0oooo00L0_g@00018W03Oool0oooo
0?oog`2LB4P0W=oo00<0oooo00@0okmd0018W02oW4P0M;oo0`3oool03`3o_g@004RL0=ooo`3oool0
oono07@00018W=l0oooo0?noM000B9`0gooo0?ooo`3ookl0M00004RLg`040?ooo`040?oog`2LB000
001d0;ooo`T0oooo00<0gia80000M02oool00P3oool0803ookl0M00007Boo`3oool0okmd0000M02o
_g@0B9cO0?ooo`3o_g@0001d0;ooo`3oool0omnL04P0B02Lgol0oooo0=nLM02Lgol0oooo0?noM000
B9`0gooo0?ooo`3ookl0M00004RLg`3oool0okmd0018W02oW4P0M;oo0`3oool00`3ooml0W4P0001d
_`020?ooo`060?oOW01dW=l0oooo0?noM00007@0_ooo0P3oool01`3OW4P0001d0;ooo`3oool0omnL
04P0B02Lgol00`3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo0080oooo00X0omnL
07BLg`3oool0okmd0018W03Oool0oooo0?oo_`1d0000B9cO0`3oool0103ooml0W4P00000B02Lgol6
0?ooo`0B0=nLB0000000B9cO0?ooo`3ogi`0B01809cOo`3oool0giad09cOo`3oool0gia80000M02o
ool0oooo0?oo_`1d0000M;oo0P3oool00`3OW4P0001809cOo`020?ooo`030?oOW01807@0_ooo0080
oooo00<0omnL04P0M02oool00P3oool00`3o_g@0001d0;ooo`020?ooo`070=nLB00007@0_ooo0?oo
o`3ogi`0B01809cOo`030?ooo`030=nLB00004P0W=oo0080oooo00<0gia80000M02oool00P3oool0
4`3ookl0M00007Boo`3oool0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;ooo`3oool0omnL04P0
B02Lgol0oooo0=nLM02Lgol0@`3oool008d0oooo00<0okmd0000000000000`0000006`1d_ol0oooo
0?ooo`3oool0oono07@0B02Lgol0_g@007AdM000B9`0gooo0?ooo`3OW4P0001d0;ooo`3oool0gia8
0018W03Oool0oooo0=nLB00007@0_ooo0?ooo`3OW4P004RL0=ooo`040?ooo`030;md000004P0W=oo
00X0oooo01L0_g@00000M02oool0oooo0?noM00007@0_ooo0?ooo`3ooml0W4P007Boo`3OW4P007Bo
0?oOW01804P0W=oo0?ooo`3ogi`0B01809cOo`3ooml0W4P007Boo`020?ooo`0A0=nLB00007@0_ooo
0?ooo`3OW4P004RL0=ooo`3ookl0M01809cOo`2oM000M7Ad0018W03Oool0omnL04P00018W=l00P3o
ool03`3o_g@004RL0=ooo`3oool0gia80000M02oool0oooo0;md000004P0W=oo0?ooo`3ooml0W4P0
04RLg`030?ooo`030?oOW0180000B9cO0080oooo00<0omnL04P00018W=l00P3oool02`3o_g@004RL
0=ooo`3oool0gia80000M02oool0oooo0=nLB000B9`0gooo00<0oooo00<0gia800000018W=l01P3o
ool02P3ogi`0B0000018W03Oool0omnL04P0B02Lgol0oooO09a8001d_ol20?ooo`060;md000007@0
_ooo0?ooo`3OW4P0B9cO0P3oool00`3ogi`0B00004RLg`020?ooo`030?oo_`1d0000M;oo0080oooo
00<0oono07@0001d_ol00`3oool02`3OW4P0001d0;ooo`3oool0_g@00000B02Lgol0oooo0?oog`2L
B000B9cO00<0oooo00<0omnL04P00018W=l00`3oool05`2oM000001d0;ooo`3oool0okmd0000M02o
ool0oooo0?oog`2LB000M;oo0=nLB000M;l0omnL04P0B02Lgol0oooo0?oOW01804P0W=oo0?oog`2L
B000M;oo04<0oooo002=0?ooo`030?oo_`1d0000M;oo0080oooo00`0gia804RLg`3oool0oooo0?oO
W0180000000007Boo`3oool0_g@00000M02oool20?ooo`050?oOW018000000000000001d_ol00`3o
ool01@3ogi`0B000000000000000M;oo00D0oooo00<0okmd00000000M;l02`3oool03`3o_g@00000
000000000000M;oo0?ooo`3ookl0M00000000018W=l0oooo0?noM0000000001809cOo`020?ooo`05
0;md00000000000000000018W=l00`3oool05@3ogi`0B000000000000000M;oo0?oOW01800000000
07Boo`3oool0_g@00000M01dM00000000000B02Lgol0oooo0?oog`2LB00004RL0=ooo`020?ooo`08
0?oOW0180000000004RLW01d0000B9cO0?oo_`1d00030000000?07Boo`3o_g@0000000000000B9`0
gooo0;md00000000001809cOo`3oool0oooO09a80000B9`0gooo0080oooo00D0omnL04P000000000
000007Boo`040?ooo`040?oo_`1d000004RL0=ooo`D0oooo00H0oooO09a80000B9`0gooo0?ooo`2o
M0030000000;04RLg`3oool0oooo0?ooo`3ogi`0B0000000000004P0W=oo0?ooo`3o_g@00P000000
1P00B9`0gooo0?ooo`3oool0_g@004RLg`<0oooo00<0_g@004RLg`3oool00`3oool0203ogi`0B000
00000018W9`0M00004RLg`3ookl0M0000`0000001P1d_ol0okmd00000000000004RL0=ooo`<0oooo
00l0okmd000000000000000007Boo`3oool0oono07@000000000B9cO0?ooo`3o_g@000000000B02L
gol00P3oool01@2oM0000000000000000000B9cO04<0oooo002=0?ooo`030?oog`2LB00007Bo0080
oooo00<0oooO09adW03Oool07P3oool00`2oM000001809cOo`050?ooo`030?oo_`1dM;l0oooo03X0
oooo00<0okmd0000M02oool06`3oool00`3o_g@0000004RLg`050?ooo`040?oog`2LB00004RL0=oo
oaH0oooo00<0gia80018W03Oool00P3oool00`3OW4P004RL0=ooo`0;0?ooo`030?noM00007@0_ooo
0680oooo002>0?ooo`030=nLB000B9`0gooo00@0oooo00<0omnL09boo`3oool06`3oool0103ookl0
M0000000M02oool40?ooo`030?oOW018B9`0gooo03/0oooo00<0giad09cOo`3oool06`3oool00`3O
W4P0000007Boo`040?ooo`030?oo_`1d000007Bo01L0oooo00<0omnL04P0M02oool00P3oool00`3o
gi`0B01d0;ooo`0<0?ooo`030=nLM02Lgol0oooo0640oooo002>0?ooo`030?noM00004P0W=oo00@0
oooo00<0gia8001d_`3oool0703oool0103ooml0W4P00000001d_ol20?ooo`040?oog`2LB0000018
09cOod00oooo00@0oono07@00000B9`0gooo5P3oool00`3o_g@00000001d_`020?ooo`040?oog`2L
B000001809cOoa80oooo00P0oono07@00000B9`0gooo0?ooo`3ooml0W4P007Boo`80oooo00<0oooO
09a8001d_ol04@3oool0103ookl0M0000018W03OoomK0?ooo`00S@3oool00`2oM000000000000006
000000030000M02oool0oooo01d0oooo00P0oono07@00000000000000000B02Lgol0okmd07Booe`0
oooo00H0_g@000000000000000000000M02ooolI0?ooo`030=nLB018W=l0oooo0080oooo00<0gia8
04RLg`3oool0K`3oool00?l0oooo>03oool02@3ooml0W4P000000000M;l0oooo0?oog`2LB0000000
001d_`1`0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-3.93373, -2.1461, 0.0234865, \
0.0141648}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Driven undamped oscillator", "Subsection"],

Cell[CellGroupData[{

Cell["Harmonic oscillator", "Subsubsection"],

Cell["\<\
If the natural and driving frequencies are commensurate (in other words, \
their ratio is rational), we find closed curves in phase space with multiple \
periodicities.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(duffingPlot[1, 0, 0, 1, 0.25, 0, 0, 0, 50, MaxSteps \[Rule] 2000, 
        PlotPoints \[Rule] 100];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.535554 0.23988 0.500001 0.362582 [
[.05579 -0.0125 -9.34375 -15.6875 ]
[.05579 -0.0125 9.34375 0 ]
[.29567 -0.0125 -9.34375 -15.6875 ]
[.29567 -0.0125 9.34375 0 ]
[.53555 -0.0125 -5 -15.6875 ]
[.53555 -0.0125 5 0 ]
[.77543 -0.0125 -5 -15.6875 ]
[.77543 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.9688 -31.375 ]
[.5 -0.0125 21.9688 -15.6875 ]
[-0.0125 .13742 -18.6875 -7.84375 ]
[-0.0125 .13742 0 7.84375 ]
[-0.0125 .31871 -27.6875 -7.84375 ]
[-0.0125 .31871 0 7.84375 ]
[-0.0125 .5 -10 -7.84375 ]
[-0.0125 .5 0 7.84375 ]
[-0.0125 .68129 -19 -7.84375 ]
[-0.0125 .68129 0 7.84375 ]
[-0.0125 .86258 -10 -7.84375 ]
[-0.0125 .86258 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -43.375 -20.4688 ]
[-0.01875 .5 -27.6875 20.4688 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -43.9375 0 ]
[.5 1.0125 43.9375 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05579 0 m
.05579 .00625 L
s
gsave
.05579 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.29567 0 m
.29567 .00625 L
s
gsave
.29567 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.53555 0 m
.53555 .00625 L
s
gsave
.53555 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.77543 0 m
.77543 .00625 L
s
gsave
.77543 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.10377 0 m
.10377 .00375 L
s
.15175 0 m
.15175 .00375 L
s
.19972 0 m
.19972 .00375 L
s
.2477 0 m
.2477 .00375 L
s
.34365 0 m
.34365 .00375 L
s
.39163 0 m
.39163 .00375 L
s
.4396 0 m
.4396 .00375 L
s
.48758 0 m
.48758 .00375 L
s
.58353 0 m
.58353 .00375 L
s
.63151 0 m
.63151 .00375 L
s
.67948 0 m
.67948 .00375 L
s
.72746 0 m
.72746 .00375 L
s
.00782 0 m
.00782 .00375 L
s
.82341 0 m
.82341 .00375 L
s
.87139 0 m
.87139 .00375 L
s
.91936 0 m
.91936 .00375 L
s
.96734 0 m
.96734 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.9688 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
102.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .13742 m
.00625 .13742 L
s
gsave
-0.0125 .13742 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .31871 m
.00625 .31871 L
s
gsave
-0.0125 .31871 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .68129 m
.00625 .68129 L
s
gsave
-0.0125 .68129 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .86258 m
.00625 .86258 L
s
gsave
-0.0125 .86258 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .17368 m
.00375 .17368 L
s
0 .20994 m
.00375 .20994 L
s
0 .24619 m
.00375 .24619 L
s
0 .28245 m
.00375 .28245 L
s
0 .35497 m
.00375 .35497 L
s
0 .39123 m
.00375 .39123 L
s
0 .42748 m
.00375 .42748 L
s
0 .46374 m
.00375 .46374 L
s
0 .53626 m
.00375 .53626 L
s
0 .57252 m
.00375 .57252 L
s
0 .60878 m
.00375 .60878 L
s
0 .64503 m
.00375 .64503 L
s
0 .71755 m
.00375 .71755 L
s
0 .75381 m
.00375 .75381 L
s
0 .79007 m
.00375 .79007 L
s
0 .82632 m
.00375 .82632 L
s
0 .10116 m
.00375 .10116 L
s
0 .0649 m
.00375 .0649 L
s
0 .02864 m
.00375 .02864 L
s
0 .89884 m
.00375 .89884 L
s
0 .9351 m
.00375 .9351 L
s
0 .97136 m
.00375 .97136 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -117 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
81.4688 11.8438 translate
90 rotate
-81.4688 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(velocity) show
99.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.05579 .99375 m
.05579 1 L
s
.29567 .99375 m
.29567 1 L
s
.53555 .99375 m
.53555 1 L
s
.77543 .99375 m
.77543 1 L
s
.125 Mabswid
.10377 .99625 m
.10377 1 L
s
.15175 .99625 m
.15175 1 L
s
.19972 .99625 m
.19972 1 L
s
.2477 .99625 m
.2477 1 L
s
.34365 .99625 m
.34365 1 L
s
.39163 .99625 m
.39163 1 L
s
.4396 .99625 m
.4396 1 L
s
.48758 .99625 m
.48758 1 L
s
.58353 .99625 m
.58353 1 L
s
.63151 .99625 m
.63151 1 L
s
.67948 .99625 m
.67948 1 L
s
.72746 .99625 m
.72746 1 L
s
.00782 .99625 m
.00782 1 L
s
.82341 .99625 m
.82341 1 L
s
.87139 .99625 m
.87139 1 L
s
.91936 .99625 m
.91936 1 L
s
.96734 .99625 m
.96734 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .13742 m
1 .13742 L
s
.99375 .31871 m
1 .31871 L
s
.99375 .5 m
1 .5 L
s
.99375 .68129 m
1 .68129 L
s
.99375 .86258 m
1 .86258 L
s
.125 Mabswid
.99625 .17368 m
1 .17368 L
s
.99625 .20994 m
1 .20994 L
s
.99625 .24619 m
1 .24619 L
s
.99625 .28245 m
1 .28245 L
s
.99625 .35497 m
1 .35497 L
s
.99625 .39123 m
1 .39123 L
s
.99625 .42748 m
1 .42748 L
s
.99625 .46374 m
1 .46374 L
s
.99625 .53626 m
1 .53626 L
s
.99625 .57252 m
1 .57252 L
s
.99625 .60878 m
1 .60878 L
s
.99625 .64503 m
1 .64503 L
s
.99625 .71755 m
1 .71755 L
s
.99625 .75381 m
1 .75381 L
s
.99625 .79007 m
1 .79007 L
s
.99625 .82632 m
1 .82632 L
s
.99625 .10116 m
1 .10116 L
s
.99625 .0649 m
1 .0649 L
s
.99625 .02864 m
1 .02864 L
s
.99625 .89884 m
1 .89884 L
s
.99625 .9351 m
1 .9351 L
s
.99625 .97136 m
1 .97136 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .5 m
1 .5 L
s
.53555 0 m
.53555 1 L
s
gsave
.5 1.0125 -104.938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Duffing) show
102.938 15.813 moveto
(Equation) show
146.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.53555 .5 m
.53558 .50543 L
.53565 .51036 L
.53579 .51605 L
.53597 .52143 L
.53643 .53098 L
.53712 .54133 L
.5381 .55267 L
.5394 .56464 L
.54239 .58591 L
.54636 .60752 L
.55087 .62737 L
.56394 .67075 L
.58103 .71172 L
.59973 .74562 L
.62454 .77976 L
.65085 .80659 L
.6764 .8256 L
.69129 .83397 L
.70509 .84011 L
.7182 .84458 L
.72566 .84654 L
.73255 .848 L
.73862 .84899 L
.74211 .84944 L
.7453 .84978 L
.74867 .85006 L
.75228 .85026 L
.75563 .85037 L
.75881 .8504 L
.76217 .85035 L
.76579 .85021 L
.76921 .84999 L
.77234 .84972 L
.77581 .84933 L
.77959 .8488 L
.78721 .84744 L
.79471 .84567 L
.80267 .84333 L
.81685 .83795 L
.83084 .83105 L
.84375 .82317 L
.86697 .80497 L
.89093 .77974 L
.91382 .74761 L
.931 .71614 L
.94705 .67769 L
.95437 .65547 L
.96039 .63352 L
.96506 .61292 L
Mistroke
.96916 .59038 L
.97108 .57732 L
.97256 .56535 L
.97381 .55306 L
.97473 .54166 L
.97515 .53525 L
.97553 .52819 L
.97582 .52107 L
.97594 .51717 L
.97604 .51353 L
.97611 .51006 L
.97615 .50678 L
.97619 .50061 L
.97616 .49396 L
.97611 .49019 L
.97604 .48671 L
.97588 .48067 L
.97565 .47431 L
.97506 .46293 L
.97419 .45065 L
.97296 .43723 L
.97 .41312 L
.9664 .3908 L
.9551 .34032 L
.94695 .31268 L
.93844 .28812 L
.89694 .20102 L
.86765 .15757 L
.83736 .12203 L
.80739 .09393 L
.77305 .06864 L
.75248 .05655 L
.73325 .04711 L
.71465 .0396 L
.69458 .03319 L
.676 .02877 L
.66535 .02687 L
.65531 .02551 L
.65084 .02503 L
.64612 .02461 L
.64203 .02432 L
.63767 .02408 L
.63296 .0239 L
.62857 .02382 L
.62335 .02382 L
.6186 .02392 L
.61342 .02412 L
.61081 .02427 L
.60794 .02446 L
.59811 .02535 L
Mistroke
.59259 .02602 L
.58667 .02688 L
.57599 .02878 L
.5552 .03381 L
.53642 .0399 L
.4989 .05672 L
.46553 .07734 L
.43095 .10518 L
.39694 .14031 L
.3674 .17888 L
.33943 .22503 L
.31716 .27202 L
.30044 .31742 L
.29365 .34007 L
.28739 .36461 L
.28281 .38597 L
.27873 .40927 L
.27669 .42348 L
.27512 .43659 L
.27392 .44886 L
.27288 .46234 L
.27254 .46812 L
.27223 .47434 L
.272 .48019 L
.27184 .48554 L
.27172 .49123 L
.27166 .49743 L
.27165 .50056 L
.27167 .50388 L
.27174 .50986 L
.27187 .51571 L
.27198 .51903 L
.27209 .52212 L
.2724 .52886 L
.27275 .53497 L
.27356 .54595 L
.27467 .55761 L
.27805 .58312 L
.28237 .60649 L
.29264 .64579 L
.29981 .66648 L
.30729 .68456 L
.32533 .71873 L
.34487 .74578 L
.36417 .76551 L
.37556 .77456 L
.38649 .78167 L
.39753 .78743 L
.40957 .79218 L
.41652 .79422 L
Mistroke
.42312 .7957 L
.42908 .79666 L
.43245 .79705 L
.43556 .79731 L
.43859 .79747 L
.44186 .79754 L
.44494 .79751 L
.44776 .7974 L
.45105 .79717 L
.45291 .797 L
.45463 .7968 L
.46116 .79581 L
.46468 .79509 L
.468 .7943 L
.47417 .79254 L
.48785 .78722 L
.49898 .78137 L
.51092 .77349 L
.53382 .75307 L
.55324 .72906 L
.56947 .70255 L
.58575 .66698 L
.59257 .64786 L
.59812 .62933 L
.60645 .59279 L
.60971 .57264 L
.61109 .56201 L
.6123 .55067 L
.61319 .54022 L
.61358 .53464 L
.61393 .52866 L
.6142 .52312 L
.61439 .51807 L
.61454 .51297 L
.61463 .50815 L
.61468 .5025 L
.61468 .49649 L
.61462 .49135 L
.6145 .48568 L
.61431 .47958 L
.61403 .47301 L
.61333 .46111 L
.61245 .4501 L
.61125 .43808 L
.6084 .41621 L
.6048 .39498 L
.60074 .37542 L
.58746 .32702 L
.5711 .28334 L
.55336 .24629 L
Mistroke
.53117 .20915 L
.50428 .17346 L
.47658 .14445 L
.44538 .11913 L
.42819 .10799 L
.40898 .09767 L
.39035 .08965 L
.37285 .08382 L
.35591 .07968 L
.3473 .07813 L
.34267 .07745 L
.33778 .07685 L
.33368 .07644 L
.3292 .07608 L
.32511 .07584 L
.32132 .07569 L
.31682 .07561 L
.31273 .07562 L
.30802 .07573 L
.30357 .07594 L
.29968 .07621 L
.29556 .07656 L
.28819 .07742 L
.28028 .07864 L
.27162 .08034 L
.25326 .08523 L
.23607 .09143 L
.20467 .1071 L
.17248 .12968 L
.13987 .16062 L
.11429 .19216 L
.08912 .23178 L
.06674 .27783 L
.0497 .32474 L
.03719 .3726 L
.03241 .39743 L
.03013 .41185 L
.02837 .42506 L
.02707 .43651 L
.02591 .44899 L
.02496 .46222 L
.02463 .46818 L
.02432 .47476 L
.02411 .48083 L
.02396 .48652 L
.02385 .49253 L
.02381 .499 L
.02383 .50499 L
.0239 .51069 L
.02401 .5158 L
Mistroke
.02418 .52138 L
.02446 .52832 L
.02478 .5347 L
.02575 .54908 L
.02689 .5617 L
.02837 .57497 L
.03162 .59781 L
.03616 .62252 L
.04979 .67556 L
.06677 .72224 L
.08833 .76679 L
.1122 .8049 L
.13618 .83527 L
.16466 .86371 L
.19439 .88646 L
.22904 .90557 L
.24702 .91271 L
.25657 .91579 L
.2667 .91853 L
.27565 .9205 L
.28549 .9222 L
.28983 .9228 L
.29446 .92333 L
.29878 .92373 L
.30283 .92401 L
.30723 .92424 L
.30957 .92432 L
.31208 .92437 L
.31471 .9244 L
.3172 .92439 L
.32188 .92429 L
.32624 .9241 L
.33028 .92384 L
.3347 .92347 L
.33941 .92296 L
.35009 .92141 L
.36009 .91943 L
.37863 .91443 L
.39612 .90807 L
.41192 .90089 L
.44638 .88017 L
.47666 .85548 L
.50288 .82819 L
.53065 .79164 L
.55373 .75304 L
.5729 .71238 L
.58982 .66553 L
.59593 .64419 L
.60148 .62124 L
.60574 .59992 L
Mistroke
.60902 .57952 L
.61048 .56849 L
.61183 .55644 L
.61284 .54536 L
.61357 .53533 L
.6139 .52962 L
.61419 .52345 L
.61433 .52006 L
.61443 .51694 L
.61458 .51082 L
.61466 .50557 L
.61469 .49982 L
.61465 .49384 L
.61456 .48827 L
.61443 .48306 L
.61422 .4774 L
.6137 .46718 L
.613 .45731 L
.6122 .44825 L
.6098 .42802 L
.60641 .40704 L
.60217 .38668 L
.59756 .36863 L
.58474 .33046 L
.57088 .30012 L
.55397 .27199 L
.53467 .24783 L
.52329 .23661 L
.51211 .2274 L
.50138 .22007 L
.48944 .21354 L
.47838 .20889 L
.46803 .20571 L
.46198 .20435 L
.45642 .20343 L
.45335 .20305 L
.45172 .20289 L
.44999 .20275 L
.44681 .20256 L
.44387 .20247 L
.44092 .20247 L
.43773 .20257 L
.43472 .20275 L
.43196 .203 L
.42946 .20329 L
.42673 .20368 L
.42121 .20468 L
.41453 .20632 L
.40847 .2082 L
.39503 .21375 L
Mistroke
.38284 .22054 L
.3716 .2284 L
.35025 .24811 L
.32959 .27464 L
.31394 .30154 L
.29913 .33532 L
.29269 .35405 L
.28677 .37475 L
.28239 .3934 L
.27851 .41401 L
.27669 .42597 L
.27527 .437 L
.27406 .44837 L
.27317 .45897 L
.27238 .47151 L
.27208 .47816 L
.27196 .48157 L
.27185 .48524 L
.27172 .49142 L
.27166 .49723 L
.27165 .50078 L
.27167 .50416 L
.27175 .51052 L
.27189 .51656 L
.272 .51997 L
.27212 .5231 L
.27272 .535 L
.27348 .54587 L
.2745 .55736 L
.27735 .58138 L
.28161 .60773 L
.29213 .65435 L
.30527 .69696 L
.32483 .74553 L
.34717 .78891 L
.39818 .86112 L
.42898 .89302 L
.46428 .92177 L
.49621 .94182 L
.53289 .95879 L
.55311 .96559 L
.56318 .96833 L
.57258 .97052 L
.58181 .97231 L
.59021 .97365 L
.59956 .97481 L
.6047 .97529 L
.60955 .97565 L
.6144 .97592 L
.61716 .97604 L
Mistroke
.61973 .97611 L
.62492 .97619 L
.62783 .97619 L
.63049 .97615 L
.63523 .97603 L
.64038 .97579 L
.64524 .97546 L
.64974 .97508 L
.65973 .97394 L
.67072 .97223 L
.68216 .96992 L
.69284 .96728 L
.731 .95388 L
.74971 .94493 L
.76971 .93347 L
.83347 .88197 L
.86499 .8459 L
.89075 .80908 L
.91699 .76194 L
.93719 .7152 L
.9523 .66974 L
.96435 .62005 L
.96896 .59391 L
.97225 .56933 L
.97369 .55523 L
.97472 .54235 L
.97517 .53524 L
.97557 .52751 L
.97585 .52021 L
.97604 .51346 L
.97615 .50688 L
.97618 .50358 L
.97619 .49996 L
.97616 .49356 L
.97606 .48761 L
.97598 .484 L
.97588 .4806 L
.97564 .47423 L
.9753 .46741 L
.97485 .46002 L
.97387 .44757 L
.97255 .43449 L
.96944 .41137 L
.96561 .3898 L
.96128 .37009 L
.94882 .32733 L
.93282 .28769 L
.91263 .25048 L
.89298 .22278 L
.86934 .19721 L
Mistroke
.85556 .1854 L
.84211 .17575 L
.82956 .16825 L
.816 .16168 L
.80886 .15882 L
.80095 .15612 L
.79362 .15405 L
.7869 .1525 L
.77893 .1511 L
.77453 .15052 L
.77035 .1501 L
.76649 .14983 L
.76292 .14967 L
.76105 .14962 L
.75899 .1496 L
.75684 .14961 L
.75482 .14965 L
.75137 .14978 L
.74767 .15002 L
.74419 .15033 L
.74102 .15069 L
.73328 .15187 L
.72599 .15338 L
.71159 .15751 L
.69621 .16367 L
.68311 .1704 L
.66955 .1789 L
.64622 .19756 L
.62317 .22188 L
.60073 .2528 L
.58215 .28601 L
.5676 .31936 L
.55427 .35976 L
.54499 .39937 L
.54105 .42287 L
.53838 .44449 L
.53728 .45657 L
.53681 .46295 L
.53639 .4697 L
.5361 .47563 L
.53584 .48214 L
.53568 .48807 L
.53559 .4936 L
.53555 .49942 L
.53556 .50236 L
.53558 .50561 L
.53567 .51134 L
.53581 .51671 L
.53604 .52302 L
.53631 .52879 L
Mistroke
.53715 .54176 L
.53806 .55231 L
.5393 .56378 L
.54251 .58667 L
.54631 .60729 L
.55125 .62887 L
.56238 .6663 L
.57848 .70634 L
.59965 .74549 L
.62279 .77766 L
.64644 .80264 L
.67202 .82277 L
.69724 .8368 L
.71213 .84267 L
.72592 .8466 L
.7336 .84819 L
.73767 .84885 L
.742 .84943 L
.74618 .84986 L
.74996 .85014 L
.75377 .85032 L
.75735 .8504 L
.76079 .85038 L
.76448 .85027 L
.76796 .85008 L
.77113 .84983 L
.77485 .84944 L
.77888 .84891 L
.78618 .84765 L
.79379 .84591 L
.80182 .84361 L
.81607 .83829 L
.82888 .83211 L
.84066 .82519 L
.86644 .80545 L
.89197 .77847 L
.91385 .74756 L
.93115 .71584 L
.94717 .67735 L
.9546 .6547 L
.96065 .63249 L
.96532 .61163 L
.96938 .58898 L
.97113 .57697 L
.97275 .56364 L
.97398 .55124 L
.97486 .53983 L
.97526 .53334 L
.97561 .52624 L
.97577 .52234 L
Mistroke
.9759 .51872 L
.976 .51503 L
.97608 .51156 L
.97617 .50543 L
.97619 .50216 L
.97619 .49863 L
.97617 .49513 L
.97613 .49144 L
.976 .48482 L
.97581 .47853 L
.97553 .47169 L
.97482 .45925 L
.97389 .44712 L
.97282 .43592 L
.96962 .41049 L
.96508 .38367 L
.95488 .3395 L
.93995 .29224 L
.92014 .24462 L
.89856 .20375 L
.8695 .16001 L
.83917 .12393 L
.80624 .09297 L
.77435 .06948 L
.73704 .04883 L
.71591 .04006 L
.69568 .0335 L
.67726 .02903 L
.66674 .0271 L
.65689 .02569 L
.65154 .0251 L
.64646 .02463 L
.6419 .02431 L
.63695 .02404 L
.63438 .02395 L
.63155 .02387 L
.62859 .02382 L
.62582 .02381 L
.62087 .02386 L
.61809 .02393 L
.61554 .02403 L
.61122 .02424 L
.60661 .02456 L
.59831 .02533 L
.58847 .0266 L
.57957 .02809 L
.56028 .03242 L
.54227 .03784 L
.50498 .05356 L
.48673 .06359 L
Mistroke
.46719 .07618 L
.40533 .13082 L
.37524 .16778 L
.35068 .20509 L
.32587 .25223 L
.30684 .2986 L
.2929 .3428 L
.28188 .39081 L
.27775 .41581 L
.27483 .43929 L
.27359 .45267 L
.27272 .46491 L
.27237 .47131 L
.27206 .47829 L
.27194 .4818 L
.27184 .48555 L
.27176 .48908 L
.27171 .49229 L
.27166 .49799 L
.27166 .50331 L
.27173 .50913 L
.27186 .51536 L
.27196 .51846 L
.27208 .52184 L
.27235 .52797 L
.27305 .53938 L
.27391 .55002 L
.27507 .56123 L
.27772 .58102 L
.28213 .60533 L
.28731 .62733 L
.29953 .66573 L
.31458 .69972 L
.33332 .73079 L
.35128 .753 L
.3727 .77245 L
.38491 .78074 L
.39679 .78709 L
.40765 .79152 L
.41381 .79348 L
.41962 .79497 L
.42586 .79619 L
.42918 .79668 L
.43089 .79688 L
.43276 .79708 L
.43448 .79723 L
.43632 .79736 L
.43826 .79745 L
.44007 .79751 L
.44188 .79754 L
Mistroke
.44358 .79753 L
.44678 .79744 L
.44983 .79727 L
.45306 .79698 L
.45581 .79665 L
.45884 .79621 L
.46556 .79489 L
.47182 .79326 L
.48403 .7889 L
.49709 .78246 L
.50913 .77478 L
.51996 .76631 L
.53939 .7469 L
.55827 .72157 L
.57615 .68931 L
.58436 .67049 L
.59207 .64937 L
.59797 .62987 L
.60348 .60755 L
.60756 .58648 L
.61057 .56627 L
.61181 .55551 L
.6129 .54396 L
.61336 .53789 L
.6138 .53116 L
.61412 .52494 L
.61435 .51921 L
.61452 .5137 L
.61463 .50789 L
.61469 .50203 L
.61469 .49871 L
.61467 .49562 L
.6146 .48996 L
.61448 .48482 L
.61429 .47887 L
.61404 .47326 L
.61344 .46268 L
.61257 .45148 L
.61046 .43137 L
.60739 .40975 L
.60304 .38611 L
.59125 .33919 L
.57703 .29784 L
.5567 .25265 L
.53379 .21311 L
.5091 .17924 L
.48003 .14769 L
.45321 .12483 L
.42181 .10432 L
.40528 .09592 L
Mistroke
.38752 .0886 L
.37213 .08361 L
.3551 .07952 L
.3454 .07784 L
.33656 .07672 L
.33165 .07627 L
.32906 .07607 L
.32632 .07591 L
.32393 .07579 L
.32129 .07569 L
.31664 .07561 L
.31197 .07563 L
.3077 .07575 L
.30535 .07585 L
.30278 .07599 L
.2981 .07633 L
.29375 .07675 L
.28911 .0773 L
.2808 .07855 L
.27156 .08035 L
.26185 .08272 L
.24463 .08814 L
.22638 .09565 L
.20679 .10586 L
.17313 .12915 L
.1438 .1564 L
.11502 .19116 L
.0908 .22881 L
.07187 .26608 L
.05458 .30978 L
.04128 .35492 L
.03534 .38153 L
.03086 .40697 L
.02899 .42014 L
.02733 .43408 L
.02615 .44619 L
.02515 .45917 L
.02471 .46654 L
.02439 .47323 L
.02413 .47997 L
.02396 .48634 L
.02389 .48995 L
.02384 .49377 L
.02381 .50062 L
.02383 .50443 L
.02386 .508 L
.02392 .51191 L
.02402 .5161 L
.02424 .5231 L
.02451 .52942 L
Mistroke
.02534 .54356 L
.0264 .55661 L
.02765 .56884 L
.03134 .59609 L
.03668 .62504 L
.05 .67621 L
.0661 .72062 L
.086 .76252 L
.10752 .79814 L
.1341 .83289 L
.16553 .86447 L
.19796 .88877 L
.2171 .8998 L
.23521 .90822 L
.25132 .91416 L
.2693 .91914 L
.27842 .92103 L
.28346 .92189 L
.28827 .92259 L
.29272 .92314 L
.2976 .92363 L
.30203 .92396 L
.30615 .92419 L
.31074 .92435 L
.31305 .92438 L
.31559 .9244 L
.32008 .92434 L
.32427 .9242 L
.32681 .92407 L
.32922 .92392 L
.33373 .92356 L
.33858 .92306 L
.34385 .92238 L
.35274 .92093 L
.36216 .91896 L
.37895 .91433 L
.39475 .90863 L
.40937 .90215 L
.4417 .88342 L
.47246 .85931 L
.50247 .82866 L
.54868 .76228 L
.5682 .7233 L
.58548 .67895 L
.59822 .63523 L
.60668 .59452 L
.61007 .57175 L
.61154 .55928 L
.61265 .54762 L
.61341 .5377 L
Mistroke
.61403 .52706 L
.61429 .52102 L
.61448 .5153 L
.6146 .51017 L
.61467 .50459 L
.61469 .50144 L
.61469 .49805 L
.61467 .49485 L
.61463 .49191 L
.61452 .48635 L
.61434 .4805 L
.61408 .47423 L
.61377 .46841 L
.61283 .45527 L
.61176 .44399 L
.61058 .43382 L
.6072 .41143 L
.6032 .39118 L
.59806 .37044 L
.58667 .33542 L
.57154 .30138 L
.55178 .26889 L
.531 .244 L
.5103 .22606 L
.49894 .21861 L
.4862 .21204 L
.47967 .20936 L
.47263 .20699 L
.46595 .2052 L
.45985 .20396 L
.45706 .20352 L
.45407 .20313 L
.45078 .20281 L
.4477 .2026 L
.44604 .20253 L
.44424 .20248 L
.44096 .20247 L
.43777 .20257 L
.43482 .20275 L
.43208 .20299 L
.42951 .20328 L
.42367 .2042 L
.41799 .20541 L
.41189 .20709 L
.39897 .21192 L
.38562 .21884 L
.37451 .22621 L
.36271 .23579 L
.34086 .25912 L
.32294 .2852 L
Mistroke
.30503 .32058 L
.29808 .33818 L
.29127 .35866 L
.28607 .37749 L
.28133 .39857 L
.27731 .42168 L
.27585 .43229 L
.27449 .44403 L
.27341 .45578 L
.27264 .46681 L
.27234 .47228 L
.27211 .47746 L
.2719 .48345 L
.27176 .48891 L
.27169 .49401 L
.27165 .49942 L
.27167 .50405 L
.27173 .50915 L
.27184 .51466 L
.27202 .52058 L
.27225 .52619 L
.27251 .53131 L
.27322 .54245 L
.27425 .5548 L
.27715 .5799 L
.28079 .60319 L
.28506 .62502 L
.29763 .67361 L
.3157 .72445 L
.33555 .76757 L
.36111 .81169 L
.39214 .85399 L
.42355 .88789 L
.45779 .91704 L
.49217 .93958 L
.5302 .95775 L
.55225 .96533 L
.56299 .96829 L
.57285 .97058 L
.58174 .9723 L
.59145 .97382 L
.59679 .9745 L
.60175 .97502 L
.60679 .97546 L
.61154 .97578 L
.61598 .97599 L
.62078 .97614 L
.62514 .97619 L
.62915 .97617 L
.63351 .97608 L
Mistroke
.63828 .9759 L
.64326 .97561 L
.64789 .97525 L
.65861 .97409 L
.66873 .97258 L
.68756 .96865 L
.70763 .96284 L
.7291 .9547 L
.76452 .93664 L
.80164 .9108 L
.8377 .87761 L
.86852 .84128 L
.89653 .79967 L
.91965 .75642 L
.93723 .7151 L
.95283 .66789 L
.95974 .64129 L
.96516 .61591 L
.96915 .59266 L
.9724 .56799 L
.97369 .55514 L
.9748 .54105 L
.97519 .53487 L
.97553 .52826 L
.97579 .52206 L
.97597 .51634 L
.97605 .51287 L
.97612 .50919 L
.97617 .5055 L
.97619 .50143 L
.97619 .49794 L
.97616 .49418 L
.97612 .49063 L
.97606 .48738 L
.9759 .48129 L
.97565 .47464 L
.97532 .46772 L
.97493 .4613 L
.97394 .4483 L
.97276 .43642 L
.96922 .41 L
.96511 .3873 L
.95975 .36394 L
.94817 .32546 L
.93223 .28645 L
.91239 .2501 L
.89171 .22121 L
.86527 .1935 L
.85123 .1821 L
.83809 .1732 L
Mistroke
.82525 .166 L
.81109 .15967 L
.80319 .15684 L
.79587 .15464 L
.78839 .15282 L
.78138 .15148 L
.77533 .15062 L
.77193 .15025 L
.76883 .14998 L
.76543 .14977 L
.76174 .14964 L
.75825 .1496 L
.75502 .14964 L
.7517 .14976 L
.7486 .14995 L
.74519 .15023 L
.74152 .15063 L
.73406 .15173 L
.72725 .15309 L
.71345 .15689 L
.69892 .16245 L
.67348 .17627 L
.6585 .18706 L
.64487 .19881 L
.62092 .22462 L
.59954 .25468 L
.57981 .29085 L
.56556 .32478 L
.55291 .36476 L
.54395 .40494 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00g03oool00`3ooml0W4P0000000020000000307Bo
o`3oool0oooo0<`0oooo003N0?ooo`030?noM00007@0_ooo0<l0oooo003N0?ooo`030?oo_`1d0000
M;oo0<l0oooo003N0?ooo`030?oog`2LB000B9cO0<l0oooo003O0?ooo`030=nLB000000000000080
000000<0M;oo0?ooo`3oool00P3oool01@3o_g@000000000000004P0W=oo0080oooo00<0oono07@0
000000000P0000003@18W=l0oooo0?ooo`3oool0_g@00000000004P0W=oo0?ooo`3o_g@000000000
B02Lgol00P3oool0102oM00000000000B02Lgol20?ooo`050?noM000000000000000B02Lgol00`3o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000000007Bo09H0oooo003O0?ooo`070?noM00004P0
W=oo0?ooo`3ooml0W4P0001d_`020?ooo`0?0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`3oool0
oooO09a8001d_ol0oooo0?oOW0180000M;oo0080oooo01L0gia80018W03Ooml0W7BL0=ooo`3o_g@0
001809cOg`2LM9`0gooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0
B000001d_`020?ooo`030?noM00007@0_ooo0080oooo00@0gia80018W03O_g@0M;ooU@3oool00=l0
oooo00<0oono07@0001d_ol00P3oool01`3ooml0W4P004RLg`3oool0gia80018W03Oool00P3oool0
2P3ogi`0B00004RLg`3oool0_gAd0;ooo`3oool0oono07@0001d_ol20?ooo`030?noM00004P0W=oo
0080oooo00<0oono07@0001d_ol00`3oool00`3o_g@0001809cOo`020?ooo`030=nLB000B9`0gooo
0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol0UP3o
ool00=l0oooo00<0oooO09a80018W=l00`3oool01P3ogi`0B01809cOo`3o_g@0001d0;ooo`<0oooo
00<0gia80000M02oool00`3oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo
00<0_g@0001d_`3oool00P3oool00`3ookl0M00004RLg`020?ooo`030?noM00007@0_ooo00<0oooo
00/0gia80000M02oool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`2F0?ooo`00h03oool0
0`3OW4P0001d0;ooo`020?ooo`060?oog`2LB000B9cO0?oo_`1d0000M;oo0`3oool00`3ogi`0B018
09cOo`020?ooo`030?noM00004P0W=oo00@0oooo00<0_g@00018W03Oool00P3oool00`3OW4P004RL
0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3ookl0M00007Boo`030?ooo`070?oOW01804P0W=oo
0?ooo`3OW4P004Q804Qd_`020?ooo`030;md0000M;l0oooo09D0oooo003P0?ooo`040?noM0000000
04RL0=ooo`80oooo00H0gia8001d_`3oool0gia80000M02oool20?ooo`0:0?oo_`1d0000M;oo0?oo
o`3ogi`0B01809cOo`3oool0giad09cOo`80oooo00<0gia80000B02Lgol00P3oool00`3ogi`0B018
09cOo`030?ooo`030=nLB00004P0W=oo0080oooo00<0gia80000M02oool00P3oool0303ookl0M000
07Boo`3oool0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;oooiD0oooo003P0?ooo`080?oo_`1d
0000M9bL04P0M02oool0oooO09a80000M;l20?ooo`0>0;md000007@0_ooo0?ooo`3o_g@0001d0;oo
o`3oool0omnL04P0B02Lgol0oooO09a8001d_ol20?ooo`030?oOW0180000B9cO0080oooo00<0oooO
09a80018W=l00`3oool00`3ogi`0B00004RLg`030?ooo`0@0;md000007@0_ooo0?ooo`3o_g@0001d
0;ooo`3oool0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOoiD0oooo003O0?ooo`090?oOW018
0000000004RLg`3ookl0M0000000000007@0_ooo00<0oooo00D0okmd000000000000000007Boo`03
0?ooo`070;md00000000000000000018W=l0oooo0?noM002000000040018W03Oool0oono07@000<0
000000H0M;oo0?noM000000000000018W03Oool30?ooo`0?0?noM000000000000000001d_ol0oooo
0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo09D0oooo003o0?ooo`40oooo00<0okmd
0000M02oool0[@3oool00?l0oooo0P3oool00`3OW7@0W=oo0?ooo`2/0?ooo`00n`3oool0103ookl0
M0000018W03Oool70?ooo`040?oo_`1d000004RL0=ooojH0oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo001Q0?ooo`030=nLB0000000000000<0000000<0B9cO0?ooo`3oool0B`3o
ool00`3ookl0M000000000020000000304RLg`3oool0oooo04P0oooo00@0_g@0000000000000M;oo
CP3oool00`3ookl0M000000000020000000304RLg`3oool0oooo0540oooo001R0?ooo`030?noM000
M;l0oooo0080oooo00<0_gAd0;ooo`3oool0C@3oool00`3o_g@0000007Boo`1:0?ooo`060=nLB000
M;l0oooo0?oOW0180000B9cOC`3oool00`3o_g@0000007Boo`1D0?ooo`00H`3oool00`3o_g@007Bo
0?ooo`1A0?ooo`030?oog`2LB00007Bo04T0oooo00<0oooO09a80018W=l00P3oool00`3o_g@00018
09cOo`1>0?ooo`030?oog`2LB00007Bo05@0oooo001T0?ooo`030?noM000M;l0oooo0540oooo00<0
gia80018W03Oool0B03oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooodh0oooo
00<0gia80018W03Oool0D`3oool005@0oooo00<0oooO09a8000000001`0000000`18W=l0oooo0?oo
o`040?ooo`030?noM018W=l0oooo0400oooo00<0oooO09a8000000001`0000000`18W=l0oooo0?oo
o`030?ooo`030?oOW01804P0W=oo04P0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cO
o`1>0?ooo`030?oOW01804P0W=oo05<0oooo001V0?ooo`030=nLB018W=l0oooo04l0oooo00<0oono
07@0001d_ol0B@3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO04h0oooo00<0oono
07@0001d_ol0D`3oool006L0oooo00<0_g@007Boo`3oool0C`3oool00`2oM00007Bo0?ooo`180?oo
o`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0C`3oool00`2oM00007Bo0?ooo`1B0?oo
o`00I`3oool00`3ogi`0B01d0;ooo`1?0?ooo`030=nLB000B9`0gooo04P0oooo00<0omnL04P00018
W=l00`3oool00`2oM00004RL0=ooo`1>0?ooo`030=nLB000B9`0gooo0580oooo001W0?ooo`030?oo
g`2LB000M;oo04l0oooo00<0omnL04P0B02Lgol0B03oool0103ooml0W4P00018W03Oool20?ooo`03
0=nLB000B9`0gooo04h0oooo00<0omnL04P0B02Lgol0DP3oool006L0oooo00<0oono07@00018W=l0
C`3oool00`3ookl0M00007Boo`190?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0
CP3oool00`3ookl0M00007Boo`1B0?ooo`00H`3oool01`3o_g@004RL0=ooo`3oool0gia80000B02L
gol0D03oool00`2oM00007Bo0?ooo`190?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cOD03oool0
0`2oM00007Bo0?ooo`1A0?ooo`00I03oool01@3ogi`0B000000000000000M;oo04l0oooo00D0oono
07@000000000001d0;ooo`1:0?ooo`040=nLB00000000000001d_dl0oooo00D0oono07@000000000
001d0;ooo`1A0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00B`3ooooo000006800000103oool004/0oooo00@000000?ooo`3oool00000403oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0540oooo
00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo0:40oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`2Q0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3o
ool0X@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`2i0?ooo`030000
003oool0oooo0:40oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0^@3o
ool00`000000oooo0?ooo`0H0?ooo`X00000O`3oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`2i0?ooo`030000003oool0oooo00h0oooo2P00000:0?ooo`/00000M03oool0
0`000000oooo0?ooo`020?ooo`00B`3oool200000;X0oooo00<000000?ooo`3oool02P3oool50000
01h0oooo1000001^0?ooo`<00000103oool004/0oooo00<000000?ooo`3oool0^@3oool00`000000
oooo0?ooo`050?ooo`D000009`3oool4000006`0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`020?ooo`@00000;P3oool4000006T0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0000
0003000003@0oooo1@00001U0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo0;T0oooo0`00000k0?ooo`@00000HP3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`00
0000oooo0?ooo`2g0?ooo`<00000@03oool300000600oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool0]03oool300000080oooo00<000000?ooo`3oool0@03oool3000005h0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0/P3oool3000000@0oooo
00<000000?ooo`3oool0@P3oool3000005`0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool0/03oool2000000L0oooo00<000000?ooo`3oool0A@3oool2000005X0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0[P3oool2000000T0oooo00<00000
0?ooo`3oool0A`3oool2000005P0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool0[03oool2000000/0oooo00<000000?ooo`3oool0B@3oool2000005H0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool0ZP3oool2000000d0oooo00<000000?ooo`3o
ool0B`3oool2000005@0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
Z03oool2000000l0oooo00<000000?ooo`3oool0C@3oool200000580oooo00<000000?ooo`3oool0
0P3oool004/0oooo0P00002W0?ooo`<00000403oool00`000000oooo0?ooo`1?0?ooo`800000CP3o
ool3000000@0oooo001;0?ooo`030000003oool0oooo0:D0oooo0P00000B0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0DP3oool00`00
0000oooo0?ooo`1<0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0:80
oooo0P00000E0?ooo`030000003oool0oooo05<0oooo0P00001<0?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo0640oooo6000000X0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo05/0oooo1`00000F0?ooo`D000008`3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`1H0?ooo`<000008P3oool5000001`0oooo0P00000I
0?ooo`030000003oool0oooo05L0oooo0P0000180?ooo`030000003oool0oooo0080oooo001;0?oo
o`030000003oool0oooo05D0oooo0`00000Z0?ooo`<00000603oool2000001X0oooo00<000000?oo
o`3oool0F03oool2000004L0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool0DP3oool3000002l0oooo1000000D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0F@3oool2000004H0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
D03oool3000003<0oooo1000000@0?ooo`8000007@3oool00`000000oooo0?ooo`1K0?ooo`800000
A03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1>0?ooo`<00000=`3o
ool4000000d0oooo0P00000N0?ooo`030000003oool0oooo05`0oooo0P0000130?ooo`030000003o
ool0oooo0080oooo001;0?ooo`030000003oool0oooo04`0oooo0`00000k0?ooo`@000002P3oool2
000001l0oooo00<000000?ooo`3oool0G@3oool200000480oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool0BP3oool200000400oooo100000060?ooo`<00000803oool00`00
0000oooo0?ooo`1N0?ooo`800000@@3oool00`000000oooo0?ooo`020?ooo`00B`3oool2000004T0
oooo0P0000140?ooo`<00000103oool00`000000oooo0000000Q0?ooo`030000003oool0oooo05l0
oooo0P00000n0?ooo`<00000103oool004/0oooo00<000000?ooo`3oool0AP3oool2000004P0oooo
0`000000103oool0000000000000000R0?ooo`030000003oool0oooo0600oooo0P00000o0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo04@0oooo0P00001<0?ooo`<00000
903oool00`000000oooo0?ooo`1Q0?ooo`800000?P3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`130?ooo`800000C@3oool4000002<0oooo00<000000?ooo`3oool0HP3o
ool2000003d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0@@3oool2
000004h0oooo0P0000020?ooo`<000008@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0@03oool20000
04h0oooo0P0000050?ooo`<000007`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0?P3oool3000004h0
oooo0P0000080?ooo`8000007P3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool00P3oool003/0oooo00<0oono07@0000000000P0000000`18W=l0oooo
0?ooo`080?ooo`030000003oool0oooo03d0oooo0P00001?0?ooo`8000002P3oool2000001d0oooo
00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0080oooo
000m0?ooo`030?noM0000000M;oo00/0oooo00<000000?ooo`3oool0>`3oool3000004l0oooo00<0
00000?ooo`3oool0303oool2000001/0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo0080oooo000m0?ooo`030?oog`2LB00007Bo00/0oooo00<00000
0?ooo`3oool0>P3oool3000004l0oooo00<000000?ooo`3oool03P3oool2000001X0oooo00<00000
0?ooo`3oool0J@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0080oooo000n0?oo
o`030=nLB000B9`0gooo00X0oooo00<000000?ooo`3oool0>@3oool200000500oooo00<000000?oo
o`3oool0403oool2000001T0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo0080oooo000^0?ooo`030?oog`2LB000000000L0000000<0B9cO0?ooo`3o
ool00`3oool00`3ogi`0B01809cOo`0:0?ooo`030000003oool0oooo03P0oooo0P00001@0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1[0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool00P3oool003h0oooo00<0oono07@0001d_ol0
2P3oool3000003L0oooo0P00001@0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo02l0oooo100000040?ooo`00?`3o
ool00`2oM00007Bo0?ooo`090?ooo`030000003oool0oooo03H0oooo0P00001@0?ooo`800000603o
ool2000001D0oooo00<000000?ooo`3oool0K03oool2000003<0oooo00<000000?ooo`3oool00P3o
ool003l0oooo00<0gia80018W03Oool02@3oool00`000000oooo0?ooo`0d0?ooo`800000D@3oool2
000001X0oooo0P00000D0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`020?ooo`00?`3oool00`3ogi`0B01809cOo`090?ooo`030000003oool0oooo
03<0oooo0P00001B0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`1^0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool00P3oool003l0
oooo00<0oono07@0001d_ol02@3oool00`000000oooo0?ooo`0b0?ooo`800000DP3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0K`3oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo0080oooo00100?ooo`030;md0000M;l0oooo00P0oooo
00<000000?ooo`3oool0<@3oool200000580oooo0P00000P0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0@P3ooolC000001/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`020?ooo`00?P3oool01@3ookl0M0000000000007@0_ooo00P0oooo00<000000?ooo`3oool0
<03oool200000580oooo0P00000R0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
?P3oool500000180oooo1@00000G0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0k0?ooo`@000006`3o
ool3000001D0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool08`3oool2
000000h0oooo00<000000?ooo`3oool0>@3oool200000240oooo1000000C0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`1B0?ooo`8000009P3oool2000000d0oooo00<000000?ooo`3oool0=`3oool20000
02H0oooo0`00000A0?ooo`800000;03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo03D0oooo0P00000[0?ooo`800000403oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0<`3oool2000002l0oooo0P00000>0?ooo`800000:`3oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0340oooo0P00
000c0?ooo`8000003@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo001;
0?ooo`800000:`3oool00`000000oooo0?ooo`1B0?ooo`800000;@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo02l0oooo0P00000f0?ooo`8000003@3oool00`000000oooo0?ooo`0V
0?ooo`<00000103oool004/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0]0?oo
o`800000>P3oool00`000000oooo0?ooo`0:0?ooo`800000:@3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`0X0?ooo`800000E03oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0;03oool2000003`0oooo0P00000;0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
9`3oool2000005@0oooo0P00000a0?ooo`8000001`3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo03h0oooo0P00000:0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1C0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Y0?ooo`800000@P3o
ool2000000T0oooo0P00000W0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`130?ooo`8000002@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
02D0oooo0P00001D0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo04H0oooo0P0000070?ooo`8000009P3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0T0?ooo`800000E@3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09@3oool2000004X0
oooo0P0000070?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo03L0oooo
0P0000030?ooo`030000003oool0oooo02@0oooo0P00001<0?ooo`8000001`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02<0oooo0P00
001D0?ooo`800000>P3oool01@000000oooo0?ooo`3oool0000002D0oooo0P00001>0?ooo`800000
1P3oool2000002@0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01P0oooo2P00000H0?ooo`040000003o
ool0oooo000002@0oooo0P00001@0?ooo`8000001P3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0D`3o
ool00`000000oooo0?ooo`0E0?ooo`@000002P3oool5000001@0oooo00<000000?ooo`0000008`3o
ool200000580oooo0P0000050?ooo`8000008`3oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`0Q0?ooo`800000E@3oool00`000000oooo0?ooo`0A0?ooo`D000004@3oool4
00000140oooo0`00000R0?ooo`800000D`3oool00`000000oooo000000050?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool00P3oool004/0oooo0P00000R0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool03`3oool3000001T0oooo0`00000@0?ooo`8000008P3oool00`00
0000oooo0?ooo`1C0?ooo`8000001@3oool200000200oooo0`0000040?ooo`00B`3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo05<0oooo0P00000@0?ooo`8000007@3oool3000000l0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1E0?ooo`8000001@3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0=0?ooo`8000008@3oool3000000d0oooo
0P00000O0?ooo`030000003oool0oooo05L0oooo0P0000040?ooo`8000008@3oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo05<0oooo0P00
000>0?ooo`800000903oool3000000/0oooo0P00000N0?ooo`030000003oool0oooo05T0oooo0P00
00040?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00/0oooo0P00000X
0?ooo`8000002P3oool3000001`0oooo00<000000?ooo`3oool0F`3oool2000000<0oooo0P00000P
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01d0oooo0P00001E0?oo
o`8000002`3oool3000002/0oooo0P0000080?ooo`030000003oool0000001/0oooo00<000000?oo
o`3oool0G@3oool2000000<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool02@3oool2000002l0oooo00<000000?ooo`3oool01@3oool010000000oooo00000000000I0?oo
o`800000H03oool010000000oooo0?ooo`3oool2000001l0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1D0?ooo`8000002@3oool20000
0380oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000I0?ooo`030000003oool0
oooo05l0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
00L0oooo0P00000d0?ooo`800000103oool00`000000oooo0?ooo`02000001L0oooo00<000000?oo
o`3oool0H@3oool200000080oooo0P00000N0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0E03oool2000000P0oooo0P00000f0?ooo`80
00000`3oool010000000oooo0?ooo`3oool2000001D0oooo00<000000?ooo`3oool0H`3oool01@00
0000oooo0?ooo`3oool0000001h0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00H0oooo0P00000i0?oo
o`040000003oool0oooo000000<0oooo0P00000E0?ooo`030000003oool0oooo06@0oooo00<00000
0?ooo`3oool00P00000M0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0E03oool2000000L0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo000000040?ooo`8000004`3oool00`000000oooo0?ooo`1V0?ooo`040000003oool0oooo
000001d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0?03oool20000
00@0oooo0P00000B0?ooo`800000J03oool2000000030?ooo`000000000001`0oooo00<000000?oo
o`3oool00P3oool004/0oooo0P00000J0?ooo`030000003oool0oooo05@0oooo0P0000060?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool00`3oool200000100oooo0P00001Z0?ooo`04
0000003oool0oooo000001X0oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool0103oool200000400oooo0P0000050?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0JP3oool010000000oooo00000000000K0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0E03oool2000000H0oooo00<000000?ooo`3oool0?`3oool3000000@0oooo0P00000>0?ooo`80
0000K@3oool00`000000oooo0000000K0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0E03oool2000000D0oooo00<000000?ooo`3oool0
@03oool00`000000oooo000000050?ooo`030000003oool0oooo00/0oooo0P00001^0?ooo`040000
003oool00000000001X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`1D0?ooo`8000001@3oool00`000000oooo0?ooo`110?ooo`040000
003oool0oooo000000@0oooo0P00000<0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`00
00006P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo05@0oooo0P0000040?ooo`030000003oool0oooo0480oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo00T0oooo0P00001`0?ooo`030000003oool0000001X0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`1D0?ooo`800000103oool2000004@0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`80
00002P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0000001T0oooo00<000000?ooo`3o
ool00P3oool004/0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1D0?ooo`800000
103oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`070?ooo`800000LP3oool00`000000oooo0000000I0?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01D0oooo0P00001E0?ooo`800000103o
ool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo
0P0000080?ooo`030000003oool0oooo0780oooo00<000000?ooo`000000603oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05@0oooo0P00
00030?ooo`800000AP3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000
1`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0000001P0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool0503oool2000005H0oooo00@000000?ooo`3oool0oooo
0P0000170?ooo`030000003oool0oooo00@0oooo0P0000020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0M03oool00`000000oooo0000000G0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0E03oool2000000<0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000
1@3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0000001L0oooo00<000000?ooo`3oool0
0P3oool004/0oooo0P00000E0?ooo`030000003oool0oooo05@0oooo0P0000020?ooo`800000B03o
ool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
MP3oool3000001@0oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`0C0?ooo`800000EP3o
ool00`000000oooo0?ooo`02000004T0oooo00<000000?ooo`3oool01P3oool200000080oooo00D0
00000?ooo`3oool0oooo0000001i0?ooo`030000003oool0000001H0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1D0?ooo`8000000P3o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`1h0?ooo`<000005@3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`0B0?ooo`800000EP3oool00`000000oooo0?ooo`02000004X0oooo00<0
00000?ooo`3oool01`3oool200000080oooo00@000000?ooo`0000000000NP3oool00`000000oooo
0000000E0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0E@3oool010000000oooo0?ooo`00001;0?ooo`030000003oool0oooo00P0oooo
0P000000103oool000000?ooo`00001l0?ooo`<00000503oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05@0oooo00@000000?ooo`3oool0
0000C03oool00`000000oooo0?ooo`090?ooo`030000003oool0000000800000O03oool3000001@0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool04@3oool2000005H0oooo
00@000000?ooo`3oool00000C03oool00`000000oooo0?ooo`090?ooo`80000000<0oooo0000003o
ool0O@3oool2000001@0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0000004d0oooo00<000000?ooo`3oool0
2P3oool3000007h0oooo0`00000C0?ooo`030000003oool0oooo0080oooo000_0?ooo`040;md0000
0000000007Boo`<0oooo00<0omnL04P0001d_ol00P3oool01P3ogi`0B00000000000000004RL0=oo
o`X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1D0?ooo`80000000<0oooo0000
003oool0C03oool00`000000oooo0?ooo`0:0?ooo`@00000O@3oool3000001<0oooo00<000000?oo
o`3oool00P3oool002h0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000
M;oo0080oooo00H0okmd0000001d_ol0oooo0?oOW018M;l:0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0000001>0?ooo`030000003oool0oooo00X0oooo
0P0000000`3oool000000?ooo`1m0?ooo`8000004`3oool00`000000oooo0?ooo`020?ooo`00;@3o
ool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00/0oooo00<0okmd04RLg`3oool0203o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`000000CP3o
ool00`000000oooo0?ooo`0:0?ooo`@00000OP3oool300000180oooo00<000000?ooo`3oool00P3o
ool002d0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool:0?ooo`030?oo_`1d
07@0_ooo00P0oooo00<000000?ooo`3oool03`3oool2000005H0oooo0`00001?0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`0000000P00001m0?ooo`<000004P3oool00`000000oooo0?oo
o`020?ooo`00803oool00`3ooml0W4P0000000070000000604RLg`3oool0oooo0?oog`2LB00007Bo
0`3oool00`3OW4P0001809cOo`0:0?ooo`030?oog`2LB000M;oo00P0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0000004l0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`03000007h0oooo0P00000B0?ooo`030000003oool0oooo0080oooo
000^0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l02P3oool00`3ookl0M00004RL
g`080?ooo`<000003`3oool00`000000oooo0?ooo`1E0?ooo`800000D03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00<00000OP3oool3000000h0oooo100000040?ooo`00;P3oool0
0`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00X0oooo00<0okmd0000001d_ol0203oool0
0`000000oooo0?ooo`0>0?ooo`800000EP3oool300000500oooo00<000000?ooo`3oool0203oool2
000000<0oooo0`00001n0?ooo`8000004@3oool00`000000oooo0?ooo`020?ooo`00;P3oool00`3o
gi`0B00004RLg`030?ooo`030;md0000B9`0gooo00H0oooo00H0omoO0=ooo`3o_g@000000000M02o
ool80?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0000
001@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool3000007h0oooo0P00
000A0?ooo`030000003oool0oooo0080oooo000^0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0
gia80018W03Oool01P3oool01@3ookl0M0000000000004P0W=oo00T0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`1E0?ooo`800000D@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00<0oooo0`00001m0?ooo`8000004@3oool00`000000oooo0?ooo`020?ooo`00;`3o
ool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00L0oooo00<0gibL0;ooo`3oool02P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`000000D@3o
ool00`000000oooo0?ooo`070?ooo`8000001@3oool3000007h0oooo0P00000@0?ooo`030000003o
ool0oooo0080oooo000`0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO203oool00`3ogi`0M9cO
0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0E@3oool300000540oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`800000OP3oool200000100oooo
00<000000?ooo`3oool00P3oool00340oooo00@0gia800000000000007Bo2P3oool01@2oM0000000
000000000000B9cO00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1E0?ooo`80
0000DP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo0`00001m0?ooo`<0
00003`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`000000DP3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo0`00001m0?ooo`<000003`3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo05@0oooo0`00001B0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool2000007h0oooo0P00000?0?ooo`030000003o
ool0oooo0080oooo001;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0E@3oool2
000005<0oooo00<000000?ooo`3oool01@3oool2000000T0oooo0P00001n0?ooo`8000003`3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
05@0oooo0`00001C0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool30000
07d0oooo0`00000>0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0E03oool2000005@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`090?ooo`800000OP3oool2000000h0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool02`3oool2000005H0oooo0P00001D0?ooo`030000003oool0oooo00@0oooo
0P00000;0?ooo`800000OP3oool2000000h0oooo00<000000?ooo`3oool00P3oool004/0oooo0P00
000<0?ooo`030000003oool0oooo05D0oooo0P00001D0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool02P3oool2000007h0oooo0P00000<0?ooo`<00000103oool004/0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`1D0?ooo`800000E@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00/0oooo0P00001m0?ooo`8000003P3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05@0oooo0P00001E0?oo
o`030000003oool0oooo00<0oooo0P00000=0?ooo`800000OP3oool2000000d0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool02P3oool2000005H0oooo0P00001E0?ooo`03
0000003oool0oooo00<0oooo0P00000=0?ooo`800000OP3oool2000000d0oooo00<000000?ooo`3o
ool00P3oool004/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1E0?ooo`800000
E@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
O03oool2000000d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`1D0?ooo`800000EP3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00d0oooo0P00001m0?ooo`8000003@3oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05@0oooo0P00001F0?ooo`030000003oool0
oooo0080oooo0P00000?0?ooo`800000OP3oool2000000`0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool02@3oool2000005H0oooo0P00001F0?ooo`030000003oool0oooo
0080oooo0P00000?0?ooo`800000OP3oool2000000`0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool02@3oool2000005H0oooo0P00001F0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1l0?ooo`800000303oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo05@0oooo
0`00001F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool2000007d0oooo
0P00000<0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0E03oool2000005L0oooo00@000000?ooo`3oool0oooo0P00000A0?ooo`800000
OP3oool2000000/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`1D0?ooo`800000E`3oool010000000oooo0?ooo`3oool200000140oooo
0P00001n0?ooo`8000002`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo05@0oooo0P00001G0?ooo`040000003oool0oooo0?ooo`800000
4P3oool00`000000oooo0?ooo`1l0?ooo`8000002`3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool2000000T0oooo0P00001F0?ooo`800000E`3oool01@000000oooo0?ooo`3oool0000001<0oooo
0P00001m0?ooo`8000002@3oool3000000@0oooo001;0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`1F0?ooo`050000003oool0oooo0?ooo`000000
4`3oool2000007d0oooo0P00000;0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0E03oool2000005P0oooo00<000000?ooo`3oool00P00
000C0?ooo`800000OP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0E03oool2000005P0oooo00<00000
0?ooo`3oool00P00000C0?ooo`800000OP3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo00800000503oool00`000000oooo0?ooo`1l0?oo
o`8000002P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool0E`3oool010000000oooo0?ooo`00000E0?oo
o`800000O@3oool2000000X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05L0oooo00@000000?ooo`3o
ool000005@3oool2000007h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool0E`3oool010000000oooo0?ooo`00000E0?ooo`800000OP3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00L0oooo0P00001E0?ooo`80
0000F@3oool010000000oooo0?ooo`00000E0?ooo`800000OP3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0E03oool2000005T0oooo00<000000?ooo`0000005`3oool00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`1D0?ooo`800000F@3oool00`000000oooo0000000G0?ooo`030000
003oool0oooo07`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00303o
ool00`3ookl0M7Bo0?ooo`0l0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0E03o
ool2000005T0oooo00<000000?ooo`0000005`3oool00`000000oooo0?ooo`1l0?ooo`8000002@3o
ool00`000000oooo0?ooo`020?ooo`00303oool0103ogi`0B0000000B02Lgolk0?ooo`800000203o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`0000005`3o
ool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00D0oooo0`0000040?ooo`003P3oool0
0`2oM000000000000003000000030000M02oool0oooo03@0oooo00<000000?ooo`3oool01P3oool2
000005H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0000000G0?ooo`800000OP3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000B0?ooo`030?oOW0180000M;oo
03H0oooo00<000000?ooo`3oool01P3oool2000005H0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0000000G0?ooo`800000OP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0080oooo000A0?ooo`030=nLB00007@0_ooo03L0oooo00<000000?ooo`3oool01P3oool2000005H0
oooo00<000000?ooo`3oool0F03oool2000001P0oooo0P00001n0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool000`0oooo00H0omnL04P0B02Lgol0okmd00000018W=li0?oo
o`030000003oool0oooo00H0oooo0P00001E0?ooo`800000FP3oool2000001P0oooo0P00001n0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool000`0oooo00@0omnL04P00000
000007Bo>`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05@0oooo0P00001J0?oo
o`8000006@3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1D0?ooo`80
0000FP3oool2000001T0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`1I0?ooo`8000006@3oool00`000000oooo0?ooo`1l0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool000l0oooo00H0gia80000000000000000
0000B02Lgolf0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`1I0?ooo`8000006@3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool000d0oooo00T0oono07@00018W=l0omnL09boo`3oool0gia8
0018W03Oool0=@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool0F@3oool2000001T0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0080oooo000=0?ooo`090;mdM02oool0oooo0?noW02Lgol0oooo0?oo
_`1d07@0_ooo03D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo05T0oooo0P00000I0?ooo`030000003oool0oooo07`0oooo0P0000080?ooo`030000
003oool0oooo0080oooo000<0?ooo`090?oOW02L_ol0oooo0?oog`2LM9`0gooo0?ooo`3ogi`0B7Bo
03H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
05T0oooo0P00000I0?ooo`800000OP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0080oooo000<0?ooo`090?noW02Lgol0oooo0;md001d_ol0oooo0=nLB00007@0_ooo03H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05T0oooo0P00
000I0?ooo`800000OP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo000<
0?ooo`040?oo_`1d0000000007Booc/0oooo0P0000070?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool0F@3oool2000001X0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?oo
o`040?ooo`<00000103oool004/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo05T0oooo0P00000J0?ooo`030000003oool0oooo07`0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo05@0oooo00<000000?ooo`3oool0F@3oool2000001X0oooo00<000000?oo
o`3oool0O03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo000@0?ooo`06
0?noM000000000000000000007@0_ooo=@3oool00`000000oooo0?ooo`050?ooo`800000EP3oool0
0`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0O03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00080?ooo`060;nLW03Oool0oooo
0?ooo`3ogi`0B0000`0000001000B9`0gooo0?oo_`1dM;lf0?ooo`030000003oool0oooo00D0oooo
0P00001F0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`1l0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000L0oooo00<0
oooO09a8000000000`0000000`00M;l0oooo0?ooo`020?ooo`030?noM00007@0_ooo03H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05T0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool000L0oooo00<0oono07@00018W=l0@@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo07`0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`003`3oool01P3ogi`0B0000000000000000018
09cOobP0oooo00@0_g@0000000000000M;oo2P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo05@0oooo0P00001K0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0O03o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo000>0?ooo`030;md00000000
M;oo0080oooo00<0oooO09adW03Oool09P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`T0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool000d0oooo00<0gia804RLg`3oool0103oool00`3OW9`0_ooo0?oo
o`0T0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0203oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`00303oool00`3ogi`0M9cO0?ooo`040?ooo`030?oog`2LM9`0gooo02D0oooo00<0oooO
09a80018W=l00P3oool0103ooml0W4P00018W03Oool70?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo000<
0?ooo`030?noW02Lgol0oooo00<0oooo00<0oooO09a8001d_ol09P3oool00`3ooml0W4P0001d_`03
0?ooo`030=nLB00004P0W=oo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000`0oooo00<0omnL04Qd
_`3oool00P3oool00`3OW4P0000004RLg`0X0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P0
0018W=l01`3ooooo000006800000103oool000d0oooo00H0okmd00000000000000000018W03OoolY
0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l01`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`00?03oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05X0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool003`0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1J0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo000?0?ooo`060?oOW018000000000000000004P0W=oo:03oool0
0`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
00d0oooo00@0oooO09a80000B9`0gooo0P3oool00`3o_g@004RL0=ooo`0X0?ooo`060=nLB00007@0
_ooo0?oog`2LB000B9cO1`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo07`0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`003@3oool00`2oM4P0W=oo0?oo
o`030?ooo`030?oog`2LB7@0_ooo02T0oooo00@0gia800000000000007Bo203oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0F@3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`00303oool00`3ogi`0W;oo0?ooo`040?ooo`030?oOW018M;l0oooo03D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05T0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool000`0oooo00<0oknL09cOo`3oool00`3oool00`3ogi`0B4RL0=ooo`0f
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo000<0?ooo`040?oo_`1d0000000007Booc/0oooo00<00000
0?ooo`3oool01@3oool2000005H0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool0F@3oool2000001X0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`1I0?ooo`8000006P3oool00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000`0oooo00<0oono09bLg`3oool0
0`3oool0103o_g@000000000M02ooole0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`1I0?ooo`8000006P3oool00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000`0oooo00@0oono09bLg`3ookl0
M000100000000`00B9`0gooo0?ooo`0d0?ooo`8000001`3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo05T0oooo0P00000J0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3o
ool0103oool3000000@0oooo000<0?ooo`090?oOW018000000000000B02Lgol0oooo0?oog`2LB7@0
_ooo03H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo05T0oooo0P00000I0?ooo`800000OP3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00080?ooo`040?oog`2LB000001d0;ooocl0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05T0oooo0P00000I0?ooo`800000OP3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1I0?ooo`8000006@3oool00`00
0000oooo0?ooo`1l0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`00303oool01@3ogkl0
_moo0?ooo`3oool0_g@000<0000000<0001d0;ooo`3oool0=03oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo05@0oooo00<000000?ooo`3oool0F@3oool2000001T0oooo00<000000?oo
o`3oool0O03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000<0?ooo`03
0;md0000000000000080000000D0001d0;ooo`3oool0_ibL0=ooo`0e0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1I0?ooo`8000006@3oool00`00
0000oooo0?ooo`1l0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool000X0
oooo00D0_g@000000000000004RL0=ooo`030?ooo`030?oog`2LB000M;oo0080oooo00<0_g@00018
W03Oool0<@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05@0oooo0P00001J0?oo
o`8000006@3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool000`0oooo00<0oknL09cOo`3oool0203oool00`3ogi`0B7Bo0?ooo`0a0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0E03oool2000005X0oooo0P00000I0?ooo`03
0000003oool0oooo07`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00
303oool00`3ookl0M7Bo0?ooo`070?ooo`030?noM000B9`0gooo0380oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`1D0?ooo`800000FP3oool00`000000oooo0000000H0?ooo`030000
003oool0oooo07`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00303o
ool0103ogi`0B0000000M02oool50?ooo`030=nLB000M;l0oooo03<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`1D0?ooo`800000FP3oool00`000000oooo0000000H0?ooo`030000
003oool0oooo07`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`003@3o
ool00`3ogi`0B000000000050000000304RLg`3oool0oooo03<0oooo00<000000?ooo`3oool01P3o
ool2000005D0oooo0P00001J0?ooo`030000003oool0000001L0oooo0P00001n0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool00180oooo00<0okmd0000B02Lgol0=P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo05<0oooo0P00001J0?ooo`030000003oool0
000001L0oooo0P00001n0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0140oooo00<0_g@0001d_`3oool0=`3oool2000000P0oooo00<000000?ooo`3oool0E03oool20000
05T0oooo00<000000?ooo`0000005`3oool2000007d0oooo0P0000070?ooo`<00000103oool000`0
oooo00H0omnL04P0001d_ol0okmd0000001d_oli0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0E03oool2000005T0oooo00<000000?ooo`0000005`3oool2000007d0oooo0P000009
0?ooo`030000003oool0oooo0080oooo000<0?ooo`040?oOW01800000000001d_c/0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`1D0?ooo`800000F@3oool010000000oooo0?ooo`00
000F0?ooo`030000003oool0oooo07`0oooo0P0000090?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0E03oool2000005T0oooo00@00000
0?ooo`3oool000005P3oool00`000000oooo0?ooo`1l0?ooo`8000002@3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo05@0oooo0P00001I
0?ooo`040000003oool0oooo000001D0oooo0P00001n0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01`3oool2000005D0oooo0P00001I
0?ooo`040000003oool0oooo000001D0oooo0P00001n0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo05L0oooo00@000000?ooo`3oool000005@3oool2000007h0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0E`3oool010000000oooo0?ooo`00
000E0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo05@0oooo0P00001H
0?ooo`040000003oool0oooo000001D0oooo00<000000?ooo`3oool0O03oool2000000X0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1D
0?ooo`800000F03oool00`000000oooo0?ooo`02000001@0oooo00<000000?ooo`3oool0O03oool2
000000X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`1D0?ooo`800000F03oool01@000000oooo0?ooo`3oool0000001<0oooo0P00001n
0?ooo`8000002P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo05D0oooo00<000000?ooo`3oool0EP3oool01@000000oooo0?ooo`3oool0
000001<0oooo0P00001n0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
05H0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`030000003oool0oooo07`0oooo0P00000;
0?ooo`030000003oool0oooo0080oooo001;0?ooo`8000002P3oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo05H0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`030000003oool0
oooo07`0oooo0P0000090?ooo`<00000103oool004/0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`1D0?ooo`800000E`3oool01@000000oooo0?ooo`3oool000000180oooo0P00001n
0?ooo`8000002`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo05@0oooo0P00001G0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03`3oool2000007h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`090?ooo`800000EP3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo05@0oooo0P00001F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3o
ool2000007h0oooo0P00000<0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0E03oool2000005H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0=0?ooo`800000OP3oool2000000`0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1D0?ooo`800000EP3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0O@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0E03oool2000005D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05@0oooo
0P00001E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool2000007h0oooo
0P00000=0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0E03oool2000005D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0;0?ooo`800000OP3oool2000000d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`1D0?ooo`800000E@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0E03oool2000005@0oooo00<000000?ooo`3oool0103oool2000000`0oooo00<000000?oo
o`3oool0O@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo001;0?ooo`80
00003@3oool00`000000oooo0?ooo`1D0?ooo`800000E03oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00T0oooo0P00001n0?ooo`800000303oool3000000@0oooo001;0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0E03oool2000005@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`090?ooo`800000OP3oool2000000h0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1E0?ooo`800000D`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0O03o
ool2000000l0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0303oool2
000005H0oooo0P00001C0?ooo`030000003oool0oooo00D0oooo0P0000090?ooo`800000OP3oool2
000000l0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`1D0?ooo`800000D`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo0P00001n0?ooo`8000003`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0D@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo0`00001m0?ooo`<000003`3oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0=0?ooo`800000EP3oool200000580oooo
00<000000?ooo`3oool01P3oool2000000L0oooo0P00001n0?ooo`800000403oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0=0?ooo`800000EP3oool200000580oooo00<0
00000?ooo`3oool01P3oool2000000L0oooo0P00001n0?ooo`800000403oool00`000000oooo0?oo
o`020?ooo`00;`3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00H0
omnL04P00000000000000018W03Oool:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0E03oool200000580oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`<0
0000OP3oool200000100oooo00<000000?ooo`3oool00P3oool002h0oooo00H0gia8001d_`3oool0
omnL04P00018W=l20?ooo`030?oOW0180000M;oo0080oooo00H0okmd0000001d_ol0oooo0?oOW018
M;l:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0E@3oool200000540oooo00<0
00000?ooo`3oool01`3oool2000000D0oooo0`00001m0?ooo`<00000403oool00`000000oooo0?oo
o`020?ooo`00;@3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00/0oooo00<0okmd
04RLg`3oool0203oool00`000000oooo0?ooo`0>0?ooo`800000EP3oool200000540oooo00<00000
0?ooo`3oool01`3oool2000000D0oooo0P00001n0?ooo`8000004@3oool00`000000oooo0?ooo`02
0?ooo`00;@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`X0oooo00<0oono
07@0M02oool0203oool00`000000oooo0?ooo`0>0?ooo`800000EP3oool00`000000oooo0000001@
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool3000007h0oooo0P00000A
0?ooo`030000003oool0oooo0080oooo000]0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000
B02Lgol02P3oool00`3ooml0W4P007Boo`080?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0E03oool300000500oooo00<000000?ooo`3oool0203oool2000000<0oooo0`00001n0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool002h0oooo00<0_g@00018W03O
ool00P3oool00`3ogi`0B00004RLg`0:0?ooo`030?oo_`1d0000B9cO00P0oooo0`00000?0?ooo`80
0000EP3oool00`000000oooo0000001?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01000001m0?ooo`8000003`3oool4000000@0oooo000^0?ooo`030=nLB00004P0W=oo0080oooo
00<0oooO09a80000M;l02P3oool00`3o_g@0000007Boo`080?ooo`030000003oool0oooo00l0oooo
0P00001F0?ooo`030000003oool0000004l0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`03000007h0oooo0P00000B0?ooo`030000003oool0oooo0080oooo000^0?ooo`030?oOW018
0000B9cO00<0oooo00<0_g@00018W03Oool01P3oool01P3ogml0gooo0?noM0000000001d0;ooo`P0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1D0?ooo`@00000CP3oool00`000000
oooo0?ooo`0:0?ooo`D00000O@3oool2000001<0oooo00<000000?ooo`3oool00P3oool002h0oooo
00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`060?ooo`050?oo_`1d000000000000
B02Lgol02@3oool00`000000oooo0?ooo`0@0?ooo`800000E@3oool2000000030?ooo`000000oooo
04d0oooo00<000000?ooo`3oool02P3oool2000000030?ooo`000000oooo07d0oooo0P00000C0?oo
o`030000003oool0oooo0080oooo000_0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3o
ool01`3oool00`3OW9`0_ooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo0P00001F0?ooo`04
0000003oool00000000004d0oooo00<000000?ooo`3oool02P3oool4000007d0oooo00<000000?oo
o`0000004`3oool00`000000oooo0?ooo`020?ooo`00<03oool01P3OW4P0001d0;ooo`3ooml0W4P0
04RLg`P0oooo00<0omnL07BLg`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo05@0oooo0P0000000`3oool000000?ooo`1<0?ooo`030000003oool0oooo00X0oooo1000001m
0?ooo`800000503oool00`000000oooo0?ooo`020?ooo`00<@3oool0103OW4P0000000000000M;l:
0?ooo`050;md00000000000000000018W=l01`3oool00`000000oooo0?ooo`0A0?ooo`800000E@3o
ool2000000030?ooo`000000000004`0oooo00<000000?ooo`3oool02@3oool4000007h0oooo0P00
000D0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`02000004/0oooo00<000000?ooo`3oool02@3oool0
10000000oooo00000000001m0?ooo`8000005@3oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05@0oooo0P0000000`3oool000000000001;
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P00001m0?ooo`8000005@3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0B0?ooo`800000EP3oool00`00
0000oooo0?ooo`02000004X0oooo00<000000?ooo`3oool0203oool01P000000oooo000000000000
oooo000007/0oooo00<000000?ooo`0000005@3oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool00P00001:
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`1j
0?ooo`8000005P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo05@0oooo0P0000020?ooo`800000B@3oool00`000000oooo0?ooo`060?oo
o`8000000P3oool01@000000oooo0?ooo`3oool0000007T0oooo00<000000?ooo`0000005P3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool2000001@0oooo0P00001F0?ooo`030000003oool0oooo
00800000B@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo008000000`3oool00`00
0000oooo0?ooo`1g0?ooo`030000003oool0000001@0oooo0`0000040?ooo`00B`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo05@0oooo00@000000?ooo`3oool0oooo0P0000180?oo
o`030000003oool0oooo00D0oooo0P0000020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0M@3oool00`000000oooo0000000G0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0E@3oool01@000000oooo0?ooo`3oool00000
04P0oooo00<000000?ooo`3oool0103oool200000080oooo0P0000050?ooo`030000003oool0oooo
07D0oooo00<000000?ooo`0000005`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`0D0?ooo`800000EP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?oo
o`3oool0L`3oool00`000000oooo0000000H0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0E03oool2000000<0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`030?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`80
0000M03oool00`000000oooo0000000H0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo01D0oooo0P00001F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
A03oool00`000000oooo0?ooo`020?ooo`8000000`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0740oooo00@000000?ooo`3oool00000603oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0700oooo00<000000?ooo`000000
6@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0F0?ooo`800000EP3o
ool00`000000oooo0?ooo`020?ooo`800000A03oool010000000oooo0?ooo`3oool2000000<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1_0?ooo`040000003oool0oooo000001T0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`02000000@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1^0?ooo`030000
003oool0000001X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool05`3o
ool2000005H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`110?ooo`040000003o
ool0oooo000000@0oooo0P00000<0?ooo`030000003oool0oooo06d0oooo00@000000?ooo`3oool0
00006P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`100?ooo`040000
003oool00000000000@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1/0?ooo`04
0000003oool00000000001X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool0603oool2000005H0oooo00<000000?ooo`3oool00`3oool200000440oooo0`0000040?ooo`80
00003`3oool00`000000oooo0?ooo`1Z0?ooo`040000003oool0oooo000001/0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo00@0oooo0P0000100?ooo`8000001@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo06T0oooo00D000000?ooo`3oool0oooo0000000K0?ooo`030000003oool0oooo
0080oooo001;0?ooo`8000006P3oool2000005H0oooo00<000000?ooo`3oool0103oool2000003l0
oooo00<000000?ooo`3oool00`3oool200000140oooo00<000000?ooo`3oool0J03oool010000000
oooo0?ooo`00000J0?ooo`<00000103oool004/0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo00D0oooo0P00000l0?ooo`<000001@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo06H0oooo00D000000?ooo`3oool0oooo0000000L0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01X0oooo0P00001F0?ooo`03
0000003oool0oooo00D0oooo0P00000j0?ooo`80000000<0oooo0000003oool00`3oool2000001@0
oooo00<000000?ooo`3oool0I03oool01@000000oooo0?ooo`3oool0000001d0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo00H0oooo0P00000h0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0H`3oool2000000<0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0K0?ooo`800000
EP3oool00`000000oooo0?ooo`060?ooo`800000=P3oool2000000<0oooo00@000000?ooo`3oool0
oooo0P00000F0?ooo`030000003oool0oooo0680oooo00D000000?ooo`3oool0oooo0000000N0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0?ooo`3oool0000001P0oooo00<000000?ooo`3oool0H03oool20000
00<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0203oool200000300
oooo0P0000060?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool0GP3oool20000
00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool02@3oool2000002h0
oooo0P0000070?ooo`040000003oool00000000001X0oooo00<000000?ooo`3oool0G@3oool20000
00@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool02@3oool2000002`0
oooo0P0000080?ooo`030000003oool0000001`0oooo00<000000?ooo`3oool0G03oool2000000<0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`0N0?ooo`800000E@3oool00`000000oooo0?ooo`0;0?ooo`800000:03oool2000000X0oooo
0P00000N0?ooo`030000003oool0oooo05X0oooo0P0000040?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool08`3oool2000000`0oooo0P00
000O0?ooo`030000003oool0oooo05P0oooo0P0000040?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1C
0?ooo`8000003P3oool200000240oooo0`00000<0?ooo`8000008@3oool00`000000oooo0?ooo`1F
0?ooo`800000103oool200000240oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool0803oool2000005D0oooo00<000000?ooo`3oool03P3oool3000001`0oooo0`00000>0?oo
o`8000008P3oool00`000000oooo0?ooo`1D0?ooo`8000001@3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo0080oooo001;0?ooo`8000008P3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo00l0oooo1000000G0?ooo`<000003`3oool300000280oooo0P00001D0?ooo`80
00001@3oool200000200oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool5000000h0oooo1P00000@0?ooo`800000
00<0oooo0000003oool08P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool05@3oool@000001D0oooo00@0
00000?ooo`3oool00000903oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00@0oooo
0P00000S0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`0h0?ooo`8000000P3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02<0oooo0P00001E
0?ooo`030000003oool0oooo03L0oooo0P0000030?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0D`3oool2000003H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0V0?ooo`80
0000B@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool00P3oool004/0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1C0?ooo`800000
=03oool2000000D0oooo00<000000?ooo`3oool09`3oool2000004H0oooo0P0000080?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool09P3o
ool2000005D0oooo00<000000?ooo`3oool0<@3oool2000000H0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo05<0oooo0P00000b0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:P3oool2
00000440oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0D`3oool20000
0300oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
03`0oooo0P00000:0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo02d0
oooo0P0000080?ooo`030000003oool0oooo02d0oooo0P00000k0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo02h0oooo0P00000h0?ooo`800000303oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo0080oooo001;0?ooo`800000:`3oool2000005@0oooo0P00
000/0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0<03oool2000003@0oooo0`00
000<0?ooo`030000003oool0oooo02L0oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0380oooo0P00000a0?ooo`8000003@3oool2000002/0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0d0?oo
o`800000;@3oool2000000l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03H0oooo0P00000Y0?ooo`<0
00003`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0>03oool2000002@0oooo1000000@0?ooo`800000
;@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo0580oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo03X0oooo0`00000M0?ooo`D000004`3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo0080oooo001;0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0DP3oool0
0`000000oooo0?ooo`0P0?ooo`8000003`3oool00`000000oooo0?ooo`0l0?ooo`<00000603oool6
000001@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`020?ooo`00>`3oool00`3o
okl0M000000000020000000304RLg`3oool0oooo00P0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`1B0?ooo`030000003oool0oooo01h0oooo0P00000@0?ooo`030000003oool0oooo
03l0oooo1`00000=0?ooo`D00000603oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
0080oooo000m0?ooo`030?noM0000000M;oo00/0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`1A0?ooo`030000003oool0oooo01d0oooo0P00000A0?ooo`030000003oool0oooo04D0
oooo3P00000L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool00P3oool003d0oooo
00<0oooO09a80000M;l02`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0540oooo
00<000000?ooo`3oool06`3oool200000180oooo00<000000?ooo`3oool0KP3oool200000340oooo
00<000000?ooo`3oool00P3oool003h0oooo00<0gia80018W03Oool02P3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool06@3oool2000001<0oooo00<0
00000?ooo`3oool0KP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0080oooo000n
0?ooo`030?oOW01804P0W=oo00X0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1@
0?ooo`8000006@3oool2000001@0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo0080oooo000n0?ooo`030?oo_`1d0000M;oo00X0oooo0`00000f0?oo
o`030000003oool0oooo0500oooo0P00000G0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0K03oool00`000000oooo0?ooo`0_0?ooo`@00000103oool003l0oooo00<0_g@0001d_`3o
ool02@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0500oooo0P00000D0?ooo`80
00005`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool00P3oool003l0oooo00<0gia80018W03Oool02@3oool00`000000oooo0?ooo`0h0?ooo`800000
D@3oool200000180oooo0P00000H0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`020?ooo`00?`3oool00`3ogi`0B01809cOo`090?ooo`030000003o
ool0oooo03T0oooo0P00001A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`1Y0?ooo`800000=P3oool00`000000oooo0?ooo`020?ooo`00?`3oool0
0`3ookl0M00007Boo`090?ooo`030000003oool0oooo03/0oooo0P00001@0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool00P3oool00400oooo00<0_g@0001d_`3oool0203oool00`00
0000oooo0?ooo`0l0?ooo`800000D03oool00`000000oooo0?ooo`0:0?ooo`800000703oool00`00
0000oooo0?ooo`1X0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool003h0
oooo00D0oono07@000000000001d0;ooo`080?ooo`030000003oool0oooo03d0oooo0`00001?0?oo
o`030000003oool0oooo00P0oooo0P00000M0?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0n0?ooo`<0
0000C`3oool00`000000oooo0?ooo`050?ooo`8000007`3oool00`000000oooo0?ooo`1V0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
@03oool3000004h0oooo00<000000?ooo`3oool00`3oool200000200oooo00<000000?ooo`3oool0
I@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`000000CP3oool00`000000oooo0?ooo`0300000240oooo00<0
00000?ooo`3oool0H`3oool2000003`0oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool0@P3oool4000004d0oooo0`00000S0?ooo`030000003oool0oooo0680oooo0P00000m
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo04@0oooo0`00001;0?oo
o`<00000903oool00`000000oooo0?ooo`1Q0?ooo`800000?P3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`160?ooo`<00000A`3oool2000000<0oooo0P00000R0?ooo`03
0000003oool0oooo0600oooo0P00000o0?ooo`030000003oool0oooo0080oooo001;0?ooo`800000
B@3oool3000004<0oooo0`0000050?ooo`8000008@3oool00`000000oooo0?ooo`1O0?ooo`030000
003oool0oooo03d0oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`1:0?ooo`<00000?`3o
ool3000000P0oooo0P00000P0?ooo`030000003oool0oooo05d0oooo0P0000120?ooo`030000003o
ool0oooo0080oooo001;0?ooo`030000003oool0oooo04`0oooo0`00000k0?ooo`<00000303oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05`0oooo0P0000130?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo04l0oooo0`00000e0?ooo`<00000403oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo05/0oooo0P0000140?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo0540oooo0`00000`0?ooo`<00000503oool2000001`0
oooo00<000000?ooo`3oool0FP3oool2000004D0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool0D`3oool4000002X0oooo0`00000H0?ooo`8000006`3oool00`000000oooo
0?ooo`1H0?ooo`<00000AP3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`1F0?ooo`D000008`3oool3000001`0oooo0P00000J0?ooo`030000003oool0oooo05L0oooo0P00
00180?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo05T0oooo1@00000M
0?ooo`<000008@3oool2000001P0oooo00<000000?ooo`3oool0EP3oool2000004T0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0G@3oool700000100oooo1`00000U0?oo
o`8000005`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool0H`3ooolC000002/0oooo0`00000E0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`2S0?ooo`800000503oool00`000000oooo0?ooo`1B0?ooo`800000
C@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`2T0?ooo`<000004P3o
ool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool0YP3oool200000140oooo00<000000?ooo`3oool0C`3oool2
00000500oooo00<000000?ooo`3oool00P3oool004/0oooo0P00002Y0?ooo`8000003`3oool00`00
0000oooo0?ooo`1>0?ooo`800000C`3oool3000000@0oooo001;0?ooo`030000003oool0oooo0:T0
oooo0P00000>0?ooo`030000003oool0oooo04`0oooo0P00001C0?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo0:/0oooo0P00000<0?ooo`030000003oool0oooo04X0oooo
0P00001E0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0:d0oooo0P00
000:0?ooo`030000003oool0oooo04P0oooo0P00001G0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo0:l0oooo0P0000080?ooo`030000003oool0oooo04H0oooo0P00001I
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0;40oooo0P0000060?oo
o`030000003oool0oooo04@0oooo0P00001K0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo0;<0oooo0P0000040?ooo`030000003oool0oooo0440oooo0`00001M0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0;D0oooo0P0000020?ooo`030000
003oool0oooo03l0oooo0`00001O0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo0;L0oooo0`00000n0?ooo`@00000H@3oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`2i0?ooo`D00000=`3oool5000006<0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool0^@3oool010000000oooo0?ooo`3oool400000380oooo1@00001U
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0;T0oooo00<000000?oo
o`3oool01@3oool4000002/0oooo1@00001X0?ooo`030000003oool0oooo0080oooo001;0?ooo`80
0000^P3oool00`000000oooo0?ooo`090?ooo`<00000903oool5000006X0oooo0`0000040?ooo`00
B`3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo00`0oooo1P00000F0?ooo`P00000
L@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`2i0?ooo`030000003o
ool0oooo0180oooo5P00001i0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo0;T0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`00
0000oooo0?ooo`2i0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0X@3oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo0:40oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1A
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo0080oooo001;0?ooo`040000003oool0oooo00000100oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001;0?oo
o`040000003oool0oooo00000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0080oooo001;0?ooool00000HP0000040?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
cP3oool02@3ookl0M00000000018W=l0oooo0?oo_`1d0000000004RLg`0D0?ooo`030?noM0000000
00000080000000<004RL0=ooo`3oool04P3oool01@2oM0000000000000000000B9cO0:H0oooo003>
0?ooo`0:0?oo_`1d04P0W=oo0;md0000M;l0oono07@0B02Lgol0_g@0001d_a80oooo00<0okmd0000
0018W=l00`3oool00`3ogi`0B01809cOo`0C0?ooo`030?oog`2LB000B9cO0:L0oooo003A0?ooo`03
0?oo_`1d0000M;oo0080oooo00<0oono07@0001d_ol04@3oool00`3o_g@0001d0;ooo`040?ooo`03
0=nLB000M;l0oooo01<0oooo00<0gia80018W03Oool0YP3oool00=80oooo00<0gia80018W03Oool0
0P3oool00`3OW4P004RL0=ooo`0A0?ooo`080;md000007@0_ooo0?ooo`3ooml0W4P000000018W=lD
0?ooo`030?oOW01807@0_ooo0:H0oooo002k0?ooo`030;md00000000000000D0000000<004RL0=oo
o`3oool00`3oool0303ogi`0B00000000000B9`0gooo0;md0000000007Bo0?ooo`3o_g@0001809cO
o`80oooo00<0okmd0000B02Lgol00`3oool0202oM00000000000B02Lgol0oooo0=nLB000B9`0gooo
0P3oool00`2oM0000000001d_`020?ooo`060?oo_`1d000000000000000007@0_ooo1@3oool00`3o
_g@00000000000070000000907Boo`3oool0omnL04P000000000001d0;oo_`1d0000M;oo0080oooo
00/0omnL04P00000000004RL0=ooo`2oM0000000001d_`3oool0omnL04P000020000000907Boo`3O
W4P000000018W03Oool0okmd0000000004P0W=oo0080oooo00@0_g@00000000004P0W=oo0P3oool0
1@3o_g@000000000000004P0W=oo00<0oooo00<0gia80018W03Oool00P3oool00`2oM0000000001d
_`1f0?ooo`00_03oool0103ookl0M0000018W03Oool30?ooo`030;md0000000007Bo00<0oooo00`0
omnL04P0B02Lgol0omnL04Qd_`2oM00007Bo0?noW02Lgol0oono07@00018W=l20?ooo`030?oo_`1d
0000B9cO00<0oooo00P0gia80018W03Ooml0W7BL0=ooo`3o_g@0001d0;ooo`80oooo00P0gia80018
W03O_g@0M;oo0?ooo`3o_g@0001d0;ooo`T0oooo00@0oooO09a80000B9`0gooo0`3oool02`3ooml0
W4P00018W03Oool0_g@00018W03Oool0oono07@0M01dM000B9cO0080oooo02@0omnL04P0B02Lgol0
omnL04Qd_`2oM00007Bo0?noW02Lgol0_g@00018W03Oool0oooo0;md001dM7@0001d0;oOW02L_ol0
okmd0000B02Lgml0W7BL0=ooo`3oool0gia80018W03Ooml0W7BL0=ooo`3ogi`0B01809cOo`3oool0
omnL04P00000M;l20?ooo`030?noM00007@0_ooo0080oooo00@0gia80018W03O_g@0M;ooM@3oool0
0;d0oooo00<0gia80000B02Lgol0103oool03@3ookl0M0000018W03Oool0oooo0?oog`2LB000B9cO
0?ooo`3o_g@0M7Ad0018W03Oool00P3oool00`2oM00004RL0=ooo`020?ooo`030;md0000B9`0gooo
0080oooo00<0okmd0000B02Lgol00P3oool00`3ookl0M00004RLg`020?ooo`030?oOW01804P0W=oo
00<0oooo00<0_g@007Boo`3oool02@3oool00`3o_g@0001809cOo`050?ooo`040=nLM02Lgol0_g@0
001d_`80oooo0100oono07@00000B9`0gooo0?ooo`3ooml0W4P004RLg`3oool0okmd07AdM000B9`0
gooo0?ooo`2oM00007Bo0`3oool01`2oM000000007Boo`3oool0oono07@0001d_ol00`3oool00`3o
_g@0001809cOo`020?ooo`030=nLB000B9`0gooo0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d
0000B9cO0080oooo00<0omnL04P0B02Lgol0MP3oool00;d0oooo00<0omnL04P0001d_ol01@3oool0
0`3ogi`0B000001d_`020?ooo`070;md0000B9`0gooo0?ooo`2oM000001809cOo`020?ooo`030=nL
B00007@0_ooo0080oooo00<0gia80000M02oool00P3oool00`3ookl0M00004RLg`020?ooo`080?oo
g`2LB000001d0;ooo`3oool0oooO09a80018W=l20?ooo`030?oo_`1d000000000080000000<0M;oo
0?ooo`3oool01@3oool00`3ookl0M00004RLg`070?ooo`030=nLB000B9`0gooo0080oooo00<0okmd
0000M02oool00P3oool02`2oM00004RL0=ooo`3oool0_g@00000B02Lgol0oooo0?noM00007@0_ooo
0080oooo00<0oono07@00018W=l00P3oool00`2oM00007Bo0?ooo`020?ooo`030?oo_`1d0000B9cO
0080oooo00<0okmd0000M02oool00`3oool02`3OW4P0001d0;ooo`3ooml0W4P00000M02oool0oooo
0?oog`2LB000B9cO07H0oooo002m0?ooo`030?oo_`1d000007Bo00H0oooo00/0_g@00000B02Lgol0
oooo0?noM00007@0_ooo0?ooo`3ookl0M00007Boo`020?ooo`030?oOW0180000M;oo0080oooo00<0
omnL04P0001d_ol00`3oool00`2oM00004RL0=ooo`020?ooo`030=nLB000B4P0B7Bo0080oooo00/0
_g@0001d_`3oool0oooo0;md0000B9`0gooo0?ooo`3ogi`0B00004RLg`060?ooo`030?oog`2LB000
07Bo0080oooo00<0oono09bLg`3oool00P3oool00`3ogi`0B00007Boo`020?ooo`030?oo_`1d0000
M;oo0080oooo00/0okmd0000M02oool0oooo0?oo_`1d0000M;oo0?ooo`3ookl0M00007Boo`030?oo
o`070;md0000B9`0gooo0?ooo`3OW4P004RL0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3ookl0
M00007Boo`030?ooo`070?oOW01804P0W=oo0?ooo`3OW4P004Q804Qd_`020?ooo`030;md0000M;l0
oooo07D0oooo002n0?ooo`030;md0000B9`0gooo00D0oooo00L0okmd00000018W=l0omoO0=oo_`1d
0000M;oo0080oooo00L0_g@0001d_`3oool0oooo0?oog`2LB000B9cO0080oooo00<0oooO09a80018
W=l00`3oool00`3OW4P0001809cOo`020?ooo`0;0?noM00007@0_kmd04RLg`3oool0okmd0000M02o
ool0oooo0;md0000M;l00`3oool00`3OW4P0001d0;ooo`060?ooo`060=nLB00007@0_ooo0?ooo`3o
gi`0B7Bo103oool0302oM000001d0;ooo`3oool0oooO09a80018W=l0oooo0?oOg`3Ookl0M00007Bo
o`80oooo00L0_g@0001d_`3oool0oooo0?noM00007@0_ooo0080oooo00L0gia80000M02oool0oooo
0?oOW01804P0W=oo00<0oooo00<0gia80000B02Lgol00P3oool00`3OW4P0001d0;ooo`020?ooo`0<
0?oo_`1d0000M;oo0?ooo`3o_g@0001d0;noM018W=l0oooo0?noM00007@0_oooM@3oool00;h0oooo
00<0okmd0000B02Lgol01@3oool01`3ogi`0B000001d_`3ogi`0B7Bo0;md0000M;l00P3oool00`3o
_g@004RL0=ooo`020?ooo`030;md0000B9`0gooo0080oooo00<0_g@00018W03Oool00P3oool00`3o
gi`0B00004RLg`020?ooo`0<0?oog`2LB000M;oo0=nLB000M;l0omnL04P0B02Lgol0oooo0?oOW018
0000B9cO0P3oool00`3OW4P0001d0;ooo`060?ooo`030?noM000000000000080000000<0001d0;oo
o`3oool00P3oool0303ooml0W4P00018W03Oool0oono09a8B000B9`0gooo0?oOW018M;l0_g@0001d
_`80oooo00<0okmd0018W03Oool00P3oool02`3OW4P0001d0;ooo`3oool0_g@00000B02Lgol0oooo
0?oog`2LB000B9cO00<0oooo00<0omnL04P00018W=l00`3oool0402oM000001d0;ooo`3oool0okmd
0000M02oool0oooo0?oog`2LB000M;oo0=nLB000M;l0omnL04P0B02Lgome0?ooo`00_P3oool00`3o
gi`0B00007Boo`050?ooo`070?oOW018000007Bo0?ooo`3o_g@00000001d_`020?ooo`050?oOW018
04P0W=oo0?oo_`1d00000`0000000`1d_kl0M000000000020000000?07Boo`3o_g@0000000000000
B9`0gooo0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo0080oooo00<0oono07@00000
0000100000000`18W=l0oooo0?ooo`030?ooo`030?oo_`1d0000M;oo0080oooo00<0_gA809cOo`3o
ool0103oool02P3OW4P000000000M02o_g@0001d0;ooo`3oool0okmd00000000M;l20?ooo`030?oO
W01804P0W=oo00<0oooo00P0omnL04P000000000B9bL07@00018W=l0oono07@000<0000000H0M;oo
0?noM000000000000018W03Oool30?ooo`0?0?noM000000000000000001d_ol0oooo0?oo_`1d0000
000004RLg`3oool0okmd0000000004P0W=oo07D0oooo002n0?ooo`030?oog`2LB00007Bo00D0oooo
00<0okmd00000018W=l02`3oool00`3o_g@0001809cOo`020?ooo`030?noM00004P0W=oo01l0oooo
00H0_g@0001d_`3oool0oooo0?oOW01dW=lO0?ooo`030?noM00007@0_ooo08d0oooo002o0?ooo`03
0;md0000B9`0gooo00<0oooo00@0oooO09a8000007@0_ooo2`3oool00`3ooml0W4P0001d_`020?oo
o`030?oog`2LB00007Bo01l0oooo00<0gia80000M02oool0103oool00`3OW9`0_ooo0?ooo`0L0?oo
o`030=nLM02Lgol0oooo08`0oooo002o0?ooo`030=nLB00004P0W=oo0080oooo00@0oono07@00000
0000M;oo3@3oool00`3o_g@0001d0;ooo`020?ooo`030?noM00007@0_ooo0080oooo00@0oono07@0
0000B9`0gooo603oool00`3o_g@0001809cOo`030?ooo`030?oo_`1d04P0W=oo0280oooo00@0oono
07@00000B9`0goooQP3oool00;h0oooo00<0_g@0000000000000100000000`00B9`0gooo0?ooo`0>
0?ooo`0:0=nLB000B9`0gooO09a80018W=l0gia80018W03Ooml0W4P004RLgaX0oooo00<0_g@00000
000000001P0000000`1d_ol0oooo0?ooo`2Z0?ooo`00e`3oool02@3OW4P000000000B02Lgol0oooo
0=nLB0000000001809cOo`3@0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-3.12687, -1.78264, 0.0177842, \
0.0117658}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(duffingPlot[1, 0, 0, 1, 3, 0, 0, 0, 50, MaxSteps \[Rule] 2000, 
        PlotPoints \[Rule] 100];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 2.47436 0.499998 0.952386 [
[.00513 -0.0125 -13.8438 -15.6875 ]
[.00513 -0.0125 13.8438 0 ]
[.25256 -0.0125 -13.8438 -15.6875 ]
[.25256 -0.0125 13.8438 0 ]
[.5 -0.0125 -5 -15.6875 ]
[.5 -0.0125 5 0 ]
[.74744 -0.0125 -9.5 -15.6875 ]
[.74744 -0.0125 9.5 0 ]
[.99487 -0.0125 -9.5 -15.6875 ]
[.99487 -0.0125 9.5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.9688 -31.375 ]
[.5 -0.0125 21.9688 -15.6875 ]
[-0.0125 .11904 -27.6875 -7.84375 ]
[-0.0125 .11904 0 7.84375 ]
[-0.0125 .30952 -27.6875 -7.84375 ]
[-0.0125 .30952 0 7.84375 ]
[-0.0125 .5 -10 -7.84375 ]
[-0.0125 .5 0 7.84375 ]
[-0.0125 .69048 -19 -7.84375 ]
[-0.0125 .69048 0 7.84375 ]
[-0.0125 .88095 -19 -7.84375 ]
[-0.0125 .88095 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -43.375 -20.4688 ]
[-0.01875 .5 -27.6875 20.4688 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -43.9375 0 ]
[.5 1.0125 43.9375 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00513 0 m
.00513 .00625 L
s
gsave
.00513 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.25256 0 m
.25256 .00625 L
s
gsave
.25256 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.74744 0 m
.74744 .00625 L
s
gsave
.74744 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.99487 0 m
.99487 .00625 L
s
gsave
.99487 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.125 Mabswid
.05461 0 m
.05461 .00375 L
s
.1041 0 m
.1041 .00375 L
s
.15359 0 m
.15359 .00375 L
s
.20308 0 m
.20308 .00375 L
s
.30205 0 m
.30205 .00375 L
s
.35154 0 m
.35154 .00375 L
s
.40103 0 m
.40103 .00375 L
s
.45051 0 m
.45051 .00375 L
s
.54949 0 m
.54949 .00375 L
s
.59897 0 m
.59897 .00375 L
s
.64846 0 m
.64846 .00375 L
s
.69795 0 m
.69795 .00375 L
s
.79692 0 m
.79692 .00375 L
s
.84641 0 m
.84641 .00375 L
s
.8959 0 m
.8959 .00375 L
s
.94538 0 m
.94538 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.9688 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
102.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11904 m
.00625 .11904 L
s
gsave
-0.0125 .11904 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .30952 m
.00625 .30952 L
s
gsave
-0.0125 .30952 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .69048 m
.00625 .69048 L
s
gsave
-0.0125 .69048 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .88095 m
.00625 .88095 L
s
gsave
-0.0125 .88095 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .16666 m
.00375 .16666 L
s
0 .21428 m
.00375 .21428 L
s
0 .2619 m
.00375 .2619 L
s
0 .35714 m
.00375 .35714 L
s
0 .40476 m
.00375 .40476 L
s
0 .45238 m
.00375 .45238 L
s
0 .54762 m
.00375 .54762 L
s
0 .59524 m
.00375 .59524 L
s
0 .64286 m
.00375 .64286 L
s
0 .73809 m
.00375 .73809 L
s
0 .78571 m
.00375 .78571 L
s
0 .83333 m
.00375 .83333 L
s
0 .07142 m
.00375 .07142 L
s
0 .02381 m
.00375 .02381 L
s
0 .92857 m
.00375 .92857 L
s
0 .97619 m
.00375 .97619 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -117 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
81.4688 11.8438 translate
90 rotate
-81.4688 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(velocity) show
99.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00513 .99375 m
.00513 1 L
s
.25256 .99375 m
.25256 1 L
s
.5 .99375 m
.5 1 L
s
.74744 .99375 m
.74744 1 L
s
.99487 .99375 m
.99487 1 L
s
.125 Mabswid
.05461 .99625 m
.05461 1 L
s
.1041 .99625 m
.1041 1 L
s
.15359 .99625 m
.15359 1 L
s
.20308 .99625 m
.20308 1 L
s
.30205 .99625 m
.30205 1 L
s
.35154 .99625 m
.35154 1 L
s
.40103 .99625 m
.40103 1 L
s
.45051 .99625 m
.45051 1 L
s
.54949 .99625 m
.54949 1 L
s
.59897 .99625 m
.59897 1 L
s
.64846 .99625 m
.64846 1 L
s
.69795 .99625 m
.69795 1 L
s
.79692 .99625 m
.79692 1 L
s
.84641 .99625 m
.84641 1 L
s
.8959 .99625 m
.8959 1 L
s
.94538 .99625 m
.94538 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .11904 m
1 .11904 L
s
.99375 .30952 m
1 .30952 L
s
.99375 .5 m
1 .5 L
s
.99375 .69048 m
1 .69048 L
s
.99375 .88095 m
1 .88095 L
s
.125 Mabswid
.99625 .16666 m
1 .16666 L
s
.99625 .21428 m
1 .21428 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .35714 m
1 .35714 L
s
.99625 .40476 m
1 .40476 L
s
.99625 .45238 m
1 .45238 L
s
.99625 .54762 m
1 .54762 L
s
.99625 .59524 m
1 .59524 L
s
.99625 .64286 m
1 .64286 L
s
.99625 .73809 m
1 .73809 L
s
.99625 .78571 m
1 .78571 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .07142 m
1 .07142 L
s
.99625 .02381 m
1 .02381 L
s
.99625 .92857 m
1 .92857 L
s
.99625 .97619 m
1 .97619 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .5 m
1 .5 L
s
.5 0 m
.5 1 L
s
gsave
.5 1.0125 -104.938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Duffing) show
102.938 15.813 moveto
(Equation) show
146.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.5 .5 m
.50028 .51424 L
.50101 .52718 L
.50242 .54204 L
.50431 .556 L
.509 .5805 L
.51597 .60645 L
.52584 .634 L
.53872 .66175 L
.56756 .70676 L
.58438 .72645 L
.60409 .74533 L
.62232 .75959 L
.6433 .77283 L
.65648 .77961 L
.66899 .78504 L
.68218 .78977 L
.6943 .79325 L
.70636 .79591 L
.7178 .79772 L
.72995 .7989 L
.7368 .79922 L
.74312 .7993 L
.75573 .79885 L
.7672 .7977 L
.77352 .79678 L
.78037 .79553 L
.79273 .79262 L
.80416 .78916 L
.81614 .78471 L
.83711 .77471 L
.86038 .75997 L
.88092 .74317 L
.90175 .72158 L
.92187 .69483 L
.93764 .66791 L
.95209 .63568 L
.95818 .61841 L
.96376 .59929 L
.96778 .58226 L
.97128 .56332 L
.97265 .55396 L
.97386 .54393 L
.97469 .53529 L
.9754 .52571 L
.97586 .51666 L
.97613 .50688 L
.97605 .48903 L
.97516 .47033 L
.97356 .45243 L
Mistroke
.97149 .43629 L
.96855 .41863 L
.96009 .38176 L
.94746 .34221 L
.93223 .30552 L
.91548 .27266 L
.8767 .21352 L
.82657 .15728 L
.79712 .13112 L
.7633 .10582 L
.69719 .06804 L
.65413 .05035 L
.63237 .04325 L
.61199 .03765 L
.59368 .03345 L
.57331 .02969 L
.5527 .02684 L
.54136 .02567 L
.53071 .02483 L
.51213 .02397 L
.49228 .02387 L
.47356 .02457 L
.45661 .02586 L
.43672 .02818 L
.41531 .03167 L
.37698 .04056 L
.33766 .05334 L
.29746 .07059 L
.23004 .11045 L
.17462 .15613 L
.12957 .20548 L
.0886 .2655 L
.0698 .3012 L
.05538 .33469 L
.0433 .36991 L
.03459 .4033 L
.03118 .42009 L
.02824 .43817 L
.02696 .44792 L
.02585 .45817 L
.02446 .4764 L
.02389 .49187 L
.02389 .50825 L
.02447 .52354 L
.02548 .53728 L
.02725 .55319 L
.02986 .57015 L
.03299 .58583 L
.03642 .59998 L
.04585 .63017 L
Mistroke
.05687 .65675 L
.07121 .68381 L
.08905 .7102 L
.1101 .7345 L
.13208 .75426 L
.1532 .76908 L
.17747 .78197 L
.18916 .78679 L
.20171 .79103 L
.21565 .79469 L
.22189 .79597 L
.22861 .79711 L
.24078 .79857 L
.25217 .79923 L
.25914 .7993 L
.26574 .79913 L
.27808 .79821 L
.2892 .7967 L
.30093 .79439 L
.31086 .79186 L
.3217 .78848 L
.34531 .77875 L
.36662 .76696 L
.38864 .75135 L
.41025 .73198 L
.4441 .69063 L
.45992 .66432 L
.47245 .63809 L
.48363 .60771 L
.48824 .59173 L
.49245 .57383 L
.49537 .55798 L
.49746 .54302 L
.49835 .53471 L
.499 .52709 L
.49954 .51828 L
.49987 .50991 L
.49997 .49511 L
.49953 .4814 L
.49846 .4664 L
.49664 .45054 L
.49387 .43335 L
.48995 .41505 L
.4805 .38281 L
.46847 .35288 L
.45508 .32697 L
.42488 .28392 L
.40496 .26285 L
.38484 .24567 L
.36258 .23056 L
Mistroke
.34045 .21897 L
.32786 .21373 L
.31394 .20903 L
.30112 .20565 L
.28916 .20329 L
.27691 .20167 L
.2652 .20084 L
.25468 .20071 L
.2432 .20123 L
.23081 .20256 L
.22392 .20366 L
.21768 .20487 L
.20563 .20783 L
.19439 .21133 L
.17308 .22006 L
.15413 .23035 L
.13424 .24405 L
.11444 .26119 L
.09587 .28124 L
.07788 .30554 L
.06412 .32872 L
.05122 .35604 L
.04449 .37365 L
.03906 .39054 L
.03468 .40686 L
.03068 .42537 L
.02787 .44231 L
.02588 .45852 L
.0245 .47593 L
.02405 .48584 L
.02384 .495 L
.024 .5129 L
.02486 .52997 L
.02621 .5454 L
.02829 .56221 L
.03131 .5806 L
.03536 .6001 L
.0448 .63497 L
.05599 .66687 L
.06859 .69624 L
.10471 .76041 L
.1552 .82422 L
.21038 .87489 L
.24406 .8991 L
.28303 .9221 L
.32186 .9404 L
.35886 .95403 L
.39777 .96468 L
.41854 .96891 L
.4292 .9707 L
Mistroke
.44065 .97234 L
.46002 .97445 L
.47815 .97567 L
.48924 .97606 L
.49974 .97619 L
.51941 .97578 L
.53719 .97468 L
.556 .97276 L
.57199 .97052 L
.58952 .96739 L
.62805 .95802 L
.66335 .94627 L
.70062 .93033 L
.73821 .91018 L
.80034 .86622 L
.8585 .80894 L
.88487 .77545 L
.90991 .73704 L
.92983 .69957 L
.94511 .66403 L
.95689 .62943 L
.96183 .61165 L
.96632 .59251 L
.96966 .57519 L
.9721 .5594 L
.97398 .54359 L
.97523 .52867 L
.97604 .51145 L
.97617 .49566 L
.97564 .47851 L
.97431 .46054 L
.97227 .44325 L
.96974 .42767 L
.96628 .41093 L
.96186 .39373 L
.9527 .36594 L
.94032 .33739 L
.9242 .30875 L
.90421 .28134 L
.88306 .25881 L
.86215 .24132 L
.84195 .22801 L
.81865 .21634 L
.80659 .21167 L
.79342 .20756 L
.78084 .20456 L
.76923 .20257 L
.75771 .2013 L
.74698 .20075 L
.7352 .20083 L
Mistroke
.72266 .20171 L
.71076 .20331 L
.69961 .20548 L
.68969 .20798 L
.67906 .21126 L
.65547 .22086 L
.63065 .23476 L
.60626 .25282 L
.58518 .27271 L
.5523 .31485 L
.53697 .34163 L
.52516 .36769 L
.51611 .39311 L
.5084 .4222 L
.50545 .43714 L
.50415 .44505 L
.50298 .45343 L
.50132 .46894 L
.50038 .48323 L
.50002 .49652 L
.50016 .51073 L
.50079 .52412 L
.5018 .53624 L
.50349 .55043 L
.50596 .56568 L
.51206 .59287 L
.52091 .62117 L
.53329 .65087 L
.549 .67989 L
.5661 .70486 L
.60179 .74333 L
.62428 .76097 L
.64609 .77436 L
.66934 .78518 L
.69106 .79239 L
.70332 .79531 L
.70981 .79653 L
.71668 .79758 L
.72936 .79886 L
.74105 .7993 L
.75185 .79907 L
.76339 .79816 L
.77424 .79666 L
.78406 .79475 L
.7955 .79185 L
.80778 .78791 L
.82959 .77863 L
.85201 .76576 L
.87534 .74813 L
.89782 .72606 L
Mistroke
.91685 .70216 L
.93231 .67776 L
.94509 .65249 L
.9573 .62111 L
.96594 .59052 L
.96933 .57454 L
.97225 .55686 L
.97428 .53982 L
.97551 .52388 L
.97609 .50929 L
.97613 .49308 L
.97552 .47599 L
.97432 .45991 L
.97215 .44097 L
.96933 .42295 L
.96203 .38911 L
.95123 .35285 L
.93605 .31397 L
.90273 .25112 L
.85716 .18951 L
.81073 .14268 L
.75245 .09863 L
.68419 .06217 L
.64785 .04818 L
.62654 .04155 L
.60692 .03641 L
.58983 .03267 L
.57115 .02935 L
.55128 .02668 L
.53243 .02495 L
.51472 .02404 L
.49594 .02382 L
.47991 .02425 L
.46229 .02536 L
.45186 .02633 L
.44052 .02767 L
.41996 .03083 L
.40009 .03479 L
.38183 .03924 L
.34122 .05203 L
.2994 .06966 L
.22767 .11213 L
.16994 .16067 L
.1197 .2183 L
.09636 .25257 L
.07737 .28596 L
.05066 .34742 L
.04018 .38075 L
.03182 .41668 L
.02844 .43673 L
Mistroke
.02614 .4552 L
.02525 .4648 L
.02452 .47535 L
.02403 .48631 L
.02382 .49654 L
.02385 .50561 L
.02408 .5151 L
.02503 .53188 L
.0268 .54965 L
.02814 .55958 L
.02961 .5687 L
.03291 .5855 L
.03668 .60098 L
.04537 .62884 L
.05702 .65708 L
.07213 .68535 L
.08752 .70817 L
.10591 .73014 L
.12321 .74688 L
.14334 .76262 L
.16833 .77759 L
.18025 .78319 L
.19316 .78824 L
.20617 .79232 L
.21808 .79521 L
.23016 .79734 L
.24158 .79864 L
.2537 .79927 L
.26058 .79928 L
.26699 .79907 L
.27991 .798 L
.28712 .79703 L
.29366 .79591 L
.3053 .79335 L
.3178 .78977 L
.34005 .78121 L
.36511 .7679 L
.39018 .75012 L
.4101 .73214 L
.4302 .7096 L
.4465 .68701 L
.46208 .66021 L
.47451 .63313 L
.48395 .60671 L
.48795 .59285 L
.4912 .57959 L
.49372 .5674 L
.49593 .55438 L
.4978 .54005 L
.49902 .52679 L
Mistroke
.49979 .51245 L
.49998 .49669 L
.49982 .48856 L
.49944 .47974 L
.49888 .47142 L
.4982 .46374 L
.49647 .44929 L
.494 .43407 L
.49065 .41798 L
.48684 .4031 L
.47585 .37022 L
.46385 .34327 L
.45092 .31998 L
.43344 .29453 L
.41565 .27358 L
.37744 .24023 L
.35444 .22592 L
.3317 .21523 L
.32122 .21135 L
.30997 .20788 L
.30016 .20543 L
.28953 .20335 L
.27805 .20179 L
.26727 .20094 L
.25442 .20072 L
.24268 .20127 L
.2301 .20266 L
.2231 .2038 L
.21679 .20506 L
.1932 .21174 L
.18024 .21681 L
.16652 .22334 L
.14258 .23791 L
.12113 .25497 L
.10019 .27617 L
.06798 .32173 L
.05407 .3494 L
.04314 .37757 L
.03531 .40432 L
.03177 .41986 L
.02903 .43475 L
.02672 .45098 L
.02576 .45972 L
.02495 .46921 L
.02435 .47872 L
.02396 .48879 L
.02387 .50698 L
.02449 .52407 L
.02568 .54007 L
.02767 .55774 L
Mistroke
.0306 .57666 L
.03797 .61088 L
.04898 .64774 L
.06223 .68207 L
.07685 .71303 L
.11072 .76923 L
.15477 .82376 L
.21213 .87626 L
.27134 .91572 L
.30639 .93362 L
.34608 .94972 L
.38475 .96152 L
.40226 .96568 L
.42132 .96941 L
.43898 .97212 L
.45527 .97401 L
.47089 .97527 L
.48739 .97602 L
.50553 .97616 L
.52242 .97564 L
.54091 .97436 L
.56062 .97217 L
.5796 .96924 L
.60005 .96517 L
.63664 .95544 L
.67141 .94314 L
.70257 .92939 L
.76603 .8923 L
.82705 .84225 L
.87637 .7869 L
.91348 .73088 L
.93083 .69747 L
.9463 .6609 L
.9596 .62003 L
.96846 .5818 L
.97159 .56303 L
.97291 .55319 L
.97406 .54282 L
.97486 .53376 L
.97552 .52385 L
.97614 .50656 L
.97607 .48987 L
.97527 .47222 L
.97383 .45581 L
.97195 .44108 L
.96935 .42556 L
.96636 .41129 L
.95764 .37992 L
.94669 .35113 L
.93237 .32233 L
Mistroke
.91775 .29911 L
.90053 .27701 L
.86568 .24399 L
.84402 .22923 L
.83163 .22239 L
.81968 .21678 L
.80833 .21229 L
.79585 .20824 L
.78437 .20531 L
.7737 .20325 L
.76094 .20158 L
.74895 .2008 L
.74207 .20069 L
.73578 .20081 L
.72853 .2012 L
.72167 .20182 L
.71506 .20264 L
.70805 .20377 L
.69553 .20644 L
.68082 .21067 L
.66771 .21547 L
.64611 .22563 L
.62346 .2396 L
.6012 .25719 L
.58197 .27615 L
.55178 .31566 L
.53755 .3405 L
.52645 .36453 L
.51579 .39414 L
.50831 .42259 L
.50534 .43777 L
.50282 .45468 L
.50185 .46325 L
.50103 .47251 L
.50048 .48126 L
.50016 .4893 L
.50003 .50489 L
.50051 .51936 L
.50169 .53519 L
.50265 .544 L
.50371 .55196 L
.5061 .56646 L
.50934 .58198 L
.51693 .60949 L
.52654 .63571 L
.53908 .66244 L
.56711 .70618 L
.58731 .72951 L
.60832 .74889 L
.62837 .76374 L
Mistroke
.65175 .7773 L
.67548 .78749 L
.68881 .79177 L
.70149 .79493 L
.7134 .79711 L
.72439 .79845 L
.73649 .79921 L
.74926 .79918 L
.76222 .79829 L
.76946 .7974 L
.77601 .79635 L
.78869 .79367 L
.80054 .79034 L
.82652 .78012 L
.84071 .7727 L
.85343 .76481 L
.89194 .7324 L
.91113 .70996 L
.92687 .68698 L
.93978 .66371 L
.95182 .63636 L
.96112 .60885 L
.96783 .58204 L
.97099 .56512 L
.97236 .55608 L
.97358 .54643 L
.97446 .53789 L
.97522 .52844 L
.97603 .51164 L
.97616 .49508 L
.97558 .47714 L
.97433 .46008 L
.97261 .44444 L
.96967 .42488 L
.96617 .40676 L
.95546 .36584 L
.94284 .33016 L
.92623 .29304 L
.88737 .22805 L
.84292 .17377 L
.78541 .12184 L
.7531 .09905 L
.71666 .07773 L
.68286 .0616 L
.65117 .04932 L
.61852 .03933 L
.58714 .03214 L
.56914 .02904 L
.54998 .02653 L
.53356 .02503 L
Mistroke
.51546 .02407 L
.49597 .02382 L
.48504 .02405 L
.47506 .02448 L
.45573 .02594 L
.43746 .02808 L
.41982 .03085 L
.40091 .03461 L
.36711 .04341 L
.32789 .05713 L
.29306 .07275 L
.22582 .11346 L
.19476 .13792 L
.16318 .16744 L
.11665 .22245 L
.09477 .25515 L
.07666 .28734 L
.06212 .31819 L
.04893 .35238 L
.03934 .38386 L
.03253 .41308 L
.02931 .43103 L
.02694 .44805 L
.02538 .46326 L
.02429 .47977 L
.02382 .49749 L
.02387 .50732 L
.02412 .51617 L
.02514 .53324 L
.02673 .54908 L
.02879 .56375 L
.03153 .57897 L
.0379 .60541 L
.04673 .63256 L
.05868 .66057 L
.07426 .68881 L
.09055 .71214 L
.11158 .73599 L
.13341 .7553 L
.15496 .77015 L
.17587 .78124 L
.19967 .79041 L
.21194 .79382 L
.21855 .79531 L
.22563 .79664 L
.2376 .79827 L
.24879 .7991 L
.25564 .79929 L
.2621 .79925 L
.27419 .79858 L
Mistroke
.28693 .79706 L
.29859 .79491 L
.31128 .79174 L
.32455 .78748 L
.34587 .77848 L
.36512 .76789 L
.40568 .73647 L
.42581 .71496 L
.44305 .69218 L
.45698 .66969 L
.46983 .64411 L
.48132 .61479 L
.4896 .5864 L
.4935 .56856 L
.49635 .55154 L
.49821 .53611 L
.49898 .52738 L
.49949 .51933 L
.49998 .50397 L
.49985 .48943 L
.49924 .4764 L
.49805 .46229 L
.49614 .44704 L
.49342 .43101 L
.48675 .40278 L
.47863 .37758 L
.46936 .35484 L
.44261 .30717 L
.42549 .28465 L
.40557 .26343 L
.38693 .24729 L
.36578 .23251 L
.34169 .21953 L
.31842 .21042 L
.30385 .20629 L
.29663 .20467 L
.28995 .20343 L
.27737 .20171 L
.27073 .20114 L
.2637 .20079 L
.25166 .20078 L
.24487 .20111 L
.23858 .20163 L
.22709 .20312 L
.21495 .20547 L
.20423 .20822 L
.19426 .21137 L
.17198 .22059 L
.14898 .23359 L
.12894 .24827 L
Mistroke
.10837 .26727 L
.08858 .29041 L
.07415 .31136 L
.06048 .33577 L
.05025 .35841 L
.04091 .38445 L
.03615 .40105 L
.03242 .41678 L
.02951 .43185 L
.02699 .44879 L
.02535 .46424 L
.02434 .4789 L
.02384 .49458 L
.02397 .51163 L
.02434 .52133 L
.0249 .53051 L
.02646 .54774 L
.02891 .5664 L
.03247 .58663 L
.04127 .62312 L
.05205 .65643 L
.06682 .69241 L
.08648 .7308 L
.13664 .8032 L
.19174 .85948 L
.22583 .88654 L
.26026 .90927 L
.29392 .92767 L
.33207 .94451 L
.36789 .95683 L
.40179 .96558 L
.42003 .96918 L
.43935 .97217 L
.45593 .97407 L
.47412 .97546 L
.49383 .97615 L
.50487 .97616 L
.51489 .97595 L
.53437 .9749 L
.5527 .97316 L
.56984 .97085 L
.58786 .96772 L
.61981 .96032 L
.65353 .94985 L
.6896 .93544 L
.76038 .89615 L
.79687 .86908 L
.82781 .84152 L
.88055 .78136 L
.92063 .71784 L
Mistroke
.93785 .68189 L
.95118 .64729 L
.96074 .61582 L
.96849 .58166 L
.97147 .56383 L
.9739 .54436 L
.9748 .53458 L
.97551 .52416 L
.97615 .5055 L
.97599 .48709 L
.9751 .46991 L
.97371 .4547 L
.97156 .43846 L
.96896 .4235 L
.96601 .40976 L
.95752 .37955 L
.94697 .35177 L
.93327 .32394 L
.91856 .30027 L
.90293 .27981 L
.86983 .24726 L
.8475 .23136 L
.82535 .21932 L
.80472 .21102 L
.79286 .20741 L
.78183 .20477 L
.76983 .20265 L
.75856 .20137 L
.74615 .20073 L
.73919 .20072 L
.73284 .20093 L
.7201 .20199 L
.71292 .20296 L
.7063 .2041 L
.69424 .20677 L
.68156 .21043 L
.66107 .21828 L
.63969 .22922 L
.60353 .25515 L
.58442 .27352 L
.566 .29527 L
.53805 .33953 L
.52556 .3667 L
.51593 .39368 L
.50917 .41877 L
.50616 .43321 L
.50391 .44667 L
.50206 .46126 L
.50085 .47499 L
.50013 .49012 L
Mistroke
.5 .49863 L
.50006 .5064 L
.50066 .52198 L
.50129 .53077 L
.50207 .53889 L
.50397 .5537 L
.50665 .56933 L
.51322 .59711 L
.52274 .62612 L
.53396 .65226 L
.54607 .675 L
.57346 .71409 L
.58921 .73145 L
.60782 .74848 L
.62919 .76428 L
.65376 .7783 L
.66541 .78358 L
.678 .78838 L
.68903 .79183 L
.70104 .79483 L
.71272 .797 L
.72348 .79837 L
.7338 .79911 L
.74468 .79929 L
.75664 .79878 L
.76773 .79763 L
.77984 .79564 L
.79265 .79264 L
.8062 .78846 L
.8185 .78372 L
.8454 .76993 L
.86785 .75431 L
.88999 .73441 L
.92357 .69222 L
.93947 .66431 L
.95199 .63593 L
.95733 .62102 L
.96231 .60466 L
.96942 .57408 L
.97229 .55654 L
.97429 .53973 L
.97511 .52998 L
.97567 .52096 L
.97605 .51098 L
.97619 .50039 L
.97588 .48377 L
.97483 .46585 L
.97315 .44882 L
.97103 .43326 L
.96784 .41492 L
Mistroke
.96349 .395 L
.95327 .35897 L
.94171 .32735 L
.92631 .2932 L
.88691 .2274 L
.84118 .17195 L
.79115 .12632 L
.72607 .08283 L
.68636 .06312 L
.64801 .04824 L
.61009 .03718 L
.5919 .03308 L
.57504 .02997 L
.5554 .02716 L
.54502 .02602 L
.53404 .02507 L
.51553 .02407 L
.49518 .02383 L
.47563 .02445 L
.45714 .02581 L
.44061 .02766 L
.42271 .03035 L
.40339 .03407 L
.38305 .03892 L
.34715 .0499 L
.28564 .07653 L
.25249 .09549 L
.22284 .11563 L
.16676 .16382 L
.11474 .22509 L
.09259 .25874 L
.0722 .29623 L
.05738 .32962 L
.04434 .3665 L
.03915 .3846 L
.03448 .40381 L
.03091 .42161 L
.02823 .43824 L
.0263 .45374 L
.02484 .4703 L
.02396 .48855 L
.02384 .50506 L
.02432 .52063 L
.02527 .53489 L
.02688 .55032 L
.02923 .56646 L
.03207 .58157 L
.03526 .5955 L
.04256 .62067 L
.05335 .64896 L
Mistroke
.06538 .67361 L
.08199 .70051 L
.09907 .72253 L
.11745 .74166 L
.139 .75952 L
.16328 .77493 L
.1756 .78112 L
.18739 .78611 L
.20864 .79299 L
.22011 .79562 L
.23254 .79767 L
.23878 .79839 L
.2456 .79893 L
.25805 .7993 L
.27018 .79889 L
.28141 .79782 L
.2928 .79607 L
.30346 .7938 L
.32312 .78799 L
.34378 .77949 L
.36535 .76776 L
.38578 .7536 L
.40635 .73582 L
.4393 .69755 L
.45637 .67077 L
.47016 .64336 L
.48044 .61735 L
.4853 .60227 L
.48924 .58783 L
.49273 .57248 L
.49533 .55822 L
.49755 .54223 L
.49844 .53378 L
.49916 .52484 L
.49962 .5167 L
.49991 .50798 L
.49992 .49226 L
.49959 .48266 L
.49905 .4736 L
.49837 .46549 L
.49743 .45672 L
.4954 .44218 L
.49248 .42633 L
.48447 .395 L
.4746 .36708 L
.4633 .34217 L
.43332 .29437 L
.41307 .27089 L
.39246 .25175 L
.37159 .23623 L
Mistroke
.35089 .22404 L
.33904 .21833 L
.32599 .21304 L
.31402 .20905 L
.30272 .20602 L
.29216 .20381 L
.28078 .2021 L
.26809 .20098 L
.2565 .20069 L
.24443 .20114 L
.23762 .20173 L
.23135 .20249 L
.21988 .20442 L
.2078 .20723 L
.18694 .21406 L
.1679 .22263 L
.14777 .23439 L
.12716 .24974 L
.10797 .26769 L
.08918 .28963 L
.07452 .31077 L
.06048 .33578 L
.04661 .36778 L
.04127 .38328 L
.03637 .40021 L
.03261 .4159 L
.02922 .43357 L
.02684 .44998 L
.02523 .4656 L
.02413 .48355 L
.02385 .49381 L
.02382 .50339 L
.02433 .52108 L
.02493 .53103 L
.02568 .54007 L
.02762 .55731 L
.03048 .57599 L
.03772 .60988 L
.04962 .6496 L
.06608 .69079 L
.10524 .7612 L
.15342 .8223 L
.20548 .87099 L
.23727 .89457 L
.27385 .91712 L
.307 .9339 L
.34489 .9493 L
.38089 .9605 L
.41531 .96832 L
.43451 .9715 L
Mistroke
.45218 .97369 L
.47265 .97538 L
.49217 .97612 L
.50882 .97611 L
.52655 .97542 L
.54325 .97415 L
.55835 .97247 L
.57607 .96985 L
.59511 .96624 L
.6292 .95768 L
.66465 .94578 L
.70149 .92991 L
.7641 .89363 L
.79937 .86702 L
.83037 .83902 L
.88142 .78018 L
.9036 .74749 L
.92408 .71122 L
.93913 .67887 L
.95253 .64326 L
.95872 .62317 L
.96357 .60467 L
.96769 .58583 L
.97079 .56831 L
.97339 .54909 L
.97442 .53896 L
.97526 .52818 L
.97586 .5169 L
.97614 .50631 L
.97618 .49686 L
.97598 .48668 L
.97509 .46972 L
.97368 .45444 L
.97135 .4371 L
.96845 .42097 L
.96172 .39324 L
.95216 .3645 L
.93914 .33503 L
.9226 .30628 L
.88674 .26234 L
.86434 .24296 L
.83836 .22597 L
.82592 .21959 L
.8125 .21384 L
.8007 .20971 L
.78789 .20613 L
.77528 .20351 L
.76371 .20187 L
.75203 .20093 L
.74096 .2007 L
Mistroke
.72807 .20123 L
.71621 .20248 L
.70325 .2047 L
.68964 .20799 L
.66685 .21582 L
.64367 .22696 L
.6247 .23874 L
.60502 .25387 L
.58515 .27274 L
.56581 .29551 L
.53656 .34245 L
.52519 .36761 L
.51516 .3962 L
.51138 .40971 L
.50796 .42421 L
.50549 .43691 L
.50334 .45066 L
.50176 .4641 L
.50076 .47644 L
.50017 .48888 L
.5 .5007 L
.50028 .51442 L
.501 .5271 L
.5023 .54096 L
.50425 .5556 L
.50659 .56904 L
.50972 .58359 L
.51783 .61226 L
.52742 .6378 L
.53807 .6605 L
.56781 .70708 L
.58755 .72976 L
.60719 .74795 L
.62564 .7619 L
.64621 .77443 L
.66976 .78535 L
.6805 .78922 L
.6922 .7927 L
.70328 .7953 L
.71349 .79712 L
.72381 .7984 L
.73365 .7991 L
.74506 .79929 L
.75565 .79885 L
.76725 .7977 L
.77953 .7957 L
.79164 .79291 L
.80477 .78896 L
.83062 .77812 L
.85354 .76474 L
Mistroke
.8738 .74945 L
.89602 .72805 L
.91441 .70557 L
.93311 .67634 L
.94804 .64572 L
.95863 .61701 L
.96343 .60055 L
.96727 .58468 L
.97021 .56974 L
.9724 .55578 L
.97426 .54002 L
.97557 .52276 L
.97616 .5052 L
.97604 .48867 L
.97516 .47036 L
.97433 .46005 L
.97336 .45065 L
.97077 .43156 L
.96701 .41081 L
.95767 .37318 L
.94645 .33952 L
.93151 .30397 L
.89712 .24236 L
.84461 .17557 L
.78682 .12292 L
.71843 .07867 L
.67673 .05901 L
.63656 .04453 L
.6162 .03872 L
.59683 .03412 L
.57908 .03066 L
.56023 .02777 L
.55035 .02657 L
.5395 .02551 L
.52039 .02426 L
.5096 .02391 L
.49804 .02381 L
.48714 .02399 L
.47722 .02437 L
.45859 .02568 L
.4412 .02758 L
.42221 .03044 L
.40192 .03439 L
.36121 .04522 L
.32493 .05833 L
.25861 .09172 L
.20108 .1326 L
.14319 .1891 L
.09867 .24889 L
.06122 .3203 L
Mistroke
.04579 .36189 L
.03995 .38162 L
.03531 .40011 L
.03165 .41759 L
.02892 .43352 L
.02658 .45117 L
.02486 .46999 L
.02398 .48791 L
.02381 .49796 L
.02387 .50721 L
.0245 .52401 L
.0259 .54162 L
.02766 .55621 L
.03014 .57168 L
.03613 .59888 L
.04568 .62968 L
.05663 .65624 L
.07071 .68297 L
.08572 .70574 L
.10573 .72994 L
.12573 .74904 L
.14835 .76599 L
.17096 .7789 L
.19584 .78916 L
.21022 .79339 L
.21663 .7949 L
.22365 .79629 L
.23595 .79809 L
.24768 .79905 L
.25913 .7993 L
.26974 .79892 L
.28232 .79771 L
.29366 .79591 L
.30664 .793 L
.31873 .78947 L
.34017 .78116 L
.35924 .77139 L
.39936 .74231 L
.41845 .72338 L
.43478 .70371 L
.45214 .67801 L
.46584 .65269 L
.47789 .62443 L
.48698 .59639 L
.49073 .58165 L
.49403 .56576 L
.49547 .55739 L
.49682 .54811 L
.49779 .54016 L
.49863 .53164 L
Mistroke
.49961 .5169 L
.49999 .50316 L
.49996 .49474 L
.49976 .48681 L
.49893 .472 L
.49739 .45641 L
.49539 .44216 L
.49255 .42667 L
.48882 .4105 L
.48109 .38452 L
.47211 .36111 L
.44582 .31194 L
.42792 .28757 L
.40903 .26679 L
.39043 .25008 L
.36932 .23475 L
.34515 .22117 L
.32181 .21155 L
.30857 .2075 L
.29597 .20454 L
.28871 .20322 L
.28202 .20225 L
.27465 .20145 L
.26687 .20092 L
.25471 .20071 L
.24785 .20094 L
.24152 .20136 L
.22993 .20269 L
.21771 .20486 L
.20688 .20748 L
.19683 .2105 L
.17441 .21943 L
.15115 .2322 L
.13094 .24665 L
.10913 .26649 L
.09019 .28832 L
.07551 .3092 L
.06163 .33351 L
.0512 .35608 L
.04169 .38199 L
.0368 .39859 L
.03296 .41428 L
.02996 .42933 L
.02733 .44619 L
.02558 .46162 L
.02448 .47623 L
.02389 .49186 L
.0239 .5088 L
.0246 .52603 L
.02531 .53589 L
Mistroke
.02618 .54519 L
.02855 .56398 L
.03201 .58429 L
.04067 .621 L
.05133 .65443 L
.06602 .69067 L
.08559 .72923 L
.13555 .80189 L
.19072 .85858 L
.22483 .88581 L
.25919 .90862 L
.2929 .92716 L
.33099 .94409 L
.36678 .95649 L
.40054 .9653 L
.41991 .96916 L
.43842 .97205 L
.45513 .97399 L
.4734 .97542 L
.49326 .97614 L
.50437 .97617 L
.51442 .97596 L
.53399 .97493 L
.55235 .9732 L
.56962 .97089 L
.58772 .96774 L
.61977 .96033 L
.6536 .94983 L
.68967 .93541 L
.76076 .8959 L
.79733 .8687 L
.82824 .8411 L
.88097 .78079 L
.90286 .74868 L
.92091 .71732 L
.94915 .65309 L
.96012 .61813 L
.96466 .60004 L
.96875 .58026 L
.97191 .56077 L
.97406 .54274 L
.97494 .53279 L
.97553 .52381 L
.97598 .51348 L
.97617 .50379 L
.97598 .48667 L
.97519 .4711 L
.97366 .45425 L
.97129 .43675 L
.96861 .42176 L
Mistroke
.96568 .40835 L
.95741 .37923 L
.94778 .35367 L
.93701 .33086 L
.9076 .2855 L
.88811 .2637 L
.86851 .2462 L
.84907 .23234 L
.82759 .22038 L
.81599 .21523 L
.80308 .21047 L
.79104 .20692 L
.77997 .20439 L
.76857 .20247 L
.75774 .2013 L
.74628 .20073 L
.73384 .20089 L
.72297 .20168 L
.71151 .20318 L
.70177 .20501 L
.69114 .20758 L
.66561 .21633 L
.64307 .22729 L
.61831 .24331 L
.59631 .26165 L
.56176 .30096 L
.54515 .32657 L
.53186 .35217 L
.52016 .38093 L
.51168 .40857 L
.50813 .42341 L
.50497 .43991 L
.50367 .44831 L
.50249 .45735 L
.50159 .46586 L
.50094 .47376 L
.50016 .48928 L
.50001 .49747 L
.50005 .50618 L
.50059 .52077 L
.50115 .52906 L
.50186 .53681 L
.50359 .55111 L
.50567 .56412 L
.51207 .59293 L
.51992 .6184 L
.52889 .64122 L
.54155 .66704 L
.55483 .68904 L
.58683 .72901 L
Mistroke
.60683 .74766 L
.62704 .76285 L
.64838 .77558 L
.66917 .78511 L
.68115 .78944 L
.69268 .79283 L
.69909 .7944 L
.70611 .79586 L
.71847 .79781 L
.72538 .79855 L
.73189 .79901 L
.74407 .7993 L
.7509 .79912 L
.75717 .79874 L
.76404 .79809 L
.77127 .79713 L
.78325 .79493 L
.79432 .79219 L
.80624 .78845 L
.81899 .78352 L
.84107 .77249 L
.86104 .75949 L
.89543 .72869 L
.91282 .70772 L
.92933 .68291 L
.94174 .65969 L
.9533 .63247 L
.95868 .61684 L
.96307 .6019 L
.96697 .58601 L
.96994 .57127 L
.9723 .55649 L
.97403 .54233 L
.97531 .52715 L
.97606 .51051 L
.97614 .49343 L
.97588 .48366 L
.97543 .47449 L
.97392 .45587 L
.97273 .44537 L
.97142 .43578 L
.96854 .41862 L
.96465 .39993 L
.95552 .36604 L
.94469 .33487 L
.93013 .30105 L
.89255 .23552 L
.84864 .17993 L
.80024 .1337 L
.73995 .09085 L
Mistroke
.70306 .07084 L
.66728 .05523 L
.62813 .042 L
.59168 .03304 L
.57123 .02936 L
.5604 .02779 L
.54889 .02641 L
.53881 .02545 L
.5277 .02464 L
.5081 .02388 L
.48866 .02395 L
.47021 .02477 L
.45369 .02615 L
.43575 .02832 L
.41641 .03147 L
.39598 .03573 L
.35978 .04568 L
.32395 .05873 L
.2913 .07364 L
.23368 .10789 L
.17662 .15423 L
.12304 .21387 L
.10001 .24678 L
.07855 .28369 L
.06277 .31668 L
.04861 .35334 L
.03766 .39035 L
.03385 .4067 L
.03036 .42472 L
.02776 .44164 L
.02592 .45746 L
.0246 .47406 L
.02389 .49181 L
.02386 .5068 L
.02444 .52301 L
.02571 .5397 L
.02749 .55497 L
.02968 .5691 L
.0321 .5817 L
.03896 .60913 L
.0484 .63693 L
.06114 .66554 L
.07692 .69298 L
.09374 .71616 L
.12818 .7511 L
.14955 .76677 L
.17008 .77847 L
.18205 .78395 L
.19501 .78888 L
.20637 .79238 L
Mistroke
.21878 .79536 L
.22574 .79665 L
.23215 .79762 L
.24479 .79888 L
.25151 .79921 L
.25887 .7993 L
.26655 .79909 L
.2737 .79863 L
.28668 .7971 L
.29887 .79485 L
.30972 .79218 L
.32137 .78859 L
.3469 .77798 L
.36947 .76515 L
.40807 .73415 L
.42745 .713 L
.44348 .69156 L
.45677 .67006 L
.46941 .64505 L
.47939 .62033 L
.48706 .59612 L
.49088 .581 L
.49428 .5644 L
.49668 .54913 L
.49833 .53497 L
.49948 .51952 L
.49984 .51073 L
.49999 .50251 L
.49995 .49383 L
.49973 .48593 L
.49927 .47682 L
.49862 .46821 L
.49707 .4538 L
.49481 .43862 L
.48915 .4118 L
.48083 .38378 L
.46907 .35419 L
.45678 .32996 L
.44127 .30522 L
.42421 .28314 L
.40407 .26201 L
.38356 .2447 L
.36377 .23127 L
.34293 .22011 L
.32258 .21182 L
.31102 .20818 L
.29816 .20499 L
.29163 .20372 L
.2846 .2026 L
.27183 .20122 L
Mistroke
.2591 .2007 L
.24701 .20098 L
.23618 .20188 L
.22443 .20357 L
.21721 .20497 L
.21046 .20654 L
.19796 .21013 L
.17064 .22125 L
.14803 .23421 L
.12497 .2516 L
.10608 .26968 L
.08756 .29177 L
.07314 .313 L
.05931 .33814 L
.04573 .37017 L
.04052 .38569 L
.03573 .40267 L
.03208 .41836 L
.02881 .43607 L
.02654 .45251 L
.02502 .46819 L
.02404 .48606 L
.02382 .4963 L
.02385 .50586 L
.02446 .52351 L
.02511 .53345 L
.02591 .5425 L
.02794 .55968 L
.0309 .57835 L
.03832 .61224 L
.0504 .65183 L
.06708 .69297 L
.10666 .76332 L
.15483 .82382 L
.20689 .87212 L
.23859 .89546 L
.27515 .91784 L
.30826 .93448 L
.34619 .94976 L
.38203 .96081 L
.41639 .96852 L
.43552 .97164 L
.45317 .9738 L
.47262 .97537 L
.49316 .97614 L
.50974 .97609 L
.52745 .97537 L
.54412 .97407 L
.55924 .97236 L
.57693 .96971 L
Mistroke
.59599 .96606 L
.63015 .95741 L
.66531 .94553 L
.70194 .92969 L
.76428 .89351 L
.8303 .83909 L
.8813 .78035 L
.92343 .71248 L
.942 .67192 L
.95568 .63343 L
.96117 .61418 L
.96556 .59602 L
.96889 .57949 L
.97173 .56208 L
.97293 .55302 L
.97403 .54311 L
.97541 .52578 L
.97589 .51607 L
.97615 .50572 L
.97617 .49601 L
.976 .48722 L
.97518 .47093 L
.97384 .45586 L
.97173 .43959 L
.96874 .42241 L
.96505 .40575 L
.96039 .3887 L
.95021 .35954 L
.93868 .33412 L
.92632 .31212 L
.89297 .26868 L
.87131 .24848 L
.84936 .23253 L
.82861 .22088 L
.80525 .2112 L
.79282 .2074 L
.77901 .2042 L
.77199 .20298 L
.76444 .20195 L
.75729 .20127 L
.75075 .20087 L
.73825 .20074 L
.73119 .20102 L
.72465 .20152 L
.71271 .20299 L
.70009 .20537 L
.68911 .20814 L
.67722 .21189 L
.65378 .22168 L
.6329 .23333 L
Mistroke
.61433 .24631 L
.57625 .28261 L
.55769 .30672 L
.54279 .33072 L
.53137 .35325 L
.52108 .37837 L
.51206 .40713 L
.50883 .42026 L
.50591 .43456 L
.5037 .4481 L
.50213 .46058 L
.50098 .4732 L
.5003 .48524 L
.5 .49922 L
.5002 .5122 L
.50095 .52641 L
.50236 .5415 L
.50437 .55635 L
.50727 .57249 L
.51533 .60435 L
.52533 .63274 L
.53678 .65797 L
.56951 .70923 L
.59159 .73382 L
.61372 .75321 L
.63597 .76856 L
.65762 .78014 L
.6823 .78981 L
.69505 .79343 L
.70196 .79503 L
.70928 .79644 L
.72177 .79819 L
.73328 .79908 L
.74569 .79928 L
.75272 .79903 L
.75925 .79857 L
.7711 .79716 L
.78182 .79523 L
.79408 .79225 L
.80553 .7887 L
.82802 .7794 L
.84829 .76815 L
.86946 .75303 L
.89071 .73367 L
.91098 .71016 L
.92811 .68495 L
.94153 .66012 L
.95388 .63089 L
.96324 .60129 L
.9696 .57312 L
Mistroke
.97223 .55701 L
.97433 .53925 L
.9756 .52221 L
.97614 .50633 L
.9761 .49139 L
.97559 .47734 L
.97449 .46183 L
.9727 .44512 L
.97012 .42751 L
.96702 .41082 L
.95949 .37957 L
.94869 .3456 L
.93615 .31421 L
.89914 .24547 L
.8524 .1841 L
.79158 .12666 L
.73035 .08524 L
.69734 .06811 L
.65988 .05243 L
.62676 .04161 L
.60827 .03673 L
.59067 .03284 L
.57411 .02982 L
.55608 .02724 L
.53962 .02552 L
.52442 .02446 L
.50461 .02383 L
.48583 .02402 L
.46898 .02485 L
.45069 .02646 L
.43091 .02903 L
.41003 .0327 L
.37299 .04168 L
.33966 .0526 L
.30916 .06511 L
.24333 .10137 L
.21103 .1246 L
.17921 .1518 L
.12868 .2066 L
.08454 .27264 L
.06463 .31244 L
.04957 .35053 L
.03824 .38806 L
.03068 .42288 L
.02784 .44104 L
.02655 .45145 L
.02559 .46095 L
.0248 .47092 L
.02421 .48159 L
.0239 .49143 L
Mistroke
.02381 .50073 L
.02417 .51731 L
.02526 .53475 L
.02696 .55094 L
.02905 .56537 L
.03218 .58208 L
.03634 .59969 L
.04591 .63031 L
.05655 .65606 L
.07034 .68235 L
.08576 .70579 L
.10423 .72833 L
.12318 .74685 L
.14164 .76142 L
.16127 .77382 L
.18044 .78327 L
.20219 .79118 L
.21396 .7943 L
.22676 .79682 L
.23955 .79846 L
.246 .79896 L
.25307 .79925 L
.2656 .79913 L
.27723 .7983 L
.289 .79673 L
.30005 .79459 L
.30988 .79214 L
.32043 .78891 L
.34363 .77956 L
.36424 .76844 L
.40457 .73752 L
.42505 .71586 L
.44234 .69322 L
.45812 .66764 L
.47094 .6416 L
.48297 .60981 L
.48727 .59535 L
.49123 .57946 L
.49444 .56349 L
.49675 .54865 L
.49839 .53435 L
.4995 .51918 L
.49996 .5055 L
.49993 .49275 L
.49938 .47877 L
.49821 .46387 L
.49629 .44803 L
.49342 .431 L
.48616 .4007 L
.47663 .37225 L
Mistroke
.46576 .34715 L
.44128 .30524 L
.42484 .28388 L
.40796 .26574 L
.37022 .23533 L
.3472 .22217 L
.32527 .21277 L
.31297 .20874 L
.30124 .20567 L
.29061 .20354 L
.27904 .20189 L
.26634 .20089 L
.25994 .20071 L
.2529 .20075 L
.24046 .20145 L
.22888 .20284 L
.21729 .20495 L
.20639 .20761 L
.18628 .21432 L
.16523 .22402 L
.14327 .23743 L
.1224 .25383 L
.10106 .27519 L
.08099 .30092 L
.0645 .32802 L
.05141 .35558 L
.04148 .38263 L
.03301 .41406 L
.02976 .43046 L
.02831 .43932 L
.02699 .44881 L
.02515 .46663 L
.02414 .48333 L
.02381 .50155 L
.02398 .512 L
.02437 .52183 L
.02564 .5397 L
.02746 .55612 L
.03034 .57516 L
.03384 .59328 L
.04227 .62659 L
.05235 .65725 L
.08315 .72486 L
.1052 .76113 L
.12888 .79365 L
.18022 .84913 L
.24464 .89948 L
.28441 .92283 L
.32281 .94079 L
.35931 .95417 L
Mistroke
.3934 .96367 L
.41253 .96779 L
.43349 .97135 L
.45342 .97382 L
.47191 .97533 L
.48895 .97606 L
.50495 .97616 L
.52249 .97564 L
.54134 .97433 L
.55999 .97226 L
.57951 .96926 L
.614 .96184 L
.65138 .9506 L
.69012 .93521 L
.7559 .89913 L
.79307 .87216 L
.82559 .84366 L
.87897 .78348 L
.91789 .72295 L
.93575 .68669 L
.94955 .65196 L
.96102 .61478 L
.96868 .58065 L
.97176 .5618 L
.97306 .55188 L
.9742 .54136 L
.97498 .53223 L
.97561 .52219 L
.97617 .50458 L
.97603 .48835 L
.97521 .47146 L
.97398 .45723 L
.97207 .44188 L
.96936 .42562 L
.96574 .40861 L
.95737 .3791 L
.94661 .35094 L
.93444 .32607 L
.90694 .28468 L
.88917 .26476 L
.87118 .24837 L
.85016 .23304 L
.82631 .21977 L
.81399 .21443 L
.80031 .20958 L
.78719 .20597 L
.77489 .20345 L
.76262 .20175 L
.75146 .2009 L
.73855 .20073 L
Mistroke
.72639 .20136 L
.71585 .20253 L
.70433 .20448 L
.6924 .20724 L
.68138 .21049 L
.66201 .21787 L
.64187 .22797 L
.61932 .24256 L
.59921 .25898 L
.56549 .29594 L
.55035 .31792 L
.53778 .34007 L
.52501 .36806 L
.51551 .39505 L
.50826 .42282 L
.50546 .43708 L
.50305 .45283 L
.50208 .46106 L
.50133 .46885 L
.50067 .47786 L
.50026 .48606 L
.5 .50097 L
.50012 .50938 L
.5004 .51713 L
.50123 .52996 L
.50262 .54368 L
.5044 .55654 L
.50643 .5682 L
.51297 .59623 L
.52121 .622 L
.5317 .64748 L
.54315 .66992 L
.57475 .71563 L
.59463 .73676 L
.61443 .75376 L
.63763 .76956 L
.66346 .78276 L
.67466 .7872 L
.68684 .7912 L
.69748 .79402 L
.70915 .79642 L
.71631 .79753 L
.72294 .79831 L
.7293 .79885 L
.73605 .7992 L
.74775 .79923 L
.76062 .79844 L
.77281 .79689 L
.78434 .79469 L
.7946 .79211 L
Mistroke
.80569 .78864 L
.82993 .77846 L
.85155 .76605 L
.88788 .73652 L
.90615 .71629 L
.92124 .69578 L
.93648 .67014 L
.9487 .64414 L
.95923 .61512 L
.9641 .598 L
.96799 .58131 L
.97071 .5668 L
.97307 .55071 L
.97465 .53583 L
.97562 .52187 L
.97614 .50664 L
.97606 .48964 L
.97526 .47171 L
.97381 .45473 L
.97164 .43733 L
.96847 .41822 L
.95951 .37966 L
.94819 .34421 L
.93504 .3117 L
.89639 .24125 L
.86958 .20441 L
.84221 .17303 L
.78567 .12204 L
.7515 .09802 L
.71771 .07829 L
.65453 .0505 L
.61957 .03961 L
.60107 .03505 L
.58119 .03103 L
.56992 .02916 L
.55968 .0277 L
.5396 .02552 L
.52831 .02468 L
.51608 .02409 L
.50452 .02383 L
.4939 .02385 L
.47458 .02451 L
.46364 .02525 L
.45345 .02617 L
.43294 .02872 L
.41113 .03248 L
.37028 .04246 L
.33257 .05529 L
.29725 .07069 L
.26535 .08771 L
Mistroke
.20569 .12884 L
.14793 .18372 L
.10118 .24498 L
.07944 .28201 L
.06257 .31714 L
.05102 .34641 L
.04093 .37806 L
.03618 .39638 L
.03254 .41303 L
.02967 .42883 L
.02725 .44551 L
.02541 .46288 L
.02434 .47878 L
.02383 .49576 L
.02384 .50534 L
.02405 .51423 L
.0249 .53015 L
.0262 .54449 L
.02832 .56078 L
.03094 .57595 L
.03891 .60896 L
.04894 .63831 L
.0599 .66306 L
.07369 .68789 L
.09092 .71261 L
.11125 .73566 L
.13039 .75291 L
.15226 .76849 L
.17388 .78031 L
.19427 .78863 L
.20429 .79179 L
.21529 .7946 L
.22575 .79666 L
.23547 .79803 L
.2468 .799 L
.25744 .7993 L
.26911 .79896 L
.28163 .7978 L
.28786 .79691 L
.29464 .79572 L
.3069 .79294 L
.31872 .78948 L
.32955 .78561 L
.35404 .77429 L
.37559 .76106 L
.39789 .74361 L
.41963 .72208 L
.45123 .67951 L
.46602 .65231 L
.47758 .62528 L
Mistroke
.48649 .59815 L
.49007 .58444 L
.49291 .57158 L
.49503 .56005 L
.49694 .54722 L
.4984 .53422 L
.49943 .52035 L
.49996 .50526 L
.4999 .4914 L
.49923 .47622 L
.49784 .46029 L
.49606 .44649 L
.49394 .43374 L
.48745 .40531 L
.47793 .37567 L
.46692 .34957 L
.4525 .32259 L
.43474 .29624 L
.39978 .25807 L
.37747 .24025 L
.35527 .22637 L
.3331 .2158 L
.3219 .21158 L
.31137 .20828 L
.30096 .20561 L
.29146 .20369 L
.28084 .2021 L
.26948 .20106 L
.25719 .20069 L
.2459 .20104 L
.23353 .2022 L
.22055 .20428 L
.20933 .20683 L
.19897 .20981 L
.17589 .21875 L
.15215 .23157 L
.13131 .24635 L
.10994 .26567 L
.08926 .28953 L
.07426 .3112 L
.06001 .33672 L
.04686 .3671 L
.03706 .39761 L
.03049 .42643 L
.02773 .44327 L
.02581 .45923 L
.02447 .47642 L
.02388 .49225 L
.02394 .51074 L
.02475 .52835 L
Mistroke
.02603 .54372 L
.02799 .56006 L
.03015 .57405 L
.03304 .58944 L
.04145 .62375 L
.05174 .65559 L
.08322 .72498 L
.10598 .7623 L
.13009 .79517 L
.18134 .85016 L
.24466 .8995 L
.27419 .91731 L
.3074 .93408 L
.33707 .94643 L
.37044 .95758 L
.40824 .96694 L
.42916 .9707 L
.44876 .97332 L
.46725 .97502 L
.48412 .97592 L
.5036 .97618 L
.52201 .97566 L
.54007 .97444 L
.55942 .97233 L
.57759 .96959 L
.5941 .96646 L
.6339 .95628 L
.67078 .94339 L
.74023 .90897 L
.77677 .88465 L
.80855 .85923 L
.86023 .80691 L
.89964 .75375 L
.91818 .72242 L
.93544 .6874 L
.94905 .65339 L
.95906 .62194 L
.9673 .58777 L
.97069 .56895 L
.97315 .55118 L
.97477 .53485 L
.97573 .51984 L
.97618 .50349 L
.97597 .4863 L
.97506 .46934 L
.97425 .45991 L
.97332 .45134 L
.97113 .43576 L
.96819 .41967 L
.95981 .38675 L
Mistroke
.95382 .36893 L
.94748 .35296 L
.93274 .32301 L
.91645 .29726 L
.88054 .25647 L
.85781 .23819 L
.83554 .22443 L
.80993 .21287 L
.79667 .20848 L
.78902 .20641 L
.78189 .20478 L
.77499 .20346 L
.76872 .20249 L
.76173 .20166 L
.75428 .20106 L
.74775 .20076 L
.7407 .2007 L
.72793 .20124 L
.71543 .20259 L
.70916 .20358 L
.70232 .20489 L
.6903 .20781 L
.67921 .21121 L
.65255 .22229 L
.62934 .23562 L
.60413 .25463 L
.58218 .27592 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00eP3oool00`3ooml0W4P0000000020000000307Boo`3oool0oooo0=80oooo003H0?ooo`03
0?noM00007@0_ooo0=D0oooo003H0?ooo`030?oo_`1d0000M;oo0=D0oooo003H0?ooo`030?oog`2L
B000B9cO0=D0oooo003I0?ooo`030=nLB000000000000080000000<0M;oo0?ooo`3oool00P3oool0
1@3o_g@000000000000004P0W=oo0080oooo00<0oono07@0000000000P0000003@18W=l0oooo0?oo
o`3oool0_g@00000000004P0W=oo0?ooo`3o_g@000000000B02Lgol00P3oool0102oM00000000000
B02Lgol20?ooo`050?noM000000000000000B02Lgol00`3oool00`3OW4P004RL0=ooo`020?ooo`03
0;md0000000007Bo09`0oooo003I0?ooo`070?noM00004P0W=oo0?ooo`3ooml0W4P0001d_`020?oo
o`0?0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`3oool0oooO09a8001d_ol0oooo0?oOW0180000
M;oo0080oooo01L0gia80018W03Ooml0W7BL0=ooo`3o_g@0001809cOg`2LM9`0gooo0?ooo`3OW4P0
04RL0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`020?ooo`030?noM00007@0
_ooo0080oooo00@0gia80018W03O_g@0M;ooV`3oool00=T0oooo00<0oono07@0001d_ol00P3oool0
1`3ooml0W4P004RLg`3oool0gia80018W03Oool00P3oool02P3ogi`0B00004RLg`3oool0_gAd0;oo
o`3oool0oono07@0001d_ol20?ooo`030?noM00004P0W=oo0080oooo00<0oono07@0001d_ol00`3o
ool00`3o_g@0001809cOo`020?ooo`030=nLB000B9`0gooo0080oooo00L0omnL04P00018W=l0oooo
0?oo_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol0W03oool00=T0oooo00<0oooO09a80018W=l0
0`3oool01P3ogi`0B01809cOo`3o_g@0001d0;ooo`<0oooo00<0gia80000M02oool00`3oool00`3O
W4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo00<0_g@0001d_`3oool00P3oool00`3o
okl0M00004RLg`020?ooo`030?noM00007@0_ooo00<0oooo00/0gia80000M02oool0oooO09a80000
07@0_ooo0?ooo`3ooml0W4P004RLg`2L0?ooo`00fP3oool00`3OW4P0001d0;ooo`020?ooo`060?oo
g`2LB000B9cO0?oo_`1d0000M;oo0`3oool00`3ogi`0B01809cOo`020?ooo`030?noM00004P0W=oo
00@0oooo00<0_g@00018W03Oool00P3oool00`3OW4P004RL0=ooo`030?ooo`070;md0000B9`0gooo
0?ooo`3ookl0M00007Boo`030?ooo`070?oOW01804P0W=oo0?ooo`3OW4P004Q804Qd_`020?ooo`03
0;md0000M;l0oooo09/0oooo003J0?ooo`040?noM000000004RL0=ooo`80oooo00H0gia8001d_`3o
ool0gia80000M02oool20?ooo`0:0?oo_`1d0000M;oo0?ooo`3ogi`0B01809cOo`3oool0giad09cO
o`80oooo00<0gia80000B02Lgol00P3oool00`3ogi`0B01809cOo`030?ooo`030=nLB00004P0W=oo
0080oooo00<0gia80000M02oool00P3oool0303ookl0M00007Boo`3oool0okmd0000M02o_g@0B9cO
0?ooo`3o_g@0001d0;oooi/0oooo003J0?ooo`080?oo_`1d0000M9bL04P0M02oool0oooO09a80000
M;l20?ooo`0>0;md000007@0_ooo0?ooo`3o_g@0001d0;ooo`3oool0omnL04P0B02Lgol0oooO09a8
001d_ol20?ooo`030?oOW0180000B9cO0080oooo00<0oooO09a80018W=l00`3oool00`3ogi`0B000
04RLg`030?ooo`0@0;md000007@0_ooo0?ooo`3o_g@0001d0;ooo`3oool0oooO09a8001d_ol0gia8
001d_`3ogi`0B01809cOoi/0oooo003I0?ooo`090?oOW0180000000004RLg`3ookl0M00000000000
07@0_ooo00<0oooo00D0okmd000000000000000007Boo`030?ooo`070;md00000000000000000018
W=l0oooo0?noM002000000040018W03Oool0oono07@000<0000000H0M;oo0?noM000000000000018
W03Oool30?ooo`0?0?noM000000000000000001d_ol0oooo0?oo_`1d0000000004RLg`3oool0okmd
0000000004P0W=oo09/0oooo003j0?ooo`030?noM00007@0_ooo0;<0oooo003k0?ooo`030=nLM02L
gol0oooo0;80oooo003e0?ooo`040?oo_`1d000004RL0=ooo`L0oooo00@0oono07@00000B9`0gooo
[03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool004H0oooo00@0_g@0000000000000M;oo0`3oool0
0`3ogi`0B00007Boo`020?ooo`030=nLB0000000000000<0000000<0B9cO0?ooo`3oool0@@3oool0
102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00<0oono07@0000000000P00
00000`18W=l0oooo0?ooo`120?ooo`040;md00000000000007Bood/0oooo00@0_g@0000000000000
M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3o
ool0@P3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00<0gia80000
000000000`0000000`18W=l0oooo0?ooo`040?ooo`00A@3oool01P3OW4P007Bo0?ooo`3ogi`0B000
04RLg`80oooo00<0omnL04P0001d_ol00`3oool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02oool0
oooo0400oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00@0oooo
00<0okmd0000001d_ol0A03oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLgdT0oooo00H0gia8001d
_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00@0oooo00<0okmd0000001d_ol0A03o
ool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0
07Bo0?ooo`020?ooo`030;mdM02oool0oooo00@0oooo00140?ooo`030?oog`2LB000B9cO0080oooo
00<0okmd0000B02Lgol0203oool00`3o_g@007Bo0?ooo`130?ooo`030?oog`2LB000B9cO0080oooo
00<0okmd0000B02Lgol0203oool00`3ooml0W4P0001d_`130?ooo`030?oog`2LB000B9cO0080oooo
00<0okmd0000B02Lgol0A`3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00P0oooo
00<0oooO09a80000M;l0@`3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00P0oooo
00<0okmd001d_`3oool0203oool004@0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018
W03Oool80?ooo`030?noM000M;l0oooo0480oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P0
0018W03Oool80?ooo`030=nLB000B9`0gooo0480oooo00<0oooO09a80018W=l00P3oool0103ooml0
W4P00018W03Ooom60?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo203oool0
0`3OW4P004RL0=ooo`120?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo203o
ool00`3o_g@007Bo0?ooo`070?ooo`00=`3oool00`3ooml0W4P0000000070000000604RLg`3oool0
oooo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`090?ooo`030?noM018W=l0oooo03@0oooo
00<0oooO09a8000000001`0000001P18W=l0oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0gia80000
B02Lgol0203oool00`3ogi`0B01809cOo`120?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000
B02Lgol0AP3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00P0oooo00<0omnL04P0
B02Lgol0@P3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00T0oooo00<0okmd04RL
g`3oool01P3oool004D0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?ooo`03
0=nLB018W=l0oooo0440oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`080?ooo`03
0?oo_`1d0000M;oo04<0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`170?ooo`03
0;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0203oool00`3ookl0M00007Boo`130?ooo`03
0;md0000B9`0gooo0080oooo00<0omnL04P00018W=l02P3oool00`3OW4P0B9cO0?ooo`050?ooo`00
A@3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00/0oooo00<0_g@007Boo`3oool0
@03oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00T0oooo00<0_g@0001d_`3oool0
@P3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo04L0oooo00<0gia80000B02Lgol0
0P3oool00`3ooml0W4P0001d_`090?ooo`030;md0000M;l0oooo0480oooo00<0gia80000B02Lgol0
0P3oool00`3ooml0W4P0001d_`0;0?ooo`030;md001d_ol0oooo00@0oooo00150?ooo`030?oOW018
0000B9cO00<0oooo00<0_g@00018W03Oool02P3oool00`3ogi`0B01d0;ooo`100?ooo`030?oOW018
0000B9cO00<0oooo00<0_g@00018W03Oool0203oool00`3OW4P004RL0=ooo`120?ooo`030?oOW018
0000B9cO00<0oooo00<0_g@00018W03Oool0AP3oool00`3ogi`0B00004RLg`030?ooo`030;md0000
B9`0gooo00P0oooo00<0gia80018W03Oool0@P3oool00`3ogi`0B00004RLg`030?ooo`030;md0000
B9`0gooo00X0oooo00<0omnL04P0M02oool0103oool004D0oooo00@0oooO09a80000B9`0gooo0P3o
ool00`3OW4P004RL0=ooo`0:0?ooo`030?oog`2LB000M;oo0400oooo00@0oooO09a80000B9`0gooo
0P3oool00`3OW4P004RL0=ooo`080?ooo`030?oOW01804P0W=oo0480oooo00@0oooO09a80000B9`0
gooo0P3oool00`3OW4P004RL0=ooo`160?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018
W03Oool0203oool00`3ogi`0B01809cOo`120?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia8
0018W03Oool02P3oool00`3ooml0W4P007Boo`040?ooo`00AP3oool00`3ogi`0B00007Boo`020?oo
o`030=nLB000M;l0oooo00X0oooo00<0oono07@00018W=l0@@3oool00`3ogi`0B00007Boo`020?oo
o`030=nLB000M;l0oooo00P0oooo00<0oono07@0001d_ol0@`3oool00`3ogi`0B00007Boo`020?oo
o`030=nLB000M;l0oooo04L0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`080?oo
o`030?oo_`1d0000M;oo04<0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`0:0?oo
o`030?oo_`1d0000B9cO00@0oooo00170?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO1`3oool0
1`3o_g@004RL0=ooo`3oool0gia80000B02Lgol0@P3oool01P3OW4P0001d0;ooo`3ooml0W4P004RL
g`X0oooo00<0_g@0001d_`3oool0@`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLgdT0oooo00H0
gia80000M02oool0oooO09a80018W=l:0?ooo`030;md0000M;l0oooo04<0oooo00H0gia80000M02o
ool0oooO09a80018W=l70?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cOo`040?ooo`00B03o
ool0103OW4P0000000000000M;l90?ooo`050?oOW018000000000000001d_ol0A03oool0103OW4P0
000000000000M;l90?ooo`050?oo_`1d000000000000M02oool0A03oool0103OW4P0000000000000
M;m;0?ooo`040=nLB00000000000001d_`T0oooo00D0oono07@000000000001d0;ooo`140?ooo`04
0=nLB00000000000001d_`T0oooo00D0omnL04P000000000000007Boo`050?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00A`3ooooo000005d000003@3oool0
04L0oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool00000
00d0oooo00170?ooo`030000003oool000000100oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0000000=0?ooo`00A`3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0:X0oooo
00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?oo
o`2Z0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo0:/0oooo00<00000
0?ooo`3oool0ZP3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`2[0?oo
o`030000003oool0oooo0:X0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3o
ool0Z`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000
003oool0oooo0:/0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0;0?ooo`00A`3o
ool2000009P0oooo:@00002G0?ooo`8000003@3oool004L0oooo00<000000?ooo`3oool0TP3oool8
00000140oooo00<000000?ooo`3oool02`3oool=00000980oooo00<000000?ooo`3oool02`3oool0
04L0oooo00<000000?ooo`3oool0R`3oool9000001L0oooo00<000000?ooo`3oool04`3oool:0000
08d0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0Q`3oool7000001d0
oooo00<000000?ooo`3oool06@3oool9000008P0oooo00<000000?ooo`3oool02`3oool004L0oooo
00<000000?ooo`3oool0P`3oool700000240oooo00<000000?ooo`3oool07`3oool6000008D0oooo
00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0O`3oool7000002D0oooo00<0
00000?ooo`3oool08`3oool600000840oooo00<000000?ooo`3oool02`3oool004L0oooo00<00000
0?ooo`3oool0N`3oool6000002X0oooo00<000000?ooo`3oool09`3oool5000007h0oooo00<00000
0?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0N@3oool5000002d0oooo00<000000?oo
o`3oool0:P3oool6000007X0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3o
ool0M@3oool600000300oooo00<000000?ooo`3oool0;P3oool5000007L0oooo00<000000?ooo`3o
ool02`3oool004L0oooo00<000000?ooo`3oool0LP3oool6000003<0oooo00<000000?ooo`3oool0
<@3oool5000007@0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0L03o
ool5000003H0oooo00<000000?ooo`3oool0<`3oool500000780oooo00<000000?ooo`3oool02`3o
ool004L0oooo00<000000?ooo`3oool0KP3oool5000003P0oooo00<000000?ooo`3oool0=P3oool4
00000700oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0J`3oool50000
03/0oooo00<000000?ooo`3oool0>@3oool3000006h0oooo00<000000?ooo`3oool02`3oool004L0
oooo00<000000?ooo`3oool0J@3oool5000003d0oooo00<000000?ooo`3oool0>`3oool3000006`0
oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0I`3oool5000003l0oooo
00<000000?ooo`3oool0?@3oool3000006X0oooo00<000000?ooo`3oool02`3oool004L0oooo00<0
00000?ooo`3oool0I@3oool400000480oooo00<000000?ooo`3oool0?`3oool3000006P0oooo00<0
00000?ooo`3oool02`3oool004L0oooo0P00001T0?ooo`@00000A03oool00`000000oooo0?ooo`11
0?ooo`@00000I03oool2000000d0oooo00170?ooo`030000003oool0oooo0640oooo100000160?oo
o`030000003oool0oooo04<0oooo1000001S0?ooo`030000003oool0oooo00/0oooo00170?ooo`03
0000003oool0oooo0600oooo0`0000180?ooo`030000003oool0oooo04D0oooo1000001Q0?ooo`03
0000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo05h0oooo0`00001:0?ooo`030000
003oool0oooo04L0oooo1000001O0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003o
ool0oooo05`0oooo0`00001<0?ooo`030000003oool0oooo04P0oooo1@00001M0?ooo`030000003o
ool0oooo00/0oooo00170?ooo`030000003oool0oooo05X0oooo1000001=0?ooo`030000003oool0
oooo04X0oooo1000001L0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo
05P0oooo1000001?0?ooo`030000003oool0oooo04`0oooo1000001J0?ooo`030000003oool0oooo
00/0oooo00170?ooo`030000003oool0oooo05H0oooo1000001A0?ooo`030000003oool0oooo04h0
oooo1000001H0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo05@0oooo
1000001C0?ooo`030000003oool0oooo0500oooo1000001F0?ooo`030000003oool0oooo00/0oooo
00170?ooo`030000003oool0oooo0580oooo1@00001D0?ooo`030000003oool0oooo0540oooo1000
001E0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo0540oooo1000001F
0?ooo`030000003oool0oooo05<0oooo0`00001D0?ooo`030000003oool0oooo00/0oooo00170?oo
o`030000003oool0oooo0500oooo0`00001H0?ooo`030000003oool0oooo05@0oooo1000001B0?oo
o`030000003oool0oooo00/0oooo000[0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0
001d_ol01@3oool00`3ooml0W4P004RLg`0:0?ooo`030000003oool0oooo04h0oooo1000001I0?oo
o`030000003oool0oooo05H0oooo0`00001A0?ooo`030000003oool0oooo00/0oooo000Z0?ooo`06
0=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`060?ooo`030=nLB000B9`0
gooo00T0oooo00<000000?ooo`3oool0C@3oool3000005/0oooo00<000000?ooo`3oool0F03oool2
00000500oooo00<000000?ooo`3oool02`3oool002T0oooo00<0oooO09a80018W=l00P3oool00`3o
_g@0001809cOo`0:0?ooo`030?oOW01804P0W=oo00T0oooo00<000000?ooo`3oool0B`3oool30000
05d0oooo00<000000?ooo`3oool0F@3oool3000004h0oooo00<000000?ooo`3oool02`3oool002T0
oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool50?ooo`030?noM00000000000
00@0000000<004RL0=ooo`3oool01P3oool00`000000oooo0?ooo`1:0?ooo`<00000GP3oool00`00
0000oooo0?ooo`1J0?ooo`<00000C@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`3ooml0
W4P0000000070000000604RLg`3oool0oooo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`05
0?ooo`030?oog`2LB4P0W=oo0080oooo00<0_g@0001d_`3oool0203oool00`000000oooo0?ooo`19
0?ooo`<00000G`3oool00`000000oooo0?ooo`1L0?ooo`<00000B`3oool00`000000oooo0?ooo`0;
0?ooo`00:P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00H0oooo00L0oono07@0
M02oool0oooo0?noM000B9`0gooo00P0oooo0`0000180?ooo`800000H@3oool00`000000oooo0?oo
o`1M0?ooo`<00000B03oool3000000d0oooo000Z0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO
09a80000M;l01`3oool01P3ogi`0B4RL0=ooo`3ogi`0B01809cOo`P0oooo00<000000?ooo`3oool0
A`3oool200000680oooo00<000000?ooo`3oool0GP3oool4000004P0oooo00<000000?ooo`3oool0
2`3oool002X0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`070?ooo`050?noM000
M;l0oooO09a80018W=l0203oool00`000000oooo0?ooo`150?ooo`<00000H`3oool00`000000oooo
0?ooo`1P0?ooo`<00000A`3oool00`000000oooo0?ooo`0;0?ooo`00:P3oool0103ooml0W4P00018
W03Oool20?ooo`030=nLB000B9`0gooo00P0oooo00@0gia804RLg`2oM00007Bo203oool00`000000
oooo0?ooo`140?ooo`<00000I03oool00`000000oooo0?ooo`1Q0?ooo`<00000AP3oool00`000000
oooo0?ooo`0;0?ooo`00:`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00T0oooo
00@0gia807AdM00007@0_ooo1`3oool00`000000oooo0?ooo`130?ooo`800000IP3oool00`000000
oooo0?ooo`1R0?ooo`<00000A@3oool00`000000oooo0?ooo`0;0?ooo`00;03oool01P3OW4P0001d
0;ooo`3ooml0W4P004RLg`/0oooo00<0_g@00000B02Lgol01`3oool00`000000oooo0?ooo`120?oo
o`800000I`3oool00`000000oooo0?ooo`1T0?ooo`800000A03oool00`000000oooo0?ooo`0;0?oo
o`00;@3oool0103OW4P0000000000000M;l<0?ooo`030?oog`2LB000B9cO00L0oooo00<000000?oo
o`3oool0@@3oool2000006P0oooo00<000000?ooo`3oool0I@3oool2000004<0oooo00<000000?oo
o`3oool02`3oool004L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1X0?ooo`03
0000003oool0oooo06H0oooo0P0000120?ooo`030000003oool0oooo00/0oooo00170?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1X0?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0?@3o
ool2000006`0oooo00<000000?ooo`3oool0J@3oool2000003l0oooo00<000000?ooo`3oool02`3o
ool004L0oooo00<000000?ooo`3oool0?03oool2000006d0oooo00<000000?ooo`3oool0JP3oool2
000003h0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0>`3oool20000
06h0oooo00<000000?ooo`3oool0J`3oool2000003d0oooo00<000000?ooo`3oool02`3oool004L0
oooo00<000000?ooo`3oool0>P3oool2000006l0oooo00<000000?ooo`3oool0K03oool2000003`0
oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0>@3oool200000700oooo
00<000000?ooo`3oool0K@3oool2000003/0oooo00<000000?ooo`3oool02`3oool004L0oooo00<0
00000?ooo`3oool0>03oool200000740oooo00<000000?ooo`3oool0KP3oool2000003X0oooo00<0
00000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0=`3oool200000780oooo00<00000
0?ooo`3oool0K`3oool2000003T0oooo00<000000?ooo`3oool02`3oool004L0oooo0P00000g0?oo
o`800000L`3oool00`000000oooo0?ooo`1`0?ooo`800000=`3oool2000000d0oooo00170?ooo`03
0000003oool0oooo03D0oooo0P00001d0?ooo`030000003oool0oooo0740oooo0P00000g0?ooo`03
0000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo03@0oooo0P00001e0?ooo`030000
003oool0oooo0780oooo0P00000f0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003o
ool0oooo03<0oooo0P00001f0?ooo`030000003oool0oooo07<0oooo0P00000e0?ooo`030000003o
ool0oooo00/0oooo00170?ooo`030000003oool0oooo0380oooo0P00001g0?ooo`030000003oool0
oooo07@0oooo0P00000d0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo
0340oooo0P00001h0?ooo`030000003oool0oooo07D0oooo0P00000c0?ooo`030000003oool0oooo
00/0oooo00170?ooo`030000003oool0oooo0300oooo0P00001i0?ooo`030000003oool0oooo07H0
oooo0P00000b0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo02l0oooo
0P00001j0?ooo`030000003oool0oooo07L0oooo0P00000a0?ooo`030000003oool0oooo00/0oooo
00170?ooo`030000003oool0oooo02h0oooo0P00001k0?ooo`030000003oool0oooo07P0oooo0P00
000`0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo02h0oooo0P00001k
0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0;
0?ooo`00A`3oool00`000000oooo0?ooo`0]0?ooo`800000O03oool00`000000oooo0?ooo`1i0?oo
o`800000;`3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0/0?ooo`80
0000O@3oool00`000000oooo0?ooo`1j0?ooo`800000;P3oool00`000000oooo0?ooo`0;0?ooo`00
A`3oool00`000000oooo0?ooo`0[0?ooo`800000803ooolD000004X0oooo00<000000?ooo`3oool0
B03ooolB00000240oooo0P00000]0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool06@3oool9000000h0oooo200000150?ooo`030000003o
ool0oooo0440oooo2P00000=0?ooo`P00000703oool2000002`0oooo00<000000?ooo`3oool02`3o
ool004L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0G0?ooo`L000006@3oool6
00000440oooo00<000000?ooo`3oool0?@3oool8000001T0oooo1P00000I0?ooo`800000:`3oool0
0`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0Y0?ooo`8000005@3oool70000
0200oooo1`00000m0?ooo`030000003oool0oooo03/0oooo1P00000P0?ooo`L000005@3oool20000
02/0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0:03oool2000001@0
oooo1@00000X0?ooo`D00000>`3oool00`000000oooo0?ooo`0h0?ooo`D00000:03oool6000001<0
oooo0P00000Z0?ooo`030000003oool0oooo00/0oooo00170?ooo`800000:03oool2000001<0oooo
1000000_0?ooo`@00000>03oool00`000000oooo0?ooo`0f0?ooo`@00000;P3oool500000180oooo
0P00000X0?ooo`8000003@3oool004L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0@0?ooo`@00000<`3oool4000003H0oooo00<000000?ooo`3oool0<`3oool4000003@0oooo1000
000A0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02`3oool004L0oooo00<00000
0?ooo`3oool09P3oool200000100oooo0`00000h0?ooo`@00000=03oool00`000000oooo0?ooo`0a
0?ooo`@00000>03oool4000000l0oooo0P00000X0?ooo`030000003oool0oooo00/0oooo00170?oo
o`030000003oool0oooo02D0oooo0P00000?0?ooo`<00000?03oool400000380oooo00<000000?oo
o`3oool0;`3oool4000003`0oooo0`00000?0?ooo`8000009`3oool00`000000oooo0?ooo`0;0?oo
o`00A`3oool00`000000oooo0?ooo`0T0?ooo`8000003P3oool300000400oooo0`00000a0?ooo`03
0000003oool0oooo02h0oooo0`0000100?ooo`<000003P3oool2000002H0oooo00<000000?ooo`3o
ool02`3oool004L0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0<0?ooo`800000
A03oool3000002l0oooo00<000000?ooo`3oool0;03oool3000004@0oooo0`00000=0?ooo`800000
9@3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0S0?ooo`800000303o
ool3000004L0oooo0`00000]0?ooo`030000003oool0oooo02X0oooo0`0000180?ooo`800000303o
ool2000002D0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool08P3oool2
000000/0oooo0`00001:0?ooo`<00000;03oool00`000000oooo0?ooo`0Y0?ooo`800000B`3oool3
000000/0oooo0P00000T0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool02@3oool2000004h0oooo0P00000[0?ooo`030000003oool0oooo
02L0oooo0`00001>0?ooo`8000002`3oool2000002<0oooo00<000000?ooo`3oool02`3oool004L0
oooo00<000000?ooo`3oool08@3oool2000000X0oooo0P00001A0?ooo`800000:@3oool00`000000
oooo0?ooo`0V0?ooo`<00000D03oool2000000/0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0P0?ooo`8000002@3oool3000005<0oooo
0P00000X0?ooo`030000003oool0oooo02D0oooo0P00001D0?ooo`8000002@3oool200000280oooo
00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool07`3oool2000000T0oooo0P00
001F0?ooo`<000009P3oool00`000000oooo0?ooo`0T0?ooo`800000EP3oool2000000T0oooo0P00
000Q0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo01l0oooo0P000008
0?ooo`800000F03oool3000002D0oooo00<000000?ooo`3oool08P3oool3000005P0oooo0P000009
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?oo
o`3oool07P3oool2000000P0oooo0P00001K0?ooo`800000903oool00`000000oooo0?ooo`0Q0?oo
o`800000F`3oool3000000L0oooo0P00000P0?ooo`030000003oool0oooo00/0oooo00170?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool01P3oool2000005d0oooo0P00000S0?ooo`03
0000003oool0oooo0200oooo0P00001M0?ooo`<000001`3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo01d0oooo0P0000070?ooo`800000
G`3oool300000240oooo00<000000?ooo`3oool07`3oool200000600oooo0P0000060?ooo`800000
7`3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool2000001d0oooo0P0000060?ooo`800000HP3o
ool300000200oooo00<000000?ooo`3oool07P3oool200000680oooo0P0000060?ooo`030000003o
ool0oooo01`0oooo0P00000=0?ooo`00A`3oool00`000000oooo0?ooo`0L0?ooo`8000001@3oool2
000006@0oooo0`00000O0?ooo`030000003oool0oooo01d0oooo0P00001T0?ooo`8000001@3oool2
000001h0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool06`3oool20000
00D0oooo0P00001W0?ooo`8000007P3oool00`000000oooo0?ooo`0L0?ooo`800000IP3oool20000
00D0oooo0P00000M0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool00`3oool2000006T0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo06L0oooo0P0000040?ooo`8000007@3oool00`000000
oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0J0?ooo`8000001@3oool00`000000oooo
0?ooo`1X0?ooo`8000007@3oool00`000000oooo0?ooo`0J0?ooo`800000JP3oool2000000@0oooo
0P00000L0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo01T0oooo0P00
00050?ooo`030000003oool0oooo06X0oooo0P00000L0?ooo`030000003oool0oooo01T0oooo0P00
001[0?ooo`<000000`3oool3000001/0oooo00<000000?ooo`3oool02`3oool004L0oooo00<00000
0?ooo`3oool06@3oool2000000@0oooo00<000000?ooo`3oool0K03oool2000001/0oooo00<00000
0?ooo`3oool0603oool2000006d0oooo0`0000030?ooo`8000006`3oool00`000000oooo0?ooo`0;
0?ooo`00A`3oool00`000000oooo0?ooo`0H0?ooo`800000103oool2000006l0oooo0P00000J0?oo
o`030000003oool0oooo01L0oooo0P00001_0?ooo`800000103oool2000001X0oooo00<000000?oo
o`3oool02`3oool004L0oooo00<000000?ooo`3oool0603oool2000000<0oooo0P00001a0?ooo`80
00006@3oool00`000000oooo0?ooo`0F0?ooo`800000L@3oool2000000<0oooo0P00000J0?ooo`03
0000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo01L0oooo0P0000030?ooo`800000
L`3oool2000001P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1`0?ooo`<00000
0`3oool2000001T0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool05`3o
ool200000080oooo0`00001c0?ooo`<000005`3oool00`000000oooo0?ooo`0E0?ooo`800000L`3o
ool2000000<0oooo0P00000I0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0
oooo01H0oooo0P0000030?ooo`800000M@3oool2000001L0oooo00<000000?ooo`3oool0503oool2
000007D0oooo0P0000030?ooo`800000603oool00`000000oooo0?ooo`0;0?ooo`00:`3oool0102o
M00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00<0gia80000000000000`000000
0`18W=l0oooo0?ooo`070?ooo`030000003oool0oooo01H0oooo0P0000020?ooo`800000M`3oool2
000001H0oooo00<000000?ooo`3oool04`3oool2000007L0oooo0P0000020?ooo`800000603oool0
0`000000oooo0?ooo`0;0?ooo`00:P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0
omnL04P0001d_ol00`3oool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02oool0oooo00L0oooo00<0
00000?ooo`3oool05@3oool200000080oooo0P00001i0?ooo`8000005@3oool00`000000oooo0?oo
o`0B0?ooo`800000N03oool300000080oooo0P00000G0?ooo`030000003oool0oooo00/0oooo000Y
0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0203oool00`3o_g@007Bo0?ooo`0;
0?ooo`030000003oool0oooo01D0oooo0P0000020?ooo`800000N@3oool2000001D0oooo00<00000
0?ooo`3oool04P3oool2000007T0oooo0`0000000`3oool000000000000G0?ooo`030000003oool0
oooo00/0oooo000Y0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo203oool0
0`3o_g@007Bo0?ooo`0:0?ooo`030000003oool0oooo01@0oooo0P0000020?ooo`800000N`3oool2
000001@0oooo00<000000?ooo`3oool04@3oool2000007/0oooo0P0000020?ooo`8000005P3oool0
0`000000oooo0?ooo`0;0?ooo`00703oool00`3ooml0W4P0000000070000000604RLg`3oool0oooo
0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`090?ooo`030?noM018W=l0oooo00T0oooo00<0
00000?ooo`3oool0503oool2000000030?ooo`000000000007d0oooo0P00000C0?ooo`030000003o
ool0oooo0100oooo0P00001m0?ooo`80000000<0oooo0000000000005P3oool00`000000oooo0?oo
o`0;0?ooo`00:P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00X0oooo00<0gia8
04RLg`3oool0203oool3000001<0oooo0`0000000`3oool000000000001n0?ooo`8000004P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo07`0oooo0P0000020?ooo`8000004`3oool3
000000d0oooo000Z0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l02`3oool00`2o
M000M;oo0?ooo`070?ooo`030000003oool0oooo01<0oooo0P0000000`3oool000000000001o0?oo
o`8000004P3oool00`000000oooo0?ooo`0?0?ooo`800000O`3oool2000000030?ooo`0000000000
01D0oooo00<000000?ooo`3oool02`3oool002X0oooo00<0omnL04P00018W=l00`3oool00`2oM000
04RL0=ooo`0:0?ooo`030?oOW01807@0_ooo00L0oooo00<000000?ooo`3oool04`3oool400000840
oooo0P00000A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0O`3oool200000003
0?ooo`000000000001@0oooo00<000000?ooo`3oool02`3oool002X0oooo00@0oooO09a80000B9`0
gooo0P3oool00`3OW4P004RL0=ooo`0:0?ooo`030?oog`2LB000M;oo00L0oooo00<000000?ooo`3o
ool04P3oool2000000030?ooo`00000000000880oooo0P00000@0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0P03oool2000000030?ooo`000000000001@0oooo00<000000?ooo`3o
ool02`3oool002/0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`0:0?ooo`030?oo
_`1d0000B9cO00L0oooo00<000000?ooo`3oool04P3oool4000008<0oooo0P00000@0?ooo`030000
003oool0oooo00d0oooo0P0000230?ooo`@00000503oool00`000000oooo0?ooo`0;0?ooo`00;03o
ool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`L0oooo00L0okmd0018W03Oool0oooo0=nLB00004P0
W=oo00L0oooo00<000000?ooo`3oool04@3oool2000000030?ooo`000000oooo08@0oooo0P00000?
0?ooo`030000003oool0oooo00`0oooo0P0000250?ooo`040000003oool00000000001<0oooo00<0
00000?ooo`3oool02`3oool002d0oooo00@0gia800000000000007Bo2@3oool01@3ogi`0B0000000
00000000M;oo00P0oooo00<000000?ooo`3oool04@3oool4000008H0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08@0oooo1000000C0?ooo`030000
003oool0oooo00/0oooo00170?ooo`030000003oool0oooo0100oooo100000270?ooo`8000003P3o
ool00`000000oooo0?ooo`0;0?ooo`800000Q`3oool010000000oooo00000000000B0?ooo`030000
003oool0oooo00/0oooo00170?ooo`030000003oool0oooo0100oooo100000280?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool02P3oool2000008P0oooo1000000B0?ooo`030000003o
ool0oooo00/0oooo00170?ooo`030000003oool0oooo0100oooo0`0000290?ooo`8000003@3oool0
0`000000oooo0?ooo`0:0?ooo`800000R@3oool00`000000oooo0000000B0?ooo`030000003oool0
oooo00/0oooo00170?ooo`030000003oool0oooo00l0oooo1000002:0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02@3oool2000008X0oooo1000000A0?ooo`030000003oool0oooo
00/0oooo00170?ooo`030000003oool0oooo00l0oooo1000002:0?ooo`800000303oool00`000000
oooo0?ooo`090?ooo`800000R`3oool300000140oooo00<000000?ooo`3oool02`3oool004L0oooo
00<000000?ooo`3oool03`3oool3000008`0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`080?ooo`800000S03oool300000140oooo00<000000?ooo`3oool02`3oool004L0oooo00<0
00000?ooo`3oool03P3oool4000008`0oooo0P00000;0?ooo`030000003oool0oooo00P0oooo0P00
002=0?ooo`<00000403oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0>
0?ooo`<00000SP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo0P00002>
0?ooo`<00000403oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0>0?oo
o`<00000SP3oool2000000X0oooo00<000000?ooo`3oool01`3oool2000008h0oooo1000000?0?oo
o`030000003oool0oooo00/0oooo00170?ooo`8000003P3oool300000900oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08h0oooo0`00000>0?ooo`80
00003@3oool004L0oooo00<000000?ooo`3oool03@3oool300000900oooo0P0000090?ooo`030000
003oool0oooo00H0oooo0P00002@0?ooo`<000003`3oool00`000000oooo0?ooo`0;0?ooo`00A`3o
ool00`000000oooo0?ooo`0<0?ooo`@00000T@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0T03oool3000000h0oooo00<000000?ooo`3oool02`3o
ool004L0oooo00<000000?ooo`3oool0303oool300000980oooo0P0000080?ooo`030000003oool0
oooo00D0oooo0P00002B0?ooo`<000003P3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`00
0000oooo0?ooo`0<0?ooo`<00000T`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00D0oooo0P00002B0?ooo`<000003P3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000
oooo0?ooo`0<0?ooo`800000U03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0TP3oool2000000h0oooo00<000000?ooo`3oool02`3oool004L0oooo
00<000000?ooo`3oool02`3oool3000009@0oooo0P0000070?ooo`030000003oool0oooo00@0oooo
0P00002D0?ooo`<000003@3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?oo
o`0;0?ooo`<00000U@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0U03oool2000000d0oooo00<000000?ooo`3oool02`3oool004L0oooo00<00000
0?ooo`3oool02`3oool2000009H0oooo0P0000060?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0U03oool2000000d0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?oo
o`3oool02`3oool2000009H0oooo0P0000060?ooo`030000003oool0oooo00<0oooo0P00002F0?oo
o`8000003@3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0:0?ooo`<0
0000U`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0UP3oool2000000`0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0
2P3oool2000009P0oooo0P0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
UP3oool2000000`0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool02P3o
ool2000009P0oooo0P0000050?ooo`030000003oool0oooo0080oooo0P00002H0?ooo`800000303o
ool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0:0?ooo`800000V@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0U`3oool2
000000`0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool02@3oool20000
09X0oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0V03oool20000
00/0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool02@3oool2000009X0
oooo0P0000040?ooo`040000003oool0oooo0?ooo`800000VP3oool2000000/0oooo00<000000?oo
o`3oool02`3oool004L0oooo00<000000?ooo`3oool02@3oool2000009/0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`3oool2000009X0oooo0P00000;0?ooo`030000003oool0oooo
00/0oooo00170?ooo`8000002P3oool2000009/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`02000009/0oooo0P00000:0?ooo`8000003@3oool004L0oooo00<000000?ooo`3oool0
203oool2000009`0oooo0P0000030?ooo`030000003oool0oooo00800000W03oool2000000X0oooo
00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0203oool2000009`0oooo0P00
00030?ooo`030000003oool0oooo00800000W03oool2000000X0oooo00<000000?ooo`3oool02`3o
ool004L0oooo00<000000?ooo`3oool0203oool2000009d0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo09/0oooo0P00000:0?ooo`030000003oool0oooo00/0oooo0017
0?ooo`030000003oool0oooo00P0oooo0P00002M0?ooo`060000003oool0oooo0?ooo`000000oooo
0P00002M0?ooo`8000002P3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo09`0oooo0P0000020?ooo`040000003oool00000000009h0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`00203oool00`3ookl0M7Bo0?oo
o`0l0?ooo`030000003oool0oooo00L0oooo0P00002N0?ooo`8000000P3oool010000000oooo0000
0000002N0?ooo`8000002@3oool00`000000oooo0?ooo`0;0?ooo`00203oool0103ogi`0B0000000
B02Lgolk0?ooo`030000003oool0oooo00L0oooo0P00002N0?ooo`8000000P3oool010000000oooo
00000000002N0?ooo`8000002@3oool00`000000oooo0?ooo`0;0?ooo`002P3oool00`2oM0000000
00000003000000030000M02oool0oooo03@0oooo00<000000?ooo`3oool01`3oool2000009l0oooo
00H000000?ooo`3oool000000?ooo`00002O0?ooo`8000002@3oool00`000000oooo0?ooo`0;0?oo
o`003P3oool00`3ogi`0B00007Boo`0f0?ooo`030000003oool0oooo00L0oooo0P00002O0?ooo`80
000000@0oooo0000000000000000W`3oool2000000T0oooo00<000000?ooo`3oool02`3oool000d0
oooo00<0gia80000M02oool0=`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo09h0
oooo0P000000103oool0000000000000002O0?ooo`8000002@3oool00`000000oooo0?ooo`0;0?oo
o`00203oool01P3ogi`0B01809cOo`3o_g@0000004RLgcT0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`2N0?ooo`80000000@0oooo0000000000000000X03oool2000000P0oooo00<0
00000?ooo`3oool02`3oool000P0oooo00@0omnL04P00000000007Bo>`3oool00`000000oooo0?oo
o`060?ooo`800000X03oool2000000040?ooo`000000000000000:00oooo0P0000080?ooo`030000
003oool0oooo00/0oooo00170?ooo`030000003oool0oooo00H0oooo0P00002P0?ooo`80000000<0
oooo000000000000X@3oool2000000P0oooo00<000000?ooo`3oool02`3oool004L0oooo00<00000
0?ooo`3oool01P3oool200000:40oooo00@000000?ooo`0000000000X@3oool2000000P0oooo00<0
00000?ooo`3oool02`3oool000/0oooo00H0gia800000000000000000000B02Lgolf0?ooo`030000
003oool0oooo00H0oooo0P00002Q0?ooo`@00000X@3oool2000000P0oooo00<000000?ooo`3oool0
2`3oool000T0oooo00T0oono07@00018W=l0omnL09boo`3oool0gia80018W03Oool0=@3oool20000
00L0oooo0P00002Q0?ooo`@00000X@3oool2000000L0oooo0P00000=0?ooo`002@3oool02@2oM7@0
_ooo0?ooo`3o_i`0W=oo0?ooo`3ookl0M01d0;ooo`0e0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0X03oool400000:80oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0;0?ooo`00203oool02@3ogi`0W;oo0?ooo`3ooml0W7BL0=ooo`3oool0omnL04Qd_`0f0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0X03oool400000:80oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0;0?ooo`00203oool02@3o_i`0W=oo0?ooo`2oM000M;oo0?oo
o`3OW4P0001d0;ooo`0f0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0X@3oool3
00000:80oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`00203oool0103o
okl0M0000000001d_olk0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0X@3oool2
00000:<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0:40oooo0P00002S0?ooo`8000001`3oool00`00
0000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0:40
oooo0P00002S0?ooo`8000001`3oool00`000000oooo0?ooo`0;0?ooo`00303oool01P3o_g@00000
000000000000001d0;ooocD0oooo00<000000?ooo`3oool01@3oool200000:<0oooo0P00002S0?oo
o`8000001`3oool00`000000oooo0?ooo`0;0?ooo`00103oool01P2oW9`0gooo0?ooo`3oool0omnL
04P000<0000000@004RL0=ooo`3ookl0M7Bo=P3oool00`000000oooo0?ooo`050?ooo`800000X`3o
ool200000:<0oooo0P0000070?ooo`030000003oool0oooo00/0oooo00030?ooo`030?oog`2LB000
000000<0000000<007Bo0?ooo`3oool00P3oool00`3o_g@0001d0;ooo`0f0?ooo`030000003oool0
oooo00D0oooo0P00002S0?ooo`800000X`3oool2000000L0oooo00<000000?ooo`3oool02`3oool0
00<0oooo00<0oono07@00018W=l0@@3oool00`000000oooo0?ooo`050?ooo`800000X`3oool20000
0:<0oooo0P0000070?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo00D0
oooo0P00002S0?ooo`800000Y03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0
oooo000;0?ooo`060?oOW018000000000000000004P0W=oo:03oool0102oM00000000000001d_ol:
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0XP3oool200000:@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`002P3oool00`2oM000000007Boo`020?oo
o`030?oog`2LM9`0gooo02H0oooo00H0gia8001d_`3oool0omnL04P00018W=l90?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0XP3oool200000:@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0;0?ooo`002@3oool00`3OW4P0B9cO0?ooo`040?ooo`030=nLW02oool0
oooo02@0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0XP3oool200000:@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0;0?ooo`00203oool00`3ogi`0M9cO0?ooo`040?ooo`030?oog`2LM9`0gooo
02D0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool70?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0XP3oool200000:@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0;0?ooo`00203oool00`3o_i`0W=oo0?ooo`030?ooo`030?oog`2LB000M;oo
02H0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`070?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool02`3oool000P0oooo00<0omnL04Qd_`3oool00P3oool00`3OW4P0
000004RLg`0X0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01`3ooooo000005d0
00003@3oool000T0oooo00H0okmd00000000000000000018W03OoolY0?ooo`030=nLB00004P0W=oo
0080oooo00<0oooO09a80000M;l01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0:<0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00/0oooo000h0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0:80oooo0P00002T0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool02`3oool003P0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P0
04RL0=ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0XP3oool200000:@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`002`3oool01P3ogi`0B000
000000000000001809cOobP0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0XP3oool200000:@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`002@3oool0103ooml0W4P00018W03Oool20?oo
o`030?noM000B9`0gooo02P0oooo00H0gia80000M02oool0oooO09a80018W=l70?ooo`030000003o
ool0oooo00D0oooo0P00002S0?ooo`800000Y03oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00/0oooo00090?ooo`030;mdB02Lgol0oooo00<0oooo00<0oooO09a8M02oool0:@3oool0
103OW4P0000000000000M;l80?ooo`030000003oool0oooo00D0oooo0P00002S0?ooo`800000X`3o
ool2000000L0oooo00<000000?ooo`3oool02`3oool000P0oooo00<0omnL09boo`3oool0103oool0
0`3ogi`0B7Bo0?ooo`0e0?ooo`030000003oool0oooo00D0oooo0P00002S0?ooo`800000X`3oool2
000000L0oooo00<000000?ooo`3oool02`3oool000P0oooo00<0oknL09cOo`3oool00`3oool00`3o
gi`0B4RL0=ooo`0f0?ooo`030000003oool0oooo00D0oooo0P00002S0?ooo`800000X`3oool20000
00L0oooo00<000000?ooo`3oool02`3oool000P0oooo00@0oono07@000000000M;oo>`3oool00`00
0000oooo0?ooo`050?ooo`800000X`3oool200000:<0oooo0P0000070?ooo`030000003oool0oooo
00/0oooo00170?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0X@3oool200000:<0
oooo0P0000070?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0X@3oool200000:<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0;0?ooo`00203oool00`3ookl0W9cO0?ooo`030?ooo`040?noM0000000001d0;ooocD0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2Q0?ooo`800000X`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00/0oooo00080?ooo`040?oo_`2LW=l0oono07@000@00000
00<004RL0=ooo`3oool0=03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0:40oooo
0P00002S0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool000P0oooo00T0
omnL04P000000000001809cOo`3oool0oooO09a8M02oool0=P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0:00oooo0`00002S0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02`3oool000@0oooo00@0oooO09a8000007@0_ooo?`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0:00oooo1000002R0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02`3oool004L0oooo0P0000070?ooo`800000X@3oool400000:80oooo00<000000?ooo`3o
ool01@3oool2000000d0oooo00080?ooo`050?oO_`2ogol0oooo0?ooo`2oM0000`0000000`0007@0
_ooo0?ooo`0d0?ooo`030000003oool0oooo00H0oooo0P00002Q0?ooo`@00000X@3oool2000000P0
oooo00<000000?ooo`3oool02`3oool000P0oooo00<0_g@00000000000000P0000001@0007@0_ooo
0?ooo`2oW9`0gooo03D0oooo00<000000?ooo`3oool01P3oool200000:40oooo00@000000?ooo`00
00000000X@3oool2000000P0oooo00<000000?ooo`3oool02`3oool000H0oooo00D0_g@000000000
000004RL0=ooo`030?ooo`030?oog`2LB000M;oo0080oooo00<0_g@00018W03Oool0<@3oool00`00
0000oooo0?ooo`060?ooo`800000X@3oool010000000oooo00000000002Q0?ooo`800000203oool0
0`000000oooo0?ooo`0;0?ooo`00203oool00`3o_i`0W=oo0?ooo`080?ooo`030?oOW018M;l0oooo
0340oooo00<000000?ooo`3oool01P3oool200000:40oooo00<000000?ooo`0000000P00002P0?oo
o`800000203oool00`000000oooo0?ooo`0;0?ooo`00203oool00`3ookl0M7Bo0?ooo`070?ooo`03
0?noM000B9`0gooo0380oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2N0?ooo`80
000000@0oooo0000000000000000X03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00/0oooo00080?ooo`040?oOW0180000001d0;ooo`D0oooo00<0gia8001d_`3oool0<`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo09h0oooo0P000000103oool0000000000000002O
0?ooo`8000002@3oool00`000000oooo0?ooo`0;0?ooo`002@3oool00`3ogi`0B000000000050000
000304RLg`3oool0oooo03<0oooo00<000000?ooo`3oool01`3oool2000009l0oooo0P000000103o
ool000000?ooo`00002O0?ooo`8000002@3oool00`000000oooo0?ooo`0;0?ooo`003P3oool00`3o
_g@0001809cOo`0f0?ooo`030000003oool0oooo00L0oooo0P00002O0?ooo`80000000@0oooo0000
003oool00000W`3oool2000000T0oooo00<000000?ooo`3oool02`3oool000d0oooo00<0_g@0001d
_`3oool0=`3oool00`000000oooo0?ooo`070?ooo`800000WP3oool200000080oooo00@000000?oo
o`0000000000WP3oool2000000T0oooo00<000000?ooo`3oool02`3oool000P0oooo00H0omnL04P0
001d_ol0okmd0000001d_oli0?ooo`030000003oool0oooo00L0oooo0P00002N0?ooo`8000000P3o
ool010000000oooo00000000002N0?ooo`8000002@3oool00`000000oooo0?ooo`0;0?ooo`00203o
ool0103ogi`0B00000000000M;lk0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
W03oool200000080oooo00@000000?ooo`3oool00000WP3oool2000000T0oooo00<000000?ooo`3o
ool02`3oool004L0oooo00<000000?ooo`3oool0203oool2000009d0oooo0P0000020?ooo`040000
003oool0oooo000009d0oooo0P00000:0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000
003oool0oooo00P0oooo0P00002M0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`2K0?ooo`8000002P3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo
0?ooo`080?ooo`800000W03oool2000000<0oooo00<000000?ooo`3oool00P00002L0?ooo`800000
2P3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`080?ooo`800000W03o
ool2000000<0oooo00D000000?ooo`3oool0oooo0000002L0?ooo`8000002P3oool00`000000oooo
0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`080?ooo`<00000V`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000W03oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00/0oooo00170?ooo`8000002P3oool2000009/0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000009/0oooo0P00000:0?ooo`8000003@3oool004L0oooo00<0
00000?ooo`3oool02@3oool2000009X0oooo0P0000040?ooo`040000003oool0oooo0?ooo`800000
VP3oool2000000/0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool02@3o
ool2000009X0oooo0P0000040?ooo`040000003oool0oooo0?ooo`800000VP3oool2000000/0oooo
00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool02@3oool3000009T0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo09P0oooo0P00
000;0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo00X0oooo0P00002I
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2G
0?ooo`800000303oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0:0?oo
o`800000V03oool2000000D0oooo00<000000?ooo`3oool00P3oool2000009P0oooo0P00000<0?oo
o`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo00X0oooo0P00002H0?ooo`80
00001@3oool00`000000oooo0?ooo`020?ooo`800000V03oool2000000`0oooo00<000000?ooo`3o
ool02`3oool004L0oooo00<000000?ooo`3oool02P3oool3000009L0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo09D0oooo0`00000<0?ooo`030000
003oool0oooo00/0oooo00170?ooo`030000003oool0oooo00/0oooo0P00002F0?ooo`8000001P3o
ool00`000000oooo0?ooo`030?ooo`800000UP3oool3000000`0oooo00<000000?ooo`3oool02`3o
ool004L0oooo00<000000?ooo`3oool02`3oool2000009H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?ooo`800000UP3oool2000000d0oooo00<000000?ooo`3oool02`3oool0
04L0oooo00<000000?ooo`3oool02`3oool3000009D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`800000U@3oool2000000d0oooo00<000000?ooo`3oool02`3oool004L0
oooo00<000000?ooo`3oool02`3oool3000009@0oooo0P0000070?ooo`030000003oool0oooo00@0
oooo0P00002D0?ooo`<000003@3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo
0?ooo`0<0?ooo`800000U03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo
0`00002C0?ooo`8000003P3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?oo
o`0<0?ooo`<00000TP3oool2000000P0oooo00<000000?ooo`3oool01@3oool200000980oooo0`00
000>0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo00`0oooo0`00002B
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool200000980oooo0`00000>
0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo00d0oooo0`00002@0?oo
o`8000002@3oool00`000000oooo0?ooo`060?ooo`800000T@3oool2000000l0oooo00<000000?oo
o`3oool02`3oool004L0oooo0P00000>0?ooo`<00000T03oool2000000T0oooo00<000000?ooo`3o
ool01P3oool200000900oooo0`00000>0?ooo`8000003@3oool004L0oooo00<000000?ooo`3oool0
3@3oool4000008l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`800000
S`3oool3000000l0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool03P3o
ool3000008h0oooo0P00000:0?ooo`030000003oool0oooo00L0oooo0P00002>0?ooo`<00000403o
ool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0>0?ooo`<00000SP3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0S03oool3
00000100oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool03P3oool40000
08`0oooo0P00000;0?ooo`030000003oool0oooo00P0oooo0P00002<0?ooo`@00000403oool00`00
0000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0?0?ooo`<00000S03oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0RP3oool00`000000
oooo0000000A0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo00l0oooo
1000002:0?ooo`800000303oool00`000000oooo0?ooo`090?ooo`800000RP3oool400000140oooo
00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool03`3oool2000000030?ooo`00
0000oooo08P0oooo0P00000=0?ooo`030000003oool0oooo00X0oooo0P0000290?ooo`030000003o
ool000000180oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0403oool4
000008P0oooo0P00000=0?ooo`030000003oool0oooo00X0oooo0P0000280?ooo`@000004P3oool0
0`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0@0?ooo`80000000<0oooo0000
003oool0QP3oool2000000h0oooo00<000000?ooo`3oool02`3oool2000008L0oooo00@000000?oo
o`00000000004P3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0@0?oo
o`80000000<0oooo000000000000QP3oool2000000h0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`240?ooo`80000000<0oooo0000003oool04P3oool00`000000oooo0?ooo`0;0?oo
o`00A`3oool00`000000oooo0?ooo`0A0?ooo`80000000<0oooo0000003oool0Q03oool2000000l0
oooo00<000000?ooo`3oool0303oool2000008D0oooo00@000000?ooo`00000000004`3oool00`00
0000oooo0?ooo`0;0?ooo`00:`3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo
0080oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`070?ooo`030000003oool0oooo
0140oooo0P0000000`3oool00000000000240?ooo`8000003`3oool00`000000oooo0?ooo`0=0?oo
o`800000P`3oool2000000030?ooo`000000000001<0oooo00<000000?ooo`3oool02`3oool002X0
oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00<0oooo00<0okmd
001d_`3oool00P3oool00`2oM7@0_ooo0?ooo`070?ooo`030000003oool0oooo0180oooo0P000000
0`3oool000000?ooo`220?ooo`800000403oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0840oooo00@000000?ooo`0000000000503oool00`000000oooo0?ooo`0;0?ooo`00:@3oool0
0`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00P0oooo00<0okmd001d_`3oool02`3oool0
0`000000oooo0?ooo`0B0?ooo`80000000<0oooo000000000000P@3oool200000140oooo00<00000
0?ooo`3oool03P3oool200000840oooo0P0000000`3oool000000000000D0?ooo`030000003oool0
oooo00/0oooo000Y0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo203oool0
0`3o_g@007Bo0?ooo`0:0?ooo`030000003oool0oooo01<0oooo0P0000000`3oool0000000000020
0?ooo`8000004@3oool00`000000oooo0?ooo`0?0?ooo`800000P03oool010000000oooo00000000
000E0?ooo`030000003oool0oooo00/0oooo000Y0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia8
0000B02Lgol02@3oool00`3o_g@0B9cO0?ooo`090?ooo`030000003oool0oooo01<0oooo0P000000
0`3oool000000000001o0?ooo`8000004P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo07d0oooo0P0000000`3oool000000000000E0?ooo`030000003oool0oooo00/0oooo000Z0?oo
o`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l02P3oool00`3OW4P0B9cO0?ooo`080?oo
o`<00000503oool00`000000oooo0?ooo`02000007d0oooo0`00000B0?ooo`030000003oool0oooo
0100oooo0P00001m0?ooo`80000000<0oooo000000000000503oool3000000d0oooo000Z0?ooo`03
0=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l02`3oool00`2oM000M;oo0?ooo`070?ooo`03
0000003oool0oooo01@0oooo0P0000020?ooo`800000O03oool2000001<0oooo00<000000?ooo`3o
ool04@3oool2000007`0oooo0P0000000`3oool000000000000F0?ooo`030000003oool0oooo00/0
oooo000Z0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool02P3oool00`3ogi`0B01d
0;ooo`070?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P00001k0?ooo`800000
503oool00`000000oooo0?ooo`0A0?ooo`800000N`3oool2000000030?ooo`000000000001L0oooo
00<000000?ooo`3oool02`3oool002X0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL
0=ooo`0:0?ooo`030?oog`2LB000M;oo00L0oooo00<000000?ooo`3oool05@3oool200000080oooo
0P00001i0?ooo`8000005@3oool00`000000oooo0?ooo`0B0?ooo`800000N@3oool200000080oooo
0P00000G0?ooo`030000003oool0oooo00/0oooo000[0?ooo`030?oOW0180000M;oo0080oooo00<0
gia8001d_`3oool02P3oool00`3ookl0M00004RLg`070?ooo`030000003oool0oooo01H0oooo00@0
00000?ooo`3oool0oooo0P00001g0?ooo`<000005@3oool00`000000oooo0?ooo`0B0?ooo`<00000
N03oool00`000000oooo0?ooo`02000001P0oooo00<000000?ooo`3oool02`3oool002`0oooo00H0
gia80000M02oool0oooO09a80018W=l70?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cOo`07
0?ooo`030000003oool0oooo01H0oooo0P0000020?ooo`800000M`3oool2000001H0oooo00<00000
0?ooo`3oool04`3oool3000007H0oooo0P0000020?ooo`800000603oool00`000000oooo0?ooo`0;
0?ooo`00;@3oool0103OW4P0000000000000M;l90?ooo`050?oOW018000000000000001d_ol0203o
ool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo0?ooo`800000M@3oool2000001L0oooo
00<000000?ooo`3oool0503oool2000007D0oooo0P0000020?ooo`8000006@3oool00`000000oooo
0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0G0?ooo`8000000`3oool2000007<0oooo0P00
000H0?ooo`030000003oool0oooo01D0oooo0P00001c0?ooo`8000000`3oool2000001T0oooo00<0
00000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0603oool2000000<0oooo00<00000
0?ooo`3oool0L03oool3000001P0oooo00<000000?ooo`3oool05@3oool300000780oooo00@00000
0?ooo`3oool0oooo0P00000J0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0
oooo01P0oooo0P0000040?ooo`030000003oool0oooo06h0oooo0`00000I0?ooo`030000003oool0
oooo01H0oooo0`00001`0?ooo`030000003oool0oooo0080oooo0P00000J0?ooo`030000003oool0
oooo00/0oooo00170?ooo`030000003oool0oooo01T0oooo0P0000030?ooo`800000KP3oool30000
01X0oooo00<000000?ooo`3oool05`3oool3000006h0oooo0P0000030?ooo`8000006`3oool00`00
0000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0I0?ooo`800000103oool2000006d0
oooo0P00000K0?ooo`030000003oool0oooo01P0oooo0P00001]0?ooo`800000103oool2000001/0
oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool06P3oool2000000@0oooo
0P00001[0?ooo`800000703oool00`000000oooo0?ooo`0I0?ooo`800000J`3oool2000000@0oooo
0P00000L0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo01X0oooo0`00
00040?ooo`800000J@3oool2000001d0oooo00<000000?ooo`3oool06P3oool2000006X0oooo00<0
00000?ooo`3oool00P3oool3000001`0oooo00<000000?ooo`3oool02`3oool004L0oooo00<00000
0?ooo`3oool06`3oool2000000D0oooo0P00001W0?ooo`8000007P3oool00`000000oooo0?ooo`0K
0?ooo`800000J03oool00`000000oooo0?ooo`030?ooo`8000007@3oool00`000000oooo0?ooo`0;
0?ooo`00A`3oool00`000000oooo0?ooo`0L0?ooo`8000001@3oool2000006D0oooo0P00000O0?oo
o`030000003oool0oooo01`0oooo0P00001V0?ooo`030000003oool0oooo00<0oooo0`00000M0?oo
o`030000003oool0oooo00/0oooo00170?ooo`8000007@3oool2000000H0oooo0P00001S0?ooo`80
0000803oool00`000000oooo0?ooo`0M0?ooo`800000I03oool00`000000oooo0?ooo`040?ooo`80
00007@3oool2000000d0oooo00170?ooo`030000003oool0oooo01d0oooo0P0000060?ooo`800000
H@3oool200000240oooo00<000000?ooo`3oool07P3oool200000640oooo0P0000060?ooo`<00000
7P3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00D0oooo0P00001N0?ooo`<000008P3oool00`000000oooo0?ooo`0O0?ooo`800000G`3o
ool2000000L0oooo0P00000O0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0
oooo01h0oooo0P0000070?ooo`800000G03oool3000002<0oooo00<000000?ooo`3oool0803oool2
000005d0oooo0P0000070?ooo`<000007`3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`00
0000oooo0?ooo`0O0?ooo`8000001`3oool2000005X0oooo0P00000U0?ooo`030000003oool0oooo
0280oooo0P00001J0?ooo`8000001`3oool300000200oooo00<000000?ooo`3oool02`3oool004L0
oooo00<000000?ooo`3oool07`3oool2000000P0oooo0P00001H0?ooo`8000009P3oool00`000000
oooo0?ooo`0S0?ooo`800000F03oool2000000P0oooo0P00000Q0?ooo`030000003oool0oooo00/0
oooo00170?ooo`030000003oool0oooo0200oooo0P0000080?ooo`<00000E03oool3000002L0oooo
00<000000?ooo`3oool0903oool2000005H0oooo0P0000080?ooo`<000008@3oool00`000000oooo
0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0P0?ooo`<00000203oool300000580oooo0`00
000X0?ooo`030000003oool0oooo02D0oooo0`00001B0?ooo`<000002@3oool200000280oooo00<0
00000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool08@3oool2000000X0oooo0P00001@
0?ooo`800000:P3oool00`000000oooo0?ooo`0W0?ooo`800000D03oool2000000X0oooo0P00000S
0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo0280oooo0P00000:0?oo
o`<00000C03oool3000002/0oooo00<000000?ooo`3oool0:03oool3000004`0oooo0`00000:0?oo
o`800000903oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0R0?ooo`80
0000303oool3000004T0oooo0`00000/0?ooo`030000003oool0oooo02T0oooo0`0000190?ooo`<0
0000303oool2000002@0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0
8`3oool2000000d0oooo0P0000160?ooo`<00000;P3oool00`000000oooo0?ooo`0[0?ooo`<00000
AP3oool3000000`0oooo0P00000U0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003o
ool0oooo02@0oooo0P00000=0?ooo`<00000@P3oool4000002l0oooo00<000000?ooo`3oool0;@3o
ool300000480oooo0`00000=0?ooo`8000009P3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool0
0`000000oooo0?ooo`0U0?ooo`8000003P3oool3000003h0oooo1000000a0?ooo`030000003oool0
oooo02l0oooo0`00000n0?ooo`<000003`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00/0oooo00170?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool03@3oool40000
03/0oooo0`00000c0?ooo`030000003oool0oooo0300oooo0`00000k0?ooo`@000003`3oool20000
02L0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool09P3oool200000100
oooo0`00000g0?ooo`@00000=@3oool00`000000oooo0?ooo`0b0?ooo`<00000=`3oool400000100
oooo0P00000X0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo02L0oooo
0P00000A0?ooo`@00000<P3oool3000003P0oooo00<000000?ooo`3oool0=03oool400000380oooo
1000000B0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02`3oool004L0oooo0P00
000Y0?ooo`8000004`3oool3000002d0oooo1000000j0?ooo`030000003oool0oooo03H0oooo1@00
000/0?ooo`D000004`3oool00`000000oooo0?ooo`0W0?ooo`8000003@3oool004L0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0C0?ooo`D000009P3oool5000003`0oooo00<00000
0?ooo`3oool0>03oool5000002P0oooo1000000E0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0:@3oool2000001H0oooo1P00000O0?oo
o`H00000?`3oool00`000000oooo0?ooo`0l0?ooo`D00000803oool5000001L0oooo0P00000[0?oo
o`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo02X0oooo0P00000I0?ooo`L0
00005P3oool700000480oooo00<000000?ooo`3oool0?`3oool7000001H0oooo1`00000I0?ooo`80
0000;03oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0[0?ooo`800000
7@3oool;000000@0oooo2`0000170?ooo`030000003oool0oooo04<0oooo2`0000060?ooo`/00000
7@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003o
ool0oooo02/0oooo0`00000S0?ooo``00000CP3oool00`000000oooo0?ooo`1;0?ooo``00000903o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0
oooo02`0oooo0P00001m0?ooo`030000003oool0oooo07X0oooo0P00000^0?ooo`030000003oool0
oooo00/0oooo00170?ooo`030000003oool0oooo02d0oooo0P00001l0?ooo`030000003oool0oooo
07T0oooo0P00000_0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo02h0
oooo0P00001k0?ooo`030000003oool0oooo07P0oooo0P00000`0?ooo`030000003oool0oooo00/0
oooo00170?ooo`030000003oool0oooo02l0oooo0P00001j0?ooo`030000003oool0oooo07L0oooo
0P00000a0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo0300oooo0P00
001i0?ooo`030000003oool0oooo07H0oooo0P00000b0?ooo`030000003oool0oooo00/0oooo0017
0?ooo`030000003oool0oooo0340oooo0P00001h0?ooo`030000003oool0oooo07D0oooo0P00000c
0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo0340oooo0`00001g0?oo
o`030000003oool0oooo07@0oooo0P00000d0?ooo`030000003oool0oooo00/0oooo00170?ooo`03
0000003oool0oooo0380oooo0P00001g0?ooo`030000003oool0oooo07<0oooo0P00000e0?ooo`03
0000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo03<0oooo0P00001f0?ooo`030000
003oool0oooo07<0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00A`3o
ool00`000000oooo0?ooo`0d0?ooo`800000M@3oool00`000000oooo0?ooo`1b0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool02`3oool004L0oooo0P00000f0?ooo`<00000L`3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo03D0oooo0P00000=0?ooo`00A`3oool00`00
0000oooo0?ooo`0f0?ooo`<00000LP3oool00`000000oooo0?ooo`1`0?ooo`800000>03oool00`00
0000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0h0?ooo`800000L@3oool00`000000
oooo0?ooo`1_0?ooo`800000>@3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo
0?ooo`0i0?ooo`800000L03oool00`000000oooo0?ooo`1^0?ooo`800000>P3oool00`000000oooo
0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0j0?ooo`800000K`3oool00`000000oooo0?oo
o`1/0?ooo`<00000>`3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0k
0?ooo`800000KP3oool00`000000oooo0?ooo`1[0?ooo`<00000?03oool00`000000oooo0?ooo`0;
0?ooo`00A`3oool00`000000oooo0?ooo`0l0?ooo`800000K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000?@3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0m0?ooo`80
0000K03oool00`000000oooo0?ooo`1Y0?ooo`<00000?P3oool00`000000oooo0?ooo`0;0?ooo`00
A`3oool00`000000oooo0?ooo`0n0?ooo`800000J`3oool00`000000oooo0?ooo`1X0?ooo`800000
@03oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`0o0?ooo`800000JP3o
ool00`000000oooo0?ooo`1V0?ooo`<00000@@3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool0
0`000000oooo0?ooo`100?ooo`800000J@3oool00`000000oooo0?ooo`1U0?ooo`<00000@P3oool0
0`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`110?ooo`<00000I`3oool00`00
0000oooo0?ooo`1T0?ooo`<00000@`3oool00`000000oooo0?ooo`0;0?ooo`00:`3oool0102oM000
00000000001d_ol30?ooo`030?oOW0180000M;oo00D0oooo00<0oooO09a80018W=l02P3oool00`00
0000oooo0?ooo`120?ooo`<00000IP3oool00`000000oooo0?ooo`1S0?ooo`<00000A03oool00`00
0000oooo0?ooo`0;0?ooo`00:P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL
04P0001d_ol01P3oool00`3OW4P004RL0=ooo`090?ooo`030000003oool0oooo04@0oooo0P00001U
0?ooo`030000003oool0oooo0680oooo0`0000150?ooo`030000003oool0oooo00/0oooo000Y0?oo
o`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol02P3oool00`3ogi`0B01809cOo`090?oo
o`030000003oool0oooo04D0oooo0P00001T0?ooo`030000003oool0oooo0600oooo100000160?oo
o`030000003oool0oooo00/0oooo000Y0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000
B9`0gooo1@3oool00`3o_g@0000000000004000000030018W03Oool0oooo00H0oooo00<000000?oo
o`3oool0AP3oool300000680oooo00<000000?ooo`3oool0G`3oool3000004P0oooo00<000000?oo
o`3oool02`3oool002T0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`050?ooo`03
0?oog`2LB4P0W=oo0080oooo00<0_g@0001d_`3oool0203oool00`000000oooo0?ooo`170?ooo`<0
0000H@3oool00`000000oooo0?ooo`1N0?ooo`<00000B@3oool00`000000oooo0?ooo`0;0?ooo`00
:P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00H0oooo00L0oono07@0M02oool0
oooo0?noM000B9`0gooo00P0oooo0`0000180?ooo`<00000H03oool00`000000oooo0?ooo`1M0?oo
o`800000B@3oool3000000d0oooo000Z0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000
M;l01`3oool01P3ogi`0B4RL0=ooo`3ogi`0B01809cOo`P0oooo00<000000?ooo`3oool0BP3oool3
000005h0oooo00<000000?ooo`3oool0G03oool2000004`0oooo00<000000?ooo`3oool02`3oool0
02X0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`070?ooo`050?noM000M;l0oooO
09a80018W=l0203oool00`000000oooo0?ooo`1;0?ooo`<00000G@3oool00`000000oooo0?ooo`1J
0?ooo`<00000C@3oool00`000000oooo0?ooo`0;0?ooo`00:P3oool0103ooml0W4P00018W03Oool2
0?ooo`030=nLB000B9`0gooo00P0oooo00@0gia804RLg`2oM00007Bo203oool00`000000oooo0?oo
o`1<0?ooo`<00000G03oool00`000000oooo0?ooo`1I0?ooo`800000C`3oool00`000000oooo0?oo
o`0;0?ooo`00:`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00T0oooo00@0gia8
07AdM00007@0_ooo1`3oool00`000000oooo0?ooo`1>0?ooo`<00000FP3oool00`000000oooo0?oo
o`1H0?ooo`800000D03oool00`000000oooo0?ooo`0;0?ooo`00;03oool01P3OW4P0001d0;ooo`3o
oml0W4P004RLg`/0oooo00<0_g@00000B02Lgol01`3oool00`000000oooo0?ooo`1?0?ooo`<00000
F@3oool00`000000oooo0?ooo`1F0?ooo`<00000D@3oool00`000000oooo0?ooo`0;0?ooo`00;@3o
ool0103OW4P0000000000000M;l<0?ooo`030?oog`2LB000B9cO00L0oooo00<000000?ooo`3oool0
D03oool4000005L0oooo00<000000?ooo`3oool0E03oool3000005<0oooo00<000000?ooo`3oool0
2`3oool004L0oooo00<000000?ooo`3oool0DP3oool3000005H0oooo00<000000?ooo`3oool0D`3o
ool3000005@0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0E03oool3
000005@0oooo00<000000?ooo`3oool0D@3oool3000005H0oooo00<000000?ooo`3oool02`3oool0
04L0oooo00<000000?ooo`3oool0E@3oool400000580oooo00<000000?ooo`3oool0C`3oool40000
05L0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0E`3oool300000540
oooo00<000000?ooo`3oool0CP3oool3000005T0oooo00<000000?ooo`3oool02`3oool004L0oooo
00<000000?ooo`3oool0F03oool4000004l0oooo00<000000?ooo`3oool0C03oool4000005X0oooo
00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0FP3oool4000004d0oooo00<0
00000?ooo`3oool0BP3oool4000005`0oooo00<000000?ooo`3oool02`3oool004L0oooo00<00000
0?ooo`3oool0G03oool4000004/0oooo00<000000?ooo`3oool0B03oool4000005h0oooo00<00000
0?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0GP3oool3000004X0oooo00<000000?oo
o`3oool0A`3oool300000600oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3o
ool0H03oool3000004P0oooo00<000000?ooo`3oool0A@3oool300000680oooo00<000000?ooo`3o
ool02`3oool004L0oooo0P00001S0?ooo`<00000AP3oool00`000000oooo0?ooo`130?ooo`<00000
H`3oool2000000d0oooo00170?ooo`030000003oool0oooo06@0oooo0`0000140?ooo`030000003o
ool0oooo0440oooo0`00001V0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0
oooo06H0oooo100000110?ooo`030000003oool0oooo03l0oooo0`00001X0?ooo`030000003oool0
oooo00/0oooo00170?ooo`030000003oool0oooo06P0oooo1000000o0?ooo`030000003oool0oooo
03d0oooo0`00001Z0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo06X0
oooo1000000m0?ooo`030000003oool0oooo03X0oooo1000001/0?ooo`030000003oool0oooo00/0
oooo00170?ooo`030000003oool0oooo06`0oooo1000000k0?ooo`030000003oool0oooo03P0oooo
1000001^0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo06l0oooo0`00
000i0?ooo`030000003oool0oooo03D0oooo1@00001`0?ooo`030000003oool0oooo00/0oooo0017
0?ooo`030000003oool0oooo0740oooo1@00000e0?ooo`030000003oool0oooo0380oooo1@00001c
0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo07@0oooo1@00000b0?oo
o`030000003oool0oooo02l0oooo1@00001f0?ooo`030000003oool0oooo00/0oooo00170?ooo`03
0000003oool0oooo07L0oooo1@00000_0?ooo`030000003oool0oooo02`0oooo1@00001i0?ooo`03
0000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo07X0oooo1@00000/0?ooo`030000
003oool0oooo02T0oooo1@00001l0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003o
ool0oooo07d0oooo1P00000X0?ooo`030000003oool0oooo02D0oooo1P00001o0?ooo`030000003o
ool0oooo00/0oooo00170?ooo`030000003oool0oooo0800oooo1`00000T0?ooo`030000003oool0
oooo0240oooo1`0000220?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo
08@0oooo1`00000P0?ooo`030000003oool0oooo01d0oooo1`0000260?ooo`030000003oool0oooo
00/0oooo00170?ooo`030000003oool0oooo08T0oooo2000000J0?ooo`030000003oool0oooo01T0
oooo1`00002:0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo08h0oooo
2@00000D0?ooo`030000003oool0oooo01<0oooo2000002?0?ooo`030000003oool0oooo00/0oooo
00170?ooo`030000003oool0oooo0980oooo3P00000;0?ooo`030000003oool0oooo00L0oooo3`00
002D0?ooo`030000003oool0oooo00/0oooo00170?ooo`800000W@3ooolN000009d0oooo0P00000=
0?ooo`00A`3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0:X0oooo00<000000?oo
o`3oool02`3oool004L0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`2Z0?ooo`03
0000003oool0oooo00/0oooo00170?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0
ZP3oool00`000000oooo0?ooo`0;0?ooo`00A`3oool00`000000oooo0?ooo`2[0?ooo`030000003o
ool0oooo0:X0oooo00<000000?ooo`3oool02`3oool004L0oooo00<000000?ooo`3oool0Z`3oool0
0`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00/0oooo00170?ooo`030000003oool00000
05D0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`0000003@3oool004L0oooo00<000000?ooo`000000403oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0000000d0oooo00170?ooool00000G@00000=0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00b03oool02@3ookl0M00000000018W=l0oooo0?oo_`1d0000000004RLg`0D0?ooo`03
0?noM000000000000080000000<004RL0=ooo`3oool04P3oool01@2oM0000000000000000000B9cO
0:`0oooo00380?ooo`0:0?oo_`1d04P0W=oo0;md0000M;l0oono07@0B02Lgol0_g@0001d_a80oooo
00<0okmd00000018W=l00`3oool00`3ogi`0B01809cOo`0C0?ooo`030?oog`2LB000B9cO0:d0oooo
003;0?ooo`030?oo_`1d0000M;oo0080oooo00<0oono07@0001d_ol04@3oool00`3o_g@0001d0;oo
o`040?ooo`030=nLB000M;l0oooo01<0oooo00<0gia80018W03Oool0[03oool00<`0oooo00<0gia8
0018W03Oool00P3oool00`3OW4P004RL0=ooo`0A0?ooo`080;md000007@0_ooo0?ooo`3ooml0W4P0
00000018W=lD0?ooo`030?oOW01807@0_ooo0:`0oooo002e0?ooo`030;md00000000000000D00000
00<004RL0=ooo`3oool00`3oool0303ogi`0B00000000000B9`0gooo0;md0000000007Bo0?ooo`3o
_g@0001809cOo`80oooo00<0okmd0000B02Lgol00`3oool0202oM00000000000B02Lgol0oooo0=nL
B000B9`0gooo0P3oool00`2oM0000000001d_`020?ooo`060?oo_`1d000000000000000007@0_ooo
1@3oool00`3o_g@00000000000070000000907Boo`3oool0omnL04P000000000001d0;oo_`1d0000
M;oo0080oooo00/0omnL04P00000000004RL0=ooo`2oM0000000001d_`3oool0omnL04P000020000
000907Boo`3OW4P000000018W03Oool0okmd0000000004P0W=oo0080oooo00@0_g@00000000004P0
W=oo0P3oool01@3o_g@000000000000004P0W=oo00<0oooo00<0gia80018W03Oool00P3oool00`2o
M0000000001d_`1l0?ooo`00]P3oool0103ookl0M0000018W03Oool30?ooo`030;md0000000007Bo
00<0oooo00`0omnL04P0B02Lgol0omnL04Qd_`2oM00007Bo0?noW02Lgol0oono07@00018W=l20?oo
o`030?oo_`1d0000B9cO00<0oooo00P0gia80018W03Ooml0W7BL0=ooo`3o_g@0001d0;ooo`80oooo
00P0gia80018W03O_g@0M;oo0?ooo`3o_g@0001d0;ooo`T0oooo00@0oooO09a80000B9`0gooo0`3o
ool02`3ooml0W4P00018W03Oool0_g@00018W03Oool0oono07@0M01dM000B9cO0080oooo02@0omnL
04P0B02Lgol0omnL04Qd_`2oM00007Bo0?noW02Lgol0_g@00018W03Oool0oooo0;md001dM7@0001d
0;oOW02L_ol0okmd0000B02Lgml0W7BL0=ooo`3oool0gia80018W03Ooml0W7BL0=ooo`3ogi`0B018
09cOo`3oool0omnL04P00000M;l20?ooo`030?noM00007@0_ooo0080oooo00@0gia80018W03O_g@0
M;ooN`3oool00;L0oooo00<0gia80000B02Lgol0103oool03@3ookl0M0000018W03Oool0oooo0?oo
g`2LB000B9cO0?ooo`3o_g@0M7Ad0018W03Oool00P3oool00`2oM00004RL0=ooo`020?ooo`030;md
0000B9`0gooo0080oooo00<0okmd0000B02Lgol00P3oool00`3ookl0M00004RLg`020?ooo`030?oO
W01804P0W=oo00<0oooo00<0_g@007Boo`3oool02@3oool00`3o_g@0001809cOo`050?ooo`040=nL
M02Lgol0_g@0001d_`80oooo0100oono07@00000B9`0gooo0?ooo`3ooml0W4P004RLg`3oool0okmd
07AdM000B9`0gooo0?ooo`2oM00007Bo0`3oool01`2oM000000007Boo`3oool0oono07@0001d_ol0
0`3oool00`3o_g@0001809cOo`020?ooo`030=nLB000B9`0gooo0080oooo00L0omnL04P00018W=l0
oooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol0O03oool00;L0oooo00<0omnL04P0001d
_ol01@3oool00`3ogi`0B000001d_`020?ooo`070;md0000B9`0gooo0?ooo`2oM000001809cOo`02
0?ooo`030=nLB00007@0_ooo0080oooo00<0gia80000M02oool00P3oool00`3ookl0M00004RLg`02
0?ooo`080?oog`2LB000001d0;ooo`3oool0oooO09a80018W=l20?ooo`030?oo_`1d000000000080
000000<0M;oo0?ooo`3oool01@3oool00`3ookl0M00004RLg`070?ooo`030=nLB000B9`0gooo0080
oooo00<0okmd0000M02oool00P3oool02`2oM00004RL0=ooo`3oool0_g@00000B02Lgol0oooo0?no
M00007@0_ooo0080oooo00<0oono07@00018W=l00P3oool00`2oM00007Bo0?ooo`020?ooo`030?oo
_`1d0000B9cO0080oooo00<0okmd0000M02oool00`3oool02`3OW4P0001d0;ooo`3ooml0W4P00000
M02oool0oooo0?oog`2LB000B9cO07`0oooo002g0?ooo`030?oo_`1d000007Bo00H0oooo00/0_g@0
0000B02Lgol0oooo0?noM00007@0_ooo0?ooo`3ookl0M00007Boo`020?ooo`030?oOW0180000M;oo
0080oooo00<0omnL04P0001d_ol00`3oool00`2oM00004RL0=ooo`020?ooo`030=nLB000B4P0B7Bo
0080oooo00/0_g@0001d_`3oool0oooo0;md0000B9`0gooo0?ooo`3ogi`0B00004RLg`060?ooo`03
0?oog`2LB00007Bo0080oooo00<0oono09bLg`3oool00P3oool00`3ogi`0B00007Boo`020?ooo`03
0?oo_`1d0000M;oo0080oooo00/0okmd0000M02oool0oooo0?oo_`1d0000M;oo0?ooo`3ookl0M000
07Boo`030?ooo`070;md0000B9`0gooo0?ooo`3OW4P004RL0=ooo`030?ooo`070;md0000B9`0gooo
0?ooo`3ookl0M00007Boo`030?ooo`070?oOW01804P0W=oo0?ooo`3OW4P004Q804Qd_`020?ooo`03
0;md0000M;l0oooo07/0oooo002h0?ooo`030;md0000B9`0gooo00D0oooo00L0okmd00000018W=l0
omoO0=oo_`1d0000M;oo0080oooo00L0_g@0001d_`3oool0oooo0?oog`2LB000B9cO0080oooo00<0
oooO09a80018W=l00`3oool00`3OW4P0001809cOo`020?ooo`0;0?noM00007@0_kmd04RLg`3oool0
okmd0000M02oool0oooo0;md0000M;l00`3oool00`3OW4P0001d0;ooo`060?ooo`060=nLB00007@0
_ooo0?ooo`3ogi`0B7Bo103oool0302oM000001d0;ooo`3oool0oooO09a80018W=l0oooo0?oOg`3O
okl0M00007Boo`80oooo00L0_g@0001d_`3oool0oooo0?noM00007@0_ooo0080oooo00L0gia80000
M02oool0oooo0?oOW01804P0W=oo00<0oooo00<0gia80000B02Lgol00P3oool00`3OW4P0001d0;oo
o`020?ooo`0<0?oo_`1d0000M;oo0?ooo`3o_g@0001d0;noM018W=l0oooo0?noM00007@0_oooN`3o
ool00;P0oooo00<0okmd0000B02Lgol01@3oool01`3ogi`0B000001d_`3ogi`0B7Bo0;md0000M;l0
0P3oool00`3o_g@004RL0=ooo`020?ooo`030;md0000B9`0gooo0080oooo00<0_g@00018W03Oool0
0P3oool00`3ogi`0B00004RLg`020?ooo`0<0?oog`2LB000M;oo0=nLB000M;l0omnL04P0B02Lgol0
oooo0?oOW0180000B9cO0P3oool00`3OW4P0001d0;ooo`060?ooo`030?noM0000000000000800000
00<0001d0;ooo`3oool00P3oool0303ooml0W4P00018W03Oool0oono09a8B000B9`0gooo0?oOW018
M;l0_g@0001d_`80oooo00<0okmd0018W03Oool00P3oool02`3OW4P0001d0;ooo`3oool0_g@00000
B02Lgol0oooo0?oog`2LB000B9cO00<0oooo00<0omnL04P00018W=l00`3oool0402oM000001d0;oo
o`3oool0okmd0000M02oool0oooo0?oog`2LB000M;oo0=nLB000M;l0omnL04P0B02Lgomk0?ooo`00
^03oool00`3ogi`0B00007Boo`050?ooo`070?oOW018000007Bo0?ooo`3o_g@00000001d_`020?oo
o`050?oOW01804P0W=oo0?oo_`1d00000`0000000`1d_kl0M000000000020000000?07Boo`3o_g@0
000000000000B9`0gooo0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo0080oooo00<0
oono07@000000000100000000`18W=l0oooo0?ooo`030?ooo`030?oo_`1d0000M;oo0080oooo00<0
_gA809cOo`3oool0103oool02P3OW4P000000000M02o_g@0001d0;ooo`3oool0okmd00000000M;l2
0?ooo`030?oOW01804P0W=oo00<0oooo00P0omnL04P000000000B9bL07@00018W=l0oono07@000<0
000000H0M;oo0?noM000000000000018W03Oool30?ooo`0?0?noM000000000000000001d_ol0oooo
0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo07/0oooo002h0?ooo`030?oog`2LB000
07Bo00D0oooo00<0okmd00000018W=l02`3oool00`3o_g@0001809cOo`020?ooo`030?noM00004P0
W=oo01l0oooo00H0_g@0001d_`3oool0oooo0?oOW01dW=lO0?ooo`030?noM00007@0_ooo09<0oooo
002i0?ooo`030;md0000B9`0gooo00<0oooo00@0oooO09a8000007@0_ooo2`3oool00`3ooml0W4P0
001d_`020?ooo`030?oog`2LB00007Bo01l0oooo00<0gia80000M02oool0103oool00`3OW9`0_ooo
0?ooo`0L0?ooo`030=nLM02Lgol0oooo0980oooo002i0?ooo`030=nLB00004P0W=oo0080oooo00@0
oono07@000000000M;oo3@3oool00`3o_g@0001d0;ooo`020?ooo`030?noM00007@0_ooo0080oooo
00@0oono07@00000B9`0gooo603oool00`3o_g@0001809cOo`030?ooo`030?oo_`1d04P0W=oo0280
oooo00@0oono07@00000B9`0goooS03oool00;P0oooo00<0_g@0000000000000100000000`00B9`0
gooo0?ooo`0>0?ooo`0:0=nLB000B9`0gooO09a80018W=l0gia80018W03Ooml0W4P004RLgaX0oooo
00<0_g@00000000000001P0000000`1d_ol0oooo0?ooo`2`0?ooo`00d@3oool02@3OW4P000000000
B02Lgol0oooo0=nLB0000000001809cOo`3F0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-0.285438, -0.687768, \
0.00174723, 0.00453943}}]
}, Closed]],

Cell[TextData[{
  "If the natural and driving frequencies noncommensurate, the motion appears \
to be space filling \[LongDash] as ",
  StyleBox["tmax", "InlineInput"],
  " increases, the phase trajectory tends to completely fill a circle in \
phase space whose radius depends upon the total energy specified by the \
initial conditions.  (Verify by make plots for several values of ",
  StyleBox["tmax", "InlineInput"],
  "!)"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(duffingPlot[1, 0, 0, 1, \[Pi], 0, 0, 0, 200, MaxSteps \[Rule] 5000, 
        PlotPoints \[Rule] 100];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.500172 2.11412 0.500519 1.02092 [
[.07735 -0.0125 -13.8438 -15.6875 ]
[.07735 -0.0125 13.8438 0 ]
[.28876 -0.0125 -13.8438 -15.6875 ]
[.28876 -0.0125 13.8438 0 ]
[.50017 -0.0125 -5 -15.6875 ]
[.50017 -0.0125 5 0 ]
[.71158 -0.0125 -9.5 -15.6875 ]
[.71158 -0.0125 9.5 0 ]
[.923 -0.0125 -9.5 -15.6875 ]
[.923 -0.0125 9.5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.9688 -31.375 ]
[.5 -0.0125 21.9688 -15.6875 ]
[-0.0125 .09215 -27.6875 -7.84375 ]
[-0.0125 .09215 0 7.84375 ]
[-0.0125 .29634 -27.6875 -7.84375 ]
[-0.0125 .29634 0 7.84375 ]
[-0.0125 .50052 -10 -7.84375 ]
[-0.0125 .50052 0 7.84375 ]
[-0.0125 .7047 -19 -7.84375 ]
[-0.0125 .7047 0 7.84375 ]
[-0.0125 .90889 -19 -7.84375 ]
[-0.0125 .90889 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -43.375 -20.4688 ]
[-0.01875 .5 -27.6875 20.4688 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -43.9375 0 ]
[.5 1.0125 43.9375 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07735 0 m
.07735 .00625 L
s
gsave
.07735 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.28876 0 m
.28876 .00625 L
s
gsave
.28876 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.50017 0 m
.50017 .00625 L
s
gsave
.50017 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.71158 0 m
.71158 .00625 L
s
gsave
.71158 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.923 0 m
.923 .00625 L
s
gsave
.923 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.125 Mabswid
.11963 0 m
.11963 .00375 L
s
.16191 0 m
.16191 .00375 L
s
.20419 0 m
.20419 .00375 L
s
.24648 0 m
.24648 .00375 L
s
.33104 0 m
.33104 .00375 L
s
.37332 0 m
.37332 .00375 L
s
.41561 0 m
.41561 .00375 L
s
.45789 0 m
.45789 .00375 L
s
.54245 0 m
.54245 .00375 L
s
.58474 0 m
.58474 .00375 L
s
.62702 0 m
.62702 .00375 L
s
.6693 0 m
.6693 .00375 L
s
.75387 0 m
.75387 .00375 L
s
.79615 0 m
.79615 .00375 L
s
.83843 0 m
.83843 .00375 L
s
.88071 0 m
.88071 .00375 L
s
.03506 0 m
.03506 .00375 L
s
.96528 0 m
.96528 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.9688 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
102.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .09215 m
.00625 .09215 L
s
gsave
-0.0125 .09215 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .29634 m
.00625 .29634 L
s
gsave
-0.0125 .29634 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .50052 m
.00625 .50052 L
s
gsave
-0.0125 .50052 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .7047 m
.00625 .7047 L
s
gsave
-0.0125 .7047 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .90889 m
.00625 .90889 L
s
gsave
-0.0125 .90889 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .1432 m
.00375 .1432 L
s
0 .19424 m
.00375 .19424 L
s
0 .24529 m
.00375 .24529 L
s
0 .34738 m
.00375 .34738 L
s
0 .39843 m
.00375 .39843 L
s
0 .44947 m
.00375 .44947 L
s
0 .55156 m
.00375 .55156 L
s
0 .60261 m
.00375 .60261 L
s
0 .65366 m
.00375 .65366 L
s
0 .75575 m
.00375 .75575 L
s
0 .80679 m
.00375 .80679 L
s
0 .85784 m
.00375 .85784 L
s
0 .04111 m
.00375 .04111 L
s
0 .95993 m
.00375 .95993 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -117 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
81.4688 11.8438 translate
90 rotate
-81.4688 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(velocity) show
99.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.07735 .99375 m
.07735 1 L
s
.28876 .99375 m
.28876 1 L
s
.50017 .99375 m
.50017 1 L
s
.71158 .99375 m
.71158 1 L
s
.923 .99375 m
.923 1 L
s
.125 Mabswid
.11963 .99625 m
.11963 1 L
s
.16191 .99625 m
.16191 1 L
s
.20419 .99625 m
.20419 1 L
s
.24648 .99625 m
.24648 1 L
s
.33104 .99625 m
.33104 1 L
s
.37332 .99625 m
.37332 1 L
s
.41561 .99625 m
.41561 1 L
s
.45789 .99625 m
.45789 1 L
s
.54245 .99625 m
.54245 1 L
s
.58474 .99625 m
.58474 1 L
s
.62702 .99625 m
.62702 1 L
s
.6693 .99625 m
.6693 1 L
s
.75387 .99625 m
.75387 1 L
s
.79615 .99625 m
.79615 1 L
s
.83843 .99625 m
.83843 1 L
s
.88071 .99625 m
.88071 1 L
s
.03506 .99625 m
.03506 1 L
s
.96528 .99625 m
.96528 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .09215 m
1 .09215 L
s
.99375 .29634 m
1 .29634 L
s
.99375 .50052 m
1 .50052 L
s
.99375 .7047 m
1 .7047 L
s
.99375 .90889 m
1 .90889 L
s
.125 Mabswid
.99625 .1432 m
1 .1432 L
s
.99625 .19424 m
1 .19424 L
s
.99625 .24529 m
1 .24529 L
s
.99625 .34738 m
1 .34738 L
s
.99625 .39843 m
1 .39843 L
s
.99625 .44947 m
1 .44947 L
s
.99625 .55156 m
1 .55156 L
s
.99625 .60261 m
1 .60261 L
s
.99625 .65366 m
1 .65366 L
s
.99625 .75575 m
1 .75575 L
s
.99625 .80679 m
1 .80679 L
s
.99625 .85784 m
1 .85784 L
s
.99625 .04111 m
1 .04111 L
s
.99625 .95993 m
1 .95993 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .50052 m
1 .50052 L
s
.50017 0 m
.50017 1 L
s
gsave
.5 1.0125 -104.938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Duffing) show
102.938 15.813 moveto
(Equation) show
146.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.50017 .50052 m
.50395 .56123 L
.51382 .61447 L
.53241 .67126 L
.55639 .71823 L
.58328 .75422 L
.61136 .77999 L
.64478 .79909 L
.68194 .80804 L
.7196 .80484 L
.75879 .78771 L
.7929 .75891 L
.82036 .72255 L
.8465 .66926 L
.85793 .63463 L
.86612 .60004 L
.87456 .53183 L
.8736 .45455 L
.86908 .41487 L
.86134 .37295 L
.83995 .29937 L
.82398 .26009 L
.80655 .22501 L
.7833 .18647 L
.75857 .15283 L
.70827 .10066 L
.65696 .06387 L
.5975 .03719 L
.56265 .02843 L
.52997 .02452 L
.47377 .02729 L
.42192 .04069 L
.36744 .06694 L
.31311 .10779 L
.26527 .15965 L
.2229 .22426 L
.19412 .28557 L
.17114 .35678 L
.16198 .39945 L
.15636 .43888 L
.15332 .48177 L
.15361 .52613 L
.16188 .59656 L
.17066 .63339 L
.18134 .66523 L
.20686 .71653 L
.23553 .75302 L
.25307 .76847 L
.27323 .78132 L
.31172 .79359 L
Mistroke
.33545 .79396 L
.35761 .7895 L
.37708 .78159 L
.39736 .76904 L
.41831 .75078 L
.43861 .72673 L
.45419 .70265 L
.46913 .67291 L
.48089 .64223 L
.48953 .61234 L
.49691 .57602 L
.5012 .54034 L
.50218 .47536 L
.49893 .43869 L
.49351 .40538 L
.47831 .34875 L
.45453 .29369 L
.42587 .24952 L
.39526 .21728 L
.3576 .19211 L
.31374 .17869 L
.29115 .17779 L
.26715 .18127 L
.22525 .19903 L
.20341 .21505 L
.18448 .23355 L
.1653 .25778 L
.14717 .28758 L
.12253 .34629 L
.11223 .38374 L
.10526 .42092 L
.09955 .4945 L
.10303 .56448 L
.11761 .64566 L
.14173 .72005 L
.17183 .78292 L
.21232 .84355 L
.2572 .89199 L
.30308 .92755 L
.35789 .95582 L
.42098 .97232 L
.45339 .9747 L
.48806 .97281 L
.54955 .95792 L
.58225 .94363 L
.61138 .92679 L
.64133 .90495 L
.67232 .87677 L
.7189 .82068 L
.74127 .78566 L
Mistroke
.75939 .75162 L
.7872 .68311 L
.80706 .60608 L
.81594 .53437 L
.81601 .46839 L
.80822 .40616 L
.79489 .35525 L
.77297 .30479 L
.74702 .26692 L
.71936 .24117 L
.69184 .22607 L
.66038 .21929 L
.62698 .22335 L
.59437 .23889 L
.56229 .26753 L
.53605 .3048 L
.51654 .34619 L
.49998 .40193 L
.49396 .436 L
.49067 .46866 L
.49052 .53016 L
.4988 .59538 L
.51362 .65198 L
.53731 .70869 L
.56944 .7595 L
.60495 .79692 L
.64208 .82195 L
.67787 .83527 L
.72028 .83882 L
.75999 .83026 L
.80132 .80784 L
.84094 .76995 L
.87 .72706 L
.89554 .67018 L
.9142 .59982 L
.92026 .55717 L
.92285 .51681 L
.91957 .43629 L
.90619 .35971 L
.8848 .29055 L
.85839 .23182 L
.82023 .17066 L
.77774 .12146 L
.73343 .08429 L
.68953 .05829 L
.63879 .03942 L
.58365 .03098 L
.52744 .03464 L
.46862 .05195 L
.41589 .08037 L
Mistroke
.37144 .11559 L
.32481 .16693 L
.30309 .19769 L
.28243 .23264 L
.25138 .30159 L
.23108 .36878 L
.21884 .43932 L
.21562 .51455 L
.22187 .58105 L
.2351 .63658 L
.25438 .6838 L
.27635 .71872 L
.30581 .74847 L
.33633 .76533 L
.3712 .77084 L
.40782 .76193 L
.4374 .74276 L
.46657 .71034 L
.49251 .66374 L
.504 .63311 L
.51233 .60284 L
.52208 .53918 L
.52297 .47524 L
.51714 .42029 L
.5037 .361 L
.48217 .30298 L
.45553 .25421 L
.42586 .2154 L
.39518 .18652 L
.35856 .16319 L
.31775 .14899 L
.27521 .14611 L
.2302 .15623 L
.18968 .17817 L
.15573 .20811 L
.12072 .25453 L
.10385 .28552 L
.09039 .31682 L
.07149 .38011 L
.06044 .45333 L
.05916 .52809 L
.06874 .61064 L
.08822 .68661 L
.11496 .75284 L
.14906 .81234 L
.18577 .85942 L
.23397 .9041 L
.28385 .93543 L
.34201 .95676 L
.40535 .96375 L
Mistroke
.45941 .95699 L
.51694 .93646 L
.57502 .89995 L
.60505 .87357 L
.63051 .84623 L
.67399 .78534 L
.7069 .72036 L
.72804 .66132 L
.74362 .59441 L
.75116 .52491 L
.75029 .46236 L
.74296 .40818 L
.73118 .36339 L
.71333 .32082 L
.68988 .28476 L
.66219 .2583 L
.6299 .24245 L
.59831 .23965 L
.56993 .24734 L
.53832 .26847 L
.52197 .28581 L
.50814 .30499 L
.48647 .34751 L
.46986 .40112 L
.46084 .45995 L
.45992 .5284 L
.46794 .59435 L
.48305 .65405 L
.50267 .70461 L
.5305 .75526 L
.56564 .80031 L
.60333 .8337 L
.64863 .85886 L
.69897 .87098 L
.74251 .86902 L
.78911 .8537 L
.83615 .82211 L
.86027 .79796 L
.88043 .77226 L
.9139 .71309 L
.9374 .64778 L
.95041 .58644 L
.9566 .51505 L
.95357 .43857 L
.94187 .36749 L
.92338 .30358 L
.90038 .24865 L
.86716 .19111 L
.82968 .14368 L
.784 .10207 L
Mistroke
.73054 .06973 L
.67702 .05152 L
.62721 .04577 L
.56845 .05222 L
.536 .06204 L
.50693 .07486 L
.45615 .1074 L
.40764 .15317 L
.36638 .20782 L
.34759 .23975 L
.33008 .27554 L
.30488 .34468 L
.28986 .41063 L
.28303 .47332 L
.28319 .53003 L
.29028 .58796 L
.3053 .64324 L
.32696 .68916 L
.34166 .71027 L
.35662 .72643 L
.38961 .74819 L
.40906 .75374 L
.42696 .75459 L
.4587 .74612 L
.49094 .72291 L
.51763 .6886 L
.53771 .64757 L
.55163 .60243 L
.56064 .54822 L
.56295 .49327 L
.55953 .44137 L
.5487 .38045 L
.52864 .31628 L
.5022 .26021 L
.47179 .21411 L
.43157 .17082 L
.38921 .14026 L
.34851 .12229 L
.30296 .11371 L
.25278 .11772 L
.20145 .13721 L
.16049 .16585 L
.12019 .20904 L
.08384 .26779 L
.05811 .33143 L
.04804 .3675 L
.03978 .40901 L
.03447 .45381 L
.03265 .49669 L
.03737 .57593 L
Mistroke
.0508 .64706 L
.07669 .72455 L
.11088 .79091 L
.14817 .84184 L
.19395 .88613 L
.24161 .91717 L
.2875 .93555 L
.34338 .94474 L
.40414 .93934 L
.45989 .91996 L
.50828 .89063 L
.55544 .84835 L
.59929 .79234 L
.63312 .73161 L
.65684 .67161 L
.67542 .59849 L
.68144 .55698 L
.68415 .51909 L
.68215 .45252 L
.67787 .42103 L
.67078 .38845 L
.66172 .35951 L
.65006 .33213 L
.62458 .2922 L
.6083 .27548 L
.59215 .26371 L
.57364 .25519 L
.55335 .25126 L
.53567 .25222 L
.51675 .25782 L
.49943 .26739 L
.48419 .27978 L
.45809 .31212 L
.43569 .35776 L
.42076 .40994 L
.41258 .47437 L
.41341 .53977 L
.42196 .60197 L
.43788 .66276 L
.45849 .71531 L
.48915 .7709 L
.52401 .81638 L
.56783 .85662 L
.61893 .88634 L
.66509 .90017 L
.71677 .90236 L
.77173 .8892 L
.8014 .87486 L
.8273 .85758 L
.87352 .81316 L
Mistroke
.91084 .75921 L
.93659 .70557 L
.9577 .63988 L
.97083 .56613 L
.97441 .49436 L
.96996 .42719 L
.95937 .36694 L
.94079 .30385 L
.91389 .24268 L
.87946 .18767 L
.83601 .13893 L
.78992 .10383 L
.74494 .082 L
.68969 .0692 L
.6581 .06825 L
.62906 .07137 L
.57675 .08687 L
.52435 .11631 L
.47767 .15673 L
.4335 .2119 L
.39942 .27238 L
.37529 .3334 L
.35888 .39649 L
.35064 .4539 L
.34885 .51837 L
.35439 .57514 L
.36786 .63092 L
.3893 .67987 L
.41235 .71204 L
.44124 .73581 L
.47487 .74701 L
.49405 .74653 L
.51132 .74187 L
.54331 .72157 L
.57012 .68947 L
.58918 .6531 L
.605 .60484 L
.61472 .54711 L
.61681 .48821 L
.61224 .43088 L
.6024 .37791 L
.58436 .31798 L
.5608 .26397 L
.52901 .21112 L
.48859 .16272 L
.44529 .12637 L
.40271 .10242 L
.34986 .08628 L
.31944 .08327 L
.29138 .08447 L
Mistroke
.24051 .09663 L
.18929 .12324 L
.14319 .16239 L
.11961 .18974 L
.09967 .21812 L
.0684 .27692 L
.04365 .34718 L
.02964 .41461 L
.02381 .48023 L
.02574 .55277 L
.0375 .62916 L
.05896 .70117 L
.07515 .73899 L
.09263 .77177 L
.13435 .8296 L
.16093 .85638 L
.18675 .87687 L
.23618 .90388 L
.29264 .91827 L
.3468 .91733 L
.39588 .90415 L
.43965 .88175 L
.48331 .84769 L
.52029 .80715 L
.54974 .76412 L
.57823 .7081 L
.60125 .64228 L
.61488 .578 L
.62038 .51869 L
.61852 .45448 L
.60942 .399 L
.59578 .35493 L
.57603 .31497 L
.54963 .2819 L
.51802 .26047 L
.48941 .25384 L
.45795 .25923 L
.42588 .27955 L
.39958 .31095 L
.38763 .33176 L
.37619 .35791 L
.3664 .38843 L
.35945 .41968 L
.35286 .48224 L
.35433 .54366 L
.36464 .61306 L
.38537 .68514 L
.41053 .74287 L
.44456 .79899 L
.48272 .84485 L
Mistroke
.52167 .87913 L
.57167 .90915 L
.62917 .92765 L
.68487 .93085 L
.73575 .92124 L
.78801 .89787 L
.8398 .85851 L
.88293 .80903 L
.91615 .75486 L
.94634 .68262 L
.95884 .6386 L
.96729 .5964 L
.97475 .51702 L
.97451 .47668 L
.97111 .43255 L
.96476 .3908 L
.9549 .34825 L
.92955 .27738 L
.91146 .24162 L
.8923 .2112 L
.86739 .17959 L
.84165 .15397 L
.79088 .11909 L
.74136 .10092 L
.68647 .09631 L
.65555 .10055 L
.62746 .10874 L
.57743 .13435 L
.53376 .17023 L
.49888 .21078 L
.46648 .26245 L
.43898 .32497 L
.42732 .3619 L
.41914 .39607 L
.40985 .46312 L
.40907 .5247 L
.41509 .57927 L
.42802 .63122 L
.44379 .66955 L
.46529 .70393 L
.49228 .73076 L
.52406 .74664 L
.55517 .74879 L
.58311 .73975 L
.61392 .71596 L
.62802 .69881 L
.64209 .67617 L
.66228 .62757 L
.6748 .57346 L
.6788 .53956 L
Mistroke
.68033 .50212 L
.6759 .43222 L
.66931 .39247 L
.66052 .35561 L
.64795 .31576 L
.63122 .27453 L
.59579 .21002 L
.57209 .17723 L
.5481 .14982 L
.49936 .10762 L
.44265 .07614 L
.38898 .06071 L
.33774 .05785 L
.28195 .06782 L
.22445 .09356 L
.19556 .11334 L
.16984 .13557 L
.12633 .18576 L
.0874 .25075 L
.06963 .2914 L
.05615 .33078 L
.03999 .4001 L
.03197 .47849 L
.03455 .56007 L
.04683 .63309 L
.05789 .67241 L
.07303 .7126 L
.09014 .74768 L
.10816 .77727 L
.14739 .82484 L
.19486 .86179 L
.22108 .87498 L
.25018 .88452 L
.30391 .8893 L
.33658 .88438 L
.36705 .87434 L
.39355 .86105 L
.42122 .84215 L
.4441 .82209 L
.46718 .79698 L
.50378 .74366 L
.53195 .68413 L
.55066 .62493 L
.56266 .55856 L
.56558 .5209 L
.56579 .48633 L
.56344 .45094 L
.55907 .42002 L
.55152 .38642 L
.54205 .35706 L
Mistroke
.52168 .31434 L
.49492 .27939 L
.46902 .25921 L
.43846 .24807 L
.40509 .24962 L
.3867 .25665 L
.37043 .26692 L
.34276 .29506 L
.31823 .33666 L
.30017 .38799 L
.29311 .42077 L
.2888 .45303 L
.28678 .51616 L
.29343 .58637 L
.30728 .64983 L
.32695 .70789 L
.3557 .7681 L
.39434 .82645 L
.44295 .87856 L
.47337 .90271 L
.50313 .92125 L
.56055 .94479 L
.59371 .95174 L
.62406 .95407 L
.68144 .94797 L
.74155 .92608 L
.79461 .89148 L
.83875 .84873 L
.87517 .80004 L
.90764 .74029 L
.93137 .67829 L
.94668 .61853 L
.95662 .54628 L
.95746 .46768 L
.94886 .3959 L
.9332 .33375 L
.90998 .2759 L
.88236 .22872 L
.84657 .18625 L
.80302 .15276 L
.75631 .1331 L
.70544 .12758 L
.66217 .13513 L
.61666 .15581 L
.59381 .17173 L
.57093 .19202 L
.53403 .23636 L
.50135 .29361 L
.48649 .3295 L
.47521 .36465 L
Mistroke
.46152 .43054 L
.45673 .49125 L
.45721 .52417 L
.46021 .55899 L
.47197 .61809 L
.48859 .66417 L
.51272 .70618 L
.54298 .73819 L
.5746 .75586 L
.60533 .76078 L
.6335 .75529 L
.66309 .73833 L
.69135 .70859 L
.7171 .66326 L
.73442 .61198 L
.74108 .58015 L
.74572 .54333 L
.74675 .47194 L
.73861 .40211 L
.72016 .32795 L
.69653 .26685 L
.66256 .20432 L
.63844 .1701 L
.61318 .14046 L
.5604 .09372 L
.52842 .07331 L
.49748 .05836 L
.46247 .04659 L
.42436 .03961 L
.39088 .0383 L
.35475 .04195 L
.32108 .05019 L
.29079 .06182 L
.23606 .09414 L
.18371 .14179 L
.14107 .19776 L
.12036 .2334 L
.10357 .26851 L
.07915 .33714 L
.06275 .41387 L
.05669 .48341 L
.05835 .54774 L
.06814 .61527 L
.08744 .6822 L
.11498 .74088 L
.13377 .7696 L
.15304 .79303 L
.19629 .82982 L
.22241 .84384 L
.24692 .85233 L
Mistroke
.29187 .85725 L
.34029 .84774 L
.38392 .82519 L
.42089 .79371 L
.45152 .75617 L
.47932 .70849 L
.5 .65805 L
.51373 .60876 L
.5232 .54903 L
.52528 .48385 L
.5195 .42467 L
.50779 .37392 L
.48793 .32351 L
.46378 .28466 L
.43851 .25813 L
.40849 .23936 L
.37388 .23142 L
.33725 .23781 L
.3074 .25519 L
.27778 .28631 L
.25126 .3327 L
.23314 .38583 L
.22652 .41685 L
.2217 .45319 L
.21958 .49308 L
.22044 .53181 L
.22935 .60466 L
.24596 .67138 L
.27333 .74194 L
.3118 .81007 L
.3513 .8606 L
.39945 .90544 L
.44947 .93772 L
.49764 .95764 L
.55644 .96888 L
.62066 .96565 L
.67993 .94791 L
.73171 .91947 L
.78255 .8772 L
.83027 .81986 L
.86748 .75635 L
.89389 .6924 L
.91492 .61286 L
.92189 .56685 L
.92514 .52423 L
.92317 .44765 L
.91839 .41048 L
.91027 .37118 L
.89974 .33535 L
.88597 .30032 L
Mistroke
.85524 .24589 L
.83518 .22075 L
.81493 .201 L
.79128 .18363 L
.76473 .17022 L
.74102 .16303 L
.71489 .15993 L
.69016 .16148 L
.66758 .16672 L
.6263 .18632 L
.58613 .21992 L
.55303 .26236 L
.52375 .31832 L
.50371 .378 L
.49237 .43698 L
.4883 .4966 L
.4908 .54983 L
.50074 .60819 L
.51654 .6581 L
.54018 .70503 L
.57105 .74362 L
.60096 .76621 L
.63609 .77896 L
.67477 .77788 L
.69606 .77046 L
.7148 .7595 L
.74836 .72716 L
.77519 .68407 L
.7931 .63902 L
.8066 .58189 L
.81283 .51585 L
.81076 .45006 L
.80163 .38731 L
.78712 .3301 L
.76455 .26925 L
.73364 .20931 L
.69522 .15445 L
.64745 .10482 L
.59714 .06812 L
.54813 .04439 L
.48784 .0291 L
.45326 .02675 L
.42139 .02864 L
.36366 .0422 L
.3053 .07033 L
.25274 .11047 L
.20219 .1668 L
.16235 .22999 L
.13329 .2951 L
.11257 .36379 L
Mistroke
.1011 .42766 L
.09655 .50116 L
.10063 .56789 L
.11394 .6361 L
.13707 .69959 L
.16321 .7451 L
.19733 .78414 L
.23883 .81217 L
.26345 .82112 L
.2863 .82495 L
.33083 .82065 L
.37147 .80272 L
.40374 .77743 L
.43546 .74004 L
.46311 .69191 L
.483 .64017 L
.49572 .58783 L
.50211 .53792 L
.50309 .47972 L
.49769 .42556 L
.4853 .3707 L
.46515 .31819 L
.4404 .27624 L
.41398 .24599 L
.37921 .22118 L
.35845 .21282 L
.33894 .20886 L
.30286 .21115 L
.2659 .22709 L
.23249 .25585 L
.2155 .27751 L
.20129 .3008 L
.17967 .35085 L
.16405 .41286 L
.15734 .47401 L
.15774 .53478 L
.16597 .60321 L
.18406 .67664 L
.21157 .74714 L
.23113 .78472 L
.25174 .81764 L
.29988 .87673 L
.33016 .90468 L
.35943 .92649 L
.41529 .95622 L
.47913 .97385 L
.54068 .97586 L
.5969 .96502 L
.64752 .94422 L
.6987 .91103 L
Mistroke
.74282 .87031 L
.77874 .8261 L
.81455 .76736 L
.84507 .69678 L
.8651 .62622 L
.87575 .55952 L
.87857 .48521 L
.87257 .41864 L
.86049 .36344 L
.84097 .31037 L
.81299 .26195 L
.77748 .22356 L
.74369 .20217 L
.70455 .19141 L
.66197 .19486 L
.62392 .21152 L
.60512 .22508 L
.58557 .24366 L
.56674 .26682 L
.55082 .29171 L
.52668 .34417 L
.51103 .39824 L
.50166 .46179 L
.50103 .53033 L
.5079 .58714 L
.52242 .6443 L
.54239 .69294 L
.5652 .73112 L
.59681 .76721 L
.63537 .79375 L
.67427 .80561 L
.71072 .80457 L
.7487 .79063 L
.78652 .76132 L
.81769 .72091 L
.84098 .67438 L
.86064 .61006 L
.86763 .56991 L
.87124 .53086 L
.87034 .45612 L
.86608 .41754 L
.85837 .37488 L
.84795 .33411 L
.83384 .29211 L
.80095 .22107 L
.77861 .18463 L
.75544 .15322 L
.72575 .12012 L
.69536 .09277 L
.63583 .05426 L
Mistroke
.57789 .03245 L
.51341 .02398 L
.47685 .0262 L
.44342 .03272 L
.38323 .0559 L
.32967 .09051 L
.28585 .13103 L
.24375 .18404 L
.20604 .24981 L
.18891 .28943 L
.17596 .32661 L
.15804 .40104 L
.15012 .47142 L
.1505 .53581 L
.15881 .59966 L
.17185 .64924 L
.19177 .69695 L
.21882 .73901 L
.25282 .77189 L
.28812 .79036 L
.32166 .79612 L
.36121 .78929 L
.38058 .78039 L
.4011 .76649 L
.43423 .73222 L
.46054 .69004 L
.47305 .66221 L
.484 .6305 L
.49735 .56906 L
.50113 .53301 L
.5022 .4989 L
.50064 .46131 L
.49583 .42162 L
.48061 .35772 L
.46828 .32422 L
.45471 .29552 L
.42479 .24949 L
.38732 .21215 L
.35011 .19021 L
.31348 .18044 L
.27276 .18225 L
.23026 .19894 L
.20887 .21391 L
.18987 .23171 L
.15814 .27401 L
.13082 .33136 L
.11914 .36821 L
.11101 .40448 L
.10338 .46945 L
.10419 .54447 L
Mistroke
.11564 .62413 L
.13603 .69682 L
.15172 .73656 L
.17195 .77765 L
.19239 .81168 L
.21657 .84509 L
.26851 .8994 L
.32244 .9376 L
.35414 .95326 L
.38934 .9655 L
.45462 .97507 L
.49465 .97283 L
.53232 .96507 L
.56542 .95353 L
.60045 .93615 L
.62983 .91705 L
.66001 .89253 L
.70953 .83888 L
.75012 .77715 L
.77988 .71413 L
.80321 .6416 L
.81217 .59949 L
.8177 .56015 L
.82057 .5191 L
.82058 .48248 L
.81759 .44168 L
.81191 .40493 L
.79662 .34872 L
.77335 .29816 L
.74876 .26384 L
.71777 .23654 L
.68173 .22053 L
.66081 .21772 L
.64158 .21907 L
.6069 .23124 L
.57287 .25703 L
.54354 .29412 L
.52933 .31958 L
.51797 .34559 L
.50196 .39864 L
.49256 .46026 L
.49121 .51797 L
.49613 .57235 L
.50835 .63038 L
.52905 .68848 L
.55875 .74252 L
.57865 .76866 L
.5988 .78957 L
.63912 .81858 L
.66307 .82911 L
Mistroke
.68532 .83494 L
.728 .83597 L
.77328 .82214 L
.81336 .79511 L
.84642 .75899 L
.87308 .71603 L
.89579 .66163 L
.91083 .60378 L
.91859 .54691 L
.92 .47691 L
.91178 .39929 L
.89466 .32705 L
.87099 .26332 L
.83929 .20282 L
.80339 .15231 L
.75804 .10548 L
.70355 .06672 L
.64529 .04156 L
.58149 .03037 L
.52658 .03351 L
.46781 .05013 L
.43775 .06432 L
.40712 .08317 L
.35614 .1261 L
.30822 .18373 L
.28478 .22082 L
.26558 .25776 L
.23801 .32861 L
.22123 .39581 L
.21547 .43312 L
.21203 .47336 L
.21315 .54393 L
.22301 .60753 L
.23866 .65833 L
.26353 .70692 L
.2922 .74114 L
.32212 .76193 L
.35121 .77116 L
.38366 .77022 L
.41699 .75686 L
.45059 .72846 L
.477 .6913 L
.48942 .66666 L
.50087 .63706 L
.51556 .57711 L
.5215 .51589 L
.51902 .44849 L
.50963 .39123 L
.49174 .33089 L
.47738 .29702 L
Mistroke
.46139 .26706 L
.42587 .21814 L
.40335 .19573 L
.38103 .17847 L
.35529 .16374 L
.32678 .15318 L
.30141 .1485 L
.27377 .14827 L
.24784 .15273 L
.2244 .16084 L
.18204 .18654 L
.14183 .22762 L
.10988 .2781 L
.09491 .31104 L
.08327 .34398 L
.06795 .4095 L
.06089 .4843 L
.06302 .55337 L
.07238 .61838 L
.09077 .68783 L
.11969 .75814 L
.15738 .82138 L
.1822 .85313 L
.20729 .8796 L
.26298 .92302 L
.29647 .94091 L
.32796 .95293 L
.38601 .96404 L
.4495 .96067 L
.50807 .94302 L
.55932 .91494 L
.60356 .87942 L
.64616 .83247 L
.6808 .78118 L
.70713 .72971 L
.73096 .66569 L
.74796 .59361 L
.7553 .52586 L
.75471 .46545 L
.74597 .40232 L
.73065 .34995 L
.71184 .31022 L
.68712 .2763 L
.6562 .2511 L
.62099 .23891 L
.59034 .24049 L
.55774 .25476 L
.52567 .28395 L
.50039 .32244 L
.48931 .3464 L
Mistroke
.47905 .37547 L
.47071 .40841 L
.46526 .44125 L
.4616 .50494 L
.46577 .56522 L
.47871 .6309 L
.5015 .69631 L
.52755 .74635 L
.5614 .79233 L
.59813 .82707 L
.63457 .85019 L
.68003 .86612 L
.73054 .8687 L
.77762 .85679 L
.81886 .83366 L
.85909 .79673 L
.89615 .74434 L
.92385 .6845 L
.94194 .62284 L
.95348 .54452 L
.95512 .49846 L
.95341 .45531 L
.9422 .37654 L
.9326 .33769 L
.91902 .29609 L
.90304 .25765 L
.88331 .21949 L
.84128 .15859 L
.81452 .12946 L
.78776 .10583 L
.75666 .08405 L
.72175 .06586 L
.69049 .05454 L
.65584 .04704 L
.62276 .04459 L
.59222 .04633 L
.53525 .05996 L
.47772 .08854 L
.42769 .12774 L
.3796 .18217 L
.34174 .24255 L
.31407 .30421 L
.29427 .36845 L
.28308 .42759 L
.27814 .49472 L
.28106 .55473 L
.29207 .61454 L
.31155 .66854 L
.33349 .70548 L
.36187 .73488 L
Mistroke
.39572 .75237 L
.41543 .75547 L
.43345 .75407 L
.46752 .73995 L
.4971 .71333 L
.51898 .68142 L
.53849 .63757 L
.55263 .58381 L
.55929 .52786 L
.55929 .47271 L
.55381 .42109 L
.54172 .36485 L
.52231 .30803 L
.49588 .25467 L
.461 .20488 L
.42274 .16655 L
.38444 .14032 L
.33635 .1211 L
.3084 .1162 L
.28247 .11558 L
.23521 .12434 L
.18727 .14743 L
.14428 .18301 L
.10355 .23515 L
.07251 .29545 L
.05132 .35903 L
.03831 .42742 L
.03384 .49215 L
.03757 .56801 L
.04978 .63828 L
.07259 .71172 L
.10658 .78211 L
.1428 .83441 L
.18893 .88159 L
.24458 .91886 L
.2777 .93302 L
.30864 .94153 L
.36982 .94592 L
.42726 .93535 L
.47456 .91543 L
.52348 .88268 L
.56958 .83771 L
.60703 .78715 L
.63616 .73423 L
.65744 .68229 L
.67524 .61992 L
.68528 .56 L
.68863 .49705 L
.68406 .43385 L
.67264 .38007 L
Mistroke
.657 .33779 L
.63315 .29753 L
.61765 .27998 L
.60236 .26732 L
.5725 .25323 L
.5399 .25166 L
.50857 .26343 L
.49179 .27573 L
.47717 .29059 L
.45339 .32591 L
.43355 .37362 L
.42158 .42341 L
.41592 .47486 L
.4164 .5347 L
.42512 .60086 L
.44242 .66616 L
.45593 .70171 L
.4708 .73332 L
.50716 .79133 L
.53082 .81953 L
.55411 .84204 L
.59942 .87401 L
.65222 .89518 L
.70384 .90124 L
.75139 .89441 L
.79436 .87735 L
.83776 .84789 L
.87492 .81019 L
.90476 .76814 L
.93367 .71101 L
.95683 .64086 L
.96986 .56931 L
.97383 .50039 L
.96871 .42211 L
.95469 .35039 L
.9348 .28951 L
.90608 .2293 L
.86701 .17213 L
.8185 .12374 L
.7725 .0935 L
.71878 .07306 L
.6592 .06656 L
.60426 .0748 L
.57623 .0844 L
.54621 .09903 L
.51617 .11859 L
.4895 .14067 L
.44521 .18948 L
.41079 .24215 L
.38077 .30645 L
Mistroke
.35871 .37847 L
.348 .44037 L
.34454 .5051 L
.34854 .5628 L
.35786 .61069 L
.37502 .6598 L
.39991 .70206 L
.42795 .72992 L
.45629 .74426 L
.48764 .74705 L
.52072 .73561 L
.54963 .71155 L
.57267 .67919 L
.59405 .63016 L
.60292 .59791 L
.6088 .56564 L
.61325 .50183 L
.61221 .46801 L
.60841 .42998 L
.60206 .39308 L
.59252 .35447 L
.56834 .28781 L
.55107 .2529 L
.5327 .22237 L
.50867 .18965 L
.48363 .1621 L
.43365 .12199 L
.38411 .09763 L
.32826 .0856 L
.29635 .08561 L
.26705 .09004 L
.21418 .1094 L
.16712 .14078 L
.12881 .17895 L
.09247 .23028 L
.06085 .29545 L
.04712 .33539 L
.03728 .37329 L
.02563 .45035 L
.02402 .52472 L
.03089 .5942 L
.04676 .66474 L
.06695 .721 L
.0956 .77693 L
.13314 .82865 L
.17976 .87251 L
.22833 .90158 L
.27513 .91692 L
.33168 .92089 L
.36017 .9171 L
Mistroke
.39116 .9085 L
.44368 .88247 L
.48908 .84644 L
.51283 .82135 L
.53578 .79184 L
.5709 .73247 L
.58689 .69648 L
.5993 .6617 L
.6101 .62258 L
.61832 .58029 L
.6244 .50991 L
.62363 .47159 L
.62036 .43775 L
.60834 .38065 L
.58809 .32955 L
.56459 .29385 L
.53918 .27025 L
.50887 .25617 L
.47527 .25542 L
.45765 .26111 L
.44159 .27026 L
.41378 .29683 L
.38849 .33822 L
.37701 .36668 L
.36851 .39569 L
.35916 .44956 L
.35667 .51414 L
.36334 .58499 L
.37834 .65146 L
.39063 .68848 L
.40698 .72733 L
.42387 .75994 L
.44419 .79241 L
.48874 .84637 L
.5359 .88569 L
.56394 .90245 L
.59529 .91618 L
.65396 .92902 L
.68842 .92912 L
.72442 .92334 L
.75458 .91366 L
.78654 .89817 L
.81335 .88056 L
.84085 .8574 L
.88574 .80541 L
.92195 .74402 L
.94765 .67999 L
.96634 .60481 L
.97247 .56044 L
.97519 .51847 L
Mistroke
.97487 .47413 L
.97176 .43405 L
.96485 .38872 L
.95511 .34719 L
.93217 .28201 L
.89949 .22075 L
.86572 .17661 L
.82328 .13798 L
.77343 .10966 L
.74402 .09999 L
.71656 .09517 L
.66564 .09649 L
.61309 .1119 L
.56435 .14022 L
.53871 .16149 L
.51655 .18417 L
.4802 .23258 L
.44876 .29158 L
.42753 .34905 L
.41392 .40506 L
.40613 .46695 L
.406 .53156 L
.41471 .59498 L
.42335 .62748 L
.43353 .6549 L
.45689 .69719 L
.47215 .71578 L
.48705 .72924 L
.51725 .74535 L
.55124 .74839 L
.5828 .73738 L
.60985 .71569 L
.63238 .68578 L
.65225 .64451 L
.66601 .59802 L
.67366 .55048 L
.6761 .49004 L
.67019 .42095 L
.65617 .35493 L
.63597 .29537 L
.60824 .23765 L
.57629 .18843 L
.53536 .1417 L
.48555 .10176 L
.43172 .07442 L
.37222 .06023 L
.32064 .06055 L
.26512 .07417 L
.2076 .10441 L
.15923 .14556 L
Mistroke
.13625 .17171 L
.11314 .20376 L
.09143 .24097 L
.07423 .27758 L
.04968 .35026 L
.04034 .39241 L
.03432 .43325 L
.03059 .50649 L
.03662 .58507 L
.05242 .65814 L
.07459 .7187 L
.10849 .77971 L
.14724 .82642 L
.18799 .85922 L
.22829 .87954 L
.27443 .89055 L
.32371 .88919 L
.37641 .87277 L
.42156 .84511 L
.44484 .82503 L
.4684 .79974 L
.50583 .74576 L
.53365 .6878 L
.55464 .6212 L
.56525 .56242 L
.56904 .49807 L
.5674 .46065 L
.56323 .42656 L
.54897 .36801 L
.5377 .33926 L
.52537 .31554 L
.51003 .2932 L
.49194 .27397 L
.47504 .26137 L
.4559 .25227 L
.43734 .24813 L
.42013 .24821 L
.38807 .25862 L
.3566 .28382 L
.33096 .31999 L
.31875 .34527 L
.30919 .37146 L
.29654 .42555 L
.29087 .48979 L
.29316 .55095 L
.30192 .6099 L
.31896 .67427 L
.34586 .74089 L
.38115 .80218 L
.42828 .86007 L
Mistroke
.45498 .88478 L
.48534 .90736 L
.54375 .93709 L
.60519 .95155 L
.66407 .95048 L
.71606 .93722 L
.76989 .91005 L
.81695 .8728 L
.8564 .82877 L
.89344 .77164 L
.92484 .70202 L
.94733 .62281 L
.95828 .54444 L
.9593 .47387 L
.95102 .39923 L
.93452 .33291 L
.91289 .27842 L
.88092 .22397 L
.84506 .18254 L
.80783 .15363 L
.77122 .1358 L
.72947 .12624 L
.68491 .12763 L
.63757 .14217 L
.61194 .15611 L
.58927 .17244 L
.55095 .21032 L
.51605 .26022 L
.49084 .31146 L
.47291 .36359 L
.45999 .42341 L
.45421 .4885 L
.45682 .5519 L
.46188 .58591 L
.46877 .61577 L
.48861 .66959 L
.50276 .69509 L
.51719 .71494 L
.54618 .74196 L
.58054 .7576 L
.61405 .75863 L
.64429 .74763 L
.67084 .72718 L
.69617 .69495 L
.71602 .65562 L
.72989 .61314 L
.74016 .55679 L
.74319 .48944 L
.73767 .42242 L
.72505 .3595 L
Mistroke
.70466 .29625 L
.67884 .23972 L
.6436 .18293 L
.59834 .12995 L
.54729 .08803 L
.48847 .05711 L
.43562 .04257 L
.37662 .03985 L
.31346 .05267 L
.25768 .07869 L
.23009 .09745 L
.20131 .12193 L
.17301 .15187 L
.1493 .18259 L
.11182 .24627 L
.09487 .28468 L
.08138 .32286 L
.06406 .39342 L
.05509 .47229 L
.05639 .54848 L
.06593 .61452 L
.08621 .68458 L
.11348 .74223 L
.14484 .78678 L
.17786 .81902 L
.21755 .84389 L
.26192 .85753 L
.31118 .85736 L
.35518 .84381 L
.37855 .83108 L
.40281 .81326 L
.44291 .77117 L
.47451 .72216 L
.50064 .66222 L
.51622 .6067 L
.52576 .54318 L
.52755 .50692 L
.52659 .46934 L
.51787 .40537 L
.50932 .3724 L
.49918 .34402 L
.48584 .31586 L
.46933 .2897 L
.45337 .27063 L
.43467 .25409 L
.41597 .24266 L
.39813 .23587 L
.36359 .23321 L
.32765 .24509 L
.29645 .26953 L
Mistroke
.26694 .30987 L
.24503 .35964 L
.23112 .41425 L
.22429 .47464 L
.22463 .53301 L
.23311 .60266 L
.24914 .66822 L
.27559 .73773 L
.31294 .80533 L
.35179 .85624 L
.40067 .90277 L
.45925 .94012 L
.49403 .95457 L
.5265 .96344 L
.59075 .96861 L
.65119 .9586 L
.70107 .93881 L
.75282 .90561 L
.80177 .8593 L
.84168 .80649 L
.8728 .75049 L
.89556 .69482 L
.91453 .62702 L
.92503 .5608 L
.92801 .48989 L
.9219 .41689 L
.90781 .35276 L
.8886 .30028 L
.85907 .24723 L
.83961 .22219 L
.8202 .20254 L
.78152 .17546 L
.73784 .16023 L
.69395 .15901 L
.66934 .16428 L
.64704 .17288 L
.60809 .19752 L
.57079 .23523 L
.54222 .27748 L
.52024 .32318 L
.50218 .37831 L
.4904 .44136 L
.48689 .50561 L
.48859 .54149 L
.49252 .574 L
.50702 .63548 L
.51871 .66655 L
.53133 .69218 L
.5581 .73089 L
.59187 .76077 L
Mistroke
.62668 .77611 L
.65984 .77846 L
.69039 .77026 L
.72155 .75042 L
.74822 .72167 L
.76933 .68751 L
.78905 .6391 L
.80332 .5776 L
.80895 .51321 L
.80679 .44998 L
.79547 .37693 L
.77616 .30895 L
.75185 .25049 L
.71861 .19194 L
.67475 .1356 L
.62123 .08716 L
.57092 .05633 L
.51235 .03489 L
.44745 .02722 L
.38745 .03459 L
.35675 .0439 L
.32376 .0584 L
.29062 .07811 L
.26105 .10061 L
.2116 .15108 L
.17271 .20641 L
.13823 .27503 L
.11221 .35333 L
.09893 .4219 L
.09367 .49515 L
.09703 .56214 L
.10677 .61944 L
.12579 .68064 L
.1545 .73701 L
.18797 .77887 L
.22293 .80641 L
.26309 .82331 L
.3076 .82667 L
.34911 .81592 L
.38511 .79485 L
.42328 .75771 L
.44232 .73143 L
.45803 .70413 L
.48135 .64798 L
.49019 .61727 L
.49753 .58203 L
.5021 .54721 L
.50422 .5101 L
.50107 .44439 L
.49553 .40907 L
Mistroke
.48803 .37755 L
.47735 .345 L
.46327 .31305 L
.44908 .28823 L
.4318 .26465 L
.41396 .24591 L
.39638 .23188 L
.36102 .21458 L
.32205 .21016 L
.28562 .21949 L
.24822 .24443 L
.21697 .28136 L
.19295 .32614 L
.17507 .37903 L
.16471 .43299 L
.16041 .50048 L
.16434 .56714 L
.17779 .64104 L
.20233 .71721 L
.23134 .77834 L
.27103 .83894 L
.32183 .8941 L
.3534 .91957 L
.38377 .93898 L
.44606 .96551 L
.50748 .97619 L
.56007 .97387 L
.61711 .95921 L
.67394 .93087 L
.7233 .893 L
.76468 .84901 L
.79796 .80231 L
.82868 .74536 L
.85383 .68065 L
.87137 .6118 L
.88088 .53738 L
.88116 .46867 L
.87435 .4094 L
.85833 .34568 L
.84581 .31342 L
.83227 .28645 L
.80306 .24462 L
.76725 .21247 L
.72919 .19414 L
.68605 .18927 L
.64565 .19909 L
.61011 .22016 L
.57805 .2515 L
.55275 .28782 L
.52896 .33758 L
Mistroke
.5127 .39032 L
.50236 .45249 L
.50039 .52008 L
.50605 .57705 L
.51975 .6362 L
.54263 .69337 L
.55873 .72136 L
.57518 .74385 L
.61117 .77825 L
.64877 .79818 L
.68226 .80468 L
.71934 .80025 L
.75665 .78263 L
.78887 .75444 L
.81533 .71868 L
.83565 .67869 L
.85287 .62787 L
.86443 .56809 L
.86865 .50223 L
.86417 .42885 L
.85124 .35901 L
.83223 .29705 L
.8013 .2281 L
.78006 .19209 L
.75824 .16122 L
.71304 .1112 L
.65922 .06942 L
.60199 .04105 L
.56831 .03092 L
.53659 .02548 L
.47802 .02553 L
.41665 .03973 L
.36425 .06424 L
.31816 .09678 L
.27226 .142 L
.22947 .20031 L
.19474 .26642 L
.17898 .30642 L
.167 .34477 L
.15091 .42387 L
.14668 .4681 L
.1458 .50764 L
.15103 .57553 L
.166 .64253 L
.188 .69706 L
.21402 .73813 L
.24213 .76728 L
.27535 .78804 L
.30838 .7971 L
.33901 .79631 L
Mistroke
.37407 .78458 L
.4099 .75915 L
.43995 .72411 L
.46344 .6833 L
.48379 .6295 L
.49618 .57331 L
.50128 .52009 L
.50012 .46155 L
.49096 .39877 L
.47267 .33673 L
.45066 .28942 L
.42062 .24562 L
.38293 .21017 L
.34451 .18951 L
.32364 .18373 L
.3003 .18148 L
.27594 .18382 L
.2534 .19039 L
.21395 .21324 L
.18117 .24595 L
.15051 .29369 L
.12588 .35548 L
.11228 .415 L
.10583 .48394 L
.10788 .55207 L
.11679 .61475 L
.13587 .68732 L
.16666 .76168 L
.20467 .82513 L
.24652 .87574 L
.29715 .91956 L
.35684 .95327 L
.41652 .97124 L
.4723 .97534 L
.53721 .96509 L
.57294 .95226 L
.605 .93603 L
.66014 .8961 L
.6884 .86856 L
.71211 .84076 L
.73523 .80846 L
.75702 .7718 L
.78881 .70104 L
.80229 .65962 L
.81203 .62032 L
.81955 .57693 L
.82392 .53084 L
.82468 .49177 L
.82242 .45071 L
.81744 .41371 L
Mistroke
.81052 .38145 L
.79181 .32653 L
.76502 .27884 L
.73465 .24548 L
.6976 .22312 L
.6607 .21616 L
.62639 .22212 L
.59384 .23943 L
.56665 .26434 L
.53924 .30291 L
.51837 .34748 L
.50207 .40345 L
.49315 .4682 L
.49273 .52577 L
.50005 .58893 L
.51683 .65391 L
.53007 .68784 L
.54435 .71665 L
.57754 .76535 L
.61448 .80088 L
.64891 .82165 L
.68896 .83366 L
.73155 .83331 L
.77075 .82081 L
.80531 .79875 L
.83439 .77011 L
.86248 .73009 L
.88669 .67934 L
.90469 .62014 L
.91563 .55046 L
.91749 .48077 L
.91175 .41598 L
.89588 .34038 L
.88265 .299 L
.86782 .26217 L
.83431 .19906 L
.79082 .14062 L
.74187 .09411 L
.68262 .05686 L
.62285 .03588 L
.56576 .02942 L
.50916 .03553 L
.45914 .0516 L
.4043 .08195 L
.35683 .12108 L
.31079 .17421 L
.27036 .23964 L
.24332 .30102 L
.22218 .37176 L
.20969 .44907 L
Mistroke
.20736 .49167 L
.20807 .52938 L
.21685 .59813 L
.23339 .65548 L
.25294 .69678 L
.27926 .73287 L
.31072 .7588 L
.34253 .77145 L
.37296 .77281 L
.40049 .76525 L
.42932 .74759 L
.45691 .71913 L
.48102 .68074 L
.50107 .63096 L
.5137 .57747 L
.51932 .52514 L
.51837 .46111 L
.51416 .42484 L
.50795 .39185 L
.49085 .33352 L
.46522 .27722 L
.4335 .22986 L
.41307 .20723 L
.39278 .1893 L
.35289 .16471 L
.30796 .15131 L
.26715 .15106 L
.22935 .16106 L
.18979 .18328 L
.15091 .21985 L
.11754 .26834 L
.10164 .30052 L
.08905 .33316 L
.07083 .40562 L
.06515 .44913 L
.06296 .48994 L
.06633 .56462 L
.08066 .64537 L
.10418 .71851 L
.134 .78102 L
.1681 .83311 L
.21077 .88104 L
.2558 .91733 L
.30013 .94205 L
.35453 .95997 L
.41547 .96549 L
.47284 .95718 L
.52448 .93802 L
.57927 .90406 L
.62614 .86128 L
Mistroke
.66332 .81522 L
.69743 .75882 L
.72666 .69149 L
.74776 .61675 L
.7576 .55237 L
.75982 .48364 L
.75271 .41517 L
.73819 .35896 L
.72792 .33307 L
.71469 .30763 L
.69904 .28488 L
.6829 .26735 L
.65066 .2454 L
.61931 .23735 L
.58465 .24199 L
.54985 .26175 L
.52335 .28951 L
.49928 .32918 L
.48163 .37472 L
.47058 .42154 L
.46433 .48139 L
.46635 .54942 L
.47687 .61389 L
.49385 .67113 L
.51917 .72741 L
.55384 .77994 L
.59252 .81977 L
.63177 .84635 L
.6808 .86416 L
.70929 .86747 L
.73576 .86607 L
.78338 .85225 L
.8089 .83827 L
.83098 .82189 L
.85314 .8007 L
.87474 .77438 L
.90791 .71807 L
.92288 .68221 L
.93433 .64634 L
.94392 .60472 L
.95057 .55811 L
.95319 .51661 L
.95267 .47081 L
.94893 .42734 L
.94267 .38745 L
.9236 .31401 L
.89348 .24142 L
.85671 .18063 L
.80843 .12493 L
.75655 .08453 L
Mistroke
.70435 .0589 L
.65036 .04556 L
.6006 .04409 L
.54371 .05489 L
.49205 .0769 L
.43934 .11313 L
.38958 .16361 L
.3531 .21494 L
.32039 .27797 L
.29461 .35087 L
.28463 .39287 L
.27837 .43126 L
.2739 .50432 L
.27869 .56934 L
.28911 .6193 L
.30661 .66722 L
.33052 .70746 L
.35704 .73485 L
.3841 .75051 L
.41001 .75619 L
.43859 .75274 L
.46766 .73832 L
.4948 .7129 L
.51974 .6748 L
.53822 .62987 L
.54993 .58286 L
.55671 .52204 L
.55697 .48598 L
.55485 .45211 L
.54498 .38968 L
.52618 .32549 L
.50016 .2677 L
.46388 .21248 L
.42321 .17017 L
.38114 .1412 L
.33663 .12344 L
.29503 .11742 L
.24692 .12279 L
.20299 .13994 L
.15801 .17174 L
.11596 .21901 L
.08581 .26922 L
.06008 .33298 L
.04208 .40942 L
.03676 .45466 L
.035 .49678 L
.04016 .57934 L
.05544 .65586 L
.07612 .71764 L
.10655 .78017 L
Mistroke
.14599 .83714 L
.18905 .88115 L
.23338 .91278 L
.27665 .93311 L
.32601 .94543 L
.37876 .94683 L
.43196 .93617 L
.48652 .91185 L
.53443 .87759 L
.57385 .83804 L
.61412 .78282 L
.6323 .75069 L
.64909 .71492 L
.67298 .64589 L
.68676 .58059 L
.69266 .51305 L
.68949 .44338 L
.67798 .38409 L
.66083 .33689 L
.63865 .29908 L
.61513 .27364 L
.5852 .25556 L
.55567 .25012 L
.5233 .25722 L
.49116 .27912 L
.4668 .30876 L
.44476 .35155 L
.42788 .40784 L
.42202 .44301 L
.41914 .47675 L
.42056 .54546 L
.43072 .61179 L
.44621 .66741 L
.47025 .7254 L
.50259 .78004 L
.5388 .82378 L
.57686 .85662 L
.61451 .87899 L
.66026 .89481 L
.70489 .89933 L
.7527 .89244 L
.80191 .87174 L
.84516 .84006 L
.8805 .80187 L
.91613 .74656 L
.93284 .71115 L
.94585 .67628 L
.9634 .60756 L
.9724 .53058 L
.9713 .4532 L
Mistroke
.96628 .40974 L
.95885 .37023 L
.93846 .30077 L
.9078 .23336 L
.87345 .18071 L
.83602 .13907 L
.79028 .10332 L
.73694 .07752 L
.68104 .06569 L
.64897 .06534 L
.61926 .06912 L
.56066 .08853 L
.52935 .10595 L
.50222 .12557 L
.45745 .16901 L
.41583 .22628 L
.38425 .28775 L
.36245 .34863 L
.3488 .40716 L
.34139 .4699 L
.34119 .52712 L
.3465 .57621 L
.35883 .62806 L
.37887 .67579 L
.40293 .71075 L
.42854 .73326 L
.45983 .74633 L
.49006 .74626 L
.5166 .73598 L
.5434 .71438 L
.56903 .67915 L
.59031 .63037 L
.60268 .58093 L
.60918 .52051 L
.60718 .45096 L
.59666 .38516 L
.58784 .35112 L
.57552 .31442 L
.55963 .2771 L
.54261 .24469 L
.50568 .191 L
.48366 .16643 L
.4588 .1437 L
.41359 .1134 L
.36081 .09299 L
.30764 .0868 L
.25943 .09329 L
.20566 .11506 L
.15853 .14902 L
.11937 .19124 L
Mistroke
.08819 .23823 L
.0603 .29739 L
.03894 .36667 L
.02606 .44697 L
.02407 .52235 L
.02701 .56391 L
.03347 .60848 L
.05362 .68602 L
.08162 .75203 L
.12005 .81291 L
.15885 .85559 L
.20678 .89131 L
.23576 .90583 L
.26725 .91641 L
.32489 .923 L
.35707 .91981 L
.38666 .9125 L
.41835 .8998 L
.45093 .88106 L
.47771 .86078 L
.50497 .83487 L
.5272 .80896 L
.5487 .77873 L
.58294 .71516 L
.60634 .65128 L
.62134 .58537 L
.62812 .51377 L
.62559 .44934 L
.61598 .39468 L
.6003 .34736 L
.58157 .31171 L
.55569 .28048 L
.52836 .26179 L
.49668 .25401 L
.46311 .26051 L
.4359 .27783 L
.40912 .30862 L
.38556 .35422 L
.37536 .38469 L
.36822 .41508 L
.36085 .47988 L
.36243 .54598 L
.37066 .6038 L
.38717 .66716 L
.41252 .73045 L
.44338 .78499 L
.47767 .82984 L
.51318 .86468 L
.55584 .89492 L
.60382 .91663 L
Mistroke
.65464 .92724 L
.70948 .92519 L
.76021 .91048 L
.80413 .88664 L
.85173 .84652 L
.87602 .8186 L
.8965 .78982 L
.92872 .7302 L
.95426 .65944 L
.96987 .58525 L
.97586 .50158 L
.9708 .42283 L
.95701 .35263 L
.93517 .28787 L
.90896 .23507 L
.87203 .18277 L
.83186 .14346 L
.78314 .11263 L
.7284 .09514 L
.68055 .09276 L
.62861 .10333 L
.57512 .12946 L
.54705 .1503 L
.52304 .17278 L
.48141 .22494 L
.44922 .28263 L
.42796 .33644 L
.41166 .39854 L
.40282 .46415 L
.40207 .52405 L
.40768 .57667 L
.41776 .62067 L
.43465 .66503 L
.45514 .69952 L
.48089 .72697 L
.51125 .74426 L
.54121 .74859 L
.56826 .74229 L
.59849 .72258 L
.61414 .70587 L
.62734 .68714 L
.64793 .64495 L
.66338 .59093 L
.67118 .53056 L
.67205 .49409 L
.67045 .4593 L
.66138 .3942 L
.64294 .32539 L
.61903 .26659 L
.59054 .21534 L
Mistroke
.55317 .16534 L
.50669 .12067 L
.45507 .08738 L
.42415 .07416 L
.39463 .06575 L
.33389 .06068 L
.29992 .06493 L
.2695 .07321 L
.21695 .09835 L
.1645 .13976 L
.12101 .19102 L
.08735 .24724 L
.06238 .30585 L
.04313 .37375 L
.03259 .44072 L
.02962 .50282 L
.03425 .57458 L
.04896 .64933 L
.07155 .7142 L
.09932 .76754 L
.13746 .81798 L
.17868 .85453 L
.21895 .87743 L
.26467 .89104 L
.31565 .8924 L
.36864 .87874 L
.41167 .85544 L
.45501 .81867 L
.4955 .76794 L
.52614 .71277 L
.53923 .68159 L
.55121 .64582 L
.56088 .60744 L
.56725 .57097 L
.57214 .50451 L
.56906 .4461 L
.55788 .38724 L
.53827 .33394 L
.51646 .29769 L
.48911 .26933 L
.46067 .25332 L
.43373 .24837 L
.40205 .25446 L
.36956 .2754 L
.34239 .30814 L
.32175 .34837 L
.3056 .40047 L
.29624 .46474 L
.29585 .53092 L
.30312 .59382 L
Mistroke
.32109 .66767 L
.33571 .70834 L
.35204 .74468 L
.38853 .80645 L
.41214 .83723 L
.43571 .86285 L
.48705 .90506 L
.51605 .9222 L
.54778 .93617 L
.60302 .9497 L
.66447 .94956 L
.69924 .94237 L
.73022 .93138 L
.7648 .91357 L
.79596 .89189 L
.84659 .84252 L
.87189 .80915 L
.89283 .77527 L
.92454 .70674 L
.94593 .63585 L
.9574 .5694 L
.96134 .496 L
.95554 .41811 L
.94787 .37633 L
.9383 .34007 L
.91294 .27515 L
.8818 .22261 L
.84708 .18227 L
.80595 .15049 L
.76826 .13283 L
.72535 .1239 L
.67874 .12659 L
.63005 .1433 L
.58692 .17137 L
.55123 .20631 L
.51492 .25729 L
.49935 .28635 L
.48454 .32047 L
.46487 .38451 L
.4543 .44689 L
.45176 .48259 L
.4518 .51958 L
.45863 .58262 L
.46599 .61519 L
.47495 .64333 L
.48693 .67138 L
.50194 .69765 L
.53141 .73202 L
.54982 .74547 L
.56756 .75385 L
Mistroke
.60115 .75877 L
.63639 .74899 L
.66596 .72739 L
.69058 .69681 L
.71285 .6528 L
.72982 .59512 L
.73546 .56085 L
.73842 .5268 L
.73754 .45978 L
.72682 .38506 L
.71626 .34301 L
.70371 .30503 L
.6767 .24392 L
.63907 .18281 L
.59184 .12814 L
.54175 .08768 L
.51114 .0698 L
.4766 .05499 L
.44309 .0456 L
.41165 .04104 L
.35189 .04339 L
.28989 .06158 L
.25918 .0771 L
.22752 .09828 L
.17504 .14745 L
.14803 .18175 L
.12277 .22176 L
.10265 .26162 L
.08661 .30142 L
.06513 .37784 L
.05463 .4496 L
.05304 .5268 L
.05653 .56926 L
.06246 .60715 L
.07794 .66697 L
.10234 .72585 L
.13502 .77777 L
.17101 .8159 L
.19324 .83261 L
.21859 .84657 L
.2667 .86025 L
.31433 .85888 L
.35748 .84496 L
.40121 .81717 L
.42422 .79589 L
.44426 .77266 L
.47911 .7177 L
.49507 .68281 L
.5072 .64889 L
.52277 .58352 L
Mistroke
.52929 .52027 L
.52834 .46437 L
.52028 .40688 L
.50378 .35046 L
.49272 .32526 L
.47867 .30052 L
.4498 .26551 L
.41927 .244 L
.38672 .23429 L
.35537 .23651 L
.32798 .24803 L
.30005 .27062 L
.27341 .30618 L
.25069 .35546 L
.23587 .41104 L
.22884 .46738 L
.22924 .54019 L
.23327 .57806 L
.24071 .6199 L
.26161 .69311 L
.28976 .75818 L
.31068 .7951 L
.33299 .82775 L
.38068 .88148 L
.41028 .90663 L
.43921 .92636 L
.47239 .94386 L
.50887 .95739 L
.56672 .96761 L
.6295 .96376 L
.68737 .94601 L
.73772 .91818 L
.78904 .87533 L
.81541 .846 L
.8379 .81581 L
.87668 .74743 L
.8941 .70572 L
.90707 .66627 L
.92335 .59271 L
.9301 .523 L
.92813 .44798 L
.9155 .37209 L
.90533 .33685 L
.89156 .30111 L
.86004 .24455 L
.82267 .20169 L
.78368 .17408 L
.74101 .15869 L
.69986 .15641 L
.66323 .16434 L
Mistroke
.62522 .18307 L
.58681 .21481 L
.55142 .25947 L
.52642 .30513 L
.5054 .3612 L
.49673 .39487 L
.49005 .43242 L
.48641 .46836 L
.48537 .50152 L
.48941 .5629 L
.50195 .62366 L
.51151 .6524 L
.52394 .68077 L
.55134 .72412 L
.57063 .7448 L
.59038 .76001 L
.60898 .76975 L
.6299 .77597 L
.66837 .77517 L
.70228 .7609 L
.72007 .74755 L
.7381 .72892 L
.76657 .68474 L
.78706 .63242 L
.80073 .56787 L
.80508 .50716 L
.80147 .43685 L
.78743 .35983 L
.76508 .29 L
.74996 .25502 L
.73062 .21808 L
.70735 .18147 L
.68361 .15049 L
.63486 .1014 L
.6069 .08009 L
.57602 .06132 L
.5214 .03883 L
.4594 .02808 L
.39872 .03197 L
.34474 .0477 L
.28562 .07971 L
.2346 .1225 L
.19281 .17167 L
.15981 .22387 L
.13049 .2871 L
.10799 .3587 L
.09406 .43857 L
.09088 .51122 L
.09297 .55027 L
.09827 .5914 L
Mistroke
.11554 .66079 L
.13966 .71709 L
.17252 .76598 L
.20885 .80005 L
.24486 .81987 L
.26829 .82671 L
.29338 .82923 L
.33806 .82181 L
.36219 .81121 L
.38382 .79737 L
.40626 .77803 L
.42844 .75286 L
.44576 .72777 L
.4624 .6974 L
.47584 .66617 L
.48613 .63551 L
.49967 .57406 L
.50514 .50644 L
.5023 .44766 L
.49128 .38656 L
.4716 .32907 L
.44674 .28378 L
.41861 .25011 L
.39006 .22815 L
.35479 .21397 L
.32058 .21213 L
.28381 .22319 L
.24746 .24943 L
.21996 .283 L
.19496 .33058 L
.17564 .39242 L
.16874 .43103 L
.16512 .46821 L
.16585 .54407 L
.17635 .61808 L
.19276 .68021 L
.21872 .74615 L
.25411 .80968 L
.29434 .86238 L
.337 .90379 L
.37982 .9343 L
.42993 .95865 L
.48506 .97321 L
.54209 .97587 L
.60257 .96507 L
.65759 .94227 L
.70466 .9115 L
.75496 .86427 L
.78043 .83295 L
.80181 .80144 L
Mistroke
.83524 .73815 L
.86173 .66548 L
.87806 .59218 L
.88519 .51196 L
.88186 .43889 L
.87047 .37584 L
.85202 .31995 L
.82986 .27635 L
.79895 .23582 L
.7658 .20836 L
.72657 .19106 L
.68369 .18775 L
.64748 .19702 L
.60977 .21942 L
.57327 .25664 L
.55533 .28277 L
.54084 .30944 L
.51849 .36771 L
.50511 .42857 L
.50012 .48264 L
.50161 .54268 L
.5109 .60344 L
.52645 .65643 L
.54635 .70055 L
.56863 .7353 L
.59679 .76602 L
.6296 .78886 L
.66514 .80118 L
.70393 .8015 L
.73982 .78947 L
.77056 .76833 L
.80304 .73166 L
.81901 .70578 L
.83195 .67891 L
.85066 .62285 L
.86238 .55588 L
.86499 .48538 L
.85735 .40563 L
.83992 .33046 L
.81507 .26346 L
.78265 .20179 L
.74718 .15173 L
.69993 .10255 L
.65041 .06618 L
.59185 .03868 L
.5272 .02486 L
.4713 .02583 L
.411 .04038 L
.34911 .07125 L
.31663 .09496 L
Mistroke
.2888 .12023 L
.24033 .17828 L
.20247 .24215 L
.17704 .30171 L
.1569 .37067 L
.14498 .44402 L
.14229 .51168 L
.14694 .57193 L
.1569 .62323 L
.1746 .67631 L
.19683 .71931 L
.22553 .75606 L
.26027 .78334 L
.29554 .79705 L
.32838 .79912 L
.36661 .789 L
.3873 .77752 L
.40549 .76344 L
.43604 .72942 L
.46308 .68337 L
.48319 .63008 L
.49141 .59725 L
.49685 .56559 L
.50118 .50559 L
.49763 .44127 L
.48745 .38567 L
.47214 .33672 L
.44949 .2885 L
.41906 .24491 L
.38361 .2119 L
.36185 .19851 L
.34085 .18975 L
.29721 .18344 L
.27272 .18674 L
.25085 .19402 L
.21344 .21708 L
.1771 .25592 L
.14848 .30457 L
.12821 .35829 L
.11548 .41453 L
.10907 .47992 L
.11037 .54457 L
.11801 .60462 L
.13477 .67406 L
.16241 .74638 L
.19691 .80904 L
.2355 .86035 L
.28556 .90849 L
.33773 .94282 L
.38758 .9636 L
Mistroke
.44339 .97473 L
.50506 .97309 L
.56888 .95583 L
.62073 .92902 L
.67325 .88789 L
.7228 .83199 L
.76167 .77047 L
.79328 .69949 L
.80608 .65994 L
.81668 .61656 L
.82407 .57181 L
.82805 .52514 L
.82841 .48613 L
.82568 .44494 L
.82037 .40852 L
.81189 .37203 L
.79 .31402 L
.77539 .28797 L
.76035 .26718 L
.74236 .24812 L
.72197 .23248 L
.68555 .21712 L
.66426 .21463 L
.64432 .2164 L
.60808 .23008 L
.57724 .25379 L
.54595 .29323 L
.52198 .34087 L
.50491 .39564 L
.49584 .44987 L
.49342 .51551 L
.49924 .57764 L
.5116 .63354 L
.52855 .68157 L
.55283 .72891 L
.58401 .7709 L
.6204 .80348 L
.66306 .82553 L
.70521 .83314 L
.74371 .82846 L
.78734 .80881 L
.81045 .79116 L
.83044 .77085 L
.86285 .72422 L
.88974 .66316 L
.90668 .59709 L
.91443 .5286 L
.914 .46427 L
.90529 .39304 L
.88619 .31728 L
Mistroke
.87125 .27655 L
.85516 .24114 L
.81735 .17762 L
.7747 .12609 L
.72929 .08644 L
.67699 .05518 L
.62984 .03785 L
.57659 .02925 L
.5189 .03237 L
.45838 .04979 L
.40417 .07893 L
.35848 .11534 L
.31059 .1688 L
.26824 .23573 L
.24001 .29888 L
.21797 .37235 L
.20997 .41406 L
.20537 .45215 L
.20329 .49331 L
.20439 .53536 L
.21351 .60161 L
.22244 .63576 L
.23297 .66485 L
.25879 .7128 L
.28842 .74629 L
.31805 .76564 L
.35197 .77456 L
.38926 .76981 L
.40755 .76179 L
.42688 .74878 L
.45807 .7157 L
.48255 .67432 L
.5021 .62176 L
.50985 .58921 L
.51475 .55823 L
.51818 .49507 L
.51379 .43435 L
.50798 .40008 L
.49928 .36476 L
.47741 .30519 L
.46196 .27484 L
.44562 .24885 L
.42591 .22345 L
.4025 .19971 L
.35965 .17005 L
.31623 .15472 L
.27287 .15248 L
.23323 .16182 L
.19239 .18406 L
.15151 .22251 L
Mistroke
.13317 .24697 L
.11545 .27681 L
.08949 .33888 L
.07349 .40339 L
.06604 .46793 L
.06655 .54167 L
.07739 .621 L
.08689 .6604 L
.10015 .70195 L
.13174 .77283 L
.17106 .83414 L
.21379 .88197 L
.25855 .91799 L
.30356 .94305 L
.3554 .96032 L
.41247 .96647 L
.47218 .95907 L
.52712 .93932 L
.5738 .91163 L
.6206 .87175 L
.66217 .82294 L
.69965 .7628 L
.72759 .70052 L
.7463 .64102 L
.75946 .57286 L
.76419 .5094 L
.76114 .44417 L
.74893 .37998 L
.73999 .35212 L
.72811 .32436 L
.71367 .29896 L
.69852 .27878 L
.66836 .25209 L
.63307 .23761 L
.59725 .23824 L
.56419 .25243 L
.53673 .2759 L
.51053 .31207 L
.49673 .33961 L
.48583 .36857 L
.47164 .42911 L
.4675 .46585 L
.46626 .5008 L
.46782 .5399 L
.47281 .58137 L
.48866 .64886 L
.51161 .70773 L
.52809 .73874 L
.54503 .76476 L
.56539 .79033 L
Mistroke
.58894 .81389 L
.61032 .83076 L
.63508 .84571 L
.68086 .86206 L
.70725 .86536 L
.73576 .86405 L
.76241 .85814 L
.78631 .84877 L
.82784 .8221 L
.8686 .77961 L
.88677 .7533 L
.90407 .72198 L
.92905 .65823 L
.94549 .5847 L
.9499 .54551 L
.95163 .50137 L
.94649 .42222 L
.93223 .34917 L
.91926 .30649 L
.90406 .26761 L
.86839 .20038 L
.84473 .16682 L
.82068 .13872 L
.7924 .11176 L
.75976 .08724 L
.70053 .05745 L
.64203 .04381 L
.58426 .04428 L
.53196 .05656 L
.47751 .0822 L
.42248 .12379 L
.39712 .14954 L
.3721 .18021 L
.33316 .24232 L
.30346 .30973 L
.28417 .3752 L
.27227 .44784 L
.26993 .48389 L
.27014 .52254 L
.27674 .58344 L
.29184 .64153 L
.31267 .68721 L
.33627 .7198 L
.36389 .74309 L
.39148 .7548 L
.42257 .75633 L
.45511 .74496 L
.48398 .72212 L
.50802 .69072 L
.52609 .65524 L
Mistroke
.54109 .61024 L
.55165 .5515 L
.55431 .49364 L
.54862 .42452 L
.53446 .35951 L
.51402 .30237 L
.48921 .25376 L
.45613 .207 L
.4153 .1668 L
.37004 .13814 L
.3432 .1276 L
.31804 .12166 L
.27113 .12035 L
.22242 .13266 L
.19744 .14487 L
.17183 .16212 L
.1295 .20363 L
.10664 .23512 L
.08754 .26866 L
.07269 .30158 L
.05925 .33991 L
.0423 .41639 L
.03631 .49236 L
.03735 .53675 L
.04117 .57733 L
.04898 .62363 L
.05971 .66655 L
.073 .70644 L
.09021 .74688 L
.12851 .81277 L
.15617 .84788 L
.18472 .8767 L
.21215 .89879 L
.2434 .91836 L
.2988 .94063 L
.33123 .9471 L
.36176 .94903 L
.42312 .94094 L
.45668 .92955 L
.48634 .91508 L
.53634 .88011 L
.58489 .83028 L
.62385 .77391 L
.65301 .71575 L
.67581 .6509 L
.69092 .58081 L
.69657 .52151 L
.69531 .45945 L
.68573 .39794 L
.67699 .36699 L
Mistroke
.66715 .34146 L
.64351 .29977 L
.61689 .27133 L
.58931 .25512 L
.55878 .24958 L
.53271 .2544 L
.5052 .26965 L
.47824 .29708 L
.45384 .33805 L
.43642 .38611 L
.42616 .43635 L
.42182 .5009 L
.423 .53495 L
.42701 .57308 L
.44106 .64012 L
.46223 .70062 L
.4776 .73314 L
.49622 .76527 L
.53514 .81589 L
.55957 .83956 L
.58379 .8583 L
.61172 .87489 L
.6428 .88775 L
.69651 .89732 L
.72706 .89589 L
.75501 .89015 L
.80466 .86866 L
.85321 .83105 L
.89143 .78557 L
.92158 .73409 L
.94726 .66943 L
.9652 .59278 L
.97034 .5503 L
.97234 .50958 L
.96862 .433 L
.95381 .35239 L
.9407 .309 L
.92574 .27097 L
.89489 .21242 L
.85357 .15735 L
.80356 .11214 L
.75215 .08271 L
.72155 .07188 L
.68757 .06507 L
.65517 .06345 L
.62524 .06609 L
.56971 .08176 L
.51396 .11288 L
.48717 .13424 L
.46014 .16094 L
Mistroke
.41693 .21766 L
.3957 .25461 L
.37666 .29597 L
.36324 .33276 L
.35163 .37399 L
.34419 .41025 L
.33893 .44946 L
.33675 .51872 L
.34333 .58142 L
.35632 .63287 L
.37685 .67959 L
.39102 .70127 L
.40562 .71805 L
.42212 .73185 L
.43796 .74083 L
.45683 .74677 L
.475 .74796 L
.50503 .74028 L
.53512 .71916 L
.56026 .68776 L
.57917 .65072 L
.5956 .59799 L
.60161 .5648 L
.60491 .53256 L
.60504 .47006 L
.5965 .40196 L
.57949 .3361 L
.56618 .30019 L
.55159 .26836 L
.51946 .21445 L
.4786 .16561 L
.4372 .13094 L
.39519 .10729 L
.34673 .09214 L
.29338 .08919 L
.23761 .10146 L
.20712 .11536 L
.17992 .13262 L
.13395 .17451 L
.1109 .20329 L
.09194 .23242 L
.06179 .29429 L
.03856 .36927 L
.02643 .4451 L
.0241 .51691 L
.02969 .58398 L
.04391 .65363 L
.06477 .71533 L
.08965 .76677 L
.12515 .81959 L
Mistroke
.17037 .86617 L
.21797 .89834 L
.26496 .91702 L
.31469 .92464 L
.36162 .92109 L
.41196 .90554 L
.4633 .87589 L
.50957 .83463 L
.55175 .78034 L
.58142 .72707 L
.60642 .66368 L
.6241 .59183 L
.63153 .52545 L
.63206 .49164 L
.63008 .45566 L
.62524 .41998 L
.6183 .38877 L
.60007 .33821 L
.5781 .30118 L
.56423 .285 L
.548 .27108 L
.51643 .25622 L
.48456 .25525 L
.45628 .26598 L
.42607 .29163 L
.4016 .32778 L
.38358 .37057 L
.37187 .41648 L
.36512 .47256 L
.36557 .53616 L
.3754 .60781 L
.39293 .67255 L
.40606 .70721 L
.42302 .74336 L
.4605 .8034 L
.50244 .85089 L
.55288 .88994 L
.5995 .91263 L
.65323 .92522 L
.68428 .92629 L
.71684 .92257 L
.77361 .90358 L
.80382 .88629 L
.83057 .8661 L
.8581 .83963 L
.88502 .80673 L
.90604 .77463 L
.92606 .73657 L
.94114 .70056 L
.95431 .66037 L
Mistroke
.97094 .57997 L
.97619 .50326 L
.97162 .42656 L
.95567 .3463 L
.9307 .27652 L
.89982 .21932 L
.86282 .17145 L
.82484 .13692 L
.77698 .10853 L
.72943 .09373 L
.67601 .09114 L
.62037 .10374 L
.57498 .12636 L
.52904 .16261 L
.48552 .21338 L
.46444 .24623 L
.44757 .27834 L
.42154 .34531 L
.40565 .41176 L
.39896 .46883 L
.39884 .52986 L
.40645 .58921 L
.42012 .6387 L
.43783 .67799 L
.45754 .70706 L
.48348 .73147 L
.51026 .74485 L
.54004 .74807 L
.57141 .73864 L
.59916 .71785 L
.6216 .68961 L
.64342 .64592 L
.653 .61696 L
.65987 .58792 L
.66714 .52959 L
.66663 .46305 L
.65748 .39528 L
.64844 .35695 L
.63762 .32199 L
.61178 .26038 L
.57634 .20063 L
.53854 .15427 L
.49852 .11815 L
.45061 .08807 L
.39568 .06809 L
.33893 .06192 L
.3067 .06476 L
.27705 .07153 L
.21922 .09716 L
.18873 .11821 L
Mistroke
.16258 .14126 L
.1202 .19122 L
.08214 .25619 L
.05494 .32564 L
.03814 .39451 L
.03003 .46104 L
.02962 .53297 L
.03705 .59938 L
.05027 .65727 L
.07302 .71981 L
.10591 .77953 L
.14358 .82599 L
.18309 .85916 L
.23153 .88407 L
.27929 .89474 L
.32267 .89362 L
.36875 .88123 L
.41667 .85508 L
.46265 .81456 L
.49694 .77093 L
.52817 .71545 L
.55334 .64943 L
.56825 .58519 L
.57276 .55131 L
.57513 .51425 L
.57472 .4764 L
.57175 .44217 L
.56015 .38405 L
.54323 .33784 L
.51884 .29684 L
.48819 .2666 L
.45973 .25243 L
.42825 .24942 L
.39891 .25821 L
.37371 .27577 L
.34712 .30755 L
.32371 .35419 L
.30816 .40816 L
.30045 .46458 L
.29998 .5298 L
.30896 .60275 L
.32661 .67163 L
.35035 .73218 L
.3869 .79757 L
.41138 .83082 L
.43626 .85869 L
.48664 .90129 L
.51403 .91815 L
.54546 .93283 L
.57671 .94288 L
Mistroke
.61024 .94893 L
.67068 .94781 L
.70398 .9405 L
.73434 .92945 L
.7666 .91273 L
.79947 .88974 L
.82625 .8658 L
.85324 .83589 L
.87502 .80641 L
.8958 .77231 L
.92803 .70105 L
.94876 .62952 L
.96038 .55394 L
.96202 .4709 L
.95311 .39487 L
.93619 .32885 L
.91189 .26985 L
.8841 .22333 L
.84629 .17939 L
.80625 .14873 L
.75904 .12805 L
.70728 .1214 L
.66314 .1281 L
.6164 .14807 L
.56987 .18324 L
.54619 .2085 L
.52643 .23457 L
.49372 .29225 L
.47052 .35328 L
.45723 .40809 L
.44969 .46958 L
.44979 .53253 L
.457 .58821 L
.46946 .63533 L
.48523 .67324 L
.50663 .7078 L
.53282 .73507 L
.56218 .75222 L
.59504 .75798 L
.62596 .75123 L
.65277 .73496 L
.68128 .70398 L
.69535 .68127 L
.70674 .65727 L
.72308 .60633 L
.73297 .54447 L
.73443 .47858 L
.72616 .4034 L
.70869 .33208 L
.68424 .26824 L
Mistroke
.65255 .20933 L
.61803 .16145 L
.57215 .11446 L
.52415 .07987 L
.46747 .05407 L
.40504 .04183 L
.3512 .04406 L
.29334 .05996 L
.23426 .09234 L
.20345 .11697 L
.17721 .14311 L
.13202 .20306 L
.09751 .26898 L
.07517 .33054 L
.0587 .40198 L
.05097 .47821 L
.05255 .54885 L
.06152 .6121 L
.07574 .66629 L
.09873 .72286 L
.12638 .76928 L
.16132 .80975 L
.20323 .84097 L
.24571 .85829 L
.28546 .86347 L
.33227 .85673 L
.35798 .84698 L
.38089 .83437 L
.42036 .80269 L
.45712 .75855 L
.48697 .70647 L
.50075 .67402 L
.51135 .64252 L
.52515 .58229 L
.53158 .517 L
.53015 .4599 L
.52288 .40902 L
.50876 .35813 L
.48714 .31106 L
.46002 .27402 L
.44274 .25813 L
.42573 .24693 L
.38965 .23542 L
.36907 .23567 L
.35054 .24011 L
.31863 .25803 L
.28752 .29127 L
.26313 .33471 L
.24619 .38379 L
.23606 .4359 L
Mistroke
.23194 .49709 L
.23498 .55806 L
.24384 .61499 L
.26165 .6811 L
.29 .75019 L
.32481 .81016 L
.3634 .85928 L
.41317 .90525 L
.46484 .93777 L
.51406 .95708 L
.569 .96674 L
.62953 .96355 L
.69193 .94463 L
.74238 .91632 L
.79315 .8734 L
.84068 .81516 L
.87684 .75211 L
.8924 .71642 L
.90674 .67539 L
.91845 .63114 L
.92632 .58884 L
.93282 .5109 L
.92983 .44111 L
.91712 .36889 L
.89392 .30073 L
.86745 .25145 L
.8334 .20884 L
.79699 .17927 L
.76144 .16204 L
.71792 .15391 L
.67061 .16001 L
.62763 .1795 L
.59095 .20839 L
.55627 .24946 L
.52555 .30334 L
.50379 .3612 L
.49069 .41787 L
.484 .48613 L
.48437 .52448 L
.48736 .55919 L
.49917 .61928 L
.50806 .6472 L
.51997 .67565 L
.53336 .70034 L
.54927 .72307 L
.58145 .75429 L
.60094 .76596 L
.61974 .77292 L
.64077 .7761 L
.66332 .77424 L
Mistroke
.68254 .76824 L
.70275 .75717 L
.7209 .74246 L
.73658 .72534 L
.76264 .68424 L
.78383 .62962 L
.79649 .56958 L
.80111 .49714 L
.79596 .42482 L
.78261 .35675 L
.76132 .29078 L
.7353 .23398 L
.69788 .17407 L
.65616 .12503 L
.60444 .08148 L
.54455 .04879 L
.49059 .03279 L
.43004 .02853 L
.36529 .03976 L
.33001 .0531 L
.2989 .06951 L
.24242 .1123 L
.19515 .16475 L
.16083 .21697 L
.13005 .28103 L
.1066 .35294 L
.09311 .42289 L
.0881 .48821 L
.08985 .54672 L
.0985 .60783 L
.11473 .66689 L
.138 .71967 L
.16925 .76614 L
.20357 .79922 L
.23767 .81941 L
.27988 .83056 L
.30404 .83074 L
.32619 .82705 L
.36576 .81086 L
.40465 .78126 L
.43804 .74148 L
.46794 .68782 L
.48879 .62965 L
.50101 .57148 L
.50599 .512 L
.50431 .45843 L
.49521 .39908 L
.48007 .34775 L
.45687 .29864 L
.42614 .25734 L
Mistroke
.39602 .23212 L
.36034 .21633 L
.32058 .21404 L
.29849 .21959 L
.27892 .22889 L
.24339 .25823 L
.21436 .29879 L
.1943 .34216 L
.17826 .3979 L
.16924 .46308 L
.16865 .52862 L
.17531 .59175 L
.18761 .64971 L
.20788 .71189 L
.23654 .77375 L
.27299 .83117 L
.31899 .884 L
.36805 .92414 L
.41626 .95122 L
.47614 .97069 L
.51071 .97544 L
.54272 .97578 L
.6011 .96627 L
.66064 .94228 L
.71507 .90574 L
.74352 .87985 L
.76808 .85283 L
.80805 .79656 L
.84244 .72904 L
.86533 .66417 L
.87981 .60099 L
.88769 .5312 L
.88687 .45778 L
.87679 .38887 L
.86724 .35279 L
.85604 .32159 L
.82735 .26688 L
.80825 .24176 L
.78932 .22269 L
.75254 .19808 L
.71009 .18591 L
.6694 .18851 L
.63289 .20279 L
.601 .22575 L
.57011 .25989 L
.54517 .29996 L
.52662 .34211 L
.51075 .39647 L
.5012 .45975 L
.49993 .5209 L
Mistroke
.50551 .57673 L
.51935 .63625 L
.53912 .68672 L
.5618 .72581 L
.59069 .75996 L
.62623 .78619 L
.66654 .79997 L
.70171 .79978 L
.73946 .78671 L
.77707 .7581 L
.80751 .71907 L
.82123 .69431 L
.83434 .66386 L
.84553 .62891 L
.85349 .59356 L
.86121 .52377 L
.85995 .45597 L
.84902 .37993 L
.82671 .30124 L
.79956 .23835 L
.76275 .17702 L
.72138 .12656 L
.67905 .08832 L
.62456 .05394 L
.56156 .03098 L
.50013 .02381 L
.44349 .02992 L
.38474 .04964 L
.32542 .08518 L
.27471 .13107 L
.23414 .18199 L
.19486 .25036 L
.17698 .29218 L
.16338 .33236 L
.14611 .408 L
.14084 .45047 L
.13877 .48851 L
.13933 .52818 L
.14294 .56858 L
.1567 .63568 L
.1681 .66936 L
.18091 .69792 L
.19713 .72575 L
.21666 .75109 L
.23509 .76905 L
.25637 .78418 L
.27738 .79415 L
.29729 .79955 L
.33544 .79971 L
.37497 .78572 L
Mistroke
.40964 .75997 L
.44291 .71932 L
.46846 .67072 L
.48603 .61862 L
.49689 .56245 L
.50076 .50925 L
.49795 .44734 L
.48825 .39063 L
.47019 .33287 L
.44343 .27931 L
.41524 .24161 L
.37984 .21044 L
.33815 .19041 L
.31387 .18576 L
.29157 .18578 L
.24893 .19755 L
.21096 .22276 L
.18191 .25432 L
.15449 .29905 L
.1323 .3554 L
.11848 .41561 L
.11236 .47635 L
.11285 .53462 L
.12033 .5998 L
.1361 .66791 L
.16026 .73451 L
.19462 .80035 L
.23437 .85533 L
.27586 .89775 L
.33001 .93688 L
.36254 .95329 L
.39346 .96459 L
.45176 .97542 L
.51404 .97257 L
.57329 .95583 L
.63444 .92267 L
.68708 .87834 L
.73007 .82747 L
.76609 .76951 L
.79239 .71211 L
.8147 .64214 L
.82751 .57479 L
.83241 .5018 L
.8275 .4287 L
.81567 .37172 L
.7955 .31714 L
.76663 .26968 L
.74786 .24895 L
.72951 .23404 L
.69145 .21634 L
Mistroke
.65413 .21372 L
.6227 .22227 L
.5898 .24274 L
.55885 .27554 L
.53422 .31566 L
.51599 .35986 L
.50388 .40489 L
.49609 .45786 L
.49446 .51576 L
.49987 .57504 L
.51341 .63612 L
.53315 .68946 L
.55637 .73252 L
.58931 .77484 L
.61009 .79401 L
.63036 .80835 L
.66967 .82584 L
.71277 .83109 L
.7547 .82261 L
.77766 .81188 L
.7981 .7982 L
.83272 .76415 L
.86419 .71622 L
.88639 .66464 L
.90141 .60987 L
.91066 .54448 L
.91156 .46991 L
.90266 .3938 L
.89324 .35102 L
.88166 .31198 L
.85033 .23707 L
.8284 .19837 L
.80595 .16576 L
.76035 .11458 L
.70435 .07129 L
.64688 .04364 L
.59141 .03038 L
.53903 .02896 L
.4832 .03917 L
.43225 .05963 L
.38813 .08701 L
.34071 .12856 L
.29534 .18406 L
.25971 .24429 L
.23364 .30509 L
.21289 .37694 L
.20196 .44546 L
.19924 .50574 L
.20358 .56765 L
.21638 .62919 L
Mistroke
.23797 .68481 L
.26189 .72298 L
.29259 .75361 L
.32886 .77221 L
.3638 .77584 L
.38199 .77255 L
.40166 .76485 L
.42144 .75239 L
.43899 .73679 L
.4677 .69915 L
.48909 .6556 L
.506 .59981 L
.51535 .53469 L
.51599 .47701 L
.50915 .41496 L
.49563 .35815 L
.47769 .30974 L
.45024 .25865 L
.41381 .21278 L
.37433 .18053 L
.3349 .16163 L
.2912 .15389 L
.24414 .16034 L
.20146 .18049 L
.16544 .21038 L
.12862 .2582 L
.11099 .29076 L
.09703 .32406 L
.07806 .39165 L
.07151 .43235 L
.06822 .47051 L
.06755 .51209 L
.07009 .55654 L
.08298 .63589 L
.09474 .67905 L
.10858 .71803 L
.1281 .76143 L
.14972 .79988 L
.19571 .86121 L
.24431 .90636 L
.30216 .94179 L
.33664 .95524 L
.36925 .96327 L
.43036 .96681 L
.48804 .95657 L
.53809 .93646 L
.58952 .90344 L
.63985 .85607 L
.66504 .82499 L
.68582 .79437 L
Mistroke
.72008 .72934 L
.74427 .66349 L
.75948 .59961 L
.76749 .53225 L
.76787 .47659 L
.76177 .41913 L
.74819 .3635 L
.72654 .31307 L
.70061 .27594 L
.67349 .25205 L
.63889 .237 L
.6209 .23493 L
.60102 .23698 L
.56692 .2515 L
.53742 .27721 L
.52223 .29674 L
.50785 .32078 L
.48709 .37157 L
.47864 .4035 L
.47299 .43508 L
.46937 .47131 L
.46861 .51128 L
.47474 .57945 L
.4823 .6175 L
.49184 .65173 L
.51554 .71095 L
.54859 .7661 L
.58409 .80665 L
.62135 .83556 L
.6654 .85592 L
.71468 .86347 L
.74091 .86123 L
.76531 .85513 L
.80925 .83352 L
.85252 .79598 L
.87432 .76878 L
.89238 .74026 L
.91776 .68573 L
.93761 .6179 L
.94841 .5407 L
.94875 .46542 L
.94465 .42222 L
.93666 .37565 L
.92577 .33257 L
.91291 .29397 L
.88155 .22557 L
.83912 .16185 L
.81401 .13343 L
.78485 .10663 L
.72753 .06922 L
Mistroke
.69228 .05453 L
.65417 .04487 L
.62117 .04143 L
.585 .04274 L
.55369 .04818 L
.52036 .0585 L
.4625 .08843 L
.41093 .13031 L
.3689 .17849 L
.33053 .23907 L
.31242 .27646 L
.29807 .31284 L
.28592 .35149 L
.277 .38867 L
.26987 .43161 L
.26631 .47041 L
.26657 .53434 L
.27517 .5971 L
.29037 .6492 L
.30925 .68885 L
.33661 .725 L
.35385 .73974 L
.37051 .74953 L
.40243 .75786 L
.43631 .7529 L
.46795 .73471 L
.48452 .71891 L
.49867 .701 L
.5211 .66054 L
.53879 .60846 L
.54842 .5557 L
.5516 .5026 L
.54822 .4422 L
.5364 .37713 L
.51487 .31115 L
.49877 .27625 L
.48147 .24604 L
.44451 .19751 L
.42125 .17488 L
.39882 .1575 L
.35366 .13356 L
.30233 .12187 L
.25332 .12509 L
.20936 .14039 L
.17034 .16526 L
.13224 .20258 L
.10093 .247 L
.07714 .29432 L
.05588 .35663 L
.04174 .43067 L
Mistroke
.0376 .50422 L
.042 .57327 L
.05474 .64307 L
.07407 .70578 L
.10298 .76945 L
.14234 .82989 L
.18854 .87935 L
.24327 .91823 L
.29349 .93964 L
.35049 .94994 L
.41286 .94535 L
.46886 .92689 L
.49696 .91208 L
.52659 .89193 L
.55611 .86658 L
.58123 .84006 L
.62213 .78404 L
.64016 .75222 L
.65731 .71571 L
.68096 .64759 L
.69507 .58119 L
.70105 .51243 L
.69893 .45312 L
.68818 .3907 L
.67084 .34016 L
.64946 .30199 L
.6263 .27546 L
.59813 .25663 L
.56673 .24904 L
.53234 .25537 L
.50262 .27411 L
.48742 .28953 L
.47225 .31008 L
.44922 .35662 L
.43406 .40923 L
.42586 .47222 L
.42589 .52976 L
.43379 .59479 L
.44202 .63168 L
.45356 .66964 L
.48123 .73363 L
.50034 .76628 L
.52025 .79411 L
.54586 .82306 L
.57206 .84643 L
.5962 .86333 L
.62349 .87781 L
.67314 .89291 L
.70191 .89548 L
.73235 .89336 L
Mistroke
.78574 .87709 L
.83228 .84808 L
.85669 .82607 L
.87775 .8023 L
.91181 .75099 L
.94048 .68702 L
.95858 .62361 L
.96861 .5602 L
.97148 .48831 L
.96484 .41047 L
.94822 .33498 L
.93454 .29427 L
.91917 .25824 L
.88098 .19241 L
.85584 .1604 L
.83095 .13476 L
.7823 .09787 L
.72519 .0721 L
.66896 .06216 L
.6167 .06558 L
.56905 .07939 L
.52017 .10509 L
.4774 .13882 L
.442 .17678 L
.40602 .22839 L
.37432 .29155 L
.3523 .35545 L
.33909 .41637 L
.3326 .48447 L
.33442 .54567 L
.34221 .59639 L
.35657 .64502 L
.37831 .68894 L
.40665 .72303 L
.43387 .74104 L
.46539 .74835 L
.49921 .74147 L
.52876 .72186 L
.54299 .70683 L
.55739 .68666 L
.57071 .66187 L
.58137 .63544 L
.59558 .58026 L
.60183 .52365 L
.60053 .45729 L
.58952 .38569 L
.57253 .32634 L
.54687 .26641 L
.51607 .21515 L
.48315 .1746 L
Mistroke
.43934 .13584 L
.38715 .10655 L
.33507 .09235 L
.28619 .09153 L
.23481 .10383 L
.18239 .13189 L
.13731 .17168 L
.10124 .21821 L
.06671 .28323 L
.05135 .32414 L
.04005 .36417 L
.02707 .44134 L
.02433 .48571 L
.02469 .52611 L
.02804 .56895 L
.03487 .61343 L
.05523 .68956 L
.0709 .72916 L
.08809 .76374 L
.11108 .80078 L
.13546 .83207 L
.1849 .87812 L
.23464 .90724 L
.29134 .92393 L
.32402 .92645 L
.35422 .92434 L
.39383 .91507 L
.43038 .89962 L
.46179 .88053 L
.4941 .85446 L
.52623 .82066 L
.55667 .77909 L
.5813 .73556 L
.59991 .6933 L
.61496 .64846 L
.62528 .60623 L
.63263 .55965 L
.63591 .51111 L
.63509 .47026 L
.63137 .43387 L
.62418 .39652 L
.61313 .36014 L
.59652 .32368 L
.57806 .29612 L
.55513 .27346 L
.52862 .25871 L
.50477 .25406 L
.48229 .25664 L
.45827 .26715 L
.43401 .28719 L
Mistroke
.41573 .31047 L
.39845 .3422 L
.38407 .38152 L
.37459 .42295 L
.36948 .46526 L
.36824 .50587 L
.37103 .55443 L
.37794 .60104 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00g03oool00`3ooml0W4P0000000020000000307Bo
o`3oool0oooo0<`0oooo003N0?ooo`030?noM00007@0_ooo0<l0oooo003N0?ooo`030?oo_`1d0000
M;oo0<l0oooo003N0?ooo`030?oog`2LB000B9cO0<l0oooo003O0?ooo`030=nLB000000000000080
000000<0M;oo0?ooo`3oool00P3oool01@3o_g@000000000000004P0W=oo0080oooo00<0oono07@0
000000000P0000003@18W=l0oooo0?ooo`3oool0_g@00000000004P0W=oo0?ooo`3o_g@000000000
B02Lgol00P3oool0102oM00000000000B02Lgol20?ooo`050?noM000000000000000B02Lgol00`3o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000000007Bo09H0oooo003O0?ooo`070?noM00004P0
W=oo0?ooo`3ooml0W4P0001d_`020?ooo`0?0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`3oool0
oooO09a8001d_ol0oooo0?oOW0180000M;oo0080oooo01L0gia80018W03Ooml0W7BL0=ooo`3o_g@0
001809cOg`2LM9`0gooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0
B000001d_`020?ooo`030?noM00007@0_ooo0080oooo00@0gia80018W03O_g@0M;ooU@3oool00=l0
oooo00<0oono07@0001d_ol00P3oool01`3ooml0W4P004RLg`3oool0gia80018W03Oool00P3oool0
2P3ogi`0B00004RLg`3oool0_gAd0;ooo`3oool0oono07@0001d_ol20?ooo`030?noM00004P0W=oo
0080oooo00<0oono07@0001d_ol00`3oool00`3o_g@0001809cOo`020?ooo`030=nLB000B9`0gooo
0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol0UP3o
ool00=l0oooo00<0oooO09a80018W=l00`3oool01P3ogi`0B01809cOo`3o_g@0001d0;ooo`<0oooo
00<0gia80000M02oool00`3oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo
00<0_g@0001d_`3oool00P3oool00`3ookl0M00004RLg`020?ooo`030?noM00007@0_ooo00<0oooo
00/0gia80000M02oool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`2F0?ooo`00h03oool0
0`3OW4P0001d0;ooo`020?ooo`060?oog`2LB000B9cO0?oo_`1d0000M;oo0`3oool00`3ogi`0B018
09cOo`020?ooo`030?noM00004P0W=oo00@0oooo00<0_g@00018W03Oool00P3oool00`3OW4P004RL
0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3ookl0M00007Boo`030?ooo`070?oOW01804P0W=oo
0?ooo`3OW4P004Q804Qd_`020?ooo`030;md0000M;l0oooo09D0oooo003P0?ooo`040?noM0000000
04RL0=ooo`80oooo00H0gia8001d_`3oool0gia80000M02oool20?ooo`0:0?oo_`1d0000M;oo0?oo
o`3ogi`0B01809cOo`3oool0giad09cOo`80oooo00<0gia80000B02Lgol00P3oool00`3ogi`0B018
09cOo`030?ooo`030=nLB00004P0W=oo0080oooo00<0gia80000M02oool00P3oool0303ookl0M000
07Boo`3oool0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;oooiD0oooo003P0?ooo`080?oo_`1d
0000M9bL04P0M02oool0oooO09a80000M;l20?ooo`0>0;md000007@0_ooo0?ooo`3o_g@0001d0;oo
o`3oool0omnL04P0B02Lgol0oooO09a8001d_ol20?ooo`030?oOW0180000B9cO0080oooo00<0oooO
09a80018W=l00`3oool00`3ogi`0B00004RLg`030?ooo`0@0;md000007@0_ooo0?ooo`3o_g@0001d
0;ooo`3oool0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOoiD0oooo003O0?ooo`090?oOW018
0000000004RLg`3ookl0M0000000000007@0_ooo00<0oooo00D0okmd000000000000000007Boo`03
0?ooo`070;md00000000000000000018W=l0oooo0?noM002000000040018W03Oool0oono07@000<0
000000H0M;oo0?noM000000000000018W03Oool30?ooo`0?0?noM000000000000000001d_ol0oooo
0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo09D0oooo003o0?ooo`40oooo00<0okmd
0000M02oool0[@3oool00?l0oooo0P3oool00`3OW7@0W=oo0?ooo`2/0?ooo`00n`3oool0103ookl0
M0000018W03Oool70?ooo`040?oo_`1d000004RL0=ooojH0oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo001S0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol0
0P3oool00`3OW4P00000000000030000000304RLg`3oool0oooo03H0oooo00@0_g@0000000000000
M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3o
ool0=P3oool0102oM00000000000001d_om00?ooo`040;md00000000000007Boo`<0oooo00<0omnL
04P0001d_ol00P3oool00`3ookl0M000000000020000000304RLg`3oool0oooo03H0oooo00@0_g@0
000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB0000000000000<0000000<0
B9cO0?ooo`3oool05@3oool00680oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oO
W0180000M;oo00<0oooo00<0okmd001d_`3oool00P3oool00`2oM7@0_ooo0?ooo`0e0?ooo`060=nL
B000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`040?ooo`030?noM0000000M;oo
03P0oooo00H0gia8001d_`3oool0omnL04P00018W=ln0?ooo`060=nLB000M;l0oooo0?oOW0180000
B9cO0P3oool00`3ogi`0B00007Boo`040?ooo`030?noM0000000M;oo03P0oooo00H0gia8001d_`3o
ool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00<0oooo00<0okmd001d_`3oool00P3oool0
0`2oM7@0_ooo0?ooo`0E0?ooo`00H@3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo
00P0oooo00<0okmd001d_`3oool0>03oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo
00P0oooo00<0oooO09a80000M;l0=`3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo
03`0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?oog`2LB00007Bo
03L0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?noM000M;l0oooo
01T0oooo001Q0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo203oool00`3o
_g@007Bo0?ooo`0g0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo203oool0
0`3OW4P004RL0=ooo`0f0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo>`3o
ool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<0gia80018W03Oool0
=P3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<0okmd001d_`3o
ool0603oool005@0oooo00<0oooO09a8000000001`0000001P18W=l0oooo0?ooo`3ooml0W4P0001d
_`<0oooo00<0gia80000B02Lgol02@3oool00`3o_g@0B9cO0?ooo`0Y0?ooo`030?oog`2LB0000000
00L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`030=nLB00004P0W=oo00P0oooo00<0
omnL04P0B02Lgol0=P3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo03/0oooo00<0
oooO09a80000M;l00`3oool00`3OW4P0001809cOo`080?ooo`030?oOW01804P0W=oo03H0oooo00<0
oooO09a80000M;l00`3oool00`3OW4P0001809cOo`090?ooo`030?noM018W=l0oooo01L0oooo001R
0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l02P3oool00`3OW4P0B9cO0?ooo`0f
0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0203oool00`3ookl0M00007Boo`0g
0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0?03oool00`2oM00004RL0=ooo`02
0?ooo`030?oOW0180000B9cO00P0oooo00<0oono07@0001d_ol0=`3oool00`2oM00004RL0=ooo`02
0?ooo`030?oOW0180000B9cO00X0oooo00<0gia804RLg`3oool05P3oool00680oooo00<0gia80000
B02Lgol00P3oool00`3ooml0W4P0001d_`0;0?ooo`030;md001d_ol0oooo03D0oooo00<0gia80000
B02Lgol00P3oool00`3ooml0W4P0001d_`090?ooo`030;md0000M;l0oooo03H0oooo00<0gia80000
B02Lgol00P3oool00`3ooml0W4P0001d_`0l0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a8
0000M;l02@3oool00`2oM00007Bo0?ooo`0f0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a8
0000M;l02`3oool00`2oM000M;oo0?ooo`0E0?ooo`00HP3oool00`3ogi`0B00004RLg`030?ooo`03
0;md0000B9`0gooo00X0oooo00<0omnL04P0M02oool0=@3oool00`3ogi`0B00004RLg`030?ooo`03
0;md0000B9`0gooo00P0oooo00<0gia80018W03Oool0=P3oool00`3ogi`0B00004RLg`030?ooo`03
0;md0000B9`0gooo03/0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`080?ooo`03
0=nLB000B9`0gooo03H0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`0:0?ooo`03
0?oOW01807@0_ooo01D0oooo001R0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03O
ool02P3oool00`3ooml0W4P007Boo`0e0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018
W03Oool0203oool00`3ogi`0B01809cOo`0f0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia8
0018W03Oool0>`3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00P0oooo00<0
omnL04P0B02Lgol0=P3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00X0oooo
00<0oooO09a8001d_ol05@3oool006<0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?oo
o`0:0?ooo`030?oo_`1d0000B9cO03H0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?oo
o`080?ooo`030?oo_`1d0000M;oo03L0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?oo
o`0l0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0203oool00`3ookl0M00007Bo
o`0g0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool02P3oool00`3ookl0M00004RL
g`0E0?ooo`00I03oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`L0oooo00L0okmd0018W03Oool0
oooo0=nLB00004P0W=oo03L0oooo00H0gia80000M02oool0oooO09a80018W=l:0?ooo`030;md0000
M;l0oooo03L0oooo00H0gia80000M02oool0oooO09a80018W=ln0?ooo`060=nLB00007@0_ooo0?oo
g`2LB000B9cO2P3oool00`2oM00007Bo0?ooo`0g0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO
1`3oool01`3o_g@004RL0=ooo`3oool0gia80000B02Lgol05@3oool006D0oooo00@0gia800000000
000007Bo2@3oool01@3ogi`0B000000000000000M;oo03T0oooo00@0gia800000000000007Bo2@3o
ool01@3ookl0M0000000000007@0_ooo03P0oooo00@0gia800000000000007Bo@03oool0103OW4P0
000000000000M;l90?ooo`050?oo_`1d000000000000M02oool0>03oool0103OW4P0000000000000
M;l90?ooo`050?oOW018000000000000001d_ol05P3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool004/0ooooo`00001R000000@0oooo001;0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0080oooo001;0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
0:d0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0:d0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0Z@3oool<00000:P0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool0U`3ooolV00000:00oooo00<000000?ooo`3o
ool00P3oool004/0oooo00<000000?ooo`3oool0T03ooolN000000X0oooo4`00002B0?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo08P0oooo9P0000040?oooal00000S03o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`240?ooo`P000001P3oool;
000000X0oooo6P0000000`3oool000000000000C000008H0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool0P03oool<000000<0oooo2P00000A0?ooo`/000004P3oool:0000
00030?ooo`000000000000P00000P@3oool00`000000oooo0?ooo`020?ooo`00B`3oool2000007d0
oooo6P00000@0?ooo`H0000000<0oooo0000000000002P00000A0?ooo`T000001@3oool8000007/0
oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`1g0?ooobH000001`3oool5000000030?oo
o`0000000000008000001`3oool8000000`0oooo6P00001j0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo07@0oooo2000000:0?ooo`h000000`3oool5000000030?ooo`00
0000000000L0000000<0oooo0000000000000P0000020?ooo`030000003oool0oooo00P0oooo2000
00030?ooob<00000M`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1^
0?ooo``000002P3oool2000000030?ooo`000000000000@000001`3oool500000080oooo3@000005
0?ooo`030000003oool0oooo00X0oooo2@0000000`3oool000000000000D000000@0oooo3000001c
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo06/0oooo1`0000000`3o
ool0000000000003000000X0oooo0P0000000`3oool0000000000003000000l0oooo2`000000103o
ool000000000000000050?ooo`030000003oool0oooo00`0oooo3`00000:0?ooo`L000002P3oool8
000006l0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0J@3oool60000
00030?ooo`000000000000@000002P3oool2000000030?ooo`000000000000<000004@3oool50000
00030?ooo`000000000000X000000P3oool00`000000oooo0?ooo`090?ooo`d000004P3oool70000
00T0oooo2P00001[0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo06H0
oooo1@0000030?ooo`l000000P3oool00`000000oooo0000000400000140oooo1@000000103oool0
00000000000000030?ooo`80000000<0oooo0000000000000P000000103oool00000000000000008
0?ooo`D0000000<0oooo0000000000001P000000103oool0000000000000000B0?ooo`L000002@3o
ool;000006P0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0I03oool4
000000@0oooo7000000=0?ooo`D0000000@0oooo00000000000000001`3oool2000000030?ooo`00
000000000080000000<0oooo0000000000001@3oool:000000D0oooo0`000000103oool000000000
0000000B0?ooo`@0000000<0oooo0000000000002@3oool6000000030?ooo`000000000000800000
IP3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1R0?ooo`<000000`3o
oolO000000040?ooo`0000000000000000P0oooo1@000000103oool0000000000000000;0?ooo`80
000000<0oooo0000000000000P000000103oool000000000003oool9000000T0oooo10000000103o
ool0000000000000000A0?ooo`l000000P3oool5000000<0oooo1000001S0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo0600oooo3`00000:0?oooaD00000103oool80000
00l0oooo0P0000000`3oool000000000000:000000h0oooo200000070?ooob0000000`3oool50000
0600oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0GP3oool>000000`0
oooo1`0000040?oooaD000004`3oool7000000040?ooo`000000000000000180oooo1@000000103o
ool000000000003ooolX000000030?ooo`000000000000<00000GP3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`1L0?ooo`H000000`3oool5000000d0oooo0P000000103o
ool0000000000000000=0?ooo``000005P3oool700000080oooo0P00000C0?ooo`030000003oool0
000001<000000P3oool5000000030?ooo`000000oooo00H0oooo4@00001L0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo05X0oooo100000050?ooo`<0000000<0oooo0000
003oool0303oool700000140oooo2`00000B0?ooo`@0000000<0oooo000000000000100000020?oo
o`030000003oool0oooo0140oooo2P000000103oool0000000000000000;0?ooo`030000003oool0
000000@000002P3oool=000005/0oooo00<000000?ooo`3oool00P3oool002l0oooo00@0_g@00000
00000000M;oo0`3oool00`3ogi`0B00007Boo`050?ooo`030?oog`2LB000B9cO00X0oooo00<00000
0?ooo`3oool0F03oool4000000H0oooo0P0000000`3oool000000000000=0?ooo`80000000@0oooo
0000003oool000004@3oool700000080oooo1P00000>0?ooo`@0000000<0oooo0000000000000`3o
ool5000000030?ooo`000000000000d0oooo2`000000103oool0000000000000000?0?ooo`D00000
00<0oooo0000003oool02P3oool=000005T0oooo00<000000?ooo`3oool00P3oool002h0oooo00H0
gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00H0oooo00<0gia80018W03O
ool02@3oool00`000000oooo0?ooo`1F0?ooo`@000001`3oool2000000030?ooo`000000oooo00`0
oooo0`000000103oool0000000000000000A0?ooo`H000000P3oool3000000030?ooo`0000000000
00@000002P3oool4000000040?ooo`0000000000000000H0oooo1@0000000`3oool000000?ooo`09
0?ooo`T0000000<0oooo0000000000001@00000A0?ooo`@0000000<0oooo0000003oool02`3oool8
000000030?ooo`000000000000800000E`3oool00`000000oooo0?ooo`020?ooo`00;@3oool00`3o
oml0W4P004RLg`020?ooo`030?noM00004P0W=oo00X0oooo00<0omnL04P0B02Lgol02@3oool00`00
0000oooo0?ooo`1D0?ooo`@000001`3oool3000000030?ooo`000000oooo00@0oooo2P0000000`3o
ool000000000000200000100oooo1@0000000`3oool000000?ooo`050?ooo`80000000<0oooo0000
00000000100000060?ooo`@0000000H0oooo00000000000000000?ooo`0000080?ooo`L000001P3o
ool9000000070?ooo`00000000000000003oool000000?ooo`02000000030?ooo`000000oooo0140
oooo0`0000000`3oool000000000000;0?ooo`D000000P3oool6000005H0oooo00<000000?ooo`3o
ool00P3oool002d0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool50?ooo`03
0?noM0000000000000@0000000<004RL0=ooo`3oool01P3oool00`000000oooo0?ooo`1B0?ooo`D0
00001`3oool2000000030?ooo`000000000001L00000303oool6000000030?ooo`000000oooo00P0
oooo2@0000020?ooo`P000000`3oool00`000000oooo0?ooo`080?ooo`L000000P3oool<000000D0
oooo00<000000?ooo`0000000`00000B0?ooo`@0000000<0oooo0000003oool02P3oool00`000000
oooo00000002000000@0oooo1@00001D0?ooo`030000003oool0oooo0080oooo000P0?ooo`030?oo
g`2LB000000000L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`030=nLB00004P0W=oo
00D0oooo00<0oooO09a8B02Lgol00P3oool00`2oM00007Bo0?ooo`080?ooo`030000003oool0oooo
0500oooo1@0000080?oooa/000000P3oool3000000P0oooo00<000000?ooo`0000001@00000=0?oo
o`T0000000<0oooo0000000000000`0000040?ooo`030000003oool0oooo00T0oooo00H000000?oo
o`000000oooo0000003oool5000000040?ooo`00000000000?ooo`8000002@3oool2000000030?oo
o`0000000000008000004P3oool3000000030?ooo`000000000000X0oooo1@0000060?ooo`@00000
DP3oool00`000000oooo0?ooo`020?ooo`00;P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW018
0000B9cO00H0oooo00L0oono07@0M02oool0oooo0?noM000B9`0gooo00P0oooo0`00001>0?ooo`D0
00001@3ooolX000000@0oooo00<000000?ooo`0000001000000A0?ooo`T0000000<0oooo0000003o
ool01@3oool00`000000oooo0?ooo`0:0?ooo`P0000000@0oooo000000000000oooo0P00000=0?oo
o`060000003oool000000000003oool000003P3oool;000000X0oooo100000070?ooo`@00000C@3o
ool4000000@0oooo000^0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l01`3oool0
1P3ogi`0B4RL0=ooo`3ogi`0B01809cOo`P0oooo00<000000?ooo`3oool0C03oool5000000<0oooo
3000000<0?ooo`030000003oool0000000<000000`3oool?000000060?ooo`00000000000000003o
ool000004`3oool9000000L0oooo00<000000?ooo`3oool02`3oool5000000040?ooo`0000000000
0?ooo`800000403oool01@000000oooo000000000000oooo008000001`3oool5000000030?ooo`00
0000000001P000001`3oool4000004h0oooo00<000000?ooo`3oool00P3oool002h0oooo00<0omnL
04P00018W=l00`3oool00`2oM00004RL0=ooo`070?ooo`050?noM000M;l0oooO09a80018W=l0203o
ool00`000000oooo0?ooo`1:0?ooo`H0000000<0oooo000000000000200000000`3oool000000000
000=0?ooo`040000003oool000000?ooo`800000203oool700000080oooo1@0000000`3oool00000
0?ooo`0B0?ooo`030000003oool0000000P000001P3oool00`000000oooo0?ooo`090?ooo`800000
00<0oooo0000000000001P00000C0?ooo`040000003oool0000000000080oooo00<000000?ooo`00
0000600000040?ooo`T000001`3oool5000004`0oooo00<000000?ooo`3oool00P3oool002h0oooo
00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`080?ooo`040=nLB018W=l0_g@0001d
_`P0oooo00<000000?ooo`3oool0B03oool4000000030?ooo`000000000000/0000000<0oooo0000
003oool03@3oool010000000oooo0000003oool2000000`0oooo3P00000A0?ooo`X0000000@0oooo
0000000000000000103oool00`000000oooo0?ooo`070?ooo`80000000@0oooo000000000000oooo
1P0000000`3oool000000?ooo`0B0?oooa400000203oool4000000030?ooo`000000oooo00h00000
1`3oool5000004/0oooo00<000000?ooo`3oool00P3oool002l0oooo00<0omnL04P0001d_ol00P3o
ool00`3OW4P007Bo0?ooo`090?ooo`040=nLB01dM7@0001d0;ooo`L0oooo00<000000?ooo`3oool0
A`3oool2000000030?ooo`000000oooo00L000000`3oool3000000030?ooo`000000oooo00d0oooo
00<000000?ooo`0000000`00000@0?ooo`H0000000D0oooo00000000000000000?ooo`02000000h0
oooo0P0000000`3oool0000000000002000000050?ooo`00000000000?ooo`0000000P3oool30000
0080oooo00<000000?ooo`3oool01@3oool2000000040?ooo`00000000000?ooo`80000000<0oooo
000000000000100000000`3oool000000000000@0?ooo`/00000403oool4000000030?ooo`000000
oooo00X0oooo1P0000060?ooo`D00000B@3oool00`000000oooo0?ooo`020?ooo`00<03oool01P3O
W4P0001d0;ooo`3ooml0W4P004RLg`/0oooo00<0_g@00000B02Lgol01`3oool00`000000oooo0?oo
o`160?ooo`80000000<0oooo0000000000001@0000050?ooo`D000003P3oool00`000000oooo0000
000200000140oooo00<000000?ooo`0000001`000000103oool000000000003oool2000000X0oooo
200000040?ooo`@0000000<0oooo0000003oool00`0000060?ooo`030000003oool0oooo00800000
00<0oooo0000003oool00P0000040?ooo`<000000P3oool00`000000oooo0?ooo`0;0?ooo`@00000
00<0oooo0000000000000`0000020?ooo`030000003oool0oooo00l0oooo100000000`3oool00000
0?ooo`0:0?ooo`T000000`3oool5000004P0oooo00<000000?ooo`3oool00P3oool00340oooo00@0
gia800000000000007Bo303oool00`3ooml0W4P004RLg`070?ooo`030000003oool0oooo04@0oooo
0P0000020?ooo`H000001@3oool5000000h0oooo0P000000103oool0000000000000000A0?ooo`03
0000003oool000000080000000@0oooo000000000000oooo1`0000000`3oool00000000000070?oo
o`80000000<0oooo0000003oool00P0000080?ooo`030000003oool0000000<0000000<0oooo0000
003oool0103oool01@000000oooo000000000000oooo00@000001`3oool300000080oooo00<00000
0?ooo`3oool0203oool=00000080oooo00<000000?ooo`3oool03`3oool2000000040?ooo`000000
oooo000000/0oooo1`0000000`3oool00000000000020?ooo`<0000000<0oooo000000000000AP3o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`130?ooo`80000000<0oooo
000000000000100000060?ooo`030000003oool00000008000003P3oool00`000000oooo0?ooo`03
00000140oooo1@0000000`3oool000000?ooo`040?ooo`L0000000<0oooo000000000000103oool4
000000030?ooo`000000000000X0oooo0P0000000`3oool000000?ooo`0300000080oooo2@00000:
0?ooo`@0000000<0oooo0000003oool01P3oool500000080oooo0P0000040?ooo`<000000P3oool0
0`000000oooo0?ooo`0?0?ooo`80000000@0oooo0000003oool00000303oool3000000030?ooo`00
0000000000@0000000D0oooo00000000000000000?ooo`02000004D0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool0@P3oool2000000030?ooo`000000000000<000001`3o
ool00`000000oooo00000002000000T0oooo2`00000A0?ooo`80000000D0oooo000000000000oooo
000000080?ooo`L0000000<0oooo0000003oool010000000103oool0000000000000000=0?ooo`03
0000003oool000000080000000@0oooo000000000000oooo0P000000103oool0000000000000000>
0?ooo`<0000000<0oooo0000003oool00`3oool500000080oooo0P0000070?ooo`<000000P3oool0
0`000000oooo0?ooo`0?0?ooo`80000000@0oooo0000000000000000303oool4000000030?ooo`00
0000000000@0000000H0oooo00000000000000000?ooo`0000140?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo0400oooo0P000000103oool000000000003oool3000000L0
oooo7`00000;0?ooo`D0000000<0oooo0000003oool02@3oool:000000060?ooo`000000oooo0000
003oool000003`3oool2000000030?ooo`000000000000L000004@3oool3000000030?ooo`000000
000000D000000P3oool2000000X0oooo0`0000020?ooo`030000003oool0oooo00l0oooo0P000000
103oool0000000000000000<0?ooo`@000000`3oool4000000050?ooo`00000000000000003oool0
0P0000120?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo03l0oooo2@00
00070?ooo`80000000@0oooo0000000000000000103oool?000000030?ooo`000000000000X00000
0`3oool6000000030?ooo`000000oooo00`0oooo00<000000?ooo`000000200000000`3oool00000
0?ooo`0A0?ooo`L0000000<0oooo0000003oool04P3oool800000080oooo0P00000=0?ooo`<00000
0P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0000000800000303oool4000000@0oooo
1`000000103oool000000000000000100?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo03h0oooo200000090?ooo``00000103ooolM00000080oooo00<000000?ooo`3oool0
3@3oool2000000030?ooo`000000000000H000004`3oool6000000030?ooo`000000oooo01@0oooo
1P0000000`3oool000000000000A0?ooo`8000000P3oool00`000000oooo0?ooo`090?ooo`P00000
00@0oooo0000000000000000303oool4000000D0oooo1P000000103oool0000000000000000o0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo03d0oooo1@0000000`3oool0
0000000000090?ooo`D0000000<0oooo0000000000002@0000001`3oool000000?ooo`3oool00000
0?ooo`000000103oool400000080oooo100000000`3oool000000000000400000080oooo00<00000
0?ooo`3oool03`3oool3000000030?ooo`000000000000<0000000<0oooo0000003oool0403oool8
000000030?ooo`000000oooo0140oooo2@00000D0?ooo`<0000000@0oooo0000003oool0oooo6@00
00080?ooo`@000001P3oool500000080oooo0P00000n0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo03`0oooo1@0000000`3oool00000000000070?ooo`X000002P3oool2
000000040?ooo`000000oooo000000T0oooo1@0000000`3oool000000000000800000100oooo0P00
00020?ooo`80000000<0oooo0000000000000P0000000`3oool000000?ooo`0>0?ooo`80000000<0
oooo0000000000001@0000000`3oool000000?ooo`0?0?ooo`T0000000<0oooo0000003oool04`3o
ool600000080oooo3@0000020?ooo`80000000<0oooo0000000000002@0000020?ooo`030000003o
ool00000008000001P3oool500000080oooo0P00000m0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo03X0oooo1P0000000`3oool00000000000050?ooo`X00000303oool2
000000040?ooo`000000oooo000000l0oooo2P0000000`3oool000000000000=0?ooo`040000003o
ool000000?ooo`D0000000D0oooo00000000000000000?ooo`02000000`0oooo0P000000203oool0
00000000003oool000000?ooo`000000oooo0P0000000`3oool000000?ooo`0<0?ooo`<0000000<0
oooo0000003oool00`000000103oool000000000003oool200000100oooo3`0000080?ooo`l00000
00H0oooo000000000000oooo0000003oool3000000L0oooo100000020?ooo`800000?03oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0i0?ooo`@0000000<0oooo0000003o
ool00P0000040?ooo`80000000<0oooo0000000000001@00000=0?ooo`80000000@0oooo0000003o
ool00000403oool00`000000oooo0000000=000000T0oooo00@000000?ooo`000000oooo0P000000
0`3oool000000?ooo`02000000040?ooo`000000000000000080oooo00<000000?ooo`3oool01`3o
ool200000080oooo100000030?ooo`060000003oool000000000003oool000002`3oool7000000<0
oooo00@000000?ooo`00000000000P3oool00`000000oooo0?ooo`0;0?ooo`@0000000<0oooo0000
000000000`00000B0?ooo`<0000000<0oooo0000003oool0400000070?ooo`D0000000<0oooo0000
00000000>`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0h0?ooo`@0
000000<0oooo0000000000000P0000030?ooo`T0000000<0oooo0000003oool0303oool200000005
0?ooo`00000000000?ooo`000000403oool2000000040?ooo`00000000000?ooo``000001P3oool0
10000000oooo0000003oool2000000030?ooo`000000oooo00<0oooo00<000000?ooo`0000000`00
00000`3oool000000?ooo`060?ooo`8000000P3oool010000000oooo0?ooo`0000050?ooo`030000
003oool0000000<000002@3oool4000000030?ooo`000000oooo00D0oooo00@000000?ooo`000000
00000P3oool00`000000oooo0?ooo`080?ooo`<0000000D0oooo00000000000000000?ooo`020000
00030?ooo`00000000000180oooo1@0000060?ooo`X000002@3oool4000000030?ooo`0000000000
03X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0=`3oool400000003
0?ooo`0000000000008000000P3oool7000000050?ooo`00000000000?ooo`0000003@3oool20000
00050?ooo`00000000000?ooo`000000403oool2000000050?ooo`00000000000?ooo`0000000`3o
ool6000000030?ooo`000000000000800000103oool2000000050?ooo`00000000000?ooo`000000
1P3oool00`000000oooo00000003000000030?ooo`000000oooo00@0oooo0P0000020?ooo`030000
003oool0oooo008000001P3oool010000000oooo0000003oool3000000H0oooo0`0000020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo00@0
oooo200000040?ooo`80000000<0oooo0000000000004P3oool5000000L0oooo0P0000000`3oool0
000000000004000000T0oooo100000000`3oool000000000000i0?ooo`030000003oool0oooo0080
oooo001;0?ooo`800000=`3oool4000000030?ooo`0000000000008000000P3oool600000080oooo
0P0000000`3oool000000?ooo`0=0?ooo`@0000000<0oooo0000003oool03`3oool2000000050?oo
o`00000000000?ooo`0000001P3oool6000000030?ooo`00000000000080000000H0oooo00000000
0000oooo0000003oool2000000P0oooo0P0000001P3oool000000?ooo`000000oooo000000<0oooo
0P0000020?ooo`060000003oool0oooo0000003oool000001`3oool01`000000oooo0000003oool0
00000?ooo`000000103oool3000000030?ooo`000000000000T0oooo00D000000?ooo`000000oooo
000000020?ooo`040000003oool0oooo0?ooo`80000000@0oooo000000000000oooo0P0000070?oo
o`80000000<0oooo0000000000004P3oool5000000P0oooo0P0000000`3oool00000000000030000
00T0oooo100000000`3oool000000000000f0?ooo`<00000103oool004/0oooo00<000000?ooo`3o
ool0=@3oool4000000030?ooo`00000000000080000000<0oooo000000000000100000030?ooo`80
000000<0oooo0000003oool03@3oool<000000X0oooo00<000000?ooo`0000000P0000020?ooo`03
0000003oool0oooo00H0oooo0`000000203oool000000000003oool000000?ooo`000000oooo0P00
00000`3oool000000000000;0?ooo`060000003oool000000?ooo`000000oooo100000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool01P3oool3000000050?ooo`000000oooo
0000003oool0100000000`3oool000000?ooo`0;0?ooo`040000003oool0000000000080oooo00D0
00000?ooo`00000000000?ooo`02000000030?ooo`000000000000X0oooo0P0000000`3oool00000
0000000A0?ooo`030000003oool0000000<000002@3oool8000000P0oooo100000000`3oool00000
0000000g0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo03@0oooo0`00
00020?ooo`@0000000<0oooo000000000000100000030?ooo`80000000<0oooo0000003oool03@3o
oolG000000070?ooo`00000000000?ooo`000000oooo0000000;0?ooo`<0000000D0oooo0000003o
ool000000?ooo`02000000030?ooo`000000000000d0oooo00@000000?ooo`000000oooo10000000
103oool000000000003oool2000000<0oooo00<000000?ooo`3oool0203oool2000000030?ooo`00
0000oooo0080000000@0oooo0000003oool000003P3oool01@000000oooo000000000000oooo0080
000000@0oooo000000000000oooo0P00000=0?ooo`<0000000<0oooo0000003oool0403oool00`00
0000oooo00000003000000/0oooo1`0000060?ooo`D000000P3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo03<0oooo0`0000030?ooo`80
000000<0oooo0000000000000P0000000`3oool000000?ooo`030?ooo`80000000<0oooo0000003o
ool02P3ooolI000000080?ooo`00000000000000003oool000000?ooo`00000>0?ooo`X000003`3o
ool010000000oooo0000003oool5000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool0
2@3oool2000000030?ooo`00000000000080000000<0oooo0000003oool03`3oool00`000000oooo
00000004000000030?ooo`000000000000l0oooo00H000000?ooo`00000000000?ooo`00000A0?oo
o`040000003oool000000?ooo`800000303oool6000000H0oooo1@0000020?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0<P3oool30000
00<0oooo0P0000000`3oool0000000000004000000@0oooo0P0000000`3oool000000?ooo`070?oo
ob@000004@3oool4000000040?ooo`000000000000000100oooo00@000000?ooo`000000oooo0P00
00000`3oool00000000000060?ooo`030000003oool0oooo00X0oooo100000000`3oool000000000
000B0?ooo`@0000000<0oooo0000000000004P3oool01P000000oooo000000000000oooo000000@0
oooo1P0000070?ooo`040000003oool000000?ooo`8000002`3oool8000000D0oooo2000000d0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0340oooo0`0000030?ooo`P0
00001P3oool2000000030?ooo`000000oooo00@0oooo4P0000060?ooo`D000000P3oool:000000l0
oooo2@00000@0?ooo`@0000000<0oooo0000000000000P0000050?ooo`030000003oool0oooo00T0
oooo10000000103oool0000000000000000A0?ooo`<0000000D0oooo000000000000oooo0000000C
0?ooo`d000000P3oool5000000<0oooo0`0000000`3oool000000000000;0?ooo`P000001@3oool8
000003<0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0<03oool30000
00<0oooo1`0000070?ooo`80000000<0oooo0000003oool00`3oool=000000030?ooo`000000oooo
00l0oooo3`00000;0?ooo`<0000000<0oooo0000000000000P000000103oool0000000000000000=
0?ooo`050000003oool000000000003oool0100000000`3oool000000?ooo`030?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`0000001@0000000`3oool000000?ooo`0=0?ooo`80000000D0
oooo00000000000000000?ooo`02000000030?ooo`000000oooo00`0oooo8P00000<0?ooo`P00000
1@3oool800000380oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0;`3o
ool3000000@0oooo1P0000070?ooo`80000000<0oooo0000003oool00P3oool8000000<0oooo0P00
00000`3oool000000000000A0?ooo`80000000@0oooo000000000000oooo200000000`3oool00000
000000080?ooo`<0000000<0oooo0000003oool01P0000000`3oool000000?ooo`0:0?ooo`050000
003oool000000000003oool00`0000001@3oool000000000003oool0000000<0oooo00<000000?oo
o`3oool01`3oool01@000000oooo000000000000oooo00<0000000@0oooo0000003oool00000303o
ool500000080oooo00H000000?ooo`00000000000?ooo`00000:0?ooo`80000000<0oooo00000000
00002P0000080?ooo`T0000000<0oooo0000000000000P00000<0?ooo`P000001@3oool300000003
0?ooo`000000000000800000<@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`0^0?ooo`<00000103oool5000000P0oooo100000020?ooo`P00000103oool2000000040?oo
o`000000000000000140oooo00@000000?ooo`000000oooo0P0000040?ooo`H0000000<0oooo0000
000000001@3oool3000000040?ooo`000000oooo000000<0oooo1P0000090?ooo`050000003oool0
00000000003oool00`0000000`3oool000000?ooo`02000000050?ooo`000000oooo0?ooo`000000
203oool02@000000oooo000000000000oooo0000003oool000000?ooo`02000000030?ooo`000000
oooo00T0oooo0P000000103oool000000000000000040?ooo`060000003oool000000000003oool0
00001`3oool;000000060?ooo`00000000000000003oool000003P3oool9000000`0oooo10000000
0`3oool0000000000002000000@0oooo0`0000000`3oool000000000000200000300oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0;@3oool3000000@0oooo1@0000080?oo
o`@000000P3oool7000000D0oooo0P000000103oool0000000000000000A0?ooo`040000003oool0
00000?ooo`8000001`3oool6000000030?ooo`000000oooo0080oooo00<000000?ooo`0000000P00
00000`3oool000000?ooo`040?ooo`L000001P3oool02@000000oooo000000000000oooo0000003o
ool000000?ooo`03000000070?ooo`00000000000?ooo`000000oooo000000070?ooo`060000003o
ool000000000003oool000000`3oool01P000000oooo000000000000oooo000000P0oooo0P000000
0`3oool00000000000060?ooo`030000003oool0oooo00<000001@3oool9000000D0oooo00<00000
0?ooo`0000000P00000A0?ooo`P000002`3oool4000000030?ooo`0000000000008000000`3oool4
000000030?ooo`000000000000800000;`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`00
0000oooo0?ooo`0]0?ooo`800000103oool5000000T0oooo0`0000000`3oool00000000000050000
00H0oooo0P000000103oool000000?ooo`00000A0?ooo`040000003oool000000?ooo`8000002P3o
ool9000000070?ooo`00000000000?ooo`000000oooo000000060?ooo`80000000D0oooo00000000
0000oooo000000040?ooo`080000003oool0oooo0000003oool000000?ooo`0000040?ooo`800000
00H0oooo00000000000000000?ooo`0000060?ooo`060000003oool000000000003oool000001@3o
ool01P000000oooo000000000000oooo000000D0oooo0P0000000`3oool00000000000090?ooo`06
0000003oool000000000003oool000000P3oool7000000X0oooo00<000000?ooo`0000000P00000A
0?ooo`030000003oool0000000H000002@3oool5000000030?ooo`0000000000008000000`3oool4
000000030?ooo`000000000000800000;P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`00
0000oooo0?ooo`0/0?ooo`800000103oool5000000T0oooo00<000000?ooo`0000001`0000070?oo
o`040000003oool000000?ooo`<00000403oool3000000030?ooo`000000000000h0oooo20000000
103oool000000?ooo`0000090?ooo`060000003oool000000000003oool000000P3oool00`000000
oooo0?ooo`03000000030?ooo`000000oooo00D0oooo0P0000000`3oool0000000000002000000H0
oooo0`0000000`3oool000000?ooo`060?ooo`80000000@0oooo0000003oool000000`3oool20000
00030?ooo`000000000000/0oooo00D000000?ooo`00000000000?ooo`07000000d0oooo00<00000
0?ooo`0000000P00000A0?ooo`80000000<0oooo0000000000001@0000080?ooo`<0000000@0oooo
0000003oool0oooo100000020?ooo`<000000P3oool4000002d0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool0:`3oool2000000@0oooo1@0000090?ooo`T000002@3oool2
000000040?ooo`0000000000000000/0oooo20000000103oool000000?ooo`00000@0?ooo`L00000
00<0oooo0000003oool02P3oool01@000000oooo000000000000oooo008000000P3oool300000003
0?ooo`000000oooo00L0oooo0P000000103oool000000?ooo`0000050?ooo`80000000<0oooo0000
000000002@3oool2000000050?ooo`000000oooo0000003oool00P0000000`3oool000000000000=
0?ooo`030000003oool0000000D000004@3oool2000000030?ooo`00000000000140oooo0`000000
0`3oool0000000000005000000L0oooo100000030?ooo`@0000000<0oooo0000000000000P000002
0?ooo`<00000;@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0Z0?oo
o`800000103oool5000000T0oooo2000000:0?ooo`80000000@0oooo0000000000000000203oool4
000000<0oooo2000000B0?ooo`L000003@3oool00`000000oooo00000003000000040?ooo`000000
00000?ooo`8000002@3oool2000000030?ooo`0000000000008000000`3oool2000000030?ooo`00
0000000000X0oooo00@000000?ooo`000000oooo100000000`3oool000000000000>0?ooo`H00000
4`3oool01@000000oooo0000003oool000000180oooo0`0000000`3oool0000000000006000000D0
oooo00<000000?ooo`0000000P0000040?ooo`<0000000<0oooo0000000000000P0000020?ooo`<0
0000;03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0Y0?ooo`800000
103oool5000000X0oooo1P00000;0?ooo`80000000<0oooo0000003oool00P0000040?oooa800000
00@0oooo00000000000000003P3oool2000000030?ooo`000000000000<000003P3oool01@000000
oooo000000000000oooo0080000000<0oooo0000000000002`3oool2000000060?ooo`0000000000
0?ooo`000000oooo0P0000000`3oool000000000000<0?ooo`030000003oool0000000<0000000<0
oooo0000000000003P3oool4000000040?ooo`0000000000000001<0oooo00<000000?ooo`000000
0P00000A0?ooo`80000000D0oooo00000000000000000?ooo`04000000030?ooo`000000oooo00@0
oooo1@0000040?ooo`<0000000<0oooo0000000000000P0000000`3oool0000000000002000002/0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0:@3oool2000000<0oooo
1@00000:0?ooo`H000002`3oool010000000oooo0000003oool3000000<0oooo100000000`3oool0
00000000000E000000X0oooo0P0000000`3oool0000000000005000000d0oooo1`0000000`3oool0
00000?ooo`0;0?ooo`80000000H0oooo000000000000oooo0000003oool3000000h0oooo0P000000
103oool0000000000000000>0?ooo`@0000000@0oooo0000003oool0oooo0`00000>0?ooo`X00000
4@3oool2000000030?ooo`000000000000<0oooo1P0000040?ooo`@000001P3oool600000080oooo
0`00000[0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02P0oooo0P00
00040?ooo`@000002P3oool6000000`0oooo0P0000001@3oool00000000000000000oooo00d00000
0P3oool00`000000oooo00000003000000<0oooo2P0000060?ooo`80000000@0oooo000000000000
oooo1P00000<0?ooo`80000000<0oooo0000000000000`00000>0?ooo`T000003`3oool300000004
0?ooo`0000000000000000`0oooo0`0000030?ooo`030000003oool0oooo00<000001@3oool?0000
00030?ooo`000000oooo00<000003`3oool01P000000oooo000000000000oooo000000<0oooo00H0
00000?ooo`00000000000?ooo`0000030?ooo`D000001P3oool600000080oooo0`00000Z0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02L0oooo0P0000040?ooo`<00000
00<0oooo0000003oool0203oool5000000d0oooo00D000000?ooo`00000000000?ooo`0<000000H0
oooo0`0000000`3oool00000000000080?ooo`P000000P3oool2000000050?ooo`00000000000?oo
o`0000000P3oool5000000/0oooo00<000000?ooo`0000001@00000>0?ooo`040000003oool00000
0?ooo`@000003`3oool00`000000oooo0000000200000080oooo00<000000?ooo`3oool02@3oool3
000000D0oooo00<000000?ooo`3oool00`0000020?ooo`80000000<0oooo0000000000005@00000=
0?ooo`80000000@0oooo00000000000000000`3oool6000000<0oooo1@0000060?ooo`H000000P3o
ool3000002T0oooo00<000000?ooo`3oool00P3oool004/0oooo0P00000W0?ooo`<000000`3oool5
000000T0oooo1@00000>0?ooo`d000002@3oool2000000040?ooo`0000000000000000`0oooo2P00
0000103oool000000?ooo`0000030?ooo`D000002@3oool010000000oooo0000003oool5000000l0
oooo1`00000>0?ooo`040000003oool000000?ooo`<0000000<0oooo000000000000203oool40000
00L0oooo00@000000?ooo`000000oooo300000080?ooo``000002`3oool2000000030?ooo`000000
000000D0oooo1P0000020?ooo`@000001P3oool3000000050?ooo`00000000000000003oool00`00
000W0?ooo`<00000103oool004/0oooo00<000000?ooo`3oool09P3oool2000000<0oooo1@000009
0?ooo`H000003@3oool:000000d0oooo0`0000000`3oool000000?ooo`0>0?ooo`T0000000<0oooo
0000003oool0103oool3000000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool01@000000
0`3oool000000000000?0?ooo`D0000000<0oooo0000003oool0303oool2000000070?ooo`000000
oooo0000003oool000000?ooo`02000000H0oooo0`0000090?ooo`X000003`3oool00`000000oooo
0000000;000000P0oooo00<000000?ooo`0000000`0000050?ooo`070000003oool000000000003o
ool000000?ooo`05000000H0oooo1P0000020?ooo`<00000:03oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`0U0?ooo`8000000`3oool5000000T0oooo1P00000=0?ooo`T0
00003P3oool2000000030?ooo`00000000000180oooo200000080?ooo`@000001P3oool00`000000
oooo00000003000000040?ooo`00000000000?ooo`8000003@3oool7000000030?ooo`000000oooo
00X0oooo0P0000000`3oool00000000000020?ooo`80000000<0oooo0000000000001@3oool30000
00T0oooo2000000C0?ooo`060000003oool000000?ooo`000000oooo2@0000070?ooo`80000000@0
oooo00000000000000001@3oool6000000030?ooo`000000000000<000001P3oool600000080oooo
0`00000W0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02@0oooo0`00
00020?ooo`H000001`3oool7000000h0oooo0`000000103oool0000000000000000?0?ooo`800000
00@0oooo00000000000000004`3oool7000000T0oooo1@0000030?ooo`030000003oool000000080
000000@0oooo0000003oool0oooo0P0000000`3oool000000000000;0?ooo`030000003oool00000
00<0000000D0oooo000000000000oooo000000090?ooo`80000000<0oooo000000000000103oool2
000000030?ooo`00000000000080oooo100000080?ooo`H0000000<0oooo0000003oool00P00000B
0?ooo`040000003oool000000?ooo`8000000`3oool3000000030?ooo`0000000000008000001@3o
ool01P000000oooo000000000000oooo000000L0oooo00<000000?ooo`000000100000000`3oool0
0000000000070?ooo`D000000`3oool2000002L0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool08`3oool300000080oooo00@000000?ooo`000000oooo0P0000070?ooo`03
0000003oool000000080000000<0oooo000000000000303oool800000100oooo0`0000000`3oool0
00000?ooo`0B0?ooo`80000000<0oooo0000000000001@0000080?ooo`D0000000D0oooo0000003o
ool000000?ooo`03000000<0oooo0`0000000`3oool00000000000090?ooo`030000003oool00000
00<0000000@0oooo000000000000oooo0P0000080?ooo`80000000<0oooo0000000000001P3oool2
000000030?ooo`000000000000@000001`3oool5000000<0oooo00H000000?ooo`00000000000?oo
o`00000B0?ooo`040000003oool000000?ooo`800000103oool3000000040?ooo`00000000000000
00D0oooo00<000000?ooo`0000000`0000070?ooo`050000003oool000000000003oool01@000007
0?ooo`D000000P3oool3000002H0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool08`3oool200000080oooo00<000000?ooo`000000100000060?ooo`030000003oool00000
00D00000303oool800000100oooo0P000000103oool000000000000000080?ooo`P000000P3oool0
0`000000oooo00000002000000030?ooo`000000000000@00000203oool7000000040?ooo`000000
0000000000D0oooo0`0000000`3oool00000000000080?ooo`80000000H0oooo0000003oool0oooo
0000003oool3000000030?ooo`000000oooo00D0oooo0P0000000`3oool00000000000070?ooo`03
0000003oool0000000D000001`3oool010000000oooo0000000000050?ooo`070000003oool00000
0?ooo`000000oooo0000000A0?ooo`030000003oool0oooo00<000001P3oool3000000040?ooo`00
00000000000000<0oooo00@000000?ooo`000000oooo0`0000070?ooo`050000003oool000000000
003oool01@0000060?ooo`H000000P3oool3000002D0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool08P3oool3000000030?ooo`000000oooo0080000000<0oooo00000000
00001P3oool00`000000oooo00000005000000`0oooo2000000@0?ooo`030000003oool0000000<0
000000<0oooo0000000000003@0000000`3oool0000000000003000000030?ooo`000000000000<0
oooo1@0000070?ooo`T000001`3oool4000000030?ooo`000000oooo00D0oooo0P0000000`3oool0
0000000000030?ooo`030000003oool000000080000000<0oooo0000003oool00`3oool00`000000
oooo00000002000000T0oooo1P0000070?ooo`<00000203oool01P000000oooo000000000000oooo
00000180oooo00@000000?ooo`000000oooo0P0000060?ooo`@0000000<0oooo0000000000000`3o
ool01@000000oooo000000000000oooo008000001`3oool00`000000oooo00000006000000L0oooo
0`0000000`3oool000000?ooo`020?ooo`8000009@3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`0Q0?ooo`<000000P3oool6000000H0oooo00<000000?ooo`0000000P00
0000103oool0000000000000000:0?ooo`80000000<0oooo0000000000001@00000@0?ooo`<00000
00@0oooo00000000000000000P3ooolF000000D0oooo00<000000?ooo`0000000P0000060?ooo`L0
00002@3oool01P000000oooo000000000000oooo000000@0oooo0P000000103oool000000?ooo`00
00030?ooo`080000003oool0oooo0000003oool000000?ooo`0000020?ooo`030000003oool00000
008000002P3oool4000000030?ooo`000000oooo00@0oooo0`00000:0?ooo`P000004@3oool01P00
0000oooo000000000000oooo000000L0oooo00<000000?ooo`000000100000020?ooo`80000000@0
oooo0000000000000000203oool3000000030?ooo`000000000000<000001`3oool3000000030?oo
o`000000oooo0080oooo0P00000T0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo0240oooo0`0000000`3oool000000?ooo`05000000H0oooo10000000103oool000000000
0000000:0?ooo`80000000<0oooo0000000000001@00000@0?ooo`80000000<0oooo000000000000
2P0000080?ooo`X000001@3oool01@000000oooo0000003oool0000000H0oooo1P0000090?ooo`80
000000D0oooo000000000000oooo000000020?ooo`8000000P3oool00`000000oooo000000040?oo
o`050000003oool0oooo0000003oool00P0000020?ooo`<0000000<0oooo0000003oool02@3oool6
000000@0oooo0`0000070?ooo`/0000000<0oooo0000000000001P0000090?ooo`040000003oool0
00000?ooo`800000203oool2000000030?ooo`00000000000080000000D0oooo0000003oool00000
0?ooo`03000000T0oooo0P0000001P3oool00000000000000000oooo000000L0oooo100000030?oo
o`<000008`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0P0?ooo`<0
00000P3oool6000000H0oooo0`000000103oool000000000003oool2000000T0oooo0P0000000`3o
ool0000000000003000000030?ooo`000000oooo0100oooo2`00000=0?ooo`<0000000@0oooo0000
00000000oooo100000040?ooo`<0000000<0oooo0000003oool00`3oool7000000X0oooo10000000
103oool000000?ooo`3oool2000000050?ooo`000000oooo0?ooo`0000001@3oool00`000000oooo
00000002000000050?ooo`00000000000000003oool00P00000:0?ooo`@0000000@0oooo00000000
000000000P3oool3000000@0oooo5@0000000`3oool0000000000002000000P0oooo00H000000?oo
o`00000000000?ooo`0000090?ooo`040000003oool000000?ooo`D0000000D0oooo000000000000
oooo000000090?ooo`L00000203oool4000000<0oooo0P00000S0?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo01l0oooo100000000`3oool0000000000004000000H0oooo
0`0000000`3oool000000?ooo`03000000T0oooo0P0000000`3oool0000000000002000000040?oo
o`000000000000000100oooo2000000@0?ooo`80000000D0oooo000000000000oooo000000030?oo
o`@00000103oool2000000060?ooo`000000oooo0?ooo`000000oooo0P0000000`3oool000000000
0002000000X0oooo100000001@3oool00000000000000000oooo008000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0000000@0oooo00000000000000002`3oool400000003
0?ooo`000000000000@00000103oool8000000@0oooo00@000000?ooo`000000oooo3P0000070?oo
o`030000003oool00000008000002P3oool3000000070?ooo`000000oooo0000003oool000000?oo
o`03000000X0oooo1@0000000`3oool000000?ooo`060?ooo`D000000`3oool200000280oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool07P3oool4000000080?ooo`000000
00000000003oool000000?ooo`0000050?ooo`<0000000H0oooo00000000000000000?ooo`000009
0?ooo`80000000D0oooo00000000000000000?ooo`0400000100oooo1`00000A0?ooo`050000003o
ool000000000003oool00P0000060?ooo`@000000`3oool2000000030?ooo`000000oooo00800000
00<0oooo0000000000001000000;0?ooo`030000003oool0000000<0000000<0oooo000000000000
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000H000002`3oool300000080oooo
00<000000?ooo`0000000`0000030?ooo`D000002P3oool010000000oooo0000003oool2000000<0
oooo100000000`3oool0000000000003000000D0oooo00H000000?ooo`00000000000?ooo`00000;
0?ooo`80000000<0oooo0000003oool00P0000001@3oool000000000003oool0000000X0oooo1@00
00000`3oool000000?ooo`060?ooo`@000000`3oool300000240oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool07P3oool4000000030?ooo`000000000000@000001@3oool6
000000040?ooo`0000000000000000P0oooo0P0000000`3oool0000000000003000000040?ooo`00
00000000000000h0oooo2000000B0?ooo`80000000D0oooo000000000000oooo000000080?ooo`@0
00000P3oool4000000070?ooo`00000000000000003oool000000?ooo`03000000X0oooo1P000000
0`3oool000000?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@00000;
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000`000000103oool0000000000000
000?0?ooo`80000000<0oooo0000000000001P3oool3000000030?ooo`000000000000<00000103o
ool00`000000oooo00000002000000`0oooo0P0000000`3oool000000?ooo`02000000040?ooo`00
00000000000000/0oooo100000000`3oool000000?ooo`070?ooo`@000000`3oool200000240oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool07@3oool4000000050?ooo`00
000000000000003oool00`0000040?ooo`@0000000H0oooo00000000000000000?ooo`0000080?oo
o`80000000<0oooo0000000000000`000000103oool0000000000000000>0?ooo`030000003oool0
000000@0000000<0oooo0000003oool0403oool00`000000oooo00000002000000030?ooo`000000
oooo00@0oooo100000020?ooo`@0000000<0oooo0000000000000`0000001P3oool000000000003o
ool000000?ooo`<000002P3oool4000000030?ooo`000000000000@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo00000004000000X0oooo0`0000050?ooo`L000004@3oool010000000oooo
0000003oool2000000L0oooo0`0000000`3oool000000000000300000080oooo00H000000?ooo`00
000000000?ooo`00000<0?ooo`H0000000D0oooo000000000000oooo0000000;0?ooo`@0000000<0
oooo0000003oool01`3oool3000000<0oooo0`00000P0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo01d0oooo0`0000001@3oool00000000000000000oooo00<000001@3o
ool3000000040?ooo`00000000000?ooo`<000001`3oool2000000030?ooo`000000000000800000
00@0oooo000000000000oooo0P00000=0?ooo`040000003oool000000?ooo`80000000<0oooo0000
000000004@3oool010000000oooo0000003oool300000080oooo3`0000000`3oool0000000000003
000000060?ooo`000000oooo0?ooo`000000oooo0`00000:0?ooo`H00000103oool00`000000oooo
0?ooo`060?ooo`030000003oool0000000@000002@3oool2000000D0oooo1`00000C0?ooo`050000
003oool000000?ooo`0000002@3oool9000000030?ooo`000000oooo00<000003@3oool010000000
oooo0000003oool2000000040?ooo`0000000000000000/0oooo100000000`3oool000000?ooo`07
0?ooo`@000000`3oool200000200oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool0703oool4000000050?ooo`00000000000000003oool00P0000050?ooo`D0000000D0oooo
000000000000oooo000000070?ooo`030000003oool0000000<0000000@0oooo000000000000oooo
0`00000=0?ooo`P0000000<0oooo0000003oool0403oool2000000030?ooo`000000000001@00000
00H0oooo00000000000000000?ooo`0000030?ooo`030000003oool00000008000002P3oool40000
00030?ooo`000000oooo00<0oooo00<000000?ooo`3oool01@3oool8000000P0oooo0P0000050?oo
oa<00000203oool010000000oooo0000003oool2000000T0oooo1@0000000`3oool0000000000002
000000050?ooo`00000000000?ooo`0000003@3oool00`000000oooo00000005000000030?ooo`00
0000oooo00X0oooo100000000`3oool000000?ooo`070?ooo`@000000P3oool3000001l0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0703oool3000000050?ooo`000000
00000000003oool00`0000040?ooo`030000003oool00000008000000P3oool4000000H0oooo00D0
00000?ooo`00000000000?ooo`03000000060?ooo`00000000000000003oool00000303oool20000
00030?ooo`000000oooo0080000000<0oooo0000000000004@3oool00`000000oooo000000080000
00`0oooo2@0000040?ooo`030000003oool0000000800000203oool6000000030?ooo`000000oooo
0080oooo00<000000?ooo`3oool01@3oool5000000040?ooo`0000000000000000H0oooo0P000005
0?oooa<0000000<0oooo0000000000001`3oool010000000oooo0000003oool2000000X0oooo1@00
00001@3oool000000?ooo`000000oooo00<000003P3oool00`000000oooo00000006000000`0oooo
1@0000080?ooo`@000000`3oool2000001l0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool06`3oool4000000030?ooo`00000000000080oooo0P0000040?ooo`070000003o
ool000000000003oool000000?ooo`02000000030?ooo`000000oooo00H0oooo0`000000103oool0
00000000003oool2000000040?ooo`0000000000000000/0oooo0`0000001@3oool0000000000000
0000oooo0080000000<0oooo0000003oool0403oool700000140oooo200000050?ooo`030000003o
ool00000008000001P3oool00`000000oooo00000005000000050?ooo`000000oooo0?ooo`000000
1P3oool00`000000oooo00000002000000030?ooo`0000000000008000001@3oool00`000000oooo
000000040?oooa80000000<0oooo000000000000100000060?ooo`80000000<0oooo000000000000
303oool2000000030?ooo`000000000000D0000000<0oooo0000003oool03@3oool010000000oooo
0000003oool3000000030?ooo`000000oooo00/0oooo1@0000080?ooo`@000000`3oool2000001h0
oooo00<000000?ooo`3oool00P3oool004/0oooo0P00000L0?ooo`<0000000D0oooo000000000000
00000?ooo`03000000<0oooo00<000000?ooo`0000000`0000020?ooo`@000001P3oool300000006
0?ooo`00000000000?ooo`000000oooo0`0000000`3oool000000?ooo`090?ooo`80000000<0oooo
000000000000100000000`3oool000000000000A0?ooo`L000004P3oool2000000030?ooo`000000
000000@000001@3oool01@000000oooo0000003oool0000000D0oooo0P0000000`3oool000000000
000300000080oooo00<000000?ooo`0000001P3oool5000000030?ooo`000000oooo00<00000103o
ool200000080oooo1P0000040?ooo`030000003oool00000008000001@3oool:000000@0oooo00@0
00000?ooo`000000oooo0P00000<0?ooo`8000000P3oool7000000l0oooo00D000000?ooo`000000
00000?ooo`03000000`0oooo1@0000080?ooo`@000000`3oool2000001`0oooo0`0000040?ooo`00
B`3oool00`000000oooo0?ooo`0J0?ooo`L000000P3oool2000000@0oooo00<000000?ooo`000000
0P0000020?ooo`80000000<0oooo0000003oool01@3oool010000000oooo0000003oool200000080
oooo0P000000103oool0000000000000000:0?ooo`80000000<0oooo0000003oool00`0000001@3o
ool000000000003oool0000000l0oooo100000001@3oool000000000003oool000000140oooo0P00
0000103oool000000000003oool>000000@0oooo00<000000?ooo`0000000P0000020?ooo`<00000
00@0oooo0000003oool000001@3oool3000000070?ooo`000000oooo0000003oool000000?ooo`03
00000080oooo0P0000000`3oool0000000000005000000D0oooo00H000000?ooo`00000000000?oo
o`0000060?ooo`80000000<0oooo0000000000001@0000030?ooo`80000000<0oooo000000000000
3@3oool200000080oooo1@0000000`3oool000000?ooo`0>0?ooo`H0000000<0oooo0000003oool0
2`3oool5000000P0oooo100000030?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`0J0?ooo`<0000000<0oooo0000000000000P3oool3000000<0oooo00<0
00000?ooo`0000000P0000030?ooo`@000001@3oool00`000000oooo0000000300000080oooo00<0
00000?ooo`0000000P0000000`3oool000000?ooo`080?ooo`80000000<0oooo0000003oool00P00
0000103oool000000000003oool2000000h0oooo100000000`3oool000000000000300000180oooo
5@0000020?ooo`050000003oool000000?ooo`0000000`3oool4000000030?ooo`000000000000D0
oooo0P000000103oool000000?ooo`3ooolB000000L0oooo00<000000?ooo`0000000P0000080?oo
o`8000000P3oool6000000050?ooo`000000oooo0000003oool00P00000=0?ooo`<0000000<0oooo
0000000000001000000@0?ooo`D0000000<0oooo0000003oool02`3oool3000000030?ooo`000000
oooo00L0oooo100000030?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`00
0000oooo0?ooo`0I0?ooo`<0000000@0oooo00000000000000000P3oool2000000<0oooo00<00000
0?ooo`0000000`0000020?ooo`80000000<0oooo0000000000001@3oool5000000<0oooo0P000000
103oool000000000000000090?ooo`80000000D0oooo0000003oool000000?ooo`02000000050?oo
o`00000000000?ooo`000000303oool7000000050?ooo`00000000000?ooo`0000004@3oool70000
00030?ooo`000000000000H000000P3oool8000000030?ooo`000000000000<0oooo2P0000000`3o
ool000000000000200000080oooo5@0000050?ooo`060000003oool000000000003oool000002@3o
ool200000080oooo200000000`3oool000000000000>0?ooo`060000003oool000000?ooo`000000
oooo0P0000000`3oool000000?ooo`0?0?ooo`D0000000<0oooo0000003oool02P3oool5000000T0
oooo100000030?ooo`800000703oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`0I0?ooo`H000000P3oool300000080oooo00<000000?ooo`3oool00`0000030?ooo`@00000
1@3oool5000000<0oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`070?ooo`090000
003oool000000000003oool000000?ooo`000000oooo0080000000<0oooo000000000000303oool0
1@000000oooo000000000000oooo00<0000000@0oooo0000000000000000403oool:000000<0oooo
1`0000001@3oool00000000000000000oooo01h0000000<0oooo000000000000100000020?ooo`/0
00000`3oool00`000000oooo00000002000000/0oooo0P0000000`3oool000000000000200000005
0?ooo`00000000000000003oool00P00000>0?ooo`<0000000<0oooo0000003oool00`00000A0?oo
o`H00000303oool3000000030?ooo`000000oooo00L0oooo100000030?ooo`800000703oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0H0?ooo`<0000000@0oooo00000000
000000000P3oool2000000<0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
000000800000103oool01P000000oooo000000000000oooo000000<0oooo0P000000103oool00000
0000000000080?ooo`060000003oool000000000003oool000000P3oool2000000050?ooo`000000
00000?ooo`0000002`3oool01@000000oooo000000000000oooo00<0000000D0oooo000000000000
oooo0000000>0?ooo`D0000000D0oooo000000000000oooo000000050?ooo`@0000000D0oooo0000
0000000000000?ooo`0<00000080oooo3`0000030?ooo`030000003oool0000000@000000`3oool:
000000060?ooo`00000000000?ooo`000000oooo0P0000000`3oool000000?ooo`0;0?ooo`800000
00<0oooo000000000000100000000`3oool000000000000@0?ooo`P00000403oool7000000/0oooo
1@0000080?ooo`D000000`3oool2000001/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool0603oool600000080oooo0`0000020?ooo`030000003oool0000000800000103o
ool4000000@0oooo00<000000?ooo`0000000`0000030?ooo`030000003oool000000080000000<0
oooo0000003oool01P3oool01P000000oooo000000000000oooo00000080oooo00D000000?ooo`00
000000000?ooo`02000000/0oooo00D000000?ooo`00000000000?ooo`02000000030?ooo`000000
oooo00<000003P3oool010000000oooo0000003oool6000000L0oooo100000001@3oool000000000
00000000oooo00X000000`3oool00`000000oooo0000000300000080oooo2@0000020?ooo`H00000
0P3oool3000000<0oooo1`0000001@3oool000000?ooo`000000oooo0080000000<0oooo0000003o
ool0303oool01@000000oooo000000000000oooo00<0000000<0oooo000000000000403oool30000
00040?ooo`000000000000000140oooo1P00000<0?ooo`<0000000<0oooo0000003oool01`3oool4
000000<0oooo0P00000K0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
01L0oooo0`000000103oool000000000000000020?ooo`8000000`3oool00`000000oooo00000002
000000@0oooo100000040?ooo`D00000103oool00`000000oooo00000003000000P0oooo0`000000
0`3oool000000?ooo`020?ooo`80000000D0oooo000000000000oooo0000000:0?ooo`@0000000D0
oooo0000003oool000000?ooo`03000000030?ooo`000000oooo00/0oooo1`0000000`3oool00000
0?ooo`02000000P0oooo0`0000020?ooo`T000000P3oool400000080oooo100000000`3oool00000
0000000B000000030?ooo`000000000000H0oooo2@0000001@3oool000000000003oool0000000h0
oooo00<000000?ooo`0000001`00000A0?ooo`L00000403oool00`000000oooo00000004000000/0
oooo1@0000080?ooo`D000000`3oool2000001X0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool05`3oool600000080oooo0`0000020?ooo`050000003oool000000?ooo`00
0000103oool4000000@0oooo0P000000103oool000000000000000040?ooo`@0000000<0oooo0000
003oool01P3oool2000000040?ooo`000000oooo000000<0oooo0`0000000`3oool000000000000:
0?ooo`<000000P3oool01P000000oooo0000003oool000000?ooo`<00000303oool010000000oooo
0000003oool4000000040?ooo`0000000000000000X0oooo0`0000000`3oool00000000000060000
00D0oooo1@0000000`3oool0000000000005000000<0oooo00<000000?ooo`000000300000090?oo
o`P0000000D0oooo000000000000oooo0000000>0?ooo`040000003oool000000?ooo`80000000@0
oooo0000003oool000004@3oool600000140oooo1P00000;0?ooo`060000003oool000000000003o
ool00000203oool4000000<0oooo0P00000J0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo01H0oooo0`000000103oool000000000000000020?ooo`<000000P3oool00`00
0000oooo00000002000000@0oooo100000040?ooo`D00000103oool00`000000oooo000000030000
00L0oooo0P000000103oool000000?ooo`0000030?ooo`050000003oool000000000003oool00P00
00090?ooo`<000000P3oool01@000000oooo0?ooo`000000oooo00<0000000<0oooo0000003oool0
2P3oool010000000oooo0000003oool4000000030?ooo`000000oooo008000002`3oool400000003
0?ooo`000000000000@000001P3oool:000000030?ooo`000000oooo00<0oooo2@000000103oool0
000000000000000<0?ooo`030000003oool0000000H0000000<0oooo0000003oool03P3oool00`00
0000oooo00000003000000030?ooo`00000000000180oooo00<000000?ooo`0000000`00000@0?oo
o`030000003oool0000000@000002`3oool5000000P0oooo1@0000030?ooo`8000006@3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0F0?ooo`H000000`3oool200000080
oooo00D000000?ooo`000000oooo000000040?ooo`@00000103oool2000000040?ooo`000000oooo
000000@0oooo0`0000000`3oool00000000000060?ooo`060000003oool000000000003oool00000
103oool2000000050?ooo`00000000000?ooo`0000002@3oool200000080oooo00L000000?ooo`3o
ool000000?ooo`000000oooo00<000002`3oool00`000000oooo00000003000000040?ooo`000000
00000?ooo`<00000303oool<000000H0oooo2P0000060?ooo``000003@3oool9000000030?ooo`00
0000oooo00h0oooo00<000000?ooo`3oool01P00000A0?ooo`@0000000<0oooo0000000000003`3o
ool00`000000oooo00000004000000/0oooo00<000000?ooo`0000000`0000080?ooo`@000000`3o
ool2000001T0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool05@3oool3
000000040?ooo`000000000000000080oooo0`0000020?ooo`030000003oool0000000800000103o
ool4000000<0oooo0P000000103oool000000000000000040?ooo`030000003oool0000000<00000
1`3oool3000000030?ooo`000000oooo00<0oooo00D000000?ooo`00000000000?ooo`02000000T0
oooo0`0000000`3oool000000?ooo`020?ooo`050000003oool000000000003oool00P00000:0?oo
o`030000003oool00000008000000P3oool2000000030?ooo`000000oooo008000002P3oool60000
00030?ooo`000000000000D000001P3oool8000000030?ooo`000000oooo00@0oooo00<000000?oo
o`0000001@0000000`3oool0000000000003000000h0oooo00D000000?ooo`00000000000?ooo`02
000000030?ooo`000000oooo00l0oooo00<000000?ooo`3oool00P0000000`3oool000000000000B
0?ooo`@0000000<0oooo0000003oool03`3oool4000000030?ooo`000000000000/0oooo1@000008
0?ooo`D000000`3oool2000001P0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool05@3oool00`000000oooo00000003000000<0oooo0`0000001P3oool000000?ooo`000000
oooo000000@0oooo0P0000000`3oool00000000000030?ooo`D000001@3oool2000000040?ooo`00
00000000000000H0oooo0`0000000`3oool000000?ooo`040?ooo`80000000D0oooo000000000000
oooo000000080?ooo`<0000000<0oooo0000003oool00`3oool00`000000oooo0000000200000003
0?ooo`000000oooo00P0oooo1@0000030?ooo`80000000@0oooo00000000000000002P3oool00`00
0000oooo00000005000000030?ooo`000000000000D00000103oool00`000000oooo000000080000
00@0oooo00D000000?ooo`00000000000?ooo`0:000000l0oooo00D000000?ooo`00000000000?oo
o`02000000030?ooo`000000oooo00l0oooo00<000000?ooo`0000001@00000B0?ooo`H000003`3o
ool00`000000oooo00000004000000/0oooo1P0000080?ooo`@000000`3oool2000001P0oooo00<0
00000?ooo`3oool00P3oool002l0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Bo
o`020?ooo`030=nLB0000000000000<0000000<0B9cO0?ooo`3oool01`3oool00`000000oooo0?oo
o`0D0?ooo`L000000P3oool300000080oooo1@0000040?ooo`@000000`3oool2000000040?ooo`00
00000000000000D0oooo1@0000060?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`050000
003oool000000000003oool00P0000080?ooo`<0000000<0oooo0000003oool00`3oool010000000
oooo0000003oool3000000T0oooo0P0000000`3oool00000000000030?ooo`80000000<0oooo0000
003oool00P0000090?ooo`030000003oool000000080000000<0oooo0000000000000P0000000`3o
ool0000000000004000000<0oooo00D000000?ooo`00000000000?ooo`06000000060?ooo`000000
oooo0?ooo`000000oooo1@0000020?ooo`P000003`3oool00`000000oooo0000000500000140oooo
00<000000?ooo`0000001000000B0?ooo`L000003`3oool7000000/0oooo1@0000080?ooo`D00000
0`3oool2000001L0oooo00<000000?ooo`3oool00P3oool002h0oooo00H0gia8001d_`3oool0omnL
04P00018W=l20?ooo`030?oOW0180000M;oo00<0oooo00<0okmd001d_`3oool00P3oool00`2oM7@0
_ooo0?ooo`070?ooo`030000003oool0oooo01@0oooo00@000000?ooo`000000oooo0P0000030?oo
o`<0000000H0oooo0000003oool000000?ooo`0000050?ooo`040000003oool00000000000<0oooo
1@0000050?ooo`030000003oool0000000<000001P3oool200000080oooo00<000000?ooo`3oool0
0`3oool2000000030?ooo`000000oooo008000001`3oool2000000030?ooo`000000000000D0oooo
00<000000?ooo`0000000P0000000`3oool000000?ooo`070?ooo`80000000@0oooo0000003oool0
00000`3oool2000000040?ooo`0000000000000000T0oooo1@0000000`3oool000000?ooo`050000
0080oooo100000000`3oool000000?ooo`04000000030?ooo`000000000000D0000000<0oooo0000
003oool00`0000000`3oool00000000000020?ooo`@0000000@0oooo0000000000000000403oool8
00000140oooo0`000000103oool0000000000000000B0?ooo`H000003`3oool2000000030?ooo`00
00000000008000002`3oool6000000P0oooo100000030?ooo`8000005`3oool00`000000oooo0?oo
o`020?ooo`00;@3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00P0oooo00<0okmd
001d_`3oool02`3oool00`000000oooo0?ooo`0C0?ooo`L000000`3oool3000000030?ooo`000000
000000<00000103oool2000000030?ooo`000000oooo0080oooo0`0000000`3oool000000?ooo`05
0?ooo`@0000000<0oooo0000003oool0103oool3000000030?ooo`000000oooo00D0oooo0`000000
0`3oool00000000000070?ooo`030000003oool00000008000001@3oool010000000oooo0000003o
ool3000000P0oooo0P000000103oool000000?ooo`0000030?ooo`80000000<0oooo0000003oool0
0P0000080?ooo`80000000D0oooo000000000000oooo000000020?ooo`D000000`3oool300000004
0?ooo`00000000000?ooo`8000000P3oool8000000050?ooo`00000000000000003oool00P000003
0?ooo`P000004@3oool5000000030?ooo`000000oooo0140oooo0`000000103oool0000000000000
000A0?ooo`D0000000<0oooo0000003oool03P3oool7000000X0oooo00<000000?ooo`0000000`00
00080?ooo`@00000103oool2000001H0oooo00<000000?ooo`3oool00P3oool002d0oooo00<0oooO
09a80018W=l00P3oool0103ooml0W4P00018W03Oool80?ooo`030?noM000M;l0oooo00X0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo00000003000000<0oooo0`0000000`3oool000000?oo
o`03000000D0oooo100000030?ooo`D000001@3oool00`000000oooo00000003000000D0oooo0`00
00000`3oool000000?ooo`050?ooo`80000000<0oooo0000003oool00P0000060?ooo`030000003o
ool00000008000001P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool200000004
0?ooo`000000oooo000000@0oooo0P0000000`3oool000000?ooo`02000000L0oooo0P0000001@3o
ool000000000003oool000000080oooo00<000000?ooo`0000000P0000040?ooo`D0000000<0oooo
0000000000000`3oool8000000030?ooo`00000000000080oooo0P0000020?ooo`@0000000<0oooo
0000003oool00`00000A0?ooo`<0000000<0oooo0000000000004P3oool3000000040?ooo`000000
000000000180oooo1@0000000`3oool000000?ooo`0=0?ooo`80000000<0oooo0000000000000P00
000;0?ooo`H00000203oool4000000<0oooo0P00000F0?ooo`030000003oool0oooo0080oooo000P
0?ooo`030?oog`2LB000000000L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`030=nL
B00004P0W=oo00T0oooo00<0okmd04RLg`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`800000
00<0oooo0000000000000P0000030?ooo`<0000000<0oooo0000000000000`0000050?ooo`030000
003oool0000000<0oooo1@0000060?ooo`80000000@0oooo00000000000000001@3oool300000003
0?ooo`000000oooo00D0oooo0`0000020?ooo`030000003oool0oooo00D0oooo100000070?ooo`80
000000D0oooo000000000000oooo000000060?ooo`040000003oool000000?ooo`8000001@3oool0
10000000oooo0000003oool2000000L0oooo0P0000001@3oool000000000003oool0000000<0oooo
0P000000103oool000000000000000040?ooo`<0000000<0oooo0000000000000`3oool300000003
0?ooo`000000000000H0000000<0oooo0000000000000P3oool4000000030?ooo`000000oooo00D0
00004@3oool600000180oooo0`000000103oool000000?ooo`00000A0?ooo`<0000000@0oooo0000
003oool000003`3oool00`000000oooo00000004000000X0oooo1P0000080?ooo`@000000`3oool3
000001D0oooo00<000000?ooo`3oool00P3oool002h0oooo00<0_g@00018W03Oool00P3oool00`3o
gi`0B00004RLg`0:0?ooo`030=nLB018W=l0oooo00P0oooo0`00000B0?ooo`L000000`3oool30000
00030?ooo`0000000000008000001@3oool4000000<0oooo1@0000060?ooo`@0000000<0oooo0000
003oool00`3oool3000000030?ooo`000000oooo00D0oooo0P0000000`3oool000000?ooo`020000
00H0oooo00<000000?ooo`0000000P0000060?ooo`070000003oool000000?ooo`000000oooo0000
00060?ooo`040000003oool000000?ooo`8000001@3oool2000000030?ooo`000000oooo00800000
1`3oool00`000000oooo0?ooo`03000000@0oooo0`0000000`3oool00000000000040?ooo`@00000
00<0oooo0000003oool00P3oool3000000030?ooo`000000oooo00D000000P3oool2000000030?oo
o`0000000000008000000P3oool4000000040?ooo`000000000000000100oooo1`00000A0?ooo`P0
00004@3oool400000080oooo00<000000?ooo`3oool0303oool2000000030?ooo`00000000000080
00002`3oool6000000L0oooo100000040?ooo`8000004P3oool4000000@0oooo000^0?ooo`030=nL
B00004P0W=oo0080oooo00<0oooO09a80000M;l02`3oool00`2oM000M;oo0?ooo`070?ooo`030000
003oool0oooo0180oooo00<000000?ooo`0000000`0000030?ooo`<0000000<0oooo000000000000
0`0000050?ooo`@000000P3oool5000000H0oooo0P000000103oool000000000000000050?ooo`@0
00001`3oool300000080oooo00<000000?ooo`3oool0103oool00`000000oooo00000002000000L0
oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`040?ooo`040000003oool000000?oo
o`8000001P3oool2000000050?ooo`00000000000?ooo`0000001P3oool00`000000oooo0?ooo`03
000000@0oooo0P0000000`3oool0000000000003000000<0oooo1@0000030?ooo`@000000P3oool5
00000080oooo0P0000020?ooo`@000000`3oool00`000000oooo00000003000000030?ooo`000000
oooo00l0oooo100000000`3oool000000000000A0?ooo`D0000000<0oooo000000000000403oool5
000000030?ooo`000000000000h0oooo00<000000?ooo`0000001000000:0?ooo`H00000203oool4
000000<0oooo0P00000E0?ooo`030000003oool0oooo0080oooo000^0?ooo`030?oOW0180000B9cO
00<0oooo00<0_g@00018W03Oool02P3oool00`3ogi`0B01d0;ooo`070?ooo`030000003oool0oooo
0140oooo1`0000030?ooo`<0000000<0oooo0000000000000P0000050?ooo`80000000<0oooo0000
003oool00P3oool5000000H0oooo0P000000103oool000000000000000040?ooo`<0000000<0oooo
0000003oool01@3oool010000000oooo0000000000020?ooo`030000003oool0oooo00@0oooo0`00
00000`3oool000000?ooo`060?ooo`80000000D0oooo0000003oool0oooo000000050?ooo`800000
00@0oooo0000003oool000001P3oool010000000oooo0000003oool2000000H0oooo0P0000001@3o
ool000000000003oool0000000@0oooo0`0000000`3oool000000?ooo`0200000080oooo1P000003
0?ooo`@000000P3oool6000000040?ooo`00000000000?ooo`@00000103oool800000100oooo2000
000@0?ooo`H0000000<0oooo0000003oool03`3oool500000080oooo0P00000=0?ooo`80000000D0
oooo000000000000oooo0000000:0?ooo`030000003oool0000000@000001`3oool4000000@0oooo
0P00000D0?ooo`030000003oool0oooo0080oooo000^0?ooo`040?oog`2LB00004RL0=ooo`80oooo
00<0gia80018W03Oool02P3oool00`3ooml0W4P007Boo`070?ooo`030000003oool0oooo0140oooo
1`0000020?ooo`H0000000<0oooo0000000000001@3oool400000080oooo1@0000070?ooo`@00000
00<0oooo0000003oool00`3oool4000000L0oooo0P0000000`3oool000000?ooo`02000000D0oooo
0P0000000`3oool00000000000070?ooo`070000003oool000000?ooo`000000oooo000000050?oo
o`060000003oool000000000003oool000001P3oool2000000050?ooo`00000000000?ooo`000000
1@3oool2000000030?ooo`000000oooo00800000103oool00`000000oooo0000000200000080oooo
100000000`3oool0000000000004000000060?ooo`00000000000000003oool000000P3oool80000
00030?ooo`000000000000<000001@3oool2000000030?ooo`000000000000<000003`3oool70000
00030?ooo`000000oooo00l0oooo0P000000103oool000000000003oool200000100oooo1@000000
0`3oool000000000000=0?ooo`80000000<0oooo0000000000000`00000:0?ooo`H000001`3oool5
000000<0oooo0P00000D0?ooo`030000003oool0oooo0080oooo000_0?ooo`030?oOW0180000M;oo
0080oooo00<0gia8001d_`3oool02P3oool00`3ookl0M00004RLg`070?ooo`030000003oool0oooo
0140oooo1P0000030?ooo`030000003oool0000000D000001P3oool400000080oooo1@0000060?oo
o`80000000@0oooo0000000000000000103oool3000000030?ooo`000000oooo00H0oooo0`000002
0?ooo`030000003oool0oooo00@0oooo0`0000000`3oool000000?ooo`060?ooo`80000000D0oooo
000000000000oooo000000050?ooo`<0000000<0oooo0000003oool01P3oool3000000030?ooo`00
0000000000D0oooo00D000000?ooo`00000000000?ooo`02000000D0oooo0P0000000`3oool00000
000000030?ooo`80000000<0oooo0000000000001@0000001`3oool00000000000000000oooo0000
003oool02@0000000`3oool0000000000002000000H0oooo00<000000?ooo`000000100000000`3o
ool000000?ooo`0>0?ooo`P00000403oool6000000030?ooo`000000000000l0oooo1@0000020?oo
o`800000303oool2000000060?ooo`00000000000000003oool000002P3oool7000000H0oooo1@00
00030?ooo`800000503oool00`000000oooo0?ooo`020?ooo`00<03oool01P3OW4P0001d0;ooo`3o
oml0W4P004RLg`L0oooo00L0okmd0018W03Oool0oooo0=nLB00004P0W=oo00L0oooo00<000000?oo
o`3oool0403oool7000000<0oooo0`0000000`3oool000000?ooo`02000000D0oooo0P0000000`3o
ool00000000000020?ooo`040000003oool00000000000L0oooo0P000000103oool0000000000000
00040?ooo`@000001`3oool010000000oooo0000000000020?ooo`030000003oool0oooo00<0oooo
0P0000000`3oool00000000000070?ooo`070000003oool000000?ooo`000000oooo000000050?oo
o`<0000000<0oooo0000003oool01`3oool010000000oooo0000003oool2000000@0oooo00D00000
0?ooo`00000000000?ooo`02000000H0oooo100000040?ooo`H0000000<0oooo0000000000001@00
00000`3oool000000?ooo`08000000030?ooo`000000000000<000001P3oool00`000000oooo0000
0006000000l0oooo1`0000000`3oool000000?ooo`0>0?ooo`040000003oool000000?ooo`D00000
3`3oool2000000080?ooo`00000000000000003oool000000?ooo`00000<0?ooo`P000002P3oool6
000000L0oooo00@000000?ooo`0000000000103oool2000001<0oooo00<000000?ooo`3oool00P3o
ool00340oooo00@0gia800000000000007Bo2@3oool01@3ogi`0B000000000000000M;oo00P0oooo
00<000000?ooo`3oool0403oool700000080oooo2@0000050?ooo`@000000P3oool5000000H0oooo
00D000000?ooo`00000000000?ooo`02000000<0oooo0`0000000`3oool000000?ooo`060?ooo`05
0000003oool000000000003oool00P0000040?ooo`030000003oool0000000800000203oool01`00
0000oooo0000003oool000000?ooo`0000001@3oool01@000000oooo0000003oool0000000L0oooo
0P0000001@3oool000000000003oool0000000<0oooo00<000000?ooo`3oool0100000060?ooo`80
000000<0oooo000000000000103oool3000000040?ooo`000000oooo0?ooo`@0000000@0oooo0000
003oool0oooo3`0000080?ooo`030000003oool0000000@0000000<0oooo0000003oool03P3oool2
000000030?ooo`000000000000<00000403oool6000000030?ooo`000000000000h0oooo00<00000
0?ooo`0000000`0000020?ooo`800000303oool2000000060?ooo`00000000000000003oool00000
2P3oool6000000L0oooo1@0000030?ooo`8000004`3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`0?0?ooo`L000000`3oool5000000030?ooo`000000000000H0oooo1000
00020?ooo`030000003oool00000008000001P3oool00`000000oooo00000003000000@0oooo1000
00080?ooo`80000000<0oooo0000003oool00P0000040?ooo`80000000<0oooo000000000000203o
ool2000000050?ooo`00000000000?ooo`000000103oool3000000030?ooo`000000oooo00L0oooo
0`0000000`3oool00000000000040?ooo`050000003oool000000000003oool00P0000060?ooo`80
000000<0oooo0000003oool00`3oool00`000000oooo00000003000000<0oooo1@0000020?ooo`@0
00000P3oool9000000P0oooo00<000000?ooo`0000001@0000000`3oool000000?ooo`0=0?ooo`07
0000003oool000000000003oool000000?ooo`02000000l0oooo0P000000103oool000000000003o
ool3000000l0oooo0P000000203oool00000000000000000oooo0000003oool000002`3oool20000
00050?ooo`00000000000000003oool00P0000090?ooo`030000003oool0000000@000001P3oool5
000000<0oooo0P00000C0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
00l0oooo1`0000030?ooo`<0000000<0oooo0000000000000P0000050?ooo`<0000000<0oooo0000
003oool01@0000070?ooo`80000000@0oooo00000000000000000`3oool3000000030?ooo`000000
oooo00L0oooo0`0000000`3oool00000000000040?ooo`030000003oool0000000800000203oool0
1`000000oooo0000003oool000000?ooo`000000103oool2000000040?ooo`000000oooo000000P0
oooo0`0000000`3oool00000000000030?ooo`030000003oool0oooo00@000001`3oool4000000@0
oooo1@0000040?ooo`D000000P3oool400000080oooo2000000:0?ooo`<0000000L0oooo00000000
0000oooo0000003oool0000000h0oooo0P000000103oool000000000003oool2000000l0oooo00<0
00000?ooo`000000100000000`3oool000000000000>0?ooo`80000000@0oooo0000000000000000
0P3oool2000000/0oooo00<000000?ooo`000000100000000`3oool000000?ooo`090?ooo`H00000
1`3oool4000000<0oooo0`00000B0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo00l0oooo1`0000020?ooo`P000001P3oool400000080oooo00<000000?ooo`0000000P00
00060?ooo`050000003oool000000000003oool00P0000030?ooo`@00000203oool01@000000oooo
000000000000oooo008000000`3oool010000000oooo0000003oool2000000P0oooo00L000000?oo
o`000000oooo0000003oool0000000@0oooo0`0000000`3oool000000?ooo`070?ooo`80000000D0
oooo000000000000oooo000000030?ooo`030000003oool000000080000000<0oooo0000003oool0
1@3oool2000000030?ooo`000000oooo00<0oooo0P0000000`3oool0000000000002000000<0oooo
1@0000020?ooo`<000000`3oool8000000X0oooo00<000000?ooo`0000001@0000000`3oool00000
0?ooo`0=0?ooo`030000003oool0000000<0000000<0oooo0000000000003`3oool2000000040?oo
o`00000000000?ooo`<000003P3oool01@000000oooo000000000000oooo0080000000@0oooo0000
003oool000002`3oool3000000040?ooo`00000000000?ooo`8000002@3oool6000000L0oooo1@00
00030?ooo`8000004P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0>
0?ooo`L000000`3oool8000000H0oooo100000000`3oool0000000000003000000L0oooo00<00000
0?ooo`0000000P000000103oool000000?ooo`3oool3000000030?ooo`000000oooo00L0oooo00D0
00000?ooo`00000000000?ooo`02000000<0oooo00<000000?ooo`0000000P0000090?ooo`800000
00D0oooo000000000000oooo000000030?ooo`80000000@0oooo0000003oool00000203oool30000
00030?ooo`000000000000<0oooo00<000000?ooo`3oool0100000070?ooo`@00000103oool30000
00040?ooo`0000000000000000<0oooo1@0000000`3oool0000000000002000000<0oooo1`00000<
0?ooo`@0000000H0oooo0000003oool000000?ooo`00000=0?ooo`030000003oool0000000D00000
00<0oooo0000003oool03@3oool2000000030?ooo`00000000000080000000<0oooo000000000000
3P3oool2000000080?ooo`00000000000000003oool000000?ooo`00000;0?ooo`80000000<0oooo
0000000000000P0000000`3oool000000?ooo`080?ooo`L000001P3oool5000000<0oooo0P00000B
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00h0oooo1`0000020?oo
o`050000003oool000000000003oool0100000050?ooo`080000003oool000000?ooo`000000oooo
0000003oool3000000L0oooo0P000000103oool000000000000000030?ooo`@000002@3oool30000
00030?ooo`000000000000<0oooo00@000000?ooo`000000oooo0P0000080?ooo`040000003oool0
00000?ooo`<00000103oool3000000030?ooo`000000oooo00L0oooo00D000000?ooo`0000000000
0?ooo`02000000<0oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`050?ooo`800000
00<0oooo0000000000000`3oool2000000030?ooo`000000000000@000000P3oool9000000@0oooo
2000000;0?ooo`030000003oool0000000@0000000<0oooo0000000000003P3oool6000000030?oo
o`000000000000h0oooo00<000000?ooo`0000000`000000103oool0000000000000000>0?ooo`80
000000<0oooo0000000000000P0000000`3oool000000000000;0?ooo`030000003oool0000000@0
000000<0oooo0000000000002@3oool2000000040?ooo`000000oooo000000H0oooo1P0000020?oo
o`<000004@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0>0?ooo`L0
00000P3oool8000000H0oooo100000020?ooo`030000003oool00000008000001P3oool010000000
oooo0000003oool300000080oooo00D000000?ooo`000000oooo000000080?ooo`050000003oool0
00000000003oool00P0000030?ooo`030000003oool00000008000002@3oool01`000000oooo0000
003oool000000?ooo`0000000`3oool2000000040?ooo`000000oooo000000P0oooo0P000000103o
ool000000000000000030?ooo`030000003oool0oooo00@000001`3oool2000000030?ooo`000000
oooo00<0oooo0`000000103oool000000?ooo`3oool2000000030?ooo`000000000000P000000`3o
ool9000000/0oooo00<000000?ooo`00000010000000103oool000000?ooo`00000=0?ooo`D00000
00<0oooo0000003oool00P00000>0?ooo`80000000H0oooo000000000000oooo0000003oool20000
00d0oooo00D000000?ooo`00000000000?ooo`02000000040?ooo`000000oooo000000X0oooo00D0
00000?ooo`00000000000?ooo`02000000030?ooo`000000000000T0oooo1P0000070?ooo`D00000
0P3oool300000140oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool03@3o
ool800000080oooo200000060?ooo`@0000000<0oooo0000000000000`0000070?ooo`030000003o
ool000000080000000@0oooo0000003oool0oooo100000090?ooo`050000003oool000000000003o
ool00P0000020?ooo`040000003oool000000?ooo`800000203oool00`000000oooo0?ooo`040000
00@0oooo0`0000000`3oool000000?ooo`080?ooo`<0000000<0oooo0000000000000`3oool00`00
0000oooo00000002000000030?ooo`000000oooo00H0oooo00@000000?ooo`00000000000`3oool2
000000040?ooo`000000000000000080oooo300000040?ooo`80000000<0oooo0000000000001@00
000;0?ooo`050000003oool000000000003oool00P0000000`3oool000000000000=0?ooo`050000
003oool000000000003oool00P0000000`3oool000000000000>0?ooo`030000003oool0000000<0
000000@0oooo00000000000000003P3oool5000000050?ooo`00000000000?ooo`0000002`3oool2
000000030?ooo`000000000000@000002@3oool5000000030?ooo`000000oooo00D0oooo1@000003
0?ooo`8000004@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0=0?oo
o`L000000`3oool3000000050?ooo`00000000000?ooo`0000001@3oool020000000oooo0000003o
ool000000?ooo`000000oooo0`0000070?ooo`80000000@0oooo00000000000000000P3oool01@00
0000oooo0000003oool0000000T0oooo0P000000103oool000000000000000030?ooo`030000003o
ool00000008000002@3oool010000000oooo0000003oool3000000<0oooo0P000000103oool00000
0?ooo`0000080?ooo`050000003oool000000000003oool00P0000030?ooo`030000003oool00000
00<000001`3oool2000000030?ooo`000000000000<0oooo0`0000000`3oool000000?ooo`020?oo
o`@0000000<0oooo0000000000001@0000040?ooo`X000002`3oool00`000000oooo000000060000
00030?ooo`000000oooo00`0oooo0P0000001P3oool000000000003oool000000?ooo`8000003@3o
ool00`000000oooo00000003000000030?ooo`000000oooo008000003@3oool2000000030?ooo`00
000000000080000000<0oooo0000000000002`3oool2000000030?ooo`00000000000080000000<0
oooo000000000000203oool3000000040?ooo`0000000000000000H0oooo1P0000020?ooo`<00000
403oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0=0?ooo`L000000P3o
ool01@000000oooo000000000000oooo0080000000<0oooo0000003oool0103oool3000000030?oo
o`00000000000080000000<0oooo0000003oool01`3oool2000000040?ooo`000000000000000080
oooo1000000:0?ooo`<0000000<0oooo0000000000000P3oool010000000oooo0000003oool20000
00T0oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`020?ooo`<0000000<0oooo0000
003oool0203oool3000000030?ooo`000000000000<0oooo00<000000?ooo`0000000P0000000`3o
ool000000?ooo`060?ooo`80000000<0oooo0000003oool00P3oool2000000040?ooo`0000000000
000000@0oooo1@0000000`3oool0000000000003000000<0oooo3000000:0?ooo`030000003oool0
000000D0000000<0oooo0000000000003@3oool2000000030?ooo`00000000000080000000<0oooo
0000000000003@3oool010000000oooo0000003oool3000000040?ooo`0000000000000000d0oooo
00<000000?ooo`00000010000000103oool000000?ooo`00000:0?ooo`070000003oool000000000
003oool000000?ooo`03000000T0oooo1P0000070?ooo`D000000P3oool300000100oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool03@3oool700000080oooo200000050?oo
o`060000003oool000000?ooo`000000oooo1@0000070?ooo`050000003oool000000000003oool0
0P0000000`3oool000000?ooo`03000000T0oooo00D000000?ooo`00000000000?ooo`0200000080
oooo00<000000?ooo`0000000P0000090?ooo`030000003oool0oooo00@000000`3oool200000004
0?ooo`000000oooo000000T0oooo0`0000000`3oool00000000000030?ooo`80000000@0oooo0000
0000000000001`3oool00`000000oooo00000002000000<0oooo0`0000000`3oool000000?ooo`04
0?ooo`D0000000<0oooo0000000000000`0000030?ooo``000002P3oool00`000000oooo0?ooo`02
000000030?ooo`00000000000080000000<0oooo0000003oool02`3oool2000000070?ooo`000000
00000000003oool000000?ooo`02000000d0oooo00<000000?ooo`0000000`000000103oool00000
00000000000=0?ooo`030000003oool0000000H0000000<0oooo0000003oool02@3oool01@000000
oooo000000000000oooo00@0000000<0oooo0000003oool01`3oool5000000030?ooo`000000oooo
00D0oooo1@0000020?ooo`<00000403oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`0<0?ooo`L000000`3oool8000000D0oooo00@000000?ooo`000000oooo0`000000103o
ool000000000000000070?ooo`030000003oool0000000<000000P3oool00`000000oooo00000002
000000T0oooo00D000000?ooo`00000000000?ooo`0200000080oooo0P0000000`3oool000000000
00090?ooo`040000003oool000000?ooo`<000000`3oool3000000030?ooo`000000oooo00P0oooo
00D000000?ooo`00000000000?ooo`0200000080oooo00D000000?ooo`00000000000?ooo`020000
00L0oooo0P0000000`3oool00000000000020?ooo`80000000@0oooo00000000000000001@3oool4
00000080oooo1P0000000`3oool0000000000003000000030?ooo`000000000000@0000000<0oooo
0000003oool02@3oool00`000000oooo00000005000000030?ooo`000000000000d0oooo0P000000
0`3oool0000000000002000000030?ooo`000000000000d0oooo00<000000?ooo`0000001@000000
0`3oool000000000000=0?ooo`80000000<0oooo0000000000000P0000000`3oool000000000000;
0?ooo`80000000D0oooo00000000000000000?ooo`03000000P0oooo1`0000060?ooo`D000000`3o
ool3000000l0oooo00<000000?ooo`3oool00P3oool004/0oooo0P00000=0?ooo`L000000`3oool3
000000050?ooo`00000000000?ooo`0000001@3oool3000000030?ooo`000000000000@00000203o
ool2000000070?ooo`00000000000000003oool000000?ooo`03000000X0oooo0P000000103oool0
00000000000000020?ooo`060000003oool000000000003oool000002@3oool00`000000oooo0000
0002000000060?ooo`000000oooo0?ooo`000000oooo0P0000000`3oool000000?ooo`080?ooo`03
0000003oool000000080oooo0P0000020?ooo`80000000@0oooo0000000000000000203oool30000
00040?ooo`000000oooo0?ooo`<0000000<0oooo0000003oool01@3oool4000000030?ooo`000000
000000D0000000<0oooo0000000000001@0000000`3oool0000000000004000000X0oooo00@00000
0?ooo`000000oooo0`0000001@3oool000000000003oool0000000`0oooo0P0000000`3oool00000
0000000200000080oooo0P00000<0?ooo`040000003oool000000?ooo`<0000000@0oooo00000000
000000003@3oool00`000000oooo00000002000000060?ooo`00000000000000003oool000002P3o
ool2000000050?ooo`00000000000000003oool00`0000090?ooo`80000000@0oooo000000000000
00001P3oool00`000000oooo0000000300000080oooo0`00000=0?ooo`<00000103oool004/0oooo
00<000000?ooo`3oool0303oool7000000<0oooo1`0000050?ooo`060000003oool000000?ooo`00
0000oooo1@0000080?ooo`80000000L0oooo00000000000000000?ooo`000000oooo00<000002P3o
ool3000000030?ooo`00000000000080oooo0P0000000`3oool00000000000090?ooo`030000003o
ool0oooo00<0000000@0oooo0000003oool0oooo0P0000000`3oool000000000000:0?ooo`<00000
00<0oooo0000000000000P3oool01@000000oooo000000000000oooo00800000203oool400000080
oooo0P000000103oool000000000000000050?ooo`030000003oool000000080000000<0oooo0000
000000002P0000000`3oool0000000000007000000X0oooo00@000000?ooo`000000oooo1P000000
0`3oool000000?ooo`0;0?ooo`80000000L0oooo00000000000000000?ooo`000000oooo00800000
303oool010000000oooo0000003oool2000000040?ooo`00000000000?ooo`800000303oool00`00
0000oooo00000006000000030?ooo`000000oooo00T0oooo00D000000?ooo`00000000000?ooo`04
000000030?ooo`000000oooo00L0oooo1`0000060?ooo`D000000P3oool3000000l0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0303oool00`000000oooo000000030000
00<0oooo200000050?ooo`040000003oool000000?ooo`80000000@0oooo0000003oool00000203o
ool01P000000oooo000000000000oooo00000080oooo0P0000000`3oool00000000000090?ooo`05
0000003oool000000000003oool00P0000020?ooo`<0000000<0oooo0000003oool0203oool01000
0000oooo0000003oool3000000<0oooo0`0000000`3oool000000?ooo`080?ooo`050000003oool0
00000000003oool00P0000020?ooo`80000000D0oooo000000000000oooo000000070?ooo`030000
003oool00000008000000P3oool3000000030?ooo`000000oooo00D0oooo4P0000000`3oool00000
0?ooo`08000000X0oooo00<000000?ooo`000000100000001@3oool000000000003oool0000000`0
oooo00<000000?ooo`3oool0100000000`3oool000000000000=0?ooo`030000003oool000000080
000000@0oooo000000000000oooo0P00000=0?ooo`80000000<0oooo0000000000000P000000103o
ool000000?ooo`0000090?ooo`050000003oool000000000003oool00`0000000`3oool000000000
00080?ooo`L000001P3oool500000080oooo0`00000?0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo00/0oooo1`0000030?ooo`P000001@3oool3000000030?ooo`000000
000000@00000203oool2000000040?ooo`000000000000000080oooo0P0000000`3oool000000000
00090?ooo`060000003oool000000000003oool000000P3oool2000000040?ooo`000000oooo0000
00T0oooo00D000000?ooo`00000000000?ooo`0200000080oooo00H000000?ooo`00000000000?oo
o`0000090?ooo`050000003oool000000000003oool00P0000000`3oool000000?ooo`0200000003
0?ooo`000000000000P0oooo0`0000001@3oool000000?ooo`000000oooo0080000000<0oooo0000
003oool01@3ooolA00000080oooo00@000000?ooo`000000oooo1P00000:0?ooo`030000003oool0
000000@0000000D0oooo000000000000oooo0000000<0?ooo`80000000<0oooo0000000000000P00
00020?ooo`800000303oool010000000oooo0000003oool2000000060?ooo`00000000000000003o
ool00000303oool00`000000oooo00000002000000060?ooo`00000000000000003oool000002P3o
ool2000000050?ooo`00000000000000003oool00`0000080?ooo`L000001P3oool5000000<0oooo
0`00000>0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00/0oooo0`00
0000103oool000000000000000030?ooo`L000001P3oool3000000030?ooo`000000000000@00000
203oool2000000070?ooo`00000000000000003oool000000?ooo`03000000X0oooo0`0000000`3o
ool00000000000020?ooo`80000000<0oooo0000000000002P3oool00`000000oooo000000020000
00040?ooo`000000oooo0?ooo`80000000<0oooo0000000000002P3oool3000000050?ooo`000000
oooo0000003oool00P0000000`3oool000000?ooo`02000000P0oooo100000020?ooo`<0000000<0
oooo0000000000001P3oool:000000030?ooo`000000000000@0000000<0oooo0000000000000P3o
ool3000000050?ooo`00000000000?ooo`0000002@3oool010000000oooo0000003oool600000080
oooo00<000000?ooo`3oool02@3oool2000000070?ooo`00000000000000003oool000000?ooo`02
000000`0oooo00@000000?ooo`000000oooo0P000000103oool000000000003oool2000000`0oooo
00<000000?ooo`0000000P0000001P3oool00000000000000000oooo000000X0oooo0P0000001@3o
ool00000000000000000oooo00<000002@3oool2000000030?ooo`0000000000008000001@3oool0
0`000000oooo0000000300000080oooo0`00000>0?ooo`030000003oool0oooo0080oooo001;0?oo
o`030000003oool0oooo00/0oooo1`0000030?ooo`L000001P3oool2000000040?ooo`0000000000
0?ooo`@00000203oool2000000050?ooo`00000000000000003oool00P0000000`3oool000000000
00090?ooo`050000003oool000000000003oool00P0000020?ooo`<0000000<0oooo0000003oool0
203oool00`000000oooo0?ooo`03000000050?ooo`000000oooo0000003oool00P0000000`3oool0
00000?ooo`090?ooo`<0000000<0oooo0000000000000P3oool3000000030?ooo`000000000000T0
oooo100000020?ooo`<0000000<0oooo0000003oool01@3oool00`000000oooo0000000?00000003
0?ooo`000000oooo0080oooo200000090?ooo`040000003oool000000?ooo`@0000000D0oooo0000
00000000oooo0000000;0?ooo`80000000<0oooo0000000000000`0000000`3oool000000000000<
0?ooo`040000003oool000000?ooo`D0000000@0oooo0000003oool000002`3oool01@000000oooo
000000000000oooo00<0000000@0oooo0000003oool000002@3oool2000000030?ooo`000000oooo
00@0000000<0oooo0000003oool01`3oool00`000000oooo00000004000000H0oooo1@0000020?oo
o`<000003P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0000000<00000103oool7000000D0oooo00@000000?ooo`000000oooo100000000`3o
ool000000?ooo`070?ooo`030000003oool0000000<000000P3oool2000000030?ooo`0000000000
00T0oooo00D000000?ooo`00000000000?ooo`0200000080oooo00@000000?ooo`00000000002P3o
ool010000000oooo0000003oool300000080oooo00H000000?ooo`00000000000?ooo`0000090?oo
o`050000003oool000000000003oool00P0000001P3oool000000000003oool000000?ooo`800000
2@3oool4000000040?ooo`00000000000?ooo`<000001P3oool4000000030?ooo`00000000000080
000000<0oooo0000000000001@0000000`3oool00000000000030?ooo`P000002P3oool00`000000
oooo00000003000000060?ooo`00000000000000003oool00000303oool00`000000oooo0?ooo`03
000000030?ooo`000000oooo00800000303oool2000000030?ooo`00000000000080000000D0oooo
000000000000oooo0000000<0?ooo`80000000D0oooo00000000000000000?ooo`02000000030?oo
o`000000oooo00P0oooo00D000000?ooo`00000000000?ooo`03000000030?ooo`000000000000P0
oooo1`0000060?ooo`D000000P3oool3000000h0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool02P3oool7000000<0oooo200000050?ooo`<0000000<0oooo000000000000
100000080?ooo`80000000@0oooo00000000000000000P3oool3000000030?ooo`000000oooo00P0
oooo00H000000?ooo`00000000000?ooo`0000020?ooo`80000000<0oooo0000000000002P3oool0
0`000000oooo00000002000000060?ooo`000000oooo0?ooo`000000oooo0`00000:0?ooo`030000
003oool000000080000000<0oooo0000003oool00P0000001@3oool000000000003oool0000000P0
oooo100000020?ooo`<0000000<0oooo0000000000001P3oool4000000030?ooo`00000000000080
00000P3oool6000000030?ooo`000000000000@0oooo1P0000000`3oool000000?ooo`080?ooo`03
0000003oool0000000L0000000<0oooo0000003oool02`3oool2000000070?ooo`00000000000000
003oool000000?ooo`02000000`0oooo00@000000?ooo`000000oooo0P0000001P3oool000000000
00000000oooo000000`0oooo00<000000?ooo`0000000P0000001P3oool00000000000000000oooo
000000X0oooo0P0000001@3oool00000000000000000oooo00<00000203oool8000000D0oooo1@00
00030?ooo`8000003P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0:
0?ooo`L000000`3oool7000000H0oooo0`0000000`3oool0000000000004000000P0oooo0P000000
1@3oool00000000000000000oooo0080000000<0oooo0000000000002P3oool3000000030?ooo`00
000000000080oooo0P0000000`3oool000000000000:0?ooo`030000003oool000000080000000D0
oooo0000003oool000000?ooo`02000000030?ooo`000000oooo00T0oooo0P000000103oool00000
0000000000020?ooo`<0000000<0oooo0000000000002@3oool400000080oooo00H000000?ooo`00
000000000?ooo`0000060?ooo`P000000`3oool6000000030?ooo`000000000000@0oooo0`000000
0`3oool0000000000002000000T0oooo00@000000?ooo`000000oooo100000001@3oool000000000
003oool0000000/0oooo0P0000000`3oool0000000000003000000040?ooo`000000oooo000000/0
oooo00@000000?ooo`000000oooo1@000000103oool000000?ooo`00000;0?ooo`030000003oool0
00000080000000<0oooo0000003oool00P0000000`3oool000000?ooo`080?ooo`80000000@0oooo
000000000000oooo100000080?ooo`<0000000D0oooo000000000000oooo000000050?ooo`H00000
0P3oool3000000d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02P3o
ool7000000<0oooo1`0000060?ooo`D0000000<0oooo0000000000000P0000080?ooo`80000000D0
oooo00000000000000000?ooo`02000000030?ooo`000000000000T0oooo00D000000?ooo`000000
00000?ooo`0200000080oooo1000000:0?ooo`040000003oool000000?ooo`80000000D0oooo0000
003oool000000?ooo`02000000030?ooo`000000oooo00T0oooo0`0000000`3oool0000000000002
0?ooo`<0000000<0oooo0000000000002@3oool400000080oooo00<000000?ooo`0000000P000007
0?ooo`<0000000<0oooo0000000000000P0000030?ooo`H0000000<0oooo0000003oool0103oool8
000000X0oooo0P0000001@3oool00000000000000000oooo00<0000000<0oooo0000003oool02P3o
ool2000000030?ooo`00000000000080000000<0oooo0000003oool00P00000;0?ooo`040000003o
ool000000?ooo`D0000000@0oooo0000003oool000002`3oool010000000oooo0000003oool30000
00050?ooo`00000000000?ooo`0000002@3oool2000000030?ooo`000000oooo00<0000000<0oooo
000000000000203oool00`000000oooo00000004000000H0oooo1@0000020?ooo`<000003@3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool00000
00@000000`3oool7000000H0oooo1`0000000`3oool00000000000080?ooo`80000000H0oooo0000
003oool000000?ooo`0000020?ooo`8000002@3oool01@000000oooo000000000000oooo00800000
00@0oooo000000000000oooo0P00000:0?ooo`040000003oool000000?ooo`80000000D0oooo0000
003oool000000?ooo`03000000X0oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`02
000000050?ooo`00000000000?ooo`0000002@3oool4000000050?ooo`00000000000000003oool0
0P0000060?ooo`@0000000<0oooo0000000000000`0000020?ooo`P000001P3oool8000000T0oooo
00<000000?ooo`0000001@000000103oool000000?ooo`00000;0?ooo`8000000P3oool300000003
0?ooo`000000oooo00800000303oool2000000030?ooo`000000oooo0080000000D0oooo00000000
0000oooo0000000;0?ooo`040000003oool000000?ooo`<0000000D0oooo000000000000oooo0000
00090?ooo`050000003oool000000000003oool00`0000000`3oool00000000000080?ooo`L00000
1P3oool500000080oooo0`00000=0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo00X0oooo1P0000040?ooo`030000003oool0000000<000001`3oool2000000030?ooo`00
000000000080000000<0oooo0000003oool01`3oool00`000000oooo0000000300000080oooo00D0
00000?ooo`000000oooo000000090?ooo`060000003oool000000000003oool000000P3oool20000
00030?ooo`000000000000X0oooo00<000000?ooo`0000000P0000001`3oool000000?ooo`000000
oooo0000003oool00P00000:0?ooo`030000003oool000000080000000<0oooo0000003oool00P00
0000103oool000000000000000090?ooo`040000003oool0000000000080oooo100000000`3oool0
00000?ooo`050?ooo`@0000000<0oooo0000000000000`0000020?ooo`P000001P3oool300000003
0?ooo`0000000000008000002@3oool00`000000oooo00000002000000030?ooo`000000oooo00@0
0000303oool2000000030?ooo`000000000000<0000000@0oooo0000003oool000002`3oool01`00
0000oooo000000000000oooo0000003oool00P0000000`3oool000000000000<0?ooo`80000000T0
oooo000000000000oooo0000003oool000000?ooo`0000002P3oool3000000050?ooo`0000000000
0000003oool00P0000080?ooo`P000001@3oool500000080oooo0`00000=0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo00T0oooo1`0000030?ooo`80000000<0oooo0000
000000000P0000060?ooo`060000003oool000000?ooo`000000oooo100000080?ooo`80000000D0
oooo00000000000000000?ooo`02000000030?ooo`000000000000X0oooo0P000000103oool00000
0000000000020?ooo`80000000<0oooo0000003oool02P3oool00`000000oooo0000000200000005
0?ooo`000000oooo0000003oool00P0000000`3oool000000?ooo`090?ooo`80000000@0oooo0000
0000000000000P3oool3000000030?ooo`000000000000T0oooo100000020?ooo`060000003oool0
00000000003oool000001P3oool00`000000oooo00000003000000040?ooo`000000000000000080
oooo200000060?ooo`<0000000H0oooo00000000000000000?ooo`0000080?ooo`040000003oool0
00000?ooo`<0000000H0oooo00000000000000000?ooo`00000;0?ooo`80000000<0oooo00000000
00000P0000001@3oool000000000003oool0000000/0oooo00D000000?ooo`00000000000?ooo`04
000000040?ooo`000000oooo000000/0oooo0P0000001P3oool000000000003oool000000?ooo`80
000000<0oooo0000003oool0203oool2000000040?ooo`00000000000?ooo`@00000203oool30000
00030?ooo`0000000000008000001@3oool600000080oooo0`00000<0?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo00T0oooo1`0000030?ooo`L000001P3oool500000003
0?ooo`000000000000800000203oool2000000050?ooo`00000000000000003oool00P0000000`3o
ool000000000000:0?ooo`<0000000H0oooo000000000000oooo0000003oool3000000X0oooo00<0
00000?ooo`3oool00`0000000`3oool00000000000020?ooo`80000000<0oooo0000003oool02@3o
ool2000000040?ooo`000000000000000080oooo0`0000000`3oool00000000000090?ooo`@00000
00L0oooo000000000000oooo0000003oool0000000L0oooo00@000000?ooo`000000oooo0P000000
0`3oool0000000000002000000030?ooo`000000000000D000001`3oool6000000030?ooo`000000
000000T0oooo0P0000002P3oool00000000000000000oooo0000003oool000000?ooo`00000;0?oo
o`80000000<0oooo0000000000000P0000000`3oool000000?ooo`02000000/0oooo00@000000?oo
o`000000oooo100000001@3oool000000000003oool0000000/0oooo00D000000?ooo`0000000000
0?ooo`02000000050?ooo`00000000000?ooo`0000002@3oool2000000040?ooo`00000000000?oo
o`80000000<0oooo0000000000001`3oool3000000050?ooo`00000000000?ooo`0000001P3oool5
00000080oooo0`00000<0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
00T0oooo1`0000030?ooo`L000001P3oool7000000030?ooo`000000000000P0oooo0P0000001@3o
ool000000?ooo`000000oooo0080000000<0oooo0000000000002@3oool01@000000oooo00000000
0000oooo0080000000@0oooo000000000000oooo0P00000:0?ooo`040000003oool000000?ooo`80
000000<0oooo0000000000000P3oool3000000X0oooo00<000000?ooo`0000000P0000001@3oool0
00000?ooo`000000oooo00<0000000<0oooo0000003oool0203oool4000000030?ooo`0000000000
0080000000<0oooo0000003oool01@3oool4000000040?ooo`00000000000?ooo`@0000000<0oooo
0000000000001P0000070?ooo`030000003oool0000000D000002@3oool00`000000oooo00000005
000000040?ooo`0000000000000000/0oooo0P0000000`3oool000000?ooo`02000000060?ooo`00
0000oooo0000003oool000002`3oool2000000050?ooo`000000oooo0000003oool00`0000000`3o
ool000000?ooo`0:0?ooo`040000003oool000000?ooo`<0000000D0oooo000000000000oooo0000
00090?ooo`80000000<0oooo0000003oool00`0000000`3oool00000000000080?ooo`L000001P3o
ool500000080oooo0`00000<0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo00T0oooo1`0000030?ooo`030000003oool0000000<000001`3oool7000000030?ooo`000000
000000L0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000000T0oooo00D000000?ooo`00000000000?ooo`02000000040?ooo`00000000000?ooo`800000
2P3oool01`000000oooo000000000000oooo0000003oool00P0000001@3oool000000000003oool0
000000X0oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`03000000030?ooo`000000
000000X0oooo0`0000020?ooo`@0000000<0oooo0000003oool01@3oool8000000030?ooo`000000
000000X000001`3oool010000000oooo0000003oool4000000T0oooo00D000000?ooo`0000000000
0?ooo`02000000030?ooo`000000000000800000303oool2000000030?ooo`000000000000<00000
00@0oooo0000003oool000002`3oool2000000050?ooo`000000oooo0000003oool00P0000000`3o
ool000000000000;0?ooo`040000003oool000000?ooo`80000000H0oooo0000003oool000000?oo
o`0000090?ooo`050000003oool000000000003oool00`0000000`3oool00000000000080?ooo`L0
00001P3oool500000080oooo0`00000<0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo00T0oooo1P0000040?ooo`030000003oool0000000<000001`3oool7000000030?oo
o`000000000000L0oooo00<000000?ooo`0000000`0000020?ooo`040000003oool00000000000X0
oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`02000000030?ooo`000000oooo00X0
oooo00<000000?ooo`0000000P0000001@3oool000000?ooo`000000oooo0080000000<0oooo0000
003oool02@3oool2000000040?ooo`000000000000000080oooo0`0000000`3oool0000000000009
0?ooo`@000000P3oool01P000000oooo000000000000oooo000000H0oooo1P0000000`3oool00000
0?ooo`0<000000L0oooo0`0000001P3oool00000000000000000oooo000000P0oooo00D000000?oo
o`00000000000?ooo`02000000060?ooo`000000oooo0000003oool000002`3oool2000000030?oo
o`00000000000080000000D0oooo000000000000oooo0000000;0?ooo`80000000<0oooo0000003o
ool00`0000001@3oool000000000003oool0000000/0oooo0P0000000`3oool00000000000020000
00040?ooo`0000000000000000X0oooo0`0000000`3oool0000000000004000000P0oooo0`000000
0`3oool0000000000002000000D0oooo0`0000000`3oool00000000000020?ooo`800000303oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`080?ooo`L000000`3oool70000
00L0oooo100000000`3oool0000000000002000000P0oooo00<000000?ooo`0000000`000000103o
ool000000000003oool2000000X0oooo0P0000001`3oool00000000000000000oooo0000003oool0
0`00000;0?ooo`030000003oool000000080000000<0oooo0000000000000P3oool3000000/0oooo
0P0000001`3oool00000000000000000oooo0000003oool00P0000000`3oool00000000000090?oo
o`@0000000<0oooo0000000000000P0000000`3oool000000?ooo`060?ooo`030000003oool00000
00<0000000@0oooo0000003oool0oooo300000060?ooo`H0000000<0oooo000000000000203oool0
1@000000oooo000000000000oooo00@0000000@0oooo00000000000000002`3oool2000000030?oo
o`00000000000080000000<0oooo0000003oool00P00000;0?ooo`050000003oool000000000003o
ool00`0000001@3oool000000000003oool0000000/0oooo0P0000000`3oool00000000000020000
00050?ooo`00000000000?ooo`0000002@3oool2000000040?ooo`00000000000?ooo`@00000203o
ool3000000030?ooo`0000000000008000001@3oool600000080oooo0`00000;0?ooo`030000003o
ool0oooo0080oooo001;0?ooo`8000002@3oool7000000<0oooo1`0000060?ooo`L0000000<0oooo
000000000000203oool2000000050?ooo`000000oooo0000003oool00P0000000`3oool000000000
000:0?ooo`80000000D0oooo00000000000000000?ooo`02000000030?ooo`000000000000/0oooo
00<000000?ooo`0000000P0000000`3oool00000000000020?ooo`030000003oool0000000X0oooo
00@000000?ooo`000000oooo0`0000000`3oool000000?ooo`03000000030?ooo`000000oooo00P0
oooo100000000`3oool0000000000002000000030?ooo`000000oooo00H0oooo00<000000?ooo`00
00000`000000103oool000000?ooo`3oool6000000030?ooo`000000000000<000001P3oool90000
00T0oooo00<000000?ooo`0000001@000000103oool0000000000000000;0?ooo`80000000/0oooo
000000000000oooo0000003oool000000?ooo`000000oooo0000000;0?ooo`80000000D0oooo0000
003oool000000?ooo`03000000030?ooo`000000oooo00X0oooo0P0000000`3oool000000?ooo`02
000000050?ooo`00000000000?ooo`0000002@3oool2000000040?ooo`00000000000?ooo`@00000
203oool2000000030?ooo`000000000000<000001@3oool600000080oooo0`0000090?ooo`<00000
103oool004/0oooo00<000000?ooo`3oool0203oool7000000<0oooo1`0000060?ooo`L0000000<0
oooo0000000000001`3oool020000000oooo0000003oool000000?ooo`000000oooo0`0000000`3o
ool000000?ooo`090?ooo`80000000D0oooo00000000000000000?ooo`02000000030?ooo`000000
000000X0oooo00<000000?ooo`3oool00`000000103oool000000000003oool2000000030?ooo`00
0000oooo00T0oooo00D000000?ooo`00000000000?ooo`02000000080?ooo`000000oooo0000003o
ool000000?ooo`0000090?ooo`80000000<0oooo0000003oool0100000000`3oool000000?ooo`05
0?ooo`80000000<0oooo0000000000000`0000030?ooo``000001P3oool2000000030?ooo`000000
000000@000002@3oool00`000000oooo00000005000000040?ooo`0000000000000000/0oooo0P00
00000`3oool000000?ooo`02000000060?ooo`000000oooo0000003oool000002`3oool200000005
0?ooo`000000oooo0000003oool00P0000000`3oool000000000000;0?ooo`070000003oool00000
0000003oool000000?ooo`03000000030?ooo`000000oooo00P0oooo00<000000?ooo`0000000P00
0000103oool000000000003oool2000000L0oooo0P0000000`3oool0000000000003000000H0oooo
1@0000020?ooo`<000002`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`080?ooo`L000000`3oool6000000L0oooo1`0000000`3oool00000000000070?ooo`030000003o
ool000000080000000<0oooo0000003oool00`0000000`3oool000000?ooo`080?ooo`050000003o
ool000000000003oool00P000000103oool000000000003oool2000000X0oooo00D000000?ooo`00
000000000?ooo`02000000030?ooo`000000oooo00<000002`3oool2000000060?ooo`0000000000
0?ooo`000000oooo0`0000000`3oool000000000000:0?ooo`80000000<0oooo0000003oool00P00
0000103oool000000?ooo`0000060?ooo`H0000000<0oooo0000003oool00P3oool<000000L0oooo
00@000000?ooo`000000oooo100000090?ooo`050000003oool000000000003oool00P0000001P3o
ool00000000000000000oooo000000X0oooo00@000000?ooo`000000oooo1@000000103oool00000
0?ooo`00000;0?ooo`80000000<0oooo0000003oool00`0000001@3oool000000000003oool00000
00/0oooo0P0000000`3oool0000000000003000000030?ooo`000000000000T0oooo00<000000?oo
o`0000000P0000000`3oool0000000000003000000L0oooo0P000000103oool000000000003oool2
000000H0oooo1@0000030?ooo`8000002`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`00
0000oooo0?ooo`080?ooo`L000000`3oool2000000040?ooo`0000000000000000L0oooo1`000000
0`3oool00000000000070?ooo`030000003oool000000080000000D0oooo00000000000000000?oo
o`02000000X0oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`03000000030?ooo`00
0000oooo00T0oooo00<000000?ooo`0000000P0000001@3oool000000?ooo`000000oooo00<00000
2`3oool2000000070?ooo`00000000000000003oool000000?ooo`02000000030?ooo`0000000000
00T0oooo00D000000?ooo`00000000000?ooo`03000000030?ooo`000000000000L0oooo1P000000
0`3oool000000?ooo`020?ooo`d000001P3oool7000000030?ooo`000000oooo00L0oooo00D00000
0?ooo`00000000000?ooo`02000000030?ooo`000000oooo00<000002P3oool010000000oooo0000
003oool4000000050?ooo`00000000000?ooo`0000002`3oool2000000030?ooo`000000oooo00<0
000000D0oooo000000000000oooo0000000;0?ooo`80000000<0oooo0000000000000P000000103o
ool000000000000000090?ooo`030000003oool000000080000000<0oooo0000000000000`000008
0?ooo`P000001@3oool5000000<0oooo0P00000;0?ooo`030000003oool0oooo0080oooo001;0?oo
o`030000003oool0oooo00L0oooo1`0000040?ooo`H000001`3oool3000000040?ooo`0000000000
0?ooo`800000203oool00`000000oooo00000003000000040?ooo`00000000000?ooo`8000002P3o
ool2000000080?ooo`00000000000?ooo`000000oooo0000003oool2000000/0oooo00<000000?oo
o`0000000P0000001@3oool000000?ooo`000000oooo00<000002P3oool010000000oooo0000003o
ool3000000030?ooo`000000oooo00<0000000<0oooo0000003oool0203oool4000000050?ooo`00
000000000000003oool00P0000070?ooo`H0000000<0oooo0000003oool00`3oool<000000H0oooo
2@0000080?ooo`050000003oool000000000003oool010000000103oool0000000000000000;0?oo
o`80000000<0oooo0000000000000P0000000`3oool000000?ooo`02000000/0oooo0P0000000`3o
ool000000?ooo`03000000050?ooo`00000000000?ooo`0000002`3oool2000000030?ooo`000000
00000080000000D0oooo000000000000oooo000000090?ooo`80000000@0oooo000000000000oooo
100000080?ooo`80000000<0oooo0000000000000`0000050?ooo`H000000P3oool3000000X0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01`3oool7000000@0oooo1P00
00070?ooo`@0000000<0oooo0000003oool00P0000080?ooo`030000003oool0000000<0000000H0
oooo00000000000000000?ooo`00000:0?ooo`80000000D0oooo00000000000000000?ooo`020000
00030?ooo`000000000000/0oooo00<000000?ooo`0000000P000000103oool000000000003oool2
000000030?ooo`000000oooo00T0oooo00@000000?ooo`000000oooo0`000000203oool000000?oo
o`000000oooo0000003oool000002@3oool4000000030?ooo`00000000000080000000<0oooo0000
003oool01P3oool7000000@0oooo1P0000000`3oool0000000000004000000H0oooo2@0000080?oo
o`050000003oool000000000003oool010000000103oool0000000000000000;0?ooo`80000000<0
oooo0000000000000P0000000`3oool000000?ooo`02000000/0oooo0P0000000`3oool000000?oo
o`02000000060?ooo`000000oooo0000003oool000002`3oool2000000030?ooo`00000000000080
000000D0oooo000000000000oooo000000090?ooo`80000000@0oooo000000000000oooo10000008
0?ooo`80000000<0oooo0000000000000`0000050?ooo`H000000P3oool3000000X0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01`3oool7000000<0oooo1`0000060?oo
o`L0000000<0oooo000000000000203oool00`000000oooo00000003000000060?ooo`0000000000
0000003oool000002P3oool2000000050?ooo`00000000000000003oool00P0000000`3oool00000
0000000;0?ooo`030000003oool000000080000000@0oooo000000000000oooo0P0000000`3oool0
00000?ooo`090?ooo`040000003oool000000?ooo`<0000000P0oooo0000003oool000000?ooo`00
0000oooo000000T0oooo100000000`3oool0000000000002000000030?ooo`000000oooo00H0oooo
00<000000?ooo`0000000P0000000`3oool000000?ooo`030?ooo`D000000P3oool2000000040?oo
o`0000000000000000H0oooo2@0000090?ooo`040000003oool000000?ooo`@0000000@0oooo0000
0000000000002`3oool200000080oooo1@000000103oool000000?ooo`00000:0?ooo`040000003o
ool000000?ooo`<0000000<0oooo0000003oool00P0000000`3oool000000?ooo`090?ooo`030000
003oool0000000<0000000H0oooo00000000000000000?ooo`0000090?ooo`80000000@0oooo0000
00000000oooo0P0000000`3oool000000?ooo`070?ooo`80000000<0oooo0000000000000`000006
0?ooo`D000000P3oool3000000X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool01`3oool7000000<0oooo1`0000060?ooo`L0000000<0oooo0000000000001`3oool01@00
0000oooo000000000000oooo0080000000H0oooo00000000000000000?ooo`00000:0?ooo`800000
00D0oooo00000000000000000?ooo`02000000030?ooo`000000000000/0oooo00<000000?ooo`00
00000P000000103oool000000000003oool2000000030?ooo`000000oooo00T0oooo00<000000?oo
o`0000000P000000103oool000000000003oool2000000030?ooo`000000000000X0oooo10000000
1`3oool000000000003oool000000?ooo`0000001P3oool6000000030?ooo`000000oooo00<0oooo
1@0000020?ooo`H000001`3oool2000000030?ooo`000000oooo00<000002@3oool010000000oooo
0000003oool3000000040?ooo`00000000000?ooo`8000002P3oool200000080oooo1@000000103o
ool000000?ooo`00000;0?ooo`80000000@0oooo000000000000oooo0P0000001@3oool000000000
003oool0000000/0oooo100000000`3oool0000000000002000000030?ooo`000000oooo00P0oooo
0P000000103oool000000000003oool2000000030?ooo`000000000000L0oooo0P0000000`3oool0
000000000003000000H0oooo1@0000020?ooo`<000002P3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`070?ooo`L000000`3oool7000000H0oooo0`0000001@3oool00000
000000000000oooo008000001`3oool00`000000oooo00000002000000030?ooo`000000oooo00<0
000000<0oooo0000003oool0203oool01@000000oooo000000000000oooo0080000000H0oooo0000
0000000000000?ooo`00000;0?ooo`80000000L0oooo0000003oool000000?ooo`000000oooo00<0
00002`3oool2000000040?ooo`00000000000?ooo`80000000@0oooo000000000000oooo0P00000:
0?ooo`80000000<0oooo0000000000000P0000000`3oool00000000000070?ooo`H0000000<0oooo
0000003oool00`3oool5000000030?ooo`000000000000D000001`3oool2000000030?ooo`000000
00000080000000<0oooo0000003oool01`3oool01@000000oooo000000000000oooo0080000000@0
oooo000000000000oooo0P00000:0?ooo`040000003oool000000?ooo`D0000000@0oooo0000003o
ool000002`3oool2000000030?ooo`000000oooo00<0000000D0oooo000000000000oooo0000000;
0?ooo`<0000000<0oooo0000000000000P0000000`3oool00000000000090?ooo`030000003oool0
00000080000000<0oooo0000000000000`0000070?ooo`80000000@0oooo000000000000oooo0`00
00050?ooo`D000000P3oool4000000T0oooo00<000000?ooo`3oool00P3oool000`0oooo00<0oono
07Ad_`3oool0?03oool00`000000oooo0?ooo`070?ooo`030000003oool0000000<00000103oool6
000000L0oooo0`0000001@3oool00000000000000000oooo008000001`3oool00`000000oooo0000
0002000000050?ooo`00000000000000003oool00P00000:0?ooo`030000003oool0000000800000
00<0oooo0000003oool00`0000000`3oool000000?ooo`090?ooo`030000003oool0000000800000
00<0oooo0000003oool00P0000000`3oool000000000000;0?ooo`80000000@0oooo000000000000
oooo0P000000103oool000000000003oool2000000T0oooo00@000000?ooo`000000oooo10000000
0`3oool00000000000070?ooo`<0000000<0oooo0000000000000P0000040?ooo`D0000000<0oooo
0000000000001P0000060?ooo`L0000000<0oooo0000003oool01`3oool01@000000oooo00000000
0000oooo0080000000<0oooo0000003oool00`00000:0?ooo`040000003oool000000?ooo`@00000
00D0oooo000000000000oooo0000000;0?ooo`80000000<0oooo0000003oool00`0000001@3oool0
00000000003oool0000000/0oooo0P0000000`3oool0000000000002000000050?ooo`0000000000
0?ooo`000000203oool01P000000oooo0000003oool000000?ooo`D000001`3oool2000000040?oo
o`00000000000?ooo`<000001@3oool5000000<0oooo0`0000090?ooo`030000003oool0oooo0080
oooo000<0?ooo`040?oOW0180000001809cOoc/0oooo00<000000?ooo`3oool01`3oool00`000000
oooo00000003000000@0oooo1P0000070?ooo`<0000000<0oooo0000000000000`0000080?ooo`03
0000003oool000000080000000<0oooo0000000000000P0000000`3oool000000?ooo`090?ooo`80
000000@0oooo000000000000oooo0P000000103oool0000000000000000;0?ooo`030000003oool0
00000080000000<0oooo0000003oool00P0000000`3oool000000000000;0?ooo`80000000L0oooo
00000000000000000?ooo`000000oooo00<0000000<0oooo0000003oool0203oool010000000oooo
0000003oool4000000030?ooo`000000000000L0oooo0`0000000`3oool0000000000002000000@0
oooo1@0000000`3oool0000000000006000000H0oooo2@0000080?ooo`050000003oool000000000
003oool00P0000000`3oool000000?ooo`03000000X0oooo00H000000?ooo`000000oooo0000003o
ool2000000050?ooo`00000000000?ooo`0000002`3oool2000000030?ooo`000000oooo00<00000
00<0oooo0000003oool00P00000;0?ooo`80000000<0oooo0000000000000P0000001@3oool00000
0000003oool0000000P0oooo00H000000?ooo`000000oooo0000003oool5000000L0oooo0P000000
0`3oool0000000000004000000D0oooo1@0000030?ooo`<000002@3oool00`000000oooo0?ooo`02
0?ooo`003P3oool00`2oM000000000000003000000030000M02oool0oooo03@0oooo00<000000?oo
o`3oool01`3oool6000000@0oooo1P0000070?ooo`<0000000<0oooo0000000000000`0000080?oo
o`030000003oool0000000<0000000H0oooo00000000000000000?ooo`00000:0?ooo`80000000L0
oooo00000000000000000?ooo`000000oooo00<000002`3oool00`000000oooo0000000200000006
0?ooo`00000000000?ooo`000000oooo0P00000;0?ooo`80000000D0oooo00000000000000000?oo
o`02000000050?ooo`00000000000?ooo`0000002@3oool01@000000oooo000000000000oooo00@0
000000<0oooo0000003oool01P3oool3000000040?ooo`0000000000000000D0oooo1@000000103o
ool000000000003oool5000000H0oooo2@0000080?ooo`050000003oool000000000003oool01000
00001@3oool000000000003oool0000000T0oooo00H000000?ooo`000000oooo0000003oool50000
0080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo00<0000000<0oooo0000
003oool00P00000;0?ooo`80000000<0oooo0000000000000P0000001@3oool000000000003oool0
000000T0oooo0P0000000`3oool0000000000005000000L0oooo00<000000?ooo`0000001P000005
0?ooo`D000000`3oool3000000T0oooo00<000000?ooo`3oool00P3oool00180oooo00<0omnL04P0
001d_ol0=P3oool00`000000oooo0?ooo`060?ooo`L00000103oool6000000L0oooo00@000000?oo
o`000000oooo0P0000000`3oool00000000000080?ooo`030000003oool0000000<0000000H0oooo
00000000000000000?ooo`00000:0?ooo`80000000D0oooo00000000000000000?ooo`0200000003
0?ooo`000000000000/0oooo00<000000?ooo`0000000P000000103oool000000000003oool20000
00030?ooo`000000oooo00T0oooo00@000000?ooo`000000oooo0`000000203oool0000000000000
0000oooo0000003oool000002@3oool4000000030?ooo`00000000000080000000<0oooo0000003o
ool01P3oool7000000D0oooo1@0000000`3oool000000?ooo`06000000H0oooo2@0000090?ooo`<0
000000D0oooo00000000000000000?ooo`03000000030?ooo`000000oooo00T0oooo0P0000000`3o
ool000000?ooo`04000000040?ooo`000000oooo000000X0oooo00D000000?ooo`00000000000?oo
o`03000000030?ooo`000000oooo008000002`3oool00`000000oooo00000003000000060?ooo`00
000000000000003oool000002@3oool2000000030?ooo`000000000000<0000000<0oooo0000003o
ool01`3oool2000000030?ooo`000000000000<000001@3oool5000000<0oooo0`0000090?ooo`03
0000003oool0oooo0080oooo000A0?ooo`030=nLB00007@0_ooo03L0oooo00<000000?ooo`3oool0
1P3oool7000000@0oooo1P0000070?ooo`040000003oool000000?ooo`80000000<0oooo00000000
0000203oool2000000050?ooo`00000000000000003oool00`0000000`3oool000000?ooo`090?oo
o`80000000D0oooo00000000000000000?ooo`02000000030?ooo`000000000000/0oooo00<00000
0?ooo`0000000P000000103oool000000000003oool2000000030?ooo`000000oooo00T0oooo00P0
00000?ooo`000000oooo0000003oool000000?ooo`<0000000<0oooo0000000000002P3oool40000
00070?ooo`00000000000?ooo`000000oooo000000070?ooo`L00000103oool6000000030?ooo`00
0000oooo0080000000@0oooo00000000000000001`3oool2000000030?ooo`000000000000800000
00<0oooo0000003oool01`3oool3000000050?ooo`00000000000000003oool00`0000000`3oool0
00000?ooo`090?ooo`050000003oool000000000003oool010000000103oool000000?ooo`00000:
0?ooo`050000003oool000000000003oool00P0000000`3oool000000?ooo`02000000030?ooo`00
0000oooo00T0oooo00<000000?ooo`0000000`0000001P3oool00000000000000000oooo000000T0
oooo0P0000000`3oool0000000000003000000030?ooo`000000000000L0oooo0P0000000`3oool0
000000000002000000030?ooo`000000oooo00@0oooo1@0000020?ooo`<000002@3oool00`000000
oooo0?ooo`020?ooo`00303oool01P3ogi`0B01809cOo`3o_g@0000004RLgcT0oooo00<000000?oo
o`3oool01P3oool7000000@0oooo1P0000070?ooo`040000003oool000000?ooo`80000000<0oooo
000000000000203oool2000000050?ooo`00000000000000003oool00`0000000`3oool000000?oo
o`080?ooo`040000003oool000000?ooo`<0000000H0oooo00000000000000000?ooo`00000;0?oo
o`80000000@0oooo000000000000oooo0P0000001@3oool000000000003oool0000000X0oooo00<0
00000?ooo`0000000P000000103oool000000000003oool2000000030?ooo`000000000000X0oooo
100000001`3oool000000000003oool000000?ooo`0000001P3oool2000000060?ooo`0000000000
0000003oool00000103oool8000000040?ooo`00000000000?ooo`<000001`3oool2000000030?oo
o`00000000000080000000<0oooo0000003oool01`3oool010000000oooo0000003oool300000006
0?ooo`00000000000000003oool000002P3oool01@000000oooo000000000000oooo00<0000000D0
oooo000000000000oooo0000000:0?ooo`070000003oool000000000003oool000000?ooo`020000
00030?ooo`000000oooo008000002P3oool00`000000oooo00000003000000040?ooo`0000000000
0?ooo`8000002@3oool2000000040?ooo`00000000000?ooo`80000000<0oooo0000000000001`3o
ool2000000040?ooo`00000000000?ooo`<000001@3oool500000080oooo0`0000090?ooo`030000
003oool0oooo0080oooo000<0?ooo`040?oOW01800000000001d_c/0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo00000004000000<0oooo1`0000060?ooo`L0000000<0oooo000000000000
1`3oool010000000oooo0000003oool3000000030?ooo`0000000000008000002P3oool01@000000
oooo000000000000oooo0080000000H0oooo00000000000000000?ooo`00000;0?ooo`80000000L0
oooo00000000000000000?ooo`000000oooo0080000000<0oooo0000003oool02@3oool200000004
0?ooo`00000000000?ooo`80000000@0oooo000000000000oooo0P0000090?ooo`030000003oool0
00000080000000@0oooo000000000000oooo0P0000070?ooo`P00000103oool8000000030?ooo`00
0000000000@000001`3oool2000000050?ooo`00000000000000003oool00P0000080?ooo`040000
003oool000000?ooo`<0000000<0oooo0000003oool00`00000:0?ooo`040000003oool000000?oo
o`@0000000D0oooo000000000000oooo0000000:0?ooo`040000003oool000000?ooo`80000000H0
oooo000000000000oooo0000003oool2000000X0oooo00@000000?ooo`000000oooo10000000103o
ool000000000000000090?ooo`80000000@0oooo000000000000oooo1@0000070?ooo`80000000@0
oooo000000000000oooo0`0000050?ooo`D000000P3oool3000000T0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool01P3oool00`000000oooo00000004000000<0oooo0`00
0000103oool000000000000000060?ooo`L0000000<0oooo0000000000001`3oool010000000oooo
0000003oool4000000040?ooo`0000000000000000X0oooo0P000000103oool000000000003oool2
000000050?ooo`00000000000?ooo`0000002`3oool2000000050?ooo`00000000000000003oool0
0P000000103oool000000?ooo`00000:0?ooo`80000000@0oooo000000000000oooo0`0000001@3o
ool000000000003oool0000000T0oooo00<000000?ooo`0000001@0000000`3oool0000000000007
0?ooo`P00000103oool700000080oooo1P0000070?ooo`H0000000<0oooo000000000000203oool0
0`000000oooo00000004000000030?ooo`000000oooo00<000002P3oool010000000oooo0000003o
ool4000000050?ooo`00000000000?ooo`0000002`3oool2000000040?ooo`00000000000?ooo`80
000000<0oooo0000003oool00P00000;0?ooo`80000000<0oooo0000000000000P000000103oool0
00000000000000090?ooo`80000000@0oooo000000000000oooo1@0000070?ooo`80000000@0oooo
000000000000oooo0`0000050?ooo`D000000P3oool3000000T0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool01P3oool00`000000oooo00000004000000<0oooo1`000006
0?ooo`L0000000<0oooo0000003oool01`3oool01@000000oooo000000000000oooo00<0000000@0
oooo00000000000000002P3oool2000000040?ooo`00000000000?ooo`80000000D0oooo00000000
0000oooo0000000;0?ooo`80000000<0oooo0000000000000P0000001P3oool000000?ooo`000000
oooo000000X0oooo0P0000001@3oool00000000000000000oooo0080000000D0oooo000000000000
oooo000000090?ooo`030000003oool0000000D0000000<0oooo0000000000001`3oool8000000@0
oooo1`0000020?ooo`H000001`3oool9000000P0oooo00<000000?ooo`0000000P0000001@3oool0
0000000000000000oooo00<000002P3oool010000000oooo0000003oool2000000030?ooo`000000
oooo008000000P3oool00`000000oooo0?ooo`080?ooo`80000000@0oooo000000000000oooo0P00
00000`3oool000000?ooo`02000000/0oooo0P0000000`3oool0000000000002000000040?ooo`00
00000000000000X0oooo00@000000?ooo`000000oooo1P0000070?ooo`80000000@0oooo00000000
0000oooo0`0000050?ooo`D000000P3oool3000000T0oooo00<000000?ooo`3oool00P3oool000l0
oooo00H0gia800000000000000000000B02Lgolf0?ooo`8000001`3oool00`000000oooo00000003
000000@0oooo1`0000060?ooo`T00000203oool01@000000oooo000000000000oooo00@0000000<0
oooo0000000000002P3oool2000000040?ooo`00000000000?ooo`80000000D0oooo000000000000
oooo0000000;0?ooo`80000000<0oooo0000000000000P0000000`3oool000000?ooo`02000000/0
oooo0P0000001@3oool00000000000000000oooo0080000000D0oooo000000000000oooo00000009
0?ooo`030000003oool0000000D0000000<0oooo0000000000001`3oool8000000@0oooo1`000002
0?ooo`L000001P3oool9000000T0oooo100000001@3oool00000000000000000oooo00<000002P3o
ool010000000oooo0000003oool2000000030?ooo`000000oooo008000000P3oool00`000000oooo
0?ooo`080?ooo`80000000@0oooo000000000000oooo0P0000000`3oool000000?ooo`02000000/0
oooo0P0000000`3oool0000000000002000000050?ooo`00000000000?ooo`0000002@3oool30000
00030?ooo`000000000000@000001`3oool2000000040?ooo`00000000000?ooo`<000001@3oool5
00000080oooo0`0000070?ooo`<00000103oool000d0oooo00T0oono07@00018W=l0omnL09boo`3o
ool0gia80018W03Oool0=@3oool00`000000oooo0?ooo`060?ooo`H00000103oool6000000L0oooo
2@0000080?ooo`050000003oool000000000003oool01@0000000`3oool000000?ooo`090?ooo`80
000000@0oooo000000000000oooo0P000000103oool0000000000000000;0?ooo`050000003oool0
00000000003oool00`0000000`3oool000000?ooo`02000000/0oooo0P0000001@3oool000000000
00000000oooo0080000000D0oooo000000000000oooo000000090?ooo`050000003oool000000000
003oool0100000000`3oool000000?ooo`060?ooo`@0000000@0oooo0000000000000000103oool7
00000080oooo1`0000060?ooo`T000002@3oool3000000030?ooo`00000000000080000000@0oooo
00000000000000002P3oool00`000000oooo0?ooo`03000000080?ooo`00000000000000003oool0
00000?ooo`00000:0?ooo`030000003oool000000080000000H0oooo000000000000oooo0000003o
ool2000000/0oooo0P0000000`3oool0000000000002000000050?ooo`00000000000?ooo`000000
2@3oool3000000030?ooo`000000000000<0000000<0oooo0000003oool01@3oool00`000000oooo
00000002000000040?ooo`0000000000000000D0oooo1@0000030?ooo`8000002@3oool00`000000
oooo0?ooo`020?ooo`003@3oool02@2oM7@0_ooo0?ooo`3o_i`0W=oo0?ooo`3ookl0M01d0;ooo`0e
0?ooo`030000003oool0oooo00H0oooo1P0000040?ooo`H000001`3oool9000000P0oooo00<00000
0?ooo`0000000P0000000`3oool0000000000002000000030?ooo`000000oooo00T0oooo0P000000
103oool000000000003oool2000000040?ooo`0000000000000000/0oooo00D000000?ooo`000000
00000?ooo`03000000050?ooo`00000000000?ooo`0000002`3oool2000000050?ooo`0000000000
0000003oool00P0000001@3oool000000000003oool0000000T0oooo100000000`3oool000000000
0002000000030?ooo`000000oooo00H0oooo100000000`3oool00000000000050?ooo`L000000P3o
ool5000000030?ooo`000000oooo00D0oooo2@0000090?ooo`<0000000<0oooo0000000000000P00
00001@3oool000000000003oool0000000X0oooo00<000000?ooo`0000000P000000203oool00000
000000000000oooo0000003oool000002P3oool02`000000oooo000000000000oooo0000003oool0
00000?ooo`000000oooo008000002`3oool2000000030?ooo`00000000000080000000D0oooo0000
00000000oooo000000090?ooo`<0000000<0oooo0000000000000`0000000`3oool000000?ooo`05
0?ooo`030000003oool000000080000000@0oooo00000000000000001@3oool5000000<0oooo0P00
00090?ooo`030000003oool0oooo0080oooo000<0?ooo`090?oOW02L_ol0oooo0?oog`2LM9`0gooo
0?ooo`3ogi`0B7Bo03H0oooo00<000000?ooo`3oool01P3oool6000000@0oooo1P0000070?ooo`T0
0000203oool00`000000oooo00000002000000030?ooo`000000000000<000002`3oool200000004
0?ooo`00000000000?ooo`80000000@0oooo0000003oool000002`3oool01@000000oooo00000000
0000oooo00<0000000D0oooo000000000000oooo0000000;0?ooo`80000000D0oooo000000000000
00000?ooo`02000000040?ooo`0000000000000000X0oooo100000000`3oool00000000000020000
00030?ooo`000000oooo00H0oooo1`0000050?ooo`L000000P3oool5000000030?ooo`000000oooo
00D0oooo2@0000090?ooo`<0000000D0oooo00000000000000000?ooo`03000000030?ooo`000000
oooo00T0oooo00<000000?ooo`0000000P000000203oool00000000000000000oooo0000003oool0
00002P3oool01`000000oooo000000000000oooo0000003oool00`0000000`3oool000000000000;
0?ooo`80000000<0oooo0000000000000P0000001@3oool000000000003oool0000000T0oooo0`00
00000`3oool0000000000003000000030?ooo`000000oooo00H0oooo10000000103oool000000000
000000060?ooo`@000000`3oool3000000P0oooo00<000000?ooo`3oool00P3oool000`0oooo00T0
oknL09cOo`3oool0_g@007Boo`3oool0gia80000M02oool0=P3oool00`000000oooo0?ooo`060?oo
o`H00000103oool00`000000oooo00000003000000L0oooo1@000000103oool00000000000000008
0?ooo`030000003oool0000000<0000000<0oooo0000000000000P00000;0?ooo`80000000@0oooo
000000000000oooo100000000`3oool000000?ooo`0:0?ooo`030000003oool000000080000000@0
oooo000000000000oooo0P0000000`3oool000000?ooo`0:0?ooo`<0000000@0oooo000000000000
oooo0P000000103oool000000000000000090?ooo`030000003oool000000080000000L0oooo0000
00000000oooo0000003oool0000000H0oooo00<000000?ooo`0000001@0000050?ooo`L000000P3o
ool7000000H0oooo0`0000000`3oool0000000000002000000030?ooo`000000oooo00L0oooo00@0
00000?ooo`000000oooo0`0000001P3oool00000000000000000oooo000000X0oooo00<000000?oo
o`0000000P000000203oool00000000000000000oooo0000003oool000002P3oool01`000000oooo
000000000000oooo0000003oool00`0000000`3oool000000000000;0?ooo`80000000H0oooo0000
00000000oooo0000003oool2000000030?ooo`000000oooo00P0oooo0`000000203oool000000000
00000000oooo0000003oool000001`3oool4000000040?ooo`0000000000000000H0oooo1@000002
0?ooo`<00000203oool00`000000oooo0?ooo`020?ooo`00303oool0103ookl0M0000000001d_olk
0?ooo`030000003oool0oooo00D0oooo1`0000040?ooo`030000003oool0000000<000001`3oool3
000000030?ooo`000000oooo00<00000203oool00`000000oooo00000003000000030?ooo`000000
0000008000002`3oool2000000040?ooo`000000oooo0?ooo`@0000000<0oooo0000003oool02P3o
ool00`000000oooo00000003000000030?ooo`000000oooo0080000000<0oooo0000003oool02P3o
ool3000000040?ooo`00000000000?ooo`80000000@0oooo0000003oool000002@3oool00`000000
oooo00000002000000040?ooo`00000000000?ooo`8000001`3oool00`000000oooo000000050000
00D0oooo1`0000030?ooo`80000000@0oooo00000000000000001P3oool3000000030?ooo`000000
00000080000000<0oooo0000003oool01`3oool010000000oooo0000003oool3000000060?ooo`00
000000000000003oool000002P3oool00`000000oooo00000002000000080?ooo`00000000000000
003oool000000?ooo`00000:0?ooo`070000003oool000000000003oool000000?ooo`0300000004
0?ooo`000000oooo000000X0oooo0P000000103oool000000000003oool4000000030?ooo`000000
oooo00P0oooo0`000000203oool00000000000000000oooo0000003oool000001`3oool400000004
0?ooo`0000000000000000H0oooo0P0000000`3oool00000000000020?ooo`<00000203oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`050?ooo`L000000`3oool7000000L0
oooo0`0000001@3oool000000000003oool0000000T0oooo00<000000?ooo`00000010000000103o
ool0000000000000000;0?ooo`80000000@0oooo0000003oool0oooo100000000`3oool000000?oo
o`0:0?ooo`80000000L0oooo00000000000000000?ooo`000000oooo0080000000<0oooo0000003o
ool02@3oool01@000000oooo000000000000oooo0080000000<0oooo0000000000000P0000000`3o
ool000000?ooo`080?ooo`030000003oool0000000D0000000<0oooo0000000000001`3oool20000
00030?ooo`000000000000<000001@3oool7000000<0oooo0P000000103oool00000000000000006
0?ooo`<0000000<0oooo0000000000000P0000000`3oool000000?ooo`070?ooo`040000003oool0
00000?ooo`<0000000H0oooo00000000000000000?ooo`00000:0?ooo`030000003oool000000080
000000P0oooo00000000000000000?ooo`000000oooo000000/0oooo0`0000000`3oool000000?oo
o`03000000040?ooo`000000oooo000000X0oooo0P000000103oool000000000003oool300000003
0?ooo`000000000000T0oooo0`000000203oool00000000000000000oooo0000003oool000001`3o
ool2000000030?ooo`000000oooo00<000001P3oool2000000030?ooo`00000000000080oooo0`00
00080?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00D0oooo1`000003
0?ooo`L000001`3oool3000000050?ooo`00000000000?ooo`0000002@3oool00`000000oooo0000
0004000000040?ooo`0000000000000000/0oooo0P000000103oool000000?ooo`3oool400000003
0?ooo`000000oooo00X0oooo0P0000001`3oool00000000000000000oooo0000003oool00P000000
0`3oool000000?ooo`090?ooo`050000003oool000000000003oool00`0000001P3oool000000000
00000000oooo000000T0oooo00<000000?ooo`0000001@0000000`3oool00000000000070?ooo`80
000000<0oooo0000000000000`0000040?ooo`P000000`3oool2000000040?ooo`00000000000000
00H0oooo0`0000000`3oool0000000000002000000030?ooo`000000oooo00L0oooo00@000000?oo
o`000000oooo0`0000001P3oool00000000000000000oooo000000X0oooo00D000000?ooo`000000
00000?ooo`04000000040?ooo`000000oooo000000/0oooo0`0000000`3oool000000?ooo`020000
00050?ooo`00000000000?ooo`0000002P3oool2000000040?ooo`00000000000?ooo`<0000000<0
oooo0000000000002@3oool2000000030?ooo`00000000000080000000@0oooo0000003oool00000
1`3oool2000000030?ooo`000000oooo00<000001P3oool2000000030?ooo`00000000000080oooo
0`0000080?ooo`030000003oool0oooo0080oooo000@0?ooo`060?noM000000000000000000007@0
_ooo=@3oool00`000000oooo0?ooo`050?ooo`L000000`3oool7000000L0oooo0`0000000`3oool0
000000000002000000T0oooo00<000000?ooo`00000010000000103oool0000000000000000;0?oo
o`040000003oool0000000000080oooo00H000000?ooo`00000000000?ooo`00000;0?ooo`800000
00L0oooo00000000000000000?ooo`000000oooo0080000000<0oooo0000003oool02@3oool01@00
0000oooo000000000000oooo00<0000000H0oooo00000000000000000?ooo`0000090?ooo`030000
003oool0000000D0000000<0oooo0000000000001`3oool2000000030?ooo`000000000000<00000
103oool8000000<0oooo0P000000103oool000000000000000060?ooo`80000000<0oooo00000000
00000`0000000`3oool000000?ooo`070?ooo`040000003oool000000?ooo`<0000000H0oooo0000
0000000000000?ooo`00000:0?ooo`050000003oool000000000003oool010000000103oool00000
0?ooo`00000;0?ooo`<0000000<0oooo0000003oool00P0000001@3oool000000000003oool00000
00X0oooo0P000000103oool000000000003oool2000000040?ooo`0000000000000000T0oooo0P00
00001@3oool00000000000000000oooo0080000000<0oooo0000003oool01P3oool2000000030?oo
o`000000oooo00<000001P3oool2000000030?ooo`00000000000080oooo0`0000080?ooo`030000
003oool0oooo0080oooo00080?ooo`060;nLW03Oool0oooo0?ooo`3ogi`0B0000`0000001000B9`0
gooo0?oo_`1dM;lf0?ooo`030000003oool0oooo00D0oooo1`0000030?ooo`L000001P3oool20000
00030?ooo`000000oooo00@000002@3oool00`000000oooo00000004000000040?ooo`0000000000
000000/0oooo00@000000?ooo`00000000000P3oool01P000000oooo000000000000oooo000000/0
oooo0P0000001@3oool00000000000000000oooo0080000000@0oooo0000003oool000002P3oool0
0`000000oooo00000002000000040?ooo`00000000000?ooo`<0000000<0oooo0000003oool0203o
ool00`000000oooo00000005000000030?ooo`000000000000L0oooo200000040?ooo`P000000`3o
ool2000000040?ooo`0000000000000000L0oooo00<000000?ooo`000000100000000`3oool00000
0?ooo`070?ooo`080000003oool000000?ooo`000000oooo0000003oool2000000030?ooo`000000
000000X0oooo00@000000?ooo`000000oooo1@000000103oool000000?ooo`00000;0?ooo`800000
00@0oooo000000000000oooo0P0000001@3oool000000000003oool0000000X0oooo00<000000?oo
o`0000000P000000103oool000000000003oool3000000T0oooo00<000000?ooo`0000000`000000
1@3oool000000000003oool0000000L0oooo0P0000000`3oool000000?ooo`03000000H0oooo0P00
00000`3oool00000000000020?ooo`<00000203oool00`000000oooo0?ooo`020?ooo`001`3oool0
0`3ooml0W4P00000000300000003001d_`3oool0oooo0080oooo00<0okmd0000M02oool0=P3oool0
0`000000oooo0?ooo`050?ooo`L000000`3oool7000000H0oooo2@0000090?ooo`80000000<0oooo
0000000000000P000000103oool0000000000000000:0?ooo`80000000@0oooo000000000000oooo
0P0000001@3oool000000000003oool0000000/0oooo0P0000001@3oool00000000000000000oooo
0080000000@0oooo0000003oool000002P3oool00`000000oooo00000002000000040?ooo`000000
00000?ooo`<0000000<0oooo0000003oool0203oool00`000000oooo00000005000000030?ooo`00
0000000000L0oooo200000040?ooo`T000000P3oool2000000040?ooo`0000000000000000L0oooo
1P0000000`3oool00000000000080?ooo`080000003oool000000?ooo`000000oooo0000003oool2
000000030?ooo`000000000000X0oooo00@000000?ooo`000000oooo1@000000103oool000000?oo
o`00000;0?ooo`80000000@0oooo000000000000oooo0P0000000`3oool000000?ooo`02000000X0
oooo00<000000?ooo`0000000P000000103oool000000000003oool3000000T0oooo00<000000?oo
o`0000000`0000000`3oool0000000000002000000L0oooo0P0000000`3oool00000000000020000
00030?ooo`000000oooo00@0oooo1@0000020?ooo`<00000203oool00`000000oooo0?ooo`020?oo
o`001`3oool00`3ookl0M00004RLg`110?ooo`030000003oool0oooo00D0oooo1`0000030?ooo`L0
00001P3oool9000000T0oooo0P0000000`3oool0000000000002000000040?ooo`00000000000000
00X0oooo0P000000103oool000000000003oool2000000050?ooo`00000000000?ooo`0000002`3o
ool2000000050?ooo`00000000000000003oool00P000000103oool000000?ooo`00000:0?ooo`03
0000003oool000000080000000@0oooo000000000000oooo0`0000000`3oool000000?ooo`080?oo
o`030000003oool0000000D0000000<0oooo0000000000001`3oool8000000@0oooo1@000000103o
ool000000000000000020?ooo`80000000@0oooo00000000000000001`3oool9000000P0oooo00P0
00000?ooo`000000oooo0000003oool000000?ooo`80000000<0oooo0000000000002P3oool01000
0000oooo0000003oool4000000050?ooo`00000000000?ooo`0000002`3oool2000000040?ooo`00
000000000?ooo`80000000<0oooo0000003oool00P00000;0?ooo`@0000000@0oooo000000000000
oooo0`0000090?ooo`030000003oool0000000<0000000<0oooo0000000000000P0000070?ooo`80
000000<0oooo0000000000000P0000000`3oool000000?ooo`040?ooo`D000000P3oool3000000P0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01@3oool7000000<0oooo
1`0000060?ooo`T000002@3oool2000000030?ooo`000000000000<0000000<0oooo000000000000
2P3oool2000000040?ooo`00000000000?ooo`80000000@0oooo0000000000000000303oool20000
00050?ooo`00000000000000003oool00P000000103oool000000?ooo`00000:0?ooo`80000000@0
oooo000000000000oooo0`0000001@3oool000000000003oool0000000T0oooo00<000000?ooo`00
00001@0000000`3oool00000000000070?ooo`P00000103oool5000000040?ooo`00000000000000
0080oooo1P0000070?ooo`T00000203oool02P000000oooo0000003oool000000?ooo`000000oooo
0000003oool3000000X0oooo00@000000?ooo`000000oooo0`0000001P3oool00000000000000000
oooo000000/0oooo0P000000103oool000000000003oool2000000030?ooo`000000oooo00800000
2`3oool3000000050?ooo`00000000000000003oool00P0000000`3oool000000?ooo`070?ooo`03
0000003oool0000000<0000000<0oooo0000000000000P0000070?ooo`80000000<0oooo00000000
00000P0000000`3oool000000?ooo`040?ooo`D000000P3oool3000000P0oooo00<000000?ooo`3o
ool00P3oool000l0oooo00H0omnL04P00000000000000000B02LgolX0?ooo`040;md000000000000
07Boo`X0oooo00<000000?ooo`3oool01@3oool00`000000oooo00000003000000@0oooo1`000006
0?ooo`T000002@3oool2000000030?ooo`000000000000<0000000<0oooo0000000000002P3oool2
000000040?ooo`00000000000?ooo`80000000@0oooo0000000000000000303oool3000000040?oo
o`00000000000?ooo`80000000@0oooo0000003oool000002P3oool2000000040?ooo`0000000000
0?ooo`<0000000@0oooo00000000000000002P3oool00`000000oooo00000006000000030?ooo`00
0000oooo00H0oooo200000040?ooo`D0000000@0oooo00000000000000000P3oool6000000L0oooo
2@0000080?ooo`030000003oool000000080oooo0P0000000`3oool000000?ooo`03000000X0oooo
00@000000?ooo`000000oooo0`0000001P3oool00000000000000000oooo000000/0oooo0P000000
103oool000000000003oool2000000030?ooo`000000oooo008000002`3oool3000000050?ooo`00
000000000000003oool00P0000000`3oool000000?ooo`070?ooo`030000003oool0000000<00000
00<0oooo0000000000000P0000070?ooo`80000000<0oooo000000000000100000050?ooo`D00000
0P3oool3000000P0oooo00<000000?ooo`3oool00P3oool000h0oooo00<0_g@00000001d_ol00P3o
ool00`3ooml0W7BL0=ooo`0V0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO2@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0000000<00000103oool7000000H0oooo2@0000090?ooo`<0
000000<0oooo0000000000000P0000000`3oool000000000000:0?ooo`80000000@0oooo00000000
0000oooo0P000000103oool0000000000000000<0?ooo`<0000000@0oooo000000000000oooo0P00
0000103oool000000?ooo`00000:0?ooo`80000000@0oooo000000000000oooo0`000000103oool0
000000000000000:0?ooo`030000003oool0000000H0000000<0oooo0000003oool01P3oool80000
00@0oooo1@000000103oool000000000000000020?ooo`H000001`3oool9000000P0oooo00D00000
0?ooo`00000000000?ooo`04000000040?ooo`0000000000000000X0oooo00@000000?ooo`000000
oooo0`0000001P3oool00000000000000000oooo000000/0oooo0P000000103oool000000000003o
ool2000000030?ooo`000000oooo008000002`3oool3000000050?ooo`00000000000000003oool0
0P0000000`3oool000000?ooo`070?ooo`030000003oool0000000<0000000<0oooo000000000000
0P0000070?ooo`80000000<0oooo000000000000100000050?ooo`D000000P3oool3000000P0oooo
00<000000?ooo`3oool00P3oool000d0oooo00<0gia804RLg`3oool0103oool00`3OW9`0_ooo0?oo
o`0T0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0203oool00`000000oooo0?oo
o`050?ooo`030000003oool0000000<00000103oool7000000H0oooo2@0000090?ooo`<0000000<0
oooo0000000000000P0000000`3oool000000000000:0?ooo`80000000@0oooo000000000000oooo
0P000000103oool0000000000000000<0?ooo`<0000000@0oooo000000000000oooo0P000000103o
ool000000?ooo`00000:0?ooo`80000000@0oooo000000000000oooo0`000000103oool000000000
0000000:0?ooo`030000003oool0000000H0000000<0oooo0000003oool01P3oool8000000@0oooo
1@000000103oool000000000000000020?ooo`L000001P3oool9000000T0oooo0`0000000`3oool0
000000000002000000050?ooo`00000000000?ooo`0000002@3oool010000000oooo0000003oool3
000000040?ooo`00000000000?ooo`8000002`3oool2000000040?ooo`00000000000?ooo`800000
00<0oooo0000003oool00P00000;0?ooo`<0000000D0oooo00000000000000000?ooo`0200000003
0?ooo`000000oooo00P0oooo1@0000000`3oool0000000000002000000L0oooo0P0000000`3oool0
000000000004000000D0oooo1@0000020?ooo`<00000203oool00`000000oooo0?ooo`020?ooo`00
303oool00`3ogi`0M9cO0?ooo`040?ooo`030?oog`2LM9`0gooo02D0oooo00<0oooO09a80018W=l0
0P3oool0103ooml0W4P00018W03Oool70?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
00000`0000040?ooo`L000001P3oool9000000T0oooo0`0000000`3oool000000000000200000003
0?ooo`000000000000X0oooo0P000000103oool000000000003oool2000000040?ooo`0000000000
000000`0oooo0`000000103oool000000000003oool2000000040?ooo`000000oooo000000X0oooo
0P000000103oool000000000003oool3000000040?ooo`0000000000000000X0oooo0P0000000`3o
ool0000000000004000000030?ooo`000000oooo00H0oooo200000040?ooo`D0000000@0oooo0000
0000000000000P3oool7000000H0oooo2@0000090?ooo`<0000000<0oooo0000000000000P000000
1@3oool000000000003oool0000000T0oooo00@000000?ooo`000000oooo0`000000103oool00000
0000003oool2000000/0oooo00<000000?ooo`0000000P0000001P3oool000000000003oool00000
0?ooo`8000002`3oool3000000050?ooo`00000000000000003oool00P0000000`3oool000000?oo
o`080?ooo`D0000000<0oooo0000000000000P0000070?ooo`80000000<0oooo0000000000001000
00050?ooo`D000000`3oool2000000P0oooo00<000000?ooo`3oool00P3oool000`0oooo00<0oknL
09cOo`3oool00`3oool00`3ooml0W4P007Boo`0V0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia8
0000B02Lgol01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000<00000103oool7
000000H0oooo2@0000090?ooo`<0000000<0oooo0000000000000P0000000`3oool000000000000:
0?ooo`80000000@0oooo000000000000oooo0P000000103oool0000000000000000<0?ooo`<00000
00@0oooo000000000000oooo0P0000000`3oool000000000000;0?ooo`80000000@0oooo00000000
0000oooo0`000000103oool0000000000000000:0?ooo`80000000<0oooo00000000000010000000
0`3oool000000?ooo`060?ooo`P00000103oool5000000040?ooo`000000000000000080oooo1`00
00060?ooo`T000002@3oool3000000030?ooo`00000000000080000000D0oooo000000000000oooo
0000000:0?ooo`80000000D0oooo00000000000000000?ooo`02000000030?ooo`000000000000/0
oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`02000000030?ooo`000000000000/0
oooo0`0000001@3oool00000000000000000oooo0080000000<0oooo0000003oool0203oool50000
00030?ooo`0000000000008000001`3oool2000000030?ooo`000000000000@000001@3oool50000
00<0oooo0P0000080?ooo`030000003oool0oooo0080oooo000<0?ooo`030?oOW018M;l0oooo0080
oooo00<0gia800000018W=l0:03oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00L0
ooooo`00001R000000@0oooo000=0?ooo`060?noM0000000000000000000B9`0gooo:@3oool00`3O
W4P0001809cOo`020?ooo`030?oog`2LB00007Bo00L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo00000003000000@0oooo1`0000060?ooo`T000002@3oool3000000030?ooo`0000000000
0080000000<0oooo0000000000002P3oool2000000040?ooo`00000000000?ooo`80000000@0oooo
0000000000000000303oool3000000030?ooo`000000oooo00<0000000<0oooo0000000000002`3o
ool2000000040?ooo`00000000000?ooo`<0000000@0oooo00000000000000002P3oool200000003
0?ooo`000000000000@0000000<0oooo0000003oool01P3oool8000000@0oooo1@000000103oool0
00000000000000020?ooo`L000001P3oool9000000T0oooo0`0000000`3oool00000000000020000
00050?ooo`00000000000?ooo`0000002P3oool2000000050?ooo`00000000000000003oool00P00
00000`3oool000000000000;0?ooo`030000003oool000000080000000<0oooo0000003oool00P00
00000`3oool000000000000;0?ooo`<0000000D0oooo00000000000000000?ooo`02000000030?oo
o`000000oooo00P0oooo1@0000000`3oool0000000000002000000L0oooo0P0000000`3oool00000
00000004000000@0oooo00<000000?ooo`0000000`0000030?ooo`800000203oool00`000000oooo
0?ooo`020?ooo`00?03oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo00000003000000@0oooo1`0000060?ooo`P0000000<0
oooo0000003oool01`3oool3000000030?ooo`00000000000080000000<0oooo0000000000002P3o
ool2000000040?ooo`00000000000?ooo`80000000@0oooo0000003oool00000303oool300000003
0?ooo`000000oooo00<0000000<0oooo0000000000002`3oool2000000040?ooo`00000000000?oo
o`<0000000@0oooo00000000000000002P3oool2000000030?ooo`000000000000@0000000<0oooo
0000003oool01P3oool8000000@0oooo1@000000103oool000000000000000020?ooo`L000001P3o
ool9000000T0oooo0`0000000`3oool0000000000002000000050?ooo`00000000000?ooo`000000
2P3oool2000000050?ooo`00000000000000003oool00P0000000`3oool000000000000;0?ooo`03
0000003oool000000080000000<0oooo0000003oool00P0000000`3oool000000000000;0?ooo`<0
000000D0oooo00000000000000000?ooo`02000000030?ooo`000000oooo00P0oooo1@0000000`3o
ool0000000000002000000L0oooo0P0000000`3oool0000000000004000000@0oooo00<000000?oo
o`0000000`0000030?ooo`800000203oool00`000000oooo0?ooo`020?ooo`00?03oool0103ooml0
W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00H0oooo00<000000?ooo`3oool01@3oool60000
00@0oooo1`0000060?ooo`D0000000D0oooo000000000000oooo000000080?ooo`<0000000<0oooo
0000000000000P0000000`3oool000000000000:0?ooo`80000000<0oooo0000003oool00`000000
103oool000000?ooo`00000<0?ooo`<0000000<0oooo0000003oool00`0000000`3oool000000000
000;0?ooo`80000000@0oooo000000000000oooo0`000000103oool0000000000000000:0?ooo`80
000000<0oooo000000000000100000000`3oool000000?ooo`060?ooo`P00000103oool500000004
0?ooo`000000000000000080oooo0`000000103oool000000000000000060?ooo`T000002@3oool3
000000030?ooo`00000000000080000000D0oooo000000000000oooo0000000:0?ooo`80000000D0
oooo00000000000000000?ooo`02000000030?ooo`000000000000/0oooo00<000000?ooo`000000
0P0000000`3oool000000?ooo`02000000030?ooo`000000000000/0oooo0`0000001@3oool00000
000000000000oooo0080000000<0oooo0000003oool0203oool5000000030?ooo`00000000000080
00001`3oool2000000030?ooo`000000000000@00000103oool00`000000oooo00000003000000<0
oooo0P0000080?ooo`030000003oool0oooo0080oooo000?0?ooo`060?oOW0180000000000000000
04P0W=oo:03oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00H0oooo00<000000?oo
o`3oool01@3oool6000000@0oooo1`0000060?ooo`D0000000D0oooo000000000000oooo00000008
0?ooo`<0000000<0oooo0000000000000P0000000`3oool000000000000:0?ooo`80000000<0oooo
0000003oool00`000000103oool000000?ooo`00000<0?ooo`<0000000<0oooo0000003oool00`00
00000`3oool000000000000;0?ooo`80000000@0oooo000000000000oooo0`000000103oool00000
00000000000:0?ooo`80000000<0oooo000000000000100000000`3oool000000?ooo`060?ooo`P0
0000103oool5000000040?ooo`000000000000000080oooo0`000000103oool00000000000000006
0?ooo`T000002@3oool3000000030?ooo`00000000000080000000D0oooo000000000000oooo0000
000:0?ooo`80000000D0oooo00000000000000000?ooo`02000000030?ooo`000000000000/0oooo
00<000000?ooo`0000000P0000000`3oool000000?ooo`02000000030?ooo`000000000000/0oooo
0`0000001@3oool00000000000000000oooo0080000000<0oooo0000003oool0203oool500000003
0?ooo`0000000000008000001`3oool2000000030?ooo`000000000000@00000103oool00`000000
oooo00000003000000<0oooo0P0000080?ooo`030000003oool0oooo0080oooo000=0?ooo`040?oo
g`2LB00004RL0=ooo`80oooo00<0okmd0018W03Oool0:03oool01P3OW4P0001d0;ooo`3ooml0W4P0
04RLg`L0oooo00<000000?ooo`3oool01@3oool6000000@0oooo1`0000060?ooo`D0000000<0oooo
0000003oool00P0000080?ooo`<0000000<0oooo0000000000000P0000000`3oool000000000000:
0?ooo`050000003oool000000000003oool00`0000000`3oool000000?ooo`02000000/0oooo0`00
00000`3oool000000?ooo`03000000030?ooo`000000000000/0oooo0P000000203oool000000000
003oool000000?ooo`000000oooo0`00000:0?ooo`80000000<0oooo0000000000000P000000103o
ool000000?ooo`0000070?ooo`P00000103oool5000000040?ooo`000000000000000080oooo0`00
0000103oool000000000000000060?ooo`T000002@3oool3000000030?ooo`000000000000800000
00D0oooo000000000000oooo0000000:0?ooo`80000000D0oooo00000000000000000?ooo`020000
00030?ooo`000000000000/0oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`020000
00030?ooo`000000000000/0oooo0`0000001@3oool00000000000000000oooo0080000000<0oooo
0000003oool0203oool5000000030?ooo`0000000000008000001`3oool2000000030?ooo`000000
000000@00000103oool00`000000oooo00000003000000<0oooo0P0000080?ooo`030000003oool0
oooo0080oooo000=0?ooo`030;mdB02Lgol0oooo00<0oooo00<0oooO09a8M02oool0:@3oool0103O
W4P0000000000000M;l80?ooo`030000003oool0oooo00D0oooo1P0000040?ooo`L000001P3oool5
000000030?ooo`000000oooo00800000203oool3000000050?ooo`00000000000000003oool00`00
000:0?ooo`050000003oool000000000003oool00`0000000`3oool000000?ooo`02000000/0oooo
0`0000000`3oool000000?ooo`03000000030?ooo`000000000000`0oooo00T000000?ooo`000000
00000?ooo`000000oooo0000003oool00`00000:0?ooo`80000000<0oooo0000000000000P000000
103oool000000?ooo`0000070?ooo`D0000000<0oooo000000000000103oool5000000040?ooo`00
0000000000000080oooo1`0000060?ooo`T000002@3oool5000000040?ooo`00000000000?ooo`80
000000<0oooo0000003oool02@3oool2000000050?ooo`00000000000000003oool00P0000000`3o
ool000000000000;0?ooo`030000003oool000000080000000@0oooo0000003oool000000P3oool2
000000X0oooo00D000000?ooo`00000000000?ooo`03000000050?ooo`00000000000?ooo`000000
2@3oool5000000030?ooo`0000000000008000001`3oool9000000@0oooo00<000000?ooo`000000
0`0000030?ooo`800000203oool00`000000oooo0?ooo`020?ooo`00303oool00`3ogi`0W;oo0?oo
o`040?ooo`030?oOW018M;l0oooo03D0oooo00<000000?ooo`3oool01@3oool6000000@0oooo1`00
00070?ooo`@0000000<0oooo0000000000000P0000080?ooo`<0000000D0oooo0000000000000000
0?ooo`03000000X0oooo00D000000?ooo`00000000000?ooo`03000000030?ooo`000000oooo0080
00002`3oool2000000040?ooo`00000000000?ooo`<0000000<0oooo000000000000303oool02@00
0000oooo000000000000oooo0000003oool000000?ooo`03000000X0oooo0P0000000`3oool00000
00000002000000040?ooo`0000000000000000L0oooo1@0000000`3oool00000000000040?ooo`D0
000000@0oooo00000000000000000P3oool7000000H0oooo100000001@3oool000000000003oool0
000000T0oooo1@000000103oool000000000003oool2000000030?ooo`000000oooo00T0oooo0`00
0000103oool000000000003oool2000000030?ooo`000000000000/0oooo00<000000?ooo`000000
0P000000103oool000000?ooo`0000020?ooo`8000002P3oool01@000000oooo000000000000oooo
00<0000000@0oooo00000000000000002P3oool00`000000oooo00000002000000030?ooo`000000
0000008000001`3oool9000000@0oooo00<000000?ooo`0000000`0000030?ooo`800000203oool0
0`000000oooo0?ooo`020?ooo`00303oool00`3o_i`0W=oo0?ooo`030?ooo`030?oOW018B9`0gooo
03H0oooo00<000000?ooo`3oool01@3oool7000000<0oooo1`0000070?ooo`@0000000<0oooo0000
000000000P0000080?ooo`<0000000D0oooo00000000000000000?ooo`03000000/0oooo0`000000
1`3oool00000000000000000oooo0000003oool00P00000;0?ooo`80000000@0oooo000000000000
oooo0P000000103oool0000000000000000<0?ooo`090000003oool000000000003oool000000?oo
o`000000oooo00<000002P3oool2000000030?ooo`00000000000080000000@0oooo000000000000
00001`3oool2000000030?ooo`000000000000<00000103oool5000000040?ooo`00000000000000
0080oooo1`0000060?ooo`050000003oool000000000003oool00P0000000`3oool000000?ooo`08
0?ooo`D0000000@0oooo000000000000oooo0P0000000`3oool000000?ooo`090?ooo`<0000000@0
oooo000000000000oooo0P0000000`3oool000000000000;0?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo0P00000:0?ooo`80000000<0oooo0000003oool00`000000
103oool0000000000000000:0?ooo`030000003oool0000000<0000000@0oooo0000000000000000
1`3oool9000000@0oooo1P0000030?ooo`800000203oool00`000000oooo0?ooo`020?ooo`00303o
ool0103ookl0M0000000001d_olk0?ooo`030000003oool0oooo00D0oooo1`0000030?ooo`L00000
1`3oool4000000030?ooo`000000000000800000203oool2000000030?ooo`000000000000800000
00@0oooo00000000000000002`3oool3000000070?ooo`00000000000000003oool000000?ooo`02
000000/0oooo0P0000000`3oool000000?ooo`03000000040?ooo`0000000000000000`0oooo00T0
00000?ooo`00000000000?ooo`000000oooo0000003oool00`00000:0?ooo`80000000<0oooo0000
000000000P000000103oool000000000000000070?ooo`80000000<0oooo0000000000000`000004
0?ooo`D0000000@0oooo00000000000000000P3oool00`000000oooo00000004000000H0oooo00D0
00000?ooo`00000000000?ooo`02000000030?ooo`000000oooo00P0oooo1@000000103oool00000
0000003oool3000000/0oooo0`000000103oool000000000003oool2000000030?ooo`0000000000
00/0oooo00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00X0oooo0P0000000`3oool000000?ooo`03000000040?ooo`0000000000000000X0oooo00<00000
0?ooo`0000000`000000103oool000000000000000070?ooo`H0000000<0oooo000000000000103o
ool600000080oooo0`0000080?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo00D0oooo1`0000030?ooo`L000001`3oool4000000030?ooo`000000000000800000203oool0
0`000000oooo00000004000000040?ooo`0000000000000000/0oooo0`0000001`3oool000000000
00000000oooo0000003oool00P00000;0?ooo`80000000<0oooo0000003oool00`000000103oool0
000000000000000<0?ooo`@0000000<0oooo0000003oool01@00000:0?ooo`80000000<0oooo0000
000000000P000000103oool000000000000000070?ooo`80000000<0oooo0000000000000`000004
0?ooo`D0000000<0oooo0000000000000`3oool00`000000oooo00000004000000D0oooo0P000000
103oool000000000003oool2000000030?ooo`000000oooo00P0oooo1@0000001@3oool000000?oo
o`000000oooo008000002`3oool3000000030?ooo`0000000000008000000P3oool00`000000oooo
0?ooo`0:0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000000:0?ooo`<000000P3oool3000000040?ooo`0000000000000000X0oooo00<000000?ooo`00
00000`000000103oool000000000000000070?ooo`H0000000<0oooo000000000000103oool60000
0080oooo0`0000080?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00D0
oooo1`0000030?ooo`L000001`3oool3000000030?ooo`000000000000<00000203oool00`000000
oooo00000004000000040?ooo`0000000000000000/0oooo0`0000001`3oool000000?ooo`000000
oooo0000003oool00P00000;0?ooo`80000000<0oooo0000003oool00`000000103oool000000000
0000000<0?ooo`@0000000<0oooo0000003oool0100000000`3oool000000?ooo`080?ooo`800000
00<0oooo0000000000000P000000103oool000000000000000070?ooo`80000000<0oooo00000000
00000P0000000`3oool000000?ooo`020?ooo`P000000`3oool7000000D0oooo0P000000103oool0
00000000003oool2000000030?ooo`000000oooo00P0oooo1@0000001@3oool000000?ooo`000000
oooo008000002`3oool3000000030?ooo`0000000000008000000P3oool00`000000oooo0?ooo`0:
0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000000:
0?ooo`<0000000<0oooo0000003oool00P000000103oool0000000000000000:0?ooo`030000003o
ool0000000<0000000@0oooo0000003oool000001`3oool6000000030?ooo`000000oooo00@0oooo
1P0000020?ooo`<00000203oool00`000000oooo0?ooo`020?ooo`00303oool00`3ookl0W9cO0?oo
o`030?ooo`040?noM0000000001d0;ooocD0oooo00<000000?ooo`3oool01@3oool7000000<0oooo
1`0000070?ooo`<0000000<0oooo0000000000000`0000080?ooo`030000003oool0000000@00000
00@0oooo00000000000000002`3oool3000000070?ooo`000000oooo0000003oool000000?ooo`02
000000/0oooo0P0000000`3oool000000?ooo`02000000030?ooo`000000000000800000303oool4
00000080oooo1@0000000`3oool000000?ooo`080?ooo`80000000<0oooo0000000000000P000000
103oool000000000000000070?ooo`80000000<0oooo0000000000000P0000000`3oool000000?oo
o`020?ooo`030000003oool0000000D000000`3oool6000000H0oooo0`0000000`3oool000000?oo
o`03000000T0oooo00<000000?ooo`0000001@0000000`3oool000000?ooo`02000000/0oooo0`00
00000`3oool000000000000200000080oooo00<000000?ooo`3oool02P3oool03@000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000002P3oool3000000030?ooo`00
0000oooo0080000000@0oooo00000000000000002P3oool00`000000oooo00000003000000040?oo
o`000000oooo000000L0oooo1P0000000`3oool000000?ooo`040?ooo`H000000P3oool3000000P0
oooo00<000000?ooo`3oool00P3oool000`0oooo00@0oono09bLg`3ookl0M000100000000`00B9`0
gooo0?ooo`0d0?ooo`030000003oool0oooo00D0oooo1`0000030?ooo`H0000000<0oooo0000003o
ool01@3oool9000000P0oooo00<000000?ooo`00000010000000103oool0000000000000000;0?oo
o`<0000000L0oooo0000003oool000000?ooo`000000oooo008000002`3oool2000000030?ooo`00
0000oooo0080000000<0oooo0000000000000P00000<0?ooo`<0000000<0oooo0000003oool01@00
00000`3oool000000?ooo`080?ooo`030000003oool0000000@0000000@0oooo0000000000000000
1`3oool00`000000oooo00000004000000030?ooo`000000oooo0080oooo00<000000?ooo`000000
1@0000030?ooo`H000001P3oool3000000030?ooo`000000oooo00<000002@3oool010000000oooo
0000003oool4000000050?ooo`00000000000?ooo`0000002`3oool3000000030?ooo`0000000000
0080000000<0oooo000000000000303oool010000000oooo0000003oool2000000070?ooo`000000
00000?ooo`000000oooo0000000:0?ooo`<0000000<0oooo0000003oool00P000000103oool00000
0000000000090?ooo`<0000000P0oooo00000000000000000?ooo`000000oooo000000L0oooo1P00
00000`3oool000000?ooo`040?ooo`H000000P3oool3000000P0oooo00<000000?ooo`3oool00P3o
ool000`0oooo00T0omnL04P000000000001809cOo`3oool0oooO09a8M02oool0=P3oool00`000000
oooo0?ooo`050?ooo`L000000`3oool6000000030?ooo`000000oooo00D0oooo2@0000080?ooo`03
0000003oool000000080000000<0oooo0000003oool00P0000000`3oool000000?ooo`090?ooo`<0
000000L0oooo0000003oool000000?ooo`000000oooo008000002`3oool01@000000oooo00000000
0000oooo0080000000H0oooo00000000000000000?ooo`00000;0?ooo`80000000@0oooo00000000
0000oooo1@0000000`3oool000000?ooo`090?ooo`<0000000@0oooo000000000000oooo0`000007
0?ooo`030000003oool0000000@0000000<0oooo0000003oool00P3oool00`000000oooo00000005
000000<0oooo1P0000060?ooo`T000002@3oool3000000030?ooo`00000000000080000000D0oooo
000000000000oooo0000000:0?ooo`050000003oool000000000003oool0100000000`3oool00000
0000000<0?ooo`040000003oool000000?ooo`80000000L0oooo000000000000oooo0000003oool0
000000X0oooo0`000000103oool000000?ooo`0000020?ooo`<000002@3oool3000000080?ooo`00
000000000000003oool000000?ooo`0000070?ooo`P000001@3oool600000080oooo0P0000090?oo
o`030000003oool0oooo0080oooo00080?ooo`040?oog`2LB000001d0;ooocl0oooo00<000000?oo
o`3oool01@3oool7000000<0oooo0`0000001@3oool000000000003oool0000000H0oooo2@000008
0?ooo`030000003oool000000080000000<0oooo0000003oool00P0000000`3oool000000?ooo`09
0?ooo`80000000@0oooo000000000000oooo0`000000103oool000000?ooo`00000:0?ooo`050000
003oool000000000003oool00P000000103oool000000000003oool2000000/0oooo0P000000103o
ool000000000003oool5000000030?ooo`000000oooo00T0oooo0P0000001@3oool0000000000000
0000oooo00<00000203oool6000000030?ooo`000000oooo00<0oooo1`0000030?ooo`H000001P3o
ool9000000T0oooo0`0000000`3oool0000000000002000000050?ooo`00000000000?ooo`000000
2P3oool2000000030?ooo`000000oooo00@0000000<0oooo000000000000303oool3000000040?oo
o`00000000000?ooo`80000000<0oooo0000000000002`3oool3000000070?ooo`000000oooo0000
003oool000000?ooo`02000000T0oooo0`0000001@3oool000000?ooo`000000oooo00800000203o
ool8000000D0oooo1P0000020?ooo`8000002@3oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0000000<000000`3oool3000000050?ooo`000000
00000?ooo`0000001P3oool9000000P0oooo00D000000?ooo`00000000000?ooo`02000000050?oo
o`00000000000?ooo`0000002P3oool00`000000oooo00000002000000040?ooo`00000000000?oo
o`80000000<0oooo0000003oool02P3oool3000000030?ooo`000000oooo00<0000000<0oooo0000
000000002`3oool2000000040?ooo`00000000000?ooo`@0000000<0oooo0000000000002P3oool2
000000040?ooo`00000000000?ooo`<0000000<0oooo0000003oool01P3oool6000000030?ooo`00
0000oooo00<0oooo1`0000020?ooo`L000001P3oool9000000T0oooo0`0000000`3oool000000000
0002000000050?ooo`00000000000?ooo`0000002P3oool2000000030?ooo`000000oooo00@00000
00<0oooo000000000000303oool3000000040?ooo`00000000000?ooo`80000000<0oooo00000000
00002`3oool3000000070?ooo`000000oooo0000003oool000000?ooo`02000000T0oooo0`000000
1@3oool000000?ooo`000000oooo00800000203oool00`000000oooo00000005000000D0oooo1P00
00020?ooo`8000002@3oool00`000000oooo0?ooo`020?ooo`00303oool01@3ogkl0_moo0?ooo`3o
ool0_g@000<0000000<0001d0;ooo`3oool0=03oool00`000000oooo0?ooo`060?ooo`H000000`3o
ool010000000oooo0000003oool2000000030?ooo`000000oooo00D0oooo2@0000080?ooo`050000
003oool000000000003oool01@0000000`3oool000000?ooo`090?ooo`030000003oool000000080
000000@0oooo000000000000oooo0P0000000`3oool000000?ooo`0:0?ooo`<0000000<0oooo0000
003oool00`0000000`3oool000000000000;0?ooo`80000000@0oooo000000000000oooo10000000
0`3oool000000000000:0?ooo`80000000@0oooo000000000000oooo0`0000000`3oool000000?oo
o`060?ooo`H0000000<0oooo0000003oool00`3oool700000080oooo1`0000060?ooo`T000002@3o
ool3000000030?ooo`00000000000080000000@0oooo00000000000000002`3oool2000000040?oo
o`00000000000?ooo`<0000000<0oooo000000000000303oool3000000040?ooo`00000000000?oo
o`80000000<0oooo0000000000002`3oool3000000050?ooo`00000000000000003oool00P000000
0`3oool000000?ooo`080?ooo`<0000000<0oooo0000003oool0100000080?ooo`030000003oool0
000000D000001@3oool600000080oooo0P0000090?ooo`030000003oool0oooo0080oooo000<0?oo
o`030;md0000000000000080000000D0001d0;ooo`3oool0_ibL0=ooo`0e0?ooo`8000001`3oool6
000000<0oooo00@000000?ooo`000000oooo100000060?ooo`P0000000<0oooo0000003oool01`3o
ool3000000080?ooo`00000000000000003oool000000?ooo`00000:0?ooo`030000003oool00000
0080000000@0oooo000000000000oooo0P0000000`3oool000000?ooo`0:0?ooo`<0000000<0oooo
0000003oool00`0000000`3oool000000000000;0?ooo`030000003oool000000080000000H0oooo
000000000000oooo0000003oool2000000X0oooo0P0000000`3oool0000000000004000000030?oo
o`000000oooo00H0oooo200000040?ooo`L000000P3oool3000000040?ooo`0000000000000000H0
oooo2@0000080?ooo`030000003oool000000080000000<0oooo0000000000000P0000000`3oool0
00000000000;0?ooo`80000000@0oooo000000000000oooo0`0000000`3oool000000000000;0?oo
o`050000003oool000000000003oool00P000000103oool000000000003oool2000000X0oooo00D0
00000?ooo`00000000000?ooo`03000000050?ooo`00000000000?ooo`0000002@3oool500000003
0?ooo`000000000000800000203oool00`000000oooo00000005000000D0oooo1P0000020?ooo`80
00001`3oool3000000@0oooo000:0?ooo`050;md0000000000000018W03Oool00`3oool00`3ooml0
W4P007Boo`020?ooo`030;md0000B9`0gooo0340oooo00<000000?ooo`3oool01P3oool6000000<0
oooo00@000000?ooo`000000oooo100000060?ooo`D0000000D0oooo000000000000oooo00000008
0?ooo`<0000000D0oooo00000000000000000?ooo`03000000/0oooo0`0000001@3oool000000000
00000000oooo0080000000<0oooo0000003oool02P3oool2000000040?ooo`00000000000?ooo`<0
000000<0oooo0000000000002`3oool00`000000oooo00000002000000060?ooo`00000000000?oo
o`000000oooo0P00000:0?ooo`80000000<0oooo0000000000000`0000000`3oool0000000000007
0?ooo`P00000103oool700000080oooo0`000000103oool000000000000000060?ooo`80000000<0
oooo0000000000000P0000000`3oool000000?ooo`070?ooo`030000003oool000000080000000<0
oooo0000000000000P0000000`3oool000000000000;0?ooo`80000000@0oooo000000000000oooo
0`0000000`3oool000000000000;0?ooo`050000003oool000000000003oool00P000000103oool0
00000000003oool2000000X0oooo0P0000000`3oool000000?ooo`03000000050?ooo`0000000000
0?ooo`0000002@3oool5000000030?ooo`0000000000008000001`3oool2000000030?ooo`000000
000000@00000103oool00`000000oooo0000000400000080oooo0P0000090?ooo`030000003oool0
oooo0080oooo000<0?ooo`030?noW02Lgol0oooo00P0oooo00<0omnL04Qd_`3oool0<@3oool00`00
0000oooo0?ooo`060?ooo`D0000000<0oooo0000003oool00P3oool7000000L0oooo100000001@3o
ool000000000003oool0000000P0oooo00@000000?ooo`000000oooo0`000000103oool000000000
0000000;0?ooo`<0000000D0oooo00000000000000000?ooo`02000000030?ooo`000000oooo00X0
oooo0P000000103oool000000000003oool3000000040?ooo`000000oooo000000X0oooo00<00000
0?ooo`0000000P0000000`3oool000000?ooo`05000000X0oooo0P0000000`3oool0000000000002
000000040?ooo`0000000000000000L0oooo200000040?ooo`L000000P3oool3000000040?ooo`00
00000000000000H0oooo0`0000001P3oool00000000000000000oooo000000P0oooo0P0000001@3o
ool00000000000000000oooo00<0000000<0oooo0000000000002`3oool2000000040?ooo`000000
00000?ooo`<0000000<0oooo0000000000002`3oool01@000000oooo000000000000oooo00800000
00H0oooo00000000000000000?ooo`00000:0?ooo`80000000<0oooo0000003oool00`000000103o
ool0000000000000000:0?ooo`D0000000<0oooo0000000000000P0000070?ooo`80000000<0oooo
0000003oool0100000040?ooo`L000000P3oool2000000T0oooo00<000000?ooo`3oool00P3oool0
00`0oooo00<0oono07Ad_`3oool01`3oool00`3o_g@004RL0=ooo`0b0?ooo`030000003oool0oooo
00H0oooo1`0000030?ooo`L000001`3oool4000000030?ooo`000000oooo00800000203oool00`00
0000oooo00000004000000040?ooo`0000000000000000/0oooo0`000000103oool000000000003o
ool2000000030?ooo`000000000000/0oooo0P000000103oool000000000003oool3000000040?oo
o`000000oooo000000/0oooo100000000`3oool000000?ooo`05000000/0oooo00<000000?ooo`00
00000`000000103oool000000000000000070?ooo`P00000103oool8000000030?ooo`0000000000
00D000001P3oool4000000050?ooo`00000000000?ooo`000000203oool2000000050?ooo`000000
00000000003oool0100000000`3oool000000?ooo`090?ooo`070000003oool000000000003oool0
00000?ooo`03000000030?ooo`000000000000/0oooo00T000000?ooo`00000000000?ooo`000000
oooo0000003oool00P0000000`3oool000000?ooo`090?ooo`80000000<0oooo0000003oool00`00
0000103oool000000000000000090?ooo`030000003oool0000000<0000000<0oooo000000000000
0P0000070?ooo`@0000000<0oooo0000000000000P0000040?ooo`L0000000@0oooo000000000000
00002@3oool00`000000oooo0?ooo`020?ooo`00303oool0103ogi`0B0000000M02oool50?ooo`03
0=nLB000M;l0oooo03<0oooo00<000000?ooo`3oool01P3oool7000000<0oooo1`0000070?ooo`@0
000000<0oooo0000000000000P0000080?ooo`030000003oool000000080000000<0oooo0000003o
ool00P0000000`3oool000000?ooo`090?ooo`<0000000@0oooo000000000000oooo0P0000000`3o
ool000000000000;0?ooo`80000000<0oooo0000003oool00`0000001@3oool000000000003oool0
000000/0oooo100000020?ooo`@0000000<0oooo0000000000002P3oool00`000000oooo00000003
000000040?ooo`0000000000000000P0oooo1`0000040?ooo`P0000000<0oooo0000000000001@00
00050?ooo`D0000000D0oooo000000000000oooo000000080?ooo`80000000<0oooo000000000000
0`0000001@3oool000000000003oool0000000X0oooo0P0000001@3oool000000?ooo`000000oooo
008000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000<0000000L0oooo0000
00000000oooo0000003oool0000000X0oooo0`0000020?ooo`<0000000@0oooo0000000000000000
2@3oool2000000050?ooo`00000000000000003oool0100000070?ooo`@0000000<0oooo00000000
00000P0000040?ooo`L0000000@0oooo00000000000000002@3oool00`000000oooo0?ooo`020?oo
o`003@3oool00`3ogi`0B000000000050000000304RLg`3oool0oooo03<0oooo00<000000?ooo`3o
ool01P3oool7000000<0oooo1`0000070?ooo`@0000000<0oooo0000000000000P0000080?ooo`03
0000003oool000000080000000<0oooo0000003oool00P0000000`3oool000000?ooo`090?ooo`80
000000@0oooo000000000000oooo0`0000000`3oool000000000000;0?ooo`80000000<0oooo0000
003oool00`0000000`3oool000000?ooo`02000000/0oooo0P000000103oool000000?ooo`3oool4
000000030?ooo`000000000000X0oooo0P0000001@3oool00000000000000000oooo00<00000203o
ool6000000030?ooo`000000oooo0080oooo200000000`3oool0000000000005000000D0oooo1P00
0000103oool000000?ooo`0000080?ooo`<0000000<0oooo0000000000000P0000001@3oool00000
0000003oool0000000X0oooo0P000000203oool000000000003oool000000?ooo`000000oooo0P00
000<0?ooo`030000003oool0000000<0000000@0oooo000000000000oooo0P00000;0?ooo`<00000
00<0oooo0000003oool00`0000000`3oool00000000000090?ooo`80000000<0oooo000000000000
0P3oool00`000000oooo000000080?ooo`T00000103oool600000080oooo0`0000090?ooo`030000
003oool0oooo0080oooo000B0?ooo`030?noM00004P0W=oo03H0oooo00<000000?ooo`3oool01P3o
ool2000000030?ooo`0000000000008000000`3oool6000000030?ooo`000000oooo00D0oooo1000
00000`3oool0000000000002000000P0oooo00D000000?ooo`00000000000?ooo`02000000050?oo
o`00000000000?ooo`0000002P3oool00`000000oooo00000002000000040?ooo`00000000000?oo
o`80000000<0oooo0000003oool02P3oool3000000040?ooo`00000000000?ooo`80000000<0oooo
0000000000002`3oool2000000040?ooo`000000oooo0?ooo`@0000000<0oooo0000000000002P3o
ool2000000040?ooo`00000000000?ooo`@00000203oool2000000060?ooo`00000000000000003o
ool00000103oool5000000030?ooo`000000000000H000001P3oool6000000030?ooo`0000000000
00T0oooo0`0000000`3oool0000000000002000000050?ooo`00000000000?ooo`0000002P3oool2
000000040?ooo`00000000000?ooo`<0000000<0oooo0000000000002`3oool01@000000oooo0000
00000000oooo0080000000@0oooo000000000000oooo0P00000;0?ooo`<0000000<0oooo0000003o
ool00`0000000`3oool00000000000090?ooo`80000000@0oooo000000000000oooo0P0000000`3o
ool000000?ooo`070?ooo`H0000000<0oooo000000000000103oool600000080oooo0`0000090?oo
o`030000003oool0oooo0080oooo000A0?ooo`030;md0000M;l0oooo03L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo00000003000000<0oooo0`0000000`3oool0000000000002000000H0
oooo0`0000000`3oool0000000000003000000P0oooo00D000000?ooo`00000000000?ooo`040000
00030?ooo`000000000000X0oooo00<000000?ooo`0000000P000000103oool000000000003oool2
000000030?ooo`000000oooo00X0oooo0`000000103oool000000000003oool2000000030?ooo`00
0000000000/0oooo00<000000?ooo`0000000P0000000`3oool0000000000002000000030?ooo`00
0000000000X0oooo0P000000103oool000000000003oool4000000P0oooo200000040?ooo`D00000
00<0oooo0000000000000P000000103oool000000000000000060?ooo`T00000203oool01@000000
oooo000000000000oooo00@0000000@0oooo00000000000000002`3oool2000000040?ooo`000000
00000?ooo`<0000000<0oooo0000000000002`3oool01@000000oooo000000000000oooo00800000
00@0oooo000000000000oooo0P00000;0?ooo`<0000000L0oooo00000000000000000?ooo`000000
oooo008000002@3oool2000000040?ooo`00000000000?ooo`@00000203oool6000000030?ooo`00
0000oooo00@0oooo1P0000020?ooo`8000002P3oool00`000000oooo0?ooo`020?ooo`00303oool0
1P3ogi`0B00007Boo`3o_g@0000007BoocT0oooo00<000000?ooo`3oool01`3oool00`000000oooo
00000003000000@0oooo1`0000060?ooo`<0000000<0oooo0000003oool00`0000080?ooo`050000
003oool000000000003oool0100000000`3oool000000000000:0?ooo`030000003oool000000080
000000@0oooo000000000000oooo0P0000000`3oool000000?ooo`0:0?ooo`<0000000<0oooo0000
003oool00`0000000`3oool000000000000;0?ooo`030000003oool000000080000000H0oooo0000
00000000oooo0000003oool2000000X0oooo0P0000000`3oool0000000000005000000P0oooo1000
0000103oool000000000000000040?ooo`D0000000<0oooo0000000000000P000000103oool00000
0000000000060?ooo`<0000000<0oooo0000000000000`0000080?ooo`80000000@0oooo00000000
0000oooo100000000`3oool000000000000;0?ooo`<0000000<0oooo0000003oool00`0000000`3o
ool000000000000;0?ooo`050000003oool000000000003oool00P000000103oool000000000003o
ool2000000/0oooo0`0000001`3oool00000000000000000oooo0000003oool00P0000090?ooo`80
000000@0oooo000000000000oooo100000080?ooo`<0000000<0oooo0000000000000P0000050?oo
o`@0000000@0oooo0000003oool0oooo0P00000:0?ooo`030000003oool0oooo0080oooo000<0?oo
o`040?oOW01800000000001d_c/0oooo00<000000?ooo`3oool01`3oool00`000000oooo00000003
000000@0oooo1`0000060?ooo`D0000000@0oooo00000000000000002@3oool3000000050?ooo`00
000000000000003oool00`00000;0?ooo`<0000000D0oooo00000000000000000?ooo`0200000003
0?ooo`000000oooo00X0oooo0P0000000`3oool000000?ooo`04000000040?ooo`000000oooo0000
00X0oooo00<000000?ooo`0000000P000000103oool000000000003oool4000000X0oooo0P000000
0`3oool0000000000005000000P0oooo10000000103oool000000000000000040?ooo`D0000000<0
oooo0000000000000P000000103oool000000000000000050?ooo`D0000000<0oooo000000000000
0P0000080?ooo`80000000D0oooo00000000000000000?ooo`03000000030?ooo`000000000000/0
oooo0`000000103oool000000000003oool2000000030?ooo`000000000000/0oooo00D000000?oo
o`00000000000?ooo`02000000040?ooo`00000000000?ooo`8000002P3oool2000000030?ooo`00
0000oooo00<0000000<0oooo0000003oool00P0000090?ooo`<0000000<0oooo0000003oool01000
00070?ooo`050000003oool000000000003oool0100000050?ooo`H000000P3oool2000000X0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000
0003000000@0oooo1`0000070?ooo`@0000000@0oooo00000000000000002@3oool3000000050?oo
o`00000000000000003oool00`00000;0?ooo`<0000000@0oooo000000000000oooo0`0000000`3o
ool000000?ooo`0:0?ooo`80000000<0oooo0000003oool010000000103oool000000?ooo`00000:
0?ooo`030000003oool000000080000000<0oooo0000003oool0100000000`3oool000000?ooo`09
0?ooo`030000003oool0000000<0000000@0oooo0000000000000000203oool7000000@0oooo1@00
00000`3oool0000000000006000000D0oooo1@0000000`3oool0000000000002000000P0oooo0P00
00001@3oool00000000000000000oooo00<0000000<0oooo0000000000002P3oool01@000000oooo
000000000000oooo0080000000@0oooo000000000000oooo0P00000;0?ooo`050000003oool00000
0000003oool00P0000001P3oool00000000000000000oooo000000X0oooo0P0000000`3oool00000
0?ooo`03000000050?ooo`00000000000?ooo`0000002@3oool00`000000oooo0000000200000003
0?ooo`0000000000008000001`3oool9000000@0oooo1`0000020?ooo`8000002P3oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`070?ooo`H00000103oool7000000L0oooo
10000000103oool000000000000000090?ooo`030000003oool0000000@0000000D0oooo00000000
0000oooo0000000:0?ooo`<0000000@0oooo000000000000oooo0`0000000`3oool000000?ooo`0:
0?ooo`80000000<0oooo0000003oool00`0000001@3oool000000000003oool0000000X0oooo00L0
00000?ooo`00000000000?ooo`000000oooo00@0000000<0oooo0000000000002P3oool600000004
0?ooo`0000000000000000P0oooo0P0000000`3oool0000000000002000000D0oooo2P0000000`3o
ool00000000000050?ooo`H0000000@0oooo0000003oool00000203oool2000000050?ooo`000000
00000000003oool0100000000`3oool000000?ooo`090?ooo`80000000@0oooo000000000000oooo
0P0000000`3oool000000?ooo`02000000X0oooo00<000000?ooo`3oool00P0000001@3oool00000
0?ooo`000000oooo0080000000<0oooo0000003oool02@3oool2000000030?ooo`000000oooo00<0
000000@0oooo00000000000000002@3oool2000000050?ooo`00000000000000003oool010000007
0?ooo`T00000103oool600000080oooo0`00000:0?ooo`030000003oool0oooo0080oooo001;0?oo
o`030000003oool0oooo00L0oooo1`0000030?ooo`L000001`3oool4000000050?ooo`0000000000
0?ooo`000000203oool00`000000oooo00000002000000030?ooo`000000oooo0080000000<0oooo
0000003oool02@3oool3000000040?ooo`00000000000?ooo`80000000<0oooo0000000000002`3o
ool2000000030?ooo`000000oooo00<0000000<0oooo0000003oool00P00000;0?ooo`80000000@0
oooo000000000000oooo100000000`3oool000000000000:0?ooo`80000000D0oooo000000000000
00000?ooo`03000000P0oooo0P0000000`3oool0000000000002000000D0oooo1@0000000`3oool0
000000000002000000030?ooo`000000000000D0oooo200000000`3oool000000?ooo`060?ooo`05
0000003oool000000000003oool00`0000001P3oool00000000000000000oooo000000X0oooo0P00
0000103oool000000000003oool2000000030?ooo`000000oooo008000002P3oool01@000000oooo
000000000000oooo0080000000L0oooo000000000000oooo0000003oool0000000X0oooo0`000002
0?ooo`@0000000<0oooo0000000000002@3oool2000000030?ooo`000000000000<0000000<0oooo
0000000000001`3oool6000000030?ooo`000000000000@0oooo1P0000020?ooo`<000002P3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`070?ooo`L00000103oool50000
00030?ooo`000000oooo00D0oooo0`0000001P3oool00000000000000000oooo000000T0oooo1000
00000`3oool000000?ooo`02000000030?ooo`000000oooo00T0oooo0P000000103oool000000000
003oool3000000040?ooo`000000oooo000000/0oooo0P0000000`3oool000000000000200000003
0?ooo`000000oooo008000002`3oool00`000000oooo00000002000000030?ooo`00000000000080
000000<0oooo0000000000002P3oool2000000050?ooo`00000000000000003oool00`0000080?oo
o`80000000<0oooo0000000000000`0000040?ooo`D0000000<0oooo0000000000000`0000000`3o
ool000000?ooo`030?ooo`050000003oool000000000003oool0100000000`3oool000000?ooo`06
0?ooo`050000003oool000000000003oool0100000001@3oool000000000003oool0000000X0oooo
0P000000103oool000000000003oool3000000030?ooo`000000000000/0oooo00D000000?ooo`00
000000000?ooo`02000000040?ooo`00000000000?ooo`8000002`3oool3000000030?ooo`000000
oooo00<0000000<0oooo0000000000002@3oool2000000040?ooo`00000000000?ooo`80000000<0
oooo0000003oool01`3oool6000000030?ooo`000000000000@0oooo1P0000020?ooo`<000002P3o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
000000<00000103oool7000000H0oooo0P0000000`3oool0000000000004000000T0oooo0`000000
1P3oool000000000003oool000000?ooo`8000002`3oool4000000040?ooo`00000000000?ooo`80
000000<0oooo0000003oool02P3oool2000000030?ooo`00000000000080000000<0oooo0000003o
ool00P00000;0?ooo`030000003oool000000080000000<0oooo0000000000000P0000000`3oool0
00000000000:0?ooo`80000000@0oooo000000000000oooo100000080?ooo`@0000000@0oooo0000
000000000000103oool<000000D0oooo100000000`3oool0000000000003000000P0oooo0P000000
103oool000000000003oool3000000050?ooo`00000000000?ooo`0000002P3oool3000000040?oo
o`00000000000?ooo`80000000<0oooo0000000000002`3oool01@000000oooo000000000000oooo
0080000000@0oooo000000000000oooo0P00000:0?ooo`0;0000003oool000000000003oool00000
0?ooo`000000oooo0000003oool00P0000090?ooo`<0000000<0oooo0000003oool00P0000000`3o
ool000000?ooo`070?ooo`H0000000<0oooo000000000000103oool600000080oooo0`00000:0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`00
00000`0000040?ooo`L000001P3oool00`000000oooo00000002000000040?ooo`00000000000000
00T0oooo0`0000001@3oool00000000000000000oooo00<000002`3oool4000000040?ooo`000000
00000?ooo`80000000<0oooo0000003oool02P3oool2000000030?ooo`000000oooo00@0000000@0
oooo0000003oool000002P3oool01@000000oooo000000000000oooo00<0000000H0oooo00000000
000000000?ooo`00000:0?ooo`L0000000<0oooo0000003oool01`3oool4000000040?ooo`000000
0000000000@0oooo20000000103oool000000000000000050?ooo`D0000000<0oooo000000000000
0P0000080?ooo`80000000@0oooo000000000000oooo100000000`3oool000000000000;0?ooo`<0
000000@0oooo000000000000oooo0P0000000`3oool000000000000;0?ooo`050000003oool00000
0000003oool00P0000001P3oool00000000000000000oooo000000X0oooo0P0000000`3oool00000
0?ooo`03000000050?ooo`00000000000?ooo`0000002@3oool3000000030?ooo`000000oooo0080
000000<0oooo0000003oool01`3oool4000000030?ooo`000000oooo00800000103oool600000080
oooo0P00000;0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`0000000`0000040?ooo`L000001P3oool5000000040?ooo`0000000000000000T0
oooo0P0000000`3oool0000000000002000000040?ooo`0000000000000000/0oooo100000000`3o
ool000000?ooo`03000000030?ooo`000000oooo00X0oooo0P0000000`3oool000000?ooo`040000
00040?ooo`000000oooo000000X0oooo00@000000?ooo`000000oooo0P0000000`3oool000000?oo
o`03000000030?ooo`000000oooo00T0oooo1`0000000`3oool000000?ooo`080?ooo`L000000`3o
ool9000000040?ooo`0000000000000000D0oooo1@0000000`3oool0000000000002000000L0oooo
00D000000?ooo`00000000000?ooo`03000000040?ooo`00000000000?ooo`8000002P3oool20000
00060?ooo`00000000000?ooo`000000oooo0P0000000`3oool000000000000;0?ooo`030000003o
ool000000080000000<0oooo0000003oool00`0000000`3oool000000?ooo`090?ooo`<000000P3o
ool3000000040?ooo`0000000000000000X0oooo00H000000?ooo`000000oooo0000003oool20000
00030?ooo`000000oooo00L0oooo10000000103oool000000?ooo`0000050?ooo`H000000P3oool2
000000/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0203oool60000
00@0oooo1`0000070?ooo`@0000000@0oooo00000000000000002@3oool00`000000oooo00000004
000000050?ooo`00000000000?ooo`0000002P3oool3000000030?ooo`000000oooo00<0000000<0
oooo0000000000002`3oool01@000000oooo000000000000oooo00<0000000D0oooo000000000000
oooo0000000:0?ooo`030000003oool0oooo00<0000000<0oooo0000003oool00P0000000`3oool0
00000000000:0?ooo`<0000000H0oooo00000000000000000?ooo`0000090?ooo`80000000<0oooo
0000000000000`0000020?ooo`/0000000<0oooo0000003oool0103oool3000000030?ooo`000000
00000080000000<0oooo0000003oool01P3oool01@000000oooo000000000000oooo00<0000000H0
oooo00000000000000000?ooo`00000:0?ooo`80000000@0oooo000000000000oooo0P0000000`3o
ool000000?ooo`02000000X0oooo00@000000?ooo`000000oooo0P0000000`3oool000000?ooo`03
000000030?ooo`000000oooo00T0oooo0`0000000`3oool000000?ooo`03000000030?ooo`000000
000000T0oooo0P0000001@3oool00000000000000000oooo00@000001`3oool00`000000oooo0000
0006000000D0oooo1P000000103oool0000000000000000;0?ooo`030000003oool0oooo0080oooo
001;0?ooo`8000002@3oool7000000<0oooo1`0000070?ooo`@0000000@0oooo0000000000000000
2P3oool6000000050?ooo`00000000000?ooo`0000002P3oool2000000040?ooo`00000000000?oo
o`<0000000<0oooo000000000000303oool2000000030?ooo`00000000000080000000<0oooo0000
003oool00P00000;0?ooo`030000003oool000000080000000<0oooo0000000000000P0000000`3o
ool000000?ooo`0:0?ooo`80000000D0oooo00000000000000000?ooo`03000000P0oooo20000002
0?ooo``000001@3oool01@000000oooo000000000000oooo00D00000203oool2000000040?ooo`00
000000000?ooo`<0000000D0oooo000000000000oooo0000000:0?ooo`<0000000<0oooo0000003o
ool00P000000103oool0000000000000000;0?ooo`040000003oool000000?ooo`<0000000<0oooo
0000003oool00P0000000`3oool000000?ooo`090?ooo`<0000000<0oooo0000003oool00`000000
0`3oool00000000000090?ooo`80000000<0oooo0000000000000`0000000`3oool0000000000007
0?ooo`H0000000<0oooo0000000000001@3oool500000080oooo0`0000090?ooo`<00000103oool0
04/0oooo00<000000?ooo`3oool02@3oool6000000@0oooo0`0000000`3oool00000000000070?oo
o`80000000<0oooo0000000000000`00000:0?ooo`@0000000<0oooo0000003oool00P0000000`3o
ool000000?ooo`090?ooo`80000000@0oooo000000000000oooo0`000000103oool000000?ooo`00
000;0?ooo`80000000@0oooo000000000000oooo0`0000000`3oool000000000000;0?ooo`050000
003oool000000000003oool00`000000103oool000000?ooo`00000<0?ooo`@0000000<0oooo0000
000000000P0000080?ooo`P000000P3oool<000000D0oooo100000000`3oool00000000000030000
00P0oooo0`0000000`3oool000000?ooo`04000000040?ooo`000000oooo000000X0oooo0`000000
103oool000000000003oool2000000030?ooo`000000000000/0oooo00D000000?ooo`0000000000
0?ooo`02000000040?ooo`000000oooo00000080oooo00<000000?ooo`3oool0203oool300000003
0?ooo`000000oooo00<0000000<0oooo0000000000002@3oool2000000030?ooo`000000000000<0
000000<0oooo0000000000001`3oool6000000030?ooo`000000000000@0oooo1P0000020?ooo`<0
00002`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0000000<00000103oool5000000030?ooo`000000oooo00D0oooo0P0000000`3oool00000
00000002000000030?ooo`000000oooo00P0oooo0`0000000`3oool0000000000002000000030?oo
o`000000000000/0oooo10000000103oool000000000003oool2000000030?ooo`000000oooo00X0
oooo00D000000?ooo`00000000000?ooo`04000000030?ooo`000000000000/0oooo00D000000?oo
o`00000000000?ooo`03000000040?ooo`0000000000000000`0oooo1`0000000`3oool000000?oo
o`080?ooo`<0000000D0oooo00000000000000000?ooo`09000000040?ooo`0000000000000000D0
oooo1@0000000`3oool0000000000002000000L0oooo00L000000?ooo`00000000000?ooo`000000
oooo00@0000000@0oooo0000003oool000002P3oool01`000000oooo000000000000oooo0000003o
ool00P0000000`3oool000000000000;0?ooo`80000000H0oooo000000000000oooo0000003oool3
000000030?ooo`000000oooo00T0oooo0`0000020?ooo`070000003oool000000?ooo`000000oooo
0000000:0?ooo`<0000000<0oooo0000003oool00P0000000`3oool000000?ooo`070?ooo`@00000
00<0oooo0000003oool00P0000040?ooo`030000003oool0000000<000000P3oool3000000/0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0000
0003000000@0oooo1`0000060?ooo`L0000000<0oooo0000003oool0203oool2000000030?ooo`00
0000000000<0000000<0oooo0000000000002`3oool400000080oooo00H000000?ooo`0000000000
0?ooo`00000;0?ooo`050000003oool000000000003oool010000000103oool000000?ooo`00000:
0?ooo`040000003oool000000?ooo`80000000<0oooo0000003oool00`00000<0?ooo`L0000000<0
oooo0000003oool0203ooolC000000030?ooo`000000oooo00@0oooo0`0000000`3oool000000?oo
o`04000000L0oooo00D000000?ooo`00000000000?ooo`03000000060?ooo`00000000000000003o
ool000002P3oool2000000060?ooo`00000000000?ooo`000000oooo0P0000000`3oool000000000
000:0?ooo`040000003oool000000?ooo`80000000<0oooo0000003oool00`0000000`3oool00000
0?ooo`090?ooo`<0000000<0oooo0000003oool00P000000103oool000000000000000090?ooo`07
0000003oool000000000003oool000000?ooo`04000000P0oooo10000000103oool0000000000000
00050?ooo`H0000000@0oooo0000000000000000303oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`090?ooo`H00000103oool7000000H0oooo1@000000103oool000000000
000000090?ooo`80000000<0oooo0000000000000P0000001@3oool000000000003oool0000000X0
oooo0P000000103oool000000000003oool3000000030?ooo`000000000000`0oooo0P0000000`3o
ool0000000000002000000030?ooo`000000oooo008000002`3oool00`000000oooo000000020000
00030?ooo`000000oooo0080000000<0oooo0000003oool02P3oool2000000030?ooo`0000000000
0080000000<0oooo000000000000203oool;000000030?ooo`000000000000H000001@3oool02P00
0000oooo000000000000oooo0000003oool000000?ooo`0000080?ooo`80000000@0oooo00000000
0000oooo0P0000001P3oool00000000000000000oooo000000X0oooo0`0000000`3oool000000?oo
o`02000000040?ooo`000000oooo000000/0oooo00@000000?ooo`000000oooo0`0000000`3oool0
00000?ooo`02000000030?ooo`000000oooo00T0oooo0`0000000`3oool000000?ooo`0300000003
0?ooo`000000000000T0oooo0P0000001@3oool00000000000000000oooo00@000001`3oool50000
00040?ooo`0000000000000000D0oooo1P000000103oool0000000000000000<0?ooo`030000003o
ool0oooo0080oooo001;0?ooo`030000003oool0oooo00T0oooo1P0000050?ooo`H000001`3oool2
000000030?ooo`000000oooo00<000002P3oool4000000030?ooo`000000oooo0080000000<0oooo
0000003oool02@3oool2000000040?ooo`00000000000?ooo`<0000000<0oooo000000000000303o
ool2000000080?ooo`00000000000?ooo`000000oooo0000003oool2000000/0oooo00D000000?oo
o`00000000000?ooo`02000000050?ooo`00000000000?ooo`000000303oool4000000030?ooo`00
0000000000800000203oool;000000030?ooo`000000000000H000001@3oool5000000030?ooo`00
0000000000800000203oool3000000030?ooo`000000oooo00<0000000D0oooo000000000000oooo
0000000:0?ooo`<0000000H0oooo000000000000oooo0000003oool3000000/0oooo00X000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0P0000000`3oool000000?ooo`090?ooo`<0
000000<0oooo0000003oool00`0000000`3oool00000000000090?ooo`80000000L0oooo00000000
000000000?ooo`000000oooo008000001`3oool9000000D0oooo1P000000103oool0000000000000
000<0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`0000000`0000040?ooo`H000001`3oool2000000030?ooo`000000oooo0080000000<0oooo
0000003oool0203oool3000000030?ooo`000000000000<0000000<0oooo0000003oool02@3oool0
0`000000oooo00000002000000040?ooo`00000000000?ooo`80000000<0oooo0000003oool02P3o
ool01@000000oooo000000000000oooo00@0000000<0oooo0000000000002`3oool01@000000oooo
000000000000oooo00<0000000@0oooo0000000000000000303oool7000000030?ooo`000000oooo
00P0oooo100000000`3oool0000000000003000000030?ooo`000000000000H000001@3oool50000
00030?ooo`0000000000008000001`3oool01@000000oooo000000000000oooo0080000000P0oooo
00000000000000000?ooo`000000oooo000000X0oooo00@000000?ooo`000000oooo0P0000000`3o
ool000000?ooo`03000000X0oooo00@000000?ooo`000000oooo0P000000203oool000000?ooo`00
0000oooo0000003oool000002`3oool3000000030?ooo`000000oooo00<0000000<0oooo00000000
00002@3oool2000000030?ooo`000000000000<0000000<0oooo0000003oool01`3oool400000003
0?ooo`000000oooo008000001@3oool500000080oooo0`00000<0?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`0000000`0000040?ooo`H00000
1`3oool2000000030?ooo`00000000000080000000<0oooo0000003oool0203oool2000000030?oo
o`000000000000<0000000<0oooo0000000000002`3oool2000000060?ooo`00000000000?ooo`00
0000oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool000000000003oool010000000
103oool000000?ooo`00000;0?ooo`80000000<0oooo0000000000000P000000103oool000000000
0000000<0?ooo`L0000000<0oooo0000003oool0203oool4000000030?ooo`000000000000800000
0P3oool6000000030?ooo`000000oooo00<0oooo00L000000?ooo`00000000000?ooo`000000oooo
00<00000203oool01@000000oooo000000000000oooo0080000000<0oooo0000000000000P000000
0`3oool000000?ooo`090?ooo`<0000000D0oooo0000003oool000000?ooo`02000000030?ooo`00
0000000000X0oooo00@000000?ooo`000000oooo0P0000000`3oool000000?ooo`03000000030?oo
o`000000oooo00T0oooo00H000000?ooo`000000oooo0000003oool2000000040?ooo`0000000000
000000T0oooo00<000000?ooo`0000000P0000000`3oool0000000000003000000P0oooo10000000
1@3oool000000000003oool0000000@0oooo1P0000020?ooo`8000003@3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`0:0?ooo`H00000103oool6000000L0oooo2@000009
0?ooo`80000000<0oooo0000000000000`0000000`3oool000000000000;0?ooo`80000000@0oooo
000000000000oooo0`0000000`3oool000000000000<0?ooo`80000000<0oooo0000000000000P00
00000`3oool000000?ooo`02000000/0oooo00D000000?ooo`00000000000?ooo`02000000050?oo
o`00000000000?ooo`000000303oool6000000030?ooo`000000000000P0oooo2@0000020?ooo`P0
0000103oool500000080oooo00<000000?ooo`000000203oool2000000040?ooo`00000000000?oo
o`80000000H0oooo00000000000000000?ooo`00000:0?ooo`<0000000<0oooo0000003oool00P00
00000`3oool000000?ooo`02000000X0oooo00D000000?ooo`000000oooo000000020?ooo`800000
00D0oooo000000000000oooo0000000:0?ooo`<0000000<0oooo0000003oool00P000000103oool0
00000000000000090?ooo`030000003oool0000000<0000000<0oooo0000000000000P0000070?oo
o`D0000000@0oooo00000000000000001@3oool6000000040?ooo`0000000000000000d0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02P3oool6000000D0oooo1P000007
0?ooo`@0000000@0oooo00000000000000002P3oool4000000070?ooo`00000000000?ooo`000000
oooo0000000:0?ooo`80000000@0oooo000000000000oooo0`0000000`3oool000000000000<0?oo
o`050000003oool000000000003oool00P0000000`3oool000000?ooo`02000000/0oooo00D00000
0?ooo`00000000000?ooo`02000000050?ooo`00000000000?ooo`000000303oool9000000P0oooo
0P0000000`3oool000000000000400000080oooo2@0000030?ooo`D000000P3oool3000000P0oooo
0`0000001P3oool000000000003oool000000?ooo`<0000000<0oooo0000003oool0203oool01@00
0000oooo000000000000oooo0080000000H0oooo0000003oool000000?ooo`00000:0?ooo`040000
003oool000000?ooo`80000000D0oooo0000003oool000000?ooo`02000000030?ooo`000000oooo
00T0oooo0`0000000`3oool000000?ooo`03000000030?ooo`000000000000T0oooo0P0000001`3o
ool00000000000000000oooo0000003oool00P0000070?ooo`T000001@3oool6000000040?ooo`00
00000000000000d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02P3o
ool2000000040?ooo`0000000000000000D0oooo1P0000070?ooo`80000000<0oooo0000003oool0
0P0000000`3oool000000?ooo`080?ooo`<0000000<0oooo0000000000000`0000000`3oool00000
0?ooo`090?ooo`040000003oool000000?ooo`@0000000D0oooo000000000000oooo0000000;0?oo
o`050000003oool000000000003oool0100000000`3oool000000000000<0?ooo`<0000000<0oooo
0000000000000P0000000`3oool000000000000<0?ooo`T000002@3oool800000080oooo1`000000
1P3oool000000?ooo`3oool000000?ooo`@0000000<0oooo0000000000000P0000070?ooo`050000
003oool000000000003oool00P000000103oool000000000003oool2000000030?ooo`000000oooo
00P0oooo0`0000020?ooo`80000000<0oooo0000003oool00`00000:0?ooo`040000003oool00000
0?ooo`80000000<0oooo0000003oool00P0000000`3oool000000000000;0?ooo`<0000000<0oooo
0000003oool00`0000000`3oool00000000000090?ooo`80000000<0oooo0000000000000`000000
0`3oool000000?ooo`070?ooo`@0000000<0oooo0000003oool00P0000050?ooo`H0000000@0oooo
00000000000000003@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool00000008000001@3oool6000000L0oooo100000001@3oool000000000003o
ool0000000T0oooo0`0000000`3oool0000000000002000000030?ooo`000000000000/0oooo0P00
00001P3oool000000000003oool000000?ooo`80000000<0oooo0000003oool02`3oool200000003
0?ooo`000000000000<0000000@0oooo0000003oool000002`3oool2000000030?ooo`000000oooo
0080000000@0oooo0000000000000000303oool00`000000oooo00000004000000030?ooo`000000
oooo00P0oooo0P0000000`3oool000000000000200000080oooo20000000103oool000000?ooo`3o
ool4000000030?ooo`000000oooo00<00000203oool01P000000oooo000000000000oooo00000080
oooo100000000`3oool000000?ooo`090?ooo`<0000000L0oooo0000003oool000000?ooo`000000
oooo00<000002P3oool00`000000oooo0000000200000080oooo00<000000?ooo`0000000P000000
0`3oool000000?ooo`090?ooo`080000003oool000000?ooo`000000oooo0000003oool300000003
0?ooo`000000oooo00L0oooo00<000000?ooo`0000000P0000001P3oool00000000000000000oooo
000000P0oooo100000000`3oool000000?ooo`02000000@0oooo1P0000020?ooo`8000003P3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0;0?ooo`H00000103oool60000
00L0oooo00D000000?ooo`00000000000?ooo`04000000T0oooo00<000000?ooo`0000001@000000
0`3oool000000000000;0?ooo`80000000<0oooo0000003oool00P0000000`3oool000000?ooo`02
000000`0oooo0P0000000`3oool000000?ooo`02000000050?ooo`00000000000?ooo`0000002`3o
ool01@000000oooo000000000000oooo0080000000D0oooo000000000000oooo0000000<0?ooo`D0
000000@0oooo0000000000000000203oool2000000030?ooo`000000000000<0000000<0oooo0000
000000001@0000020?ooo`030000003oool0oooo00D000000P3oool00`000000oooo000000080?oo
o`<0000000H0oooo000000000000oooo0000003oool3000000030?ooo`000000oooo00P0oooo00L0
00000?ooo`00000000000?ooo`000000oooo008000000P3oool3000000T0oooo00@000000?ooo`00
0000oooo0P0000020?ooo`80000000D0oooo000000000000oooo0000000:0?ooo`<0000000<0oooo
0000003oool00P000000103oool000000000000000090?ooo`80000000@0oooo000000000000oooo
1@0000070?ooo`T000001@3oool6000000040?ooo`0000000000000000h0oooo00<000000?ooo`3o
ool00P3oool004/0oooo00<000000?ooo`3oool02`3oool6000000D0oooo1@0000080?ooo`@00000
00@0oooo00000000000000002P3oool4000000040?ooo`00000000000?ooo`800000303oool30000
00030?ooo`00000000000080000000<0oooo000000000000303oool01@000000oooo000000000000
oooo0080000000<0oooo0000003oool00P00000;0?ooo`060000003oool000000?ooo`000000oooo
100000000`3oool000000?ooo`0;0?ooo`030000003oool0000000H000002@3oool7000000050?oo
o`00000000000000003oool0100000001`3oool00000000000000000oooo0000003oool00P000000
0`3oool0000000000002000000L0oooo00D000000?ooo`00000000000?ooo`02000000030?ooo`00
0000oooo00<0000000<0oooo0000003oool0203oool00`000000oooo0000000200000080oooo0P00
00000`3oool000000?ooo`02000000T0oooo00@000000?ooo`000000oooo0P0000020?ooo`800000
00D0oooo000000000000oooo000000090?ooo`070000003oool000000000003oool000000?ooo`03
000000030?ooo`000000000000T0oooo0P0000001`3oool00000000000000000oooo0000003oool0
0P0000070?ooo`T000001@3oool2000000050?ooo`000000oooo0000003oool00`00000>0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00/0oooo0P000000103oool00000
0000000000050?ooo`H000001`3oool4000000050?ooo`00000000000?ooo`0000002@3oool30000
00080?ooo`00000000000000003oool000000?ooo`00000;0?ooo`80000000H0oooo000000000000
oooo0000003oool2000000030?ooo`000000oooo00X0oooo00@000000?ooo`000000oooo1@000000
0`3oool000000000000<0?ooo`050000003oool000000000003oool00`0000000`3oool000000000
000<0?ooo`030000003oool0000000H000002@3oool@00000080oooo1@0000000`3oool000000?oo
o`04000000L0oooo00@000000?ooo`000000oooo0P0000020?ooo`80000000D0oooo000000000000
oooo000000080?ooo`0>0000003oool000000000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`00000:0?ooo`030000003oool00000008000000P3oool020000000oooo000000000000
oooo0000003oool000002@3oool2000000050?ooo`000000oooo0000003oool00`0000000`3oool0
0000000000080?ooo`030000003oool000000080000000D0oooo00000000000000000?ooo`020000
00L0oooo100000000`3oool000000?ooo`02000000@0oooo1P0000020?ooo`<000003P3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0;0?ooo`80000000@0oooo00000000
000000001@3oool6000000L0oooo00D000000?ooo`00000000000?ooo`02000000030?ooo`000000
oooo00P0oooo00@000000?ooo`000000oooo100000000`3oool000000000000;0?ooo`80000000<0
oooo0000003oool00P0000001@3oool000000000003oool0000000`0oooo0P0000000`3oool00000
00000003000000040?ooo`000000oooo000000/0oooo00D000000?ooo`00000000000?ooo`020000
00050?ooo`00000000000?ooo`000000303oool5000000040?ooo`0000000000000000T0oooo3`00
00020?ooo`H000000P3oool00`000000oooo000000080?ooo`040000003oool000000?ooo`800000
0P3oool4000000030?ooo`000000oooo00P0oooo00/000000?ooo`00000000000?ooo`000000oooo
0000003oool000000?ooo`03000000T0oooo00<000000?ooo`3oool00`0000020?ooo`030000003o
ool000000080000000<0oooo0000003oool02@3oool3000000050?ooo`000000oooo0000003oool0
0`0000000`3oool000000?ooo`070?ooo`80000000@0oooo000000000000oooo0`0000000`3oool0
00000?ooo`070?ooo`@0000000<0oooo0000003oool00P0000040?ooo`H000000P3oool2000000l0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0303oool6000000@0oooo
1P0000070?ooo`050000003oool000000000003oool01000000:0?ooo`@0000000@0oooo00000000
0000oooo0P00000<0?ooo`<0000000H0oooo000000000000oooo0000003oool2000000`0oooo00@0
00000?ooo`000000oooo0`0000001@3oool000000000003oool0000000`0oooo0P0000000`3oool0
00000?ooo`04000000030?ooo`000000oooo00/0oooo00H000000?ooo`000000oooo0000003oool3
000000T0oooo100000000`3oool0000000000009000000030?ooo`00000000000080000000<0oooo
0000003oool00P0000000`3oool000000?ooo`060?ooo`030000003oool000000080000000D0oooo
0000003oool000000?ooo`03000000030?ooo`000000oooo00L0oooo00H000000?ooo`3oool00000
0?ooo`0000020?ooo`8000000P3oool3000000T0oooo00@000000?ooo`000000oooo0P0000020?oo
o`80000000D0oooo000000000000oooo000000090?ooo`80000000D0oooo0000003oool000000?oo
o`02000000040?ooo`0000000000000000T0oooo0P0000001@3oool00000000000000000oooo00@0
00001`3oool9000000D0oooo10000000103oool000000?ooo`3oool2000000l0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool0303oool6000000D0oooo1@0000080?ooo`@0
000000@0oooo00000000000000002P3oool4000000040?ooo`00000000000?ooo`800000303oool2
000000030?ooo`000000000000<0000000<0oooo000000000000303oool010000000oooo0000003o
ool3000000030?ooo`000000oooo00800000303oool01@000000oooo000000000000oooo00@00000
00<0oooo0000003oool0303oool8000000T0oooo100000000`3oool0000000000009000000030?oo
o`000000000000<000000P3oool4000000L0oooo00@000000?ooo`000000oooo0P0000020?ooo`03
0000003oool000000080000000<0oooo0000003oool01`3oool01P000000oooo000000000000oooo
00000080oooo0P0000000`3oool000000?ooo`02000000T0oooo00<000000?ooo`0000000P000003
0?ooo`<0000000@0oooo0000003oool000002@3oool3000000040?ooo`000000oooo0?ooo`800000
00@0oooo0000000000000000203oool2000000040?ooo`00000000000?ooo`<0000000<0oooo0000
000000001`3oool9000000@0oooo0`0000000`3oool00000000000020?ooo`<000003`3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool2000000d0oooo0P000000103oool000000000000000050?oo
o`H000001`3oool4000000050?ooo`00000000000?ooo`0000002@3oool2000000040?ooo`000000
00000?ooo`80000000<0oooo000000000000303oool3000000040?ooo`00000000000?ooo`800000
00<0oooo0000003oool02`3oool00`000000oooo00000002000000040?ooo`00000000000?ooo`80
00003@3oool2000000030?ooo`00000000000080000000<0oooo0000000000003@3oool600000003
0?ooo`000000oooo00P0oooo20000000103oool000000000003oool4000000060?ooo`0000000000
0000003oool000000P3oool00`000000oooo000000080?ooo`@0000000H0oooo0000003oool0oooo
0000003oool4000000P0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`070000003oool0
00000?ooo`000000oooo000000090?ooo`040000003oool000000?ooo`8000000P3oool020000000
oooo000000000000oooo0000003oool00000203oool01P000000oooo000000000000oooo00000080
oooo0`0000000`3oool00000000000080?ooo`80000000@0oooo000000000000oooo0`0000000`3o
ool00000000000070?ooo`@0000000<0oooo0000003oool00P0000040?ooo`H000000P3oool20000
00h0oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`0<0?ooo`80000000<0oooo00000000
00000P0000040?ooo`H000001`3oool00`000000oooo00000004000000030?ooo`000000oooo00T0
oooo10000000103oool000000000003oool2000000`0oooo0`0000000`3oool00000000000030000
00030?ooo`000000oooo00/0oooo00@000000?ooo`000000oooo10000000103oool000000?ooo`00
000<0?ooo`050000003oool000000000003oool0100000000`3oool000000?ooo`0<0?ooo`@00000
00@0oooo00000000000000001`3oool9000000050?ooo`00000000000000003oool010000000103o
ool000000000000000020?ooo`80000000<0oooo0000003oool01`3oool2000000030?ooo`000000
00000080oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`070?ooo`060000003oool0
00000000003oool000000P3oool2000000030?ooo`000000oooo008000002@3oool01P000000oooo
000000000000oooo00000080oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`080?oo
o`80000000<0oooo0000000000000P3oool2000000050?ooo`00000000000?ooo`000000203oool2
000000050?ooo`00000000000000003oool00P0000000`3oool000000?ooo`070?ooo`H0000000<0
oooo000000000000103oool600000080oooo0P00000@0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo00d0oooo1P0000040?ooo`80000000@0oooo00000000000000001`3o
ool00`000000oooo00000006000000X0oooo0P0000000`3oool0000000000002000000030?ooo`00
0000000000`0oooo0P0000000`3oool0000000000003000000030?ooo`000000000000d0oooo00<0
00000?ooo`0000001P0000000`3oool000000?ooo`0<0?ooo`80000000@0oooo000000000000oooo
0P0000000`3oool000000?ooo`0<0?ooo`P000001`3oool4000000030?ooo`000000000000800000
00@0oooo00000000000000000P3oool700000080oooo100000070?ooo`@0000000H0oooo0000003o
ool0oooo0000003oool3000000030?ooo`000000oooo00H0oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`80000000<0oooo0000003oool00P0000090?ooo`80000000<0oooo000000000000
0`3oool3000000040?ooo`000000oooo000000T0oooo0`000000103oool000000?ooo`3oool20000
00040?ooo`0000000000000000P0oooo0P0000000`3oool000000?ooo`02000000030?ooo`000000
0000008000001`3oool9000000D0oooo1@0000030?ooo`800000403oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`0=0?ooo`80000000@0oooo00000000000000001@3oool5
000000P0oooo10000000103oool0000000000000000:0?ooo`80000000@0oooo000000000000oooo
0`0000000`3oool000000?ooo`0;0?ooo`<0000000D0oooo00000000000000000?ooo`02000000d0
oooo00<000000?ooo`0000000P000000103oool000000000003oool2000000d0oooo00D000000?oo
o`00000000000?ooo`03000000030?ooo`000000oooo00d0oooo1@0000000`3oool000000?ooo`06
0?ooo`80000000<0oooo0000000000001`0000030?ooo`L000000P3oool3000000P0oooo0P000000
0`3oool00000000000030?ooo`030000003oool0000000<00000203oool01P000000oooo00000000
0000oooo000000<0oooo0P000000103oool000000?ooo`0000090?ooo`060000003oool000000000
003oool000000`3oool3000000040?ooo`000000oooo000000P0oooo0P0000000`3oool000000000
00030?ooo`80000000@0oooo0000000000000000203oool2000000040?ooo`00000000000?ooo`<0
000000<0oooo0000000000001`3oool9000000@0oooo1P0000020?ooo`<00000403oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0=0?ooo`80000000<0oooo000000000000
0P0000040?ooo`H000001`3oool00`000000oooo00000004000000030?ooo`000000oooo00T0oooo
10000000103oool000000000003oool2000000`0oooo0P0000000`3oool000000000000400000003
0?ooo`000000oooo00`0oooo0P0000000`3oool0000000000002000000030?ooo`000000000000h0
oooo0`0000000`3oool000000?ooo`03000000h0oooo200000050?ooo`<000000P3oool8000000<0
oooo1`0000001@3oool000000000003oool0000000L0oooo100000001@3oool000000?ooo`3oool0
00000080oooo00@000000?ooo`00000000001`3oool010000000oooo0?ooo`0000020?ooo`050000
003oool0oooo0000003oool00P0000000`3oool00000000000090?ooo`80000000<0oooo00000000
00000`3oool00`000000oooo0000000200000080oooo00<000000?ooo`3oool01P3oool300000003
0?ooo`000000oooo0080oooo00H000000?ooo`00000000000?ooo`0000080?ooo`80000000D0oooo
00000000000000000?ooo`02000000030?ooo`000000000000L0oooo0P0000001@3oool000000?oo
o`000000oooo00800000103oool600000080oooo0P00000A0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo00d0oooo0P0000000`3oool0000000000002000000@0oooo1P00
00070?ooo`030000003oool0000000@0000000<0oooo0000003oool02@3oool2000000030?ooo`00
000000000080000000<0oooo0000000000003@3oool3000000050?ooo`00000000000000003oool0
0P00000=0?ooo`030000003oool0000000@0000000@0oooo0000003oool000003@3oool200000003
0?ooo`000000000000<0000000<0oooo0000003oool03@3oool7000000D0oooo0`0000000`3oool0
000000000007000000<0oooo1@0000000`3oool000000?ooo`02000000030?ooo`000000oooo00H0
oooo1@0000030?ooo`030000003oool000000080000000<0oooo0000003oool01P3oool01P000000
oooo000000000000oooo000000<0oooo0P0000000`3oool000000?ooo`02000000P0oooo00H00000
0?ooo`00000000000?ooo`0000030?ooo`070000003oool000000?ooo`000000oooo000000080?oo
o`030000003oool00000008000000`3oool2000000040?ooo`0000000000000000P0oooo0P000000
0`3oool000000?ooo`02000000050?ooo`00000000000?ooo`000000203oool6000000030?ooo`00
0000000000@0oooo1P0000020?ooo`8000004@3oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`0>0?ooo`80000000@0oooo00000000000000001@3oool5000000P0oooo00D0
00000?ooo`00000000000?ooo`03000000X0oooo0P0000000`3oool0000000000004000000030?oo
o`000000oooo00/0oooo0P0000000`3oool0000000000002000000030?ooo`000000000000h0oooo
0P0000000`3oool0000000000003000000030?ooo`000000oooo00d0oooo0`0000001P3oool00000
000000000000oooo000000h0oooo1@0000000`3oool000000?ooo`030?ooo`<000000P3oool80000
00@0oooo1@0000000`3oool0000000000003000000L0oooo1@0000040?ooo`040000003oool00000
0?ooo`8000001`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0?ooo`800000
00@0oooo0000003oool000002@3oool2000000030?ooo`000000000000<0oooo00P000000?ooo`00
000000000?ooo`000000oooo000000P0oooo0`0000000`3oool000000?ooo`020?ooo`80000000@0
oooo0000000000000000203oool2000000040?ooo`000000000000000080oooo100000070?ooo`T0
0000103oool600000080oooo0`00000A0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo00h0oooo0P000000103oool000000000000000050?ooo`D00000203oool00`000000
oooo00000004000000030?ooo`000000oooo00T0oooo0P0000000`3oool000000000000300000003
0?ooo`000000oooo00/0oooo00<000000?ooo`0000001`00000>0?ooo`030000003oool0000000@0
000000<0oooo0000000000003P3oool2000000030?ooo`000000000000@000003`3oool7000000<0
oooo0`0000000`3oool000000?ooo`07000000<0oooo00<000000?ooo`0000000`0000020?ooo`80
000000<0oooo0000003oool01@3oool00`000000oooo00000003000000<0oooo00<000000?ooo`00
00000P0000000`3oool000000?ooo`060?ooo`060000003oool000000000003oool00000103oool3
000000030?ooo`000000000000P0oooo00H000000?ooo`00000000000?ooo`0000030?ooo`050000
003oool000000000003oool00P0000090?ooo`@00000103oool010000000oooo0000003oool20000
00P0oooo0P0000001@3oool00000000000000000oooo0080000000<0oooo0000000000001`3oool0
10000000oooo0000003oool5000000@0oooo1P0000020?ooo`<000004@3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`0>0?ooo`80000000<0oooo0000000000000P000005
0?ooo`D00000203oool6000000030?ooo`000000oooo00T0oooo0P0000000`3oool0000000000002
000000030?ooo`000000000000d0oooo0P0000000`3oool0000000000003000000030?ooo`000000
oooo00d0oooo0P0000000`3oool0000000000003000000030?ooo`000000oooo00d0oooo10000000
1@3oool000000000003oool0000000h0oooo1`0000030?ooo`<0000000D0oooo0000000000000000
0?ooo`05000000<0oooo1P0000020?ooo`80000000<0oooo0000003oool01@3oool5000000@0oooo
00<000000?ooo`0000000P0000000`3oool000000?ooo`050?ooo`040000003oool0oooo00000080
oooo00H000000?ooo`3oool0oooo0000003oool2000000030?ooo`000000000000P0oooo0P000000
0`3oool00000000000040?ooo`030000003oool000000080000000<0oooo0000003oool01`3oool2
000000030?ooo`000000000000@0oooo00<000000?ooo`0000000P0000080?ooo`80000000@0oooo
00000000000000000P3oool2000000030?ooo`000000oooo00H0oooo1`0000000`3oool000000000
00040?ooo`H000000P3oool200000180oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool03`3oool2000000040?ooo`0000000000000000D0oooo1@0000080?ooo`030000003o
ool0000000D000002`3oool3000000030?ooo`000000000000<000003@3oool00`000000oooo0000
0004000000030?ooo`000000000000h0oooo00<000000?ooo`0000001@0000000`3oool000000?oo
o`0=0?ooo`80000000<0oooo0000003oool01000000?0?ooo`<0000000D0oooo0000000000000000
0?ooo`03000000030?ooo`000000oooo0080000000<0oooo000000000000100000000`3oool00000
0?ooo`06000000040?ooo`0000000000000000H0oooo00<000000?ooo`0000000`0000030?ooo`08
0000003oool000000000003oool000000?ooo`0000060?ooo`060000003oool000000000003oool0
0000103oool300000080oooo00<000000?ooo`3oool01P3oool01P000000oooo000000000000oooo
000000<0oooo00P000000?ooo`00000000000?ooo`000000oooo000000P0oooo100000040?ooo`<0
000000<0oooo000000000000203oool2000000040?ooo`000000000000000080oooo100000070?oo
o`040000003oool000000?ooo`D000001@3oool00`000000oooo0000000200000080oooo0`00000B
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00l0oooo0P000000103o
ool000000000000000050?ooo`D000002@3oool6000000030?ooo`000000oooo00T0oooo0P000000
0`3oool0000000000003000000030?ooo`000000oooo00`0oooo0P0000000`3oool0000000000004
000000l0oooo0P0000000`3oool0000000000003000000030?ooo`000000oooo00d0oooo1`000000
0`3oool000000?ooo`0=0?ooo`L0000000D0oooo00000000000000000?ooo`0300000080oooo1`00
00000`3oool0000000000006000000030?ooo`000000000000H0oooo1@0000040?ooo`030000003o
ool000000080000000<0oooo0000003oool01@3oool010000000oooo0?ooo`0000020?ooo`060000
003oool0oooo0?ooo`000000oooo0P0000000`3oool00000000000080?ooo`80000000<0oooo0000
00000000103oool01@000000oooo000000000000oooo00800000203oool2000000030?ooo`000000
000000@0oooo0`0000000`3oool00000000000070?ooo`030000003oool0000000<000000P3oool0
0`000000oooo00000002000000H0oooo1@0000000`3oool0000000000002000000@0oooo1P000002
0?ooo`<000004P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00<000001@3oool5000000P0oooo00<000000?ooo`0000001@00000;0?oo
o`H0000000<0oooo0000000000003@3oool00`000000oooo00000005000000030?ooo`000000oooo
00d0oooo00<000000?ooo`0000001@0000000`3oool000000?ooo`0=0?ooo`80000000<0oooo0000
003oool00P0000000`3oool000000?ooo`0>0?ooo`D0000000L0oooo00000000000000000?ooo`00
0000oooo008000000P3oool7000000050?ooo`00000000000000003oool01`0000050?ooo`040000
003oool000000?ooo`800000103oool00`000000oooo00000002000000030?ooo`000000oooo00D0
oooo00H000000?ooo`00000000000?ooo`0000040?ooo`050000003oool000000000003oool00P00
00070?ooo`030000003oool00000008000001@3oool00`000000oooo00000002000000030?ooo`00
0000oooo00L0oooo100000050?ooo`060000003oool000000000003oool000001`3oool200000004
0?ooo`000000000000000080oooo0P0000000`3oool000000?ooo`060?ooo`030000003oool00000
0080000000D0oooo000000000000oooo000000040?ooo`H000000P3oool300000180oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0403oool2000000040?ooo`0000000000
000000D0oooo1@0000080?ooo`030000003oool0000000D000002`3oool2000000040?ooo`000000
00000?ooo`<000003P3oool2000000030?ooo`00000000000080000000<0oooo0000003oool03P3o
ool2000000030?ooo`00000000000080000000<0oooo0000003oool03P3oool800000100oooo2000
0000103oool000000000000000020?ooo``000000P3oool6000000@0oooo00<000000?ooo`000000
0`0000040?ooo`030000003oool00000008000000P3oool00`000000oooo0?ooo`030?ooo`060000
003oool0oooo0000003oool000001@3oool3000000030?ooo`000000000000P0oooo0P0000000`3o
ool00000000000040?ooo`050000003oool000000000003oool00P0000080?ooo`80000000<0oooo
000000000000103oool3000000030?ooo`000000000000P0oooo1@0000030?ooo`@000001P3oool5
000000030?ooo`0000000000008000001@3oool00`000000oooo0000000200000080oooo0`00000C
0?ooo`030000003oool0oooo0080oooo000_0?ooo`040;md00000000000007Boo`<0oooo00<0omnL
04P0001d_ol00P3oool00`3OW4P00000000000030000000304RLg`3oool0oooo00L0oooo00<00000
0?ooo`3oool0403oool2000000040?ooo`0000000000000000H0oooo0P0000000`3oool000000000
00080?ooo`H0000000<0oooo0000003oool02P3oool6000000030?ooo`000000000000d0oooo00<0
00000?ooo`0000001@0000000`3oool000000?ooo`0>0?ooo`80000000<0oooo0000000000000P00
00000`3oool000000?ooo`0>0?ooo`050000003oool000000000003oool00`00000?0?ooo`800000
00<0oooo0000000000001`0000020?ooo`/000000`3oool7000000<0oooo1@0000050?ooo`030000
003oool000000080000000<0oooo0000003oool0103oool00`000000oooo0?ooo`02000000030?oo
o`000000oooo00<0oooo00D000000?ooo`00000000000?ooo`02000000L0oooo00<000000?ooo`00
00000P0000050?ooo`050000003oool000000000003oool00P0000080?ooo`@000001@3oool30000
00030?ooo`000000000000L0oooo0P000000103oool000000000000000030?ooo`040000003oool0
0000000000H0oooo00<000000?ooo`0000000P0000000`3oool0000000000002000000@0oooo1P00
00020?ooo`<000004`3oool00`000000oooo0?ooo`020?ooo`00;P3oool01P3OW4P007Bo0?ooo`3o
gi`0B00004RLg`80oooo00<0omnL04P0001d_ol00`3oool00`3o_g@007Bo0?ooo`020?ooo`030;md
M02oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`03000000D0oooo
1@0000080?ooo`030000003oool0000000D000002`3oool2000000030?ooo`000000000000@00000
3P3oool2000000030?ooo`00000000000080000000<0oooo0000003oool03P3oool2000000030?oo
o`000000oooo0080000000<0oooo0000003oool03`3oool700000100oooo1P000000103oool00000
0000000000020?ooo`@0000000<0oooo000000000000100000040?ooo`D0000000@0oooo0000003o
ool0oooo1@0000060?ooo`80000000D0oooo000000000000oooo000000050?ooo`060000003oool0
00000000003oool000001@3oool2000000030?ooo`000000oooo008000001P3oool010000000oooo
0000003oool2000000@0oooo00<000000?ooo`3oool00P0000000`3oool00000000000070?ooo`80
000000<0oooo000000000000103oool2000000030?ooo`000000oooo008000001`3oool5000000<0
oooo0P0000000`3oool000000?ooo`060?ooo`@000000P3oool2000000030?ooo`000000oooo00<0
oooo00<000000?ooo`0000000`0000000`3oool0000000000002000001<0oooo00<000000?ooo`3o
ool00P3oool002d0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?no
M000M;l0oooo00/0oooo00<000000?ooo`3oool04@3oool2000000040?ooo`0000000000000000D0
oooo1@0000090?ooo`L00000303oool8000000h0oooo00<000000?ooo`000000100000000`3oool0
00000?ooo`0?0?ooo`80000000@0oooo000000000000oooo0P00000@0?ooo`@0000000<0oooo0000
00000000403oool:00000080oooo0`0000030?ooo`D00000103oool5000000070?ooo`0000000000
0000003oool000000?ooo`02000000D0oooo00<000000?ooo`0000000P0000020?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`00000000000P3oool00`000000oooo0?ooo`030?ooo`<00000
00<0oooo0000000000001P3oool00`000000oooo0?ooo`03000000D0oooo00D000000?ooo`000000
00000?ooo`02000000L0oooo0P0000000`3oool00000000000050?ooo`<0000000<0oooo00000000
00001`3oool2000000040?ooo`000000oooo000000<0oooo100000060?ooo`D0000000<0oooo0000
003oool00P0000040?ooo`@0000000@0oooo0000003oool0oooo0`00000D0?ooo`030000003oool0
oooo0080oooo000]0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo203oool0
0`3o_g@007Bo0?ooo`0:0?ooo`030000003oool0oooo0140oooo0P000000103oool0000000000000
00060?ooo`D00000203oool01@000000oooo000000000000oooo00<000002`3oool2000000030?oo
o`000000000000@000003P3oool2000000030?ooo`00000000000080000000<0oooo0000003oool0
3`3oool3000000050?ooo`00000000000?ooo`000000403oool2000000050?ooo`00000000000?oo
o`000000403oool800000080oooo100000020?ooo`D00000103oool00`000000oooo000000030000
0080oooo1P0000060?ooo`030000003oool000000080000000<0oooo0000003oool00`3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`00000000000?oo
o`02000000H0oooo00H000000?ooo`00000000000?ooo`0000050?ooo`050000003oool000000000
003oool00P0000070?ooo`80000000<0oooo000000000000103oool01@000000oooo000000000000
oooo008000001`3oool5000000@0oooo00<000000?ooo`0000001`3oool2000000040?ooo`000000
oooo0?ooo`@00000103oool00`000000oooo0000000300000080oooo0`00000D0?ooo`030000003o
ool0oooo0080oooo000]0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol02@3oool0
0`3o_g@0B9cO0?ooo`090?ooo`030000003oool0oooo0180oooo0P000000103oool0000000000000
00050?ooo`D00000203oool00`000000oooo00000005000000`0oooo2000000?0?ooo`<0000000D0
oooo000000000000oooo0000000@0?ooo`030000003oool0000000D000004@3oool7000000l0oooo
200000020?ooo`<000000P3oool00`000000oooo00000004000000<0oooo0P0000000`3oool00000
00000002000000030?ooo`000000000000<000001`3oool3000000040?ooo`000000oooo000000<0
oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`050?ooo`<000000P3oool2000000D0
oooo00@000000?ooo`000000oooo0P0000050?ooo`040000003oool0000000000080oooo0P000006
0?ooo`80000000<0oooo0000000000001@3oool2000000030?ooo`000000oooo008000001P3oool2
000000040?ooo`000000oooo000000<0oooo100000060?ooo`D0000000H0oooo0000003oool00000
0?ooo`0000030?ooo`L0000000<0oooo0000000000000P00000D0?ooo`030000003oool0oooo0080
oooo000^0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l02P3oool00`3OW4P0B9cO
0?ooo`080?ooo`<000004P3oool2000000040?ooo`0000000000000000H0oooo100000090?ooo`@0
000000@0oooo0000003oool000002`3oool2000000030?ooo`000000000000<000003`3oool20000
00030?ooo`00000000000080000000<0oooo0000003oool03`3oool3000000030?ooo`0000000000
008000004@3oool00`000000oooo00000004000000d0oooo200000020?ooo`040000003oool00000
00000080oooo1`0000020?ooo`030000003oool0000000X000001`3oool00`000000oooo00000002
000000030?ooo`000000oooo00<0oooo00H000000?ooo`00000000000?ooo`0000060?ooo`050000
003oool000000000003oool00P0000050?ooo`030000003oool0oooo0080000000<0oooo0000003o
ool0103oool01@000000oooo000000000000oooo008000001P3oool2000000030?ooo`0000000000
00H0oooo0`000000103oool000000?ooo`0000060?ooo`D00000103oool010000000oooo00000000
00060?ooo`80000000@0oooo000000000000oooo100000040?ooo`@0000000@0oooo0000003oool0
oooo0`00000B0?ooo`@00000103oool002h0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0
001d_`0;0?ooo`030;md001d_ol0oooo00L0oooo00<000000?ooo`3oool04`3oool00`000000oooo
00000002000000H0oooo1@0000080?ooo`030000003oool0000000D00000303oool2000000030?oo
o`000000000000<000003`3oool800000140oooo1`00000B0?ooo`H00000303oool:000000040?oo
o`000000000000000080oooo2@000000103oool000000000003oool2000000030?ooo`0000000000
00D000001`3oool2000000050?ooo`00000000000?ooo`0000000`3oool01P000000oooo00000000
0000oooo000000L0oooo0P0000000`3oool000000?ooo`02000000@0oooo00<000000?ooo`3oool0
0P0000000`3oool000000?ooo`050?ooo`030000003oool000000080oooo0P0000060?ooo`800000
00<0oooo0000000000001@3oool01@000000oooo000000000000oooo008000001P3oool200000004
0?ooo`000000oooo000000<0oooo0P0000000`3oool000000?ooo`050?ooo`D000000P3oool40000
00<0oooo1`0000020?ooo`<000005@3oool00`000000oooo0?ooo`020?ooo`00;P3oool00`3ogi`0
B00004RLg`030?ooo`030;md0000B9`0gooo00X0oooo00<0omnL04P0M02oool01`3oool00`000000
oooo0?ooo`0C0?ooo`80000000@0oooo00000000000000001@3oool5000000T0oooo1`00000<0?oo
o`80000000@0oooo000000000000oooo0P00000@0?ooo`040000003oool000000?ooo`<000004P3o
ool600000180oooo1`00000;0?ooo`/0000000@0oooo000000000000oooo0P000000103oool00000
0000003oool5000000060?ooo`00000000000?ooo`000000oooo1`0000060?ooo`030000003oool0
00000080000000<0oooo0000003oool00P3oool010000000oooo0000000000020?ooo`030000003o
ool0oooo00D0oooo0`0000020?ooo`8000000`3oool00`000000oooo0?ooo`02000000030?ooo`00
0000oooo00D0oooo00D000000?ooo`00000000000?ooo`02000000H0oooo0P0000000`3oool00000
000000060?ooo`<0000000@0oooo0000003oool000001P3oool5000000@0oooo100000060?ooo`80
000000T0oooo000000000000oooo0000003oool000000?ooo`0000000`3oool3000000030?ooo`00
000000000080oooo0`00000F0?ooo`030000003oool0oooo0080oooo000^0?ooo`040?oog`2LB000
04RL0=ooo`80oooo00<0gia80018W03Oool02P3oool00`3ooml0W4P007Boo`070?ooo`030000003o
ool0oooo01<0oooo0P000000103oool000000000000000060?ooo`D00000203oool00`000000oooo
00000005000000`0oooo0P0000000`3oool000000000000200000100oooo2000000A0?ooo`L00000
4@3oool8000000T0oooo3P000000103oool000000000003oool3000000030?ooo`000000000000@0
000000H0oooo000000000000oooo0000003oool6000000H0oooo00<000000?ooo`0000000P000000
0`3oool000000?ooo`020?ooo`80000000@0oooo0000003oool000001`3oool01@000000oooo0000
00000000oooo008000000`3oool01@000000oooo0?ooo`000000oooo008000001`3oool01@000000
oooo000000000000oooo008000001P3oool00`000000oooo0?ooo`02000000D0oooo00P000000?oo
o`00000000000?ooo`000000oooo000000D0oooo0P000000103oool000000?ooo`0000030?ooo`80
000000<0oooo0000000000001@3oool500000080oooo100000030?ooo`L000000P3oool3000001H0
oooo00<000000?ooo`3oool00P3oool002l0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo
0?ooo`0:0?ooo`030?oo_`1d0000B9cO00L0oooo00<000000?ooo`3oool0503oool2000000040?oo
o`0000000000000000D0oooo1@0000090?ooo`L00000303oool2000000030?ooo`000000000000<0
0000403oool2000000030?ooo`0000000000008000004P3oool2000000030?ooo`000000oooo0080
00004@3oool2000000060?ooo`00000000000000003oool000001`3oool5000000040?ooo`000000
00000?ooo`<0000000@0oooo000000000000oooo10000000103oool000000?ooo`3oool600000003
0?ooo`000000oooo00H0000000<0oooo000000000000103oool01@000000oooo000000000000oooo
008000000`3oool2000000040?ooo`000000oooo000000P0oooo0P0000000`3oool000000?ooo`02
00000080oooo00D000000?ooo`3oool000000?ooo`02000000L0oooo00P000000?ooo`3oool00000
0?ooo`000000oooo000000D0oooo0P0000000`3oool00000000000060?ooo`070000003oool00000
0?ooo`000000oooo000000060?ooo`030000003oool0000000800000103oool2000000030?ooo`00
0000oooo00D0oooo0P0000002@3oool000000000003oool000000?ooo`000000oooo000000030?oo
o`<0000000<0oooo0000000000000P3oool4000001H0oooo00<000000?ooo`3oool00P3oool00300
oooo00H0gia80000M02oool0oooO09a80018W=l70?ooo`070?noM000B9`0gooo0?ooo`3OW4P00018
09cOo`070?ooo`030000003oool0oooo01@0oooo0P000000103oool000000000000000060?ooo`@0
00002@3oool00`000000oooo00000004000000d0oooo1`00000@0?ooo`040000003oool000000?oo
o`@000004P3oool700000100oooo00<000000?ooo`000000100000000`3oool000000?ooo`050?oo
oa@0000000@0oooo0000003oool0oooo1`0000000`3oool0000000000009000000<0oooo00<00000
0?ooo`0000000P000000103oool000000?ooo`3oool2000000040?ooo`0000000000000000T0oooo
0`0000000`3oool00000000000030?ooo`040000003oool000000?ooo`800000203oool01@000000
oooo000000000000oooo008000001@3oool200000080oooo0P0000060?ooo`<0000000@0oooo0000
003oool000001@3oool2000000040?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P00
00050?ooo`D000000P3oool4000000<0oooo100000000`3oool00000000000020?ooo`<000005`3o
ool00`000000oooo0?ooo`020?ooo`00<@3oool0103OW4P0000000000000M;l90?ooo`050?oOW018
000000000000001d_ol0203oool00`000000oooo0?ooo`0E0?ooo`80000000@0oooo000000000000
00001@3oool5000000T0oooo1`00000<0?ooo`030000003oool0000000D00000403oool700000180
oooo00<000000?ooo`0000001@00000@0?ooo`L0000000<0oooo0000003oool00`3oool700000080
oooo00<000000?ooo`0000001P0000001@3oool000000?ooo`3oool0000000<0oooo2P0000000`3o
ool000000000000500000080oooo00D000000?ooo`3oool000000?ooo`02000000030?ooo`000000
000000@000002P3oool01@000000oooo000000000000oooo008000000P3oool00`000000oooo0?oo
o`03000000T0oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo00<000000?ooo`3o
ool00P0000060?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`80000000@0oooo
0000003oool00000103oool2000000030?ooo`000000000000D0oooo0P0000000`3oool000000000
00020?ooo`@000000`3oool3000000040?ooo`000000000000000080oooo0`00000G0?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01D0oooo0P000000103oool000000000
000000060?ooo`@000002@3oool00`000000oooo00000004000000d0oooo00D000000?ooo`000000
00000?ooo`0200000140oooo1`00000B0?ooo`030000003oool000000080000000<0oooo00000000
00003`3oool02@000000oooo000000000000oooo0000003oool000000?ooo`0200000080oooo1P00
00030?ooo`X000000`3oool010000000oooo0?ooo`3oool;00000080oooo1P0000000`3oool00000
0?ooo`03000000030?ooo`000000000000<0000000<0oooo0000003oool02P3oool3000000030?oo
o`00000000000080oooo00D000000?ooo`3oool000000?ooo`02000000P0oooo00D000000?ooo`3o
ool000000?ooo`02000000D0oooo0P000000103oool000000?ooo`0000060?ooo`<0000000@0oooo
0000003oool00000103oool2000000040?ooo`0000000000000000D0oooo0P0000000`3oool00000
0?ooo`040?ooo`D000000P3oool010000000oooo0000000000030?ooo`@0000000<0oooo00000000
00000P3oool4000001L0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
5P3oool2000000030?ooo`000000000000H0oooo1@0000090?ooo`<0000000<0oooo000000000000
3P3oool2000000030?ooo`0000000000008000004@3oool01@000000oooo000000000000oooo0080
00004@3oool6000000040?ooo`0000000000000000h0oooo0P0000001P3oool00000000000000000
oooo00000080oooo200000040?ooo`030000003oool0000000H000000`3oool01@000000oooo0?oo
o`000000oooo00P00000103oool3000000040?ooo`000000000000000080oooo00<000000?ooo`00
00000`000000103oool0000000000000000;0?ooo`050000003oool000000000003oool00P000000
1P3oool000000?ooo`3oool000000?ooo`8000002@3oool00`000000oooo00000002000000030?oo
o`000000oooo00<0oooo0P000000103oool000000?ooo`0000060?ooo`050000003oool000000000
003oool00P0000050?ooo`@0000000<0oooo0000003oool00`3oool2000000030?ooo`0000000000
00@0oooo0`0000000`3oool00000000000020?ooo`@000000`3oool3000000040?ooo`0000000000
00000080oooo0`00000H0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
01H0oooo0P000000103oool000000000000000060?ooo`@000002P3oool6000000h0oooo1`00000@
0?ooo`P000004@3oool6000000040?ooo`000000oooo000000d0oooo00D000000?ooo`0000000000
0?ooo`02000000030?ooo`000000oooo0080000000<0oooo0000000000000P0000050?ooo`/00000
00@0oooo0000003oool0oooo2P0000050?ooo`<0000000@0oooo000000000000oooo0`0000000`3o
ool0000000000003000000d0oooo0`0000001P3oool000000000003oool000000?ooo`D000002@3o
ool01@000000oooo0?ooo`000000oooo00800000103oool2000000040?ooo`000000oooo000000L0
oooo0`000000103oool000000?ooo`0000040?ooo`80000000@0oooo0000003oool000001@3oool2
000000030?ooo`000000oooo00@0oooo1@0000030?ooo`<000000`3oool300000080oooo0P000002
0?ooo`@00000603oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0F0?oo
o`8000000P3oool2000000H0oooo1@0000090?ooo`<0000000<0oooo0000000000003P3oool80000
0100oooo10000000103oool000000?ooo`00000@0?ooo`050000003oool000000000003oool00P00
00000`3oool000000?ooo`02000000`0oooo0P0000000`3oool0000000000005000000030?ooo`00
00000000008000001@3oool7000000030?ooo`000000000000@0000000<0oooo0000000000002P00
00040?ooo`P0000000<0oooo0000000000000P0000000`3oool000000?ooo`0<0?ooo`050000003o
ool000000000003oool00`0000001P3oool000000?ooo`000000oooo000000X0oooo00D000000?oo
o`00000000000?ooo`02000000<0oooo0P000000103oool000000?ooo`0000070?ooo`050000003o
ool000000000003oool00P0000040?ooo`80000000@0oooo0000003oool000001@3oool01@000000
oooo0000003oool0000000@0oooo10000000103oool000000?ooo`3oool4000000<0oooo0`000002
0?ooo`8000000P3oool3000001T0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool05`3oool2000000040?ooo`0000000000000000H0oooo1000000:0?ooo`H000003P3oool7
00000100oooo00<000000?ooo`000000100000000`3oool000000?ooo`0?0?ooo`030000003oool0
000000L0000000<0oooo0000003oool02P3oool01@000000oooo000000000000oooo00T000001@3o
ool5000000040?ooo`000000000000000080oooo3@0000000`3oool0000000000002000000@0oooo
3@00000>0?ooo`<0000000X0oooo00000000000000000?ooo`000000oooo0000003oool000002P3o
ool01@000000oooo0?ooo`000000oooo008000000`3oool2000000040?ooo`000000oooo000000P0
oooo0`000000103oool000000?ooo`0000030?ooo`80000000D0oooo000000000000oooo00000005
0?ooo`80000000<0oooo0000003oool00`3oool2000000040?ooo`0000000000000000<0oooo0`00
00030?ooo`<000000P3oool200000080oooo1000000I0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo01L0oooo0P0000020?ooo`8000001P3oool4000000/0oooo00<00000
0?ooo`0000000P00000?0?ooo`L00000403oool00`000000oooo00000004000000030?ooo`000000
oooo00h0oooo00<000000?ooo`0000000`0000000`3oool0000000000005000000X0oooo0P000000
103oool000000000003oool2000000030?ooo`000000000000D0000000<0oooo0000000000001000
0000103oool000000000000000040?ooo`d000000P3oool2000000<0oooo2`00000?0?ooo`050000
003oool000000000003oool01P0000000`3oool000000?ooo`0:0?ooo`050000003oool000000000
003oool00P0000020?ooo`040000003oool000000?ooo`8000002@3oool3000000030?ooo`000000
000000<0oooo0P0000001@3oool000000000003oool0000000D0oooo00D000000?ooo`000000oooo
000000040?ooo`D000000`3oool010000000oooo0000000000030?ooo`<000000P3oool200000080
oooo0`00000J0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01P0oooo
0P000000103oool000000000000000050?ooo`D000002P3oool6000000h0oooo0`0000001@3oool0
00000000003oool0000000l0oooo00<000000?ooo`0000001@0000000`3oool000000?ooo`0>0?oo
o`030000003oool0000000<0000000P0oooo00000000000000000?ooo`000000oooo000000T0oooo
00H000000?ooo`00000000000?ooo`0000020?ooo`<0000000<0oooo0000000000001`000000103o
ool000000000003oool3000000030?ooo`000000000000X0000000@0oooo00000000000000000`3o
ool200000080oooo2000000A0?ooo`L0000000<0oooo0000003oool00P00000;0?ooo`050000003o
ool0oooo0000003oool00P0000020?ooo`040000003oool000000?ooo`8000002@3oool300000004
0?ooo`000000oooo000000<0oooo100000000`3oool000000?ooo`050?ooo`80000000<0oooo0000
003oool00`3oool3000000030?ooo`000000000000<0oooo0`0000030?ooo`<000000P3oool30000
00030?ooo`0000000000008000006P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`0H0?ooo`8000000P3oool2000000H0oooo1000000;0?ooo`030000003oool000000080
00003`3oool00`000000oooo00000003000000030?ooo`000000oooo00h0oooo00<000000?ooo`00
00000P0000000`3oool0000000000002000000h0oooo00D000000?ooo`00000000000?ooo`020000
0080oooo1`0000080?ooo`80000000<0oooo000000000000100000000`3oool000000000000Q0000
0080oooo3@00000?0?ooo`030000003oool0000000P000003@3oool01@000000oooo000000000000
oooo0080000000D0oooo0000003oool000000?ooo`02000000X0oooo0`0000000`3oool000000000
00030?ooo`@0000000<0oooo0000003oool01P3oool2000000030?ooo`000000oooo00<0oooo0P00
00000`3oool00000000000040?ooo`<000000`3oool300000080oooo0P0000020?ooo`<000006`3o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0I0?ooo`80000000@0oooo
00000000000000001@3oool5000000/0oooo00<000000?ooo`0000000P00000>0?ooo`P000003`3o
ool00`000000oooo00000005000000030?ooo`000000000000h0oooo00<000000?ooo`0000000P00
00000`3oool00000000000020?ooo`L000001P3oool01@000000oooo000000000000oooo00<00000
0`3ooolA000000<0oooo0`0000000`3oool000000?ooo`020?oooa40000000<0oooo000000000000
0P00000>0?ooo`L0000000<0oooo0000003oool03@3oool00`000000oooo0?ooo`04000000060?oo
o`000000oooo0000003oool000002`3oool01@000000oooo000000000000oooo008000000P3oool2
000000050?ooo`00000000000?ooo`0000001P3oool2000000030?ooo`000000oooo00<0oooo00<0
00000?ooo`0000000P0000040?ooo`<000000`3oool300000080oooo0`0000000`3oool000000000
0002000001/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool06@3oool2
00000080oooo0P0000060?ooo`@000002`3oool5000000l0oooo2000000?0?ooo`030000003oool0
00000080000000@0oooo000000000000oooo0`00000<0?ooo`060000003oool000000000003oool0
00000P3oool300000080oooo200000030?ooo``000000P3oool2000000030?ooo`000000oooo00<0
oooo0P0000001@3oool000000?ooo`000000oooo00<0000000<0oooo0000003oool0103oool20000
00040?ooo`0000000000000000@0oooo1`000000103oool0000000000000000<0?ooo`X000003`3o
ool01@000000oooo000000000000oooo00D0000000<0oooo0000003oool02`3oool3000000030?oo
o`00000000000080oooo0P0000001@3oool000000000003oool0000000L0oooo0P0000000`3oool0
00000?ooo`020?ooo`<0000000<0oooo000000000000103oool300000080oooo100000020?ooo`80
000000<0oooo0000000000000P00000L0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo01X0oooo0P0000000`3oool00000000000060?ooo`D000002P3oool2000000040?oo
o`0000000000000000h0oooo00<000000?ooo`0000000`0000000`3oool000000000000>0?ooo`05
0000003oool000000000003oool02@00000;0?ooo`060000003oool000000000003oool00000103o
oolG000000@0oooo00<000000?ooo`0000001P3oool6000000040?ooo`0000000000000000H0oooo
00<000000?ooo`0000000`0000040?ooo`80000000<0oooo0000000000001`0000050?ooo`h00000
403oool00`000000oooo0?ooo`04000000030?ooo`000000oooo00800000303oool01@000000oooo
000000000000oooo008000000P3oool01P000000oooo000000000000oooo000000L0oooo0P000000
0`3oool000000?ooo`030?ooo`80000000<0oooo000000000000103oool300000080oooo10000002
0?ooo`<0000000<0oooo0000000000000P00000L0?ooo`030000003oool0oooo0080oooo001;0?oo
o`8000006`3oool200000080oooo0P0000060?ooo`@000002`3oool5000000l0oooo1P0000000`3o
ool000000000000>0?ooo`030000003oool000000080000000<0oooo0000000000000P0000000`3o
ool000000?ooo`02000000T0oooo00H000000?ooo`00000000000?ooo`00000:0?ooo``0000000<0
oooo0000003oool01@3oool2000000030?ooo`000000oooo00D0oooo0P0000000`3oool000000?oo
o`03000000030?ooo`000000oooo00H0oooo00<000000?ooo`0000000`0000020?ooo`030000003o
ool0000000l0000000@0oooo00000000000000000P3oool700000140oooo00D000000?ooo`000000
00000?ooo`03000000030?ooo`000000000000d0oooo0`0000000`3oool00000000000020?ooo`04
0000003oool0000000000080oooo00<000000?ooo`3oool01@3oool2000000030?ooo`000000oooo
0080oooo00D000000?ooo`000000oooo000000050?ooo`<000000P3oool3000000<0oooo1`00000K
0?ooo`<00000103oool004/0oooo00<000000?ooo`3oool06`3oool2000000030?ooo`0000000000
00H0oooo1@00000:0?ooo`H000003P3oool00`000000oooo0000000400000080oooo00<000000?oo
o`3oool02`3oool01P000000oooo000000000000oooo00000080oooo1P0000000`3oool000000000
00080?ooo`060000003oool000000000003oool000003@3oool3000000080?ooo`00000000000000
003oool000000?ooo`0000040?ooo`80000000<0oooo0000003oool01`3oool2000000030?ooo`00
0000oooo00<000002@3oool00`000000oooo00000003000000040?ooo`00000000000?ooo`800000
00<0oooo0000000000000P0000030?ooo`h0000000<0oooo0000000000004@3oool010000000oooo
0000003oool3000000040?ooo`0000000000000000d0oooo00D000000?ooo`00000000000?ooo`02
000000080?ooo`00000000000000003oool000000?ooo`0000070?ooo`80000000<0oooo0000003o
ool00P3oool3000000030?ooo`000000000000@0oooo0`0000020?ooo`<000000`3oool8000001d0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool06`3oool200000080oooo
0P0000060?ooo`@000002`3oool6000000h0oooo0P0000000`3oool000000000000200000080oooo
0P00000<0?ooo`030000003oool0000000800000103oool6000000030?ooo`000000000000H0oooo
00@000000?ooo`000000oooo0P00000;0?ooo`<000000P3oool3000000050?ooo`00000000000?oo
o`0000000`3oool2000000030?ooo`000000oooo00P0oooo2000000:0?ooo`80000000<0oooo0000
000000000P0000001P3oool000000000003oool000000?ooo`@000000`3oool3000000H0oooo0P00
00001@3oool000000000003oool000000140oooo00<000000?ooo`0000001`00000>0?ooo`<00000
00@0oooo000000000000oooo0`000000103oool000000?ooo`0000080?ooo`80000000<0oooo0000
003oool00P3oool2000000030?ooo`000000000000D0oooo0`0000000`3oool00000000000020000
00<0oooo1`00000N0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01`0
oooo0P000000103oool000000000000000050?ooo`D000002P3oool7000000d0oooo00@000000?oo
o`000000oooo100000020?ooo`800000303oool3000000030?ooo`000000oooo00@0oooo2P000004
0?ooo`060000003oool000000000003oool000001P3oool600000080oooo0`000000203oool00000
0000003oool000000?ooo`000000oooo1000000;0?ooo`H00000303oool6000000050?ooo`000000
00000?ooo`0000000P3oool4000000<0oooo100000030?ooo`050000003oool000000000003oool0
0P00000A0?ooo`L0000000<0oooo0000003oool03P3oool01@000000oooo000000000000oooo00D0
000000@0oooo0000003oool00000203oool2000000030?ooo`000000oooo0080oooo0P0000000`3o
ool00000000000050?ooo`<000000P3oool3000000<0oooo2000000N0?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo01`0oooo0`0000000`3oool00000000000060?ooo`@0
00002`3oool00`000000oooo00000004000000d0oooo0P0000000`3oool000000000000300000080
oooo0P00000;0?ooo`030000003oool00000008000001`3oool?000000030?ooo`00000000000080
oooo200000040?ooo`<0000000L0oooo0000003oool000000?ooo`000000oooo00@00000303oool0
0`000000oooo00000004000000/0oooo00<000000?ooo`0000001@0000000`3oool000000?ooo`03
0?ooo`<00000103oool5000000040?ooo`00000000000?ooo`80000000<0oooo0000003oool03`3o
ool900000100oooo0`000000103oool000000000003oool6000000T0oooo0P000000103oool00000
0?ooo`3oool4000000030?ooo`000000oooo00@0oooo0`0000000`3oool0000000000002000000<0
oooo1`00000O0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01d0oooo
0P000000103oool000000000000000050?ooo`D000002P3oool2000000030?ooo`000000000000<0
0000303oool010000000oooo0000003oool6000000040?ooo`0000000000000000X0oooo0`000000
0`3oool000000?ooo`070?oooaT00000103oool3000000<0oooo0P0000000`3oool000000?ooo`04
000000/0oooo00D000000?ooo`00000000000?ooo`03000000`0oooo1`0000000`3oool000000?oo
o`040?ooo`<00000103oool8000000030?ooo`000000000000d0oooo2`00000A0?ooo`050000003o
ool000000000003oool00`000000103oool000000?ooo`00000:0?ooo`80000000@0oooo0000003o
ool0oooo100000000`3oool000000?ooo`040?ooo`<0000000<0oooo0000000000000P0000030?oo
o`P000007`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0M0?ooo`<0
000000<0oooo0000000000001P3oool5000000X0oooo00<000000?ooo`0000000`0000000`3oool0
00000?ooo`0;0?ooo`80000000H0oooo000000000000oooo0000003oool6000000T0oooo00H00000
0?ooo`00000000000?ooo`00000;0?oooa40000000<0oooo000000000000103oool00`000000oooo
000000050?ooo`80000000<0oooo0000000000000P00000;0?ooo`030000003oool0000000<00000
00@0oooo0000003oool00000303oool2000000050?ooo`00000000000?ooo`0000001`3oool30000
00D0oooo2@0000080?ooo`D000000P3oool900000140oooo1`000000103oool000000?ooo`00000;
0?ooo`@0000000<0oooo0000000000000P0000000`3oool000000?ooo`040?ooo`050000003oool0
00000000003oool00`0000040?ooo`L00000803oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`0N0?ooo`80000000@0oooo00000000000000001P3oool5000000T0oooo0P00
00000`3oool0000000000003000000`0oooo00@000000?ooo`000000oooo0P0000001`3oool00000
000000000000oooo0000003oool00P0000090?ooo`050000003oool000000?ooo`0000004@3oool8
00000080oooo0P0000040?ooo`80000000<0oooo0000003oool01@3oool6000000`0oooo0P000000
103oool000000000003oool3000000030?ooo`000000oooo00T0oooo200000080?ooo`<000001@3o
oolL000000030?ooo`00000000000140oooo00D000000?ooo`00000000000?ooo`04000000030?oo
o`000000oooo00X0oooo0P0000000`3oool000000?ooo`04000000030?ooo`000000oooo00D0oooo
0`0000000`3oool0000000000002000000<0oooo1`00000Q0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo01l0oooo0P000000103oool000000000000000050?ooo`H00000
2@3oool2000000040?ooo`00000000000?ooo`800000303oool2000000030?ooo`000000000000<0
oooo1@0000000`3oool00000000000080?ooo`<0000000<0oooo0000003oool04P3oool01@000000
oooo000000000000oooo00<00000103oool2000000030?ooo`000000oooo00L0oooo100000000`3o
ool000000?ooo`090?ooo`050000003oool000000000003oool01`00000:0?ooo`80000000<0oooo
0000000000000`0000080?ooo`@00000103oool5000000040?ooo`000000oooo0?ooo`/00000103o
ool00`000000oooo00000002000000030?ooo`000000oooo0100oooo1`0000020?ooo`030000003o
ool0oooo00X0oooo1`0000000`3oool00000000000060?ooo`P00000103oool700000240oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0803oool00`000000oooo00000003
000000D0oooo1@0000090?ooo`80000000<0oooo0000000000001000000;0?ooo`040000003oool0
00000?ooo`8000000`3oool00`000000oooo00000006000000H0oooo00D000000?ooo`000000oooo
0000000C0?ooo`030000003oool0000000@00000103oool2000000030?ooo`000000oooo00L0oooo
1@0000020?ooo`030000003oool0oooo00H0oooo00H000000?ooo`00000000000?ooo`0000020?oo
o`80000000@0oooo0000000000000000203oool2000000030?ooo`000000000000D00000203oool4
00000080oooo0P0000000`3oool000000000000200000140oooo00D000000?ooo`00000000000?oo
o`0200000140oooo1`0000000`3oool000000000000<0?ooo`80000000<0oooo0000000000000P00
00000`3oool00000000000070?ooo`L00000103oool00`000000oooo0000000400000280oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0803oool2000000040?ooo`000000
0000000000D0oooo1P0000090?ooo`80000000@0oooo000000000000oooo0`00000;0?ooo`800000
00@0oooo0000003oool000000`3oool2000000030?ooo`000000000000L000000`3oool300000003
0?ooo`000000oooo0180oooo100000000`3oool000000?ooo`020?ooo`040000003oool000000000
00T0oooo10000000103oool000000?ooo`0000080?ooo`<0000000<0oooo0000003oool00`3oool4
000000030?ooo`000000oooo00D0oooo0P0000000`3oool00000000000020?ooo`050000003oool0
00000?ooo`000000203oool4000000030?ooo`00000000000080000000<0oooo0000000000000P00
000?0?ooo`80000000D0oooo000000000000oooo0000000A0?ooo`H0000000<0oooo0000003oool0
303oool00`000000oooo00000004000000030?ooo`000000000000L0oooo1`0000050?ooo`H00000
8`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0Q0?ooo`H000001@3o
ool6000000P0oooo00<000000?ooo`0000000`0000000`3oool0000000000002000000X0oooo0P00
00000`3oool00000000000050?ooo`80000000<0oooo000000000000100000000`3oool000000000
0002000000040?ooo`000000oooo000000l0oooo1`0000000`3oool00000000000020?ooo`040000
003oool00000000000T0oooo00@000000?ooo`000000oooo0P000000103oool000000?ooo`000006
0?ooo`030000003oool00000008000001@3oool2000000050?ooo`00000000000?ooo`0000001@3o
ool2000000080?ooo`00000000000?ooo`000000oooo0000003oool2000000T0oooo1@0000001P3o
ool000000000003oool000000?ooo`D000002`3oool00`000000oooo00000002000000030?ooo`00
0000oooo00l0oooo100000000`3oool0000000000002000000h0oooo0P0000001@3oool000000000
00000000oooo008000001`3oool00`000000oooo00000005000000@0oooo1`00000S0?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0280oooo1P0000040?ooo`L00000203o
ool2000000030?ooo`00000000000080oooo100000090?ooo`060000003oool000000000003oool0
00001P3oool200000080oooo1P0000000`3oool0000000000002000000030?ooo`000000oooo00T0
oooo1`0000020?ooo`050000003oool000000000003oool00P0000000`3oool000000?ooo`090?oo
o`030000003oool000000080oooo0P0000001@3oool000000?ooo`3oool0000000@0oooo00<00000
0?ooo`0000000P0000060?ooo`<0000000@0oooo0000000000000000103oool2000000050?ooo`00
000000000?ooo`0000000P3oool00`000000oooo0?ooo`02000000T0oooo1P0000000`3oool00000
0?ooo`020?ooo`H000002@3oool3000000040?ooo`000000oooo000000d0oooo2P00000?0?ooo`03
0000003oool0000000<0000000<0oooo000000000000203oool7000000@0oooo1`00000T0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0280oooo0P0000000`3oool00000
00000002000000@0oooo1`0000080?ooo`D000000P3oool5000000P0oooo0P000000103oool00000
0?ooo`0000070?ooo`<000000P3ooolI000000D0oooo0P0000000`3oool0000000000002000000X0
oooo100000030?ooo`80000000@0oooo0000003oool00000103oool3000000030?ooo`000000oooo
00D0oooo00D000000?ooo`00000000000?ooo`0300000080oooo0P0000001@3oool000000000003o
ool0000000@0oooo00<000000?ooo`3oool00P0000090?ooo`D0000000<0oooo0000003oool0103o
ool7000000D0oooo0P0000001@3oool000000000003oool0000000X0oooo3@00000@0?ooo`D00000
00<0oooo0000003oool0203oool00`000000oooo00000004000000D0oooo1P00000U0?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02<0oooo1`0000040?ooo`L000001`3o
ool00`000000oooo00000002000000<0oooo0`0000000`3oool000000?ooo`070?ooo`<0000000<0
oooo0000003oool02@3ooolH000000T0oooo1@00000:0?ooo`@00000103oool01`000000oooo0000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000L0oooo00<000000?oo
o`3oool00`000000103oool000000000003oool400000080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`02000000L0oooo1`0000080?ooo`P0000000<0oooo0000003oool00P000000
0`3oool00000000000080?ooo`h0000000<0oooo0000003oool03P3oool00`000000oooo00000002
000000030?ooo`000000oooo00T0oooo1`0000040?ooo`@0000000<0oooo0000000000009@3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0S0?ooo`P000000`3oool80000
00L0oooo0P0000000`3oool00000000000030?ooo`<0000000<0oooo0000000000001P3oool01P00
0000oooo000000000000oooo000000d0oooo4@00000<0?ooo`@0000000<0oooo0000003oool01`3o
ool4000000H0oooo00@000000?ooo`000000oooo0P0000001P3oool000000?ooo`000000oooo0000
00P0oooo00D000000?ooo`3oool000000?ooo`03000000030?ooo`0000000000008000000P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool00000008000001@3oool2000000030?ooo`000000
00000080000000<0oooo0000003oool0203ooolS000000030?ooo`000000oooo00h0oooo00@00000
0?ooo`000000oooo0`00000:0?ooo`030000003oool0000000@00000103oool7000002H0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0903oool2000000030?ooo`000000
000000800000103oool9000000H0oooo1@0000030?ooo`@0000000<0oooo0000003oool01@3oool3
000000030?ooo`000000oooo0140oooo0`0000000`3oool000000?ooo`0@0?ooo`D0000000<0oooo
0000000000001P3oool5000000P0oooo00L000000?ooo`00000000000?ooo`000000oooo00<00000
2@3oool01P000000oooo0?ooo`3oool000000?ooo`L0000000<0oooo0000003oool0203oool01000
0000oooo0000000000040?ooo`80000000P0oooo000000000000oooo0000003oool000000?ooo`80
00002P3ooolD00000080oooo0P0000000`3oool0000000000003000000030?ooo`00000000000100
oooo1P00000;0?ooo`H000001@3oool6000002L0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool09@3oool2000000030?ooo`0000000000008000000`3oool8000000030?oo
o`000000oooo00@0oooo00<000000?ooo`0000000P0000050?ooo`<0000000<0oooo000000000000
103oool01P000000oooo000000000000oooo00000180oooo0`0000000`3oool000000?ooo`0=0?oo
o`D0000000H0oooo00000000000000000?ooo`0000040?ooo`030000003oool00000008000002P3o
ool2000000030?ooo`000000oooo00<000002P3oool00`000000oooo0?ooo`020?ooo`80000000<0
oooo0000000000000P0000000`3oool000000?ooo`0:0?ooo`040000003oool00000000000<0oooo
0`0000000`3oool00000000000030?ooo`D000002P3oool00`000000oooo0000000D00000080oooo
00H000000?ooo`00000000000?ooo`00000>0?ooo`L000002`3oool6000000D0oooo100000000`3o
ool000000000000W0?ooo`030000003oool0oooo0080oooo001;0?ooo`8000009`3oool7000000<0
oooo200000000`3oool000000?ooo`040?ooo`D000001@3oool4000000030?ooo`000000oooo00<0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool000000080
0000303oool5000000<0oooo00H000000?ooo`00000000000?ooo`0000020?ooo`030000003oool0
000000800000303oool2000000030?ooo`0000000000008000002P3oool00`000000oooo0?ooo`03
0?ooo`H0000000<0oooo0000003oool02`3oool01@000000oooo000000000000oooo0080000000D0
oooo000000000000oooo000000050?ooo`D00000203oool2000000040?ooo`00000000000?ooo`T0
00002@3oool01P000000oooo000000000000oooo000000d0oooo2000000;0?ooo`H000001P3oool6
000002H0oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`0V0?ooo`P000000P3oool00`00
0000oooo00000006000000030?ooo`000000oooo00@0oooo1@0000060?ooo`H000000`3oool30000
00030?ooo`000000oooo0140oooo00<000000?ooo`0000000P0000090?ooo`H000001@3oool01@00
0000oooo000000000000oooo0080000000<0oooo0000000000003P3oool7000000X0oooo00<00000
0?ooo`3oool00`3oool5000000030?ooo`000000oooo00d0oooo1@0000000`3oool000000?ooo`02
000000L0oooo0P000000103oool000000000000000050?ooo`80000000D0oooo000000000000oooo
0000000A0?ooo`<0000000@0oooo0000003oool000002`3oool3000000030?ooo`000000000000<0
0000303oool5000000H0oooo1P00000Y0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo02L0oooo0P0000000`3oool000000000000300000080oooo100000000`3oool00000
00000002000000030?ooo`000000oooo00<0oooo00<000000?ooo`0000000P0000080?ooo`030000
003oool0000000<0000000<0oooo0000003oool00P0000000`3oool000000?ooo`0A0?ooo`<00000
00<0oooo0000003oool01@3oool6000000P0oooo0P000000103oool000000000003oool2000000l0
oooo0P0000000`3oool00000000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool3000000060?ooo`00000000000000003oool000003P3oool5000000030?ooo`000000
000000T0oooo0`000000103oool000000000000000020?ooo`040000003oool000000?ooo`800000
00<0oooo0000003oool0403oool01P000000oooo000000000000oooo000000X0oooo0`0000000`3o
ool0000000000004000000`0oooo1@0000060?ooo`H00000:P3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`0X0?ooo`P000000P3oool5000000060?ooo`00000000000000
003oool00000103oool5000000P0oooo0P0000000`3oool0000000000003000000050?ooo`000000
00000?ooo`0000004@3oool01P000000oooo000000000000oooo000000<0oooo1P00000:0?ooo`03
0000003oool0000000@000003`3oool2000000030?ooo`00000000000080000000<0oooo0000003o
ool0203oool010000000oooo0?ooo`3oool2000000040?ooo`00000000000?ooo`<0000000<0oooo
0000003oool0303oool7000000`0oooo0`0000001`3oool00000000000000000oooo0000003oool0
0P0000000`3oool000000?ooo`0@0?ooo`060000003oool000000000003oool000002@3oool30000
0080oooo1P00000;0?ooo`H000001P3oool7000002X0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool0:@3oool5000000030?ooo`000000oooo0080oooo00<000000?ooo`00
00000P0000020?ooo`80000000<0oooo0000003oool00`3oool5000000T0oooo0P0000000`3oool0
000000000004000000030?ooo`000000oooo0140oooo00<000000?ooo`0000000P0000000`3oool0
000000000004000000d0oooo00<000000?ooo`0000000`00000>0?ooo`80000000D0oooo00000000
000000000?ooo`02000000030?ooo`000000oooo00L0oooo00D000000?ooo`3oool000000?ooo`03
000000080?ooo`00000000000000003oool000000?ooo`00000;0?ooo`040000003oool000000?oo
o`@000003@3oool4000000030?ooo`00000000000080000000<0oooo0000000000004P3oool20000
00040?ooo`000000oooo000000L0oooo0`0000020?ooo`D0000000<0oooo0000003oool02P3oool0
0`000000oooo00000003000000L0oooo0`0000000`3oool000000000000[0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo02X0oooo1`0000020?ooo`@0000000@0oooo0000
003oool0oooo1@0000030?ooo`80000000<0oooo0000000000002P3oool<000000`0oooo3000000?
0?ooo`H0000000<0oooo0000003oool02`3oool2000000030?ooo`00000000000080oooo0P000000
103oool000000?ooo`0000070?ooo`040000003oool000000?ooo`<000000P3oool2000000060?oo
o`000000oooo0000003oool000002P3oool2000000030?ooo`000000oooo00D000003@3oool80000
00030?ooo`000000oooo0100oooo00H000000?ooo`00000000000?ooo`0000040?ooo`@000000`3o
ool4000000030?ooo`0000000000008000002P3oool00`000000oooo00000003000000L0oooo0`00
00000`3oool000000000000/0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`000000100000020?ooo`@0000000@0oooo0000003oool0oooo0`00
0000103oool000000?ooo`3oool3000000030?ooo`000000oooo00d0oooo1@0000000`3oool00000
0000000<000000030?ooo`000000000000L00000403oool400000080oooo0`00000;0?ooo`800000
00<0oooo000000000000103oool300000080oooo00<000000?ooo`3oool0103oool2000000040?oo
o`000000000000000080oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool00000
203oool01@000000oooo000000000000oooo00<0000000@0oooo00000000000000003@3oool<0000
00d0oooo00@000000?ooo`00000000000P3oool7000000030?ooo`000000000000@000000P3oool4
000000X0oooo1P0000070?ooo`<0000000<0oooo000000000000;@3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`0[0?ooo`@0000000@0oooo00000000000000000P3oool5
000000<0oooo1@0000020?ooo`D000003`3oool8000000D0oooo3P0000000`3oool000000?ooo`0<
0?ooo`D0000000@0oooo0000003oool0oooo0`0000090?ooo`@000001`3oool300000080oooo00<0
00000?ooo`3oool00`3oool020000000oooo000000000000oooo0000003oool00000103oool30000
00040?ooo`0000000000000000H0oooo00L000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000000P00000<0?ooo`80000000<0oooo0000000000003`0000040?oooa<00000
0`3oool4000000T0oooo200000060?ooo`<0000000<0oooo000000000000;P3oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0/0?ooo`@0000000<0oooo0000000000000P00
00001P3oool00000000000000000oooo000000@0oooo100000020?ooo`D000003`3oool300000003
0?ooo`000000000000h000000`3oool01P000000oooo000000000000oooo000000X0oooo1@000004
0?ooo`060000003oool000000000003oool000001`3oool4000000T0oooo0`0000020?ooo`030000
003oool0oooo0080oooo0P0000001@3oool000000000003oool0000000L0oooo0`0000000`3oool0
0000000000040?ooo`070000003oool000000?ooo`000000oooo000000040?ooo`H000002@3oool0
0`000000oooo00000002000000030?ooo`000000000000`0000000<0oooo0000000000002@000000
0`3oool0000000000007000000@0oooo0P0000000`3oool00000000000080?ooo`80000000<0oooo
0000000000000`0000060?ooo`H00000;`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`00
0000oooo0?ooo`0]0?ooo`@0000000<0oooo0000000000000P0000001P3oool00000000000000000
oooo000000@0oooo200000000`3oool000000?ooo`0?0?ooo`<0000000<0oooo0000003oool04@3o
ool01P000000oooo000000000000oooo000000L0oooo100000000`3oool000000?ooo`050?ooo`06
0000003oool000000000003oool00000103oool5000000X0oooo00@000000?ooo`00000000000P3o
ool00`000000oooo0?ooo`02000000050?ooo`00000000000?ooo`0000002@3oool3000000030?oo
o`00000000000080oooo00H000000?ooo`000000oooo0000003oool2000000D0oooo1P0000070?oo
o`030000003oool00000008000000P3oool00`000000oooo0?ooo`05000000030?ooo`0000000000
01H000001`3oool4000000P0oooo0P0000000`3oool0000000000003000000H0oooo1`00000_0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02h0oooo100000020?ooo`P0
00001@3oool8000000030?ooo`000000oooo00l0oooo00D000000?ooo`000000oooo0000000A0?oo
o`030000003oool0oooo00<000001@3oool2000000030?ooo`000000000000800000203oool01P00
0000oooo000000000000oooo00000080oooo1@00000<0?ooo`040000003oool0000000000080oooo
0P0000001P3oool00000000000000000oooo000000/0oooo0`000000103oool00000000000000002
0?ooo`030000003oool00000008000001`3oool7000000D0oooo0`000000103oool000000?ooo`00
00050?oooaP000002P3oool4000000L0oooo0P0000000`3oool0000000000004000000H0oooo1000
00000`3oool000000000000`0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo02l0oooo100000020?ooo`P000001P3oool7000000030?ooo`000000oooo00h0oooo0P000000
103oool000000?ooo`00000A0?ooo`040000003oool000000?ooo`8000000P3oool2000000050?oo
o`00000000000?ooo`0000002`3oool00`000000oooo00000002000000040?ooo`00000000000?oo
o`8000003P3oool2000000050?ooo`000000oooo0000003oool00`0000000`3oool000000?ooo`0<
0?ooo`<0000000H0oooo000000000000oooo0000003oool3000000X0oooo1`0000020?ooo`<00000
00@0oooo0000003oool000003`3oool:000000h0oooo100000060?ooo`8000000P3oool400000003
0?ooo`000000oooo00D0oooo0P0000000`3oool000000?ooo`0200000340oooo00<000000?ooo`3o
ool00P3oool004/0oooo00<000000?ooo`3oool0<03oool400000080oooo200000060?ooo`P00000
403oool2000000030?ooo`00000000000180oooo00D000000?ooo`00000000000?ooo`0200000003
0?ooo`000000000000<000003@3oool00`000000oooo00000003000000030?ooo`00000000000100
oooo0P0000000`3oool000000?ooo`03000000030?ooo`000000oooo00h0oooo1P000000103oool0
000000000000000=0?ooo`<0000000<0oooo0000000000000P0000001@3oool000000000003oool0
00000140oooo0P0000001@3oool000000000003oool0000000l0oooo0P0000000`3oool000000000
00040?ooo`<0000000H0oooo000000000000oooo0000003oool2000000H0oooo100000000`3oool0
00000000000b0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0340oooo
100000020?ooo`P000001`3oool700000100oooo0`0000000`3oool000000?ooo`0A0?ooo`050000
003oool000000000003oool01@00000@0?ooo`L000004P3oool2000000030?ooo`000000000000<0
00004@3oool800000100oooo0`0000000`3oool0000000000002000000030?ooo`000000oooo0100
oooo0P0000001@3oool000000000003oool0000000l0oooo00<000000?ooo`0000000P0000030?oo
o`<0000000L0oooo00000000000000000?ooo`000000oooo008000001@3oool5000000030?ooo`00
0000000003<0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0<P3oool4
00000080oooo1`0000090?ooo`P000003P3oool3000000030?ooo`000000oooo00l0oooo2@00000B
0?ooo`H000004`3oool5000000030?ooo`000000oooo0140oooo1`00000B0?ooo`T00000403oool2
000000050?ooo`00000000000?ooo`0000003`3oool00`000000oooo0000000200000080oooo0`00
0000103oool000000000000000020?ooo`030000003oool0000000800000103oool5000000030?oo
o`000000000003@0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0<`3o
ool400000080oooo1`00000:0?ooo`T00000303oool3000000030?ooo`000000oooo00P0oooo3@00
00000`3oool000000?ooo`0@0?ooo`80000000H0oooo00000000000000000?ooo`00000A0?ooo`03
0000003oool000000080000000@0oooo0000000000000000403oool010000000oooo0000003oool6
00000140oooo2P00000=0?ooo`80000000D0oooo000000000000oooo0000000@0?ooo`<0000000<0
oooo0000000000001`0000030?ooo`@00000103oool5000000030?ooo`000000000003D0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0=03oool4000000<0oooo1P00000:
0?ooo`D0000000<0oooo0000000000002@0000040?ooo`<0000000@0oooo0000003oool0oooo4000
00000`3oool000000?ooo`02000000l0oooo0`000000103oool000000000003oool3000000l0oooo
2P0000000`3oool000000?ooo`0=0?ooo`040000003oool000000?ooo`<0000000<0oooo00000000
00000P00000?0?ooo`030000003oool0000000X000002P3oool00`000000oooo0000000200000003
0?ooo`000000oooo00l0oooo0`0000000`3oool0000000000006000000@0oooo00@000000?ooo`00
000000000`3oool6000000030?ooo`000000000003H0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool0=@3oool3000000@0oooo1P00000:0?ooo`H000000`3ooolO000000<0
oooo00@000000?ooo`000000oooo0P00000=0?ooo`8000000P3oool2000000030?ooo`000000oooo
00<000003@3oool010000000oooo0000003oool2000000040?ooo`00000000000?ooo`80000000<0
oooo0000000000002`3oool010000000oooo0000003oool2000000040?ooo`00000000000?ooo`D0
0000303oool010000000oooo0?ooo`0000020?ooo`L0000000<0oooo0000000000000P0000050?oo
o`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0=0?ooo`/000001@3oool0
10000000oooo0000000000030?ooo`H0000000<0oooo000000000000=`3oool00`000000oooo0?oo
o`020?ooo`00B`3oool2000003L0oooo0`0000040?ooo`D000002P3oool00`000000oooo00000002
000000030?ooo`000000000000<000000P3ooolG000000L0oooo00D000000?ooo`3oool000000?oo
o`02000000X0oooo0P0000020?ooo`<000000`3oool00`000000oooo00000002000000/0oooo00D0
00000?ooo`000000oooo000000020?ooo`030000003oool0oooo00@000000P3oool00`000000oooo
0?ooo`070?ooo`040000003oool000000?ooo`80000000@0oooo0000003oool0oooo1@0000000`3o
ool000000?ooo`090?ooo`80000000D0oooo000000000000oooo000000030?oooa00000000D0oooo
0000003oool0oooo0000000>0?ooo`/000001P3oool010000000oooo0000000000020?ooo`<00000
00D0oooo00000000000000000?ooo`02000003H0oooo0`0000040?ooo`00B`3oool00`000000oooo
0?ooo`0g0?ooo`<00000103oool5000000X0oooo00<000000?ooo`0000000P0000050?ooo`L00000
103oool00`000000oooo00000005000000h0oooo00D000000?ooo`3oool000000?ooo`02000000L0
oooo0`000000103oool000000000000000060?ooo`030000003oool00000008000002@3oool30000
00030?ooo`000000oooo00800000103oool400000080oooo00<000000?ooo`3oool01@3oool30000
00050?ooo`00000000000?ooo`0000001@3oool7000000L0oooo0P0000001@3oool000000000003o
ool0000000L0oooo4P0000070?ooo`l00000203oool01@000000oooo000000000000oooo00P00000
00<0oooo000000000000>@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`0h0?ooo`<000001@3oool4000000X0oooo00<000000?ooo`0000000P00000;0?ooo`H0000000@0
oooo0000003oool000004@3oool01@000000oooo0?ooo`000000oooo00800000103oool300000004
0?ooo`0000000000000000T0oooo00<000000?ooo`0000000P0000060?ooo`<0000000D0oooo0000
00000000oooo000000060?ooo`030000003oool00000008000000P3oool00`000000oooo0?ooo`03
0?ooo`8000000P3oool2000000030?ooo`000000oooo00L0oooo1P0000050?ooo`80000000D0oooo
000000000000oooo0000000<0?oooad0000000@0oooo00000000000000002P3oool00`000000oooo
00000005000000030?ooo`000000oooo0080000000<0oooo000000000000>P3oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0i0?ooo`<000001@3oool5000000T0oooo00D0
00000?ooo`000000oooo0000000@0?ooo`<0000000<0oooo0000003oool0403oool01@000000oooo
0?ooo`000000oooo0080000000<0oooo0000000000001@00000<0?ooo`030000003oool0000000<0
00000`3oool010000000oooo0000003oool2000000030?ooo`000000oooo00H0oooo00<000000?oo
o`3oool0100000000`3oool000000?ooo`020?ooo`8000000P3oool2000000030?ooo`000000oooo
00T0oooo1`0000020?ooo`80000000D0oooo000000000000oooo0000000A0?oooaD000000P3oool4
000000`0oooo1`0000000`3oool000000?ooo`02000000030?ooo`000000000003/0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0>P3oool4000000@0oooo1P0000080?oo
o`050000003oool000000?ooo`0000003`3oool01P000000oooo000000000000oooo00000140oooo
00<000000?ooo`3oool02P00000>0?ooo`030000003oool0000000<0000000D0oooo000000000000
00000?ooo`02000000030?ooo`000000oooo00L0oooo00H000000?ooo`3oool0oooo0000003oool2
000000030?ooo`0000000000008000000P3oool2000000030?ooo`000000oooo00`0oooo20000000
1@3oool000000000003oool000000140oooo0P000000103oool000000000003ooolE000000`0oooo
1P0000000`3oool0000000000003000000030?ooo`000000000003`0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool0?03oool3000000@0oooo1`0000070?ooo`<0000000<0
oooo0000003oool03P3oool01P000000oooo000000000000oooo00000140oooo2P00000A0?ooo`04
0000003oool000000?ooo`<0000000H0oooo00000000000000000?ooo`0000090?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000000P000000103oool000000?ooo`3oool2000000030?oo
o`000000oooo00h0oooo2@0000000`3oool000000?ooo`0@0?ooo`80000000<0oooo000000000000
0P3oool00`000000oooo0?ooo`0=0?ooo`@00000303oool6000000050?ooo`000000oooo0000003o
ool00`00000n0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo03d0oooo
0`0000040?ooo`T000001@3oool3000000030?ooo`000000oooo00h0oooo00<000000?ooo`000000
0P00000?0?ooo`X00000503oool00`000000oooo00000004000000040?ooo`0000000000000000X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo00000002000000060?ooo`00000000000000
003oool000004P3oool800000140oooo0P0000000`3oool00000000000020?ooo`030000003oool0
oooo00d0oooo1000000<0?ooo`D0000000H0oooo000000000000oooo0000003oool3000003l0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0?P3oool4000000<0oooo1000
00000`3oool0000000000004000000<0oooo0`0000000`3oool000000?ooo`0>0?ooo`030000003o
ool0000000800000303oool5000000030?ooo`000000000000<0000000<0oooo0000003oool04`3o
ool8000000`0oooo00<000000?ooo`3oool0103oool00`000000oooo00000004000000030?ooo`00
0000oooo0140oooo2`00000>0?ooo`80000000H0oooo0000003oool000000?ooo`00000?0?ooo`@0
00002P3oool6000000030?ooo`00000000000080oooo1@0000100?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo03l0oooo1@0000020?ooo`@000000P3oool2000000030?oo
o`000000000000<0000000D0oooo000000000000oooo0000000?0?ooo`030000003oool000000080
0000203oool<00000080oooo00@000000?ooo`00000000004@3oool9000000`0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0000000600000180oooo00@000000?ooo`000000oooo30000009
0?ooo`080000003oool000000000003oool000000?ooo`00000?0?ooo`@00000203oool:000000<0
oooo1@0000110?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0400oooo
1@0000030?ooo`@000000P3oool3000000030?ooo`000000000000H000003`3oool00`000000oooo
00000002000000<0oooo300000040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0303oool2000000030?ooo`000000000000L000002`3oool00`000000oooo0?ooo`020?ooo`<0
000000<0oooo0000000000001P00000?0?ooo`030000003oool000000080000000<0oooo0000003o
ool00P0000000`3oool0000000000007000000D0oooo00D000000?ooo`00000000000?ooo`030000
00l0oooo100000050?ooo``00000103oool500000480oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool0@@3oool600000080oooo100000040?oooa<000001P3oool?000000T0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`090?ooo`80000000D0oooo0000
0000000000000?ooo`05000000030?ooo`000000000000X0oooo00@000000?ooo`3oool0oooo0P00
00020?ooo`80000000<0oooo0000000000000`0000000`3oool000000?ooo`0<0?ooo`D0000000<0
oooo0000003oool00`3oool200000080oooo2`000000103oool000000000003oool200000100oooo
100000030?ooo`<000000P3oool8000000D0oooo100000140?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo0480oooo1`0000000`3oool0000000000002000000L0oooo8000
000>0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01P3oool2000000050?oo
o`00000000000000003oool00P0000030?ooo`040000003oool000000?ooo`8000002@3oool00`00
0000oooo0?ooo`02000000060?ooo`00000000000000003oool000000P3oool4000000030?ooo`00
0000000000X0oooo0P0000001@3oool000000000003oool0000000L0oooo200000020?ooo`P00000
3`3oool3000000030?ooo`000000oooo00<0000000<0oooo000000000000200000060?ooo`@00000
A@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`140?ooo`/00000203o
ool00`000000oooo00000003000000H0oooo3`00000B0?ooo`80000000D0oooo0000003oool0oooo
000000050?ooo`80000000<0oooo000000000000100000060?ooo`040000003oool000000?ooo`80
0000203oool4000000030?ooo`00000000000080oooo00<000000?ooo`3oool00`3oool01@000000
oooo000000000000oooo008000001P3oool3000000050?ooo`00000000000?ooo`000000303oool7
000000030?ooo`000000000000P000002P3ooolD000000D0oooo100000170?ooo`030000003oool0
oooo0080oooo000_0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol01@3oool0
0`3ooml0W4P004RLg`0:0?ooo`030000003oool0oooo04H0oooo2P0000080?ooo`040000003oool0
00000?ooo`/000001`3oool3000000030?ooo`000000oooo0180oooo00H000000?ooo`0000000000
0?ooo`0000020?ooo`80000000<0oooo000000000000100000090?ooo`L000001@3oool300000005
0?ooo`00000000000000003oool00P0000070?ooo`D0000000<0oooo0000000000000`3oool01000
0000oooo0000003oool2000000030?ooo`000000oooo0100oooo300000020?oooaH000000`3oool4
000000D0oooo100000180?ooo`030000003oool0oooo0080oooo000^0?ooo`060=nLB000M;l0oooo
0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`060?ooo`030=nLB000B9`0gooo00T0oooo00<0
00000?ooo`3oool0A`3oool:000000P0oooo0`0000000`3oool000000000000@0?ooo`<0000000<0
oooo0000003oool04P3oool01@000000oooo000000000000oooo0080000000<0oooo000000000000
1000000=0?ooo`030000003oool0000000<000000`3oool3000000060?ooo`00000000000000003o
ool000002`3oool5000000070?ooo`00000000000000003oool000000?ooo`02000000030?ooo`00
0000oooo0100oooo00<000000?ooo`0000007P0000050?ooo`@000001P3oool3000004X0oooo00<0
00000?ooo`3oool00P3oool002d0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`0:
0?ooo`030?oOW01804P0W=oo00T0oooo00<000000?ooo`3oool0B@3oool9000000T0oooo1P00000?
0?ooo`050000003oool000000?ooo`0000004`3oool01@000000oooo000000000000oooo00H00000
403oool010000000oooo0000003oool5000000040?ooo`000000000000000080oooo00<000000?oo
o`3oool0303oool00`000000oooo00000005000000050?ooo`00000000000?ooo`0000004@3oool0
1@000000oooo000000000000oooo008000002P3oool<000000T0oooo00@000000?ooo`0000000000
1@3oool4000004/0oooo00<000000?ooo`3oool00P3oool002d0oooo00<0oooO09a80018W=l00P3o
ool0103ooml0W4P00018W03Oool50?ooo`030?noM0000000000000@0000000<004RL0=ooo`3oool0
1P3oool00`000000oooo0?ooo`1:0?ooo`T000002@3oool00`000000oooo00000003000000l0oooo
00@000000?ooo`000000oooo0P00000@0?ooo`<0000000<0oooo0000000000001000000C0?ooo`L0
000000D0oooo00000000000000000?ooo`0200000100oooo2@0000000`3oool000000?ooo`0@0?oo
o`L00000403oool4000000/0oooo00@000000?ooo`0000000000103oool4000004d0oooo00<00000
0?ooo`3oool00P3oool002d0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`050?oo
o`030?oog`2LB4P0W=oo0080oooo00<0_g@0001d_`3oool0203oool00`000000oooo0?ooo`1<0?oo
o`80000000<0oooo0000000000001@0000070?ooo`L000003P3oool01P000000oooo000000000000
oooo000000/0oooo1@0000000`3oool0000000000006000001@0oooo0P0000000`3oool000000000
0004000000030?ooo`000000oooo0140oooo2`00000@0?ooo`H000004@3oool4000000/0oooo1000
00020?ooo`D00000C`3oool00`000000oooo0?ooo`020?ooo`00;P3oool00`2oM00004RL0=ooo`02
0?ooo`030?oOW0180000B9cO00H0oooo00L0oono07@0M02oool0oooo0?noM000B9`0gooo00P0oooo
0`00001=0?ooo`<0000000<0oooo0000000000001`0000050?ooo`H000003P3oool4000000030?oo
o`000000oooo00H0oooo1@0000020?ooo`<0000000@0oooo000000000000oooo0P0000000`3oool0
00000?ooo`0A0?ooo`030000003oool0oooo00P000004P3oool00`000000oooo0?ooo`0;000000`0
oooo100000000`3oool000000000000A0?ooo`030000003oool0000000`0oooo2`00001=0?ooo`@0
0000103oool002h0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`070?ooo`060?oO
W018B9`0gooo0?oOW01804P0W=oo203oool00`000000oooo0?ooo`1?0?ooo`<000000P3oool:0000
0080oooo00<000000?ooo`0000001000000>0?ooo`D000000`3oool5000000030?ooo`0000000000
008000000P3oool200000080oooo100000000`3oool000000000000>0?ooo`80000000<0oooo0000
000000002@00000?0?ooo`8000000P3oool:000000030?ooo`000000000000<000001`3oool70000
0100oooo1000000;0?ooo`P0000000<0oooo000000000000DP3oool00`000000oooo0?ooo`020?oo
o`00;P3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00L0oooo00D0okmd001d_`3o
oml0W4P004RLg`080?ooo`030000003oool0oooo0500oooo100000000`3oool000000000000A0000
00h0oooo00<000000?ooo`0000002`0000000`3oool0000000000002000000H0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`090?ooo`80000000<0oooo0000000000000P0000000`3o
ool000000?ooo`02000000030?ooo`000000000000<00000303oool010000000oooo0?ooo`3oool5
000000@0oooo3@0000000`3oool000000000000500000100oooo0`00000<0?ooo`L0000000@0oooo
0000000000000000D`3oool00`000000oooo0?ooo`020?ooo`00;P3oool0103ooml0W4P00018W03O
ool20?ooo`030=nLB000B9`0gooo00P0oooo00@0gia804RLg`2oM00007Bo203oool00`000000oooo
0?ooo`1B0?ooo`@0000000<0oooo000000000000900000000`3oool0000000000005000000/0oooo
100000000`3oool00000000000070?ooo`80000000<0oooo0000000000000P0000000`3oool00000
0000000200000080oooo0P0000000`3oool0000000000003000000P0oooo0P0000020?ooo`<00000
00<0oooo0000003oool02@3oool?00000100oooo100000090?ooo`T0000000@0oooo000000000000
0000E@3oool00`000000oooo0?ooo`020?ooo`00;`3oool00`3ogi`0B00007Boo`020?ooo`030=nL
B000M;l0oooo00T0oooo00@0gia807AdM00007@0_ooo1`3oool00`000000oooo0?ooo`1D0?ooo`T0
000000<0oooo0000000000000P0000000`3oool000000000000L00000140oooo00<000000?ooo`00
00000P3oool010000000oooo0?ooo`3oool8000000030?ooo`0000000000008000001@3oool30000
00030?ooo`000000000000<00000103oool200000080oooo1P00000>0?ooo`l00000303oool30000
00L0oooo2`000000103oool0000000000000001G0?ooo`030000003oool0oooo0080oooo000`0?oo
o`060=nLB00007@0_ooo0?oog`2LB000B9cO2`3oool00`2oM000001809cOo`070?ooo`030000003o
ool0oooo05H0oooo200000040?oooad00000503oool4000000050?ooo`00000000000000003oool0
100000020?ooo`@000001`3oool00`000000oooo0?ooo`02000000030?ooo`000000000000<00000
00@0oooo0000003oool0oooo1P00000C0?oooa@000000P3ooolC000000<0oooo1000001H0?ooo`03
0000003oool0oooo0080oooo000a0?ooo`040=nLB00000000000001d_``0oooo00<0oooO09a80018
W=l01`3oool00`000000oooo0?ooo`1I0?ooo`L000001`3oool>000000H0oooo00<000000?ooo`00
00000`00000D0?ooo`<000000P3oool400000080oooo100000090?ooo`030000003oool0oooo0080
oooo300000000`3oool000000?ooo`0C0?ooo`<0000000<0oooo0000000000005`0000000`3oool0
000000000008000000<0oooo1000001J0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo05/0oooo1`0000060?ooo`<0000000@0oooo00000000000000003@3oool200000003
0?ooo`000000000000800000403oool>000000`0oooo00<000000?ooo`3oool01@3oool700000003
0?ooo`000000000001<0oooo0P000000103oool000000000000000090?oooa8000000`3oool50000
0080oooo1000001L0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo05d0
oooo1P0000070?ooo`80000000<0oooo0000000000000P00000=0?ooo`80000000<0oooo00000000
00000P00000;0?ooo`<000000P3oool9000000l0oooo00<000000?ooo`3oool0103oool200000003
0?ooo`000000000000H000004@3oool700000100oooo1000000:0?ooo`@0000000<0oooo00000000
00000P00001O0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0600oooo
1P0000060?ooo`80000000@0oooo00000000000000003P3oool7000000H0oooo0`0000000`3oool0
00000000000=000000d0oooo00<000000?ooo`3oool00P3oool2000000030?ooo`000000000000`0
0000303oool2000000040?ooo`000000000000000100oooo1000000:0?ooo`@0000000@0oooo0000
000000000000HP3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1R0?oo
o`X000000P3oool2000000040?ooo`0000000000000000h0oooo4@000000103oool0000000000000
00040?ooo`L000002`3oool00`000000oooo00000002000000030?ooo`000000000000@000000`3o
ool;000000H0oooo1P00000A0?ooo`@000002@3oool8000006@0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool0I03ooolB000000H0oooo4P0000000`3oool0000000000003
000000T0oooo200000070?ooo`<000000P3oool6000000P0oooo0P0000000`3oool0000000000006
000000030?ooo`000000000000@000004@3oool4000000T0oooo1`00001W0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo06L0oooo5@0000060?ooo`h000003`3oool90000
00070?ooo`00000000000000003oool000000?ooo`05000000d0oooo0`0000020?ooo`T000004@3o
ool4000000P0oooo1P00001[0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo06X0oooo800000000`3oool0000000000002000001<0oooo4000000B0?ooo`h00000303ooolB
000006d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0K03oool60000
00@0oooo2P00000:0?ooo`80000000<0oooo0000000000000P00000B0?ooo`d000005@3oool70000
00030?ooo`000000000001l00000K`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`1_0?ooo`H000000`3oool6000000h0oooo0P0000000`3oool0000000000003000000`0
oooo0`0000000`3oool000000000000;00000140oooo200000020?oooa8000001P3oool6000007<0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0LP3oool7000000030?oo
o`000000000000D000003@3oool9000000@0oooo1@0000001@3oool00000000000000000oooo00X0
00000P3oool4000000/0oooo2000000>0?ooo`D000001@3oool7000007H0oooo00<000000?ooo`3o
ool00P3oool004/0oooo0P00001f0?ooo`h000003P3oool:00000080oooo2P0000040?ooo`T00000
00<0oooo0000000000000`0000020?ooo`X000003@3oool6000000@0oooo1`00001g0?ooo`<00000
103oool004/0oooo00<000000?ooo`3oool0N@3ooolA000000D0oooo4`00000;0?ooo`030000003o
ool00000018000003`3oool5000000<0oooo1`00001m0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo07d0oooo8`00000=0?ooo`030000003oool0oooo00@0oooo3`00000:
0?ooo`l00000P@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`280?oo
o`l000001@3oool7000000X0oooo00<000000?ooo`3oool09@0000280?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo08`0oooo2@00000;0?ooo`P00000103oool<000000L0
oooo4@00002=0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0900oooo
3P0000050?oooa4000001@3oool>000009H0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool0U`3ooolA000000D0oooo4`00002M0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0:d0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`2]0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0
[@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`2]0?ooo`030000003o
ool0oooo0:d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004/0oooo
o`00001R000000@0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003>0?ooo`090?oo_`1d0000000004RLg`3oool0oono
07@000000000B9cO01@0oooo00<0okmd0000000000000P0000000`00B9`0gooo0?ooo`0B0?ooo`05
0;md00000000000000000018W=l0YP3oool00<h0oooo00X0oono07@0B02Lgol0_g@0001d_`3ookl0
M01809cOo`2oM00007Bo4P3oool00`3o_g@0000004RLg`030?ooo`030?oOW01804P0W=oo01<0oooo
00<0oooO09a80018W=l0Y`3oool00=40oooo00<0oono07@0001d_ol00P3oool00`3ookl0M00007Bo
o`0A0?ooo`030?noM00007@0_ooo00@0oooo00<0gia8001d_`3oool04`3oool00`3OW4P004RL0=oo
o`2V0?ooo`00dP3oool00`3OW4P004RL0=ooo`020?ooo`030=nLB000B9`0gooo0140oooo00P0_g@0
0000M02oool0oooo0?oog`2LB000000004RLga@0oooo00<0omnL04P0M02oool0YP3oool00;/0oooo
00<0_g@00000000000001@0000000`00B9`0gooo0?ooo`030?ooo`0<0?oOW018000000000018W03O
ool0_g@000000000M;l0oooo0?noM00004P0W=oo0P3oool00`3o_g@0001809cOo`030?ooo`080;md
00000000001809cOo`3oool0gia80018W03Oool20?ooo`030;md0000000007Bo0080oooo00H0oono
07@00000000000000000M02oool50?ooo`030?noM0000000000000L0000000T0M;oo0?ooo`3ogi`0
B0000000000007@0_ono07@0001d_ol00P3oool02`3ogi`0B00000000000B9`0gooo0;md00000000
07Bo0?ooo`3ogi`0B0000080000000T0M;oo0=nLB000000004RL0=ooo`3o_g@000000000B02Lgol0
0P3oool0102oM00000000000B02Lgol20?ooo`050?noM000000000000000B02Lgol00`3oool00`3O
W4P004RL0=ooo`020?ooo`030;md0000000007Bo07H0oooo002l0?ooo`040?oo_`1d000004RL0=oo
o`<0oooo00<0_g@000000000M;l00`3oool0303ogi`0B01809cOo`3ogi`0B7Bo0;md0000M;l0oknL
09cOo`3ookl0M00004RLg`80oooo00<0oono07@00018W=l00`3oool0203OW4P004RL0=oog`2LM9`0
gooo0?noM00007@0_ooo0P3oool0203OW4P004RL0=noM01d_ol0oooo0?noM00007@0_ooo2@3oool0
103ooml0W4P00018W03Oool30?ooo`0;0?oog`2LB00004RL0=ooo`2oM00004RL0=ooo`3ookl0M01d
07Ad0018W=l00P3oool0903ogi`0B01809cOo`3ogi`0B7Bo0;md0000M;l0oknL09cOo`2oM00004RL
0=ooo`3oool0_g@007AdM00007@0_mnL09boo`3o_g@0001809cOg`2LM9`0gooo0?ooo`3OW4P004RL
0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`80oooo00<0okmd0000M02oool0
0P3oool0103OW4P004RL0=noM01d_ome0?ooo`00_@3oool00`3OW4P0001809cOo`040?ooo`0=0?oo
_`1d000004RL0=ooo`3oool0oooO09a80018W=l0oooo0?noM01dM7@004RL0=ooo`020?ooo`030;md
0000B9`0gooo0080oooo00<0_g@00018W03Oool00P3oool00`3o_g@0001809cOo`020?ooo`030?oo
_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol00`3oool00`2oM000M;oo0?ooo`090?ooo`030?no
M00004P0W=oo00D0oooo00@0giad09cOo`2oM00007Bo0P3oool0403ookl0M0000018W03Oool0oooo
0?oog`2LB000B9cO0?ooo`3o_g@0M7Ad0018W03Oool0oooo0;md0000M;l30?ooo`070;md00000000
M;oo0?ooo`3ookl0M00007Boo`030?ooo`030?noM00004P0W=oo0080oooo00<0gia80018W03Oool0
0P3oool01`3ogi`0B00004RLg`3oool0oono07@00018W=l00P3oool00`3ogi`0B01809cOo`1f0?oo
o`00_@3oool00`3ogi`0B00007Boo`050?ooo`030?oOW018000007Bo0080oooo00L0_g@00018W03O
ool0oooo0;md000004P0W=oo0080oooo00<0gia80000M02oool00P3oool00`3OW4P0001d0;ooo`02
0?ooo`030?oo_`1d0000B9cO0080oooo00P0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`80
oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`050?ooo`030?oo_`1d0000B9cO00L0
oooo00<0gia80018W03Oool00P3oool00`3o_g@0001d0;ooo`020?ooo`0;0;md0000B9`0gooo0?oo
o`2oM000001809cOo`3oool0okmd0000M02oool00P3oool00`3ookl0M00004RLg`020?ooo`030;md
0000M;l0oooo0080oooo00<0oono07@00018W=l00P3oool00`3o_g@0001d0;ooo`030?ooo`0;0=nL
B00007@0_ooo0?oog`2LB000001d0;ooo`3oool0oooO09a80018W=l0MP3oool00;d0oooo00<0oono
07@00000M;l01P3oool02`2oM000001809cOo`3oool0okmd0000M02oool0oooo0?oo_`1d0000M;oo
0080oooo00<0omnL04P0001d_ol00P3oool00`3ogi`0B00007Boo`030?ooo`030;md0000B9`0gooo
0080oooo00<0gia80018B018M;l00P3oool02`2oM00007Bo0?ooo`3oool0_g@00018W03Oool0oooo
0?oOW0180000B9cO00H0oooo00<0oooO09a80000M;l00P3oool00`3ookl0W9cO0?ooo`020?ooo`03
0?oOW0180000M;oo0080oooo00<0oono07@0001d_ol00P3oool02`3o_g@0001d0;ooo`3oool0oono
07@0001d_ol0oooo0?oo_`1d0000M;oo00<0oooo00L0_g@00018W03Oool0oooo0=nLB000B9`0gooo
00<0oooo00L0_g@00018W03Oool0oooo0?oo_`1d0000M;oo00<0oooo00L0omnL04P0B02Lgol0oooo
0=nLB000B4P0B7Bo0080oooo00<0_g@0001d_`3oool0M@3oool00;h0oooo00<0_g@00018W03Oool0
1@3oool01`3o_g@0000004RLg`3ogml0gono07@0001d_ol00P3oool01`2oM00007Bo0?ooo`3oool0
oooO09a80018W=l00P3oool00`3ooml0W4P004RLg`030?ooo`030=nLB00004P0W=oo0080oooo00/0
okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;ooo`3oool0_g@0001d_`030?ooo`030=nLB00007@0
_ooo00H0oooo00H0gia80000M02oool0oooo0?oOW018M;l40?ooo`0<0;md000007@0_ooo0?ooo`3o
oml0W4P004RLg`3oool0omoO0=oo_`1d0000M;oo0P3oool01`2oM00007Bo0?ooo`3oool0okmd0000
M02oool00P3oool01`3OW4P0001d0;ooo`3oool0omnL04P0B02Lgol00`3oool00`3OW4P0001809cO
o`020?ooo`030=nLB00007@0_ooo0080oooo00`0oono07@0001d_ol0oooo0?noM00007@0_kmd04RL
g`3oool0okmd0000M02ooome0?ooo`00_P3oool00`3o_g@0001809cOo`050?ooo`070?oOW0180000
07Bo0?oOW018M;l0_g@0001d_`020?ooo`030?noM000B9`0gooo0080oooo00<0_g@00018W03Oool0
0P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO0080oooo00`0oooO09a8001d_ol0
gia8001d_`3ogi`0B01809cOo`3oool0omnL04P00018W=l20?ooo`030=nLB00007@0_ooo00H0oooo
00<0okmd0000000000000P0000000`0007@0_ooo0?ooo`020?ooo`0<0?oog`2LB00004RL0=ooo`3o
okl0W4Q80018W03Oool0omnL04Qd_`2oM00007Bo0P3oool00`3o_g@004RL0=ooo`020?ooo`0;0=nL
B00007@0_ooo0?ooo`2oM000001809cOo`3oool0oooO09a80018W=l00`3oool00`3ogi`0B00004RL
g`030?ooo`0@0;md000007@0_ooo0?ooo`3o_g@0001d0;ooo`3oool0oooO09a8001d_ol0gia8001d
_`3ogi`0B01809cOogD0oooo002n0?ooo`030?oOW0180000M;oo00D0oooo00L0omnL04P00000M;l0
oooo0?noM000000007Bo0080oooo00D0omnL04P0B02Lgol0oono07@000030000000307Bo_`1d0000
00000080000000l0M;oo0?noM000000000000018W03Oool0oono07@000000000B9cO0?ooo`3o_g@0
00000000B02Lgol00P3oool00`3ookl0M000000000040000000304RLg`3oool0oooo00<0oooo00<0
oono07@0001d_ol00P3oool00`2oM4P0W=oo0?ooo`040?ooo`0:0=nLB0000000001d0;noM00007@0
_ooo0?ooo`3o_g@00000001d_`80oooo00<0omnL04P0B02Lgol00`3oool0203ogi`0B00000000018
W9`0M00004RLg`3ookl0M0000`0000001P1d_ol0okmd00000000000004RL0=ooo`<0oooo00l0okmd
000000000000000007Boo`3oool0oono07@000000000B9cO0?ooo`3o_g@000000000B02Lgol0M@3o
ool00;h0oooo00<0oooO09a80000M;l01@3oool00`3o_g@0000004RLg`0;0?ooo`030?noM00004P0
W=oo0080oooo00<0okmd0000B02Lgol07`3oool01P2oM00007Bo0?ooo`3oool0omnL07BLgal0oooo
00<0okmd0000M02oool0S@3oool00;l0oooo00<0_g@00018W03Oool00`3oool0103ooml0W4P00000
M02oool;0?ooo`030?oog`2LB00007Bo0080oooo00<0oooO09a80000M;l07`3oool00`3OW4P0001d
0;ooo`040?ooo`030=nLW02oool0oooo01`0oooo00<0giad09cOo`3oool0S03oool00;l0oooo00<0
gia80000B02Lgol00P3oool0103ookl0M0000000001d_ol=0?ooo`030?noM00007@0_ooo0080oooo
00<0okmd0000M02oool00P3oool0103ookl0M0000018W03OoolH0?ooo`030?noM00004P0W=oo00<0
oooo00<0oono07@0B02Lgol08P3oool0103ookl0M0000018W03Ooon60?ooo`00_P3oool00`2oM000
000000000004000000030018W03Oool0oooo00h0oooo00X0gia80018W03Ooml0W4P004RLg`3OW4P0
04RL0=oog`2LB000B9cO6P3oool00`2oM0000000000000060000000307Boo`3oool0oooo0:X0oooo
003G0?ooo`090=nLB0000000001809cOo`3oool0gia80000000004P0W=oo0=00oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-0.338056, -0.633617, \
0.00201789, 0.00417864}}]
}, Closed]],

Cell["\<\
Nevertheless, we see below that the Poincar\[EAcute] map is just a circle.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[sol];\)\), "\[IndentingNewLine]", 
    \(\(sol[
          t_] = \(duffingSol[1, 0, 0, 1, \[Pi], 0, 0, 1000, 
            MaxSteps \[Rule] 10\^5]\)[t];\)\), "\[IndentingNewLine]", 
    \(\(pts = poincare[sol[t], \[Pi], 0, 1000];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[pts, AspectRatio \[Rule] Automatic, Frame \[Rule] True, 
        FrameLabel \[Rule] {\*"\"\<\!\(x\_k\)\>\"", \*"\"\<\!\(x\_k\%\[Prime]\
\)\>\""}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00001 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.97619 4.2237 0.500004 4.2237 [
[.13145 -0.0125 -13.8438 -15.6875 ]
[.13145 -0.0125 13.8438 0 ]
[.34263 -0.0125 -16.8438 -15.6875 ]
[.34263 -0.0125 16.8438 0 ]
[.55382 -0.0125 -13.8438 -15.6875 ]
[.55382 -0.0125 13.8438 0 ]
[.76501 -0.0125 -16.8438 -15.6875 ]
[.76501 -0.0125 16.8438 0 ]
[.97619 -0.0125 -5 -15.6875 ]
[.97619 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -7.125 -31.375 ]
[.5 -0.0125 7.125 -15.6875 ]
[-0.0125 .07763 -27.6875 -7.84375 ]
[-0.0125 .07763 0 7.84375 ]
[-0.0125 .28882 -33.6875 -7.84375 ]
[-0.0125 .28882 0 7.84375 ]
[-0.0125 .5 -10 -7.84375 ]
[-0.0125 .5 0 7.84375 ]
[-0.0125 .71119 -25 -7.84375 ]
[-0.0125 .71119 0 7.84375 ]
[-0.0125 .92237 -19 -7.84375 ]
[-0.0125 .92237 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -49.375 -7.125 ]
[-0.01875 .5 -33.6875 7.125 ]
[ 0 1.00001 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1.00001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13145 0 m
.13145 .00625 L
s
gsave
.13145 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.34263 0 m
.34263 .00625 L
s
gsave
.34263 -0.0125 -77.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
.55382 0 m
.55382 .00625 L
s
gsave
.55382 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.76501 0 m
.76501 .00625 L
s
gsave
.76501 -0.0125 -77.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
.17369 0 m
.17369 .00375 L
s
.21592 0 m
.21592 .00375 L
s
.25816 0 m
.25816 .00375 L
s
.3004 0 m
.3004 .00375 L
s
.38487 0 m
.38487 .00375 L
s
.42711 0 m
.42711 .00375 L
s
.46935 0 m
.46935 .00375 L
s
.51158 0 m
.51158 .00375 L
s
.59606 0 m
.59606 .00375 L
s
.63829 0 m
.63829 .00375 L
s
.68053 0 m
.68053 .00375 L
s
.72277 0 m
.72277 .00375 L
s
.80724 0 m
.80724 .00375 L
s
.84948 0 m
.84948 .00375 L
s
.89172 0 m
.89172 .00375 L
s
.93395 0 m
.93395 .00375 L
s
.08921 0 m
.08921 .00375 L
s
.04698 0 m
.04698 .00375 L
s
.00474 0 m
.00474 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -68.125 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 17.688 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
73.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07763 m
.00625 .07763 L
s
gsave
-0.0125 .07763 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .28882 m
.00625 .28882 L
s
gsave
-0.0125 .28882 -94.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .71119 m
.00625 .71119 L
s
gsave
-0.0125 .71119 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
0 .92237 m
.00625 .92237 L
s
gsave
-0.0125 .92237 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .11987 m
.00375 .11987 L
s
0 .16211 m
.00375 .16211 L
s
0 .20434 m
.00375 .20434 L
s
0 .24658 m
.00375 .24658 L
s
0 .33106 m
.00375 .33106 L
s
0 .37329 m
.00375 .37329 L
s
0 .41553 m
.00375 .41553 L
s
0 .45777 m
.00375 .45777 L
s
0 .54224 m
.00375 .54224 L
s
0 .58448 m
.00375 .58448 L
s
0 .62672 m
.00375 .62672 L
s
0 .66895 m
.00375 .66895 L
s
0 .75343 m
.00375 .75343 L
s
0 .79566 m
.00375 .79566 L
s
0 .8379 m
.00375 .8379 L
s
0 .88014 m
.00375 .88014 L
s
0 .0354 m
.00375 .0354 L
s
0 .96461 m
.00375 .96461 L
s
.25 Mabswid
0 0 m
0 1.00001 L
s
gsave
-0.01875 .5 -109.656 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.125 11.8438 translate
90 rotate
-68.125 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 18.625 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
68.563 11.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\242) show
73.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.13145 .99376 m
.13145 1.00001 L
s
.34263 .99376 m
.34263 1.00001 L
s
.55382 .99376 m
.55382 1.00001 L
s
.76501 .99376 m
.76501 1.00001 L
s
.97619 .99376 m
.97619 1.00001 L
s
.125 Mabswid
.17369 .99626 m
.17369 1.00001 L
s
.21592 .99626 m
.21592 1.00001 L
s
.25816 .99626 m
.25816 1.00001 L
s
.3004 .99626 m
.3004 1.00001 L
s
.38487 .99626 m
.38487 1.00001 L
s
.42711 .99626 m
.42711 1.00001 L
s
.46935 .99626 m
.46935 1.00001 L
s
.51158 .99626 m
.51158 1.00001 L
s
.59606 .99626 m
.59606 1.00001 L
s
.63829 .99626 m
.63829 1.00001 L
s
.68053 .99626 m
.68053 1.00001 L
s
.72277 .99626 m
.72277 1.00001 L
s
.80724 .99626 m
.80724 1.00001 L
s
.84948 .99626 m
.84948 1.00001 L
s
.89172 .99626 m
.89172 1.00001 L
s
.93395 .99626 m
.93395 1.00001 L
s
.08921 .99626 m
.08921 1.00001 L
s
.04698 .99626 m
.04698 1.00001 L
s
.00474 .99626 m
.00474 1.00001 L
s
.25 Mabswid
0 1.00001 m
1 1.00001 L
s
.99375 .07763 m
1 .07763 L
s
.99375 .28882 m
1 .28882 L
s
.99375 .5 m
1 .5 L
s
.99375 .71119 m
1 .71119 L
s
.99375 .92237 m
1 .92237 L
s
.125 Mabswid
.99625 .11987 m
1 .11987 L
s
.99625 .16211 m
1 .16211 L
s
.99625 .20434 m
1 .20434 L
s
.99625 .24658 m
1 .24658 L
s
.99625 .33106 m
1 .33106 L
s
.99625 .37329 m
1 .37329 L
s
.99625 .41553 m
1 .41553 L
s
.99625 .45777 m
1 .45777 L
s
.99625 .54224 m
1 .54224 L
s
.99625 .58448 m
1 .58448 L
s
.99625 .62672 m
1 .62672 L
s
.99625 .66895 m
1 .66895 L
s
.99625 .75343 m
1 .75343 L
s
.99625 .79566 m
1 .79566 L
s
.99625 .8379 m
1 .8379 L
s
.99625 .88014 m
1 .88014 L
s
.99625 .0354 m
1 .0354 L
s
.99625 .96461 m
1 .96461 L
s
.25 Mabswid
1 0 m
1 1.00001 L
s
0 .5 m
1 .5 L
s
0 0 m
1 0 L
1 1.00001 L
0 1.00001 L
closepath
clip
newpath
.008 w
.97619 .5 Mdot
.30182 .067 Mdot
.18873 .86039 Mdot
.95722 .63306 Mdot
.4307 .02887 Mdot
.10043 .75907 Mdot
.90183 .75552 Mdot
.56511 .02828 Mdot
.04395 .6371 Mdot
.81443 .85762 Mdot
.69432 .06526 Mdot
.02381 .50422 Mdot
.70198 .93124 Mdot
.80805 .13687 Mdot
.0416 .371 Mdot
.57345 .9705 Mdot
.89725 .23741 Mdot
.0959 .24805 Mdot
.43905 .97229 Mdot
.9548 .35887 Mdot
.18239 .14518 Mdot
.30952 .93645 Mdot
.97612 .49157 Mdot
.29419 .07057 Mdot
.19515 .86585 Mdot
.95951 .62495 Mdot
.42237 .03017 Mdot
.10507 .7661 Mdot
.90629 .74837 Mdot
.55674 .0272 Mdot
.04645 .64516 Mdot
.82071 .852 Mdot
.68659 .06189 Mdot
.02396 .51265 Mdot
.70959 .9276 Mdot
.80158 .13148 Mdot
.03939 .37913 Mdot
.58176 .96913 Mdot
.89254 .23042 Mdot
.0915 .25525 Mdot
.44743 .97329 Mdot
.95223 .35084 Mdot
.17616 .15086 Mdot
.31727 .93976 Mdot
.97589 .48315 Mdot
.28662 .07428 Mdot
.20168 .87119 Mdot
.96165 .61679 Mdot
.41407 .03162 Mdot
.10985 .77305 Mdot
.91063 .74113 Mdot
.54836 .02627 Mdot
.04909 .65316 Mdot
.8269 .84627 Mdot
.67881 .05865 Mdot
.02426 .52107 Mdot
.71712 .92382 Mdot
.795 .1262 Mdot
.03732 .38731 Mdot
.59006 .96761 Mdot
.8877 .22352 Mdot
.08724 .26252 Mdot
.45581 .97415 Mdot
.94951 .34286 Mdot
.17003 .15665 Mdot
.32509 .94292 Mdot
.97552 .47472 Mdot
.27911 .07813 Mdot
.2083 .87641 Mdot
.96364 .6086 Mdot
.40579 .03321 Mdot
.11474 .77991 Mdot
.91483 .73383 Mdot
.53997 .02549 Mdot
.05188 .66112 Mdot
.83298 .84043 Mdot
.67096 .05556 Mdot
.02471 .52949 Mdot
.72459 .91991 Mdot
.78834 .12103 Mdot
.0354 .39552 Mdot
.59832 .96594 Mdot
.88275 .2167 Mdot
.0831 .26986 Mdot
.46421 .97486 Mdot
.94666 .33493 Mdot
.16401 .16254 Mdot
.33296 .94595 Mdot
.975 .46631 Mdot
.27168 .0821 Mdot
.21501 .88151 Mdot
.96549 .60037 Mdot
.39754 .03496 Mdot
.11976 .78669 Mdot
.91891 .72644 Mdot
.53156 .02485 Mdot
.0548 .66903 Mdot
.83895 .83448 Mdot
.66307 .0526 Mdot
.0253 .5379 Mdot
.73199 .91587 Mdot
.78159 .11599 Mdot
.03362 .40376 Mdot
.60655 .96413 Mdot
.87767 .20996 Mdot
.07909 .27728 Mdot
.47263 .97542 Mdot
.94367 .32704 Mdot
.15808 .16854 Mdot
.34088 .94884 Mdot
.97433 .4579 Mdot
.26432 .08621 Mdot
.22181 .8865 Mdot
.9672 .59212 Mdot
.38932 .03684 Mdot
.12489 .79338 Mdot
.92285 .71899 Mdot
.52315 .02437 Mdot
.05786 .67688 Mdot
.84482 .82842 Mdot
.65512 .04978 Mdot
.02605 .5463 Mdot
.73932 .91169 Mdot
.77474 .11106 Mdot
.03199 .41203 Mdot
.61475 .96217 Mdot
.87248 .20332 Mdot
.07521 .28477 Mdot
.48105 .97583 Mdot
.94054 .31922 Mdot
.15227 .17465 Mdot
.34885 .95158 Mdot
.97351 .44951 Mdot
.25703 .09045 Mdot
.22869 .89136 Mdot
.96875 .58383 Mdot
.38114 .03887 Mdot
.13015 .79997 Mdot
.92666 .71147 Mdot
.51472 .02403 Mdot
.06106 .68468 Mdot
.85058 .82227 Mdot
.64713 .04711 Mdot
.02694 .55468 Mdot
.74657 .90739 Mdot
.76781 .10626 Mdot
.0305 .42033 Mdot
.62292 .96006 Mdot
.86716 .19677 Mdot
.07147 .29232 Mdot
.48947 .97609 Mdot
.93727 .31145 Mdot
.14656 .18086 Mdot
.35687 .95419 Mdot
.97254 .44114 Mdot
.24981 .09482 Mdot
.23566 .89611 Mdot
.97016 .57552 Mdot
.37299 .04105 Mdot
.13551 .80647 Mdot
.93034 .70388 Mdot
.50629 .02385 Mdot
.0644 .69243 Mdot
.85623 .81601 Mdot
.63909 .04457 Mdot
.02798 .56305 Mdot
.75374 .90296 Mdot
.7608 .10158 Mdot
.02917 .42865 Mdot
.63104 .95781 Mdot
.86174 .19032 Mdot
.06786 .29994 Mdot
.49791 .9762 Mdot
.93386 .30373 Mdot
.14097 .18716 Mdot
.36493 .95665 Mdot
.97142 .43278 Mdot
.24268 .09931 Mdot
.24272 .90072 Mdot
.97143 .56718 Mdot
.36489 .04337 Mdot
.141 .81288 Mdot
.93388 .69623 Mdot
.49786 .02381 Mdot
.06787 .70011 Mdot
.86177 .80965 Mdot
.631 .04218 Mdot
.02917 .5714 Mdot
.76084 .89841 Mdot
.75371 .09702 Mdot
.02798 .437 Mdot
.63913 .95542 Mdot
.8562 .18396 Mdot
.06438 .30762 Mdot
.50634 .97616 Mdot
.93032 .29608 Mdot
.13549 .19357 Mdot
.37304 .95897 Mdot
.97016 .42444 Mdot
.23563 .10393 Mdot
.24985 .90522 Mdot
.97254 .55883 Mdot
.35683 .04583 Mdot
.14659 .81918 Mdot
.93729 .68852 Mdot
.48943 .02392 Mdot
.07149 .70773 Mdot
.86719 .8032 Mdot
.62288 .03993 Mdot
.03051 .57972 Mdot
.76785 .89373 Mdot
.74653 .09259 Mdot
.02694 .44537 Mdot
.64717 .95289 Mdot
.85055 .17771 Mdot
.06104 .31537 Mdot
.51477 .97597 Mdot
.92664 .2885 Mdot
.13012 .20007 Mdot
.38118 .96114 Mdot
.96875 .41613 Mdot
.22866 .10867 Mdot
.25707 .90958 Mdot
.97351 .55045 Mdot
.34881 .04844 Mdot
.1523 .82539 Mdot
.94055 .68075 Mdot
.481 .02418 Mdot
.07523 .71528 Mdot
.8725 .79665 Mdot
.61471 .03783 Mdot
.032 .58802 Mdot
.77478 .88892 Mdot
.73928 .08829 Mdot
.02604 .45375 Mdot
.65516 .95021 Mdot
.84479 .17155 Mdot
.05784 .32317 Mdot
.52319 .97564 Mdot
.92283 .28098 Mdot
.12487 .20667 Mdot
.38937 .96318 Mdot
.96719 .40785 Mdot
.22177 .11353 Mdot
.26436 .91382 Mdot
.97433 .54206 Mdot
.34084 .05119 Mdot
.15811 .8315 Mdot
.94369 .67292 Mdot
.47258 .02459 Mdot
.07911 .72277 Mdot
.8777 .79001 Mdot
.60651 .03587 Mdot
.03363 .59629 Mdot
.78162 .884 Mdot
.73195 .08412 Mdot
.0253 .46215 Mdot
.66311 .94739 Mdot
.83892 .1655 Mdot
.05478 .33102 Mdot
.53161 .97515 Mdot
.91888 .27352 Mdot
.11973 .21335 Mdot
.39758 .96506 Mdot
.96548 .39959 Mdot
.21497 .11852 Mdot
.27172 .91792 Mdot
.975 .53366 Mdot
.33292 .05408 Mdot
.16404 .8375 Mdot
.94668 .66504 Mdot
.46417 .02515 Mdot
.08312 .73018 Mdot
.88277 .78328 Mdot
.59828 .03406 Mdot
.03541 .60453 Mdot
.78838 .87895 Mdot
.72455 .08008 Mdot
.0247 .47056 Mdot
.67101 .94444 Mdot
.83294 .15955 Mdot
.05186 .33893 Mdot
.54001 .97452 Mdot
.91481 .26614 Mdot
.11472 .22013 Mdot
.40583 .9668 Mdot
.96363 .39136 Mdot
.20826 .12363 Mdot
.27915 .9219 Mdot
.97552 .52524 Mdot
.32505 .0571 Mdot
.17006 .84339 Mdot
.94953 .65711 Mdot
.45577 .02586 Mdot
.08726 .73753 Mdot
.88773 .77646 Mdot
.59001 .03239 Mdot
.03733 .61274 Mdot
.79504 .87378 Mdot
.71708 .07617 Mdot
.02426 .47898 Mdot
.67885 .94134 Mdot
.82686 .15371 Mdot
.04908 .34689 Mdot
.54841 .97373 Mdot
.9106 .25884 Mdot
.10982 .227 Mdot
.41411 .9684 Mdot
.96164 .38317 Mdot
.20164 .12885 Mdot
.28666 .92574 Mdot
.97589 .51682 Mdot
.31723 .06027 Mdot
.1762 .84918 Mdot
.95224 .64912 Mdot
.44738 .02672 Mdot
.09153 .7448 Mdot
.89256 .76955 Mdot
.58172 .03087 Mdot
.0394 .62092 Mdot
.80161 .8685 Mdot
.70955 .07239 Mdot
.02396 .4874 Mdot
.68663 .9381 Mdot
.82068 .14798 Mdot
.04644 .3549 Mdot
.55679 .9728 Mdot
.90627 .2516 Mdot
.10505 .23395 Mdot
.42242 .96984 Mdot
.95949 .37502 Mdot
.19512 .13419 Mdot
.29423 .92945 Mdot
.97612 .50839 Mdot
.30948 .06358 Mdot
.18243 .85486 Mdot
.95481 .64109 Mdot
.43901 .02773 Mdot
.09593 .75199 Mdot
.89727 .76256 Mdot
.5734 .0295 Mdot
.04161 .62905 Mdot
.80809 .8631 Mdot
.70194 .06875 Mdot
.02381 .49583 Mdot
.69436 .93473 Mdot
.8144 .14236 Mdot
.04394 .36295 Mdot
.56515 .97172 Mdot
.90181 .24445 Mdot
.1004 .24098 Mdot
.43075 .97114 Mdot
.95721 .3669 Mdot
.18869 .13965 Mdot
.30186 .93303 Mdot
.97619 .49996 Mdot
.30178 .06702 Mdot
.18876 .86042 Mdot
.95724 .63302 Mdot
.43066 .02888 Mdot
.10045 .7591 Mdot
.90186 .75548 Mdot
.56506 .02827 Mdot
.04397 .63715 Mdot
.81447 .85759 Mdot
.69428 .06524 Mdot
.02381 .50426 Mdot
.70203 .93122 Mdot
.80802 .13685 Mdot
.04159 .37104 Mdot
.57349 .9705 Mdot
.89722 .23738 Mdot
.09588 .24809 Mdot
.4391 .97229 Mdot
.95478 .35883 Mdot
.18236 .14521 Mdot
.30956 .93647 Mdot
.97611 .49153 Mdot
.29415 .07059 Mdot
.19519 .86588 Mdot
.95952 .6249 Mdot
.42233 .03018 Mdot
.1051 .76614 Mdot
.90632 .74833 Mdot
.5567 .02719 Mdot
.04647 .6452 Mdot
.82075 .85197 Mdot
.68655 .06187 Mdot
.02396 .51269 Mdot
.70963 .92758 Mdot
.80154 .13145 Mdot
.03938 .37918 Mdot
.58181 .96912 Mdot
.89251 .23039 Mdot
.09148 .25529 Mdot
.44747 .9733 Mdot
.95221 .3508 Mdot
.17613 .15089 Mdot
.31732 .93977 Mdot
.97589 .4831 Mdot
.28658 .07431 Mdot
.20172 .87121 Mdot
.96166 .61675 Mdot
.41402 .03163 Mdot
.10987 .77309 Mdot
.91065 .74109 Mdot
.54832 .02626 Mdot
.04911 .65321 Mdot
.82693 .84624 Mdot
.67876 .05864 Mdot
.02426 .52112 Mdot
.71717 .9238 Mdot
.79497 .12617 Mdot
.03731 .38735 Mdot
.5901 .9676 Mdot
.88767 .22348 Mdot
.08721 .26256 Mdot
.45586 .97415 Mdot
.9495 .34282 Mdot
.17 .15668 Mdot
.32513 .94294 Mdot
.97552 .47468 Mdot
.27907 .07815 Mdot
.20833 .87644 Mdot
.96365 .60855 Mdot
.40574 .03322 Mdot
.11477 .77995 Mdot
.91485 .73379 Mdot
.53992 .02548 Mdot
.05189 .66116 Mdot
.83301 .84039 Mdot
.67092 .05554 Mdot
.02471 .52954 Mdot
.72463 .91989 Mdot
.7883 .121 Mdot
.03539 .39556 Mdot
.59837 .96593 Mdot
.88272 .21666 Mdot
.08307 .2699 Mdot
.46426 .97486 Mdot
.94665 .33488 Mdot
.16397 .16258 Mdot
.333 .94596 Mdot
.97499 .46626 Mdot
.27164 .08213 Mdot
.21504 .88154 Mdot
.9655 .60033 Mdot
.3975 .03497 Mdot
.11979 .78673 Mdot
.91893 .7264 Mdot
.53152 .02485 Mdot
.05482 .66907 Mdot
.83898 .83444 Mdot
.66303 .05258 Mdot
.02531 .53795 Mdot
.73203 .91584 Mdot
.78155 .11596 Mdot
.03361 .4038 Mdot
.6066 .96412 Mdot
.87764 .20993 Mdot
.07907 .27732 Mdot
.47267 .97542 Mdot
.94365 .327 Mdot
.15805 .16858 Mdot
.34092 .94885 Mdot
.97432 .45786 Mdot
.26428 .08624 Mdot
.22184 .88653 Mdot
.9672 .59207 Mdot
.38928 .03685 Mdot
.12492 .79341 Mdot
.92287 .71895 Mdot
.5231 .02437 Mdot
.05788 .67693 Mdot
.84485 .82839 Mdot
.65508 .04977 Mdot
.02605 .54635 Mdot
.73936 .91167 Mdot
.7747 .11104 Mdot
.03198 .41208 Mdot
.6148 .96216 Mdot
.87245 .20329 Mdot
.07519 .28481 Mdot
.48109 .97583 Mdot
.94052 .31917 Mdot
.15224 .17468 Mdot
.34889 .9516 Mdot
.9735 .44947 Mdot
.25699 .09047 Mdot
.22873 .89139 Mdot
.96876 .58379 Mdot
.3811 .03889 Mdot
.13018 .80001 Mdot
.92668 .71143 Mdot
.51467 .02403 Mdot
.06108 .68473 Mdot
.85061 .82223 Mdot
.64708 .04709 Mdot
.02695 .55473 Mdot
.74661 .90737 Mdot
.76777 .10623 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3oool10?ooo`070;mdB02L
gol0oooo0?oOW0180000000007Boo`2Y0?ooo`00o`3oool10?ooo`080?noM018W=l0oooo0=nLB000
M;l0oooo0;nLW03OoonX0?ooo`00o`3oool10?ooo`050?oo_`1dB4P0B7BL09a8001d_ol0Z`3oool0
0?L0oooo00h0gia800000000M;l0oooo0?oog`2LB000000007Boo`3oool0oooO09a8M02o_g@0001d
0;oooj/0oooo003i0?ooo`0<0?noM01d_ol0omnL04P0B02Lgol0_gAd0;ooo`3oool0gia807Boo`3o
okl0M7BoZ`3oool00?X0oooo00@0_gAd09bLB000B9`0gooo0`3oool0103ogi`0B7Bo0?oog`2LB002
0000000307Boo`3oool0oooo0:H0oooo003j0?ooo`030?oo_`1d000007Bo00@0oooo00<0oooO09a8
M02oool0[03oool00?X0oooo00<0oono07@0001d_ol01@3oool00`3OW4P0M;oo0?ooo`2[0?ooo`00
nP3oool0103o_g@000000018W03Oool30?ooo`030=nLB000000007Bo0:`0oooo003j0?ooo`050;md
0000B9`0gmnL04Q8W03Oool0/@3oool00?P0oooo00T0okmd000000000000M;oo0?ooo`3ogi`0B000
0018W03Oool0[`3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool007/0oooo00@0_g@0000000000000M;oo0`3oool00`3o
gi`0B00007Boo`020?ooo`030=nLB0000000000000<0000000<0B9cO0?ooo`3oool0<@3oool0102o
M00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00<0oono07@0000000000P000000
1P18W=l0oooo0?ooo`3oool0omnL04P00080000000<004RL0=ooo`3oool0<P3oool0102oM0000000
0000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00<0oono07@0000000000P0000000`18W=l0
oooo0?ooo`0b0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol0103oool0102o
M00000000000001d_ol30?ooo`060?oOW0180000000000000000B9`0gooo<`3oool0102oM0000000
0000001d_ol90?ooo`00NP3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0
001d_ol00`3oool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02oool0oooo0300oooo00H0gia8001d
_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00@0oooo00<0okmd0000001d_ol0103o
ool01P3o_g@0000007Boo`3oool0omnL04Qd_c80oooo00H0gia8001d_`3oool0omnL04P00018W=l2
0?ooo`030?oOW0180000M;oo00@0oooo00<0okmd0000001d_ol0=03oool01P3OW4P007Bo0?ooo`3o
gi`0B00004RLg`80oooo00<0omnL04P0001d_ol00`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RL
g`80oooo00H0okmd0000001d_ol0oooo0?oOW018M;lb0?ooo`060=nLB000M;l0oooo0?oOW0180000
B9cO203oool007T0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?no
M000M;l0oooo03<0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?oo
g`2LB00007Bo00T0oooo00<0okmd04RLg`3oool0;`3oool00`3ooml0W4P004RLg`020?ooo`030?no
M00004P0W=oo00P0oooo00<0oooO09a80000M;l0<`3oool00`3ooml0W4P004RLg`020?ooo`030?no
M00004P0W=oo00H0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`060?ooo`030?no
M018W=l0oooo02l0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`070?ooo`00N@3o
ool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<0okmd001d_`3oool0
<P3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<0gia80018W03O
ool0203oool00`3ookl0M01d0;ooo`0_0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000
B9`0gooo203oool00`3OW4P004RL0=ooo`0b0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a8
0000B9`0gooo1@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`D0oooo00<0
oono07@0M02oool0;`3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`H0oooo
001/0?ooo`030?oog`2LB000000000L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`03
0=nLB00004P0W=oo00T0oooo00<0okmd04RLg`3oool0903oool00`3ooml0W4P00000000700000006
04RLg`3oool0oooo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`080?ooo`030?oOW01804P0
W=oo00P0oooo00<0oooO09a8001d_ol08P3oool00`3ooml0W4P0000000070000000604RLg`3oool0
oooo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`080?ooo`030?oOW01804P0W=oo02D0oooo
00<0oooO09a8000000001`0000001P18W=l0oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0gia80000
B02Lgol01@3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00D0oooo00<0oooO09a8
001d_ol0;`3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00H0oooo001j0?ooo`03
0;md0000B9`0gooo0080oooo00<0omnL04P00018W=l02P3oool00`3OW4P0B9cO0?ooo`0a0?ooo`03
0;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0203oool00`3ookl0M00007Boo`080?ooo`03
0?oo_`1d0000B9cO0300oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`080?ooo`03
0?oo_`1d0000M;oo03<0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`060?ooo`03
0;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01@3oool00`3ookl0M00004RLg`0`0?ooo`03
0;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01P3oool007X0oooo00<0gia80000B02Lgol0
0P3oool00`3ooml0W4P0001d_`0;0?ooo`030;md001d_ol0oooo0300oooo00<0gia80000B02Lgol0
0P3oool00`3ooml0W4P0001d_`090?ooo`030;md0000M;l0oooo00L0oooo00<0okmd0000001d_ol0
<03oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00T0oooo00<0_g@0001d_`3oool0
<P3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00H0oooo00<0gia80000B02Lgol0
0P3oool00`3ooml0W4P0001d_`050?ooo`030?noM0000000M;oo0300oooo00<0gia80000B02Lgol0
0P3oool00`3ooml0W4P0001d_`060?ooo`00NP3oool00`3ogi`0B00004RLg`030?ooo`030;md0000
B9`0gooo00X0oooo00<0omnL04P0M02oool0<03oool00`3ogi`0B00004RLg`030?ooo`030;md0000
B9`0gooo00P0oooo00<0gia80018W03Oool0103oool01P3ogml0gooo0?noM0000000001d0;oooc00
oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`080?ooo`030=nLB000B9`0gooo0380
oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`050?ooo`030?oOW0180000B9cO00<0
oooo00X0_g@00018W03Oool0oooo0?oOg`3Oool0okmd0000000007@0_ooo<03oool00`3ogi`0B000
04RLg`030?ooo`030;md0000B9`0gooo00D0oooo001j0?ooo`040?oog`2LB00004RL0=ooo`80oooo
00<0gia80018W03Oool02P3oool00`3ooml0W4P007Boo`0`0?ooo`040?oog`2LB00004RL0=ooo`80
oooo00<0gia80018W03Oool0203oool00`3ogi`0B01809cOo`040?ooo`050?oo_`1d000000000000
B02Lgol0<@3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00P0oooo00<0omnL
04P0B02Lgol0<P3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00D0oooo00@0
oooO09a80000B9`0gooo0P3oool02@3OW4P004RL0=ooo`3oool0oono07@000000000001809cOo`0a
0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool01@3oool007/0oooo00<0omnL
04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`0:0?ooo`030?oo_`1d0000B9cO0340oooo00<0omnL
04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`080?ooo`030?oo_`1d0000M;oo00D0oooo00<0gibL
0;ooo`3oool0<`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00P0oooo00<0oono
07@0001d_ol0<`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00H0oooo00<0omnL
04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`020?ooo`030=nLW02oool0oooo03<0oooo00<0omnL
04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`050?ooo`00O03oool01P3OW4P0001d0;ooo`3ooml0
W4P004RLg`L0oooo00L0okmd0018W03Oool0oooo0=nLB00004P0W=oo0380oooo00H0gia80000M02o
ool0oooO09a80018W=l:0?ooo`030;md0000M;l0oooo00@0oooo00<0omnL07BLg`3oool0=03oool0
1P3OW4P0001d0;ooo`3ooml0W4P004RLg`X0oooo00<0_g@0001d_`3oool0<`3oool01P3OW4P0001d
0;ooo`3ooml0W4P004RLg`P0oooo00H0gia80000M02oool0oooO09a80018W=l30?ooo`030?oOW01d
W=l0oooo03@0oooo00H0gia80000M02oool0oooO09a80018W=l60?ooo`00O@3oool0103OW4P00000
00000000M;l90?ooo`050?oOW018000000000000001d_ol0=03oool0103OW4P0000000000000M;l9
0?ooo`050?oo_`1d000000000000M02oool01@3oool01@2oM0000000000000000000B9cO0380oooo
00@0gia800000000000007Bo2@3oool01@3ookl0M0000000000007@0_ooo03@0oooo00@0gia80000
0000000007Bo2P3oool0103OW4P0000000000000M;l50?ooo`050;md00000000000000000018W=l0
<P3oool0103OW4P0000000000000M;l70?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00D03ooooo0000060000000@3oool00500oooo00<000000?ooo`000000
3P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`00D03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool01@3o
ool100000040oooo001@0?ooo`030000003oool0oooo0?l0ooooG03oool100000040oooo001@0?oo
o`030000003oool0oooo0?l0ooooG03oool100000040oooo001@0?ooo`030000003oool0oooo0?l0
ooooG03oool100000040oooo001@0?ooo`030000003oool0oooo0?l0ooooG03oool100000040oooo
001@0?ooo`030000003oool0oooo0?l0ooooG03oool100000040oooo001@0?ooo`030000003oool0
oooo09l0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`050000
003oool0oooo0000003oool00P0000001@3oool000000?ooo`3oool000000080oooo00<000000?oo
o`3oool0W`3oool100000040oooo001@0?ooo`030000003oool0oooo09H0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool01P000000oooo000000000000oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo09H0oooo0@00
00010?ooo`00D03oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0M0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`2@0?ooo`4000000@3oool00500
oooo00<000000?ooo`3oool0RP3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000340oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00002<0?ooo`400000
0@3oool00500oooo0P0000260?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000
?@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo08H0oooo0P0000010?ooo`00
D03oool00`000000oooo0?ooo`220?ooo`060000003oool0oooo0000003oool00000B@3oool01P00
0000oooo0?ooo`000000oooo000008@0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`1o
0?ooo`040000003oool0oooo00000540oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`1o0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0O03oool010000000oooo0?ooo`00
001I0?ooo`040000003oool0oooo000007h0oooo0@0000010?ooo`00D03oool00`000000oooo0?oo
o`1f0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0G@3oool010000000oooo
0?ooo`00001k0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0M03oool00`000000oooo
000000020?ooo`030000003oool0oooo06<0oooo00@000000?ooo`3oool00000N03oool100000040
oooo001@0?ooo`030000003oool0oooo0740oooo00@000000?ooo`3oool00000K@3oool00`000000
oooo0000001f0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0KP3oool010000000oooo
0?ooo`00001b0?ooo`040000003oool0oooo000007<0oooo0@0000010?ooo`00D03oool00`000000
oooo0?ooo`1^0?ooo`030000003oool0oooo07H0oooo00@000000?ooo`3oool00000L03oool10000
0040oooo001@0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0O03oool010000000
oooo0?ooo`00001]0?ooo`4000000@3oool003@0oooo00@0_g@0000000000000M;oo0`3oool00`3o
gi`0B00007Boo`020?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0203oool00`00
0000oooo0?ooo`1Y0?ooo`030000003oool000000840oooo00<000000?ooo`000000J`3oool10000
0040oooo000c0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`04
0?ooo`030?noM0000000M;oo00/0oooo00<000000?ooo`3oool0IP3oool010000000oooo0?ooo`00
00250?ooo`030000003oool0oooo06T0oooo0@0000010?ooo`00<P3oool00`3ooml0W4P004RLg`02
0?ooo`030?noM00004P0W=oo00P0oooo00<0oooO09a80000M;l02`3oool00`000000oooo0?ooo`1S
0?ooo`040000003oool0oooo000008/0oooo00<000000?ooo`3oool0IP3oool100000040oooo000b
0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo203oool00`3OW4P004RL0=oo
o`0:0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0S03oool010000000oooo0?oo
o`00001U0?ooo`4000000@3oool002D0oooo00<0oooO09a8000000001`0000001P18W=l0oooo0?oo
o`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol0203oool00`3ogi`0B01809cOo`0:0?ooo`03
0000003oool0oooo0640oooo00<000000?ooo`3oool0T@3oool00`000000oooo0000001S0?ooo`40
00000@3oool003<0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`080?ooo`030?oo
_`1d0000M;oo00X0oooo0`00001N0?ooo`040000003oool0oooo000009D0oooo00<000000?ooo`3o
ool0G`3oool300000040oooo000c0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0
2@3oool00`2oM00007Bo0?ooo`090?ooo`030000003oool0oooo05/0oooo00@000000?ooo`3oool0
0000V`3oool00`000000oooo0?ooo`1N0?ooo`4000000@3oool003<0oooo00<0omnL04P00018W=l0
0`3oool00`2oM00004RL0=ooo`080?ooo`030=nLB000B9`0gooo00T0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2L0?ooo`040000003oool0oooo000005d0oooo0@0000010?ooo`00
<`3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00P0oooo00<0omnL04P0B02L
gol02@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`00
0000F`3oool100000040oooo000d0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0
203oool00`3ookl0M00007Boo`090?ooo`030000003oool0oooo05H0oooo00@000000?ooo`3oool0
0000Y@3oool00`000000oooo0?ooo`1I0?ooo`4000000@3oool003D0oooo00H0gia80000M02oool0
oooO09a80018W=l:0?ooo`030;md0000M;l0oooo00P0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`2Y0?ooo`030000003oool0oooo05H0oooo0@0000010?ooo`00=P3oool0103OW4P0
000000000000M;l90?ooo`050?oo_`1d000000000000M02oool0203oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`000000EP3oool100000040oooo001@0?oo
o`030000003oool0oooo0540oooo00@000000?ooo`3oool00000[`3oool00`000000oooo0?ooo`1D
0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`2c0?oo
o`030000003oool0oooo0540oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo0;D0oooo00<000000?ooo`3oool0D@3oool100000040oooo001@0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`1?0?ooo`400000
0@3oool00500oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`2j0?ooo`040000003o
ool0oooo000004h0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool000000;l0oooo00<000000?ooo`3oool0C03oool100000040oooo001@0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`1:0?ooo`4000000@3oool0
0500oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo
04X0oooo0@0000010?ooo`00D03oool2000004T0oooo00<000000?ooo`3oool0a@3oool00`000000
oooo0?ooo`170?ooo`8000000@3oool00500oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`380?ooo`030000003oool0oooo04P0oooo0@0000010?ooo`00D03oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool0A@3oool100000040oooo001@
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`15
0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0@@3oool00`000000oooo0000003A0?oo
o`030000003oool0oooo04<0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo0=40oooo00<000000?ooo`000000@`3oool100000040oooo001@0?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`110?ooo`400000
0@3oool00500oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`3H0?ooo`030000003o
ool0oooo03l0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo0=X0oooo00<000000?ooo`3oool0?`3oool100000040oooo001@0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`0l0?ooo`4000000@3oool00500
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`3O0?ooo`030000003oool0oooo03`0
oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0>40oooo
00<000000?ooo`3oool0>P3oool100000040oooo001@0?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool0h`3oool00`000000oooo0?ooo`0j0?ooo`4000000@3oool00500oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`3U0?ooo`030000003oool0oooo03P0oooo0@000001
0?ooo`00D03oool2000003L0oooo00<000000?ooo`3oool0i`3oool00`000000oooo0?ooo`0g0?oo
o`8000000@3oool00500oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`3Y0?ooo`03
0000003oool0oooo03H0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`3o0?ooob<0oooo
00<000000?ooo`3oool0=P3oool100000040oooo001@0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0o`3ooolU0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`3]0?ooo`030000003oool0oooo03@0oooo0@0000010?ooo`00D03oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo0>l0oooo00<000000?ooo`3oool0=03oool10000
0040oooo001@0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0l@3oool00`000000
oooo0?ooo`0b0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`3c0?ooo`030000003oool0oooo0380oooo0@0000010?ooo`00D03oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo0?D0oooo00<000000?ooo`3oool0<03oool100000040oooo001@
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0m`3oool00`000000oooo0?ooo`0`
0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3i0?oo
o`030000003oool0oooo02h0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo0?/0oooo00<000000?ooo`3oool0;P3oool100000040oooo001@0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0o@3oool00`000000oooo0?ooo`0/0?ooo`400000
0@3oool00500oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000003oool0oooo02`0oooo0@00
00010?ooo`00D03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0oooo;`3oool1
00000040oooo001@0?ooo`800000:`3oool00`000000oooo0?ooo`3o0?ooo`80oooo00<000000?oo
o`3oool0:@3oool200000040oooo001@0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0o`3oool40?ooo`030000003oool0oooo02X0oooo0@0000010?ooo`00D03oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo0?l0oooo1P3oool00`000000oooo0?ooo`0X0?ooo`400000
0@3oool00500oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3o0?ooo`P0oooo00<0
00000?ooo`3oool0:03oool100000040oooo001@0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0o`3oool90?ooo`030000003oool0oooo02L0oooo0@0000010?ooo`00D03oool00`00
0000oooo0?ooo`3o0?oooc80oooo00<000000?ooo`3oool09`3oool100000040oooo001@0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0o`3ooole0?ooo`4000000@3oool00500oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`3o0?ooo`d0oooo00<000000?ooo`3oool0
9@3oool100000040oooo001@0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0o`3o
ool>0?ooo`030000003oool0oooo02D0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0S0?ooo`4000000@3oool0
0500oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?oooa80oooo00<000000?oo
o`3oool08`3oool100000040oooo001@0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0o`3ooolh0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0o`3ooolg0?ooo`030000
003oool0oooo0280oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo0?l0oooo5@3oool00`000000oooo0?ooo`0R0?ooo`4000000@3oool00500oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?oooaL0oooo00<000000?ooo`3oool0803oool1
00000040oooo001@0?ooo`8000007`3oool00`000000oooo0?ooo`3o0?oooaP0oooo00<000000?oo
o`3oool07`3oool200000040oooo001@0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0o`3ooolk0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0o`3ooolk0?ooo`030000
003oool0oooo01h0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0?l0oooo703oool00`000000oooo0?ooo`0N0?ooo`4000000@3oool00500oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`3o0?oooad0oooo00<000000?ooo`3oool07@3oool1
00000040oooo001@0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0o`3ooolN0?oo
o`030000003oool0oooo01d0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo0?l0oooo?P3oool100000040oooo001@0?ooo`030000003oool0oooo0?l0oooo
?P3oool00`000000oooo0?ooo`0K0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`3o0?ooob80oooo00<000000?ooo`3oool06`3oool100000040oooo001@
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`030000003oool0
oooo01X0oooo0@0000010?ooo`00:`3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000
M;oo00@0oooo00@0_g@0000000000000M;oo0`3oool01P3ogi`0B00000000000000004RL0=ooo`X0
oooo00<000000?ooo`3oool0o`3ooolo0?ooo`030000003oool0oooo01X0oooo0@0000010?ooo`00
:P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00`3oool01P3O
W4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00H0okmd0000001d_ol0oooo0?oOW018M;l:0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooom10?ooo`4000000@3oool002T0oooo
00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`060?ooo`030?oog`2LB000B9cO0080oooo
00<0okmd0000B02Lgol01P3oool00`3o_g@0B9cO0?ooo`080?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0o`3ooolU0?ooo`030000003oool0oooo01T0oooo0@0000010?ooo`00:@3o
ool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`D0oooo00<0oooO09a80018W=l0
0P3oool0103ooml0W4P00018W03Oool50?ooo`030?oo_`1d07@0_ooo00P0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`3o0?ooobH0oooo00<000000?ooo`3oool06@3oool100000040
oooo000L0?ooo`030?oog`2LB000000000L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?oo
o`030=nLB00004P0W=oo00D0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`050?oo
o`030?oog`2LB000M;oo00P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?oo
od80oooo0@0000010?ooo`00:P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00H0
oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`050?ooo`030?oo_`1d0000B9cO00P0
oooo0`00003o0?oood80oooo00<000000?ooo`3oool05@3oool300000040oooo000Z0?ooo`030=nL
B00004P0W=oo0080oooo00<0oooO09a80000M;l01P3oool00`3OW4P0001809cOo`020?ooo`030?oo
g`2LB00007Bo00D0oooo00<0okmd0000001d_ol0203oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo0?l0oooo:P3oool00`000000oooo0?ooo`0G0?ooo`4000000@3oool002X0oooo00<0
omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`050?ooo`030?oOW0180000B9cO00<0oooo00X0
_g@00018W03Oool0oooo0?oOg`3Oool0okmd0000000007@0_ooo203oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0?l0oooo:`3oool00`000000oooo0?ooo`0F0?ooo`4000000@3oool0
02X0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`050?ooo`040?oog`2LB000
04RL0=ooo`80oooo00T0gia80018W03Oool0oooo0?oo_`1d000000000000B02Lgol02@3oool00`00
0000oooo0?ooo`3o0?oood<0oooo00<000000?ooo`3oool05P3oool100000040oooo000[0?ooo`03
0?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01P3oool00`3ogi`0B00007Boo`020?ooo`03
0=nLB000M;l0oooo0080oooo00<0gibL0;ooo`3oool02P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo0?l0ooooA@3oool100000040oooo000/0?ooo`060=nLB00007@0_ooo0?oog`2L
B000B9cO203oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`<0oooo00<0omnL07BLg`3oool02P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo0?oo
o`0E0?ooo`4000000@3oool002d0oooo00@0gia800000000000007Bo2P3oool0103OW4P000000000
0000M;l50?ooo`050;md00000000000000000018W=l01`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0E0?ooo`4000000@3oool00500oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooodH0oooo0@0000010?ooo`00D03o
ool00`000000oooo0?ooo`3o0?ooodD0oooo00<000000?ooo`3oool0503oool100000040oooo001@
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0o`3oool`0?ooo`030000003oool0
oooo01@0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0?l0oooo<P3oool00`000000oooo0?ooo`0B0?ooo`4000000@3oool00500oooo00<000000?ooo`3o
ool0o`3ooom70?ooo`030000003oool0oooo0180oooo0@0000010?ooo`00D03oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooB03oool100000040oooo001@0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0o`3ooold0?ooo`030000003oool0oooo0140oooo0@00
00010?ooo`00D03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo=P3oool0
0`000000oooo0?ooo`0A0?ooo`4000000@3oool00500oooo0P00000@0?ooo`030000003oool0oooo
0?l0ooooB@3oool200000040oooo001@0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000
oooo0?ooo`0@0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool0403oool100000040oooo001@0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`4000000@3oool00500oooo00<00000
0?ooo`3oool0o`3ooom:0?ooo`030000003oool0oooo00l0oooo0@0000010?ooo`00D03oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo>P3oool00`000000oooo0?ooo`0?0?oo
o`4000000@3oool00500oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oooc/0
oooo00<000000?ooo`3oool03P3oool100000040oooo001@0?ooo`030000003oool0oooo0?l0oooo
B`3oool00`000000oooo0?ooo`0>0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`3o0?oood`0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0?l0oooo?03oool00`000000oooo0?ooo`0=0?ooo`4000000@3oool0
0500oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo00d0oooo0@0000010?oo
o`00D03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooC@3oool100000040
oooo001@0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`030000
003oool0oooo00d0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0?l0oooo?P3oool00`000000oooo0?ooo`0=0?ooo`4000000@3oool00500oooo0P00000<
0?ooo`030000003oool0oooo0?l0ooooC@3oool200000040oooo001@0?ooo`030000003oool0oooo
0?l0ooooC@3oool00`000000oooo0?ooo`0<0?ooo`4000000@3oool00500oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`3o0?oood00oooo00<000000?ooo`3oool0303oool100000040
oooo001@0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooom?0?ooo`400000
0@3oool00500oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00/0oooo0@00
00010?ooo`00D03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo@P3oool0
0`000000oooo0?ooo`0;0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`3o0?oooe00oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`3o0?ooodl0
oooo00<000000?ooo`3oool02P3oool100000040oooo001@0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0o`3ooom30?ooo`030000003oool0oooo00X0oooo0@0000010?ooo`00D03o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo@`3oool00`000000oooo0?oo
o`0:0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0o`3ooom?0?ooo`030000003oool0
oooo00X0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0?l0ooooD@3oool100000040oooo001@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0o`3ooom50?ooo`030000003oool0oooo00T0oooo0@0000010?ooo`00D03oool00`000000oooo
0?ooo`3o0?oooe00oooo00<000000?ooo`3oool02@3oool100000040oooo001@0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0o`3ooomB0?ooo`4000000@3oool00500oooo0P000008
0?ooo`030000003oool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`080?ooo`8000000@3oool0
0500oooo00<000000?ooo`3oool0o`3ooom@0?ooo`030000003oool0oooo00T0oooo0@0000010?oo
o`00D03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooDP3oool100000040
oooo001@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooom70?ooo`030000
003oool0oooo00P0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe40oooo00<0
00000?ooo`3oool0203oool100000040oooo001@0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0o`3ooomC0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`3o0?ooodP0oooo00<000000?ooo`3oool0203oool100000040oooo001@0?ooo`03
0000003oool0oooo0?l0ooooD@3oool00`000000oooo0?ooo`080?ooo`4000000@3oool00500oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?oooe<0oooo0@0000010?ooo`00D03o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?oo
o`070?ooo`4000000@3oool00500oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o
0?ooodT0oooo00<000000?ooo`3oool01`3oool100000040oooo001@0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`4000000@3oool00500oooo00<000000?ooo`3o
ool0o`3ooomB0?ooo`030000003oool0oooo00L0oooo0@0000010?ooo`00D03oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0?l0ooooBP3oool00`000000oooo0?ooo`070?ooo`400000
0@3oool00500oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oooe@0oooo0@00
00010?ooo`00D03oool200000?l0ooooD`3oool00`000000oooo0?ooo`060?ooo`8000000@3oool0
0500oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooodX0oooo00<000000?oo
o`3oool01`3oool100000040oooo001@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0o`3ooomD0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0o`3ooomC0?ooo`030000
003oool0oooo00H0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0?l0ooooB`3oool00`000000oooo0?ooo`060?ooo`4000000@3oool00500oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oooe@0oooo0@0000010?ooo`00D03oool00`00
0000oooo0?ooo`3o0?oooe<0oooo00<000000?ooo`3oool01P3oool100000040oooo001@0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`030000003oool0oooo00H0
oooo0@0000010?ooo`003`3oool00`3OW4P0001d0;ooo`0n0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0o`3ooomD0?ooo`4000000@3oool000P0oooo00<0oono07Ad_`3oool0103o
ool00`3ookl0M4RL0=ooo`0n0?ooo`030000003oool0oooo0?l0ooooD`3oool00`000000oooo0?oo
o`060?ooo`4000000@3oool000P0oooo00<0omnL04P0M02oool00`3oool00`3o_g@0001d0;ooo`0a
0?ooo`040;md00000000000007Boo`X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3o0?oood/0oooo00<000000?ooo`3oool01P3oool100000040oooo00080?ooo`070?oOW0180000
00000000B02Lgol0omnL04Qd_`0b0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO2@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooE03oool100000040oooo000:0?ooo`03
0?oo_`1d000000000080000000<0M;oo0?ooo`3oool0;P3oool00`3ooml0W4P004RLg`020?ooo`03
0?noM00004P0W=oo00P0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`030000003oool0oooo00H0
oooo0@0000010?ooo`002@3oool02@3ookl0M01d0;ooo`3oool0oooO09a800000000001d0;ooo`0^
0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo1`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0?l0ooooB`3oool00`000000oooo0?ooo`060?ooo`4000000@3o
ool000P0oooo00<0oono07@0M02oool0103oool00`3ogi`0B7Bo0?ooo`0^0?ooo`030?oog`2LB000
07Bo00<0oooo00<0gia80000B02Lgol01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0?l0ooooE03oool100000040oooo00080?ooo`030?noM0000000M;oo00<0oooo00<0oono07A8
W03Oool0<03oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00L0ooooo`00001P0000
0040oooo000B0?ooo`040?noM0000000001d0;ooob/0oooo00<0gia80000B02Lgol00P3oool00`3o
oml0W4P0001d_`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooom;0?oo
o`030000003oool0oooo00H0oooo0@0000010?ooo`001`3oool0203OW4P0000007Boo`3oool0oooO
09bL_`3ooml0W4P00`0000000`00M;l0oooo0?ooo`0/0?ooo`030?oOW0180000B9cO00<0oooo00<0
_g@00018W03Oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooE03o
ool100000040oooo00040?ooo`040=nLB00000000000001d_`<0oooo00@0oono07@0000004P0W=oo
0P3oool00`2oW9`0gooo0?ooo`0]0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03O
ool01P3oool00`000000oooo0?ooo`3o0?oooe<0oooo00<000000?ooo`3oool01P3oool100000040
oooo00030?ooo`040?oo_`1d000004RL0=ooo`P0oooo00D0gmoO0;md000000000000001d_`0^0?oo
o`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0?l0ooooB`3oool00`000000oooo0?ooo`060?ooo`4000000@3oool000h0
oooo00<0oooO09a8001d_ol00P3oool00`3OW4P0001d0;ooo`0]0?ooo`060=nLB00007@0_ooo0?oo
g`2LB000B9cO1`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooB`3oool0
0`000000oooo0?ooo`060?ooo`4000000@3oool000h0oooo00<0oooO09adW03Oool00P3oool00`3O
W7@0W=oo0?ooo`0^0?ooo`040=nLB00000000000001d_`P0oooo00<000000?ooo`3oool0o`3ooomC
0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0?l0ooooE03oool100000040oooo001@0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0o`3ooom;0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`00
D03oool00`000000oooo0?ooo`3o0?oooe<0oooo00<000000?ooo`3oool01P3oool100000040oooo
001@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooomD0?ooo`4000000@3o
ool00500oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oood/0oooo00<00000
0?ooo`3oool01P3oool100000040oooo001@0?ooo`030000003oool0oooo0?l0ooooD`3oool00`00
0000oooo0?ooo`060?ooo`4000000@3oool00500oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`3o0?oooe@0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0?l0ooooBP3oool00`000000oooo0?ooo`070?ooo`4000000@3oool00500oooo0P00
003o0?oooe<0oooo00<000000?ooo`3oool01P3oool200000040oooo001@0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0o`3ooomD0?ooo`4000000@3oool00500oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`3o0?ooodX0oooo00<000000?ooo`3oool01`3oool10000
0040oooo001@0?ooo`030000003oool0oooo0?l0ooooDP3oool00`000000oooo0?ooo`070?ooo`40
00000@3oool00500oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?oooe<0oooo
0@0000010?ooo`00D03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooB@3o
ool00`000000oooo0?ooo`070?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0o`3ooomB
0?ooo`030000003oool0oooo00L0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0?l0ooooD`3oool100000040oooo001@0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0o`3ooom80?ooo`030000003oool0oooo00P0oooo0@0000010?ooo`00
D03oool00`000000oooo0?ooo`3o0?oooe40oooo00<000000?ooo`3oool0203oool100000040oooo
001@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`4000000@3o
ool00500oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooodP0oooo00<00000
0?ooo`3oool0203oool100000040oooo001@0?ooo`030000003oool0oooo0?l0ooooD@3oool00`00
0000oooo0?ooo`080?ooo`4000000@3oool00500oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`3o0?oooe80oooo0@0000010?ooo`00D03oool2000000P0oooo00<000000?ooo`3oool0
o`3ooom60?ooo`030000003oool0oooo00P0oooo0P0000010?ooo`00D03oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`090?ooo`4000000@3o
ool00500oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oooe80oooo0@000001
0?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe00oooo00<000000?ooo`3oool02@3oool10000
0040oooo001@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooom50?ooo`03
0000003oool0oooo00T0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0?l0ooooD@3oool100000040oooo001@0?ooo`030000003oool0oooo0?l0ooooC`3o
ool00`000000oooo0?ooo`0:0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`3o0?oood<0oooo00<000000?ooo`3oool02P3oool100000040oooo001@0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooom@0?ooo`4000000@3oool00500
oooo00<000000?ooo`3oool0o`3ooom?0?ooo`030000003oool0oooo00X0oooo0@0000010?ooo`00
D03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo@`3oool00`000000oooo
0?ooo`0:0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`3o0?oood80oooo00<000000?ooo`3oool02`3oool100000040oooo001@0?ooo`030000003oool0
oooo0?l0ooooCP3oool00`000000oooo0?ooo`0;0?ooo`4000000@3oool00500oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`3o0?ooodl0oooo0@0000010?ooo`00D03oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo@03oool00`000000oooo0?ooo`0<0?ooo`40
00000@3oool00500oooo0P00003o0?ooodh0oooo00<000000?ooo`3oool02`3oool200000040oooo
001@0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`4000000@3o
ool00500oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oooch0oooo00<00000
0?ooo`3oool03@3oool100000040oooo001@0?ooo`030000003oool0oooo0?l0ooooC03oool00`00
0000oooo0?ooo`0=0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`3o0?ooodd0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0?l0oooo?@3oool00`000000oooo0?ooo`0=0?ooo`4000000@3oool00500oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oooc`0oooo00<000000?ooo`3oool03@3o
ool100000040oooo001@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooom<
0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0o`3ooom;0?ooo`030000003oool0oooo
00h0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0
oooo>`3oool00`000000oooo0?ooo`0>0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`3o0?oood`0oooo0@0000010?ooo`00D03oool00`000000oooo0?oo
o`3o0?ooodX0oooo00<000000?ooo`3oool03`3oool100000040oooo001@0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo00l0oooo0@000001
0?ooo`00D03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo>03oool00`00
0000oooo0?ooo`0@0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0o`3ooom90?ooo`03
0000003oool0oooo0100oooo0@0000010?ooo`00D03oool200000100oooo00<000000?ooo`3oool0
o`3ooom90?ooo`8000000@3oool00500oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`3o0?ooocH0oooo00<000000?ooo`3oool04@3oool100000040oooo001@0?ooo`030000003oool0
oooo0?l0ooooB03oool00`000000oooo0?ooo`0A0?ooo`4000000@3oool00500oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`3o0?ooodP0oooo0@0000010?ooo`00D03oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0oooo<`3oool00`000000oooo0?ooo`0B0?ooo`40
00000@3oool00500oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3o0?oooc80oooo
00<000000?ooo`3oool04P3oool100000040oooo001@0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0o`3ooom70?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0o`3ooom5
0?ooo`030000003oool0oooo01@0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo0?l0oooo;`3oool00`000000oooo0?ooo`0D0?ooo`4000000@3oool00500
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3o
ool05@3oool100000040oooo000[0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d
_ol0103oool0102oM00000000000001d_ol30?ooo`060?oOW0180000000000000000B9`0gooo2P3o
ool00`000000oooo0?ooo`3o0?oood@0oooo00<000000?ooo`3oool05@3oool100000040oooo000Z
0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`030?ooo`060=nL
B000M;l0oooo0?oOW0180000B9cO0P3oool01P3o_g@0000007Boo`3oool0omnL04Qd_`X0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?ooodD0oooo0@0000010?ooo`00:@3oool0
0`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00H0oooo00<0oooO09a80018W=l00P3oool0
0`3o_g@0001809cOo`060?ooo`030?noM018W=l0oooo00P0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`3o0?ooob`0oooo00<000000?ooo`3oool05P3oool100000040oooo000Y0?oo
o`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo1@3oool00`3ooml0W4P004RLg`02
0?ooo`040?oog`2LB00004RL0=ooo`D0oooo00<0oono07@0M02oool0203oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0?l0oooo:`3oool00`000000oooo0?ooo`0F0?ooo`4000000@3o
ool002T0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`050?ooo`030?oog`2LB000
07Bo00<0oooo00<0gia80000B02Lgol01@3oool00`3ooml0W4P007Boo`080?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0o`3ooom40?ooo`4000000@3oool002X0oooo00<0_g@00018
W03Oool00P3oool00`3ogi`0B00004RLg`060?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P0
0018W=l01@3oool00`3ookl0M00004RLg`080?ooo`<00000o`3ooom20?ooo`030000003oool0oooo
01D0oooo0`0000010?ooo`00:P3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00H0
oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`050?ooo`030?noM0000000M;oo00P0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?ooobP0oooo00<000000?ooo`3o
ool05`3oool100000040oooo000Z0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool0
1@3oool00`3ogi`0B00004RLg`030?ooo`0:0;md0000B9`0gooo0?ooo`3ogml0gooo0?noM0000000
001d0;ooo`P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?ooobH0oooo00<0
00000?ooo`3oool06@3oool100000040oooo000Z0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0
gia80018W03Oool01@3oool0103ooml0W4P00018W03Oool20?ooo`090=nLB000B9`0gooo0?ooo`3o
okl0M0000000000004P0W=oo00T0oooo00<000000?ooo`3oool0o`3ooom00?ooo`030000003oool0
oooo01T0oooo0@0000010?ooo`00:`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo
00H0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`020?ooo`030=nLW02oool0oooo
00X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3o0?oood40oooo0@0000010?oo
o`00;03oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`P0oooo00H0gia80000M02oool0oooO09a8
0018W=l30?ooo`030?oOW01dW=l0oooo00X0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool06P3oool100000040oooo000]0?ooo`040=nLB000
00000000001d_`X0oooo00@0gia800000000000007Bo1@3oool01@2oM0000000000000000000B9cO
00L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?ooob<0oooo00<000000?oo
o`3oool06P3oool100000040oooo001@0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0o`3ooolR0?ooo`030000003oool0oooo01/0oooo0@0000010?ooo`00D03oool00`000000oooo
0?ooo`3o0?oooch0oooo00<000000?ooo`3oool06`3oool100000040oooo001@0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0o`3oooln0?ooo`4000000@3oool00500oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?oooah0oooo00<000000?ooo`3oool07@3oool1
00000040oooo001@0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0o`3ooolM0?oo
o`030000003oool0oooo01d0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo0?l0oooo?@3oool100000040oooo001@0?ooo`030000003oool0oooo0?l0oooo
>`3oool00`000000oooo0?ooo`0N0?ooo`4000000@3oool00500oooo0P00000O0?ooo`030000003o
ool0oooo0?l0oooo6P3oool00`000000oooo0?ooo`0M0?ooo`8000000@3oool00500oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?oooaP0oooo00<000000?ooo`3oool0803oool1
00000040oooo001@0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0o`3ooolG0?oo
o`030000003oool0oooo0200oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0?l0oooo>P3oool100000040oooo001@0?ooo`030000003oool0oooo0?l0oooo
=`3oool00`000000oooo0?ooo`0R0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`3o0?oooa<0oooo00<000000?ooo`3oool08P3oool100000040oooo001@
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooolB0?ooo`030000003oool0
oooo02<0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0?l0oooo403oool00`000000oooo0?ooo`0S0?ooo`4000000@3oool00500oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`3o0?ooo`h0oooo00<000000?ooo`3oool09@3oool100000040
oooo001@0?ooo`030000003oool0oooo0?l0oooo=03oool00`000000oooo0?ooo`0U0?ooo`400000
0@3oool00500oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`3o0?ooocD0oooo0@00
00010?ooo`00D03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0oooo2`3oool0
0`000000oooo0?ooo`0W0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`3o0?ooo`T0oooo00<000000?ooo`3oool09`3oool100000040oooo001@0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0o`3oool80?ooo`030000003oool0oooo02P0
oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0?l0oooo
1P3oool00`000000oooo0?ooo`0X0?ooo`4000000@3oool00500oooo0P00000Y0?ooo`030000003o
ool0oooo0?l0oooo103oool00`000000oooo0?ooo`0Y0?ooo`8000000@3oool00500oooo00<00000
0?ooo`3oool0o`3oool_0?ooo`030000003oool0oooo02X0oooo0@0000010?ooo`00D03oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0oooo;`3oool100000040oooo001@0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3oool00`000000oooo0?ooo`0/0?ooo`40
00000@3oool00500oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`3m0?ooo`030000
003oool0oooo02`0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo0?/0oooo00<000000?ooo`3oool0;P3oool100000040oooo001@0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool0n@3oool00`000000oooo0?ooo`0^0?ooo`4000000@3oool0
0500oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3g0?ooo`030000003oool0oooo
0300oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0?D0
oooo00<000000?ooo`3oool0<03oool100000040oooo001@0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0l`3oool00`000000oooo0?ooo`0b0?ooo`4000000@3oool00500oooo00<0
00000?ooo`3oool0o`3ooolW0?ooo`030000003oool0oooo0380oooo0@0000010?ooo`00D03oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0?l0oooo9`3oool100000040oooo001@0?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0k`3oool00`000000oooo0?ooo`0d0?oo
o`4000000@3oool00500oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`3]0?ooo`03
0000003oool0oooo03@0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo0>/0oooo00<000000?ooo`3oool0=P3oool100000040oooo001@0?ooo`800000=`3o
ool00`000000oooo0?ooo`3Y0?ooo`030000003oool0oooo03D0oooo0P0000010?ooo`00D03oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0>L0oooo00<000000?ooo`3oool0>03oool1
00000040oooo001@0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0i@3oool00`00
0000oooo0?ooo`0h0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`3S0?ooo`030000003oool0oooo03X0oooo0@0000010?ooo`00D03oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo0>40oooo00<000000?ooo`3oool0>P3oool100000040oooo
001@0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0g`3oool00`000000oooo0?oo
o`0l0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3M
0?ooo`030000003oool0oooo03`0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo0=X0oooo00<000000?ooo`3oool0?`3oool100000040oooo001@0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0o0?ooo`40
00000@3oool00500oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo0440oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo0=<0oooo00<000000?ooo`3oool0@@3oool100000040oooo001@0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`130?ooo`4000000@3oool0
0500oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`3=0?ooo`030000003oool00000
04D0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`130?ooo`030000003oool000000<d0
oooo00<000000?ooo`3oool0A@3oool100000040oooo001@0?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`180?ooo`4000000@3oool00500oooo0P00
00190?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool0A`3oool200000040oooo001@
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`1:
0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`310?oo
o`030000003oool0oooo04X0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo0;l0oooo00<000000?ooo`3oool0C03oool100000040oooo001@0?ooo`030000
003oool0oooo04`0oooo00<000000?ooo`3oool0^P3oool010000000oooo0?ooo`00001>0?ooo`40
00000@3oool00500oooo00<000000?ooo`3oool0C03oool010000000oooo0?ooo`00002i0?ooo`03
0000003oool0oooo04l0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo0;D0oooo00<000000?ooo`3oool0D@3oool100000040oooo001@0?ooo`030000003o
ool0oooo0540oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`1A0?ooo`4000000@3o
ool00500oooo00<000000?ooo`3oool0D@3oool010000000oooo0?ooo`00002_0?ooo`030000003o
ool0oooo05@0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo0:/0oooo00<000000?ooo`000000EP3oool100000040oooo000d0?ooo`040;md000000000000
07Boo`<0oooo00<0omnL04P0001d_ol00P3oool00`3ookl0M000000000020000000304RLg`3oool0
oooo00P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0
oooo05H0oooo0@0000010?ooo`00<`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0
omnL04P0001d_ol0103oool00`3o_g@0000007Boo`0;0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool0YP3oool00`000000oooo0?ooo`1I0?ooo`4000000@3oool00380oooo00<0oooO
09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?oog`2LB00007Bo00/0oooo00<00000
0?ooo`3oool0F@3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0000005/0oooo0@000001
0?ooo`00<P3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<0gia8
0018W03Oool02P3oool00`000000oooo0?ooo`1I0?ooo`030000003oool000000:40oooo00<00000
0?ooo`3oool0F`3oool100000040oooo000b0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000
B02Lgol0203oool00`3ogi`0B01809cOo`0:0?ooo`030000003oool0oooo05/0oooo00@000000?oo
o`3oool00000V`3oool00`000000oooo0?ooo`1N0?ooo`4000000@3oool003<0oooo00<0_g@00018
W03Oool00P3oool00`3ogi`0B00004RLg`080?ooo`030?oo_`1d0000M;oo00X0oooo0`00001N0?oo
o`030000003oool0oooo09H0oooo00@000000?ooo`3oool00000GP3oool300000040oooo000c0?oo
o`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l02@3oool00`2oM00007Bo0?ooo`090?oo
o`030000003oool0oooo0640oooo00<000000?ooo`3oool0T@3oool00`000000oooo0000001S0?oo
o`4000000@3oool003<0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`080?ooo`03
0=nLB000B9`0gooo00T0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0000002A0?ooo`03
0000003oool0oooo06<0oooo0@0000010?ooo`00<`3oool0103ooml0W4P00018W03Oool20?ooo`03
0=nLB000B9`0gooo00P0oooo00<0omnL04P0B02Lgol02@3oool00`000000oooo0?ooo`1S0?ooo`04
0000003oool0oooo000008/0oooo00<000000?ooo`3oool0IP3oool100000040oooo000d0?ooo`03
0?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0203oool00`3ookl0M00007Boo`090?ooo`03
0000003oool0oooo06H0oooo00@000000?ooo`3oool00000Q@3oool010000000oooo0?ooo`00001X
0?ooo`4000000@3oool003D0oooo00H0gia80000M02oool0oooO09a80018W=l:0?ooo`030;md0000
M;l0oooo00P0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`210?ooo`030000003o
ool0000006/0oooo0@0000010?ooo`00=P3oool0103OW4P0000000000000M;l90?ooo`050?oo_`1d
000000000000M02oool0203oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo07`0oooo
00@000000?ooo`3oool00000K@3oool100000040oooo001@0?ooo`030000003oool0oooo06/0oooo
00@000000?ooo`3oool00000N03oool010000000oooo0?ooo`00001`0?ooo`4000000@3oool00500
oooo00<000000?ooo`3oool0KP3oool010000000oooo0?ooo`00001b0?ooo`040000003oool0oooo
000007<0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`1a0?ooo`040000003oool0oooo
000006d0oooo00<000000?ooo`000000MP3oool100000040oooo001@0?ooo`030000003oool0oooo
07@0oooo00<000000?ooo`000000J03oool010000000oooo0?ooo`00001h0?ooo`4000000@3oool0
0500oooo00<000000?ooo`3oool0MP3oool010000000oooo0?ooo`00001R0?ooo`040000003oool0
oooo000007/0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`1i0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0E`3oool010000000oooo0?ooo`00001n0?ooo`400000
0@3oool00500oooo00<000000?ooo`3oool0O03oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`1o0?ooo`400000
0@3oool00500oooo0P0000230?ooo`060000003oool0oooo0000003oool00000B@3oool01P000000
oooo0?ooo`000000oooo000008<0oooo0P0000010?ooo`00D03oool00`000000oooo0?ooo`250?oo
o`030000003oool000000080oooo00<000000?ooo`3oool0?P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo08L0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`2:0?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0<P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000008`0oooo0@0000010?ooo`00D03oool00`000000oooo0?oo
o`2=0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0P0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`2@0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0T`3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0UP3oool100000040oooo001@0?ooo`030000003oool0oooo09`0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`040000003oool0oooo00000:40oooo0@00
00010?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe`0oooo0@0000010?ooo`00D03oool00`00
0000oooo0?ooo`3o0?oooe`0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe`0
oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe`0oooo0@0000010?ooo`00D03o
ool00`000000oooo0?ooo`3o0?oooe`0oooo0@0000010?ooo`00D03oool00`000000oooo0000000>
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool100000040oooo001@0?oo
o`030000003oool0000000h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?oo
o`4000000@3oool00500ooooo`00001P00000040oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-0.285637, -0.16309, 0.00101416, \
0.00101416}}]
}, Closed]],

Cell[TextData[{
  "However, the sequence of points is fairly complicated \[LongDash] the \
phase points hops from one place to another rather than filling the circle in \
an orderly fashion.  Below we display sequence of positions and velocities at \
each ",
  Cell[BoxData[
      \(TraditionalForm\`t\_k\)]],
  "; to minimize clutter, we show just the first 100 points. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ListPlot[Take[First /@ pts, 100], Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<k\>", \*"\"\<\!\(x\_k\)\>\""}];\)\), "\
\[IndentingNewLine]", 
    \(\(ListPlot[Take[Last /@ pts, 100], Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<k\>", \
\*"\"\<\!\(x\_k\%\[Prime]\)\>\""}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.603319 2.61039 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.21429 -0.0125 -8 -15.6875 ]
[.21429 -0.0125 8 0 ]
[.40476 -0.0125 -8 -15.6875 ]
[.40476 -0.0125 8 0 ]
[.59524 -0.0125 -8 -15.6875 ]
[.59524 -0.0125 8 0 ]
[.78571 -0.0125 -8 -15.6875 ]
[.78571 -0.0125 8 0 ]
[.97619 -0.0125 -11 -15.6875 ]
[.97619 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4.9375 -31.375 ]
[.5 -0.0125 4.9375 -15.6875 ]
[-0.0125 .08124 -27.6875 -7.84375 ]
[-0.0125 .08124 0 7.84375 ]
[-0.0125 .21176 -33.6875 -7.84375 ]
[-0.0125 .21176 0 7.84375 ]
[-0.0125 .34228 -27.6875 -7.84375 ]
[-0.0125 .34228 0 7.84375 ]
[-0.0125 .4728 -33.6875 -7.84375 ]
[-0.0125 .4728 0 7.84375 ]
[-0.0125 .60332 -10 -7.84375 ]
[-0.0125 .60332 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -49.375 -7.125 ]
[-0.01875 .30902 -33.6875 7.125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -72 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65.9375 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
68.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08124 m
.00625 .08124 L
s
gsave
-0.0125 .08124 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .21176 m
.00625 .21176 L
s
gsave
-0.0125 .21176 -94.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
0 .34228 m
.00625 .34228 L
s
gsave
-0.0125 .34228 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .4728 m
.00625 .4728 L
s
gsave
-0.0125 .4728 -94.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .10734 m
.00375 .10734 L
s
0 .13345 m
.00375 .13345 L
s
0 .15955 m
.00375 .15955 L
s
0 .18566 m
.00375 .18566 L
s
0 .23786 m
.00375 .23786 L
s
0 .26397 m
.00375 .26397 L
s
0 .29007 m
.00375 .29007 L
s
0 .31618 m
.00375 .31618 L
s
0 .36838 m
.00375 .36838 L
s
0 .39449 m
.00375 .39449 L
s
0 .42059 m
.00375 .42059 L
s
0 .4467 m
.00375 .4467 L
s
0 .4989 m
.00375 .4989 L
s
0 .52501 m
.00375 .52501 L
s
0 .55111 m
.00375 .55111 L
s
0 .57721 m
.00375 .57721 L
s
0 .05514 m
.00375 .05514 L
s
0 .02903 m
.00375 .02903 L
s
0 .00293 m
.00375 .00293 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -109.656 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.125 11.8438 translate
90 rotate
-68.125 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 17.688 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
73.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08124 m
1 .08124 L
s
.99375 .21176 m
1 .21176 L
s
.99375 .34228 m
1 .34228 L
s
.99375 .4728 m
1 .4728 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .10734 m
1 .10734 L
s
.99625 .13345 m
1 .13345 L
s
.99625 .15955 m
1 .15955 L
s
.99625 .18566 m
1 .18566 L
s
.99625 .23786 m
1 .23786 L
s
.99625 .26397 m
1 .26397 L
s
.99625 .29007 m
1 .29007 L
s
.99625 .31618 m
1 .31618 L
s
.99625 .36838 m
1 .36838 L
s
.99625 .39449 m
1 .39449 L
s
.99625 .42059 m
1 .42059 L
s
.99625 .4467 m
1 .4467 L
s
.99625 .4989 m
1 .4989 L
s
.99625 .52501 m
1 .52501 L
s
.99625 .55111 m
1 .55111 L
s
.99625 .57721 m
1 .57721 L
s
.99625 .05514 m
1 .05514 L
s
.99625 .02903 m
1 .02903 L
s
.99625 .00293 m
1 .00293 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.03333 .60332 Mdot
.04286 .18654 Mdot
.05238 .11664 Mdot
.0619 .5916 Mdot
.07143 .26619 Mdot
.08095 .06207 Mdot
.09048 .55736 Mdot
.1 .34925 Mdot
.10952 .02716 Mdot
.11905 .50335 Mdot
.12857 .42911 Mdot
.1381 .01472 Mdot
.14762 .43385 Mdot
.15714 .4994 Mdot
.16667 .02571 Mdot
.17619 .35441 Mdot
.18571 .55453 Mdot
.19524 .05927 Mdot
.20476 .27135 Mdot
.21429 .5901 Mdot
.22381 .11273 Mdot
.23333 .19129 Mdot
.24286 .60327 Mdot
.25238 .18182 Mdot
.2619 .12061 Mdot
.27143 .59301 Mdot
.28095 .26104 Mdot
.29048 .06494 Mdot
.3 .56012 Mdot
.30952 .34409 Mdot
.31905 .02871 Mdot
.32857 .50723 Mdot
.3381 .42434 Mdot
.34762 .01481 Mdot
.35714 .43855 Mdot
.36667 .4954 Mdot
.37619 .02434 Mdot
.38571 .35955 Mdot
.39524 .55162 Mdot
.40476 .05655 Mdot
.41429 .27652 Mdot
.42381 .58851 Mdot
.43333 .10887 Mdot
.44286 .19609 Mdot
.45238 .60313 Mdot
.4619 .17714 Mdot
.47143 .12464 Mdot
.48095 .59433 Mdot
.49048 .25591 Mdot
.5 .06789 Mdot
.50952 .5628 Mdot
.51905 .33891 Mdot
.52857 .03034 Mdot
.5381 .51105 Mdot
.54762 .41953 Mdot
.55714 .01499 Mdot
.56667 .44321 Mdot
.57619 .49134 Mdot
.58571 .02306 Mdot
.59524 .36467 Mdot
.60476 .54863 Mdot
.61429 .05391 Mdot
.62381 .28171 Mdot
.63333 .58683 Mdot
.64286 .10509 Mdot
.65238 .20092 Mdot
.6619 .6029 Mdot
.67143 .1725 Mdot
.68095 .12873 Mdot
.69048 .59556 Mdot
.7 .25079 Mdot
.70952 .07091 Mdot
.71905 .5654 Mdot
.72857 .33372 Mdot
.7381 .03206 Mdot
.74762 .51481 Mdot
.75714 .41468 Mdot
.76667 .01527 Mdot
.77619 .44782 Mdot
.78571 .48722 Mdot
.79524 .02188 Mdot
.80476 .36978 Mdot
.81429 .54557 Mdot
.82381 .05136 Mdot
.83333 .2869 Mdot
.84286 .58507 Mdot
.85238 .10136 Mdot
.8619 .20578 Mdot
.87143 .60258 Mdot
.88095 .16791 Mdot
.89048 .13288 Mdot
.9 .59671 Mdot
.90952 .24569 Mdot
.91905 .07401 Mdot
.92857 .56792 Mdot
.9381 .32852 Mdot
.94762 .03387 Mdot
.95714 .5185 Mdot
.96667 .4098 Mdot
.97619 .01564 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00m`3oool0202oM00007Bo0?ooo`3oool0okmd0000000007@0_ooo/@3oool00?L0oooo00P0
okmd0000M02oool0oooo0;md0000M;l0oono07Ad_k40oooo003g0?ooo`060?oOW01804P0W=oo0?oo
g`2LB000B9cO/`3oool00?L0oooo00H0oooO09a80000B7@0_knL04P0B02Lgonc0?ooo`00n03oool0
1@3OW4P004Qd07A8000007@0_ooo0;<0oooo003h0?ooo`050?noM00007@0_ooo0;md001d_ol0/`3o
ool00?P0oooo00H0oono07@0001d_ol0oooo0;mdB02Lgonb0?ooo`00n@3oool0102oM00007Bo0?oo
_`1d000200000003001d_`3oool0oooo0:h0oooo003i0?ooo`030?noM000B9`0gooo0;@0oooo003i
0?ooo`030?oOW01804P0W=oo0;@0oooo003i0?ooo`030?oog`2LB000B9cO0;@0oooo003j0?ooo`03
0;md0000M;l0oooo0;<0oooo003h0?ooo`050?oog`2LB00000000000M02oool0/`3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool005P0oooo00@0_g@0000000000000M;oo=P3oool00`3OW4P00000000000030000000304RL
g`3oool0oooo0080oooo00@0_g@0000000000000M;oo=03oool00`3ooml0W4P004RLg`050?ooo`04
0;md00000000000007Booc80oooo00D0oooO09a8000000000000001d_`050?ooo`040;md00000000
000007Booc80oooo00H0oono07@00000000000000018W03Oool40?ooo`040;md00000000000007Bo
obd0oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`030?ooo`040;md000000000000
07Boo`D0oooo00@0_g@0000000000000M;oo2P3oool005L0oooo00H0gia8001d_`3oool0omnL04P0
0018W=lf0?ooo`030?noM000M;l0oooo0080oooo00X0_gAd0;ooo`3oool0oooo0=nLB000M;l0oooo
0?oOW0180000B9cO=03oool00`3OW4P004RL0=ooo`030?ooo`060=nLB000M;l0oooo0?oOW0180000
B9cO<@3oool01`3OW4P007Bo0?ooo`3ookl0M0000018W03Oool00P3oool01P3OW4P007Bo0?ooo`3o
gi`0B00004RLgc00oooo00<0oono07@00018W=l00P3oool00`3OW4P0001d0;ooo`020?ooo`060=nL
B000M;l0oooo0?oOW0180000B9cO;P3oool00`3o_g@0000007Boo`050?ooo`060=nLB000M;l0oooo
0?oOW0180000B9cO0`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`T0oooo001F0?ooo`030?oo
g`2LB000B9cO0080oooo00<0okmd0000B02Lgol0=P3oool00`3o_g@007Bo0?ooo`040?ooo`030?oo
g`2LB000B9cO0080oooo00<0okmd0000B02Lgol0<`3oool00`3ogi`0B01809cOo`020?ooo`030?oo
g`2LB000B9cO0080oooo00<0okmd0000B02Lgol0;`3oool00`3ooml0W4P007Boo`020?ooo`070?oO
W0180000B9cO0?ooo`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo02l0oooo00<0okmd0018
W03Oool00`3oool01P2oM000B9cO0?ooo`3ooml0W4P004RLg`80oooo00<0okmd0000B02Lgol0;@3o
ool00`3ooml0W4P0001d_`040?ooo`030?oog`2LB000B9cO0080oooo00L0okmd0000B02Lgol0oooo
0?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0203oool005H0oooo00<0oooO09a80018W=l0
0P3oool0103ooml0W4P00018W03Ooolf0?ooo`030?noM000M;l0oooo00<0oooo00<0oooO09a80018
W=l00P3oool0103ooml0W4P00018W03Oool^0?ooo`030?noM0000000000000@0000000D004RL0=oo
o`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooobh0oooo00<0oono07@0001d_ol00`3o
ool01P2oM000001d0;ooo`3ooml0W4P004RLg`80oooo00@0oooO09a80000B9`0gooo;P3oool00`3o
_g@004RL0=ooo`030?ooo`060;md0000M;l0oooo0?oog`2LB000B9cO0P3oool0103ooml0W4P00018
W03Oool]0?ooo`030=nLB000B9`0gooo00<0oooo00<0oooO09a80018W=l00P3oool01`3ooml0W4P0
0018W03Oool0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool70?ooo`00EP3oool00`3o
oml0W4P0001d_`030?ooo`030=nLB00004P0W=oo03L0oooo00<0okmd04RLg`3oool00P3oool00`3o
oml0W4P0001d_`030?ooo`030=nLB00004P0W=oo02h0oooo00<0oooO09a8B02Lgol00P3oool01`2o
M00007Bo0?ooo`3oool0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`0^0?ooo`030?oog`2L
B00007Bo00<0oooo00H0gia80000B02Lgol0oooO09a80000M;l30?ooo`030=nLB00004P0W=oo02h0
oooo00<0oooO09a8001d_ol00P3oool01`3ookl0M00004RLg`3oool0oooO09a80000M;l00`3oool0
0`3OW4P0001809cOo`0]0?ooo`030?oOW01804P0W=oo00<0oooo00<0oooO09a80000M;l00`3oool0
1P3OW4P0001809cOo`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol01`3oool005L0oooo00<0
_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0h0?ooo`030=nLB018W=l0oooo0080oooo00<0
_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0_0?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@0
04RL0=ooo`020?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0;`3oool00`2oM000
001d0;ooo`020?ooo`070=nLB00004P0W=oo0?ooo`2oM00004RL0=ooo`020?ooo`030?oOW0180000
B9cO0300oooo00H0_g@00000B02Lgml0W4P00000M02oool20?ooo`030;md0000B9`0gooo0080oooo
00<0omnL04P00018W=l0;@3oool00`3ookl0M00007Boo`040?ooo`030;md0000B9`0gooo0080oooo
00L0omnL04P00018W=l0oooo0;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01`3oool005L0
oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0i0?ooo`070;md001d_ol0oooo0?oo
o`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo0300oooo00H0omnL04Q8W03Oool0omnL04P0
B02Lgol20?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0;`3oool0303o_g@00000
04RLg`3oool0oooO09a80000B9`0gooo0?ooo`3OW4P0001809cOo`80oooo00<0oooO09a80000M;l0
<@3oool01@3ooml0W4P000000000B9`0gooo0080oooo00<0gia80000B02Lgol00P3oool00`3ooml0
W4P0001d_`0^0?ooo`030;md0000M;l0oooo00<0oooo00<0gia80000B02Lgol00P3oool01`3ooml0
W4P0001d_`3oool0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`070?ooo`00E`3oool00`3o
gi`0B00004RLg`030?ooo`030;md0000B9`0gooo03P0oooo00L0omnL04P0M02oool0oooo0?oOW018
0000B9cO00<0oooo00<0_g@00018W03Oool0<03oool01@3o_g@007Bo0?oog`2LB000B9cO0080oooo
00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`0^0?ooo`030?oog`2LB000000000800000
00L0001d0;ooo`3oool0oooo0?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool0<03oool02P2o
M000001809cOo`3ogi`0B4RL0=ooo`3oool0omnL04P00018W=l30?ooo`030;md0000B9`0gooo02d0
oooo00<0gia80018W03Oool00`3oool00`3ogi`0B00004RLg`030?ooo`060;md0000B9`0gooo0?oO
W0180000B9cO0`3oool00`2oM00004RL0=ooo`060?ooo`00E`3oool0103ooml0W4P00018W03Oool2
0?ooo`030=nLB000B9`0gooo03P0oooo00P0oooO09a8001d_ol0oooo0?oog`2LB00004RL0=ooo`80
oooo00<0gia80018W03Oool0<@3oool0103OW4P0B9cO0;md0000M;l20?ooo`040?oog`2LB00004RL
0=ooo`80oooo00<0gia80018W03Oool0;`3oool00`3ookl0M000001d_`050?ooo`040?oog`2LB000
04RL0=ooo`80oooo00<0gia80018W03Oool0;`3oool00`3ogi`0B00007Boo`020?ooo`070?noM018
W=l0oooo0?oog`2LB00004RL0=ooo`020?ooo`030=nLB000B9`0gooo02d0oooo00<0omnL04P0B02L
gol00`3oool0103ooml0W4P00018W03Oool20?ooo`070=nLB000B9`0gooo0?oog`2LB00004RL0=oo
o`020?ooo`030=nLB000B9`0gooo00H0oooo001H0?ooo`030?oOW0180000M;oo0080oooo00<0gia8
001d_`3oool0>03oool00`3ookl0M00004RLg`020?ooo`030?oOW0180000M;oo0080oooo00<0gia8
001d_`3oool0<P3oool0103OW4P0M7Ad0000M02oool20?ooo`030?oOW0180000M;oo0080oooo00<0
gia8001d_`3oool0<03oool00`3ogi`0B00004RLg`050?ooo`030?oOW0180000M;oo0080oooo00<0
gia8001d_`3oool0;`3oool00`3ogi`0B01809cOo`020?ooo`070?noM000B9`0gooo0?ooo`3ogi`0
B00007Boo`020?ooo`030=nLB000M;l0oooo02d0oooo00<0oono07@0001d_ol0103oool00`3ogi`0
B00007Boo`020?ooo`070=nLB000M;l0oooo0?ooo`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0
oooo00H0oooo001I0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO=@3oool01`3o_g@004RL0=oo
o`3oool0gia80000B02Lgol00`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLgc@0oooo00<0_g@0
0000B02Lgol00`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLgc80oooo00@0oooO09a8000007@0
_ooo103oool01P3OW4P0001d0;ooo`3ooml0W4P004RLgc00oooo00<0oooO09a80018W=l00P3oool0
0`2oM00007Bo0?ooo`020?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO;`3oool00`2oM00007Bo
0?ooo`040?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO0`3oool01P3OW4P0001d0;ooo`3ooml0
W4P004RLg`L0oooo001J0?ooo`040=nLB00000000000001d_cL0oooo00D0omnL04P0000000000000
07Boo`050?ooo`040=nLB00000000000001d_cD0oooo00<0oooO09a80018W=l0103oool0103OW4P0
000000000000M;le0?ooo`040?oo_`1d0000000004RLg`<0oooo00@0gia800000000000007Bo<P3o
ool01@3ooml0W4P000000000000007Bo00D0oooo00@0gia800000000000007Bo;P3oool01@3ookl0
M0000000000007@0_ooo00D0oooo00@0gia800000000000007Bo1@3oool0103OW4P0000000000000
M;l80?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00D`3o
oooo000005800000303oool005<0oooo0P0000060?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`800000303oool005<0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`00D`3oool00`000000oooo0?ooo`3o0?ooodh0
oooo00<000000?ooo`3oool02P3oool005<0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000
003oool0oooo00X0oooo001C0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`130?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo001C0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`130?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00X0oooo001C0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`130?ooo`030000003oool0oooo00X0oooo001C0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0:0?ooo`00D`3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool02P3oool005<0oooo0P00
000R0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo05D0oooo0P00000<0?ooo`00D`3oool00`000000oooo0?ooo`2^
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00X0oooo001C0?ooo`030000003oool0oooo0?l0oooo?03oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo001C0?ooo`030000003oool0oooo0?l0
ooooCP3oool00`000000oooo0?ooo`0:0?ooo`00D`3oool00`000000oooo0?ooo`3o0?ooodh0oooo
00<000000?ooo`3oool02P3oool005<0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003o
ool0oooo00X0oooo001C0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`0:
0?ooo`00D`3oool00`000000oooo0?ooo`3o0?oooa80oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`0:0?ooo`00D`3oool200000<`0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`0h0?ooo`800000303oool005<0oooo00<000000?ooo`3oool0Q03oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool02P3oool005<0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0<H0oooo00<0
00000?ooo`3oool02P3oool005<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo0?l0oooo3@3oool00`000000oooo0?ooo`0:0?ooo`00=`3oool0102o
M00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00<0gia80000000000000`000000
0`18W=l0oooo0?ooo`070?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`3/0?ooo`030000003oool0oooo00X0oooo000f0?ooo`060=nLB000M;l0oooo
0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`030?ooo`030?noM000M;l0oooo0080oooo00<0
_gAd0;ooo`3oool01`3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo04<0oooo00<0
00000?ooo`3oool0YP3oool00`000000oooo0?ooo`0:0?ooo`00=@3oool00`3ooml0W4P004RLg`02
0?ooo`030?noM00004P0W=oo00P0oooo00<0okmd001d_`3oool02`3oool00`000000oooo0?ooo`2T
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0:
0?ooo`00=@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<0okmd
001d_`3oool02P3oool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo04<0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0:0?ooo`00:03oool00`3ooml0W4P0000000070000
000604RLg`3oool0oooo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`090?ooo`030?noM018
W=l0oooo00T0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool02P3oool003H0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0:
0?ooo`030=nLB018W=l0oooo00P0oooo0`00003o0?oood`0oooo0`00000<0?ooo`00=P3oool00`3O
W4P0001809cOo`020?ooo`030?oog`2LB00007Bo00/0oooo00<0_g@007Boo`3oool01`3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool02P3oool003H0oooo00<0omnL04P00018
W=l00`3oool00`2oM00004RL0=ooo`0:0?ooo`030?oOW01807@0_ooo00L0oooo00<000000?ooo`3o
ool0o`3ooom>0?ooo`030000003oool0oooo00X0oooo000f0?ooo`040?oog`2LB00004RL0=ooo`80
oooo00<0gia80018W03Oool02P3oool00`3ooml0W4P007Boo`070?ooo`030000003oool0oooo0?l0
ooooCP3oool00`000000oooo0?ooo`0:0?ooo`00=`3oool00`3ogi`0B00007Boo`020?ooo`030=nL
B000M;l0oooo00X0oooo00<0oono07@00018W=l01`3oool00`000000oooo0?ooo`3o0?ooodh0oooo
00<000000?ooo`3oool02P3oool003P0oooo00H0gia80000M02oool0oooO09a80018W=l70?ooo`07
0?noM000B9`0gooo0?ooo`3OW4P0001809cOo`070?ooo`030000003oool0oooo0?l0ooooCP3oool0
0`000000oooo0?ooo`0:0?ooo`00>@3oool0103OW4P0000000000000M;l90?ooo`050?oOW0180000
00000000001d_ol0203oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool02P3o
ool005<0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool02P3oool005<0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool005<0oooo0P00002?0?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`3oool0M@3oool2000000`0oooo001C0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0:0?ooo`00D`3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?l0oooo103oool00`000000oooo0?oo
o`0:0?ooo`00D`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool0o`3oool40?ooo`030000003oool0oooo00X0oooo001C0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`3f0?ooo`030000003oool0oooo
00X0oooo001C0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0mP3oool00`000000
oooo0?ooo`0:0?ooo`00D`3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0:l0oooo
00<000000?ooo`3oool02P3oool005<0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool02P3oool005<0oooo00<00000
0?ooo`3oool0h@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool02P3oool005<0oooo0P00003o0?ooobT0oooo00<000000?ooo`3oool08P3oool20000
00`0oooo001C0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`0:0?ooo`00
D`3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool02P3oool005<0oooo00<0
00000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00X0oooo001C0?ooo`030000003oool0
oooo0?l0ooooCP3oool00`000000oooo0?ooo`0:0?ooo`00D`3oool00`000000oooo0?ooo`3o0?oo
odh0oooo00<000000?ooo`3oool02P3oool005<0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`03
0000003oool0oooo00X0oooo001C0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo
0?ooo`0:0?ooo`00D`3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool02P3o
ool005<0oooo0P00003o0?ooodh0oooo0P00000<0?ooo`00D`3oool00`000000oooo0?ooo`3o0?oo
odh0oooo00<000000?ooo`3oool02P3oool005<0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool02P3oool005<0oooo00<000000?ooo`3oool0
o`3ooolU0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool02P3oool005<0oooo00<0
00000?ooo`3oool0gP3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo00X0oooo001C
0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1/
0?ooo`030000003oool0oooo00X0oooo001C0?ooo`030000003oool0oooo09L0oooo00<000000?oo
o`3oool0/`3oool00`000000oooo0?ooo`0:0?ooo`00D`3oool00`000000oooo0?ooo`1A0?ooo`03
0000003oool0oooo0?T0oooo00<000000?ooo`3oool02P3oool005<0oooo0P00000;0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0n03oool2000000`0oooo001C0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0o`3ooom10?ooo`030000003oool0oooo00X0oooo001C
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0o`3oool10?ooo`030000003oool0
oooo00X0oooo001C0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0o`3oool10?oo
o`030000003oool0oooo00X0oooo000^0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0
001d_ol00P3oool00`3ookl0M000000000020000000604RLg`3oool0oooo0?ooo`3ogi`0B0000P00
00000`00B9`0gooo0?ooo`090?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0^@3o
ool00`000000oooo0?ooo`0:0?ooo`00;@3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo
00<0omnL04P0001d_ol0103oool00`3o_g@0000007Boo`040?ooo`060?noM0000000M;oo0?ooo`3o
gi`0B7Bo2P3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool0L`3oool00`000000oooo0?ooo`0:0?ooo`00;03oool00`3ooml0W4P004RLg`020?ooo`03
0?noM00004P0W=oo00P0oooo00<0oooO09a80000M;l02@3oool00`3o_g@0B9cO0?ooo`080?ooo`03
0000003oool0oooo0=L0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0:0?ooo`00
;03oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<0gia80018W03O
ool0203oool00`3ookl0M01d0;ooo`080?ooo`030000003oool0oooo0?l0oooo7`3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000O0?ooo`030?oog`2LB000000000L00000
00H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`030=nLB00004P0W=oo00P0oooo00<0omnL04P0
B02Lgol0203oool00`3ooml0W4P007Boo`080?ooo`030000003oool0oooo0?l0oooo7`3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000]0?ooo`030;md0000B9`0gooo0080
oooo00<0omnL04P00018W=l0203oool00`3ookl0M00007Boo`080?ooo`030?oo_`1d0000B9cO00P0
oooo0`00003o0?oood`0oooo0`00000<0?ooo`00;@3oool00`3OW4P0001809cOo`020?ooo`030?oo
g`2LB00007Bo00T0oooo00<0_g@0001d_`3oool01`3oool00`3o_g@0000007Boo`080?ooo`030000
003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`0:0?ooo`00;@3oool00`3ogi`0B00004RL
g`030?ooo`030;md0000B9`0gooo00P0oooo00<0gia80018W03Oool0103oool01P3ogml0gooo0?no
M0000000001d0;ooo`P0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00X0
oooo000]0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0203oool00`3ogi`0
B01809cOo`040?ooo`050?oo_`1d000000000000B02Lgol02@3oool00`000000oooo0?ooo`3o0?oo
odh0oooo00<000000?ooo`3oool02P3oool002h0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P0
07Bo0?ooo`080?ooo`030?oo_`1d0000M;oo00D0oooo00<0gibL0;ooo`3oool02P3oool00`000000
oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool02P3oool002l0oooo00H0gia80000M02oool0
oooO09a80018W=l:0?ooo`030;md0000M;l0oooo00@0oooo00<0omnL07BLg`3oool02P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool02P3oool00300oooo00@0gia800000000
000007Bo2@3oool01@3ookl0M0000000000007@0_ooo00D0oooo00D0_g@0000000000000000004RL
g`070?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`0:0?ooo`00D`3oool0
0`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool02P3oool005<0oooo00<000000?oo
o`3oool0o`3ooom>0?ooo`030000003oool0oooo00X0oooo001C0?ooo`800000o`3ooom>0?ooo`80
0000303oool005<0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00X0oooo
001C0?ooo`030000003oool0oooo0?l0oooo;`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00X0oooo001C0?ooo`030000003oool0oooo0?l0oooo;`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo00X0oooo001C0?ooo`030000003oool0oooo0>L0oooo00<000000?oo
o`3oool0H`3oool00`000000oooo0?ooo`0:0?ooo`00D`3oool00`000000oooo0?ooo`3W0?ooo`03
0000003oool0oooo06<0oooo00<000000?ooo`3oool02P3oool005<0oooo00<000000?ooo`3oool0
X@3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo00X0oooo001C0?ooo`030000003o
ool0oooo05X0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`2Y0?ooo`030000003o
ool0oooo00X0oooo001C0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0l03oool0
0`000000oooo0?ooo`0:0?ooo`00D`3oool2000001D0oooo00<000000?ooo`3oool0o`3ooolf0?oo
o`800000303oool005<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?ooocL0
oooo00<000000?ooo`3oool02P3oool005<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool02P3oool005<0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool02P3oool005<0oooo00<00000
0?ooo`3oool0Q`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo00X0oooo001C0?oo
o`030000003oool0oooo08L0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1l0?oo
o`030000003oool0oooo00X0oooo001C0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`0:0?ooo`00D`3oool00`000000oooo0?ooo`3o0?oooaD0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0:0?ooo`004P3oool00`3OW4P0001d0;oo
o`0n0?ooo`800000o`3ooolF0?ooo`030000003oool0oooo03D0oooo0P00000<0?ooo`002`3oool0
0`3ookl0M7Bo0?ooo`040?ooo`030?oo_`1dB9`0gooo03h0oooo00<000000?ooo`3oool0o`3ooom>
0?ooo`030000003oool0oooo00X0oooo000;0?ooo`030?oOW01807@0_ooo00<0oooo00<0okmd0000
M02oool0?`3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool02P3oool000/0
oooo00L0omnL04P000000000001809cOo`3ogi`0B7Bo0440oooo00<000000?ooo`3oool0o`3ooom>
0?ooo`030000003oool0oooo00X0oooo000=0?ooo`030?oo_`1d000000000080000000<0M;oo0?oo
o`3oool0?P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool02P3oool000`0
oooo00T0oono07@0M02oool0oooo0?oog`2LB00000000000M02oool0?P3oool00`000000oooo0?oo
o`3o0?ooodh0oooo00<000000?ooo`3oool02P3oool000/0oooo00<0oono07@0M02oool0103oool0
0`3ogi`0B7Bo0?ooo`0n0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`0:
0?ooo`002`3oool00`3o_g@0000007Boo`030?ooo`030?oo_`1dB9`0gooo03l0oooo00<000000?oo
o`3oool0o`3ooom>0?ooo`030000003oool0oooo00X0oooo000D0?ooo`040?noM0000000001d0;oo
oc/0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00X0oooo000=0?ooo`04
0?oog`2LW;l0oooO09a800<0000000<007Bo0?ooo`3oool0?03oool200000?l0ooooCP3oool20000
00`0oooo000=0?ooo`040?oo_`1d0000001809cOo`80oooo00<0_ibL0=ooo`3oool0?@3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool02P3oool00140oooo00D0gmoO0;md0000
00000000001d_`0m0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`0:0?oo
o`00403oool00`3ooml0W4P007Boo`020?ooo`030=nLB00007@0_ooo03/0oooo00<000000?ooo`3o
ool0o`3ooom>0?ooo`030000003oool0oooo00X0oooo000@0?ooo`030?oog`2LM9`0gooo0080oooo
00<0giad09cOo`3oool07`3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080
oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`080?ooo`030000003oool0oooo0?l0
oooo>03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo000f0?ooo`060=nL
B000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`040?ooo`030?noM0000000M;oo
00/0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool02P3oool003D0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`03
0?oog`2LB00007Bo00/0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`1I0?ooo`03
0000003oool0oooo00X0oooo000e0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0
gooo203oool00`3OW4P004RL0=ooo`0:0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3o
ool0F@3oool00`000000oooo0?ooo`0:0?ooo`00:03oool00`3ooml0W4P0000000070000000604RL
g`3oool0oooo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`080?ooo`030?oOW01804P0W=oo
00X0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo
00X0oooo000f0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0203oool00`3ookl0
M00007Boo`0:0?ooo`<00000I03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo09d0
oooo0`00000<0?ooo`00=P3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00T0oooo
00<0_g@0001d_`3oool02@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0>H0oooo
00<000000?ooo`3oool02P3oool003H0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=oo
o`080?ooo`030=nLB000B9`0gooo00T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`3o0?ooobd0oooo00<000000?ooo`3oool02P3oool003H0oooo00@0oooO09a80000B9`0gooo0P3o
ool00`3OW4P004RL0=ooo`080?ooo`030?oOW01804P0W=oo00T0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool02P3oool003L0oooo00<0omnL
04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`080?ooo`030?oo_`1d0000M;oo00T0oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`3o0?oooa@0oooo00<000000?ooo`3oool02P3oool0
03P0oooo00H0gia80000M02oool0oooO09a80018W=l:0?ooo`030;md0000M;l0oooo00P0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`3o0?oooa@0oooo00<000000?ooo`3oool02P3o
ool003T0oooo00@0gia800000000000007Bo2@3oool01@3ookl0M0000000000007@0_ooo00P0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00X0oooo
001C0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo00X0oooo001C0?ooo`030000003oool0oooo0<@0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`0:0?ooo`00D`3oool200000?l0oooo3@3oool00`00
0000oooo0?ooo`0n0?ooo`800000303oool005<0oooo00<000000?ooo`3oool0o`3oool<0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool02P3oool005<0oooo00<000000?ooo`3oool0
o`3ooom>0?ooo`030000003oool0oooo00X0oooo001C0?ooo`030000003oool0oooo0?l0ooooCP3o
ool00`000000oooo0?ooo`0:0?ooo`00D`3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<00000
0?ooo`3oool02P3oool005<0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo
00X0oooo001C0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`0:0?ooo`00
D`3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool02P3oool005<0oooo00<0
00000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00X0oooo001C0?ooo`800000o`3ooom>
0?ooo`800000303oool005<0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo
00X0oooo001C0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`0:0?ooo`00
D`3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool02P3oool005<0oooo00<0
00000?ooo`3oool0o`3ooom20?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3o
ool005<0oooo00<000000?ooo`3oool0o`3ooom20?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02P3oool005<0oooo00<000000?ooo`3oool0n`3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo00X0oooo001C0?ooo`030000003oool0oooo0?/0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0:0?ooo`00D`3oool200000;D0oooo00<000000?ooo`3oool0
U@3oool2000000`0oooo001C0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo00X0oooo001C0?ooo`030000003oool0
oooo06h0oooo00<000000?ooo`3oool0g03oool00`000000oooo0?ooo`0:0?ooo`00D`3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`0:0?oo
o`00D`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0oooo903oool00`000000
oooo0?ooo`0:0?ooo`00D`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0oooo
7@3oool00`000000oooo0?ooo`0:0?ooo`00D`3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0:0?ooo`00D`3oool0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0=H0oooo00<000000?ooo`3oool02P3oool0
05<0oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
00X0oooo001C0?ooo`800000_03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo04P0
oooo0P00000<0?ooo`00D`3oool00`000000oooo0?ooo`3o0?ooo`80oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`0:0?ooo`00D`3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<0
00000?ooo`3oool02P3oool005<0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0
oooo00X0oooo000^0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol0103oool0
102oM00000000000001d_ol30?ooo`060?oOW0180000000000000000B9`0gooo2P3oool00`000000
oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool02P3oool002d0oooo00H0gia8001d_`3oool0
omnL04P00018W=l20?ooo`030?oOW0180000M;oo00<0oooo00H0gia8001d_`3oool0omnL04P00018
W=l20?ooo`060?noM0000000M;oo0?ooo`3ogi`0B7Bo2P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo00<000000?ooo`3oool02P3oool002`0oooo00<0oooO09a80018W=l00P3oool00`3o_g@00018
09cOo`060?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol01P3oool00`3o_g@0B9cO
0?ooo`080?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`0:0?ooo`00;03o
ool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`D0oooo00<0oooO09a80018W=l0
0P3oool0103ooml0W4P00018W03Oool50?ooo`030?oo_`1d07@0_ooo00P0oooo00<000000?ooo`3o
ool0o`3ooom>0?ooo`030000003oool0oooo00X0oooo000O0?ooo`030?oog`2LB000000000L00000
00H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`030=nLB00004P0W=oo00D0oooo00<0oooO09a8
0000M;l00`3oool00`3OW4P0001809cOo`050?ooo`030?oog`2LB000M;oo00P0oooo00<000000?oo
o`3oool0o`3ooom>0?ooo`030000003oool0oooo00X0oooo000]0?ooo`030;md0000B9`0gooo0080
oooo00<0omnL04P00018W=l01P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00D0
oooo00<0oono07@00018W=l0203oool300000?l0ooooC03oool3000000`0oooo000]0?ooo`030=nL
B00004P0W=oo0080oooo00<0oooO09a80000M;l01P3oool00`3OW4P0001809cOo`020?ooo`030?oo
g`2LB00007Bo00D0oooo00<0okmd0000001d_ol0203oool00`000000oooo0?ooo`3o0?ooodh0oooo
00<000000?ooo`3oool02P3oool002d0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=oo
o`050?ooo`030?oOW0180000B9cO00<0oooo00X0_g@00018W03Oool0oooo0?oOg`3Oool0okmd0000
000007@0_ooo203oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool02P3oool0
02d0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`050?ooo`040?oog`2LB000
04RL0=ooo`80oooo00T0gia80018W03Oool0oooo0?oo_`1d000000000000B02Lgol02@3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool02P3oool002h0oooo00<0omnL04P0001d
_ol00P3oool00`3OW4P007Bo0?ooo`060?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3o
ool00P3oool00`3OW9`0_ooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000
oooo0?ooo`0:0?ooo`00;`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`P0oooo00H0gia80000
M02oool0oooO09a80018W=l30?ooo`030?oOW01dW=l0oooo00X0oooo00<000000?ooo`3oool0o`3o
ool50?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool02P3oool00300oooo00@0gia8
00000000000007Bo2P3oool0103OW4P0000000000000M;l50?ooo`050;md00000000000000000018
W=l01`3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0:0?ooo`00D`3oool00`000000oooo0?ooo`1g0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`00D`3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool02P3o
ool005<0oooo0P00000b0?ooo`030000003oool0oooo0?l0oooo6@3oool2000000`0oooo001C0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oo
oaX0oooo00<000000?ooo`3oool02P3oool005<0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool02P3oool005<0oooo
00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo00X0oooo
001C0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?oo
o`0:0?ooo`00D`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo04<0oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`0:0?ooo`00D`3oool00`000000oooo0?ooo`3g0?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?oo
o`00D`3oool00`000000oooo0?ooo`3o0?ooocl0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0:0?ooo`00D`3oool200000?l0ooooCP3oool2000000`0oooo001C0?ooo`030000003o
ool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`0:0?ooo`00D`3oool00`000000oooo0?ooo`3o
0?ooodh0oooo00<000000?ooo`3oool02P3oool005<0oooo00<000000?ooo`3oool0o`3ooom>0?oo
o`030000003oool0oooo00X0oooo001C0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000
oooo0?ooo`0:0?ooo`00D`3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0
2P3oool005<0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00X0oooo001C
0?ooo`030000003oool0oooo0?l0oooo3`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo00X0oooo001C0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo00X0oooo001C0?ooo`800000PP3oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo0880oooo0P00000<0?ooo`00D`3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0b@3oool00`000000oooo
0?ooo`0:0?ooo`00D`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0o`3ooolA0?ooo`030000003oool0oooo00X0oooo001C0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3Y0?ooo`030000003oool0
oooo00X0oooo001C0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`2S0?ooo`030000003oool0oooo00X0oooo001C0?ooo`030000003oool0oooo0:L0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00X0
oooo001C0?ooo`030000003oool0oooo0>h0oooo00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo00X0oooo001C0?ooo`030000003oool0oooo0?l0oooo=@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00X0oooo001C0?ooo`030000003oool0
oooo0?l0ooooCP3oool00`000000oooo0?ooo`0:0?ooo`00D`3oool200000?l0ooooCP3oool20000
00`0oooo001C0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`0:0?ooo`00
D`3oool00`000000oooo0?ooo`3o0?oooaP0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`0:0?ooo`00D`3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo04<0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0:0?ooo`00A@3oool0102oM00000000000001d
_ol:0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool02P3oool004@0oooo00H0gia8
001d_`3oool0omnL04P00018W=l90?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
_`3oool00`000000oooo0?ooo`0:0?ooo`00@`3oool00`3ooml0W4P004RLg`020?ooo`030?noM000
04P0W=oo00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool02P3oool004<0oooo00<0oooO09a80018W=l00P3oool0
103ooml0W4P00018W03Oool70?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`140?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool02P3o
ool004<0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`070?ooo`030000003oool0
oooo09@0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`130?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool02P3oool004@0oooo00<0_g@00018W03Oool00P3oool00`3o
gi`0B00004RLg`070?ooo`<000001`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo
02L0oooo0`00000<0?ooo`00A03oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?`0
oooo00<000000?ooo`3oool02P3oool004@0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL
0=ooo`060?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`0:0?ooo`00A03o
ool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0:0?ooo`00A@3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000
M;l0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`00AP3oool0
1P3OW4P0001d0;ooo`3ooml0W4P004RLg`L0ooooo`00001B000000`0oooo00170?ooo`040=nLB000
00000000001d_ol0ooooIP3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-28.5246, -0.289536, \
0.468457, 0.00170913}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.309109 2.61692 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.21429 -0.0125 -8 -15.6875 ]
[.21429 -0.0125 8 0 ]
[.40476 -0.0125 -8 -15.6875 ]
[.40476 -0.0125 8 0 ]
[.59524 -0.0125 -8 -15.6875 ]
[.59524 -0.0125 8 0 ]
[.78571 -0.0125 -8 -15.6875 ]
[.78571 -0.0125 8 0 ]
[.97619 -0.0125 -11 -15.6875 ]
[.97619 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4.9375 -31.375 ]
[.5 -0.0125 4.9375 -15.6875 ]
[-0.0125 .04742 -27.6875 -7.84375 ]
[-0.0125 .04742 0 7.84375 ]
[-0.0125 .17826 -33.6875 -7.84375 ]
[-0.0125 .17826 0 7.84375 ]
[-0.0125 .30911 -10 -7.84375 ]
[-0.0125 .30911 0 7.84375 ]
[-0.0125 .43996 -25 -7.84375 ]
[-0.0125 .43996 0 7.84375 ]
[-0.0125 .5708 -19 -7.84375 ]
[-0.0125 .5708 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -49.375 -7.125 ]
[-0.01875 .30902 -33.6875 7.125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -72 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65.9375 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
68.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .04742 m
.00625 .04742 L
s
gsave
-0.0125 .04742 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .17826 m
.00625 .17826 L
s
gsave
-0.0125 .17826 -94.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
0 .30911 m
.00625 .30911 L
s
gsave
-0.0125 .30911 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .43996 m
.00625 .43996 L
s
gsave
-0.0125 .43996 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
0 .5708 m
.00625 .5708 L
s
gsave
-0.0125 .5708 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07359 m
.00375 .07359 L
s
0 .09976 m
.00375 .09976 L
s
0 .12592 m
.00375 .12592 L
s
0 .15209 m
.00375 .15209 L
s
0 .20443 m
.00375 .20443 L
s
0 .2306 m
.00375 .2306 L
s
0 .25677 m
.00375 .25677 L
s
0 .28294 m
.00375 .28294 L
s
0 .33528 m
.00375 .33528 L
s
0 .36145 m
.00375 .36145 L
s
0 .38762 m
.00375 .38762 L
s
0 .41379 m
.00375 .41379 L
s
0 .46612 m
.00375 .46612 L
s
0 .49229 m
.00375 .49229 L
s
0 .51846 m
.00375 .51846 L
s
0 .54463 m
.00375 .54463 L
s
0 .02125 m
.00375 .02125 L
s
0 .59697 m
.00375 .59697 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -109.656 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.125 11.8438 translate
90 rotate
-68.125 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 18.625 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
68.563 11.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\242) show
73.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04742 m
1 .04742 L
s
.99375 .17826 m
1 .17826 L
s
.99375 .30911 m
1 .30911 L
s
.99375 .43996 m
1 .43996 L
s
.99375 .5708 m
1 .5708 L
s
.125 Mabswid
.99625 .07359 m
1 .07359 L
s
.99625 .09976 m
1 .09976 L
s
.99625 .12592 m
1 .12592 L
s
.99625 .15209 m
1 .15209 L
s
.99625 .20443 m
1 .20443 L
s
.99625 .2306 m
1 .2306 L
s
.99625 .25677 m
1 .25677 L
s
.99625 .28294 m
1 .28294 L
s
.99625 .33528 m
1 .33528 L
s
.99625 .36145 m
1 .36145 L
s
.99625 .38762 m
1 .38762 L
s
.99625 .41379 m
1 .41379 L
s
.99625 .46612 m
1 .46612 L
s
.99625 .49229 m
1 .49229 L
s
.99625 .51846 m
1 .51846 L
s
.99625 .54463 m
1 .54463 L
s
.99625 .02125 m
1 .02125 L
s
.99625 .59697 m
1 .59697 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30911 m
1 .30911 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.03333 .30911 Mdot
.04286 .04083 Mdot
.05238 .5324 Mdot
.0619 .39155 Mdot
.07143 .01721 Mdot
.08095 .46962 Mdot
.09048 .46742 Mdot
.1 .01684 Mdot
.10952 .39405 Mdot
.11905 .53068 Mdot
.12857 .03975 Mdot
.1381 .31172 Mdot
.14762 .57629 Mdot
.15714 .08412 Mdot
.16667 .22918 Mdot
.17619 .60062 Mdot
.18571 .14641 Mdot
.19524 .15301 Mdot
.20476 .60173 Mdot
.21429 .22167 Mdot
.22381 .08927 Mdot
.23333 .57952 Mdot
.24286 .30389 Mdot
.25238 .04304 Mdot
.2619 .53578 Mdot
.27143 .38652 Mdot
.28095 .01801 Mdot
.29048 .47398 Mdot
.3 .46299 Mdot
.30952 .01617 Mdot
.31905 .39904 Mdot
.32857 .5272 Mdot
.3381 .03766 Mdot
.34762 .31694 Mdot
.35714 .57404 Mdot
.36667 .08078 Mdot
.37619 .23422 Mdot
.38571 .59977 Mdot
.39524 .14208 Mdot
.40476 .15746 Mdot
.41429 .60235 Mdot
.42381 .21669 Mdot
.43333 .09279 Mdot
.44286 .58157 Mdot
.45238 .29866 Mdot
.4619 .04534 Mdot
.47143 .53909 Mdot
.48095 .38147 Mdot
.49048 .01891 Mdot
.5 .47828 Mdot
.50952 .45851 Mdot
.51905 .01559 Mdot
.52857 .404 Mdot
.5381 .52365 Mdot
.54762 .03566 Mdot
.55714 .32216 Mdot
.56667 .5717 Mdot
.57619 .07751 Mdot
.58571 .23929 Mdot
.59524 .59883 Mdot
.60476 .1378 Mdot
.61429 .16197 Mdot
.62381 .60288 Mdot
.63333 .21175 Mdot
.64286 .09637 Mdot
.65238 .58353 Mdot
.6619 .29345 Mdot
.67143 .04772 Mdot
.68095 .54232 Mdot
.69048 .37639 Mdot
.7 .0199 Mdot
.70952 .48254 Mdot
.71905 .45398 Mdot
.72857 .01511 Mdot
.7381 .40893 Mdot
.74762 .52003 Mdot
.75714 .03374 Mdot
.76667 .32738 Mdot
.77619 .56927 Mdot
.78571 .07431 Mdot
.79524 .24437 Mdot
.80476 .59779 Mdot
.81429 .13358 Mdot
.82381 .16652 Mdot
.83333 .60332 Mdot
.84286 .20683 Mdot
.85238 .10003 Mdot
.8619 .58541 Mdot
.87143 .28823 Mdot
.88095 .05019 Mdot
.89048 .54549 Mdot
.9 .3713 Mdot
.90952 .02097 Mdot
.91905 .48673 Mdot
.92857 .44941 Mdot
.9381 .01472 Mdot
.94762 .41383 Mdot
.95714 .51634 Mdot
.96667 .03191 Mdot
.97619 .33259 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00m`3oool0202oM00007Bo0?ooo`3oool0okmd0000
000007@0_ooo/@3oool00?L0oooo00P0okmd0000M02oool0oooo0;md0000M;l0oono07Ad_k40oooo
003g0?ooo`060?oOW01804P0W=oo0?oog`2LB000B9cO/`3oool00?L0oooo00H0oooO09a80000B7@0
_knL04P0B02Lgonc0?ooo`00n03oool01@3OW4P004Qd07A8000007@0_ooo0;<0oooo003h0?ooo`05
0?noM00007@0_ooo0;md001d_ol0/`3oool00?P0oooo00H0oono07@0001d_ol0oooo0;mdB02Lgonb
0?ooo`00n@3oool0102oM00007Bo0?oo_`1d000200000003001d_`3oool0oooo0:h0oooo003i0?oo
o`030?noM000B9`0gooo0;@0oooo003i0?ooo`030?oOW01804P0W=oo0;@0oooo003i0?ooo`030?oo
g`2LB000B9cO0;@0oooo003j0?ooo`030;md0000M;l0oooo0;<0oooo003h0?ooo`050?oog`2LB000
00000000M02oool0/`3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool005H0oooo00@0_g@0000000000000M;oo=P3oool0
0`3OW4P00000000000030000000304RLg`3oool0oooo0080oooo00@0_g@0000000000000M;oo=@3o
ool00`3ooml0W4P004RLg`050?ooo`040;md00000000000007Booc@0oooo00D0oooO09a800000000
0000001d_`050?ooo`040;md00000000000007Booc<0oooo00H0oono07@00000000000000018W03O
ool40?ooo`040;md00000000000007Boobh0oooo00<0oono07@0000000000P0000000`18W=l0oooo
0?ooo`030?ooo`040;md00000000000007Boo`D0oooo00@0_g@0000000000000M;oo1`3oool005D0
oooo00H0gia8001d_`3oool0omnL04P00018W=lf0?ooo`030?noM000M;l0oooo0080oooo00X0_gAd
0;ooo`3oool0oooo0=nLB000M;l0oooo0?oOW0180000B9cO=@3oool00`3OW4P004RL0=ooo`030?oo
o`060=nLB000M;l0oooo0?oOW0180000B9cO<`3oool01`3OW4P007Bo0?ooo`3ookl0M0000018W03O
ool00P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLgc40oooo00<0oono07@00018W=l00P3oool0
0`3OW4P0001d0;ooo`020?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO;`3oool00`3o_g@00000
07Boo`050?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0`3oool01P3OW4P007Bo0?ooo`3ogi`0
B00004RLg`H0oooo001D0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0=P3oool0
0`3o_g@007Bo0?ooo`040?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0=03oool0
0`3ogi`0B01809cOo`020?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0<@3oool0
0`3ooml0W4P007Boo`020?ooo`070?oOW0180000B9cO0?ooo`3ooml0W4P004RLg`020?ooo`030?no
M00004P0W=oo0300oooo00<0okmd0018W03Oool00`3oool01P2oM000B9cO0?ooo`3ooml0W4P004RL
g`80oooo00<0okmd0000B02Lgol0;P3oool00`3ooml0W4P0001d_`040?ooo`030?oog`2LB000B9cO
0080oooo00L0okmd0000B02Lgol0oooo0?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol01@3o
ool005@0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Ooolf0?ooo`030?noM000
M;l0oooo00<0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool_0?ooo`030?no
M0000000000000@0000000D004RL0=ooo`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=oo
oc00oooo00<0oono07@0001d_ol00`3oool01P2oM000001d0;ooo`3ooml0W4P004RLg`80oooo00@0
oooO09a80000B9`0gooo;`3oool00`3o_g@004RL0=ooo`030?ooo`060;md0000M;l0oooo0?oog`2L
B000B9cO0P3oool0103ooml0W4P00018W03Oool^0?ooo`030=nLB000B9`0gooo00<0oooo00<0oooO
09a80018W=l00P3oool01`3ooml0W4P00018W03Oool0oooO09a80018W=l00P3oool0103ooml0W4P0
0018W03Oool40?ooo`00E03oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo03L0oooo
00<0okmd04RLg`3oool00P3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo02l0oooo
00<0oooO09a8B02Lgol00P3oool01`2oM00007Bo0?ooo`3oool0oooO09a80000M;l00`3oool00`3O
W4P0001809cOo`0`0?ooo`030?oog`2LB00007Bo00<0oooo00H0gia80000B02Lgol0oooO09a80000
M;l30?ooo`030=nLB00004P0W=oo02l0oooo00<0oooO09a8001d_ol00P3oool01`3ookl0M00004RL
g`3oool0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`0^0?ooo`030?oOW01804P0W=oo00<0
oooo00<0oooO09a80000M;l00`3oool01P3OW4P0001809cOo`3ooml0W4P0001d_`<0oooo00<0gia8
0000B02Lgol0103oool005D0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0h0?oo
o`030=nLB018W=l0oooo0080oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0`0?oo
o`070?oo_`1d07@0_ooo0?ooo`3o_g@004RL0=ooo`020?ooo`030;md0000B9`0gooo0080oooo00<0
omnL04P00018W=l0<@3oool00`2oM000001d0;ooo`020?ooo`070=nLB00004P0W=oo0?ooo`2oM000
04RL0=ooo`020?ooo`030?oOW0180000B9cO0340oooo00H0_g@00000B02Lgml0W4P00000M02oool2
0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0;P3oool00`3ookl0M00007Boo`04
0?ooo`030;md0000B9`0gooo0080oooo00L0omnL04P00018W=l0oooo0;md0000B9`0gooo0080oooo
00<0omnL04P00018W=l0103oool005D0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d
_`0i0?ooo`070;md001d_ol0oooo0?ooo`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo0340
oooo00H0omnL04Q8W03Oool0omnL04P0B02Lgol20?ooo`030=nLB00004P0W=oo0080oooo00<0oooO
09a80000M;l0<@3oool0303o_g@0000004RLg`3oool0oooO09a80000B9`0gooo0?ooo`3OW4P00018
09cOo`80oooo00<0oooO09a80000M;l0<P3oool01@3ooml0W4P000000000B9`0gooo0080oooo00<0
gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0_0?ooo`030;md0000M;l0oooo00<0oooo00<0
gia80000B02Lgol00P3oool01`3ooml0W4P0001d_`3oool0gia80000B02Lgol00P3oool00`3ooml0
W4P0001d_`040?ooo`00E@3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo03P0oooo
00L0omnL04P0M02oool0oooo0?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool0<@3oool01@3o
_g@007Bo0?oog`2LB000B9cO0080oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`0`
0?ooo`030?oog`2LB00000000080000000L0001d0;ooo`3oool0oooo0?oOW0180000B9cO00<0oooo
00<0_g@00018W03Oool0<@3oool02P2oM000001809cOo`3ogi`0B4RL0=ooo`3oool0omnL04P00018
W=l30?ooo`030;md0000B9`0gooo02h0oooo00<0gia80018W03Oool00`3oool00`3ogi`0B00004RL
g`030?ooo`060;md0000B9`0gooo0?oOW0180000B9cO0`3oool00`2oM00004RL0=ooo`030?ooo`00
E@3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo03P0oooo00P0oooO09a8001d
_ol0oooo0?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0<P3oool0103OW4P0B9cO0;md
0000M;l20?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0<@3oool00`3ookl0
M000001d_`050?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0<03oool00`3o
gi`0B00007Boo`020?ooo`070?noM018W=l0oooo0?oog`2LB00004RL0=ooo`020?ooo`030=nLB000
B9`0gooo02h0oooo00<0omnL04P0B02Lgol00`3oool0103ooml0W4P00018W03Oool20?ooo`070=nL
B000B9`0gooo0?oog`2LB00004RL0=ooo`020?ooo`030=nLB000B9`0gooo00<0oooo001F0?ooo`03
0?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0>03oool00`3ookl0M00004RLg`020?ooo`03
0?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0<`3oool0103OW4P0M7Ad0000M02oool20?oo
o`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0<P3oool00`3ogi`0B00004RLg`050?oo
o`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0<03oool00`3ogi`0B01809cOo`020?oo
o`070?noM000B9`0gooo0?ooo`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo02h0oooo00<0
oono07@0001d_ol0103oool00`3ogi`0B00007Boo`020?ooo`070=nLB000M;l0oooo0?ooo`3ogi`0
B00007Boo`020?ooo`030=nLB000M;l0oooo00<0oooo001G0?ooo`060=nLB00007@0_ooo0?oog`2L
B000B9cO=@3oool01`3o_g@004RL0=ooo`3oool0gia80000B02Lgol00`3oool01P3OW4P0001d0;oo
o`3ooml0W4P004RLgcD0oooo00<0_g@00000B02Lgol00`3oool01P3OW4P0001d0;ooo`3ooml0W4P0
04RLgc@0oooo00@0oooO09a8000007@0_ooo103oool01P3OW4P0001d0;ooo`3ooml0W4P004RLgc40
oooo00<0oooO09a80018W=l00P3oool00`2oM00007Bo0?ooo`020?ooo`060=nLB00007@0_ooo0?oo
g`2LB000B9cO<03oool00`2oM00007Bo0?ooo`040?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO
0`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`@0oooo001H0?ooo`040=nLB00000000000001d
_cL0oooo00D0omnL04P000000000000007Boo`050?ooo`040=nLB00000000000001d_cH0oooo00<0
oooO09a80018W=l0103oool0103OW4P0000000000000M;lg0?ooo`040?oo_`1d0000000004RLg`<0
oooo00@0gia800000000000007Bo<`3oool01@3ooml0W4P000000000000007Bo00D0oooo00@0gia8
00000000000007Bo;`3oool01@3ookl0M0000000000007@0_ooo00D0oooo00@0gia8000000000000
07Bo1@3oool0103OW4P0000000000000M;l50?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00D03ooooo000005P000002@3oool00500oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0
oooo001@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00500oooo00<0
00000?ooo`3oool0o`3ooomD0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0
oooo0?D0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00L0oooo001@0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`00D03oool200000:D0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo01`0oooo
0P0000090?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe@0oooo00<000000?ooo`3oool01`3o
ool00500oooo00<000000?ooo`3oool0o`3ooomD0?ooo`030000003oool0oooo00L0oooo001@0?oo
o`030000003oool0oooo0?l0ooooB03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00L0oooo000d0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol00P3oool00`3o
okl0M000000000020000000304RLg`3oool0oooo00P0oooo00<000000?ooo`3oool0o`3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool003<0
oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00@0oooo00<0okmd
0000001d_ol02`3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00L0oooo000b0?oo
o`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0203oool00`3ooml0W4P0001d_`0;0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`070?oo
o`00<P3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<0gia80018
W03Oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`3m0?ooo`030000003oool0oooo00L0oooo000U0?ooo`03
0?oog`2LB000000000L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`030=nLB00004P0
W=oo00P0oooo00<0omnL04P0B02Lgol02P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`070?ooo`00<`3oool00`2o
M00004RL0=ooo`020?ooo`030?oOW0180000B9cO00P0oooo00<0oono07@0001d_ol02P3oool30000
09X0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo
02@0oooo0`0000090?ooo`00<`3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00T0
oooo00<0_g@0001d_`3oool02@3oool00`000000oooo0?ooo`3R0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`070?ooo`00<`3oool00`3ogi`0B000
04RLg`030?ooo`030;md0000B9`0gooo00P0oooo00<0gia80018W03Oool02@3oool00`000000oooo
0?ooo`3o0?oooe@0oooo00<000000?ooo`3oool01`3oool003<0oooo00@0oooO09a80000B9`0gooo
0P3oool00`3OW4P004RL0=ooo`080?ooo`030?oOW01804P0W=oo00T0oooo00<000000?ooo`3oool0
o`3ooomD0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030?oOW0180000M;oo0080oooo00<0
gia8001d_`3oool0203oool00`3ookl0M00007Boo`090?ooo`030000003oool0oooo0?l0ooooE03o
ool00`000000oooo0?ooo`070?ooo`00=@3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`X0oooo
00<0_g@0001d_`3oool0203oool00`000000oooo0?ooo`3o0?oooe@0oooo00<000000?ooo`3oool0
1`3oool003H0oooo00@0gia800000000000007Bo2@3oool01@3ookl0M0000000000007@0_ooo00P0
oooo00<000000?ooo`3oool0o`3ooomD0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000
003oool0oooo0?l0ooooE03oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?oo
o`3o0?oooe@0oooo00<000000?ooo`3oool01`3oool00500oooo0P00003o0?ooo`/0oooo00<00000
0?ooo`3oool0AP3oool2000000T0oooo001@0?ooo`030000003oool0oooo0<40oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00L0oooo001@0?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool0o`3ooolO0?ooo`030000003oool0oooo00L0oooo001@
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0o`3oool80?ooo`030000003oool0
oooo00L0oooo001@0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`300?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo0900
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00L0
oooo001@0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0N03oool00`000000oooo
0?ooo`070?ooo`00D03oool200000?l0oooo8P3oool00`000000oooo0?ooo`0_0?ooo`8000002@3o
ool00500oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0o`3ooomD0?ooo`030000003oool0oooo
00L0oooo001@0?ooo`030000003oool0oooo0?l0ooooE03oool00`000000oooo0?ooo`070?ooo`00
D03oool00`000000oooo0?ooo`3o0?oooe@0oooo00<000000?ooo`3oool01`3oool00500oooo00<0
00000?ooo`3oool0o`3ooomD0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0
oooo0?l0ooooE03oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`3o0?oo
oe@0oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0o`3ooomD0?ooo`03
0000003oool0oooo00L0oooo001@0?ooo`800000o`3ooomD0?ooo`8000002@3oool00500oooo00<0
00000?ooo`3oool0o`3ooomD0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0
oooo0?l0oooo503oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00L0oooo001@0?oo
o`030000003oool0oooo0</0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3o
ool0Q@3oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`230?ooo`030000
003oool0oooo0<d0oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool01`3o
ool00500oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3o0?oooaD0oooo00<00000
0?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0o`3ooomD0?ooo`030000003oool0oooo
00L0oooo001@0?ooo`800000@03oool00`000000oooo0?ooo`3o0?oooa40oooo0P0000090?ooo`00
D03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
b@3oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`270?ooo`030000003o
ool0oooo0<T0oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0cP3oool0
0`000000oooo0?ooo`220?ooo`030000003oool0oooo00L0oooo000[0?ooo`040;md000000000000
07Boo`<0oooo00<0omnL04P0001d_ol0103oool0102oM00000000000001d_ol30?ooo`060?oOW018
0000000000000000B9`0gooo2P3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`070?ooo`00:P3oool01P3OW4P007Bo
0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00`3oool01P3OW4P007Bo0?ooo`3ogi`0
B00004RLg`80oooo00H0okmd0000001d_ol0oooo0?oOW018M;l:0?ooo`030000003oool0oooo0?l0
oooo5`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00L0oooo000Y0?ooo`030?oo
g`2LB000B9cO0080oooo00<0okmd0000B02Lgol01P3oool00`3ooml0W4P004RLg`020?ooo`030?no
M00004P0W=oo00H0oooo00<0okmd04RLg`3oool0203oool00`000000oooo0?ooo`3o0?oooe@0oooo
00<000000?ooo`3oool01`3oool002T0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018
W03Oool50?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo1@3oool00`3ookl0
M01d0;ooo`080?ooo`030000003oool0oooo0?l0ooooE03oool00`000000oooo0?ooo`070?ooo`00
703oool00`3ooml0W4P0000000070000000604RLg`3oool0oooo0?oog`2LB00007Bo0`3oool00`3O
W4P0001809cOo`050?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol01@3oool00`3o
oml0W4P007Boo`080?ooo`<00000o`3ooomB0?ooo`<000002@3oool002X0oooo00<0_g@00018W03O
ool00P3oool00`3ogi`0B00004RLg`060?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018
W=l01@3oool00`3ookl0M00004RLg`080?ooo`030000003oool0oooo0?l0ooooE03oool00`000000
oooo0?ooo`070?ooo`00:P3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00H0oooo
00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`050?ooo`030?noM0000000M;oo00P0oooo
00<000000?ooo`3oool0o`3ooomD0?ooo`030000003oool0oooo00L0oooo000Z0?ooo`030?oOW018
0000B9cO00<0oooo00<0_g@00018W03Oool01@3oool00`3ogi`0B00004RLg`030?ooo`0:0;md0000
B9`0gooo0?ooo`3ogml0gooo0?noM0000000001d0;ooo`P0oooo00<000000?ooo`3oool0o`3ooomD
0?ooo`030000003oool0oooo00L0oooo000Z0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia8
0018W03Oool01@3oool0103ooml0W4P00018W03Oool20?ooo`090=nLB000B9`0gooo0?ooo`3ookl0
M0000000000004P0W=oo00T0oooo00<000000?ooo`3oool0o`3ooomD0?ooo`030000003oool0oooo
00L0oooo000[0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01P3oool00`3ogi`0
B00007Boo`020?ooo`030=nLB000M;l0oooo0080oooo00<0gibL0;ooo`3oool02P3oool00`000000
oooo0?ooo`3o0?oooe@0oooo00<000000?ooo`3oool01`3oool002`0oooo00H0gia80000M02oool0
oooO09a80018W=l80?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO0`3oool00`3ogi`0M9cO0?oo
o`0:0?ooo`030000003oool0oooo0?l0ooooE03oool00`000000oooo0?ooo`070?ooo`00;@3oool0
103OW4P0000000000000M;l:0?ooo`040=nLB00000000000001d_`D0oooo00D0_g@0000000000000
000004RLg`070?ooo`030000003oool0oooo0?l0ooooE03oool00`000000oooo0?ooo`070?ooo`00
D03oool00`000000oooo0?ooo`3o0?oooe@0oooo00<000000?ooo`3oool01`3oool00500oooo0P00
003o0?oooe@0oooo0P0000090?ooo`00D03oool00`000000oooo0?ooo`3o0?oooah0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`3o0?oo
oah0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000
oooo0?ooo`3E0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool01`3oool00500oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo07/0oooo
00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`330?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool0o`3oool<0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool0o`3oool<0?ooo`030000003oool0oooo00L0oooo001@0?ooo`03
0000003oool0oooo0?l0ooooE03oool00`000000oooo0?ooo`070?ooo`00D03oool2000003H0oooo
00<000000?ooo`3oool0o`3ooolK0?ooo`8000002@3oool00500oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool01`3o
ool00500oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0
oooo00L0oooo001@0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool0R`3oool00`00
0000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo08/0
oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0o`3oool=0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0o`3o
ool=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool01`3oool00500oooo00<00000
0?ooo`3oool0o`3ooomD0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo
0?l0ooooE03oool00`000000oooo0?ooo`070?ooo`00D03oool200000?l0ooooE03oool2000000T0
oooo001@0?ooo`030000003oool0oooo0?l0ooooE03oool00`000000oooo0?ooo`070?ooo`00D03o
ool00`000000oooo0?ooo`3o0?oooe@0oooo00<000000?ooo`3oool01`3oool00500oooo00<00000
0?ooo`3oool0o`3ooomD0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo
0?l0ooooE03oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe@0
oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0o`3ooomD0?ooo`030000
003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo0?l0ooooE03oool00`000000oooo0?oo
o`070?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe@0oooo00<000000?ooo`3oool01`3oool0
0500oooo0P00003o0?oooe@0oooo0P0000090?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe@0
oooo00<000000?ooo`3oool01`3oool000l0oooo00<0gia80000M02oool0?P3oool00`000000oooo
0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`070?ooo`00203o
ool00`3ookl0M7Bo0?ooo`040?ooo`030?oo_`1dB9`0gooo03h0oooo00<000000?ooo`3oool0o`3o
oolW0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool01`3oool000P0oooo00<0omnL
04P0M02oool00`3oool00`3o_g@0001d0;ooo`0a0?ooo`040;md00000000000007Boo`X0oooo00<0
00000?ooo`3oool0g`3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00L0oooo0008
0?ooo`070?oOW018000000000000B02Lgol0omnL04Qd_`0b0?ooo`060=nLB000M;l0oooo0?oOW018
0000B9cO2@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool0L@3oool00`000000oooo0?ooo`070?ooo`002P3oool00`3ookl0M0000000000200000003
07Boo`3oool0oooo02h0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`03
0000003oool0oooo09L0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`070?ooo`00
2@3oool02@3ookl0M01d0;ooo`3oool0oooO09a800000000001d0;ooo`0^0?ooo`030?oog`2LB000
B9cO0080oooo00@0oooO09a80000B9`0gooo1`3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo0?l0oooo0P3oool00`000000oooo0?ooo`070?ooo`00203oool00`3ookl0M01d0;ooo`04
0?ooo`030?oOW018M;l0oooo02h0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`07
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0o`3oool20?ooo`030000003oool0
oooo00L0oooo00080?ooo`030?noM0000000M;oo00<0oooo00<0oono07A8W03Oool0<03oool00`2o
M00004RL0=ooo`020?ooo`030?oOW0180000B9cO00L0ooooo`00001H000000T0oooo00110?ooo`03
0=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l01`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0o`3ooolV0?ooo`030000003oool0oooo00L0
oooo000B0?ooo`040?noM0000000001d0;ooob/0oooo00<0omnL04P00018W=l00`3oool00`2oM000
04RL0=ooo`060?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`03
0000003oool0oooo00L0oooo00070?ooo`080=nLB0000000M;oo0?ooo`3ooml0W9bo0?oog`2LB003
00000003001d_`3oool0oooo02`0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=oo
o`060?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?oo
o`070?ooo`00103oool0103OW4P0000000000000M;l30?ooo`040?oo_`1d0000001809cOo`80oooo
00<0_ibL0=ooo`3oool0;P3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00H0oooo
00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo
00030?ooo`040?oo_`1d000004RL0=ooo`P0oooo00D0gmoO0;md000000000000001d_`0_0?ooo`06
0=nLB00007@0_ooo0?oog`2LB000B9cO1`3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0
oooo09D0oooo00<000000?ooo`3oool01`3oool000h0oooo00<0oooO09a8001d_ol00P3oool00`3O
W4P0001d0;ooo`0^0?ooo`040=nLB00000000000001d_`P0oooo00<000000?ooo`3oool0^`3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01`3oool0
00h0oooo00<0oooO09adW03Oool00P3oool00`3OW7@0W=oo0?ooo`0j0?ooo`030000003oool0oooo
0?l0oooo0`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00L0oooo001@0?ooo`03
0000003oool0oooo0?l0ooooB`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo001@0?ooo`800000o`3ooom<0?ooo`030000003oool0oooo00D0oooo0P0000090?ooo`00D03o
ool00`000000oooo0?ooo`3o0?oooe@0oooo00<000000?ooo`3oool01`3oool00500oooo00<00000
0?ooo`3oool0o`3ooomD0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo
0?l0ooooE03oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe@0
oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0o`3ooomD0?ooo`030000
003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo0?l0ooooE03oool00`000000oooo0?oo
o`070?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe@0oooo00<000000?ooo`3oool01`3oool0
0500oooo00<000000?ooo`3oool0o`3ooomD0?ooo`030000003oool0oooo00L0oooo001@0?ooo`80
0000o`3ooomD0?ooo`8000002@3oool00500oooo00<000000?ooo`3oool0o`3ooomD0?ooo`030000
003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo0?l0ooooE03oool00`000000oooo0?oo
o`070?ooo`00D03oool00`000000oooo0?ooo`3o0?oooc40oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`3o0?oooc40oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`3X0?ooo`03
0000003oool0oooo06P0oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0
j03oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003o
ool0oooo0:40oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`070?ooo`00D03oool0
0`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool01`3oool0
0500oooo0P00001J0?ooo`030000003oool0oooo0?H0oooo0P0000090?ooo`00D03oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0m`3oool00`000000
oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0o`3oool_0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0o`3oool_0?ooo`030000003oool0oooo00L0oooo001@
0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0i`3oool00`000000oooo0?ooo`07
0?ooo`00D03oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0>L0oooo00<000000?oo
o`3oool01`3oool00500oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`2O0?ooo`03
0000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003o
ool0oooo0?T0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`070?ooo`00D03oool2
00000?l0oooo@P3oool00`000000oooo0?ooo`0?0?ooo`8000002@3oool00500oooo00<000000?oo
o`3oool0o`3ooom10?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01`3oool00500
oooo00<000000?ooo`3oool0o`3ooomD0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000
003oool0oooo0?l0ooooE03oool00`000000oooo0?ooo`070?ooo`00:`3oool0102oM00000000000
001d_ol30?ooo`030?oOW0180000M;oo00@0oooo00@0_g@0000000000000M;oo0`3oool01P3ogi`0
B00000000000000004RL0=ooo`X0oooo00<000000?ooo`3oool0o`3ooomD0?ooo`030000003oool0
oooo00L0oooo000Z0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Bo
o`030?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool01P3o_g@0000007Boo`3oool0omnL
04Qd_`X0oooo00<000000?ooo`3oool0o`3ooomD0?ooo`030000003oool0oooo00L0oooo000Y0?oo
o`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol01P3oool00`3ooml0W4P004RLg`020?oo
o`030?noM00004P0W=oo00H0oooo00<0okmd04RLg`3oool0203oool00`000000oooo0?ooo`3o0?oo
oe@0oooo00<000000?ooo`3oool01`3oool002T0oooo00<0oooO09a80018W=l00P3oool0103ooml0
W4P00018W03Oool50?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo1@3oool0
0`3ookl0M01d0;ooo`080?ooo`030000003oool0oooo0?l0ooooE03oool00`000000oooo0?ooo`07
0?ooo`00:@3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00D0oooo00<0oooO09a8
0000M;l00`3oool00`3OW4P0001809cOo`050?ooo`030?oog`2LB000M;oo00P0oooo00<000000?oo
o`3oool0o`3ooomD0?ooo`030000003oool0oooo00L0oooo000Z0?ooo`030;md0000B9`0gooo0080
oooo00<0omnL04P00018W=l01P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00D0
oooo00<0oono07@00018W=l0203oool300000?l0ooooDP3oool3000000T0oooo000Z0?ooo`030=nL
B00004P0W=oo0080oooo00<0oooO09a80000M;l01P3oool00`3OW4P0001809cOo`020?ooo`030?oo
g`2LB00007Bo00D0oooo00<0okmd0000001d_ol0203oool00`000000oooo0?ooo`3o0?oooe@0oooo
00<000000?ooo`3oool01`3oool002X0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=oo
o`050?ooo`030?oOW0180000B9cO00<0oooo00X0_g@00018W03Oool0oooo0?oOg`3Oool0okmd0000
000007@0_ooo203oool00`000000oooo0?ooo`3o0?oooe@0oooo00<000000?ooo`3oool01`3oool0
02X0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`050?ooo`040?oog`2LB000
04RL0=ooo`80oooo00T0gia80018W03Oool0oooo0?oo_`1d000000000000B02Lgol02@3oool00`00
0000oooo0?ooo`3o0?oooc/0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`070?oo
o`00:`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00H0oooo00<0omnL04P0001d
_ol00P3oool00`3OW4P007Bo0?ooo`020?ooo`030=nLW02oool0oooo00X0oooo00<000000?ooo`3o
ool0o`3ooolk0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01`3oool002`0oooo
00H0gia80000M02oool0oooO09a80018W=l80?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO0`3o
ool00`3ogi`0M9cO0?ooo`0:0?ooo`030000003oool0oooo0?80oooo00<000000?ooo`3oool0GP3o
ool00`000000oooo0?ooo`070?ooo`00;@3oool0103OW4P0000000000000M;l:0?ooo`040=nLB000
00000000001d_`D0oooo00D0_g@0000000000000000004RLg`070?ooo`030000003oool0oooo0:/0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00L0
oooo001@0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo
0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0>d0oooo00<0
00000?ooo`3oool01`3oool00500oooo0P00000L0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool0k03oool2000000T0oooo001@0?ooo`030000003oool0oooo01P0oooo00@000000?oo
o`3oool00000o`3ooolh0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`3`0?ooo`030000003oool0oooo
00L0oooo001@0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0l03oool00`000000
oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0:T0oooo
00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool01`3oool00500oooo00<00000
0?ooo`3oool0k`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00L0oooo001@0?oo
o`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00L0oooo001@0?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00L0oooo001@0?ooo`800000o`3ooomD0?ooo`8000002@3oool00500oooo00<0
00000?ooo`3oool0o`3ooomD0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0
oooo0?l0ooooE03oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`3o0?oo
oe@0oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0o`3ooomD0?ooo`03
0000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo0?l0ooooE03oool00`000000oooo
0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe@0oooo00<000000?ooo`3oool01`3o
ool00500oooo00<000000?ooo`3oool0o`3ooomD0?ooo`030000003oool0oooo00L0oooo001@0?oo
o`030000003oool0oooo0?l0ooooA@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00L0oooo001@0?ooo`800000o@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00/0
oooo0P0000090?ooo`00D03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?oo
o`2d0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool01`3oool00500oooo00<00000
0?ooo`3oool0K@3oool00`000000oooo0?ooo`3S0?ooo`030000003oool0oooo00L0oooo001@0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo0><0oooo00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0oooo;03oool00`000000
oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0?X0oooo
00<000000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool01`3oool00500oooo00<00000
0?ooo`3oool0W@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo06/0oooo00<00000
0?ooo`3oool01`3oool00500oooo0P00003V0?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool08P3oool2000000T0oooo001@0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo0?l0oooo
E03oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe@0oooo00<0
00000?ooo`3oool01`3oool003@0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Bo
o`020?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0203oool00`000000oooo0?oo
o`3o0?oooe@0oooo00<000000?ooo`3oool01`3oool003<0oooo00H0gia8001d_`3oool0omnL04P0
0018W=l20?ooo`030?oOW0180000M;oo00@0oooo00<0okmd0000001d_ol02`3oool00`000000oooo
0?ooo`3o0?oooe@0oooo00<000000?ooo`3oool01`3oool00380oooo00<0oooO09a80018W=l00P3o
ool00`3o_g@0001809cOo`080?ooo`030?oog`2LB00007Bo00/0oooo00<000000?ooo`3oool0o`3o
oomD0?ooo`030000003oool0oooo00L0oooo000b0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO
09a80000B9`0gooo203oool00`3OW4P004RL0=ooo`0:0?ooo`030000003oool0oooo0?l0ooooE03o
ool00`000000oooo0?ooo`070?ooo`00<P3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0
W=oo00P0oooo00<0omnL04P0B02Lgol02P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`070?ooo`00<`3oool00`2oM00004RL0=ooo`020?oo
o`030?oOW0180000B9cO00P0oooo00<0oono07@0001d_ol02P3oool300000;h0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`180?ooo`<000002@3oool003<0oooo00<0gia80000B02L
gol00P3oool00`3ooml0W4P0001d_`090?ooo`030;md0000M;l0oooo00T0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool0TP3oool00`000000oooo0?ooo`070?ooo`00<`3oool00`3ogi`0B00004RLg`030?ooo`030;md
0000B9`0gooo00P0oooo00<0gia80018W03Oool02@3oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0fP3oool00`000000oooo0?ooo`070?ooo`00<`3o
ool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00P0oooo00<0omnL04P0B02Lgol0
2@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
_03oool00`000000oooo0?ooo`070?ooo`00=03oool00`3ogi`0B00007Boo`020?ooo`030=nLB000
M;l0oooo00P0oooo00<0oono07@0001d_ol02@3oool00`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1e0?ooo`030000003o
ool0oooo00L0oooo000e0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO2P3oool00`2oM00007Bo
0?ooo`080?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo00L0oooo000f0?ooo`040=nLB00000000000001d_`T0oooo
00D0oono07@000000000001d0;ooo`080?ooo`030000003oool0oooo0?l0oooo903oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo00L0oooo001@0?ooo`030000003oool0oooo0?l0oooo
E03oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe@0oooo00<0
00000?ooo`3oool01`3oool00500oooo0P0000390?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool0?`3oool2000000T0oooo001@0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool01`3oool00500oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`070?ooo`00
D03oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`070?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe@0oooo00<0
00000?ooo`3oool01`3oool00500oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`00D03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo001@0?ooool0
0000F00000090?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-27.1968, -0.177168, \
0.460304, 0.00167519}}]
}, Closed]]
}, Closed]],

Cell["\<\
Both quantities have show 3 interleaved curves, with the phase point hopping \
from one curve to the next.  To demonstrate this, we plot every third point.  \
Similar figures are obtained starting with either the second or third points. \
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[First /@ Take[pts, {1, Length[pts], 3}], Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<k\>", \*"\"\<\!\(x\_\(3  k\)\)\>\""}];\)\)], \
"Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.00570288 0.603319 2.6104 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.16638 -0.0125 -8 -15.6875 ]
[.16638 -0.0125 8 0 ]
[.30895 -0.0125 -8 -15.6875 ]
[.30895 -0.0125 8 0 ]
[.45153 -0.0125 -8 -15.6875 ]
[.45153 -0.0125 8 0 ]
[.5941 -0.0125 -11 -15.6875 ]
[.5941 -0.0125 11 0 ]
[.73667 -0.0125 -11 -15.6875 ]
[.73667 -0.0125 11 0 ]
[.87924 -0.0125 -11 -15.6875 ]
[.87924 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4.9375 -31.375 ]
[.5 -0.0125 4.9375 -15.6875 ]
[-0.0125 .08124 -27.6875 -7.84375 ]
[-0.0125 .08124 0 7.84375 ]
[-0.0125 .21176 -33.6875 -7.84375 ]
[-0.0125 .21176 0 7.84375 ]
[-0.0125 .34228 -27.6875 -7.84375 ]
[-0.0125 .34228 0 7.84375 ]
[-0.0125 .4728 -33.6875 -7.84375 ]
[-0.0125 .4728 0 7.84375 ]
[-0.0125 .60332 -10 -7.84375 ]
[-0.0125 .60332 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -49.375 -10.0625 ]
[-0.01875 .30902 -33.6875 10.0625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.16638 0 m
.16638 .00625 L
s
gsave
.16638 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.30895 0 m
.30895 .00625 L
s
gsave
.30895 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.45153 0 m
.45153 .00625 L
s
gsave
.45153 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(75) show
1.000 setlinewidth
grestore
.5941 0 m
.5941 .00625 L
s
gsave
.5941 -0.0125 -72 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.73667 0 m
.73667 .00625 L
s
gsave
.73667 -0.0125 -72 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(125) show
1.000 setlinewidth
grestore
.87924 0 m
.87924 .00625 L
s
gsave
.87924 -0.0125 -72 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.125 Mabswid
.05232 0 m
.05232 .00375 L
s
.08084 0 m
.08084 .00375 L
s
.10935 0 m
.10935 .00375 L
s
.13787 0 m
.13787 .00375 L
s
.1949 0 m
.1949 .00375 L
s
.22341 0 m
.22341 .00375 L
s
.25192 0 m
.25192 .00375 L
s
.28044 0 m
.28044 .00375 L
s
.33747 0 m
.33747 .00375 L
s
.36598 0 m
.36598 .00375 L
s
.3945 0 m
.3945 .00375 L
s
.42301 0 m
.42301 .00375 L
s
.48004 0 m
.48004 .00375 L
s
.50855 0 m
.50855 .00375 L
s
.53707 0 m
.53707 .00375 L
s
.56558 0 m
.56558 .00375 L
s
.62261 0 m
.62261 .00375 L
s
.65113 0 m
.65113 .00375 L
s
.67964 0 m
.67964 .00375 L
s
.70816 0 m
.70816 .00375 L
s
.76518 0 m
.76518 .00375 L
s
.7937 0 m
.7937 .00375 L
s
.82221 0 m
.82221 .00375 L
s
.85073 0 m
.85073 .00375 L
s
.90776 0 m
.90776 .00375 L
s
.93627 0 m
.93627 .00375 L
s
.96478 0 m
.96478 .00375 L
s
.9933 0 m
.9933 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65.9375 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
68.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08124 m
.00625 .08124 L
s
gsave
-0.0125 .08124 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .21176 m
.00625 .21176 L
s
gsave
-0.0125 .21176 -94.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
0 .34228 m
.00625 .34228 L
s
gsave
-0.0125 .34228 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .4728 m
.00625 .4728 L
s
gsave
-0.0125 .4728 -94.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .10734 m
.00375 .10734 L
s
0 .13345 m
.00375 .13345 L
s
0 .15955 m
.00375 .15955 L
s
0 .18566 m
.00375 .18566 L
s
0 .23786 m
.00375 .23786 L
s
0 .26397 m
.00375 .26397 L
s
0 .29007 m
.00375 .29007 L
s
0 .31618 m
.00375 .31618 L
s
0 .36838 m
.00375 .36838 L
s
0 .39449 m
.00375 .39449 L
s
0 .42059 m
.00375 .42059 L
s
0 .4467 m
.00375 .4467 L
s
0 .4989 m
.00375 .4989 L
s
0 .52501 m
.00375 .52501 L
s
0 .55111 m
.00375 .55111 L
s
0 .57721 m
.00375 .57721 L
s
0 .05514 m
.00375 .05514 L
s
0 .02903 m
.00375 .02903 L
s
0 .00293 m
.00375 .00293 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -112.594 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
71.0625 11.8438 translate
90 rotate
-71.0625 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 17.688 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
72.875 17.688 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
74.438 17.688 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
79.125 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.16638 .61178 m
.16638 .61803 L
s
.30895 .61178 m
.30895 .61803 L
s
.45153 .61178 m
.45153 .61803 L
s
.5941 .61178 m
.5941 .61803 L
s
.73667 .61178 m
.73667 .61803 L
s
.87924 .61178 m
.87924 .61803 L
s
.125 Mabswid
.05232 .61428 m
.05232 .61803 L
s
.08084 .61428 m
.08084 .61803 L
s
.10935 .61428 m
.10935 .61803 L
s
.13787 .61428 m
.13787 .61803 L
s
.1949 .61428 m
.1949 .61803 L
s
.22341 .61428 m
.22341 .61803 L
s
.25192 .61428 m
.25192 .61803 L
s
.28044 .61428 m
.28044 .61803 L
s
.33747 .61428 m
.33747 .61803 L
s
.36598 .61428 m
.36598 .61803 L
s
.3945 .61428 m
.3945 .61803 L
s
.42301 .61428 m
.42301 .61803 L
s
.48004 .61428 m
.48004 .61803 L
s
.50855 .61428 m
.50855 .61803 L
s
.53707 .61428 m
.53707 .61803 L
s
.56558 .61428 m
.56558 .61803 L
s
.62261 .61428 m
.62261 .61803 L
s
.65113 .61428 m
.65113 .61803 L
s
.67964 .61428 m
.67964 .61803 L
s
.70816 .61428 m
.70816 .61803 L
s
.76518 .61428 m
.76518 .61803 L
s
.7937 .61428 m
.7937 .61803 L
s
.82221 .61428 m
.82221 .61803 L
s
.85073 .61428 m
.85073 .61803 L
s
.90776 .61428 m
.90776 .61803 L
s
.93627 .61428 m
.93627 .61803 L
s
.96478 .61428 m
.96478 .61803 L
s
.9933 .61428 m
.9933 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08124 m
1 .08124 L
s
.99375 .21176 m
1 .21176 L
s
.99375 .34228 m
1 .34228 L
s
.99375 .4728 m
1 .4728 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .10734 m
1 .10734 L
s
.99625 .13345 m
1 .13345 L
s
.99625 .15955 m
1 .15955 L
s
.99625 .18566 m
1 .18566 L
s
.99625 .23786 m
1 .23786 L
s
.99625 .26397 m
1 .26397 L
s
.99625 .29007 m
1 .29007 L
s
.99625 .31618 m
1 .31618 L
s
.99625 .36838 m
1 .36838 L
s
.99625 .39449 m
1 .39449 L
s
.99625 .42059 m
1 .42059 L
s
.99625 .4467 m
1 .4467 L
s
.99625 .4989 m
1 .4989 L
s
.99625 .52501 m
1 .52501 L
s
.99625 .55111 m
1 .55111 L
s
.99625 .57721 m
1 .57721 L
s
.99625 .05514 m
1 .05514 L
s
.99625 .02903 m
1 .02903 L
s
.99625 .00293 m
1 .00293 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02951 .60332 Mdot
.03522 .5916 Mdot
.04092 .55736 Mdot
.04662 .50335 Mdot
.05232 .43385 Mdot
.05803 .35441 Mdot
.06373 .27135 Mdot
.06943 .19129 Mdot
.07514 .12061 Mdot
.08084 .06494 Mdot
.08654 .02871 Mdot
.09224 .01481 Mdot
.09795 .02434 Mdot
.10365 .05655 Mdot
.10935 .10887 Mdot
.11506 .17714 Mdot
.12076 .25591 Mdot
.12646 .33891 Mdot
.13216 .41953 Mdot
.13787 .49134 Mdot
.14357 .54863 Mdot
.14927 .58683 Mdot
.15498 .6029 Mdot
.16068 .59556 Mdot
.16638 .5654 Mdot
.17208 .51481 Mdot
.17779 .44782 Mdot
.18349 .36978 Mdot
.18919 .2869 Mdot
.1949 .20578 Mdot
.2006 .13288 Mdot
.2063 .07401 Mdot
.212 .03387 Mdot
.21771 .01564 Mdot
.22341 .02078 Mdot
.22911 .04888 Mdot
.23482 .0977 Mdot
.24052 .16336 Mdot
.24622 .24061 Mdot
.25192 .32332 Mdot
.25763 .40489 Mdot
.26333 .47882 Mdot
.26903 .53922 Mdot
.27474 .58128 Mdot
.28044 .60166 Mdot
.28614 .59872 Mdot
.29184 .57271 Mdot
.29755 .52569 Mdot
.30325 .46141 Mdot
.30895 .38498 Mdot
.31466 .30251 Mdot
.32036 .22056 Mdot
.32606 .14565 Mdot
.33177 .08375 Mdot
.33747 .0398 Mdot
.34317 .01729 Mdot
.34887 .01803 Mdot
.35458 .04194 Mdot
.36028 .08712 Mdot
.36598 .14998 Mdot
.37169 .22551 Mdot
.37739 .30769 Mdot
.38309 .38998 Mdot
.38879 .46582 Mdot
.3945 .52916 Mdot
.4002 .57497 Mdot
.4059 .59959 Mdot
.41161 .60106 Mdot
.41731 .57927 Mdot
.42301 .53595 Mdot
.42871 .47456 Mdot
.43442 .39997 Mdot
.44012 .31814 Mdot
.44582 .23558 Mdot
.45153 .15887 Mdot
.45723 .09413 Mdot
.46293 .04649 Mdot
.46863 .01977 Mdot
.47434 .01609 Mdot
.48004 .03575 Mdot
.48574 .07717 Mdot
.49145 .13706 Mdot
.49715 .21065 Mdot
.50285 .29207 Mdot
.50855 .37484 Mdot
.51426 .45237 Mdot
.51996 .51848 Mdot
.52566 .5679 Mdot
.53137 .5967 Mdot
.53707 .60258 Mdot
.54277 .58508 Mdot
.54847 .54558 Mdot
.55418 .48724 Mdot
.55988 .4147 Mdot
.56558 .33375 Mdot
.57129 .25082 Mdot
.57699 .17253 Mdot
.58269 .1051 Mdot
.58839 .05393 Mdot
.5941 .02307 Mdot
.5998 .01499 Mdot
.6055 .03033 Mdot
.61121 .06787 Mdot
.61691 .12462 Mdot
.62261 .19606 Mdot
.62831 .2765 Mdot
.63402 .35952 Mdot
.63972 .43852 Mdot
.64542 .50721 Mdot
.65113 .56011 Mdot
.65683 .593 Mdot
.66253 .60327 Mdot
.66823 .5901 Mdot
.67394 .55454 Mdot
.67964 .49942 Mdot
.68534 .42914 Mdot
.69105 .34928 Mdot
.69675 .26622 Mdot
.70245 .18656 Mdot
.70816 .11666 Mdot
.71386 .06208 Mdot
.71956 .02717 Mdot
.72526 .01472 Mdot
.73097 .0257 Mdot
.73667 .05926 Mdot
.74237 .1127 Mdot
.74808 .18179 Mdot
.75378 .26101 Mdot
.75948 .34406 Mdot
.76518 .42431 Mdot
.77089 .49538 Mdot
.77659 .5516 Mdot
.78229 .5885 Mdot
.788 .60313 Mdot
.7937 .59434 Mdot
.7994 .56281 Mdot
.8051 .51107 Mdot
.81081 .44323 Mdot
.81651 .3647 Mdot
.82221 .28174 Mdot
.82792 .20094 Mdot
.83362 .12876 Mdot
.83932 .07093 Mdot
.84502 .03207 Mdot
.85073 .01527 Mdot
.85643 .02187 Mdot
.86213 .05134 Mdot
.86784 .10134 Mdot
.87354 .16788 Mdot
.87924 .24566 Mdot
.88494 .32849 Mdot
.89065 .40977 Mdot
.89635 .48302 Mdot
.90205 .54241 Mdot
.90776 .58321 Mdot
.91346 .60216 Mdot
.91916 .59777 Mdot
.92486 .57036 Mdot
.93057 .52215 Mdot
.93627 .45695 Mdot
.94197 .37997 Mdot
.94768 .29733 Mdot
.95338 .21563 Mdot
.95908 .14136 Mdot
.96478 .08045 Mdot
.97049 .03775 Mdot
.97619 .01665 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00n`3oool0202oM00007Bo0?ooo`3oool0okmd0000000007@0_ooo[@3oool00?/0oooo00P0
okmd0000M02oool0oooo0;md0000M;l0oono07Ad_jd0oooo003k0?ooo`060?oOW01804P0W=oo0?oo
g`2LB000B9cO[`3oool00?/0oooo00H0oooO09a80000B7@0_knL04P0B02Lgon_0?ooo`00o03oool0
1@3OW4P004Qd07A8000007@0_ooo0:l0oooo003l0?ooo`050?noM00007@0_ooo0;md001d_ol0[`3o
ool00?`0oooo00H0oono07@0001d_ol0oooo0;mdB02Lgon^0?ooo`00o@3oool0102oM00007Bo0?oo
_`1d000200000003001d_`3oool0oooo0:X0oooo003m0?ooo`030?noM000B9`0gooo0;00oooo003m
0?ooo`030?oOW01804P0W=oo0;00oooo003m0?ooo`030?oog`2LB000B9cO0;00oooo003n0?ooo`03
0;md0000M;l0oooo0:l0oooo003l0?ooo`050?oog`2LB00000000000M02oool0[`3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool005d0oooo00@0_g@0000000000000M;oo9@3oool00`3OW4P00000000000030000000504RL
g`3oool0oooo0?oOW01800000P0000000`00B9`0gooo0?ooo`0P0?ooo`060?oOW018000000000000
0000B9`0gooo1@3oool0102oM00000000000001d_olR0?ooo`030?oo_`1dB9`0gooo00D0oooo00H0
omnL04P00000000000000018W03OoolL0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3o
ool00`3oool0102oM00000000000001d_ol50?ooo`040;md00000000000007BooaP0oooo00<0oono
07@0000000000P0000001@18W=l0oooo0?ooo`3oool0gia800D0000000D0B9cO0?ooo`3oool0omnL
04P00002000000030018W03Oool0oooo01L0oooo00<0oono07@0000000000P0000001P18W=l0oooo
0?ooo`3oool0omnL04P00080000000<004RL0=ooo`3oool0103oool0102oM00000000000001d_olW
0?ooo`00G03oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLgbD0oooo00<0okmd001d_`3oool00P3o
ool02@2oM7@0_ooo0?ooo`3o_g@0000007Boo`3oool0omnL04Qd_`0Q0?ooo`060?noM0000000M;oo
0?ooo`3ogi`0B7Bo103oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLgb80oooo00<0gia804RLg`3o
ool0103oool01P3o_g@0000007Boo`3oool0omnL04Qd_ah0oooo00<0okmd0000001d_ol01@3oool0
1P3OW4P007Bo0?ooo`3ogi`0B00004RLg`<0oooo00H0gia8001d_`3oool0omnL04P00018W=lI0?oo
o`030?noM0000000M;oo00D0oooo00<0okmd001d_`3oool00P3oool02@2oM7@0_ooo0?ooo`3o_g@0
000007Boo`3oool0omnL04Qd_`0J0?ooo`030?noM0000000M;oo00@0oooo00H0okmd0000001d_ol0
oooo0?oOW018M;l40?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO9P3oool005/0oooo00<0oooO
09a80018W=l00P3oool00`3o_g@0001809cOo`0U0?ooo`030?noM000M;l0oooo00T0oooo00<0okmd
04RLg`3oool0903oool01`3o_g@0B9cO0?ooo`3oool0oooO09a80018W=l00P3oool00`3o_g@00018
09cOo`0Q0?ooo`030?oo_`1d07@0_ooo00T0oooo00<0okmd04RLg`3oool0703oool00`3ooml0W4P0
001d_`040?ooo`030?oog`2LB000B9cO0080oooo00L0okmd0000B02Lgol0oooo0?oog`2LB000B9cO
0080oooo00<0okmd0000B02Lgol0603oool00`3ooml0W4P0001d_`060?ooo`030?noM000M;l0oooo
00T0oooo00<0okmd04RLg`3oool0603oool00`3ooml0W4P0001d_`090?ooo`070?noM018W=l0oooo
0?ooo`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo02D0oooo001K0?ooo`030?oog`2LB000
B9cO0080oooo00@0oooO09a80000B9`0gooo9@3oool00`3o_g@007Bo0?ooo`080?ooo`030?oo_`1d
07@0_ooo02@0oooo00L0oono07@0M02oool0oooo0?oog`2LB000B9cO0080oooo00@0oooO09a80000
B9`0gooo8@3oool00`3o_g@007Bo0?ooo`080?ooo`030?oo_`1d07@0_ooo01d0oooo00<0gia80018
W03Oool00`3oool00`3ooml0W4P004RLg`020?ooo`070?oog`2LB00004RL0=ooo`3ooml0W4P004RL
g`020?ooo`040?oog`2LB00004RL0=oooaP0oooo00<0gia80018W03Oool01P3oool00`3o_g@007Bo
0?ooo`080?ooo`030?oo_`1d07@0_ooo01T0oooo00<0gia80018W03Oool0203oool01`3ookl0M01d
0;ooo`3oool0oooO09a80018W=l00P3oool0103ooml0W4P00018W03OoolT0?ooo`00F`3oool00`3o
oml0W4P0001d_`030?ooo`030=nLB00004P0W=oo02H0oooo00<0okmd04RLg`3oool01`3oool00`3o
oml0W4P007Boo`0T0?ooo`070?oog`2LB000M;oo0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB000
04P0W=oo0240oooo00<0oooO09a8B02Lgol0203oool00`3ooml0W4P007Boo`0M0?ooo`030?oOW018
04P0W=oo00<0oooo00<0oooO09a80000M;l00`3oool01P3OW4P0001809cOo`3ooml0W4P0001d_`<0
oooo00<0gia80000B02Lgol0603oool00`3ogi`0B01809cOo`070?ooo`030?noM018W=l0oooo00L0
oooo00<0oooO09a8001d_ol06@3oool00`3ogi`0B01809cOo`080?ooo`070?oog`2LB000M;oo0?oo
o`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo02@0oooo001L0?ooo`030;md0000B9`0gooo
0080oooo00<0omnL04P00018W=l09`3oool00`3OW4P0B9cO0?ooo`060?ooo`030?oo_`1d0000B9cO
02@0oooo00<0oono07@00018W=l00P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO
0280oooo00<0omnL04Qd_`3oool01`3oool00`3ookl0M00004RLg`0M0?ooo`030?oo_`1d0000M;oo
00@0oooo00<0_g@00018W03Oool00P3oool01`3ogi`0B00004RLg`3oool0_g@00018W03Oool00P3o
ool00`3ogi`0B00004RLg`0H0?ooo`030?oo_`1d0000M;oo00P0oooo00<0gia804RLg`3oool01P3o
ool00`3ookl0M00004RLg`0I0?ooo`030?oo_`1d0000M;oo00P0oooo00<0oono07@00018W=l00P3o
ool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO02@0oooo001L0?ooo`030=nLB00004P0
W=oo0080oooo00<0oooO09a80000M;l0:03oool00`2oM000M;oo0?ooo`050?ooo`030?noM0000000
M;oo02@0oooo00<0okmd0000001d_ol00P3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB000
07Bo02<0oooo00<0_g@007Boo`3oool01P3oool00`3o_g@0000007Boo`0N0?ooo`030;md0000M;l0
oooo00<0oooo00<0gia80000B02Lgol00P3oool01`3ooml0W4P0001d_`3oool0gia80000B02Lgol0
0P3oool00`3ooml0W4P0001d_`0I0?ooo`030;md0000M;l0oooo00P0oooo00<0_g@007Boo`3oool0
1@3oool00`3o_g@0000007Boo`0J0?ooo`030;md0000M;l0oooo00L0oooo00<0okmd0000001d_ol0
0P3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo02@0oooo001L0?ooo`030?oOW018
0000B9cO00<0oooo00<0_g@00018W03Oool09`3oool00`3ogi`0B01d0;ooo`020?ooo`060?oOg`3O
ool0okmd0000000007@0_ooo8@3oool01P3ogml0gooo0?noM0000000001d0;ooo`80oooo00<0omnL
04P00018W=l00`3oool00`2oM00004RL0=ooo`0R0?ooo`030?oOW018B9`0gooo00<0oooo00H0omoO
0=ooo`3o_g@000000000M02ooolN0?ooo`030=nLB000B9`0gooo00<0oooo00<0omnL04P00018W=l0
0`3oool01P2oM00004RL0=ooo`3ogi`0B00004RLg`<0oooo00<0_g@00018W03Oool0603oool00`3O
W4P004RL0=ooo`080?ooo`030?oOW01807@0_ooo0080oooo00H0omoO0=ooo`3o_g@000000000M02o
oolJ0?ooo`030=nLB000B9`0gooo00@0oooo00H0omoO0=ooo`3o_g@000000000M02oool20?ooo`03
0?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool08`3oool005`0oooo00@0oooO09a80000B9`0
gooo0P3oool00`3OW4P004RL0=ooo`0W0?ooo`030?oog`2LB000M;oo0080oooo00D0oono07@00000
0000001809cOo`0R0?ooo`050?oo_`1d000000000000B02Lgol00`3oool0103ooml0W4P00018W03O
ool20?ooo`030=nLB000B9`0gooo02<0oooo00<0gia804RLg`3oool00P3oool01@3ookl0M0000000
000004P0W=oo01l0oooo00<0omnL04P0B02Lgol00`3oool0103ooml0W4P00018W03Oool20?ooo`07
0=nLB000B9`0gooo0?oog`2LB00004RL0=ooo`020?ooo`030=nLB000B9`0gooo01P0oooo00<0omnL
04P0B02Lgol0203oool00`3ooml0W4P007Boo`020?ooo`050?oo_`1d000000000000B02Lgol06`3o
ool00`3ogi`0B01809cOo`040?ooo`050?oo_`1d000000000000B02Lgol00`3oool0103ooml0W4P0
0018W03Oool20?ooo`030=nLB000B9`0gooo02<0oooo001M0?ooo`030?oOW0180000M;oo0080oooo
00<0gia8001d_`3oool09`3oool00`3ookl0M00004RLg`030?ooo`030=nLW02oool0oooo02@0oooo
00<0gibL0;ooo`3oool01@3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo01h0oooo
00<0oooO0=oOo`3oool00P3oool00`3ookl0M01d0;ooo`030?ooo`030=nLW02oool0oooo0200oooo
00<0oono07@0001d_ol0103oool00`3ogi`0B00007Boo`020?ooo`070=nLB000M;l0oooo0?ooo`3o
gi`0B00007Boo`020?ooo`030=nLB000M;l0oooo01P0oooo00<0oono07@0001d_ol0203oool00`3o
okl0M00004RLg`030?ooo`030=nLW02oool0oooo01`0oooo00<0oono07@0001d_ol01@3oool00`3O
W9`0_ooo0?ooo`050?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool08`3oool005h0
oooo00H0gia80000M02oool0oooO09a80018W=lT0?ooo`070?noM000B9`0gooo0?ooo`3OW4P00018
09cOo`030?ooo`030?oOW01dW=l0oooo02@0oooo00<0omnL07BLg`3oool01P3oool01P3OW4P0001d
0;ooo`3ooml0W4P004RLgb00oooo00<0_gAd0;ooo`3oool00P3oool00`3o_g@007Bo0?ooo`020?oo
o`030?oOW01dW=l0oooo0240oooo00<0_g@0001d_`3oool0103oool01P3OW4P0001d0;ooo`3ooml0
W4P004RLg`<0oooo00H0gia80000M02oool0oooO09a80018W=lJ0?ooo`030;md0000M;l0oooo00<0
oooo00L0okmd0018W03Oool0oooo0=nLB00004P0W=oo00<0oooo00<0omnL07BLg`3oool07@3oool0
0`2oM00007Bo0?ooo`040?ooo`030?oOW01dW=l0oooo00H0oooo00H0gia80000M02oool0oooO09a8
0018W=lT0?ooo`00G`3oool0103OW4P0000000000000M;lV0?ooo`050?oOW018000000000000001d
_ol01@3oool01@2oM0000000000000000000B9cO0280oooo00D0_g@0000000000000000004RLg`04
0?ooo`040=nLB00000000000001d_b40oooo00<0oono07@0000000000`0000000`0004P0W=oo0?oo
o`020?ooo`050;md00000000000000000018W=l0703oool01@3ookl0M0000000000007@0_ooo00D0
oooo00@0gia800000000000007Bo1@3oool0103OW4P0000000000000M;lI0?ooo`050?oo_`1d0000
00000000M02oool0103oool01@3ogi`0B000000000000000M;oo00D0oooo00D0_g@0000000000000
000004RLg`0H0?ooo`050?oo_`1d000000000000M02oool01@3oool01@2oM0000000000000000000
B9cO00@0oooo00@0gia800000000000007Bo9@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool005L0ooooo`00001B000000P0oooo001G0?ooo`8000001P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`070?ooo`<00000203oool005L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo00H0oooo001G0?ooo`030000003oool0oooo0?l0
ooooCP3oool00`000000oooo0?ooo`060?ooo`00E`3oool00`000000oooo0?ooo`3o0?ooodh0oooo
00<000000?ooo`3oool01P3oool005L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo001G0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0X0?ooo`800000:03oool00`000000oooo0000000Y
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool005L0oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`0V0?ooo`800000:03oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo05D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`060?oo
o`00E`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0NP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`060?ooo`00E`3oool00`000000oooo0?ooo`0I0?ooo`050000
003oool0oooo0?ooo`000000d03oool01@000000oooo0?ooo`3oool0000005X0oooo00<000000?oo
o`3oool01P3oool005L0oooo0P00000J0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0340oooo0P0000080?ooo`00
E`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00H0oooo001G0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`2Q0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01P3oool005L0oooo00<000000?ooo`3oool0KP3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`060?ooo`00E`3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`060?ooo`00E`3oool00`000000
oooo0?ooo`1c0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0/P3oool00`000000
oooo0?ooo`060?ooo`00E`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`060?ooo`00E`3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`060?ooo`00E`3oool200000<<0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0[
0?ooo`800000203oool005L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`2P0?oo
o`030000003oool0oooo08P0oooo00<000000?ooo`3oool01P3oool005L0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool01P3oool005L0oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool01P3oool003/0oooo00@0_g@0000000000000M;oo
0`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB0000000000000<0000000<0B9cO0?ooo`3oool0
1`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool0
GP3oool00`000000oooo0?ooo`060?ooo`00>P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80
oooo00<0omnL04P0001d_ol00`3oool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02oool0oooo00L0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo0800
oooo00<000000?ooo`3oool01P3oool003T0oooo00<0oooO09a80018W=l00P3oool00`3o_g@00018
09cOo`080?ooo`030?noM000M;l0oooo00/0oooo00<000000?ooo`3oool0bP3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool01P3oool003T0oooo00<0
oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool80?ooo`030?noM000M;l0oooo00X0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool01P3oool002`0oooo00<0oooO09a8000000001`0000001P18W=l0oooo0?oo
o`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol02@3oool00`3o_g@0B9cO0?ooo`090?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`2[0?ooo`03
0000003oool0oooo00H0oooo000j0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0
2P3oool00`3OW4P0B9cO0?ooo`080?ooo`<00000W`3oool00`000000oooo0?ooo`2O0?ooo`030000
003oool0oooo00L0oooo0`0000080?ooo`00>P3oool00`3OW4P0001809cOo`020?ooo`030?oog`2L
B00007Bo00/0oooo00<0_g@007Boo`3oool01`3oool00`000000oooo0?ooo`1/0?ooo`030000003o
ool0oooo0=80oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`00>P3oool0
0`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00X0oooo00<0omnL04P0M02oool01`3oool0
0`000000oooo0?ooo`1/0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`060?ooo`00>P3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0
gooo00X0oooo00<0oooO09a8001d_ol01`3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0
oooo0=D0oooo00<000000?ooo`3oool01P3oool003/0oooo00<0omnL04P0001d_ol00P3oool00`3O
W4P007Bo0?ooo`0:0?ooo`030?oo_`1d0000B9cO00L0oooo00<000000?ooo`3oool0UP3oool00`00
0000oooo0?ooo`2d0?ooo`030000003oool0oooo00H0oooo000l0?ooo`060=nLB00007@0_ooo0?oo
g`2LB000B9cO1`3oool01`3o_g@004RL0=ooo`3oool0gia80000B02Lgol01`3oool00`000000oooo
0?ooo`2F0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool01P3oool003d0oooo00@0
gia800000000000007Bo2@3oool01@3ogi`0B000000000000000M;oo00P0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`3o0?ooo`030000003oool0oooo00H0oooo001G0?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo00H0oooo001G0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00H0oooo001G0?ooo`8000008P3oool0
0`000000oooo0?ooo`2L0?ooo`030000003oool0oooo08T0oooo0P0000080?ooo`00E`3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0oooo:P3oool00`000000oooo0?ooo`060?oo
o`00E`3oool00`000000oooo0?ooo`3f0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool01P3oool005L0oooo00<000000?ooo`3oool0jP3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool01P3oool005L0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool01P3o
ool005L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3o0?ooocH0oooo00<00000
0?ooo`3oool01P3oool005L0oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo00H0oooo001G0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00H0oooo001G0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo00H0oooo001G0?ooo`800000@@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo0P00
00080?ooo`00E`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo0:T0oooo00<00000
0?ooo`3oool01P3oool005L0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`2K0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool005L0oooo00<000000?ooo`3o
ool0o`3ooom00?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool005L0oooo
00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo00H0oooo
001G0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`3C0?ooo`030000003oool0oooo00H0oooo001G0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool0d`3oool00`000000oooo0?ooo`060?ooo`00E`3oool00`000000oooo0?ooo`3o0?oo
odh0oooo00<000000?ooo`3oool01P3oool005L0oooo00<000000?ooo`3oool0U03oool00`000000
oooo0?ooo`2f0?ooo`030000003oool0oooo00H0oooo001G0?ooo`800000U@3oool00`000000oooo
0?ooo`2e0?ooo`800000203oool005L0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`3m0?ooo`030000003oool0oooo00H0oooo001G0?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool0dP3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00H0oooo001G0?oo
o`030000003oool0oooo0?l0oooo8`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00H0oooo001G0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0S03oool00`000000
oooo0?ooo`060?ooo`00E`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo09P0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`060?ooo`00E`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo0?l0oooo:03oool00`000000oooo0?ooo`060?ooo`00E`3oool0
0`000000oooo0?ooo`3h0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool01P3oool0
05L0oooo0P00003Y0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0D@3oool20000
00P0oooo001G0?ooo`030000003oool0oooo0>P0oooo00<000000?ooo`3oool0HP3oool00`000000
oooo0?ooo`060?ooo`00E`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0oooo
=`3oool00`000000oooo0?ooo`060?ooo`00E`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo0?l0oooo=`3oool00`000000oooo0?ooo`060?ooo`00<P3oool0102oM00000000000001d
_ol30?ooo`030?oOW0180000M;oo0080oooo00<0oono07@0000000000P0000001P18W=l0oooo0?oo
o`3oool0omnL04P00080000000<004RL0=ooo`3oool02@3oool00`000000oooo0?ooo`3>0?ooo`03
0000003oool0oooo07`0oooo00<000000?ooo`3oool01P3oool00340oooo00H0gia8001d_`3oool0
omnL04P00018W=l20?ooo`030?oOW0180000M;oo00@0oooo00<0okmd0000001d_ol0103oool01P3o
_g@0000007Boo`3oool0omnL04Qd_`X0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool01P3oool00300oooo00<0oooO
09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?oog`2LB00007Bo00T0oooo00<0okmd
04RLg`3oool0203oool00`000000oooo0?ooo`3o0?oooa@0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`060?ooo`00<03oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL
0=ooo`P0oooo00<0gia80018W03Oool0203oool00`3ookl0M01d0;ooo`080?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool0o`3oool=0?ooo`030000003oool0oooo00H0oooo000S0?oo
o`030?oog`2LB000000000L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`030=nLB000
04P0W=oo00P0oooo00<0omnL04P0B02Lgol0203oool00`3ooml0W4P007Boo`080?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool0o`3oool=0?ooo`030000003oool0oooo00H0oooo000a
0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0203oool00`3ookl0M00007Boo`08
0?ooo`030?oo_`1d0000B9cO00P0oooo0`00002S0?ooo`030000003oool0oooo0:D0oooo0`000008
0?ooo`00<@3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00T0oooo00<0_g@0001d
_`3oool01`3oool00`3o_g@0000007Boo`080?ooo`030000003oool0oooo0:<0oooo00<000000?oo
o`3oool0U`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo000a0?ooo`03
0?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool0203oool00`3OW4P004RL0=ooo`040?ooo`06
0?oOg`3Oool0okmd0000000007@0_ooo203oool00`000000oooo0?ooo`3o0?oooch0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`00<@3oool0103ooml0W4P00018W03Oool2
0?ooo`030=nLB000B9`0gooo00P0oooo00<0omnL04P0B02Lgol0103oool01@3ookl0M00000000000
04P0W=oo00T0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`3R0?ooo`030000003o
ool0oooo00H0oooo000b0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0203oool0
0`3ookl0M00007Boo`050?ooo`030=nLW02oool0oooo00X0oooo00<000000?ooo`3oool0J03oool0
0`000000oooo0?ooo`3R0?ooo`030000003oool0oooo00H0oooo000c0?ooo`060=nLB00007@0_ooo
0?oog`2LB000B9cO2P3oool00`2oM00007Bo0?ooo`040?ooo`030?oOW01dW=l0oooo00X0oooo00<0
00000?ooo`3oool0N@3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00H0oooo000d
0?ooo`040=nLB00000000000001d_`T0oooo00D0oono07@000000000001d0;ooo`050?ooo`050;md
00000000000000000018W=l01`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0=40
oooo00<000000?ooo`3oool01P3oool005L0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000
003oool0oooo00H0oooo001G0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0^03o
ool00`000000oooo0?ooo`060?ooo`00E`3oool2000009<0oooo00<000000?ooo`3oool0]`3oool2
000000P0oooo001G0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0n`3oool00`00
0000oooo0?ooo`060?ooo`00E`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0=80
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`060?ooo`00E`3oool00`000000oooo
0?ooo`3o0?ooobD0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`060?ooo`00E`3o
ool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool01P3o
ool005L0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo00H0oooo001G0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0o`3ooolV0?oo
o`030000003oool0oooo00H0oooo001G0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0dP3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00H0oooo001G0?ooo`030000
003oool0oooo0?X0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`060?ooo`00E`3o
ool200000>L0oooo00<000000?ooo`3oool0H`3oool2000000P0oooo001G0?ooo`030000003oool0
oooo0>H0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`060?ooo`00E`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`060?oo
o`005P3oool00`3OW4P0001d0;ooo`0n0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0o`3oooli0?ooo`030000003oool0oooo00H0oooo000?0?ooo`030?oo_`1dM;l0oooo00@0oooo
00<0oono07A8W03Oool0?P3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo07/0oooo
00<000000?ooo`3oool01P3oool000l0oooo00<0omnL04P0M02oool00`3oool00`3o_g@0001d0;oo
o`0o0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo00H0oooo000?0?ooo`070?oOW018000000000000B02Lgol0omnL
04Qd_`110?ooo`030000003oool0oooo0?l0oooo4P3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo00H0oooo000A0?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0?l0oooo3`3oool00`000000oooo0?oo
o`060?ooo`00403oool02@3ookl0M01d0;ooo`3oool0oooO09a800000000001d0;ooo`0n0?ooo`80
0000?@3oool00`000000oooo0?ooo`3o0?ooo`h0oooo0P0000080?ooo`003`3oool00`3ookl0M01d
0;ooo`040?ooo`030?oOW018M;l0oooo03h0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo
0?ooo`2U0?ooo`030000003oool0oooo00H0oooo000?0?ooo`030?noM0000000M;oo00<0oooo00<0
oono07A8W03Oool0?`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo0:D0oooo00<0
00000?ooo`3oool01P3oool005L0oooo00<000000?ooo`3oool0o`3oooll0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool01P3oool001T0oooo00<0omnL04Q8W03Oool0>`3oool00`00
0000oooo0?ooo`1V0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`060?ooo`006@3oool00`3ookl0M01d0;ooo`0k0?ooo`030000003oool0oooo06H0
oooo00<000000?ooo`3oool0i03oool00`000000oooo0?ooo`060?ooo`004P3oool01P3ooml0W4Qd
0;ooo`3ooml0W7BL0=ooo`80oooo00<0_ibL0=ooo`3oool0>P3oool00`000000oooo0?ooo`1k0?oo
o`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01P3oool00180oooo00T0gia807Boo`3o
ool0gia80000001d_ol0oooo0=nLB018W=l0?03oool00`000000oooo0?ooo`1k0?ooo`030000003o
ool0oooo0<l0oooo00<000000?ooo`3oool01P3oool00180oooo00D0giad09cOo`3ogi`0M9cO0=nL
B0020000000304RLg`3oool0oooo03/0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003o
ool0oooo00H0oooo000B0?ooo`040?oOW018000004RL0=oood40oooo0P00003o0?ooodh0oooo0P00
00080?ooo`00E`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0;X0oooo00<00000
0?ooo`3oool01P3oool005L0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo0;X0oooo00<000000?ooo`3oool01P3oool005L0oooo00<000000?ooo`3o
ool0D@3oool00`000000oooo0?ooo`3i0?ooo`030000003oool0oooo00H0oooo000H0?ooo`040?no
M0000000001d0;oooal0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?oo
o`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oo
obL0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`060?ooo`004@3oool0103ooml0
W9bo0?oog`2LB00300000003001d_`3oool0oooo01l0oooo00H0gia8001d_`3oool0omnL04P00018
W=l20?ooo`030?oOW0180000M;oo00@0oooo00<0okmd0000001d_ol02`3oool00`000000oooo0?oo
o`3o0?ooobL0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`060?ooo`004@3oool0
103ookl0M0000000B02Lgol20?ooo`030;nLW03Oool0oooo01l0oooo00<0oooO09a80018W=l00P3o
ool00`3o_g@0001809cOo`080?ooo`030?oog`2LB00007Bo00/0oooo00<000000?ooo`3oool0^P3o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050=oOg`2oM000
000000000000M;l07`3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo
00<0gia80018W03Oool02P3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo0900oooo
00<000000?ooo`3oool01P3oool001@0oooo00<0oooO09a8001d_ol00P3oool00`3OW4P0001d0;oo
o`0@0?ooo`030?oog`2LB000000000L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`03
0=nLB00004P0W=oo00P0oooo00<0omnL04P0B02Lgol02P3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`060?ooo`00503oool00`3ooml0W7BL
0=ooo`020?ooo`030=nLM02Lgol0oooo01h0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B000
04RLg`080?ooo`030?oo_`1d0000M;oo00X0oooo0`00000W0?ooo`030000003oool0oooo0=80oooo
00<000000?ooo`3oool0C03oool3000000P0oooo000j0?ooo`030=nLB00004P0W=oo0080oooo00<0
oooO09a80000M;l02@3oool00`2oM00007Bo0?ooo`090?ooo`030000003oool0oooo0?`0oooo00<0
00000?ooo`3oool0CP3oool00`000000oooo0?ooo`060?ooo`00>P3oool00`3ogi`0B00004RLg`03
0?ooo`030;md0000B9`0gooo00P0oooo00<0gia80018W03Oool02@3oool00`000000oooo0?ooo`3U
0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool01P3oool003X0oooo00@0oooO09a8
0000B9`0gooo0P3oool00`3OW4P004RL0=ooo`080?ooo`030?oOW01804P0W=oo00T0oooo00<00000
0?ooo`3oool0i@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00H0oooo000k0?oo
o`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0203oool00`3ookl0M00007Boo`090?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0o`3ooolk0?ooo`030000003oool0oooo
00H0oooo000l0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO2P3oool00`2oM00007Bo0?ooo`08
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0o`3ooolk0?ooo`030000003oool0
oooo00H0oooo000m0?ooo`040=nLB00000000000001d_`T0oooo00D0oono07@000000000001d0;oo
o`080?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`060?ooo`00E`3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`060?ooo`00E`3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`060?ooo`00E`3oool2000003/0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`800000203oool005L0oooo00<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`3o0?oooa40oooo00<000000?ooo`3oool01P3oool005L0oooo00<0
00000?ooo`3oool0Y`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo00H0oooo001G
0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00H0oooo001G0?ooo`030000003oool0oooo0?l0oooo>P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo001G0?ooo`030000003oool0oooo06@0
oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`060?ooo`00E`3oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo0>H0oooo00<000000?ooo`3oool01P3oool005L0oooo00<0
00000?ooo`3oool0O@3oool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo00H0oooo001G
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`06
0?ooo`00E`3oool200000?l0ooooCP3oool2000000P0oooo001G0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`060?ooo`00E`3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool01P3oool005L0oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`3g0?ooo`030000003oool0oooo00H0oooo001G
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00H0oooo001G0?ooo`030000003oool0oooo0?l0oooo:@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00H0oooo001G0?ooo`030000003oool0oooo0;P0
oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`060?ooo`00E`3oool00`000000oooo
0?ooo`2h0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool01P3oool005L0oooo0P00
000Z0?ooo`030000003oool0oooo0?l0oooo8@3oool2000000P0oooo001G0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0
oooo00H0oooo001G0?ooo`030000003oool0oooo0?d0oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`060?ooo`00E`3oool00`000000oooo0?ooo`3S0?ooo`030000003oool0oooo06L0
oooo00<000000?ooo`3oool01P3oool005L0oooo00<000000?ooo`3oool0h`3oool00`000000oooo
0?ooo`1W0?ooo`030000003oool0oooo00H0oooo001G0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0o`3ooolm0?ooo`030000003oool0oooo00H0oooo001G0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo00H0oooo001G0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`060?ooo`00E`3oool00`000000oooo0?ooo`3o0?ooo`h0oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`060?ooo`00E`3oool2000003T0oooo00<000000?ooo`3oool0
dP3oool00`000000oooo0?ooo`0l0?ooo`800000203oool005L0oooo00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`3o0?oooa<0oooo00<000000?ooo`3oool01P3oool005L0oooo00<00000
0?ooo`3oool0Z@3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo00H0oooo001G0?oo
o`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00H0oooo000b0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0
001d_ol0103oool0102oM00000000000001d_ol30?ooo`060?oOW0180000000000000000B9`0gooo
2P3oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`060?ooo`00<@3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d
_ol00`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00H0okmd0000001d_ol0oooo0?oO
W018M;l:0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0j03oool00`000000oooo
0?ooo`060?ooo`00<03oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00H0oooo00<0
oooO09a80018W=l00P3oool00`3o_g@0001809cOo`060?ooo`030?noM018W=l0oooo00P0oooo00<0
00000?ooo`3oool0HP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0</0oooo00<0
00000?ooo`3oool01P3oool00300oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03O
ool50?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo1@3oool00`3ookl0M01d
0;ooo`080?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0b`3oool00`000000oooo
0?ooo`060?ooo`008`3oool00`3ooml0W4P0000000070000000604RLg`3oool0oooo0?oog`2LB000
07Bo0`3oool00`3OW4P0001809cOo`050?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02L
gol01@3oool00`3ooml0W4P007Boo`080?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000
oooo0?ooo`060?ooo`00<@3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00H0oooo
00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`050?ooo`030?oo_`1d0000B9cO00P0oooo
0`00002<0?ooo`030000003oool0oooo0;`0oooo0`0000080?ooo`00<@3oool00`3OW4P0001809cO
o`020?ooo`030?oog`2LB00007Bo00H0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d
_`050?ooo`030?noM0000000M;oo00P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?oo
o`2n0?ooo`030000003oool0oooo00H0oooo000a0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@0
0018W03Oool01@3oool00`3ogi`0B00004RLg`030?ooo`0:0;md0000B9`0gooo0?ooo`3ogml0gooo
0?noM0000000001d0;ooo`P0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`3e0?oo
o`030000003oool0oooo00H0oooo000a0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018
W03Oool01@3oool0103ooml0W4P00018W03Oool20?ooo`090=nLB000B9`0gooo0?ooo`3ookl0M000
0000000004P0W=oo00T0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`3B0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool01P3oool00380oooo00<0omnL04P0001d_ol0
0P3oool00`3OW4P007Bo0?ooo`060?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0
0P3oool00`3OW9`0_ooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo:`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00H0oooo000c0?ooo`060=nLB00007@0_ooo0?oog`2LB000
B9cO203oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`<0oooo00<0omnL07BLg`3oool02P3oool0
0`000000oooo0?ooo`2f0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool01P3oool0
03@0oooo00@0gia800000000000007Bo2P3oool0103OW4P0000000000000M;l50?ooo`050;md0000
0000000000000018W=l01`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo08P0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`060?ooo`00E`3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`060?ooo`00E`3oool00`000000oooo0?ooo`3o0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool01P3oool005L0oooo0P00003R0?ooo`030000003oool0oooo06P0oooo0P0000080?oo
o`00E`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3o
ool0J@3oool00`000000oooo0?ooo`060?ooo`00E`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0<H0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`060?ooo`00E`3o
ool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool01P3o
ool005L0oooo00<000000?ooo`3oool0o`3oool<0?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool01P3oool005L0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`3B0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool01P3oool005L0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3o
ool01P3oool005L0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`270?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool01P3oool005L0oooo0P00001Q0?ooo`030000003o
ool0oooo0=80oooo00<000000?ooo`3oool0503oool2000000P0oooo001G0?ooo`030000003oool0
oooo0600oooo00<000000?ooo`3oool0jP3oool00`000000oooo0?ooo`060?ooo`00E`3oool00`00
0000oooo0?ooo`210?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool01P3oool005L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00H0
oooo001G0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0`03oool00`000000oooo
0?ooo`060?ooo`00E`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool0`03oool00`000000oooo0?ooo`060?ooo`00E`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`06
0?ooo`00E`3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`060?ooo`00E`3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`060?ooo`00
E`3oool2000002d0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`180?ooo`800000
203oool005L0oooo00<000000?ooo`3oool0g`3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool01P3oool005L0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`3B0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool01P3oool0
05L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
07<0oooo00<000000?ooo`3oool01P3oool005L0oooo00<000000?ooo`3oool0e`3oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool01P3oool005L0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool01P3oool005L0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`060?ooo`00E`3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo04`0oooo00<00000
0?ooo`3oool0P`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00H0oooo001G0?oo
o`030000003oool0oooo05h0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`370?oo
o`030000003oool0oooo00H0oooo001G0?ooo`800000Q03oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0<40oooo0P0000080?ooo`00E`3oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`060?ooo`00E`3o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo001G0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool01P3oool004T0oooo00@0_g@0000000000000M;oo2P3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo00H0oooo00180?ooo`060=nLB000M;l0oooo
0?oOW0180000B9cO2@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0<h0oooo00D0
00000?ooo`3oool0oooo0000000U0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0
1P3oool004L0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo00H0oooo00170?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo1`3o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo00170?ooo`030?oog`2LB000
07Bo00<0oooo00<0gia80000B02Lgol01`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`000000:03oool00`000000oooo0000000Y0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool09`3oool00`000000oooo0000000K0?ooo`030000003oool0
oooo00H0oooo00180?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01`3oool30000
00H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0I0?ooo`<00000203oool004P0
oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`070?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00H0
oooo00180?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool01P3oool004P0oooo00@0oooO09a80000B9`0gooo
0P3oool00`3OW4P004RL0=ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo000000080?ooo`00B@3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000
M;l0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0000000P0oooo001:0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO1`3ooooo000005800000
203oool004/0oooo00@0gia800000000000007Boo`3ooomR0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-49.8025, -0.289535, \
0.782324, 0.00170912}}]
}, Closed]],

Cell[TextData[{
  " Although each of these curves appears to be sinusoidal, the interleaving \
of three such curves makes the mapping from ",
  Cell[BoxData[
      \(TraditionalForm\`x\_k\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(k + 1\)\)]],
  " very complicated \[LongDash] we know that the pairs ",
  Cell[BoxData[
      \(TraditionalForm\`{x\_k, x\_\(k + 1\)}\)]],
  " fall on a simple curve but they hop around that curve almost \
unpredictably.  If we take enough samples, this ellipse will eventually fill \
in.  We leave the interesting question of whether this Poincar\[EAcute] map \
is truly continuous in the limit ",
  Cell[BoxData[
      \(TraditionalForm\`t \[Rule] \[Infinity]\)]],
  " to mathematicians.  This question cannot be answered by numerical \
simulation and requires more sophisticated mathematical analysis."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Partition[First /@ pts, 2], AspectRatio \[Rule] Automatic, 
        Frame \[Rule] True, 
        FrameLabel \[Rule] {\*"\"\<\!\(x\_k\)\>\"", \*"\"\<\!\(x\_\(k + 1\)\)\
\>\""}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.97619 4.22371 0.976192 4.22371 [
[.13145 -0.0125 -13.8438 -15.6875 ]
[.13145 -0.0125 13.8438 0 ]
[.34263 -0.0125 -16.8438 -15.6875 ]
[.34263 -0.0125 16.8438 0 ]
[.55382 -0.0125 -13.8438 -15.6875 ]
[.55382 -0.0125 13.8438 0 ]
[.76501 -0.0125 -16.8438 -15.6875 ]
[.76501 -0.0125 16.8438 0 ]
[.97619 -0.0125 -5 -15.6875 ]
[.97619 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -7.125 -31.375 ]
[.5 -0.0125 7.125 -15.6875 ]
[-0.0125 .13145 -27.6875 -7.84375 ]
[-0.0125 .13145 0 7.84375 ]
[-0.0125 .34264 -33.6875 -7.84375 ]
[-0.0125 .34264 0 7.84375 ]
[-0.0125 .55382 -27.6875 -7.84375 ]
[-0.0125 .55382 0 7.84375 ]
[-0.0125 .76501 -33.6875 -7.84375 ]
[-0.0125 .76501 0 7.84375 ]
[-0.0125 .97619 -10 -7.84375 ]
[-0.0125 .97619 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -49.375 -12.1563 ]
[-0.01875 .5 -33.6875 12.1563 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13145 0 m
.13145 .00625 L
s
gsave
.13145 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.34263 0 m
.34263 .00625 L
s
gsave
.34263 -0.0125 -77.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
.55382 0 m
.55382 .00625 L
s
gsave
.55382 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.76501 0 m
.76501 .00625 L
s
gsave
.76501 -0.0125 -77.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
.17369 0 m
.17369 .00375 L
s
.21592 0 m
.21592 .00375 L
s
.25816 0 m
.25816 .00375 L
s
.3004 0 m
.3004 .00375 L
s
.38487 0 m
.38487 .00375 L
s
.42711 0 m
.42711 .00375 L
s
.46935 0 m
.46935 .00375 L
s
.51158 0 m
.51158 .00375 L
s
.59606 0 m
.59606 .00375 L
s
.63829 0 m
.63829 .00375 L
s
.68053 0 m
.68053 .00375 L
s
.72277 0 m
.72277 .00375 L
s
.80724 0 m
.80724 .00375 L
s
.84948 0 m
.84948 .00375 L
s
.89172 0 m
.89172 .00375 L
s
.93395 0 m
.93395 .00375 L
s
.08921 0 m
.08921 .00375 L
s
.04697 0 m
.04697 .00375 L
s
.00474 0 m
.00474 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -68.125 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 17.688 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
73.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .13145 m
.00625 .13145 L
s
gsave
-0.0125 .13145 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .34264 m
.00625 .34264 L
s
gsave
-0.0125 .34264 -94.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
0 .55382 m
.00625 .55382 L
s
gsave
-0.0125 .55382 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .76501 m
.00625 .76501 L
s
gsave
-0.0125 .76501 -94.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
0 .97619 m
.00625 .97619 L
s
gsave
-0.0125 .97619 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .17369 m
.00375 .17369 L
s
0 .21592 m
.00375 .21592 L
s
0 .25816 m
.00375 .25816 L
s
0 .3004 m
.00375 .3004 L
s
0 .38487 m
.00375 .38487 L
s
0 .42711 m
.00375 .42711 L
s
0 .46935 m
.00375 .46935 L
s
0 .51158 m
.00375 .51158 L
s
0 .59606 m
.00375 .59606 L
s
0 .63829 m
.00375 .63829 L
s
0 .68053 m
.00375 .68053 L
s
0 .72277 m
.00375 .72277 L
s
0 .80724 m
.00375 .80724 L
s
0 .84948 m
.00375 .84948 L
s
0 .89172 m
.00375 .89172 L
s
0 .93395 m
.00375 .93395 L
s
0 .08921 m
.00375 .08921 L
s
0 .04698 m
.00375 .04698 L
s
0 .00474 m
.00375 .00474 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -114.688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
73.1563 11.8438 translate
90 rotate
-73.1563 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 17.688 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
72.750 17.688 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
78.500 17.688 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
83.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.13145 .99375 m
.13145 1 L
s
.34263 .99375 m
.34263 1 L
s
.55382 .99375 m
.55382 1 L
s
.76501 .99375 m
.76501 1 L
s
.97619 .99375 m
.97619 1 L
s
.125 Mabswid
.17369 .99625 m
.17369 1 L
s
.21592 .99625 m
.21592 1 L
s
.25816 .99625 m
.25816 1 L
s
.3004 .99625 m
.3004 1 L
s
.38487 .99625 m
.38487 1 L
s
.42711 .99625 m
.42711 1 L
s
.46935 .99625 m
.46935 1 L
s
.51158 .99625 m
.51158 1 L
s
.59606 .99625 m
.59606 1 L
s
.63829 .99625 m
.63829 1 L
s
.68053 .99625 m
.68053 1 L
s
.72277 .99625 m
.72277 1 L
s
.80724 .99625 m
.80724 1 L
s
.84948 .99625 m
.84948 1 L
s
.89172 .99625 m
.89172 1 L
s
.93395 .99625 m
.93395 1 L
s
.08921 .99625 m
.08921 1 L
s
.04697 .99625 m
.04697 1 L
s
.00474 .99625 m
.00474 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .13145 m
1 .13145 L
s
.99375 .34264 m
1 .34264 L
s
.99375 .55382 m
1 .55382 L
s
.99375 .76501 m
1 .76501 L
s
.99375 .97619 m
1 .97619 L
s
.125 Mabswid
.99625 .17369 m
1 .17369 L
s
.99625 .21592 m
1 .21592 L
s
.99625 .25816 m
1 .25816 L
s
.99625 .3004 m
1 .3004 L
s
.99625 .38487 m
1 .38487 L
s
.99625 .42711 m
1 .42711 L
s
.99625 .46935 m
1 .46935 L
s
.99625 .51158 m
1 .51158 L
s
.99625 .59606 m
1 .59606 L
s
.99625 .63829 m
1 .63829 L
s
.99625 .68053 m
1 .68053 L
s
.99625 .72277 m
1 .72277 L
s
.99625 .80724 m
1 .80724 L
s
.99625 .84948 m
1 .84948 L
s
.99625 .89172 m
1 .89172 L
s
.99625 .93395 m
1 .93395 L
s
.99625 .08921 m
1 .08921 L
s
.99625 .04698 m
1 .04698 L
s
.99625 .00474 m
1 .00474 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.97619 .30182 Mdot
.18872 .95722 Mdot
.4307 .10043 Mdot
.90183 .56511 Mdot
.04395 .81443 Mdot
.69432 .02381 Mdot
.70198 .80805 Mdot
.0416 .57345 Mdot
.89725 .0959 Mdot
.43905 .9548 Mdot
.18239 .30952 Mdot
.97612 .29419 Mdot
.19515 .95951 Mdot
.42237 .10507 Mdot
.90629 .55674 Mdot
.04645 .82072 Mdot
.68659 .02396 Mdot
.70959 .80158 Mdot
.03939 .58176 Mdot
.89254 .0915 Mdot
.44742 .95223 Mdot
.17616 .31727 Mdot
.97589 .28662 Mdot
.20168 .96165 Mdot
.41407 .10985 Mdot
.91063 .54836 Mdot
.04909 .8269 Mdot
.67881 .02426 Mdot
.71712 .79501 Mdot
.03732 .59006 Mdot
.8877 .08724 Mdot
.45581 .94952 Mdot
.17003 .32509 Mdot
.97552 .27911 Mdot
.2083 .96364 Mdot
.40579 .11474 Mdot
.91483 .53997 Mdot
.05187 .83298 Mdot
.67096 .02471 Mdot
.72459 .78834 Mdot
.0354 .59832 Mdot
.88275 .0831 Mdot
.46421 .94666 Mdot
.164 .33296 Mdot
.975 .27168 Mdot
.21501 .96549 Mdot
.39754 .11976 Mdot
.91891 .53156 Mdot
.0548 .83895 Mdot
.66307 .0253 Mdot
.73199 .78159 Mdot
.03362 .60655 Mdot
.87767 .07909 Mdot
.47263 .94367 Mdot
.15808 .34088 Mdot
.97433 .26432 Mdot
.22181 .9672 Mdot
.38932 .12489 Mdot
.92285 .52315 Mdot
.05786 .84482 Mdot
.65512 .02605 Mdot
.73932 .77474 Mdot
.03199 .61475 Mdot
.87248 .07521 Mdot
.48105 .94054 Mdot
.15227 .34885 Mdot
.97351 .25703 Mdot
.22869 .96875 Mdot
.38114 .13015 Mdot
.92666 .51472 Mdot
.06106 .85058 Mdot
.64713 .02694 Mdot
.74657 .76781 Mdot
.0305 .62292 Mdot
.86716 .07147 Mdot
.48947 .93727 Mdot
.14656 .35687 Mdot
.97254 .24982 Mdot
.23566 .97017 Mdot
.37299 .13552 Mdot
.93034 .50629 Mdot
.0644 .85623 Mdot
.63909 .02798 Mdot
.75374 .7608 Mdot
.02917 .63104 Mdot
.86174 .06786 Mdot
.4979 .93386 Mdot
.14097 .36493 Mdot
.97142 .24268 Mdot
.24272 .97143 Mdot
.36489 .141 Mdot
.93388 .49786 Mdot
.06787 .86177 Mdot
.631 .02917 Mdot
.76084 .75371 Mdot
.02798 .63913 Mdot
.8562 .06438 Mdot
.50634 .93032 Mdot
.13549 .37304 Mdot
.97016 .23563 Mdot
.24985 .97254 Mdot
.35683 .14659 Mdot
.93729 .48943 Mdot
.07148 .86719 Mdot
.62288 .03051 Mdot
.76785 .74653 Mdot
.02694 .64717 Mdot
.85055 .06104 Mdot
.51476 .92664 Mdot
.13012 .38118 Mdot
.96875 .22866 Mdot
.25706 .97351 Mdot
.34881 .1523 Mdot
.94055 .481 Mdot
.07523 .8725 Mdot
.61471 .032 Mdot
.77478 .73928 Mdot
.02604 .65517 Mdot
.84479 .05784 Mdot
.52319 .92283 Mdot
.12487 .38937 Mdot
.96719 .22177 Mdot
.26435 .97433 Mdot
.34084 .15811 Mdot
.94369 .47258 Mdot
.07911 .8777 Mdot
.60651 .03363 Mdot
.78162 .73195 Mdot
.0253 .66311 Mdot
.83892 .05478 Mdot
.53161 .91889 Mdot
.11973 .39758 Mdot
.96548 .21497 Mdot
.27172 .975 Mdot
.33292 .16404 Mdot
.94668 .46417 Mdot
.08312 .88277 Mdot
.59828 .03541 Mdot
.78838 .72455 Mdot
.0247 .67101 Mdot
.83294 .05186 Mdot
.54001 .91481 Mdot
.11472 .40583 Mdot
.96363 .20826 Mdot
.27915 .97552 Mdot
.32505 .17007 Mdot
.94953 .45577 Mdot
.08726 .88773 Mdot
.59001 .03733 Mdot
.79504 .71709 Mdot
.02426 .67885 Mdot
.82686 .04908 Mdot
.54841 .91061 Mdot
.10982 .41411 Mdot
.96164 .20165 Mdot
.28666 .97589 Mdot
.31723 .1762 Mdot
.95224 .44738 Mdot
.09153 .89256 Mdot
.58172 .0394 Mdot
.80161 .70955 Mdot
.02396 .68663 Mdot
.82068 .04644 Mdot
.55679 .90627 Mdot
.10505 .42242 Mdot
.95949 .19512 Mdot
.29423 .97612 Mdot
.30948 .18243 Mdot
.95481 .43901 Mdot
.09593 .89727 Mdot
.5734 .04161 Mdot
.80809 .70194 Mdot
.02381 .69436 Mdot
.8144 .04394 Mdot
.56515 .90181 Mdot
.1004 .43075 Mdot
.95721 .18869 Mdot
.30186 .97619 Mdot
.30178 .18876 Mdot
.95724 .43066 Mdot
.10045 .90186 Mdot
.56506 .04397 Mdot
.81447 .69428 Mdot
.02381 .70203 Mdot
.80802 .04159 Mdot
.57349 .89722 Mdot
.09588 .4391 Mdot
.95478 .18236 Mdot
.30956 .97612 Mdot
.29415 .19519 Mdot
.95952 .42233 Mdot
.1051 .90632 Mdot
.5567 .04647 Mdot
.82075 .68655 Mdot
.02396 .70963 Mdot
.80154 .03938 Mdot
.58181 .89251 Mdot
.09148 .44747 Mdot
.95221 .17613 Mdot
.31732 .97589 Mdot
.28658 .20172 Mdot
.96166 .41402 Mdot
.10987 .91065 Mdot
.54832 .04911 Mdot
.82693 .67876 Mdot
.02426 .71717 Mdot
.79497 .03731 Mdot
.5901 .88768 Mdot
.08721 .45586 Mdot
.9495 .17 Mdot
.32513 .97552 Mdot
.27907 .20833 Mdot
.96365 .40574 Mdot
.11477 .91485 Mdot
.53992 .05189 Mdot
.83301 .67092 Mdot
.02471 .72463 Mdot
.7883 .03539 Mdot
.59837 .88272 Mdot
.08307 .46426 Mdot
.94665 .16397 Mdot
.333 .97499 Mdot
.27164 .21504 Mdot
.9655 .3975 Mdot
.11979 .91893 Mdot
.53152 .05482 Mdot
.83898 .66303 Mdot
.02531 .73203 Mdot
.78155 .03361 Mdot
.6066 .87764 Mdot
.07907 .47267 Mdot
.94365 .15805 Mdot
.34092 .97432 Mdot
.26428 .22184 Mdot
.9672 .38928 Mdot
.12492 .92287 Mdot
.5231 .05788 Mdot
.84485 .65508 Mdot
.02605 .73936 Mdot
.7747 .03198 Mdot
.6148 .87245 Mdot
.07519 .48109 Mdot
.94052 .15224 Mdot
.34889 .9735 Mdot
.25699 .22873 Mdot
.96876 .3811 Mdot
.13017 .92668 Mdot
.51467 .06108 Mdot
.85061 .64708 Mdot
.02695 .74661 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3oool10?ooo`070;mdB02Lgol0oooo0?oOW0180000000007Boo`2Y
0?ooo`00o`3oool10?ooo`080?noM018W=l0oooo0=nLB000M;l0oooo0;nLW03OoonX0?ooo`00o`3o
ool10?ooo`050?oo_`1dB4P0B7BL09a8001d_ol0Z`3oool00?L0oooo00h0gia800000000M;l0oooo
0?oog`2LB000000007Boo`3oool0oooO09a8M02o_g@0001d0;oooj/0oooo003i0?ooo`0<0?noM01d
_ol0omnL04P0B02Lgol0_gAd0;ooo`3oool0gia807Boo`3ookl0M7BoZ`3oool00?X0oooo00@0_gAd
09bLB000B9`0gooo0`3oool0103ogi`0B7Bo0?oog`2LB0020000000307Boo`3oool0oooo0:H0oooo
003j0?ooo`030?oo_`1d000007Bo00@0oooo00<0oooO09a8M02oool0[03oool00?X0oooo00<0oono
07@0001d_ol01@3oool00`3OW4P0M;oo0?ooo`2[0?ooo`00nP3oool0103o_g@000000018W03Oool3
0?ooo`030=nLB000000007Bo0:`0oooo003j0?ooo`050;md0000B9`0gmnL04Q8W03Oool0/@3oool0
0?P0oooo00T0okmd000000000000M;oo0?ooo`3ogi`0B0000018W03Oool0[`3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool007/0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000
0000000000<0000000<0B9cO0?ooo`3oool0<@3oool0102oM00000000000001d_ol30?ooo`030?oO
W0180000M;oo0080oooo00<0oono07@0000000000P0000001P18W=l0oooo0?ooo`3oool0omnL04P0
0080000000<004RL0=ooo`3oool0<P3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000
M;oo0080oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`0b0?ooo`040;md00000000
000007Boo`<0oooo00<0omnL04P0001d_ol0103oool0102oM00000000000001d_ol30?ooo`060?oO
W0180000000000000000B9`0gooo<`3oool0102oM00000000000001d_ol90?ooo`00NP3oool01P3O
W4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00`3oool00`3o_g@007Bo0?oo
o`020?ooo`030;mdM02oool0oooo0300oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`03
0?oOW0180000M;oo00@0oooo00<0okmd0000001d_ol0103oool01P3o_g@0000007Boo`3oool0omnL
04Qd_c80oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00@0oooo
00<0okmd0000001d_ol0=03oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0
001d_ol00`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00H0okmd0000001d_ol0oooo
0?oOW018M;lb0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO203oool007T0oooo00<0oooO09a8
0018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?noM000M;l0oooo03<0oooo00<0oooO09a8
0018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?oog`2LB00007Bo00T0oooo00<0okmd04RL
g`3oool0;`3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00P0oooo00<0oooO09a8
0000M;l0<`3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00H0oooo00<0oooO09a8
0018W=l00P3oool00`3o_g@0001809cOo`060?ooo`030?noM018W=l0oooo02l0oooo00<0oooO09a8
0018W=l00P3oool00`3o_g@0001809cOo`070?ooo`00N@3oool00`3ooml0W4P004RLg`020?ooo`04
0?oog`2LB00004RL0=ooo`P0oooo00<0okmd001d_`3oool0<P3oool00`3ooml0W4P004RLg`020?oo
o`040?oog`2LB00004RL0=ooo`P0oooo00<0gia80018W03Oool0203oool00`3ookl0M01d0;ooo`0_
0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo203oool00`3OW4P004RL0=oo
o`0b0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo1@3oool00`3ooml0W4P0
04RLg`020?ooo`040?oog`2LB00004RL0=ooo`D0oooo00<0oono07@0M02oool0;`3oool00`3ooml0
W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`H0oooo001/0?ooo`030?oog`2LB000000000L0
000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`030=nLB00004P0W=oo00T0oooo00<0okmd
04RLg`3oool0903oool00`3ooml0W4P0000000070000000604RLg`3oool0oooo0?oog`2LB00007Bo
0`3oool00`3OW4P0001809cOo`080?ooo`030?oOW01804P0W=oo00P0oooo00<0oooO09a8001d_ol0
8P3oool00`3ooml0W4P0000000070000000604RLg`3oool0oooo0?oog`2LB00007Bo0`3oool00`3O
W4P0001809cOo`080?ooo`030?oOW01804P0W=oo02D0oooo00<0oooO09a8000000001`0000001P18
W=l0oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol01@3oool00`3ooml0W4P0001d
_`030?ooo`030=nLB00004P0W=oo00D0oooo00<0oooO09a8001d_ol0;`3oool00`3ooml0W4P0001d
_`030?ooo`030=nLB00004P0W=oo00H0oooo001j0?ooo`030;md0000B9`0gooo0080oooo00<0omnL
04P00018W=l02P3oool00`3OW4P0B9cO0?ooo`0a0?ooo`030;md0000B9`0gooo0080oooo00<0omnL
04P00018W=l0203oool00`3ookl0M00007Boo`080?ooo`030?oo_`1d0000B9cO0300oooo00<0_g@0
0018W03Oool00P3oool00`3ogi`0B00004RLg`080?ooo`030?oo_`1d0000M;oo03<0oooo00<0_g@0
0018W03Oool00P3oool00`3ogi`0B00004RLg`060?ooo`030;md0000B9`0gooo0080oooo00<0omnL
04P00018W=l01@3oool00`3ookl0M00004RLg`0`0?ooo`030;md0000B9`0gooo0080oooo00<0omnL
04P00018W=l01P3oool007X0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0;0?oo
o`030;md001d_ol0oooo0300oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`090?oo
o`030;md0000M;l0oooo00L0oooo00<0okmd0000001d_ol0<03oool00`3OW4P0001809cOo`020?oo
o`030?oog`2LB00007Bo00T0oooo00<0_g@0001d_`3oool0<P3oool00`3OW4P0001809cOo`020?oo
o`030?oog`2LB00007Bo00H0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`050?oo
o`030?noM0000000M;oo0300oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`060?oo
o`00NP3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00X0oooo00<0omnL04P0M02o
ool0<03oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00P0oooo00<0gia80018W03O
ool0103oool01P3ogml0gooo0?noM0000000001d0;oooc00oooo00<0omnL04P00018W=l00`3oool0
0`2oM00004RL0=ooo`080?ooo`030=nLB000B9`0gooo0380oooo00<0omnL04P00018W=l00`3oool0
0`2oM00004RL0=ooo`050?ooo`030?oOW0180000B9cO00<0oooo00X0_g@00018W03Oool0oooo0?oO
g`3Oool0okmd0000000007@0_ooo<03oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo
00D0oooo001j0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool02P3oool00`3o
oml0W4P007Boo`0`0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0203oool0
0`3ogi`0B01809cOo`040?ooo`050?oo_`1d000000000000B02Lgol0<@3oool0103ooml0W4P00018
W03Oool20?ooo`030=nLB000B9`0gooo00P0oooo00<0omnL04P0B02Lgol0<P3oool0103ooml0W4P0
0018W03Oool20?ooo`030=nLB000B9`0gooo00D0oooo00@0oooO09a80000B9`0gooo0P3oool02@3O
W4P004RL0=ooo`3oool0oono07@000000000001809cOo`0a0?ooo`040?oog`2LB00004RL0=ooo`80
oooo00<0gia80018W03Oool01@3oool007/0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo
0?ooo`0:0?ooo`030?oo_`1d0000B9cO0340oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo
0?ooo`080?ooo`030?oo_`1d0000M;oo00D0oooo00<0gibL0;ooo`3oool0<`3oool00`3ogi`0B000
07Boo`020?ooo`030=nLB000M;l0oooo00P0oooo00<0oono07@0001d_ol0<`3oool00`3ogi`0B000
07Boo`020?ooo`030=nLB000M;l0oooo00H0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo
0?ooo`020?ooo`030=nLW02oool0oooo03<0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo
0?ooo`050?ooo`00O03oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`L0oooo00L0okmd0018W03O
ool0oooo0=nLB00004P0W=oo0380oooo00H0gia80000M02oool0oooO09a80018W=l:0?ooo`030;md
0000M;l0oooo00@0oooo00<0omnL07BLg`3oool0=03oool01P3OW4P0001d0;ooo`3ooml0W4P004RL
g`X0oooo00<0_g@0001d_`3oool0<`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`P0oooo00H0
gia80000M02oool0oooO09a80018W=l30?ooo`030?oOW01dW=l0oooo03@0oooo00H0gia80000M02o
ool0oooO09a80018W=l60?ooo`00O@3oool0103OW4P0000000000000M;l90?ooo`050?oOW0180000
00000000001d_ol0=03oool0103OW4P0000000000000M;l90?ooo`050?oo_`1d000000000000M02o
ool01@3oool01@2oM0000000000000000000B9cO0380oooo00@0gia800000000000007Bo2@3oool0
1@3ookl0M0000000000007@0_ooo03@0oooo00@0gia800000000000007Bo2P3oool0103OW4P00000
00000000M;l50?ooo`050;md00000000000000000018W=l0<P3oool0103OW4P0000000000000M;l7
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00D03ooooo
0000060000000@3oool00500oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00D0oooo0@0000010?ooo`00D03oool2000002`0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`040?ooo`8000000@3oool00500oooo00<000000?ooo`3oool0
o`3ooomL0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0o`3ooomL0?ooo`4000000@3o
ool00500oooo00<000000?ooo`3oool0o`3ooomL0?ooo`4000000@3oool00500oooo00<000000?oo
o`3oool0o`3ooomL0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0o`3ooomL0?ooo`40
00000@3oool00500oooo00<000000?ooo`3oool0i`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0000006/0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`3O0?ooo`060000
003oool0oooo0000003oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
000006/0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`3F0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0000001f0?ooo`4000000@3o
ool00500oooo00<000000?ooo`3oool0e03oool00`000000oooo000000020?ooo`040000003oool0
oooo000002l0oooo00<000000?ooo`3oool0C03oool100000040oooo001@0?ooo`030000003oool0
oooo0<h0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0e0?ooo`050000003o
ool000000?ooo`000000BP3oool100000040oooo001@0?ooo`030000003oool0oooo0</0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool000000080oooo
00<000000?ooo`3oool0A@3oool100000040oooo001@0?ooo`030000003oool0oooo0<D0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`150?ooo`050000003oool000000?ooo`00
0000@`3oool100000040oooo001@0?ooo`030000003oool0oooo0<80oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`1:0?ooo`050000003oool000000?ooo`000000@@3oool10000
0040oooo001@0?ooo`800000`03oool010000000oooo0?ooo`00001F0?ooo`040000003oool0oooo
000003d0oooo0P0000010?ooo`00D03oool00`000000oooo0?ooo`2l0?ooo`040000003oool0oooo
000005`0oooo00<000000?ooo`000000?03oool100000040oooo001@0?ooo`030000003oool0oooo
0;T0oooo00@000000?ooo`3oool00000H@3oool00`000000oooo0000000j0?ooo`4000000@3oool0
0500oooo00<000000?ooo`3oool0]P3oool010000000oooo0?ooo`00001V0?ooo`030000003oool0
000003P0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`2c0?ooo`040000003oool0oooo
000006/0oooo00<000000?ooo`000000=P3oool100000040oooo001@0?ooo`030000003oool0oooo
0;00oooo00@000000?ooo`3oool00000L03oool00`000000oooo0000000d0?ooo`4000000@3oool0
0500oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`1c0?ooo`030000003oool00000
0380oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`3o0?ooobT0oooo00<000000?ooo`3o
ool0<03oool100000040oooo001@0?ooo`030000003oool0oooo0?l0oooo:`3oool00`000000oooo
0?ooo`0^0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0o`3oool[0?ooo`030000003o
ool0000002h0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`3o0?ooobd0oooo00<00000
0?ooo`000000;03oool100000040oooo001@0?ooo`030000003oool0oooo0?l0oooo;`3oool00`00
0000oooo0000000Z0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0o`3ooola0?ooo`03
0000003oool0oooo02P0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`3o0?oooc80oooo
00<000000?ooo`3oool09`3oool100000040oooo001@0?ooo`030000003oool0oooo0?l0oooo<P3o
ool00`000000oooo0000000W0?ooo`4000000@3oool00500oooo0P00003o0?ooocD0oooo00<00000
0?ooo`3oool0903oool200000040oooo001@0?ooo`030000003oool0oooo0?l0oooo=P3oool00`00
0000oooo0?ooo`0S0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0o`3ooolf0?ooo`80
0000903oool100000040oooo001@0?ooo`030000003oool0oooo0?l0oooo=`3oool00`000000oooo
0?ooo`0R0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?oo
o`350?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`35
0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`380?oo
o`4000000@3oool00500oooo00<000000?ooo`3oool0S@3oool010000000oooo0?ooo`00003:0?oo
o`4000000@3oool00500oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`3;0?ooo`40
00000@3oool00500oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3>0?ooo`400000
0@3oool003@0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`030=nL
B0000000000000<0000000<0B9cO0?ooo`3oool01`3oool00`000000oooo0?ooo`2:0?ooo`030000
003oool0oooo0<h0oooo0@0000010?ooo`00<`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80
oooo00<0omnL04P0001d_ol00`3oool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02oool0oooo00L0
oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`3A0?ooo`4000000@3oool00380oooo
00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?noM000M;l0oooo00/0oooo
00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`3A0?ooo`4000000@3oool00380oooo00<0
oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool80?ooo`030?noM000M;l0oooo00X0oooo
00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`3C0?ooo`4000000@3oool002D0oooo00<0
oooO09a8000000001`0000001P18W=l0oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0gia80000B02L
gol02@3oool00`3o_g@0B9cO0?ooo`090?ooo`030000003oool0oooo0880oooo00@000000?ooo`3o
ool00000e@3oool100000040oooo000c0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018
W=l02P3oool00`3OW4P0B9cO0?ooo`080?ooo`<00000PP3oool00`000000oooo0?ooo`3D0?ooo`<0
00000@3oool003<0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0;0?ooo`030;md
001d_ol0oooo00L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`3I0?ooo`400000
0@3oool003<0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`0:0?ooo`030?oOW018
07@0_ooo00L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`3I0?ooo`4000000@3o
ool003<0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`0:0?ooo`030?oog`2L
B000M;oo00L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`3L0?ooo`4000000@3o
ool003@0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`0:0?ooo`030?oo_`1d0000
B9cO00L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`3L0?ooo`4000000@3oool0
03D0oooo00H0gia80000M02oool0oooO09a80018W=l70?ooo`070?noM000B9`0gooo0?ooo`3OW4P0
001809cOo`070?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0g`3oool100000040
oooo000f0?ooo`040=nLB00000000000001d_`T0oooo00D0omnL04P000000000000007Boo`080?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool0g`3oool100000040oooo001@0?ooo`03
0000003oool0oooo07H0oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0B0?ooo`40
00000@3oool00500oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`3=0?ooo`030000
003oool0oooo0180oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo0=00oooo00<000000?ooo`3oool04@3oool100000040oooo001@0?ooo`030000003oool0
oooo07@0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`0A0?ooo`4000000@3oool0
0500oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo
0100oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0=@0
oooo00<000000?ooo`3oool0403oool100000040oooo001@0?ooo`030000003oool0oooo06h0oooo
00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0?0?ooo`4000000@3oool00500oooo00<0
00000?ooo`3oool0KP3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo00l0oooo0@00
00010?ooo`00D03oool2000006`0oooo00<000000?ooo`3oool0g03oool00`000000oooo0?ooo`0=
0?ooo`8000000@3oool00500oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`3L0?oo
o`030000003oool0oooo00h0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe`0
oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0=l0oooo
00<000000?ooo`3oool03@3oool100000040oooo001@0?ooo`030000003oool0oooo06T0oooo00<0
00000?ooo`3oool0g`3oool00`000000oooo0?ooo`0=0?ooo`4000000@3oool00500oooo00<00000
0?ooo`3oool0IP3oool00`000000oooo0?ooo`3R0?ooo`030000003oool0oooo00d0oooo0@000001
0?ooo`00D03oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0>80oooo00<000000?oo
o`3oool03@3oool100000040oooo001@0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool0iP3oool00`000000oooo0?ooo`0<0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0
H`3oool00`000000oooo0?ooo`3V0?ooo`030000003oool0oooo00`0oooo0@0000010?ooo`00D03o
ool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0>T0oooo00<000000?ooo`3oool02`3o
ool100000040oooo001@0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0j@3oool0
0`000000oooo0?ooo`0;0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0o`3ooomL0?oo
o`4000000@3oool00500oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3]0?ooo`03
0000003oool0oooo00X0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`1N0?ooo`030000
003oool0oooo0>d0oooo00<000000?ooo`3oool02P3oool100000040oooo001@0?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool0l03oool00`000000oooo0?ooo`0:0?ooo`4000000@3o
ool00500oooo0P00001L0?ooo`030000003oool0oooo0?00oooo00<000000?ooo`3oool02@3oool2
00000040oooo001@0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0l`3oool00`00
0000oooo0?ooo`090?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0F@3oool00`000000
oooo0?ooo`3c0?ooo`030000003oool0oooo00T0oooo0@0000010?ooo`00D03oool00`000000oooo
0?ooo`3o0?oooe`0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo0?H0oooo00<000000?ooo`3oool02@3oool100000040oooo001@0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool0mP3oool00`000000oooo0?ooo`090?ooo`4000000@3oool0
0500oooo00<000000?ooo`3oool0o`3ooomA0?ooo`030000003oool0oooo00P0oooo0@0000010?oo
o`00D03oool00`000000oooo0?ooo`3o0?oooe40oooo00<000000?ooo`3oool0203oool100000040
oooo001@0?ooo`030000003oool0oooo0?l0ooooG03oool100000040oooo001@0?ooo`030000003o
ool0oooo0?l0ooooD@3oool00`000000oooo0?ooo`080?ooo`4000000@3oool00500oooo00<00000
0?ooo`3oool0o`3ooomA0?ooo`030000003oool0oooo00P0oooo0@0000010?ooo`00D03oool00`00
0000oooo0?ooo`3o0?oooe80oooo00<000000?ooo`3oool01`3oool100000040oooo001@0?ooo`03
0000003oool0oooo0?l0ooooDP3oool00`000000oooo0?ooo`070?ooo`4000000@3oool00500oooo
00<000000?ooo`3oool0o`3ooomL0?ooo`4000000@3oool00500oooo0P00003o0?oooe<0oooo00<0
00000?ooo`3oool01P3oool200000040oooo001@0?ooo`030000003oool0oooo0?l0ooooDP3oool0
0`000000oooo0?ooo`070?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0o`3ooomB0?oo
o`030000003oool0oooo00L0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe80
oooo00<000000?ooo`3oool01`3oool100000040oooo001@0?ooo`030000003oool0oooo0?l0oooo
G03oool100000040oooo001@0?ooo`030000003oool0oooo0?l0ooooD`3oool00`000000oooo0?oo
o`060?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0o`3ooomC0?ooo`030000003oool0
oooo00H0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe`0oooo0@0000010?oo
o`00D03oool00`000000oooo0?ooo`3o0?oooe<0oooo00<000000?ooo`3oool01P3oool100000040
oooo001@0?ooo`030000003oool0oooo0?l0ooooD`3oool00`000000oooo0?ooo`060?ooo`400000
0@3oool00500oooo00<000000?ooo`3oool0o`3ooomC0?ooo`030000003oool0oooo00H0oooo0@00
00010?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe<0oooo00<000000?ooo`3oool01P3oool1
00000040oooo001@0?ooo`030000003oool0oooo0?l0ooooG03oool100000040oooo001@0?ooo`03
0000003oool0oooo0?l0ooooD`3oool00`000000oooo0?ooo`060?ooo`4000000@3oool00500oooo
00<000000?ooo`3oool0o`3ooomC0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`00D03o
ool200000?l0ooooE03oool00`000000oooo0?ooo`050?ooo`8000000@3oool00500oooo00<00000
0?ooo`3oool0o`3ooomC0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`00D03oool00`00
0000oooo0?ooo`3o0?oooe`0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo0?l0oooo7@3oool100000040oooo001@0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0o`3ooolM0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0o`3o
oomL0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`3o
0?oooal0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
0?l0oooo7`3oool100000040oooo001@0?ooo`030000003oool0oooo0?l0ooooG03oool100000040
oooo001@0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`400000
0@3oool002/0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`030?oo
_`1d000000000080000000H0B9cO0?ooo`3oool0oooo0?oOW0180002000000030018W03Oool0oooo
00T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`3o0?ooob40oooo0@0000010?oo
o`00:P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol0103oool0
0`3o_g@0000007Boo`040?ooo`060?noM0000000M;oo0?ooo`3ogi`0B7Bo2P3oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo0?l0oooo8`3oool100000040oooo000Y0?ooo`030?oog`2L
B000B9cO0080oooo00<0okmd0000B02Lgol0203oool00`3ooml0W4P0001d_`090?ooo`030?noM018
W=l0oooo00P0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`3o0?ooob<0oooo0@00
00010?ooo`00:@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<0
gia80018W03Oool0203oool00`3ookl0M01d0;ooo`080?ooo`030000003oool0oooo0?l0ooooG03o
ool100000040oooo000L0?ooo`030?oog`2LB000000000L0000000H0B9cO0?ooo`3oool0oooO09a8
0000M;l30?ooo`030=nLB00004P0W=oo00P0oooo00<0omnL04P0B02Lgol0203oool00`3ooml0W4P0
07Boo`080?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`400000
0@3oool002X0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`080?ooo`030?oo_`1d
0000M;oo00P0oooo00<0oono07@00018W=l0203oool3000003@0oooo00<000000?ooo`3oool0o`3o
oolS0?ooo`<000000@3oool002X0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`09
0?ooo`030;md0000M;l0oooo00L0oooo00<0okmd0000001d_ol0203oool00`000000oooo0?ooo`3o
0?oooe`0oooo0@0000010?ooo`00:P3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo
00P0oooo00<0gia80018W03Oool0103oool01P3ogml0gooo0?noM0000000001d0;ooo`P0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`3o0?ooobL0oooo0@0000010?ooo`00:P3oool0
103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00P0oooo00<0omnL04P0B02Lgol0103o
ool01@3ookl0M0000000000004P0W=oo00T0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`3o0?ooobL0oooo0@0000010?ooo`00:`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000
M;l0oooo00P0oooo00<0oono07@0001d_ol01@3oool00`3OW9`0_ooo0?ooo`0:0?ooo`030000003o
ool0oooo0?l0ooooG03oool100000040oooo000/0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO
2P3oool00`2oM00007Bo0?ooo`040?ooo`030?oOW01dW=l0oooo00X0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`3o0?ooobT0oooo0@0000010?ooo`00;@3oool0103OW4P000000000
0000M;l90?ooo`050?oo_`1d000000000000M02oool01@3oool01@2oM0000000000000000000B9cO
00L0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`3o0?ooobT0oooo0@0000010?oo
o`00D03oool00`000000oooo0?ooo`3o0?oooe`0oooo0@0000010?ooo`00D03oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo0?l0oooo:`3oool100000040oooo001@0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool0o`3oool[0?ooo`4000000@3oool00500oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`3o0?ooobd0oooo0@0000010?ooo`00D03oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo0?l0oooo;@3oool100000040oooo001@0?ooo`03
0000003oool0oooo0?l0ooooG03oool100000040oooo001@0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0o`3ooolS0?ooo`030000003oool0oooo00T0oooo0@0000010?ooo`00D03o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0oooo8`3oool00`000000oooo0?oo
o`090?ooo`4000000@3oool00500oooo0P00003o0?oooe`0oooo0P0000010?ooo`00D03oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo0?l0oooo9@3oool00`000000oooo0?ooo`090?oo
o`4000000@3oool00500oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`3o0?ooobD0
oooo00<000000?ooo`3oool02@3oool100000040oooo001@0?ooo`030000003oool0oooo0?l0oooo
G03oool100000040oooo001@0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0o`3o
oolV0?ooo`030000003oool0oooo00X0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo0?l0oooo9P3oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool0
0500oooo00<000000?ooo`3oool0o`3ooomL0?ooo`4000000@3oool00500oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`3o0?ooobP0oooo00<000000?ooo`3oool02P3oool100000040
oooo001@0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`030000
003oool0oooo00X0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe`0oooo0@00
00010?ooo`00D03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0?l0oooo:03oool0
0`000000oooo0?ooo`0;0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`3o0?ooobP0oooo00<000000?ooo`3oool02`3oool100000040oooo001@0?ooo`03
0000003oool0oooo0?l0ooooG03oool100000040oooo001@0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0o`3ooolY0?ooo`030000003oool0oooo00`0oooo0@0000010?ooo`00D03o
ool200000280oooo00<000000?ooo`3oool0o`3ooolY0?ooo`030000003oool0oooo00/0oooo0P00
00010?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe`0oooo0@0000010?ooo`00D03oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0oooo:P3oool00`000000oooo0?ooo`0=0?oo
o`4000000@3oool00500oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?ooobX0
oooo00<000000?ooo`3oool03@3oool100000040oooo001@0?ooo`030000003oool0oooo0?l0oooo
G03oool100000040oooo001@0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0o`3o
ool[0?ooo`030000003oool0oooo00d0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo0?l0oooo:`3oool00`000000oooo0?ooo`0=0?ooo`4000000@3oool0
0500oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3o0?ooob`0oooo00<000000?oo
o`3oool03P3oool100000040oooo001@0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0o`3oool/0?ooo`030000003oool0oooo00h0oooo0@0000010?ooo`00D03oool00`000000oooo
0?ooo`3o0?oooe`0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo0?l0oooo;03oool00`000000oooo0?ooo`0?0?ooo`4000000@3oool000l0oooo00<0gia8
0000M02oool0?P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0oooo;03oool0
0`000000oooo0?ooo`0?0?ooo`4000000@3oool000P0oooo00<0oono07Ad_`3oool0103oool00`3o
okl0M4RL0=ooo`0n0?ooo`030000003oool0oooo0?l0ooooG03oool100000040oooo00080?ooo`03
0?oOW01807@0_ooo00<0oooo00<0okmd0000M02oool0?`3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0@0?ooo`4000000@3oool000P0oooo
00L0omnL04P000000000001809cOo`3ogi`0B7Bo0440oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool0403oool100000040oooo000:0?ooo`03
0?oo_`1d000000000080000000<0M;oo0?ooo`3oool0?P3oool200000?l0ooooG03oool200000040
oooo00090?ooo`090?oo_`1d07@0_ooo0?ooo`3ooml0W4P00000000007@0_ooo03h0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool04@3oool1
00000040oooo00080?ooo`030?oo_`1d07@0_ooo00@0oooo00<0omnL04Qd_`3oool0?P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0A0?oo
o`4000000@3oool000P0oooo00<0okmd0000001d_ol00`3oool00`3ookl0M4RL0=ooo`0o0?ooo`03
0000003oool0oooo0?l0ooooG03oool100000040oooo001@0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0o`3oool]0?ooo`030000003oool0oooo0180oooo0@0000010?ooo`004@3o
ool0103o_g@000000000M02ooolk0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
o`3oool]0?ooo`030000003oool0oooo0180oooo0@0000010?ooo`002P3oool0103ooml0W9bo0?oo
g`2LB00300000003001d_`3oool0oooo03`0oooo00<000000?ooo`3oool0o`3ooomL0?ooo`400000
0@3oool000X0oooo00@0oono07@0000004P0W=oo0P3oool00`2oW9`0gooo0?ooo`0m0?ooo`030000
003oool0oooo0?l0ooooA@3oool00`000000oooo0?ooo`0D0?ooo`4000000@3oool000h0oooo00D0
gmoO0;md000000000000001d_`0m0?ooo`030000003oool0oooo0?l0ooooA@3oool00`000000oooo
0?ooo`0D0?ooo`4000000@3oool000d0oooo00<0oooO09a8001d_ol00P3oool00`3OW4P0001d0;oo
o`0k0?ooo`030000003oool0oooo0?l0ooooG03oool100000040oooo000=0?ooo`030?oog`2LM9`0
gooo0080oooo00<0giad09cOo`3oool0>`3oool00`000000oooo0?ooo`3o0?oood@0oooo00<00000
0?ooo`3oool05@3oool100000040oooo001@0?ooo`030000003oool0oooo0?l0ooooA03oool00`00
0000oooo0?ooo`0E0?ooo`4000000@3oool00100oooo00<0_gAd0;ooo`3oool0?@3oool00`000000
oooo0?ooo`3o0?oooe`0oooo0@0000010?ooo`00403oool00`2oM7@0_ooo0?ooo`0m0?ooo`030000
003oool0oooo0?l0oooo@`3oool00`000000oooo0?ooo`0F0?ooo`4000000@3oool00100oooo00<0
_gAd0;ooo`3oool0?@3oool00`000000oooo0?ooo`3o0?oood<0oooo00<000000?ooo`3oool05P3o
ool100000040oooo000=0?ooo`030;md00000000000000<0000000<0001d0;ooo`3oool0>P3oool2
00000?l0ooooG03oool200000040oooo000@0?ooo`030;mdM02oool0oooo03d0oooo00<000000?oo
o`3oool0o`3ooom20?ooo`030000003oool0oooo01L0oooo0@0000010?ooo`00403oool00`2oM7@0
_ooo0?ooo`0m0?ooo`030000003oool0oooo0?l0oooo@P3oool00`000000oooo0?ooo`0G0?ooo`40
00000@3oool00100oooo00<0_gAd0;ooo`3oool0?@3oool00`000000oooo0?ooo`3o0?oooe`0oooo
0@0000010?ooo`00D03oool00`000000oooo0?ooo`3o0?oood00oooo00<000000?ooo`3oool06@3o
ool100000040oooo001@0?ooo`030000003oool0oooo0?l0oooo@03oool00`000000oooo0?ooo`0I
0?ooo`4000000@3oool001<0oooo00<0_gAd0;ooo`3oool0>P3oool00`000000oooo0?ooo`3o0?oo
oe`0oooo0@0000010?ooo`002`3oool00`3ookl0W9cO0?ooo`020?ooo`050?oo_`1d000000000000
M02oool0>`3oool00`000000oooo0?ooo`3o0?ooocl0oooo00<000000?ooo`3oool06P3oool10000
0040oooo000;0?ooo`030?noM000000000000080000000D0001d0;ooo`3oool0gibL0;ooo`0k0?oo
o`030000003oool0oooo0?l0oooo?`3oool00`000000oooo0?ooo`0J0?ooo`4000000@3oool000/0
oooo00<0gia8001d_`3oool0@P3oool00`000000oooo0?ooo`3o0?oooe`0oooo0@0000010?ooo`00
=03oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00<0oono07@00000
00000P0000000`18W=l0oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo?P3oool00`000000
oooo0?ooo`0K0?ooo`4000000@3oool003<0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?oo
o`030?oOW0180000M;oo00@0oooo00<0okmd0000001d_ol02`3oool00`000000oooo0?ooo`3o0?oo
och0oooo00<000000?ooo`3oool06`3oool100000040oooo000b0?ooo`030?oog`2LB000B9cO0080
oooo00<0okmd0000B02Lgol0203oool00`3ooml0W4P0001d_`0;0?ooo`030000003oool0oooo0?l0
ooooG03oool100000040oooo000b0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0
gooo203oool00`3OW4P004RL0=ooo`0:0?ooo`030000003oool0oooo0?l0oooo?03oool00`000000
oooo0?ooo`0M0?ooo`4000000@3oool002D0oooo00<0oooO09a8000000001`0000001P18W=l0oooo
0?ooo`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol0203oool00`3ogi`0B01809cOo`0:0?oo
o`030000003oool0oooo0?l0oooo?03oool00`000000oooo0?ooo`0M0?ooo`4000000@3oool003<0
oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`080?ooo`030?oo_`1d0000M;oo00X0
oooo0`00003o0?oooeX0oooo0`0000010?ooo`00<`3oool00`3OW4P0001809cOo`020?ooo`030?oo
g`2LB00007Bo00T0oooo00<0_g@0001d_`3oool02@3oool00`000000oooo0?ooo`3o0?oooc/0oooo
00<000000?ooo`3oool07P3oool100000040oooo000c0?ooo`030?oOW0180000B9cO00<0oooo00<0
_g@00018W03Oool0203oool00`3OW4P004RL0=ooo`090?ooo`030000003oool0oooo0?l0oooo>`3o
ool00`000000oooo0?ooo`0N0?ooo`4000000@3oool003<0oooo00@0oooO09a80000B9`0gooo0P3o
ool00`3OW4P004RL0=ooo`080?ooo`030?oOW01804P0W=oo00T0oooo00<000000?ooo`3oool0o`3o
oomL0?ooo`4000000@3oool003@0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`08
0?ooo`030?oo_`1d0000M;oo00T0oooo00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0
oooo0200oooo0@0000010?ooo`00=@3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`X0oooo00<0
_g@0001d_`3oool0203oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool0803o
ool100000040oooo000f0?ooo`040=nLB00000000000001d_`T0oooo00D0oono07@000000000001d
0;ooo`080?ooo`030000003oool0oooo0?l0ooooG03oool100000040oooo001@0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`4000000@3oool00500oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`00D03oool00`00
0000oooo0?ooo`3o0?oooe`0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0?l0ooooC`3oool100000040oooo001@0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0o`3ooom?0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`3o0?oooe00oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0?l0ooooD03oool100000040oooo001@0?ooo`030000003oool0oooo
0?l0ooooG03oool100000040oooo001@0?ooo`8000002P3oool00`000000oooo0?ooo`3o0?ooodl0
oooo0P0000010?ooo`00D03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo
D03oool100000040oooo001@0?ooo`030000003oool0oooo0?l0ooooG03oool100000040oooo001@
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`4000000@3oool0
0500oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oooe40oooo0@0000010?oo
o`00D03oool00`000000oooo0?ooo`3o0?oooe`0oooo0@0000010?ooo`00D03oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0?l0ooooDP3oool100000040oooo001@0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0o`3ooomB0?ooo`4000000@3oool00500oooo00<00000
0?ooo`3oool0o`3ooomL0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`3o0?oooe80oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0?l0ooooDP3oool100000040oooo001@0?ooo`030000003oool0oooo0?l0oooo
G03oool100000040oooo001@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3o
oomC0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o
0?oooe<0oooo0@0000010?ooo`00D03oool200000?l0ooooG03oool200000040oooo001@0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`4000000@3oool00500oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?oooe<0oooo0@0000010?ooo`00D03o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo7P3oool00`000000oooo0?oo
o`0b0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o
0?oooah0oooo00<000000?ooo`3oool0<P3oool100000040oooo001@0?ooo`030000003oool0oooo
0?l0ooooG03oool100000040oooo001@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0o`3ooolM0?ooo`030000003oool0oooo03@0oooo0@0000010?ooo`00D03oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0?l0oooo7@3oool00`000000oooo0?ooo`0d0?ooo`400000
0@3oool00500oooo00<000000?ooo`3oool0o`3ooomL0?ooo`4000000@3oool00500oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oooa/0oooo00<000000?ooo`3oool0=P3oool1
00000040oooo001@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooolK0?oo
o`030000003oool0oooo03H0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe`0
oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo
6@3oool00`000000oooo0?ooo`0h0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`3o0?oooaT0oooo00<000000?ooo`3oool0>03oool100000040oooo001@
0?ooo`030000003oool0oooo0?l0oooo7`3oool00`000000oooo0?ooo`0j0?ooo`4000000@3oool0
0500oooo0P0000060?ooo`030000003oool0oooo0?l0oooo5`3oool00`000000oooo0?ooo`0i0?oo
o`8000000@3oool00500oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oooe@0
oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo
5@3oool00`000000oooo0?ooo`0l0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`3o0?oooaD0oooo00<000000?ooo`3oool0?03oool100000040oooo001@
0?ooo`030000003oool0oooo0?l0ooooG03oool100000040oooo001@0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`030000003oool0oooo03l0oooo0@0000010?oo
o`00D03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo4P3oool00`000000
oooo0?ooo`0o0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0o`3ooomL0?ooo`400000
0@3oool00500oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool0@@3oool100000040oooo001@0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo0440oooo0@0000010?ooo`00D03oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo3P3oool00`000000oooo0?ooo`130?oo
o`4000000@3oool00500oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`h0
oooo00<000000?ooo`3oool0@`3oool100000040oooo001@0?ooo`030000003oool0oooo0?l0oooo
G03oool100000040oooo001@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3o
ool<0?ooo`030000003oool0oooo04D0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0?l0oooo303oool00`000000oooo0?ooo`150?ooo`4000000@3oool0
0500oooo0P00003o0?oooe`0oooo0P0000010?ooo`00D03oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0?l0oooo2@3oool00`000000oooo0?ooo`180?ooo`4000000@3oool00500oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00<000000?ooo`3oool0
B03oool100000040oooo001@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3o
ool70?ooo`030000003oool0oooo04X0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0?l0oooo1`3oool00`000000oooo0?ooo`1:0?ooo`4000000@3oool0
0500oooo00<000000?ooo`3oool0o`3ooomL0?ooo`4000000@3oool00500oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool0C03oool100000040
oooo001@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool50?ooo`030000
003oool0oooo04`0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0?l0oooo0@3oool00`000000oooo0?ooo`1?0?ooo`4000000@3oool00500oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooo`40oooo00<000000?ooo`3oool0C`3oool1
00000040oooo000[0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol0103oool0
102oM00000000000001d_ol30?ooo`060?oOW0180000000000000000B9`0gooo2P3oool00`000000
oooo0?ooo`3o0?oooe`0oooo0@0000010?ooo`00:P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RL
g`80oooo00<0omnL04P0001d_ol00`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00H0
okmd0000001d_ol0oooo0?oOW018M;l:0?ooo`030000003oool0oooo0?l0oooo203oool00`000000
oooo0?ooo`1A0?ooo`4000000@3oool002T0oooo00<0oooO09a80018W=l00P3oool00`3o_g@00018
09cOo`060?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol01P3oool00`3o_g@0B9cO
0?ooo`080?ooo`030000003oool0oooo0?l0oooo203oool00`000000oooo0?ooo`1A0?ooo`400000
0@3oool002T0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool50?ooo`030?oo
g`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo1@3oool00`3ookl0M01d0;ooo`080?ooo`03
0000003oool0oooo0?l0oooo1@3oool00`000000oooo0?ooo`1D0?ooo`4000000@3oool001`0oooo
00<0oooO09a8000000001`0000001P18W=l0oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0gia80000
B02Lgol01@3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00D0oooo00<0oooO09a8
001d_ol0203oool00`000000oooo0?ooo`3o0?ooo`D0oooo00<000000?ooo`3oool0E03oool10000
0040oooo000Z0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01P3oool00`2oM000
04RL0=ooo`020?ooo`030?oOW0180000B9cO00D0oooo00<0oono07@00018W=l0203oool300000?l0
ooooFP3oool300000040oooo000Z0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0
1P3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00D0oooo00<0okmd0000001d_ol0
203oool00`000000oooo0?ooo`3o0?ooo`<0oooo00<000000?ooo`3oool0EP3oool100000040oooo
000Z0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01@3oool00`3ogi`0B00004RL
g`030?ooo`0:0;md0000B9`0gooo0?ooo`3ogml0gooo0?noM0000000001d0;ooo`P0oooo00<00000
0?ooo`3oool0o`3oool30?ooo`030000003oool0oooo05H0oooo0@0000010?ooo`00:P3oool0103o
oml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00D0oooo00@0oooO09a80000B9`0gooo0P3o
ool02@3OW4P004RL0=ooo`3oool0oono07@000000000001809cOo`090?ooo`030000003oool0oooo
0?l0oooo00<000000?ooo`3oool0F@3oool100000040oooo000[0?ooo`030?oOW0180000M;oo0080
oooo00<0gia8001d_`3oool01P3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo0080
oooo00<0gibL0;ooo`3oool02P3oool00`000000oooo0?ooo`3o0?ooo`030000003oool0oooo05T0
oooo0@0000010?ooo`00;03oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`P0oooo00H0gia80000
M02oool0oooO09a80018W=l30?ooo`030?oOW01dW=l0oooo00X0oooo00<000000?ooo`3oool0o@3o
ool00`000000oooo0?ooo`1K0?ooo`4000000@3oool002d0oooo00@0gia800000000000007Bo2P3o
ool0103OW4P0000000000000M;l50?ooo`050;md00000000000000000018W=l01`3oool00`000000
oooo0?ooo`3m0?ooo`030000003oool0oooo05/0oooo0@0000010?ooo`00D03oool00`000000oooo
0?ooo`3o0?oooe`0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`3j0?ooo`030000003o
ool0oooo05h0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`3j0?ooo`030000003oool0
oooo05h0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`3g0?ooo`030000003oool0oooo
0640oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`3g0?ooo`030000003oool0oooo0640
oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`3e0?ooo`030000003oool0oooo06<0oooo
0@0000010?ooo`00D03oool00`000000oooo0?ooo`3e0?ooo`030000003oool0oooo06<0oooo0@00
00010?ooo`00D03oool00`000000oooo0?ooo`3o0?oooe`0oooo0@0000010?ooo`00D03oool20000
0?<0oooo00<000000?ooo`3oool0I@3oool200000040oooo001@0?ooo`030000003oool0oooo0?80
oooo00<000000?ooo`3oool0IP3oool100000040oooo001@0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0o`3ooom=0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`3o0?ooodd0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0?l0ooooC03oool100000040oooo001@0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`4000000@3oool00500oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`3o0?oood`0oooo0@0000010?ooo`00D03oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooC03oool100000040oooo001@0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`4000000@3oool00500oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?oood/0oooo0@0000010?ooo`00D03oool00`00
0000oooo0?ooo`3o0?oooe`0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0?l0ooooBP3oool100000040oooo001@0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0o`3ooom:0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`3o0?ooodP0oooo0@0000010?ooo`00D03oool200000180oooo00<00000
0?ooo`3oool0o`3ooom70?ooo`8000000@3oool00500oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`3o0?ooodL0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0?l0ooooA`3oool100000040oooo001@0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0o`3ooom60?ooo`4000000@3oool00500oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`3o0?ooodH0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0?l0ooooA@3oool100000040oooo001@0?ooo`030000003oool0oooo
01@0oooo0P00003o0?ooodH0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo0?l0ooooA03oool100000040oooo001@0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`240?ooo`4000000@3oool00500oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo08@0oooo0@00
00010?ooo`00D03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0;H0oooo00<00000
0?ooo`3oool0Q`3oool100000040oooo001@0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0]P3oool00`000000oooo0?ooo`270?ooo`4000000@3oool00500oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo08X0oooo0@0000010?ooo`00
D03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool0
RP3oool100000040oooo001@0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0[@3o
ool00`000000oooo0?ooo`2=0?ooo`4000000@3oool00500oooo0P00000L0?ooo`800000Z`3oool0
10000000oooo0?ooo`00002>0?ooo`8000000@3oool00500oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo0900oooo0@0000010?ooo`00D03oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0T`3oool10000
0040oooo001@0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0Y03oool00`000000
oooo0?ooo`2C0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`2P0?ooo`030000003oool0oooo09H0oooo0@0000010?ooo`00D03oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0000009d0oooo00@000000?ooo`3oool00000V03oool100000040oooo
001@0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?oo
o`2I0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo09`0oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0S0?oo
o`800000U03oool010000000oooo0?ooo`00002N0?ooo`4000000@3oool00500oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo09l0oooo0@0000010?oo
o`00D03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0XP3oool100000040oooo001@0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`000000
RP3oool010000000oooo0?ooo`00002T0?ooo`4000000@3oool00500oooo00<000000?ooo`3oool0
:03oool00`000000oooo000000260?ooo`030000003oool000000:L0oooo0@0000010?ooo`00D03o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0Y`3o
ool100000040oooo001@0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0ZP3oool1
00000040oooo001@0?ooo`800000[03oool010000000oooo0?ooo`00002[0?ooo`8000000@3oool0
0500oooo00<000000?ooo`3oool0Z03oool010000000oooo0?ooo`00002_0?ooo`4000000@3oool0
0500oooo00<000000?ooo`3oool0Y@3oool010000000oooo0?ooo`00002b0?ooo`4000000@3oool0
0500oooo00<000000?ooo`3oool0XP3oool010000000oooo0?ooo`00002e0?ooo`4000000@3oool0
0500oooo00<000000?ooo`3oool0W`3oool010000000oooo0?ooo`00002h0?ooo`4000000@3oool0
0500oooo00<000000?ooo`3oool0W03oool010000000oooo0?ooo`00002k0?ooo`4000000@3oool0
0500oooo00<000000?ooo`3oool0V@3oool010000000oooo0?ooo`00002n0?ooo`4000000@3oool0
0500oooo00<000000?ooo`3oool0UP3oool010000000oooo0?ooo`0000310?ooo`4000000@3oool0
0500oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
0<80oooo0@0000010?ooo`00D03oool00`000000oooo0?ooo`0n0?ooo`040000003oool0oooo0000
0?l0oooo6P3oool100000040oooo00120?ooo`040;md00000000000007Boo`X0oooo00<000000?oo
o`3oool0@@3oool01@000000oooo0000003oool000000?l0oooo5P3oool100000040oooo00110?oo
o`060=nLB000M;l0oooo0?oOW0180000B9cO2@3oool00`000000oooo0?ooo`130?ooo`030000003o
ool000000080oooo00<000000?ooo`000000o`3ooolA0?ooo`4000000@3oool00400oooo00<0oooO
09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030000003oool0oooo04P0oooo00D00000
0?ooo`000000oooo0000003o0?ooo`l0oooo0@0000010?ooo`00@03oool00`3ooml0W4P004RLg`02
0?ooo`040?oog`2LB00004RL0=ooo`L0oooo00<000000?ooo`3oool0C03oool01P000000oooo0?oo
o`000000oooo00000080oooo00<000000?ooo`3oool0o`3oool50?ooo`4000000@3oool00400oooo
00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`070?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`030000003oool000000080oooo
00<000000?ooo`3oool03@3oool010000000oooo0?ooo`0000020?ooo`030000003oool000000>@0
oooo0@0000010?ooo`00@@3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00L0oooo
0`00001F0?ooo`060000003oool0oooo0000003oool000000P3oool01P000000oooo0?ooo`000000
oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`000000hP3oool300000040oooo00110?ooo`030=nLB00004P0W=oo0080
oooo00<0oooO09a80000M;l01`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool000000080
oooo00H000000?ooo`3oool000000?ooo`00003_0?ooo`4000000@3oool00440oooo00<0omnL04P0
0018W=l00`3oool00`2oM00004RL0=ooo`060?ooo`030000003oool0oooo0?l0ooooG03oool10000
0040oooo00110?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool01P3oool00`00
0000oooo0?ooo`3o0?oooe`0oooo0@0000010?ooo`00@P3oool00`3ogi`0B00007Boo`020?ooo`03
0=nLB000M;l0oooo00H0oooo00<000000?ooo`3oool0o`3ooomL0?ooo`4000000@3oool004<0oooo
00H0gia80000M02oool0oooO09a80018W=l70?ooo`030000003oool0oooo0?l0ooooG03oool10000
0040oooo00140?ooo`040=nLB00000000000001d_`P0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`170?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`170?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`00D03oool00`000000
oooo0000000>0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool100000040
oooo001@0?ooool00000H00000010?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-0.285636, -0.274674, \
0.00101416, 0.00101416}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Anharmonic oscillator", "Subsubsection"],

Cell[TextData[{
  "Next, consider a driven but undamped anharmonic oscillator.  The phase \
trajectories are not closed and fill regions of the phase space that depend \
upon the dynamical parameters.  A frequency scan is shown below for initial \
conditions ",
  Cell[BoxData[
      \(TraditionalForm\`{x\_0, v\_0} = {0, 1}\)]],
  ".  You should try other scans as well."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        duffingPlot[1, 1, 0, 1, \[Omega], 1, 0, 1, 100, 
          MaxSteps \[Rule] 10\^4], {\[Omega], 0.5, 1.5, 0.5}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.499619 0.457335 0.500382 0.73609 [
[.04228 -0.0125 -9.34375 -15.6875 ]
[.04228 -0.0125 9.34375 0 ]
[.27095 -0.0125 -13.8438 -15.6875 ]
[.27095 -0.0125 13.8438 0 ]
[.49962 -0.0125 -5 -15.6875 ]
[.49962 -0.0125 5 0 ]
[.72829 -0.0125 -9.5 -15.6875 ]
[.72829 -0.0125 9.5 0 ]
[.95695 -0.0125 -5 -15.6875 ]
[.95695 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.9688 -31.375 ]
[.5 -0.0125 21.9688 -15.6875 ]
[-0.0125 .05873 -27.9375 -7.84375 ]
[-0.0125 .05873 0 7.84375 ]
[-0.0125 .20595 -27.6875 -7.84375 ]
[-0.0125 .20595 0 7.84375 ]
[-0.0125 .35316 -27.6875 -7.84375 ]
[-0.0125 .35316 0 7.84375 ]
[-0.0125 .50038 -10 -7.84375 ]
[-0.0125 .50038 0 7.84375 ]
[-0.0125 .6476 -19 -7.84375 ]
[-0.0125 .6476 0 7.84375 ]
[-0.0125 .79482 -19 -7.84375 ]
[-0.0125 .79482 0 7.84375 ]
[-0.0125 .94204 -19.25 -7.84375 ]
[-0.0125 .94204 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -43.625 -20.4688 ]
[-0.01875 .5 -27.9375 20.4688 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -43.9375 0 ]
[.5 1.0125 43.9375 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04228 0 m
.04228 .00625 L
s
gsave
.04228 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.27095 0 m
.27095 .00625 L
s
gsave
.27095 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.49962 0 m
.49962 .00625 L
s
gsave
.49962 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.72829 0 m
.72829 .00625 L
s
gsave
.72829 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.95695 0 m
.95695 .00625 L
s
gsave
.95695 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.08802 0 m
.08802 .00375 L
s
.13375 0 m
.13375 .00375 L
s
.17948 0 m
.17948 .00375 L
s
.22522 0 m
.22522 .00375 L
s
.31669 0 m
.31669 .00375 L
s
.36242 0 m
.36242 .00375 L
s
.40815 0 m
.40815 .00375 L
s
.45389 0 m
.45389 .00375 L
s
.54535 0 m
.54535 .00375 L
s
.59109 0 m
.59109 .00375 L
s
.63682 0 m
.63682 .00375 L
s
.68255 0 m
.68255 .00375 L
s
.77402 0 m
.77402 .00375 L
s
.81975 0 m
.81975 .00375 L
s
.86549 0 m
.86549 .00375 L
s
.91122 0 m
.91122 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.9688 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
102.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05873 m
.00625 .05873 L
s
gsave
-0.0125 .05873 -88.9375 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .20595 m
.00625 .20595 L
s
gsave
-0.0125 .20595 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .35316 m
.00625 .35316 L
s
gsave
-0.0125 .35316 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .50038 m
.00625 .50038 L
s
gsave
-0.0125 .50038 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .6476 m
.00625 .6476 L
s
gsave
-0.0125 .6476 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .79482 m
.00625 .79482 L
s
gsave
-0.0125 .79482 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .94204 m
.00625 .94204 L
s
gsave
-0.0125 .94204 -80.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .09553 m
.00375 .09553 L
s
0 .13234 m
.00375 .13234 L
s
0 .16914 m
.00375 .16914 L
s
0 .24275 m
.00375 .24275 L
s
0 .27955 m
.00375 .27955 L
s
0 .31636 m
.00375 .31636 L
s
0 .38997 m
.00375 .38997 L
s
0 .42677 m
.00375 .42677 L
s
0 .46358 m
.00375 .46358 L
s
0 .53719 m
.00375 .53719 L
s
0 .57399 m
.00375 .57399 L
s
0 .6108 m
.00375 .6108 L
s
0 .6844 m
.00375 .6844 L
s
0 .72121 m
.00375 .72121 L
s
0 .75801 m
.00375 .75801 L
s
0 .83162 m
.00375 .83162 L
s
0 .86843 m
.00375 .86843 L
s
0 .90523 m
.00375 .90523 L
s
0 .02192 m
.00375 .02192 L
s
0 .97884 m
.00375 .97884 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -117.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
81.4688 11.8438 translate
90 rotate
-81.4688 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(velocity) show
99.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.04228 .99375 m
.04228 1 L
s
.27095 .99375 m
.27095 1 L
s
.49962 .99375 m
.49962 1 L
s
.72829 .99375 m
.72829 1 L
s
.95695 .99375 m
.95695 1 L
s
.125 Mabswid
.08802 .99625 m
.08802 1 L
s
.13375 .99625 m
.13375 1 L
s
.17948 .99625 m
.17948 1 L
s
.22522 .99625 m
.22522 1 L
s
.31669 .99625 m
.31669 1 L
s
.36242 .99625 m
.36242 1 L
s
.40815 .99625 m
.40815 1 L
s
.45389 .99625 m
.45389 1 L
s
.54535 .99625 m
.54535 1 L
s
.59109 .99625 m
.59109 1 L
s
.63682 .99625 m
.63682 1 L
s
.68255 .99625 m
.68255 1 L
s
.77402 .99625 m
.77402 1 L
s
.81975 .99625 m
.81975 1 L
s
.86549 .99625 m
.86549 1 L
s
.91122 .99625 m
.91122 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .05873 m
1 .05873 L
s
.99375 .20595 m
1 .20595 L
s
.99375 .35316 m
1 .35316 L
s
.99375 .50038 m
1 .50038 L
s
.99375 .6476 m
1 .6476 L
s
.99375 .79482 m
1 .79482 L
s
.99375 .94204 m
1 .94204 L
s
.125 Mabswid
.99625 .09553 m
1 .09553 L
s
.99625 .13234 m
1 .13234 L
s
.99625 .16914 m
1 .16914 L
s
.99625 .24275 m
1 .24275 L
s
.99625 .27955 m
1 .27955 L
s
.99625 .31636 m
1 .31636 L
s
.99625 .38997 m
1 .38997 L
s
.99625 .42677 m
1 .42677 L
s
.99625 .46358 m
1 .46358 L
s
.99625 .53719 m
1 .53719 L
s
.99625 .57399 m
1 .57399 L
s
.99625 .6108 m
1 .6108 L
s
.99625 .6844 m
1 .6844 L
s
.99625 .72121 m
1 .72121 L
s
.99625 .75801 m
1 .75801 L
s
.99625 .83162 m
1 .83162 L
s
.99625 .86843 m
1 .86843 L
s
.99625 .90523 m
1 .90523 L
s
.99625 .02192 m
1 .02192 L
s
.99625 .97884 m
1 .97884 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .50038 m
1 .50038 L
s
.49962 0 m
.49962 1 L
s
gsave
.5 1.0125 -104.938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Duffing) show
102.938 15.813 moveto
(Equation) show
146.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.78368 .08113 m
.75203 .08775 L
.72397 .10154 L
.69304 .12465 L
.66571 .15179 L
.62266 .20786 L
.58481 .27288 L
.55392 .34114 L
.53224 .40182 L
.52 .44216 L
.51637 .45379 L
.51317 .46193 L
.51035 .46519 L
.50771 .46348 L
.50431 .45579 L
.50035 .44332 L
.47211 .35613 L
.44156 .28416 L
.40268 .21299 L
.37638 .17396 L
.34427 .13445 L
.31079 .10197 L
.27772 .07845 L
.24227 .06315 L
.20922 .05916 L
.19095 .06182 L
.17129 .06912 L
.13683 .09537 L
.10723 .13613 L
.0799 .19694 L
.06099 .26219 L
.04585 .34604 L
.04023 .39784 L
.03681 .45438 L
.03724 .55694 L
.04113 .61286 L
.047 .6628 L
.05582 .71428 L
.06779 .76442 L
.08009 .80318 L
.09521 .83973 L
.12647 .89067 L
.16028 .92119 L
.19307 .93379 L
.22803 .93296 L
.24747 .92706 L
.26494 .91875 L
.29762 .89595 L
.3267 .86794 L
.38296 .79177 L
Mistroke
.40877 .74514 L
.42869 .70217 L
.45797 .62127 L
.47292 .56313 L
.48012 .52339 L
.48107 .51719 L
.48174 .51324 L
.48235 .51104 L
.48285 .51125 L
.48386 .51615 L
.48565 .52781 L
.49236 .56422 L
.50854 .62671 L
.53442 .69935 L
.56652 .76831 L
.61301 .84478 L
.64068 .88074 L
.67339 .91546 L
.70668 .94252 L
.73876 .96057 L
.77541 .97079 L
.81484 .9675 L
.85116 .94825 L
.88224 .9154 L
.91504 .85678 L
.93105 .81436 L
.94388 .76973 L
.96193 .67565 L
.97221 .5642 L
.97287 .4528 L
.96927 .3913 L
.96355 .33722 L
.94625 .24119 L
.92317 .16494 L
.90779 .12948 L
.88989 .09804 L
.85464 .05785 L
.8339 .04425 L
.81397 .03674 L
.79185 .0339 L
.76799 .03655 L
.73098 .05106 L
.69869 .07314 L
.66378 .10645 L
.63363 .14335 L
.5878 .21608 L
.55007 .297 L
.52253 .37899 L
.51366 .41482 L
.5072 .44853 L
Mistroke
.50399 .47178 L
.50295 .48243 L
.50238 .49057 L
.50208 .50185 L
.50242 .50687 L
.50272 .50719 L
.50298 .50576 L
.50316 .49862 L
.50247 .48456 L
.50148 .47384 L
.50008 .46229 L
.49651 .43947 L
.4905 .40988 L
.47034 .33819 L
.45313 .29157 L
.43359 .2472 L
.40833 .19894 L
.37592 .148 L
.34164 .10474 L
.30664 .07048 L
.27078 .04536 L
.252 .03635 L
.23092 .02986 L
.19375 .02866 L
.1596 .0411 L
.12383 .07205 L
.10514 .09788 L
.08929 .12675 L
.06133 .20062 L
.04851 .25068 L
.03887 .30143 L
.02713 .40352 L
.02381 .51818 L
.02853 .61499 L
.04103 .71234 L
.05927 .79337 L
.08062 .85539 L
.1102 .9116 L
.1465 .9522 L
.18315 .97184 L
.21794 .97567 L
.25797 .96565 L
.27995 .9544 L
.29959 .94114 L
.33404 .91084 L
.36743 .87279 L
.41713 .79853 L
.45864 .71461 L
.48849 .63194 L
.49931 .59214 L
Mistroke
.50603 .56134 L
.51006 .53801 L
.51254 .51915 L
.51361 .50791 L
.51399 .50352 L
.51424 .50484 L
.51478 .51134 L
.51608 .5236 L
.51884 .54303 L
.52277 .56469 L
.5289 .59219 L
.54599 .65124 L
.5811 .73847 L
.60425 .783 L
.62904 .82309 L
.65388 .85686 L
.68385 .89012 L
.71645 .91757 L
.75294 .93749 L
.77212 .9431 L
.79318 .94505 L
.81305 .94244 L
.83125 .9358 L
.86451 .91109 L
.89697 .86609 L
.912 .83523 L
.92659 .79627 L
.94793 .71209 L
.95686 .6566 L
.96325 .59427 L
.96614 .53902 L
.96653 .47771 L
.96427 .42119 L
.95987 .36917 L
.94599 .27836 L
.92366 .19459 L
.90818 .15524 L
.89237 .12448 L
.86337 .08521 L
.8288 .05899 L
.79119 .04888 L
.75579 .05311 L
.72024 .0686 L
.70104 .08121 L
.68418 .09463 L
.6261 .15754 L
.59809 .19776 L
.57181 .24247 L
.53475 .32087 L
.49766 .43141 L
Mistroke
.4928 .44973 L
.4907 .45752 L
.489 .46333 L
.48626 .47016 L
.48406 .47118 L
.48178 .46735 L
.47928 .45959 L
.47075 .42794 L
.45591 .37897 L
.42941 .30999 L
.3975 .2455 L
.3591 .18521 L
.33625 .15636 L
.31018 .12911 L
.27949 .10454 L
.2499 .08864 L
.21657 .08061 L
.19764 .08125 L
.18031 .08559 L
.14924 .10389 L
.11851 .13905 L
.09394 .18491 L
.07439 .23967 L
.05763 .31145 L
.04601 .39897 L
.04162 .49862 L
.04289 .55549 L
.04649 .60712 L
.05884 .696 L
.06772 .73675 L
.0794 .77769 L
.10343 .83666 L
.13381 .88289 L
.16538 .90992 L
.19576 .92153 L
.22489 .92219 L
.25575 .91348 L
.28402 .89795 L
.30862 .87894 L
.33584 .85213 L
.36296 .81923 L
.40504 .75456 L
.4389 .68732 L
.46407 .62432 L
.47827 .58179 L
.48813 .55112 L
.49199 .54212 L
.49511 .53913 L
.49806 .54115 L
.50157 .54853 L
Mistroke
.5058 .56089 L
.51084 .57693 L
.52405 .61728 L
.54617 .67485 L
.57991 .74517 L
.60218 .78342 L
.63031 .82454 L
.65888 .8592 L
.68847 .88811 L
.71799 .91001 L
.75165 .9262 L
.78305 .93206 L
.81216 .92832 L
.84288 .91282 L
.87487 .88031 L
.90473 .82813 L
.9281 .76262 L
.94403 .69287 L
.95519 .61028 L
.95974 .53518 L
.95926 .45171 L
.95238 .36421 L
.93814 .27879 L
.91891 .20967 L
.89737 .15868 L
.86927 .11558 L
.8405 .08949 L
.80735 .07567 L
.77117 .07603 L
.75322 .08127 L
.73398 .09027 L
.70031 .11396 L
.66976 .14397 L
.64381 .17598 L
.59999 .24564 L
.56952 .30935 L
.54477 .37634 L
.53031 .42748 L
.52178 .46562 L
.52043 .47203 L
.51924 .47709 L
.51752 .48142 L
.51603 .47984 L
.5144 .47375 L
.50794 .44347 L
.49378 .38899 L
.46586 .30978 L
.4248 .2241 L
.40002 .18288 L
.37331 .14501 L
Mistroke
.34541 .11178 L
.31226 .08006 L
.28009 .05718 L
.24891 .04277 L
.21104 .0366 L
.1767 .04357 L
.15805 .05337 L
.13842 .06919 L
.10513 .11249 L
.07958 .1659 L
.05646 .24054 L
.03912 .33355 L
.03012 .43005 L
.02846 .52402 L
.03274 .60873 L
.04427 .70058 L
.06119 .77777 L
.08509 .84697 L
.11683 .90392 L
.13436 .92459 L
.15412 .94108 L
.1913 .95659 L
.22689 .9562 L
.2638 .94278 L
.29412 .92291 L
.32545 .89441 L
.35951 .85404 L
.38711 .81346 L
.41297 .76774 L
.43639 .71792 L
.45384 .67326 L
.4665 .63457 L
.48277 .56906 L
.48694 .54522 L
.48967 .52421 L
.49089 .50954 L
.4912 .50069 L
.491 .49634 L
.49082 .49673 L
.4907 .49882 L
.49088 .50743 L
.49189 .52094 L
.49395 .5384 L
.49765 .5614 L
.5092 .61296 L
.53028 .68023 L
.56536 .76243 L
.59092 .8097 L
.61897 .85318 L
.64757 .8901 L
Mistroke
.68087 .92478 L
.69911 .94015 L
.71994 .95455 L
.758 .97189 L
.77987 .97619 L
.80352 .97564 L
.8257 .96959 L
.84565 .95888 L
.88007 .92594 L
.90916 .87872 L
.93646 .80854 L
.95866 .71456 L
.96667 .66103 L
.97269 .59974 L
.97619 .4839 L
.97025 .37221 L
.95695 .2768 L
.9351 .18779 L
.90833 .12029 L
.88044 .07516 L
.84711 .04269 L
.80894 .02581 L
.78724 .02381 L
.76761 .02606 L
.72993 .04 L
.6959 .06249 L
.66553 .09007 L
.63584 .12396 L
.58957 .19192 L
.55033 .26839 L
.51986 .34794 L
.50801 .38816 L
.49995 .42183 L
.49493 .44807 L
.49162 .47077 L
.49058 .48029 L
.48985 .48894 L
.48938 .49929 L
.4894 .50232 L
.48953 .50329 L
.48965 .50203 L
.48966 .49903 L
.48917 .48854 L
.48772 .47336 L
.48458 .45102 L
.47892 .42124 L
.46048 .35259 L
.43311 .27981 L
.39425 .20289 L
.33859 .12394 L
Mistroke
.30592 .09064 L
.28684 .07529 L
.26817 .06321 L
.23074 .04812 L
.19595 .04616 L
.16362 .0567 L
.13066 .08291 L
.10455 .11855 L
.07893 .17238 L
.0564 .24599 L
.03912 .34089 L
.03048 .44057 L
.02959 .53551 L
.03634 .63684 L
.052 .73599 L
.07386 .8157 L
.09866 .87364 L
.13239 .92267 L
.15297 .94127 L
.17261 .95292 L
.2096 .96171 L
.22836 .9606 L
.24886 .95564 L
.26963 .94693 L
.28891 .93574 L
.32355 .90847 L
.35802 .87234 L
.39171 .82792 L
.44107 .74328 L
.4739 .66812 L
.50834 .55365 L
.51227 .53603 L
.51477 .52574 L
.51577 .52289 L
.51675 .52158 L
.51782 .52225 L
.51886 .52481 L
.52122 .5341 L
.52495 .55075 L
.53666 .59689 L
.55687 .65845 L
.5851 .72461 L
.62199 .79129 L
.66507 .84986 L
.69308 .87878 L
.72052 .90051 L
.75216 .91733 L
.78644 .92481 L
.81784 .92041 L
.85045 .90186 L
Mistroke
.87934 .86981 L
.90303 .82794 L
.92672 .76342 L
.93761 .72046 L
.94585 .67729 L
.9561 .59094 L
.95951 .49414 L
.95531 .40012 L
.94973 .3492 L
.94259 .30451 L
.92498 .23077 L
.9007 .16665 L
.87525 .12343 L
.84894 .09501 L
.81835 .07684 L
.7844 .07101 L
.75046 .07739 L
.73158 .08555 L
.71438 .09562 L
.68114 .12194 L
.64837 .15655 L
.59768 .22826 L
.56203 .29498 L
.51901 .40408 L
.50726 .44094 L
.50282 .45343 L
.49941 .45984 L
.4967 .46114 L
.49372 .45808 L
.48994 .44934 L
.48566 .43658 L
.45796 .35519 L
.42927 .28899 L
.39356 .22385 L
.36964 .18807 L
.34058 .15168 L
.31303 .12371 L
.28056 .09872 L
.24881 .08287 L
.21837 .07636 L
.18609 .08012 L
.15238 .0984 L
.12294 .13018 L
.09779 .17407 L
.07828 .22468 L
.06116 .29062 L
.04742 .37988 L
.04157 .47075 L
.04337 .57214 L
.04814 .62736 L
Mistroke
.05478 .67555 L
.07291 .75787 L
.08604 .79787 L
.09983 .83017 L
.11587 .85898 L
.1315 .88024 L
.15052 .89904 L
.16918 .91132 L
.20171 .9209 L
.23639 .9175 L
.26542 .90546 L
.29607 .88453 L
.32691 .85528 L
.35706 .81858 L
.40267 .74568 L
.43692 .6722 L
.46088 .60458 L
.47315 .56082 L
.47728 .54463 L
.48047 .53317 L
.48195 .52932 L
.48341 .52742 L
.4847 .52781 L
.48597 .52999 L
.48741 .53405 L
.48892 .53932 L
.49333 .55651 L
.50735 .6071 L
.52975 .67117 L
.56171 .74242 L
.60807 .82131 L
.63509 .85773 L
.66727 .89343 L
.68701 .91142 L
.70581 .9258 L
.7242 .93722 L
.74429 .9466 L
.78047 .95468 L
.81422 .95054 L
.83456 .94159 L
.85324 .92823 L
.88618 .88962 L
.91414 .83543 L
.93567 .77121 L
.95354 .68696 L
.9648 .58649 L
.96759 .485 L
.96563 .42773 L
.96158 .37602 L
.94879 .28724 L
Mistroke
.92832 .20558 L
.90505 .14669 L
.87982 .10458 L
.84941 .07322 L
.81468 .05585 L
.77914 .05364 L
.75908 .05822 L
.74067 .06575 L
.70472 .08902 L
.68558 .10588 L
.66891 .12308 L
.61388 .19779 L
.57359 .27445 L
.51416 .48358 L
.51329 .4942 L
.51304 .49888 L
.51299 .49918 L
.5129 .49764 L
.51243 .49029 L
.51124 .47792 L
.50873 .45925 L
.50479 .43675 L
.49962 .41262 L
.48106 .3469 L
.44845 .26372 L
.40439 .18107 L
.35257 .10978 L
.32004 .07622 L
.28749 .05068 L
.24992 .03144 L
.22832 .02572 L
.20849 .02424 L
.16877 .03373 L
.14693 .04739 L
.12745 .06583 L
.09432 .11495 L
.06439 .18878 L
.04435 .2686 L
.03152 .35234 L
.02423 .45187 L
.02464 .55937 L
.03176 .65049 L
.04376 .72898 L
.06229 .80487 L
.08736 .87126 L
.11967 .92482 L
.13954 .94611 L
.15859 .96024 L
.19473 .97348 L
.23342 .97166 L
Mistroke
.26751 .95862 L
.29822 .93867 L
.3301 .91015 L
.3617 .87395 L
.41648 .78988 L
.45912 .69776 L
.48316 .62566 L
.49228 .58966 L
.49822 .56019 L
.50224 .5337 L
.50345 .52275 L
.50428 .5127 L
.50474 .50008 L
.50445 .4945 L
.50415 .49408 L
.50389 .49574 L
.50381 .50422 L
.50417 .51196 L
.50487 .52094 L
.50614 .53277 L
.50817 .54745 L
.51301 .57457 L
.5195 .60338 L
.54262 .67929 L
.57602 .75805 L
.61909 .8335 L
.64794 .87299 L
.68206 .91033 L
.71697 .93871 L
.75035 .95647 L
.77138 .96266 L
.7909 .96464 L
.81232 .96222 L
.8347 .95389 L
.8709 .92509 L
.89015 .89992 L
.90692 .87047 L
.93433 .80025 L
.94581 .75782 L
.95634 .70625 L
.96888 .60566 L
.97303 .50481 L
.97196 .44661 L
.96816 .38642 L
.95477 .28538 L
.9439 .23454 L
.93182 .19172 L
.91662 .15027 L
.89843 .11283 L
.86431 .06632 L
Mistroke
.84364 .04897 L
.82398 .03834 L
.78707 .03103 L
.74801 .03819 L
.71397 .05506 L
.68352 .07776 L
.65218 .10841 L
.62133 .14596 L
.57266 .22231 L
.53311 .30568 L
.50804 .37635 L
.49391 .42939 L
.48656 .46585 L
.48458 .47749 L
.48335 .48435 L
.48231 .48758 L
.48123 .48535 L
.48 .47885 L
.47807 .46753 L
.46947 .42546 L
.45348 .3681 L
.43068 .30618 L
.39559 .23342 L
.34487 .15667 L
.31467 .12287 L
.29609 .10603 L
.27841 .09277 L
.2457 .0755 L
.20943 .06823 L
.17739 .0738 L
.14469 .09386 L
.11559 .12785 L
.09183 .17178 L
.06866 .23749 L
.05202 .3124 L
.04182 .3905 L
.03731 .46695 L
.03795 .55235 L
.04496 .64005 L
.05828 .72147 L
.07878 .79679 L
.10306 .85381 L
.12847 .89288 L
.16102 .92293 L
.18027 .9328 L
.19839 .93771 L
.23185 .93721 L
.26691 .92523 L
.29739 .90639 L
.32889 .87918 L
Mistroke
.38482 .81143 L
.42627 .74278 L
.45569 .68099 L
.49594 .56711 L
.50024 .55311 L
.50385 .54289 L
.50715 .53734 L
.50999 .53758 L
.51282 .54241 L
.51592 .55088 L
.52597 .58358 L
.56157 .68105 L
.59438 .74802 L
.63353 .81018 L
.6588 .84233 L
.68905 .87354 L
.71984 .89743 L
.74987 .91287 L
.77014 .91862 L
.79225 .92015 L
.81307 .91657 L
.83196 .90852 L
.84863 .897 L
.86627 .87948 L
.88371 .85557 L
.89884 .82803 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00g03oool00`3ooml0W4P0000000020000000307Bo
o`3oool0oooo0<`0oooo003N0?ooo`030?noM00007@0_ooo0<l0oooo003N0?ooo`030?oo_`1d0000
M;oo0<l0oooo003N0?ooo`030?oog`2LB000B9cO0<l0oooo003O0?ooo`030=nLB000000000000080
000000<0M;oo0?ooo`3oool00P3oool01@3o_g@000000000000004P0W=oo0080oooo00<0oono07@0
000000000P0000003@18W=l0oooo0?ooo`3oool0_g@00000000004P0W=oo0?ooo`3o_g@000000000
B02Lgol00P3oool0102oM00000000000B02Lgol20?ooo`050?noM000000000000000B02Lgol00`3o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000000007Bo09H0oooo003O0?ooo`070?noM00004P0
W=oo0?ooo`3ooml0W4P0001d_`020?ooo`0?0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`3oool0
oooO09a8001d_ol0oooo0?oOW0180000M;oo0080oooo01L0gia80018W03Ooml0W7BL0=ooo`3o_g@0
001809cOg`2LM9`0gooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0
B000001d_`020?ooo`030?noM00007@0_ooo0080oooo00@0gia80018W03O_g@0M;ooU@3oool00=l0
oooo00<0oono07@0001d_ol00P3oool01`3ooml0W4P004RLg`3oool0gia80018W03Oool00P3oool0
2P3ogi`0B00004RLg`3oool0_gAd0;ooo`3oool0oono07@0001d_ol20?ooo`030?noM00004P0W=oo
0080oooo00<0oono07@0001d_ol00`3oool00`3o_g@0001809cOo`020?ooo`030=nLB000B9`0gooo
0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol0UP3o
ool00=l0oooo00<0oooO09a80018W=l00`3oool01P3ogi`0B01809cOo`3o_g@0001d0;ooo`<0oooo
00<0gia80000M02oool00`3oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo
00<0_g@0001d_`3oool00P3oool00`3ookl0M00004RLg`020?ooo`030?noM00007@0_ooo00<0oooo
00/0gia80000M02oool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`2F0?ooo`00h03oool0
0`3OW4P0001d0;ooo`020?ooo`060?oog`2LB000B9cO0?oo_`1d0000M;oo0`3oool00`3ogi`0B018
09cOo`020?ooo`030?noM00004P0W=oo00@0oooo00<0_g@00018W03Oool00P3oool00`3OW4P004RL
0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3ookl0M00007Boo`030?ooo`070?oOW01804P0W=oo
0?ooo`3OW4P004Q804Qd_`020?ooo`030;md0000M;l0oooo09D0oooo003P0?ooo`040?noM0000000
04RL0=ooo`80oooo00H0gia8001d_`3oool0gia80000M02oool20?ooo`0:0?oo_`1d0000M;oo0?oo
o`3ogi`0B01809cOo`3oool0giad09cOo`80oooo00<0gia80000B02Lgol00P3oool00`3ogi`0B018
09cOo`030?ooo`030=nLB00004P0W=oo0080oooo00<0gia80000M02oool00P3oool0303ookl0M000
07Boo`3oool0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;oooiD0oooo003P0?ooo`080?oo_`1d
0000M9bL04P0M02oool0oooO09a80000M;l20?ooo`0>0;md000007@0_ooo0?ooo`3o_g@0001d0;oo
o`3oool0omnL04P0B02Lgol0oooO09a8001d_ol20?ooo`030?oOW0180000B9cO0080oooo00<0oooO
09a80018W=l00`3oool00`3ogi`0B00004RLg`030?ooo`0@0;md000007@0_ooo0?ooo`3o_g@0001d
0;ooo`3oool0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOoiD0oooo003O0?ooo`090?oOW018
0000000004RLg`3ookl0M0000000000007@0_ooo00<0oooo00D0okmd000000000000000007Boo`03
0?ooo`070;md00000000000000000018W=l0oooo0?noM002000000040018W03Oool0oono07@000<0
000000H0M;oo0?noM000000000000018W03Oool30?ooo`0?0?noM000000000000000001d_ol0oooo
0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo09D0oooo003o0?ooo`40oooo00<0okmd
0000M02oool0[@3oool00?l0oooo0P3oool00`3OW7@0W=oo0?ooo`2/0?ooo`00n`3oool0103ookl0
M0000018W03Oool70?ooo`040?oo_`1d000004RL0=ooojH0oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo001L0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0A03o
ool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00H0omnL04P000000000
00000018W03Oooln0?ooo`040;md00000000000007BoodH0oooo00@0_g@0000000000000M;oo0`3o
ool00`3ogi`0B00007Boo`020?ooo`060?oOW0180000000000000000B9`0gooo@`3oool00`3ookl0
M000000000020000000304RLg`3oool0oooo0140oooo001N0?ooo`030?noM0000000M;oo04H0oooo
00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo0080oooo00H0okmd0000
001d_ol0oooo0?oOW018M;lm0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cOA03oool01P3OW4P0
07Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00P3oool01P3o_g@0000007Boo`3o
ool0omnL04Qd_dD0oooo00<0okmd0000001d_ol0503oool005h0oooo00<0oooO09a80000M;l0A@3o
ool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00/0oooo00<0okmd04RLg`3oool0>P3o
ool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo0480oooo00<0oooO09a80018W=l00P3o
ool00`3o_g@0001809cOo`0;0?ooo`030?noM018W=l0oooo04<0oooo00<0oooO09a80000M;l0503o
ool005l0oooo00<0gia80018W03Oool0A03oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB000
04RL0=ooo`X0oooo00<0oono07@0M02oool0>P3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2L
B00004RL0=oood40oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool:0?ooo`03
0?oo_`1d07@0_ooo04@0oooo00<0gia80018W03Oool04`3oool004l0oooo00<0oooO09a800000000
1`0000000`18W=l0oooo0?ooo`030?ooo`030?oOW01804P0W=oo03L0oooo00<0oooO09a800000000
1`0000001P18W=l0oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol02P3oool00`3o
oml0W4P007Boo`0j0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol0@@3oool00`3o
oml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00X0oooo00<0oooO09a8001d_ol0A03oool00`3o
gi`0B01809cOo`0C0?ooo`00G`3oool00`3ookl0M00007Boo`150?ooo`030;md0000B9`0gooo0080
oooo00<0omnL04P00018W=l02P3oool00`3ookl0M00004RLg`0k0?ooo`030;md0000B9`0gooo0080
oooo00<0omnL04P00018W=l0@P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00X0
oooo00<0oono07@00018W=l0A03oool00`3ookl0M00007Boo`0C0?ooo`00H03oool00`2oM00007Bo
0?ooo`140?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l02P3oool00`3o_g@00000
07Boo`0k0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0@P3oool00`3OW4P00018
09cOo`020?ooo`030?oog`2LB00007Bo00X0oooo00<0okmd0000001d_ol0A@3oool00`2oM00007Bo
0?ooo`0B0?ooo`00H03oool00`3OW4P004RL0=ooo`140?ooo`030?oOW0180000B9cO00<0oooo00<0
_g@00018W03Oool01P3oool01P3ogml0gooo0?noM0000000001d0;oooc/0oooo00<0omnL04P00018
W=l00`3oool00`2oM00004RL0=ooo`110?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03O
ool01P3oool01P3ogml0gooo0?noM0000000001d0;ooodD0oooo00<0gia80018W03Oool04P3oool0
0600oooo00<0omnL04P0B02Lgol0A03oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0
gooo00H0oooo00D0oono07@000000000001809cOo`0l0?ooo`040?oog`2LB00004RL0=ooo`80oooo
00<0gia80018W03Oool0@@3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00H0
oooo00D0oono07@000000000001809cOo`160?ooo`030?oOW01804P0W=oo0180oooo001P0?ooo`03
0?oo_`1d0000M;oo04D0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`070?ooo`03
0=nLW02oool0oooo03h0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`120?ooo`03
0?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01`3oool00`3OW9`0_ooo0?ooo`170?ooo`03
0?oo_`1d0000M;oo0180oooo001Q0?ooo`030;md0000M;l0oooo04D0oooo00H0gia80000M02oool0
oooO09a80018W=l80?ooo`030?oOW01dW=l0oooo03l0oooo00H0gia80000M02oool0oooO09a80018
W=m40?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO203oool00`3ogi`0M9cO0?ooo`180?ooo`03
0;md0000M;l0oooo0140oooo001O0?ooo`050?oo_`1d000000000000M02oool0AP3oool0103OW4P0
000000000000M;l:0?ooo`050;md00000000000000000018W=l0?@3oool0103OW4P0000000000000
M;m60?ooo`040=nLB00000000000001d_`X0oooo00D0_g@0000000000000000004RLg`130?ooo`05
0?oo_`1d000000000000M02oool04@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool004/0ooooo`00001R000000@0oooo001;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0C@3oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool0[@3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0:d0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`2]0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0
[@3oool00`000000oooo0?ooo`020?ooo`00B`3oool2000004H0oooo1@00001S0?ooo`030000003o
ool0oooo05l0oooo1`0000150?ooo`<00000103oool004/0oooo00<000000?ooo`3oool0@@3oool4
000000D0oooo1@00001N0?ooo`030000003oool0oooo05X0oooo1@0000070?ooo`H00000@@3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0n0?oooaD00000FP3oool00`00
0000oooo0?ooo`1H0?ooo`8000004P3oool2000003l0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool0>P3oool600000100oooo0P000000103oool0000000000000001G0?oo
o`030000003oool0oooo05D0oooo0`0000070?ooo`L00000203oool2000003d0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool0>03oool5000001D0oooo0`0000000`3oool0
00000000001E0?ooo`030000003oool0oooo0580oooo0`0000030?ooo`L0000000<0oooo00000000
00002P0000040?ooo`800000>`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`0f0?ooo`@000002`3oool6000000X0oooo0P0000000`3oool000000000001C0?ooo`030000
003oool0oooo0500oooo0P0000020?ooo`@000000P3oool6000000P0oooo200000020?ooo`800000
>@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0e0?ooo`800000203o
ool6000000H0oooo1`0000050?ooo`80000000<0oooo000000000000D@3oool00`000000oooo0?oo
o`1>0?ooo`8000000P3oool2000000@0oooo0P00000C0?ooo`80000000<0oooo0000000000000P3o
ool2000003L0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`040?ooo`@000004`3oool500000080oooo0P0000000`3oool000000000001?
0?ooo`030000003oool0oooo04`0oooo0P0000020?ooo`8000000`3oool3000001L0oooo0P000000
0`3oool00000000000020?ooo`800000=@3oool00`000000oooo0?ooo`020?ooo`00;`3oool0102o
M00000000000001d_ol30?ooo`030?oOW0180000M;oo00<0oooo00D0oooO09a8000000000000001d
_`0:0?ooo`030000003oool0oooo0380oooo0P0000050?ooo`8000001P3oool7000000l0oooo0P00
00020?ooo`80000000<0oooo000000000000C@3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo008000000P3oool3000001`0oooo0P0000000`3oool00000000000020?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool00P3oool002h0oooo00H0gia8001d_`3oool0omnL04P0
0018W=l20?ooo`030?oOW0180000M;oo00<0oooo00L0gia8001d_`3oool0oono07@00000B9`0gooo
00P0oooo00<000000?ooo`3oool0<@3oool2000000D0oooo00<000000?ooo`3oool00`3oool30000
00L0oooo200000090?ooo`8000000P3oool2000000030?ooo`000000000004/0oooo00<000000?oo
o`3oool0B@3oool2000000030?ooo`00000000000080oooo0P00000?0?ooo`@000003P3oool20000
00050?ooo`000000oooo0?ooo`000000<`3oool00`000000oooo0?ooo`020?ooo`00;@3oool00`3o
oml0W4P004RLg`020?ooo`030?noM00004P0W=oo00H0oooo00<0oooO09a8001d_ol00P3oool00`3o
gi`0B00004RLg`080?ooo`030000003oool0oooo0300oooo0P0000040?ooo`800000103oool20000
0180oooo0P0000090?ooo`8000000P3oool010000000oooo0?ooo`00001:0?ooo`030000003oool0
oooo04P0oooo00@000000?ooo`00000000000P3oool2000000/0oooo1P0000040?ooo`@00000303o
ool300000080oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`020?ooo`00;@3oool0
0`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`D0oooo00<0oono07@0001d_ol00`3o
ool00`2oM000001d0;ooo`070?ooo`030000003oool0oooo02l0oooo0P0000040?ooo`040000003o
ool0oooo0?ooo`<000005P3oool3000000P0oooo0P0000001@3oool000000000003oool0000004T0
oooo00<000000?ooo`3oool0AP3oool400000080oooo0P0000080?ooo`D0000000<0oooo00000000
0000200000030?ooo`<000002`3oool200000080oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`020?ooo`00803oool00`3ooml0W4P0000000070000000604RLg`3oool0oooo0?oog`2L
B00007Bo0`3oool00`3OW4P0001809cOo`050?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000
B02Lgol01`3oool00`000000oooo0?ooo`0]0?ooo`<000000`3oool200000080oooo0P00000L0?oo
o`<000001`3oool2000000030?ooo`000000oooo00800000A`3oool00`000000oooo0?ooo`150?oo
o`<000000`3oool00`000000oooo0?ooo`060?ooo`8000000P3oool4000000X0oooo2P0000090?oo
o`80000000<0oooo0000003oool0;`3oool00`000000oooo0?ooo`020?ooo`00;P3oool00`2oM000
04RL0=ooo`020?ooo`030?oOW0180000B9cO00H0oooo00<0_g@00000M02oool00P3oool00`3OW4P0
001809cOo`070?ooo`<00000;03oool2000000@0oooo00D000000?ooo`3oool0oooo0000000=0?oo
o`T000002`3oool2000000L0oooo0`0000020?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0@`3oool3000000@0oooo00<000000?ooo`3oool0103oool300000080oooo0P00000E0?oo
o`80000000<0oooo0000000000002@3oool010000000oooo00000000000/0?ooo`<00000103oool0
02h0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`060?ooo`080?noM0000000B9cO
0?ooo`3ooml0W4P00018W03Oool70?ooo`030000003oool0oooo02/0oooo0P0000040?ooo`030000
003oool0oooo008000002@3oool5000000T0oooo1`0000060?ooo`8000001`3oool3000000030?oo
o`000000oooo04@0oooo00<000000?ooo`3oool0@P3oool00`000000oooo000000030?ooo`800000
103oool3000000<0oooo0P00000I0?ooo`80000000<0oooo0000003oool0203oool010000000oooo
0?ooo`00000]0?ooo`030000003oool0oooo0080oooo000^0?ooo`030?oOW0180000B9cO00<0oooo
00<0_g@00018W03Oool01@3oool00`3ooml0W4P000000002000000030000M02oool0oooo00L0oooo
00<000000?ooo`3oool0:P3oool2000000<0oooo0P0000020?ooo`030000003oool0oooo00D0oooo
1000000E0?ooo`8000001P3oool2000000H0oooo00@000000?ooo`000000oooo0P0000130?ooo`03
0000003oool0oooo0440oooo0`0000030?ooo`030000003oool0oooo0080oooo0P0000040?ooo`80
00007@3oool4000000P0oooo00@000000?ooo`3oool00000;03oool00`000000oooo0?ooo`020?oo
o`00;P3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00H0oooo00<0oono07@0
0000M;l02`3oool00`000000oooo0?ooo`0Y0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0
000000H0oooo0P00000:0?ooo`D00000303oool2000000H0oooo0P0000050?ooo`@0000000<0oooo
0000003oool0@@3oool00`000000oooo0?ooo`100?ooo`800000103oool010000000oooo0?ooo`3o
ool2000000@0oooo0P00000Q0?ooo`<000001`3oool200000080oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`020?ooo`00;`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0
oooo00L0oooo00<0omnL04P00018W=l02P3oool00`000000oooo0?ooo`0Y0?ooo`050000003oool0
oooo0?ooo`0000000P3oool2000000H0oooo00<000000?ooo`3oool0103oool6000000D0oooo1000
000:0?ooo`8000001P3oool2000000D0oooo00D000000?ooo`000000oooo000000110?ooo`030000
003oool0oooo03l0oooo0P0000030?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`800000
3`3oool500000140oooo0P0000070?ooo`050000003oool0oooo0?ooo`000000:P3oool00`000000
oooo0?ooo`020?ooo`00<03oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`T0oooo00@0oooO09a8
000007@0_ooo203oool00`000000oooo0?ooo`0X0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`040?ooo`8000000`3oool4000000l0oooo100000080?ooo`8000001P3o
ool00`000000oooo0?ooo`030?ooo`040000003oool000000?ooo`800000?`3oool00`000000oooo
0?ooo`0n0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02@3oool6000000D0oooo1P00000=0?ooo`8000001P3oool01@000000oooo
0?ooo`3oool0000002T0oooo00<000000?ooo`3oool00P3oool00340oooo00@0gia8000000000000
07Bo303oool0103ookl0M00000000018W=l60?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000060?ooo`040000003oool0oooo0?ooo`8000002P3oool8
000000D0oooo0`0000070?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`<000000P3oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03`0oooo0P0000040?ooo`040000003oool0
oooo0?ooo`8000000`3oool2000000L0oooo1@0000020?oooa<000002`3oool00`000000oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`000000:03oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`0V0?ooo`8000000`3oool3000000H0oooo00D000000?ooo`3oool0oooo
000000060?ooo`H000000P3oool400000080oooo1P0000020?ooo`8000001`3oool2000000@0oooo
00<000000?ooo`3oool0103oool200000080oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0k0?ooo`800000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool01@3oool2000000@0oooo0`0000050?ooo`8000002@3oool5000000X0oooo00<000000?ooo`3o
ool0103oool010000000oooo0?ooo`00000X0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo02H0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`8000000P3oool20000
00D0oooo0P0000020?ooo`H00000103oool4000000@0oooo0`0000000`3oool00000000000070?oo
o`8000000`3oool2000000D0oooo0P0000020?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0>P3oool2000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`8000001P3oool2
000000<0oooo0`0000040?ooo`@000003P3oool4000000T0oooo0P0000040?ooo`8000000P3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
02D0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`030000003oool0oooo008000001@3oool6
000000h0oooo100000030?ooo`80000000<0oooo0000000000001`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0>@3oool2000000@0oooo00<000000?ooo`3oool00P0000020?ooo`8000001P3oool2
000000<0oooo0P0000030?ooo`@000005@3oool3000000P0oooo0P0000040?ooo`80000000<0oooo
0000003oool09P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo0080oooo0P0000050?ooo`040000003oool0oooo000000H0oooo0`00000F
0?ooo`<000000P3oool2000000030?ooo`000000000000H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`8000000P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo03P0oooo0P0000040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103o
ool2000000<0oooo0P0000030?ooo`800000703oool2000000L0oooo0P0000040?ooo`040000003o
ool0oooo000002H0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0903o
ool010000000oooo0?ooo`3oool2000000@0oooo0P0000000`3oool00000000000050?ooo`<00000
6`3oool200000080oooo0P0000000`3oool00000000000050?ooo`8000000`3oool00`000000oooo
0?ooo`030?ooo`8000000P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo
0P0000030?ooo`80000000<0oooo0000000000000`3oool00`000000oooo0?ooo`040?ooo`040000
003oool0oooo0?ooo`8000000`3oool200000200oooo0P0000050?ooo`800000103oool200000003
0?ooo`000000oooo02D0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
8`3oool010000000oooo0?ooo`3oool2000000@0oooo00@000000?ooo`3oool000001@3oool30000
01l0oooo0P0000020?ooo`80000000<0oooo0000003oool01@3oool01@000000oooo0?ooo`3oool0
000000D0oooo0P0000000`3oool000000?ooo`0h0?ooo`030000003oool0oooo03H0oooo0P000003
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool200000080oooo0P00
00030?ooo`8000008`3oool2000000D0oooo0P0000040?ooo`80000000<0oooo0000003oool0903o
ool00`000000oooo0?ooo`020?ooo`00B`3oool2000002<0oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00@000000?ooo`3oool00000103oool3000002<0oooo00@000000?ooo`3o
ool0oooo100000050?ooo`050000003oool0oooo0?ooo`0000001@3oool2000000030?ooo`000000
oooo03L0oooo00<000000?ooo`3oool0=@3oool2000000<0oooo00@000000?ooo`3oool000000`3o
ool2000000D0oooo00D000000?ooo`3oool0oooo000000030?ooo`8000009P3oool2000000D0oooo
0P0000040?ooo`<000008`3oool3000000@0oooo001;0?ooo`030000003oool0oooo0280oooo00@0
00000?ooo`3oool0oooo0P0000040?ooo`030000003oool0000000@0oooo0P00000V0?ooo`800000
0`3oool00`000000oooo000000050?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0000003L0oooo00<000000?ooo`3oool0=03oool2000000<0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo008000000P3oool2000002T0
oooo0P0000050?ooo`8000000`3oool010000000oooo00000000000T0?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo0240oooo00@000000?ooo`3oool0oooo0P0000040?oo
o`030000003oool0000000@0oooo00<000000?ooo`3oool0:03oool200000080oooo100000050?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`000000=P3oool00`000000oooo0?ooo`0d
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo
0P0000020?ooo`030000003oool0oooo00800000;03oool2000000D0oooo00<000000?ooo`3oool0
0P3oool2000000030?ooo`000000oooo0280oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool0803oool200000080oooo0P0000040?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool0:`3oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0000003D0oooo00<000000?ooo`3oool0<`3oool0
1@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000
003oool0oooo0080000000<0oooo000000000000;`3oool2000000D0oooo00<000000?ooo`3oool0
0P3oool3000002<0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool07`3o
ool200000080oooo00<000000?ooo`000000103oool00`000000oooo000000030?ooo`030000003o
ool0oooo02d0oooo0P0000020?ooo`030000003oool0000000D0oooo00<000000?ooo`0000001`3o
ool00`000000oooo0000000d0?ooo`030000003oool0oooo0380oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool000000280oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool07`3oool200000080oooo0P0000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`03000000D0oooo00<000000?ooo`0000001`3oool00`000000
oooo0000000c0?ooo`030000003oool0oooo0340oooo00D000000?ooo`3oool0oooo000000020?oo
o`050000003oool0oooo0?ooo`0000001@3oool010000000oooo0000000000020?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000008P3o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0N0?ooo`8000000P3oool2
000000@0oooo00<000000?ooo`0000000`3oool2000003<0oooo00@000000?ooo`3oool0oooo0`00
00040?ooo`030000003oool0000000H0oooo0P0000000`3oool000000?ooo`0a0?ooo`030000003o
ool0oooo0300oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo000000020?ooo`800000=P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0N0?ooo`80000000@0oooo0000003oool00000103oool2000000<0
oooo0P00000e0?ooo`8000000P3oool00`000000oooo000000040?ooo`030000003oool0000000H0
oooo00<000000?ooo`000000<P3oool00`000000oooo0?ooo`0_0?ooo`8000000`3oool00`000000
oooo000000030?ooo`030000003oool0oooo0080oooo0P0000001@3oool000000?ooo`3oool00000
03T0oooo00<000000?ooo`3oool00P3oool2000000<0oooo0`00000Q0?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo01d0oooo0P0000020?ooo`800000103oool2000000<0
oooo0P00000h0?ooo`030000003oool0oooo00<00000103oool3000000H0oooo00<000000?ooo`00
0000<@3oool00`000000oooo0?ooo`0_0?ooo`070000003oool0oooo0?ooo`000000oooo00000003
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo0080oooo0P0000030?ooo`030000003oool000000200oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool07@3oool2000000040?ooo`000000
oooo000000<0oooo00<000000?ooo`0000000P3oool2000003X0oooo00@000000?ooo`3oool0oooo
0P0000050?ooo`8000001P3oool00`000000oooo0000000`0?ooo`030000003oool0oooo02h0oooo
00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`000000oooo00800000?03oool2000000@0oooo00@000000?ooo`3oool0oooo0`00
000P0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01`0oooo0P000002
0?ooo`800000103oool200000080oooo0P00000l0?ooo`8000000P3oool2000000D0oooo0P000006
0?ooo`030000003oool0000002l0oooo00<000000?ooo`3oool0;@3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003o
ool00000?`3oool2000000<0oooo0P0000030?ooo`030000003oool0000001l0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool0703oool2000000040?ooo`000000oooo0000
00<0oooo0P0000020?ooo`800000?`3oool00`000000oooo0?ooo`02000000D0oooo0P0000050?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0;03oool200000080oooo00@000000?oo
o`3oool000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`000000@@3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<000007`3oool00`000000oooo
0?ooo`020?ooo`00B`3oool2000001d0oooo0P0000000`3oool00000000000030?ooo`8000000P3o
ool00`000000oooo000000100?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0000000^0?ooo`030000003oool0oooo02`0oooo00@000000?ooo`3oool0
00000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool0oooo0P000012
0?ooo`8000000`3oool2000000<0oooo00<000000?ooo`000000703oool3000000@0oooo001;0?oo
o`030000003oool0oooo01/0oooo0P000000103oool000000?ooo`0000030?ooo`80000000@0oooo
0000003oool00000@P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`000000;@3oool00`000000oooo0?ooo`0[0?ooo`070000003oool0oooo0?ooo`00
0000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool2000004@0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`3oool3000001h0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool06`3oool2000000030?ooo`000000000000<0oooo0P000002
0?ooo`800000A03oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00@0oooo0P00
000]0?ooo`030000003oool0oooo02X0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`800000AP3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo0?ooo`8000007P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`00
0000oooo0?ooo`0K0?ooo`050000003oool000000?ooo`0000000`3oool2000000030?ooo`000000
000004H0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`030?ooo`<00000;03o
ool00`000000oooo0?ooo`0Y0?ooo`8000000P3oool00`000000oooo000000040?ooo`040000003o
ool0oooo000000<0oooo0P0000170?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
oooo0`00000M0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01X0oooo
0P0000000`3oool00000000000030?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`050000
003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0000002/0
oooo00<000000?ooo`3oool0:@3oool01P000000oooo0?ooo`000000oooo000000@0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool0oooo0P00000M0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo01X0oooo0`0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00800000B03o
ool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0000000Z0?ooo`030000003oool0oooo02P0oooo00H000000?ooo`3oool000000?ooo`0000040?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0B@3oool2000000<0oooo00@00000
0?ooo`3oool0oooo0`00000L0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo01T0oooo0P0000000`3oool00000000000030?ooo`8000000P3oool00`000000oooo0?ooo`18
0?ooo`030000003oool0oooo008000001@3oool00`000000oooo0?ooo`040?ooo`800000:P3oool0
0`000000oooo0?ooo`0W0?ooo`040000003oool0oooo0?ooo`8000001@3oool00`000000oooo0000
00030?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`3oool2000001`0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool06@3o
ool3000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool00P00001;0?ooo`030000003o
ool0oooo008000001@3oool00`000000oooo0?ooo`040?ooo`800000:@3oool00`000000oooo0?oo
o`0V0?ooo`8000000P3oool2000000D0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`1=0?ooo`050000003oool0oooo0?ooo`0000000`3oool3000001/0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool06@3oool010000000oooo0000000000030?ooo`800000
0P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00800000103oool00`000000oooo
0?ooo`040?ooo`030000003oool0000002P0oooo00<000000?ooo`3oool09P3oool01@000000oooo
0?ooo`3oool0000000D0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`1>0?ooo`80
00000`3oool00`000000oooo0?ooo`03000001/0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool0603oool3000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool0
0P00001>0?ooo`030000003oool0oooo00800000103oool00`000000oooo0?ooo`040?ooo`030000
003oool0000002L0oooo00<000000?ooo`3oool09@3oool01@000000oooo0?ooo`3oool0000000H0
oooo0P0000030?ooo`030000003oool0oooo0500oooo00D000000?ooo`3oool0oooo000000030?oo
o`8000006`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0H0?ooo`@0
00000`3oool01@000000oooo0?ooo`3oool000000500oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`040?ooo`8000009`3oool00`000000oooo0?ooo`0T0?ooo`8000000P3oool0
0`000000oooo0?ooo`040?ooo`8000000`3oool200000580oooo0P0000020?ooo`8000000P3oool3
000001X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool05`3oool30000
00030?ooo`000000oooo0080oooo00@000000?ooo`3oool00000DP3oool010000000oooo00000000
00050?ooo`030000003oool0oooo00<0oooo0`00000V0?ooo`030000003oool0oooo02<0oooo0P00
00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`1B0?ooo`050000003oool0oooo0?ooo`0000000`3oool2000001X0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool05`3oool4000000<0oooo00D000000?ooo`3oool0oooo
0000001B0?ooo`030000003oool0oooo00800000103oool2000000D0oooo00<000000?ooo`000000
9@3oool00`000000oooo0?ooo`0S0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo000000030?ooo`030000003oool0oooo05<0oooo0P0000020?ooo`8000000P3oool3000001T0
oooo00<000000?ooo`3oool00P3oool004/0oooo0P00000H0?ooo`040000003oool00000000000<0
oooo00@000000?ooo`3oool00000E03oool00`000000oooo0?ooo`02000000@0oooo00<000000?oo
o`3oool0103oool2000002D0oooo00<000000?ooo`3oool08P3oool200000080oooo00<000000?oo
o`3oool0103oool2000000<0oooo00<000000?ooo`3oool0E@3oool01@000000oooo0?ooo`3oool0
000000<0oooo0P00000G0?ooo`<00000103oool004/0oooo00<000000?ooo`3oool05P3oool40000
00<0oooo00D000000?ooo`3oool0oooo0000001E0?ooo`040000003oool00000000000D0oooo00<0
00000?ooo`3oool00`3oool3000002@0oooo00<000000?ooo`3oool08@3oool200000080oooo0P00
00050?ooo`8000000`3oool2000005L0oooo0P0000020?ooo`8000000P3oool2000001T0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool05P3oool4000000<0oooo00@00000
0?ooo`3oool00000E`3oool010000000oooo0000000000050?ooo`030000003oool0oooo00<0oooo
0`00000S0?ooo`030000003oool0oooo0200oooo0P0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`0000000P3oool2000005T0oooo00D000000?ooo`3oool0oooo000000020?ooo`<0
0000603oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0F0?ooo`040000
003oool0000000000080oooo00D000000?ooo`3oool0oooo0000001H0?ooo`040000003oool00000
000000@0oooo0P0000050?ooo`030000003oool000000280oooo00<000000?ooo`3oool0803oool2
00000080oooo0P0000050?ooo`8000000P3oool2000005X0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`800000603oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0E
0?ooo`80000000<0oooo0000003oool00P3oool010000000oooo0?ooo`00001I0?ooo`050000003o
ool000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`<000008P3oool00`000000oooo
0?ooo`0O0?ooo`8000000P3oool2000000D0oooo0P0000020?ooo`800000F`3oool2000000<0oooo
00H000000?ooo`3oool000000?ooo`00000G0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo01D0oooo00@000000?ooo`00000000000P3oool200000080oooo00<000000?oo
o`3oool0F03oool010000000oooo0000000000050?ooo`030000003oool0oooo00<0oooo0`00000Q
0?ooo`030000003oool0oooo01h0oooo0P0000030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000000P3oool2000005`0oooo00D000000?ooo`3oool0oooo000000030?ooo`8000005`3o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0D0?ooo`80000000<0oooo
0000000000000P3oool010000000oooo0?ooo`00001L0?ooo`040000003oool00000000000D0oooo
00<000000?ooo`3oool00`3oool300000200oooo00<000000?ooo`3oool07@3oool00`000000oooo
000000020?ooo`8000001@3oool200000080oooo0P00001M0?ooo`030000003oool0oooo0080oooo
00H000000?ooo`3oool000000?ooo`00000F0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo01@0oooo0P000000103oool000000?ooo`3oool200000080oooo00<000000?oo
o`3oool0F`3oool2000000030?ooo`000000oooo00<0oooo0P0000040?ooo`<00000803oool00`00
0000oooo0?ooo`0M0?ooo`8000000P3oool2000000D0oooo0P0000020?ooo`800000G`3oool01@00
0000oooo0?ooo`3oool000000080oooo0`00000F0?ooo`030000003oool0oooo0080oooo000_0?oo
o`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol01@3oool00`3ooml0W4P004RLg`0:
0?ooo`030000003oool0oooo01@0oooo00@000000?ooo`00000000000P3oool2000000030?ooo`00
0000000005d0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo
0`00000O0?ooo`030000003oool0oooo01`0oooo0P0000020?ooo`030000003oool0000000@0oooo
0P0000030?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`02000001H0oooo00<000000?ooo`3oool00P3oool002h0oooo00H0gia8001d_`3oool0omnL
04P00018W=l20?ooo`030?oOW0180000M;oo00H0oooo00<0gia80018W03Oool02@3oool00`000000
oooo0?ooo`0C0?ooo`80000000@0oooo000000000000oooo0P0000020?ooo`030000003oool0oooo
05d0oooo00@000000?ooo`00000000001@3oool00`000000oooo0?ooo`030?ooo`8000007`3oool0
0`000000oooo0?ooo`0L0?ooo`8000000P3oool2000000@0oooo00<000000?ooo`0000000P3oool2
00000600oooo0P0000030?ooo`060000003oool0oooo0000003oool000005@3oool00`000000oooo
0?ooo`020?ooo`00;@3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00X0oooo00<0
omnL04P0B02Lgol02@3oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo00000080oooo
0P0000020?ooo`030000003oool0oooo05h0oooo0P0000000`3oool000000?ooo`040?ooo`030000
003oool0oooo0080oooo0`00000N0?ooo`030000003oool0oooo01/0oooo0P0000020?ooo`800000
1@3oool2000000<0oooo00<000000?ooo`3oool0H03oool010000000oooo0?ooo`3oool200000004
0?ooo`0000000000000001D0oooo00<000000?ooo`3oool00P3oool002d0oooo00<0oooO09a80018
W=l00P3oool0103ooml0W4P00018W03Oool50?ooo`030?noM0000000000000@0000000<004RL0=oo
o`3oool01P3oool00`000000oooo0?ooo`0C0?ooo`040000003oool0000000000080oooo0P000000
0`3oool000000?ooo`1P0?ooo`040000003oool00000000000D0oooo00<000000?ooo`3oool00`3o
ool2000001h0oooo00<000000?ooo`3oool06`3oool01P000000oooo0?ooo`000000oooo000000@0
oooo0P0000030?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`02000001D0oooo00<000000?ooo`3oool00P3oool00200oooo00<0oooO09a800000000
1`0000001P18W=l0oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol01@3oool00`3o
oml0W4Q809cOo`020?ooo`030;md0000M;l0oooo00P0oooo00<000000?ooo`3oool04`3oool01@00
0000oooo000000000000oooo008000000P3oool00`000000oooo0?ooo`1P0?ooo`040000003oool0
0000000000D0oooo00<000000?ooo`3oool00`3oool2000001d0oooo00<000000?ooo`3oool06P3o
ool200000080oooo0P0000040?ooo`8000000`3oool00`000000oooo0?ooo`1R0?ooo`8000000`3o
ool2000000030?ooo`000000000001D0oooo00<000000?ooo`3oool00P3oool002h0oooo00<0_g@0
0018W03Oool00P3oool00`3ogi`0B00004RLg`060?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@004RL
0=ooo`080?ooo`<000004P3oool010000000oooo0?ooo`0000020?ooo`80000000<0oooo00000000
0000H`3oool2000000030?ooo`000000oooo00<0oooo0P0000040?ooo`8000007@3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo008000001@3oool2000000<0oooo00<000000?ooo`3o
ool0H`3oool010000000oooo0?ooo`3oool2000000040?ooo`000000oooo00000180oooo0`000004
0?ooo`00;P3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00L0oooo00H0omnL04Q8
W03Oool0omnL04P0B02Lgol80?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00001T0?ooo`040000003oool00000000000D0oooo0P0000040?oo
o`800000703oool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo0?ooo`800000103oool2
000000<0oooo00<000000?ooo`3oool0I03oool200000080oooo0P000000103oool0000000000000
000D0?ooo`030000003oool0oooo0080oooo000^0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@0
0018W03Oool01`3oool01@3o_g@007Bo0?oog`2LB000B9cO00P0oooo00<000000?ooo`3oool04P3o
ool010000000oooo0000000000020?ooo`040000003oool0oooo000006D0oooo00@000000?ooo`00
00000000103oool2000000@0oooo00<000000?ooo`0000006`3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo008000001@3oool01@000000oooo0?ooo`3oool0000006L0oooo0P000003
0?ooo`030000003oool0oooo00800000503oool00`000000oooo0?ooo`020?ooo`00;P3oool0103o
oml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00P0oooo00@0gia804RLg`2oM00007Bo203o
ool00`000000oooo0?ooo`0B0?ooo`050000003oool000000000003oool00P0000000`3oool00000
0000001V0?ooo`80000000<0oooo0000003oool00`3oool2000000@0oooo0P00000K0?ooo`030000
003oool0oooo01P0oooo00@000000?ooo`3oool0oooo0P0000040?ooo`8000000`3oool00`000000
oooo0?ooo`1V0?ooo`040000003oool0oooo0?ooo`80000000<0oooo000000000000503oool00`00
0000oooo0?ooo`020?ooo`00;`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00T0
oooo00@0gia807AdM00007@0_ooo1`3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000I`3oool010000000oooo0000000000040?ooo`030000
003oool0000000<0oooo00<000000?ooo`0000006P3oool00`000000oooo0?ooo`0G0?ooo`800000
0P3oool2000000D0oooo00D000000?ooo`3oool0oooo0000001Y0?ooo`8000000P3oool200000004
0?ooo`000000oooo000001<0oooo00<000000?ooo`3oool00P3oool00300oooo00H0gia80000M02o
ool0oooO09a80018W=l;0?ooo`030;md000004P0W=oo00L0oooo00<000000?ooo`3oool04@3oool0
10000000oooo0000000000020?ooo`040000003oool0oooo000006P0oooo00@000000?ooo`000000
0000103oool2000000@0oooo0P00000J0?ooo`030000003oool0oooo01L0oooo00H000000?ooo`3o
ool000000?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0J03oool0
0`000000oooo0?ooo`0200000080oooo0P00000C0?ooo`030000003oool0oooo0080oooo000a0?oo
o`040=nLB00000000000001d_``0oooo00<0oooO09a80018W=l01`3oool00`000000oooo0?ooo`0A
0?ooo`040000003oool0000000000080oooo00<000000?ooo`000000JP3oool3000000@0oooo00<0
00000?ooo`0000000`3oool00`000000oooo0000000I0?ooo`030000003oool0oooo01H0oooo0P00
00020?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool0J@3oool01@000000oooo0?oo
o`3oool000000080oooo0P00000C0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo0100oooo0P0000001@3oool000000?ooo`3oool000000080oooo00<000000?ooo`3oool0
J03oool010000000oooo0000000000040?ooo`800000103oool2000001T0oooo00<000000?ooo`3o
ool05P3oool01P000000oooo0?ooo`000000oooo000000@0oooo00@000000?ooo`3oool0oooo0P00
001[0?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000000000004`3oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0000000000080oooo
00@000000?ooo`0000000000J`3oool010000000oooo0000000000030?ooo`030000003oool00000
00<0oooo00<000000?ooo`000000603oool00`000000oooo0?ooo`0E0?ooo`8000000P3oool20000
00@0oooo0P0000030?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool00P000000103o
ool0000000000000000B0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
0100oooo00@000000?ooo`00000000000P3oool00`000000oooo0000001]0?ooo`<00000103oool2
000000@0oooo0P00000H0?ooo`030000003oool0oooo01D0oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`8000000`3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo00800000
0P3oool200000180oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0403o
ool00`000000oooo000000020?ooo`80000000<0oooo0000003oool0K03oool010000000oooo0000
000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`0000005`3oool00`000000oooo
0?ooo`0D0?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`800000KP3oool01@000000oooo
0?ooo`3oool000000080oooo0P00000B0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo00l0oooo0P0000001P3oool000000?ooo`3oool000000?ooo`800000KP3oool30000
00@0oooo0P0000040?ooo`8000005`3oool00`000000oooo0?ooo`0D0?ooo`060000003oool0oooo
0000003oool000000`3oool2000000<0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?oo
o`02000000030?ooo`00000000000180oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool03`3oool010000000oooo0000000000020?ooo`040000003oool00000000006l0oooo
0`0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`0000005P3oool00`000000oooo
0?ooo`0C0?ooo`8000000P3oool2000000@0oooo00@000000?ooo`3oool0oooo0P00001`0?ooo`03
0000003oool0oooo0080000000@0oooo00000000000000004@3oool00`000000oooo0?ooo`020?oo
o`00B`3oool200000100oooo00<000000?ooo`0000000`3oool00`000000oooo0000001`0?ooo`<0
0000103oool2000000@0oooo00<000000?ooo`0000005@3oool00`000000oooo0?ooo`0C0?ooo`06
0000003oool0oooo0000003oool000000`3oool2000000<0oooo00<000000?ooo`3oool0K`3oool0
1@000000oooo0?ooo`3oool000000080oooo0P00000?0?ooo`<00000103oool004/0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo000000020?ooo`80000000<0oooo0000003oool0L03oool3
000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0000000E0?ooo`030000003oool0
oooo0180oooo0P0000020?ooo`800000103oool010000000oooo0?ooo`3oool200000740oooo00D0
00000?ooo`3oool0oooo000000020?ooo`8000004@3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`0>0?ooo`80000000H0oooo0000003oool0oooo0000003oool200000740
oooo0P0000000`3oool000000?ooo`020?ooo`800000103oool00`000000oooo0000000D0?ooo`03
0000003oool0oooo0180oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`8000000`3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0080000000<0oooo0000000000004@3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0>0?ooo`040000003oool00000
00000080oooo00@000000?ooo`0000000000LP3oool3000000<0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0000000D0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P00
00040?ooo`040000003oool0oooo0?ooo`800000L`3oool00`000000oooo0?ooo`02000000040?oo
o`000000000000000100oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo000000030?ooo`030000003oool0000007<0oooo0P0000000`3oool00000
0?ooo`020?ooo`800000103oool00`000000oooo0000000C0?ooo`030000003oool0oooo0140oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`8000000`3oool00`000000oooo0?ooo`1b0?oo
o`050000003oool0oooo0?ooo`0000000P3oool200000100oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool03P3oool00`000000oooo000000020?ooo`80000000<0oooo0000
003oool0L`3oool3000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0000000C0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool00P0000040?ooo`050000003oool0oooo
0?ooo`000000M@3oool200000080oooo00<000000?ooo`3oool00P00000@0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo00d0oooo0P0000001P3oool000000?ooo`3oool0
00000?ooo`800000M03oool2000000030?ooo`000000oooo0080oooo0P0000040?ooo`030000003o
ool000000180oooo00<000000?ooo`3oool0403oool01P000000oooo0?ooo`000000oooo000000<0
oooo0P0000030?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool00P0000000`3oool0
00000000000@0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00d0oooo
00@000000?ooo`3oool000000P3oool010000000oooo00000000001e0?ooo`<000000`3oool00`00
0000oooo000000030?ooo`030000003oool000000180oooo00<000000?ooo`3oool0403oool01P00
0000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0oooo0000001g0?ooo`030000
003oool0oooo0080000000@0oooo0000003oool000003`3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0000000000080oooo00<000000?ooo`00
0000MP3oool2000000030?ooo`000000oooo0080oooo0P0000030?ooo`80000000<0oooo0000003o
ool0403oool00`000000oooo0?ooo`0?0?ooo`060000003oool0oooo0000003oool000000`3oool2
000000<0oooo00<000000?ooo`3oool0M@3oool200000080oooo00D000000?ooo`000000oooo0000
000?0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00d0oooo00@00000
0?ooo`00000000000P3oool00`000000oooo0000001g0?ooo`<000000`3oool00`000000oooo0000
00030?ooo`030000003oool000000140oooo00<000000?ooo`3oool03`3oool01P000000oooo0?oo
o`000000oooo000000<0oooo00D000000?ooo`3oool0oooo0000001h0?ooo`8000000P3oool00`00
0000oooo0?ooo`02000000l0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo000000020?ooo`040000003oool00000000007L0oooo0P0000000`3o
ool000000?ooo`020?ooo`8000000`3oool2000000030?ooo`000000oooo00l0oooo00<000000?oo
o`3oool03P3oool2000000040?ooo`000000oooo000000<0oooo0P0000030?ooo`030000003oool0
oooo07L0oooo00<000000?ooo`3oool00P0000000`3oool000000000000?0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000000P3oool01000
0000oooo00000000001h0?ooo`80000000L0oooo0000003oool0oooo0000003oool0000000<0oooo
00<000000?ooo`000000403oool00`000000oooo0?ooo`0>0?ooo`060000003oool0oooo0000003o
ool000000`3oool01@000000oooo0?ooo`3oool0000007X0oooo00<000000?ooo`3oool00P000000
103oool000000?ooo`00000>0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo00`0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0000001i0?ooo`80000000<0
oooo0000003oool00P3oool2000000<0oooo0P0000000`3oool000000?ooo`0>0?ooo`030000003o
ool0oooo00d0oooo0P000000103oool000000?ooo`0000030?ooo`8000000`3oool00`000000oooo
0?ooo`1h0?ooo`8000000P3oool01@000000oooo0000003oool0000000h0oooo00<000000?ooo`3o
ool00P3oool004/0oooo0P00000=0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`00
0000NP3oool2000000070?ooo`000000oooo0?ooo`000000oooo000000020?ooo`80000000<0oooo
0000003oool03P3oool00`000000oooo0?ooo`0=0?ooo`060000003oool0oooo0000003oool00000
0`3oool01@000000oooo0?ooo`3oool0000007`0oooo00D000000?ooo`3oool000000?ooo`030000
00`0oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`0<0?ooo`050000003oool000000000
003oool01000001j0?ooo`80000000L0oooo0000003oool0oooo0000003oool0000000<0oooo0`00
000?0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`000000oooo000000030?ooo`800000
0`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo00D000003P3oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0<0?ooo`070000003oool000000000003oool0
00000?ooo`02000007/0oooo0P0000001`3oool000000?ooo`3oool000000?ooo`0000000P3oool2
000000030?ooo`000000oooo00d0oooo00<000000?ooo`3oool0303oool2000000040?ooo`000000
oooo000000<0oooo0P0000020?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P00
00000`3oool000000000000>0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`0000000P3oool00`000000oooo0000001l0?ooo`80000000L0oooo
0000003oool0oooo0000003oool0000000<0oooo0`00000>0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00P0000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
N`3oool00`000000oooo0?ooo`02000000030?ooo`000000000000h0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool0303oool00`000000oooo000000020?ooo`030000003o
ool0000007d0oooo0P0000001`3oool000000?ooo`3oool000000?ooo`0000000P3oool3000000h0
oooo00<000000?ooo`3oool02`3oool2000000040?ooo`000000oooo000000<0oooo0P0000020?oo
o`030000003oool0oooo07d0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000d0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02`3oool010000000oooo0?oo
o`0000020?ooo`<00000O@3oool2000000070?ooo`000000oooo0?ooo`000000oooo000000020?oo
o`040000003oool00000000000d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`02
000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`1m0?ooo`080000003oool0
oooo0000003oool000000?ooo`00000=0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo00/0oooo00D000000?ooo`00000000000?ooo`04000007h0oooo0P000000103oool0
00000?ooo`0000020?ooo`030000003oool0oooo00<000003@3oool00`000000oooo0?ooo`0:0?oo
o`80000000@0oooo0000003oool000000`3oool01@000000oooo0000003oool000000800oooo00D0
00000?ooo`3oool000000?ooo`03000000d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool02`3oool01`000000oooo000000000000oooo0000003oool00P00001n0?ooo`80
000000L0oooo0000003oool0oooo0000003oool000000080oooo00@000000?ooo`0000000000303o
ool00`000000oooo0?ooo`0:0?ooo`80000000@0oooo0000003oool000000`3oool200000080oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`02000000030?ooo`000000000000d0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0000
00020?ooo`030000003oool000000800oooo0P000000103oool000000?ooo`0000020?ooo`040000
003oool000000?ooo`800000303oool00`000000oooo0?ooo`090?ooo`80000000@0oooo0000003o
ool000000`3oool01@000000oooo0000003oool000000840oooo0P000000103oool000000000003o
ool2000000d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo000000020?ooo`<00000P03oool2000000040?ooo`000000oooo00000080oooo00H0
00000?ooo`3oool000000?ooo`00000<0?ooo`030000003oool0oooo00T0oooo0P000000103oool0
00000?ooo`0000030?ooo`050000003oool000000?ooo`000000P@3oool2000000040?ooo`000000
00000?ooo`8000003@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0;
0?ooo`040000003oool000000?ooo`@00000P@3oool2000000040?ooo`000000oooo00000080oooo
00@000000?ooo`000000oooo0P00000;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`800000P`3oool01@000000oooo0?ooo`000000
oooo008000003@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0:0?oo
o`@0000000<0oooo0000000000000P0000210?ooo`80000000@0oooo0000003oool000000P3oool0
0`000000oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool2
000000040?ooo`000000oooo000000<0oooo00D000000?ooo`000000oooo000000230?ooo`050000
003oool0oooo0000003oool00P00000=0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo00X0oooo100000000`3oool000000?ooo`0200000840oooo00@000000?ooo`000000
00000P3oool00`000000oooo000000020?ooo`030000003oool0000000/0oooo00<000000?ooo`3o
ool0203oool300000080oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000P`3o
ool020000000oooo0?ooo`000000oooo0000003oool00000303oool00`000000oooo0?ooo`020?oo
o`00B`3oool2000000/0oooo00L000000?ooo`00000000000?ooo`000000oooo00800000PP3oool2
000000040?ooo`000000oooo00000080oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`800000Q03oool010000000oooo0?ooo`0000020?ooo`8000002P3oool3000000@0
oooo001;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`0000000P3oool00`000000oooo
000000230?ooo`060000003oool000000000003oool000000P3oool01P000000oooo0?ooo`000000
oooo000000X0oooo00<000000?ooo`3oool01`3oool300000080oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`000000Q03oool2000000040?ooo`000000oooo0?ooo`800000303oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool00000
0080oooo0`0000230?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`040000003o
ool000000?ooo`8000002@3oool00`000000oooo0?ooo`070?ooo`<000000P3oool010000000oooo
0?ooo`0000020?ooo`<00000Q03oool2000000040?ooo`00000000000?ooo`800000303oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool000000080
oooo0`0000240?ooo`80000000@0oooo0000003oool000000P3oool00`000000oooo000000020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool2000000050?ooo`000000oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`02000008H0oooo00D000000?ooo`00000000000?oo
o`02000000`0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02@3oool4
000000030?ooo`000000oooo00800000Q03oool01`000000oooo0000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool0000000T0oooo00<000000?ooo`3oool01P3oool300000080
oooo00D000000?ooo`3oool0oooo000000020?ooo`800000QP3oool01@000000oooo0?ooo`000000
oooo00800000303oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`090?oo
o`@0000000<0oooo0000003oool00P0000250?ooo`80000000@0oooo0000003oool000000P3oool0
10000000oooo0000003oool2000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000
00020?ooo`040000003oool0oooo00000080oooo0`0000260?ooo`050000003oool0oooo0000003o
ool00P00000<0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00T0oooo
100000000`3oool000000?ooo`02000008D0oooo0P0000020?ooo`8000000P3oool00`000000oooo
000000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool2000000050?oo
o`000000oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02000008L0oooo00D000000?ooo`3o
ool000000?ooo`02000000`0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool02@3oool300000080oooo00<000000?ooo`000000QP3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000P0oooo00<000000?ooo`3oool01@3o
ool300000080oooo00@000000?ooo`3oool000000`3oool2000008L0oooo00D000000?ooo`3oool0
00000?ooo`02000000`0oooo00<000000?ooo`3oool00P3oool002l0oooo00@0_g@0000000000000
M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB0000000000000<0000000<0B9cO0?ooo`3o
ool01`3oool00`000000oooo0?ooo`090?ooo`<000000P3oool00`000000oooo000000270?ooo`80
000000@0oooo0000003oool000000P3oool00`000000oooo000000020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`000000Q`3oool010000000oooo0?ooo`0000020?ooo`8000002`3o
ool00`000000oooo0?ooo`020?ooo`00;P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo
00<0omnL04P0001d_ol00`3oool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02oool0oooo00L0oooo
00<000000?ooo`3oool02@3oool010000000oooo0000003oool2000000030?ooo`000000oooo08H0
oooo00@000000?ooo`000000oooo0P0000030?ooo`8000000P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo0P000000103oool000000?ooo`0000030?ooo`030000003oool0
oooo00800000R@3oool00`000000oooo000000020?ooo`8000002`3oool00`000000oooo0?ooo`02
0?ooo`00;@3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00P0oooo00<0okmd001d
_`3oool02`3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0100000270?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`040000003oool000000?ooo`800000
1P3oool00`000000oooo0?ooo`040?ooo`030000003oool000000080oooo00@000000?ooo`3oool0
00000`3oool2000008T0oooo00D000000?ooo`3oool000000?ooo`02000000/0oooo00<000000?oo
o`3oool00P3oool002d0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool80?oo
o`030?noM000M;l0oooo00X0oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo
00@00000R03oool200000080oooo0P0000030?ooo`8000000P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`800000RP3oool01@000000oooo0?ooo`000000oooo008000002`3oool00`000000oooo0?oo
o`020?ooo`00803oool00`3ooml0W4P0000000070000000604RLg`3oool0oooo0?oog`2LB00007Bo
0`3oool00`3OW4P0001809cOo`090?ooo`030?noM018W=l0oooo00T0oooo00<000000?ooo`3oool0
203oool4000000030?ooo`000000000000800000R03oool01`000000oooo0000003oool000000?oo
o`0000000P3oool200000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`80000000@0oooo0000003oool000000P3oool010000000oooo0?ooo`3oool2000008X0oooo00D0
00000?ooo`3oool000000?ooo`02000000/0oooo00<000000?ooo`3oool00P3oool002h0oooo00<0
_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?ooo`030=nLB018W=l0oooo00P0oooo0`00
00080?ooo`@0000000<0oooo0000003oool00P0000290?ooo`8000000P3oool2000000<0oooo0P00
00000`3oool00000000000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`<00000RP3oool01@000000oooo0?ooo`000000oooo0080
00002@3oool3000000@0oooo000^0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0
2`3oool00`2oM000M;oo0?ooo`070?ooo`030000003oool0oooo00P0oooo10000000103oool00000
0?ooo`00002:0?ooo`8000000P3oool2000000<0oooo0P0000020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`040000003oool0oooo0000
0080oooo0P00002;0?ooo`050000003oool0oooo0000003oool00P00000;0?ooo`030000003oool0
oooo0080oooo000^0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool02P3oool00`3o
gi`0B01d0;ooo`070?ooo`030000003oool0oooo00P0oooo0`0000020?ooo`030000003oool00000
08X0oooo00L000000?ooo`000000oooo0000003oool000000080oooo0P0000020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool2000000040?ooo`000000oooo00000080oooo
00@000000?ooo`3oool0oooo0P00002;0?ooo`80000000D0oooo0000003oool0oooo0000000;0?oo
o`030000003oool0oooo0080oooo000^0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018
W03Oool02P3oool00`3ooml0W4P007Boo`070?ooo`030000003oool0oooo00P0oooo0`0000001@3o
ool000000000003oool0000008/0oooo0P0000020?ooo`8000000`3oool2000000030?ooo`000000
000000@0oooo00<000000?ooo`3oool00P3oool300000080oooo00@000000?ooo`3oool000000P3o
ool3000008/0oooo0P000000103oool000000000003oool2000000X0oooo00<000000?ooo`3oool0
0P3oool002l0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`0:0?ooo`030?oo_`1d
0000B9cO00L0oooo00<000000?ooo`3oool0203oool3000000050?ooo`00000000000?ooo`000000
R`3oool010000000oooo0000003oool2000000<0oooo0P0000020?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool0oooo0P0000001@3oool000000?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P00002=0?ooo`050000003oool000000000003oool00P00000:0?ooo`030000003o
ool0oooo0080oooo000`0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO1`3oool01`3o_g@004RL
0=ooo`3oool0gia80000B02Lgol01`3oool00`000000oooo0?ooo`080?ooo`040000003oool00000
0?ooo`@00000R`3oool010000000oooo0000003oool2000000<0oooo0P0000020?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool0oooo0P000000103oool000000?ooo`0000020?ooo`04
0000003oool0oooo0?ooo`800000S@3oool01@000000oooo0?ooo`000000oooo008000002P3oool0
0`000000oooo0?ooo`020?ooo`00<@3oool0103OW4P0000000000000M;l90?ooo`050?oOW0180000
00000000001d_ol0203oool00`000000oooo0?ooo`080?ooo`040000003oool000000?ooo`@00000
S03oool200000080oooo0P0000030?ooo`80000000<0oooo0000003oool00`3oool010000000oooo
0?ooo`3oool300000080oooo00@000000?ooo`3oool000000P3oool3000008d0oooo00D000000?oo
o`3oool000000?ooo`02000000X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool0203oool010000000oooo0000003oool3000008d0oooo0P0000020?ooo`8000000`3oool2
00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`80000000L0oooo0000003oool0oooo
0000003oool0000000<0oooo0P00002>0?ooo`050000003oool0oooo0000003oool00P00000:0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`00
0000oooo0`00002>0?ooo`80000000<0oooo0000000000000`3oool200000080oooo00D000000?oo
o`3oool0oooo000000020?ooo`80000000@0oooo0000003oool000000P3oool01P000000oooo0?oo
o`000000oooo000008h0oooo00D000000?ooo`3oool000000?ooo`02000000X0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool01`3oool2000000060?ooo`000000oooo0000
003oool00000SP3oool200000080oooo0P0000030?ooo`030000003oool0oooo008000000P3oool0
0`000000oooo0?ooo`0300000080oooo00@000000?ooo`3oool000000P3oool3000008h0oooo00D0
00000?ooo`3oool000000?ooo`02000000X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool01`3oool4000000040?ooo`000000oooo000008h0oooo0P0000020?ooo`800000
0`3oool200000080oooo00L000000?ooo`3oool000000?ooo`000000oooo008000000P3oool00`00
0000oooo000000030?ooo`800000S`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01`3oool40000
00040?ooo`000000oooo000008l0oooo00D000000?ooo`3oool0oooo000000030?ooo`8000000P3o
ool01@000000oooo0?ooo`000000oooo0080000000L0oooo0000003oool0oooo0000003oool00000
0080oooo00<000000?ooo`000000S`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01`3oool60000
00030?ooo`000000oooo08h0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P0000000`3oool000000?ooo`0300000080oooo00<000000?ooo`0000000`3oool00`00
0000oooo0000002?0?ooo`80000000D0oooo0000003oool0oooo0000000:0?ooo`030000003oool0
oooo0080oooo001;0?ooo`800000203oool8000008l0oooo0P0000020?ooo`8000000`3oool20000
0080oooo00@000000?ooo`000000oooo0`0000020?ooo`030000003oool0000000<0oooo0`00002@
0?ooo`060000003oool000000000003oool00000203oool3000000@0oooo001;0?ooo`030000003o
ool0oooo00L0oooo00@000000?ooo`000000oooo1000002@0?ooo`050000003oool0oooo0?ooo`00
00000`3oool200000080oooo00<000000?ooo`0000000P0000001`3oool000000?ooo`3oool00000
0?ooo`0000000P3oool00`000000oooo0000002A0?ooo`060000003oool000000000003oool00000
2P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`070?ooo`040000003o
ool000000?ooo`@00000T03oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool01P0000030?ooo`8000000`3oool00`000000oooo0000002A0?ooo`060000003oool000000000
003oool000002P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`070?oo
o`040000003oool000000?ooo`@00000T03oool200000080oooo0P0000030?ooo`80000000<0oooo
000000000000100000020?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000T@3o
ool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool01`3oool010000000oooo0000003oool400000940oooo00D000000?ooo`3o
ool0oooo000000030?ooo`8000000P3oool500000080oooo0P0000030?ooo`030000003oool00000
0980oooo00D000000?ooo`3oool000000?ooo`02000000T0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool01`3oool010000000oooo0000003oool300000980oooo00D00000
0?ooo`3oool0oooo000000030?ooo`8000000P3oool4000000<0oooo0P0000030?ooo`030000003o
ool000000980oooo00D000000?ooo`3oool000000?ooo`02000000T0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool01`3oool010000000oooo0000003oool300000980oooo
0P0000020?ooo`8000000`3oool2000000030?ooo`0000000000008000000`3oool200000080oooo
00@000000?ooo`3oool00000TP3oool01@000000oooo0?ooo`000000oooo008000002@3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`070?ooo`070000003oool000000?oo
o`000000oooo0000002C0?ooo`050000003oool0oooo0?ooo`0000000`3oool200000080oooo0`00
00020?ooo`8000000`3oool010000000oooo00000000002B0?ooo`050000003oool0oooo0000003o
ool00P0000090?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00L0oooo
00L000000?ooo`000000oooo0000003oool0000009<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`8000000P3oool2000000<0oooo0P0000030?ooo`030000003oool0000009<0oooo00D00000
0?ooo`3oool000000?ooo`02000000T0oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool01`3oool3000000040?ooo`000000oooo000009<0oooo0P0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000000P0000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`000000T`3oool00`000000oooo0?ooo`04000000T0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool01`3oool3000000040?ooo`000000oooo000009<0oooo0P00
00030?ooo`040000003oool0oooo0?ooo`D000000`3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`04000000T0oooo00<000000?ooo`3o
ool00P3oool004/0oooo00<000000?ooo`3oool01`3oool3000000040?ooo`000000oooo000009@0
oooo00D000000?ooo`3oool0oooo000000030?ooo`D000000P3oool2000000<0oooo00@000000?oo
o`0000000000T`3oool00`000000oooo0?ooo`04000000T0oooo00<000000?ooo`3oool00P3oool0
00`0oooo00<0oono07Ad_`3oool0?03oool00`000000oooo0?ooo`070?ooo`<0000000@0oooo0000
003oool00000U03oool200000080oooo0P0000030?ooo`@000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000009@0oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`08
0?ooo`030000003oool0oooo0080oooo000<0?ooo`040?oOW0180000001809cOoc/0oooo0P000008
0?ooo`80000000D0oooo000000000000oooo0000002D0?ooo`8000000P3oool2000000<0oooo00@0
00000?ooo`00000000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0TP3oool00`000000oooo0?ooo`02000000030?ooo`000000oooo00H0oooo0`0000040?ooo`00
3P3oool00`2oM000000000000003000000030000M02oool0oooo03@0oooo00<000000?ooo`3oool0
1P3oool3000000050?ooo`00000000000?ooo`000000U03oool2000000<0oooo00@000000?ooo`3o
ool0oooo1@0000000`3oool000000?ooo`020?ooo`040000003oool00000000009@0oooo00<00000
0?ooo`3oool00P0000000`3oool000000?ooo`080?ooo`030000003oool0oooo0080oooo000B0?oo
o`030?oOW0180000M;oo03H0oooo00<000000?ooo`3oool01P3oool010000000oooo0000003oool2
000000030?ooo`000000oooo09<0oooo0P0000030?ooo`8000000P3oool3000000030?ooo`000000
000000@0oooo00@000000?ooo`0000000000U03oool2000000050?ooo`00000000000?ooo`000000
2@3oool00`000000oooo0?ooo`020?ooo`004@3oool00`3OW4P0001d0;ooo`0g0?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`000000oooo0P0000000`3oool000000?ooo`2D0?ooo`800000
0P3oool200000080oooo0`0000000`3oool00000000000040?ooo`030000003oool0000009D0oooo
0P0000001@3oool000000000003oool0000000T0oooo00<000000?ooo`3oool00P3oool000`0oooo
00H0omnL04P0B02Lgol0okmd00000018W=li0?ooo`030000003oool0oooo00H0oooo00@000000?oo
o`000000oooo0P0000000`3oool000000?ooo`2D0?ooo`8000000P3oool2000000030?ooo`000000
00000080000000<0oooo0000000000000`3oool010000000oooo0?ooo`00002E0?ooo`80000000D0
oooo000000000000oooo000000090?ooo`030000003oool0oooo0080oooo000<0?ooo`040?oOW018
00000000001d_c/0oooo00<000000?ooo`3oool01P3oool010000000oooo0000003oool200000003
0?ooo`000000oooo09@0oooo0P0000020?ooo`80000000<0oooo0000000000000P0000000`3oool0
0000000000030?ooo`040000003oool00000000009D0oooo0P0000001@3oool000000000003oool0
000000T0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01P3oool01000
0000oooo0000003oool2000000030?ooo`000000oooo09@0oooo0P0000020?ooo`030000003oool0
000000@0000000<0oooo0000000000000`3oool010000000oooo00000000002E0?ooo`80000000D0
oooo000000000000oooo000000090?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`000000oooo0P0000000`3oool000000?ooo`2D0?ooo`030000
003oool000000080oooo2@0000030?ooo`030000003oool0000009H0oooo0P0000001@3oool00000
0000003oool0000000T0oooo00<000000?ooo`3oool00P3oool000l0oooo00H0gia8000000000000
00000000B02Lgolf0?ooo`030000003oool0oooo00H0oooo00L000000?ooo`000000oooo0000003o
ool0000009L0oooo0P0000020?ooo`T000000P3oool010000000oooo00000000002G0?ooo`060000
003oool000000000003oool000002@3oool00`000000oooo0?ooo`020?ooo`003@3oool02@3ookl0
M00004RLg`3ogi`0W;oo0?ooo`3OW4P004RL0=ooo`0e0?ooo`030000003oool0oooo00H0oooo00L0
00000?ooo`000000oooo0000003oool0000009L0oooo0P0000020?ooo`@0000000<0oooo00000000
00000`0000000`3oool000000?ooo`02000009L0oooo00H000000?ooo`3oool000000?ooo`000009
0?ooo`030000003oool0oooo0080oooo000=0?ooo`090;mdM02oool0oooo0?noW02Lgol0oooo0?oo
_`1d07@0_ooo03D0oooo00<000000?ooo`3oool01P3oool01`000000oooo0000003oool000000?oo
o`000000U`3oool200000080oooo100000000`3oool0000000000003000000030?ooo`000000oooo
00800000U`3oool01P000000oooo0?ooo`000000oooo000000T0oooo00<000000?ooo`3oool00P3o
ool000`0oooo00T0omnL09boo`3oool0oooO09adW03Oool0oooo0?oOW018M;l0=P3oool00`000000
oooo0?ooo`060?ooo`070000003oool000000?ooo`000000oooo0000002G0?ooo`040000003oool0
00000?ooo`@0000000<0oooo0000003oool0100000020?ooo`800000U`3oool01@000000oooo0?oo
o`000000oooo00800000203oool00`000000oooo0?ooo`020?ooo`00303oool02@3o_i`0W=oo0?oo
o`2oM000M;oo0?ooo`3OW4P0001d0;ooo`0f0?ooo`030000003oool0oooo00H0oooo00L000000?oo
o`000000oooo0000003oool0000009P0oooo0P0000001@3oool00000000000000000oooo00L00000
00<0oooo000000000000V03oool01@000000oooo0?ooo`000000oooo00800000203oool00`000000
oooo0?ooo`020?ooo`00303oool0103ookl0M0000000001d_olk0?ooo`8000001`3oool01`000000
oooo0000003oool000000?ooo`000000V03oool2000000040?ooo`000000000000000080oooo0P00
00000`3oool00000000000020?ooo`800000V03oool01@000000oooo0?ooo`000000oooo00800000
1P3oool3000000@0oooo001;0?ooo`030000003oool0oooo00H0oooo00L000000?ooo`000000oooo
0000003oool0000009P0oooo00<000000?ooo`0000000`0000020?ooo`80000000<0oooo00000000
00000P3oool2000009P0oooo00D000000?ooo`3oool000000?ooo`02000000P0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool01P3oool01`000000oooo0000003oool00000
0?ooo`000000V03oool00`000000oooo0000000300000080oooo0P0000020?ooo`@00000V@3oool0
1@000000oooo0?ooo`000000oooo00800000203oool00`000000oooo0?ooo`020?ooo`00403oool0
1P3o_g@00000000000000000001d0;ooocD0oooo00<000000?ooo`3oool01P3oool01`000000oooo
0000003oool000000?ooo`000000V03oool00`000000oooo0000000300000080oooo0P0000020?oo
o`@00000V@3oool01@000000oooo0?ooo`000000oooo00800000203oool00`000000oooo0?ooo`02
0?ooo`00203oool01P2oW9`0gooo0?ooo`3oool0omnL04P000<0000000@004RL0=ooo`3ookl0M7Bo
=P3oool00`000000oooo0?ooo`060?ooo`070000003oool000000?ooo`000000oooo0000002I0?oo
o`030000003oool00000008000000P3oool200000080oooo1000002I0?ooo`050000003oool0oooo
0000003oool00P0000080?ooo`030000003oool0oooo0080oooo00070?ooo`030?oog`2LB0000000
00<0000000<007Bo0?ooo`3oool00P3oool00`3o_g@0001d0;ooo`0f0?ooo`030000003oool0oooo
00H0oooo0`000000103oool000000?ooo`00002I0?ooo`030000003oool00000008000000P3oool2
00000080oooo1000002I0?ooo`050000003oool0oooo0000003oool00P0000080?ooo`030000003o
ool0oooo0080oooo00070?ooo`030?oo_`1d0000B9cO0440oooo00<000000?ooo`3oool01P3oool3
000000040?ooo`000000oooo000009T0oooo0P0000000`3oool00000000000020?ooo`8000000P3o
ool3000009X0oooo00D000000?ooo`3oool000000?ooo`02000000P0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool01P3oool3000000040?ooo`000000oooo000009T0oooo
0P0000000`3oool00000000000020?ooo`8000000P3oool2000009/0oooo00D000000?ooo`3oool0
00000?ooo`02000000P0oooo00<000000?ooo`3oool00P3oool000l0oooo00H0omnL04P000000000
00000000B02LgolX0?ooo`040;md00000000000007Boo`X0oooo00<000000?ooo`3oool01P3oool3
000000040?ooo`000000oooo000009T0oooo0P0000000`3oool000000?ooo`020?ooo`8000000P3o
ool2000009/0oooo00D000000?ooo`3oool000000?ooo`02000000P0oooo00<000000?ooo`3oool0
0P3oool000h0oooo00<0_g@00000001d_ol00P3oool00`3ooml0W7BL0=ooo`0V0?ooo`060=nLB000
M;l0oooo0?oOW0180000B9cO2@3oool00`000000oooo0?ooo`050?ooo`@0000000@0oooo0000003o
ool00000W03oool010000000oooo0?ooo`3oool200000080oooo0P00002K0?ooo`050000003oool0
oooo0000003oool00P0000080?ooo`030000003oool0oooo0080oooo000=0?ooo`030=nLB018W=l0
oooo00@0oooo00<0gibL0;ooo`3oool0903oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0
W=oo00P0oooo00<000000?ooo`3oool01@3oool4000000040?ooo`000000oooo000009`0oooo00@0
00000?ooo`3oool0oooo0P0000020?ooo`800000V`3oool01@000000oooo0?ooo`000000oooo0080
0000203oool00`000000oooo0?ooo`020?ooo`00303oool00`3ogi`0M9cO0?ooo`040?ooo`030?oo
g`2LM9`0gooo02D0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool70?ooo`03
0000003oool0oooo00D0oooo10000000103oool000000?ooo`00002L0?ooo`8000000P3oool20000
0080oooo0P00002K0?ooo`80000000<0oooo0000003oool00P0000080?ooo`030000003oool0oooo
0080oooo000<0?ooo`030?noW02Lgol0oooo00<0oooo00<0oooO09a8001d_ol09P3oool00`3ooml0
W4P0001d_`030?ooo`030=nLB00004P0W=oo00L0oooo00<000000?ooo`3oool01@3oool400000004
0?ooo`000000oooo000009`0oooo0P0000020?ooo`8000000P3oool2000009/0oooo0P0000000`3o
ool000000?ooo`02000000P0oooo00<000000?ooo`3oool00P3oool000`0oooo00<0omnL04Qd_`3o
ool00P3oool00`3OW4P0000004RLg`0X0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018
W=l01`3ooooo000006800000103oool000d0oooo00H0okmd00000000000000000018W03OoolY0?oo
o`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l01`3oool00`000000oooo0?ooo`050?oo
o`@0000000@0oooo0000003oool00000W03oool200000080oooo0`0000020?ooo`030000003oool0
oooo09T0oooo0P0000000`3oool000000?ooo`02000000P0oooo00<000000?ooo`3oool00P3oool0
03`0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`060?ooo`030000003oool0oooo
00D0oooo10000000103oool000000?ooo`00002M0?ooo`030000003oool0oooo008000000`3oool0
0`000000oooo0?ooo`2I0?ooo`80000000<0oooo0000003oool00P0000080?ooo`030000003oool0
oooo0080oooo000l0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool01P3oool0
0`000000oooo0?ooo`050?ooo`@0000000@0oooo0000003oool00000W@3oool00`000000oooo0?oo
o`02000000<0oooo00<000000?ooo`3oool0V@3oool2000000030?ooo`000000oooo00800000203o
ool00`000000oooo0?ooo`020?ooo`003`3oool01P3ogi`0B000000000000000001809cOobP0oooo
00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`060?ooo`030000003oool0oooo00D0oooo
10000000103oool000000?ooo`00002J0?ooo`040000003oool0oooo00000080oooo0P0000030?oo
o`030000003oool0oooo09T0oooo0P0000000`3oool000000?ooo`02000000P0oooo00<000000?oo
o`3oool00P3oool000d0oooo00@0oooO09a80000B9`0gooo0P3oool00`3o_g@004RL0=ooo`0X0?oo
o`060=nLB00007@0_ooo0?oog`2LB000B9cO1`3oool00`000000oooo0?ooo`050?ooo`@0000000@0
oooo0000003oool00000V@3oool200000080oooo00<000000?ooo`3oool00P0000020?ooo`800000
V`3oool2000000030?ooo`000000oooo00800000203oool00`000000oooo0?ooo`020?ooo`003@3o
ool00`2oM4P0W=oo0?ooo`030?ooo`030?oog`2LB7@0_ooo02T0oooo00@0gia800000000000007Bo
203oool00`000000oooo0?ooo`050?ooo`@0000000@0oooo0000003oool00000V@3oool200000003
0?ooo`00000000000080oooo0`0000000`3oool000000000002K0?ooo`80000000<0oooo0000003o
ool00P0000080?ooo`030000003oool0oooo0080oooo000<0?ooo`030?oOW02L_ol0oooo00@0oooo
00<0omnL04Qd_`3oool0=@3oool00`000000oooo0?ooo`050?ooo`@0000000@0oooo0000003oool0
0000V@3oool2000000030?ooo`00000000000080oooo0`000000103oool000000?ooo`00002J0?oo
o`80000000<0oooo0000003oool00P0000080?ooo`030000003oool0oooo0080oooo000<0?ooo`03
0?noW02Lgol0oooo00<0oooo00<0omnL04Q8W03Oool0=P3oool00`000000oooo0?ooo`050?ooo`@0
000000@0oooo0000003oool00000V@3oool00`000000oooo0000000200000080oooo0`0000000`3o
ool0000000000002000009T0oooo0P0000000`3oool000000?ooo`02000000P0oooo00<000000?oo
o`3oool00P3oool000`0oooo00@0oono07@000000000M;oo>`3oool00`000000oooo0?ooo`050?oo
o`@0000000@0oooo0000003oool00000V@3oool500000080oooo0`0000000`3oool0000000000002
000009T0oooo0P0000000`3oool000000?ooo`02000000P0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool01@3oool4000000040?ooo`000000oooo000009T0oooo1@000002
0?ooo`@0000000@0oooo0000000000000000V@3oool2000000030?ooo`000000oooo00800000203o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`050?ooo`@0000000@0oooo
0000003oool00000V03oool2000000060?ooo`00000000000?ooo`000000oooo1@0000000`3oool0
00000000002I0?ooo`80000000<0oooo0000003oool00P0000080?ooo`030000003oool0oooo0080
oooo000<0?ooo`030?oo_`2LW=l0oooo00<0oooo00@0okmd0000000007@0_ooo=@3oool00`000000
oooo0?ooo`050?ooo`@0000000@0oooo0000003oool00000V03oool2000000060?ooo`000000oooo
0?ooo`000000oooo1@0000020?ooo`030000003oool0oooo09L0oooo100000000`3oool000000000
00080?ooo`030000003oool0oooo0080oooo000<0?ooo`040?oo_`2LW=l0oono07@000@0000000<0
04RL0=ooo`3oool0=03oool2000000H0oooo10000000103oool000000?ooo`00002H0?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`000000100000020?ooo`030000003oool0oooo09L0
oooo100000000`3oool00000000000060?ooo`<00000103oool000`0oooo00T0omnL04P000000000
001809cOo`3oool0oooO09a8M02oool0=P3oool00`000000oooo0?ooo`050?ooo`@0000000@0oooo
0000003oool00000V03oool00`000000oooo0?ooo`02000000030?ooo`00000000000080000000<0
oooo0000000000000P3oool2000009P0oooo100000000`3oool00000000000080?ooo`030000003o
ool0oooo0080oooo00080?ooo`040?oog`2LB000001d0;ooocl0oooo00<000000?ooo`3oool01P3o
ool3000000040?ooo`000000oooo000009L0oooo0P0000020?ooo`L0000000<0oooo000000000000
0P3oool2000009L0oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`080?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00H0oooo00L000000?ooo`000000oooo
0000003oool0000009L0oooo0P0000020?ooo`@0000000P0oooo000000000000oooo0000003oool0
00000?ooo`800000U`3oool00`000000oooo00000002000000030?ooo`000000oooo00P0oooo00<0
00000?ooo`3oool00P3oool000`0oooo00D0omno0;oOo`3oool0oooo0;md0003000000030000M02o
ool0oooo03@0oooo00<000000?ooo`3oool01P3oool01`000000oooo0000003oool000000?ooo`00
0000U`3oool010000000oooo0?ooo`3oool4000000030?ooo`000000oooo0080000000H0oooo0000
003oool000000?ooo`00002F0?ooo`030000003oool000000080000000<0oooo0000003oool0203o
ool00`000000oooo0?ooo`020?ooo`00303oool00`2oM000000000000002000000050000M02oool0
oooo0;nLW03Oool0=@3oool00`000000oooo0?ooo`060?ooo`070000003oool000000?ooo`000000
oooo0000002G0?ooo`040000003oool0oooo0?ooo`<0000000@0oooo000000000000oooo0P000002
0?ooo`80000000<0oooo0000003oool0U@3oool00`000000oooo00000002000000030?ooo`000000
oooo00P0oooo00<000000?ooo`3oool00P3oool000X0oooo00D0_g@000000000000004RL0=ooo`03
0?ooo`030?oog`2LB000M;oo0080oooo00<0_g@00018W03Oool0<@3oool00`000000oooo0?ooo`06
0?ooo`070000003oool000000?ooo`000000oooo0000002G0?ooo`040000003oool0oooo0?ooo`80
000000<0oooo000000000000100000020?ooo`80000000<0oooo0000003oool0U@3oool200000003
0?ooo`0000000000008000002@3oool00`000000oooo0?ooo`020?ooo`00303oool00`3o_i`0W=oo
0?ooo`080?ooo`030?oOW018M;l0oooo0340oooo00<000000?ooo`3oool01P3oool01`000000oooo
0000003oool000000?ooo`000000UP3oool010000000oooo0?ooo`3oool2000000030?ooo`000000
000000D000000`3oool3000009H0oooo0P0000000`3oool0000000000002000000T0oooo00<00000
0?ooo`3oool00P3oool000`0oooo00<0oono07Ad_`3oool01`3oool00`3o_g@004RL0=ooo`0b0?oo
o`030000003oool0oooo00H0oooo00L000000?ooo`000000oooo0000003oool0000009H0oooo00@0
00000?ooo`3oool0oooo0P0000000`3oool0000000000002000000030?ooo`000000000000<0oooo
0P0000000`3oool000000?ooo`2D0?ooo`80000000<0oooo0000000000000P0000090?ooo`030000
003oool0oooo0080oooo000<0?ooo`040?oOW0180000001d0;ooo`D0oooo00<0gia8001d_`3oool0
<`3oool00`000000oooo0?ooo`060?ooo`030000003oool000000080000000<0oooo0000003oool0
U@3oool010000000oooo0?ooo`3oool2000000030?ooo`00000000000080000000@0oooo0000003o
ool000000P3oool2000000030?ooo`000000oooo09@0oooo0P0000000`3oool00000000000020000
00T0oooo00<000000?ooo`3oool00P3oool000d0oooo00<0omnL04P0000000001@0000000`18W=l0
oooo0?ooo`0c0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000000P0000000`3oool0
00000?ooo`2D0?ooo`8000000`3oool00`000000oooo0?ooo`04000000040?ooo`00000000000000
0080oooo0P0000000`3oool000000?ooo`2D0?ooo`80000000<0oooo0000003oool00P0000090?oo
o`030000003oool0oooo0080oooo000B0?ooo`030?noM00004P0W=oo03H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo00000004000009D0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`3oool4000000030?ooo`000000000000<0oooo00<000000?ooo`000000U@3oool20000
00030?ooo`000000oooo008000002@3oool00`000000oooo0?ooo`020?ooo`004@3oool00`2oM000
07Bo0?ooo`0g0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`00000000000?ooo`020000
09D0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`D0000000<0oooo0000000000000`3oool0
10000000oooo0?ooo`00002D0?ooo`80000000<0oooo0000003oool00P0000090?ooo`030000003o
ool0oooo0080oooo000<0?ooo`060?oOW0180000M;oo0?noM0000000M;oo>@3oool2000000L0oooo
00D000000?ooo`00000000000?ooo`02000009D0oooo00D000000?ooo`3oool0oooo000000030?oo
o`80000000<0oooo0000000000000P3oool010000000oooo0?ooo`3oool2000000030?ooo`000000
oooo09<0oooo0P0000000`3oool000000?ooo`02000000L0oooo0`0000040?ooo`00303oool0103o
gi`0B00000000000M;lk0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`00000000000?oo
o`02000009@0oooo0P0000030?ooo`040000003oool0oooo0?ooo`80000000<0oooo000000000000
0P3oool010000000oooo0?ooo`3oool2000000030?ooo`000000oooo09<0oooo0P0000000`3oool0
00000?ooo`02000000T0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
1P3oool01@000000oooo000000000000oooo00800000U03oool010000000oooo0?ooo`3oool20000
0080oooo00<000000?ooo`0000000`0000020?ooo`8000000`3oool00`000000oooo0000002D0?oo
o`80000000<0oooo0000003oool00P0000090?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo00H0oooo00D000000?ooo`00000000000?ooo`03000009<0oooo00@000000?oo
o`3oool0oooo0P0000020?ooo`80000000@0oooo00000000000000000`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0T@3oool2000000030?ooo`000000oooo00800000
2@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`060?ooo`@0000000@0
oooo0000000000000000T`3oool01@000000oooo0?ooo`3oool0000000<0oooo0P000000103oool0
00000000000000030?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool0TP3oool2
000000030?ooo`000000oooo008000002@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`00
0000oooo0?ooo`060?ooo`80000000H0oooo0000003oool000000?ooo`00002B0?ooo`8000000P3o
ool200000080oooo00@000000?ooo`000000oooo0`0000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`000000T`3oool2000000030?ooo`000000oooo008000002@3oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`070?ooo`070000003oool000000?ooo`000000
oooo0000002B0?ooo`040000003oool0oooo0?ooo`8000000P3oool010000000oooo0000003oool4
00000080oooo0P0000030?ooo`030000003oool0000009<0oooo0P0000000`3oool000000?ooo`02
000000T0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01`3oool01`00
0000oooo0000003oool000000?ooo`000000TP3oool010000000oooo0?ooo`3oool2000000060?oo
o`000000oooo0?ooo`000000oooo0P0000000`3oool000000?ooo`020?ooo`040000003oool0oooo
0?ooo`80000000<0oooo0000003oool0T@3oool01@000000oooo0?ooo`000000oooo008000002@3o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`070?ooo`040000003oool0
00000?ooo`<00000TP3oool00`000000oooo0?ooo`0200000080oooo00@000000?ooo`000000oooo
0`0000000`3oool000000?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
TP3oool01@000000oooo0?ooo`000000oooo008000002@3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`070?ooo`030000003oool000000080oooo0P00002A0?ooo`800000
0P3oool200000080oooo00@000000?ooo`000000oooo1@0000030?ooo`8000000`3oool00`000000
oooo0000002B0?ooo`050000003oool000000000003oool00P0000090?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000000P3oool200000940
oooo00P000000?ooo`3oool000000?ooo`000000oooo00000080oooo00<000000?ooo`0000001@00
00030?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool0T03oool01@000000oooo
000000000000oooo008000002@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`070?ooo`030000003oool000000080oooo0P00002A0?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000020?ooo`030000003oool0000000<0000000<0oooo0000003oool00P3oool0
10000000oooo0?ooo`3oool2000000030?ooo`000000oooo08l0oooo0P0000000`3oool000000000
0003000000T0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo000000020?ooo`800000T@3oool00`000000oooo0?ooo`0200000080oooo00@00000
0?ooo`000000oooo0P0000001@3oool000000000003oool0000000<0oooo0P0000030?ooo`030000
003oool000000900oooo0P0000000`3oool0000000000003000000T0oooo00<000000?ooo`3oool0
0P3oool004/0oooo0P0000080?ooo`030000003oool000000080oooo0P00002@0?ooo`80000000H0
oooo0000003oool000000?ooo`0000020?ooo`070000003oool000000000003oool000000?ooo`03
00000080oooo0P0000030?ooo`80000000<0oooo0000003oool0SP3oool2000000030?ooo`000000
oooo00<000001`3oool3000000@0oooo001;0?ooo`030000003oool0oooo00L0oooo00D000000?oo
o`00000000000?ooo`0200000900oooo00P000000?ooo`3oool000000?ooo`000000oooo00000080
oooo00L000000?ooo`00000000000?ooo`000000oooo00<000000`3oool010000000oooo0?ooo`3o
ool2000000030?ooo`000000oooo08h0oooo0P0000000`3oool000000?ooo`03000000T0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01`3oool020000000oooo00000000
0000oooo0000003oool00000S`3oool020000000oooo0?ooo`000000oooo0000003oool000000P3o
ool300000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo
0`00002?0?ooo`80000000<0oooo0000003oool00P00000:0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo00L0oooo00P000000?ooo`00000000000?ooo`000000oooo0000
08h0oooo0P0000001P3oool000000?ooo`000000oooo00000080oooo00@000000?ooo`0000000000
0P3oool010000000oooo0000003oool200000080oooo0P0000030?ooo`80000000<0oooo0000003o
ool0S@3oool2000000030?ooo`000000oooo008000002P3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`070?ooo`080000003oool0oooo0000003oool000000?ooo`00002>
0?ooo`80000000H0oooo0000003oool000000?ooo`0000020?ooo`040000003oool0000000000080
oooo00<000000?ooo`3oool00`0000030?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000
003oool0S@3oool01@000000oooo0?ooo`000000oooo008000002P3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`070?ooo`80000000@0oooo0000003oool0oooo0P00002>
0?ooo`080000003oool0oooo0000003oool000000?ooo`0000020?ooo`80000000D0oooo0000003o
ool0oooo000000020?ooo`030000003oool0000000<0oooo00H000000?ooo`3oool0oooo0000003o
ool2000008h0oooo00D000000?ooo`00000000000?ooo`02000000X0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool01`3oool2000000040?ooo`000000oooo0?ooo`800000
S@3oool2000000040?ooo`000000oooo0?ooo`8000000`3oool3000000<0oooo00H000000?ooo`3o
ool000000?ooo`0000040?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool0S03o
ool01@000000oooo000000000000oooo008000002P3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool000000080oooo0P00002=0?ooo`80000000H0
oooo0000003oool000000?ooo`0000020?ooo`040000003oool00000000000<0oooo00@000000?oo
o`3oool0oooo0`0000030?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool0S03o
ool01@000000oooo000000000000oooo008000002P3oool00`000000oooo0?ooo`020?ooo`00;`3o
ool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00<0gia8000000000000
0`0000000`18W=l0oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000
0P3oool3000008`0oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`040000
003oool00000000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00H00000
0?ooo`3oool0oooo0000003oool2000008`0oooo0P0000000`3oool0000000000003000000X0oooo
00<000000?ooo`3oool00P3oool002h0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`03
0?oOW0180000M;oo00<0oooo00<0okmd001d_`3oool00P3oool00`2oM7@0_ooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`0000000P3oool3000008/0oooo0P000000103oool0
00000?ooo`3oool2000000<0oooo0`0000040?ooo`070000003oool0oooo0?ooo`000000oooo0000
00040?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool0RP3oool2000000060?oo
o`00000000000000003oool000002P3oool00`000000oooo0?ooo`020?ooo`00;@3oool00`3ooml0
W4P004RLg`020?ooo`030?noM00004P0W=oo00P0oooo00<0okmd001d_`3oool02`3oool00`000000
oooo0?ooo`080?ooo`030000003oool000000080oooo0`00002;0?ooo`80000000H0oooo0000003o
ool000000?ooo`0000020?ooo`040000003oool00000000000@0oooo00<000000?ooo`3oool00P3o
ool3000000<0oooo00H000000?ooo`3oool0oooo0000003oool2000008/0oooo0P0000001P3oool0
0000000000000000oooo000000X0oooo00<000000?ooo`3oool00P3oool002d0oooo00<0oooO09a8
0018W=l00P3oool0103ooml0W4P00018W03Oool80?ooo`030?noM000M;l0oooo00X0oooo00<00000
0?ooo`3oool0203oool00`000000oooo000000020?ooo`030000003oool0000008X0oooo0P000000
1`3oool000000?ooo`3oool000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000000`3oool200000080oooo00@000000?ooo`000000
0000R`3oool020000000oooo0?ooo`000000oooo0000003oool000002P3oool00`000000oooo0?oo
o`020?ooo`00;@3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00T0oooo00<0okmd
04RLg`3oool02@3oool00`000000oooo0?ooo`080?ooo`@0000000@0oooo0000003oool00000RP3o
ool2000000040?ooo`000000oooo0?ooo`8000000`3oool3000000D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000030?ooo`8000000P3oool01@000000oooo0000003oool0000008X0
oooo00D000000?ooo`3oool000000?ooo`02000000/0oooo00<000000?ooo`3oool00P3oool002h0
oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?ooo`030=nLB018W=l0oooo00P0
oooo0`0000080?ooo`80000000<0oooo0000003oool00`00002:0?ooo`<000000`3oool200000080
oooo00@000000?ooo`00000000001@3oool00`000000oooo0?ooo`030?ooo`<000000`3oool01P00
0000oooo0?ooo`3oool000000?ooo`800000RP3oool01@000000oooo0?ooo`000000oooo00800000
2@3oool3000000@0oooo000^0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l02`3o
ool00`2oM000M;oo0?ooo`070?ooo`030000003oool0oooo00P0oooo0P000000103oool000000?oo
o`3oool2000008T0oooo0P000000103oool000000?ooo`3oool2000000<0oooo00<000000?ooo`00
00001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000<0oooo0P0000020?ooo`04
0000003oool00000000008X0oooo00D000000?ooo`00000000000?ooo`02000000/0oooo00<00000
0?ooo`3oool00P3oool002h0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`0:0?oo
o`030?oOW01807@0_ooo00L0oooo00<000000?ooo`3oool0203oool2000000040?ooo`000000oooo
0?ooo`<00000R03oool2000000040?ooo`000000oooo0?ooo`8000000`3oool3000000H0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000030?ooo`8000000P3oool00`000000oooo0?oo
o`02000008T0oooo00D000000?ooo`00000000000?ooo`02000000/0oooo00<000000?ooo`3oool0
0P3oool002h0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`0:0?ooo`030?oo
g`2LB000M;oo00L0oooo00<000000?ooo`3oool0203oool2000000040?ooo`000000oooo0?ooo`<0
0000R03oool3000000<0oooo0P0000020?ooo`040000003oool00000000000H0oooo00<000000?oo
o`3oool0103oool2000000@0oooo0P0000020?ooo`040000003oool00000000008T0oooo00<00000
0?ooo`0000001000000;0?ooo`030000003oool0oooo0080oooo000_0?ooo`030?oOW0180000M;oo
0080oooo00<0gia8001d_`3oool02P3oool00`3ookl0M00004RLg`070?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`0000000P3oool3000008L0oooo0P000000103oool000000?ooo`3oool2
000000<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
000000<0oooo0P0000020?ooo`040000003oool00000000008T0oooo00<000000?ooo`0000001000
000;0?ooo`030000003oool0oooo0080oooo000`0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO
1`3oool01`3o_g@004RL0=ooo`3oool0gia80000B02Lgol01`3oool00`000000oooo0?ooo`090?oo
o`030000003oool000000080oooo0`0000270?ooo`80000000@0oooo0000003oool0oooo0P000003
0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo00000003
0?ooo`8000000`3oool010000000oooo0000000000270?ooo`80000000H0oooo0000000000000000
0?ooo`00000;0?ooo`030000003oool0oooo0080oooo000a0?ooo`040=nLB00000000000001d_`T0
oooo00D0omnL04P000000000000007Boo`080?ooo`030000003oool0oooo00T0oooo0`0000020?oo
o`<00000Q`3oool00`000000oooo000000030?ooo`8000000`3oool2000000P0oooo00<000000?oo
o`3oool01@3oool2000000@0oooo0P0000020?ooo`040000003oool00000000008L0oooo00P00000
0?ooo`3oool000000?ooo`000000oooo000000/0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool02@3oool2000000030?ooo`000000oooo00<00000QP3oool2000000030?oo
o`000000oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0000000P0oooo00<000000?oo
o`3oool01@3oool00`000000oooo000000030?ooo`8000000P3oool01@000000oooo0000003oool0
000008H0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000/0oooo00<000000?ooo`3o
ool00P3oool004/0oooo00<000000?ooo`3oool02@3oool2000000030?ooo`000000oooo00@00000
Q@3oool3000000<0oooo0P0000030?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0
1P3oool2000000<0oooo00<000000?ooo`0000000P3oool010000000oooo0000000000260?ooo`05
0000003oool0oooo0000003oool00P00000<0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo00T0oooo0P000000103oool000000?ooo`3oool3000008D0oooo00<000000?oo
o`0000000`3oool2000000<0oooo0P0000090?ooo`030000003oool0oooo00H0oooo0P0000030?oo
o`030000003oool000000080oooo00@000000?ooo`0000000000QP3oool01@000000oooo0?ooo`00
0000oooo00800000303oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool000000080oooo0`0000240?ooo`80000000<0oooo0000003oool00P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000002@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0000000<0oooo0P0000020?ooo`030000003oool0oooo00800000Q@3oool00`000000oooo
00000004000000`0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo000000020?ooo`<00000Q03oool3000000<0oooo0P0000030?ooo`<000002@3o
ool00`000000oooo0?ooo`070?ooo`8000000`3oool00`000000oooo000000020?ooo`040000003o
ool00000000008D0oooo00@000000?ooo`000000oooo0`00000<0?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo00X0oooo0`0000020?ooo`<00000P`3oool2000000030?oo
o`000000oooo0080oooo0P0000030?ooo`8000002P3oool00`000000oooo0?ooo`070?ooo`<00000
0P3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`000000Q03oool010000000
oooo0000003oool3000000`0oooo00<000000?ooo`3oool00P3oool004/0oooo0P00000;0?ooo`<0
00000P3oool3000008<0oooo0`0000030?ooo`8000000`3oool3000000X0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00@000000?ooo`00
00000000P`3oool020000000oooo0?ooo`000000oooo0000003oool000002P3oool3000000@0oooo
001;0?ooo`030000003oool0oooo00X0oooo100000000`3oool000000000000200000840oooo00@0
00000?ooo`00000000000`3oool2000000<0oooo0P00000;0?ooo`030000003oool0oooo00P0oooo
0`0000020?ooo`030000003oool000000080oooo00D000000?ooo`000000oooo000000220?ooo`05
0000003oool0oooo0000003oool00P00000=0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`0000000P3oool300000840oooo0P0000000`3oool0
00000?ooo`020?ooo`030000003oool0oooo0080oooo0P00000;0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`0000000`3oool01@000000oooo0000003oool000000080oooo0P0000220?oo
o`050000003oool000000000003oool00P00000=0?ooo`030000003oool0oooo0080oooo001;0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`0000000P3oool00`000000oooo000000200?oo
o`040000003oool00000000000<0oooo0P0000030?ooo`<000002`3oool00`000000oooo0?ooo`08
0?ooo`040000003oool0000000000080oooo00<000000?ooo`0000000P3oool010000000oooo0000
000000220?ooo`050000003oool000000000003oool00P00000=0?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`0000000P3oool00`000000oooo
000000200?ooo`040000003oool00000000000<0oooo00<000000?ooo`3oool00P3oool2000000`0
oooo00<000000?ooo`3oool02@3oool3000000<0oooo00D000000?ooo`000000oooo000000020?oo
o`800000P@3oool010000000oooo0000003oool3000000d0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool02`3oool00`000000oooo000000020?ooo`<00000O`3oool01000
0000oooo0000000000030?ooo`800000103oool2000000`0oooo00<000000?ooo`3oool02@3oool0
10000000oooo0000000000020?ooo`030000003oool000000080oooo00@000000?ooo`0000000000
P03oool01@000000oooo0?ooo`000000oooo00<000003@3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0;0?ooo`<000000P3oool3000007l0oooo00@000000?ooo`000000
00000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000`0oooo00<000000?ooo`3o
ool02@3oool010000000oooo0000000000030?ooo`050000003oool000000?ooo`0000000P3oool2
000007l0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000d0oooo00<000000?ooo`3o
ool00P3oool004/0oooo00<000000?ooo`3oool0303oool200000080oooo0P0000000`3oool00000
0?ooo`1l0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool2000000d0
oooo00<000000?ooo`3oool02P3oool010000000oooo0000000000020?ooo`050000003oool00000
0?ooo`0000000P3oool2000007l0oooo00D000000?ooo`00000000000?ooo`02000000h0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0303oool00`000000oooo00000002
0?ooo`030000003oool0000007d0oooo00@000000?ooo`00000000000`3oool00`000000oooo0?oo
o`020?ooo`<000003@3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0000000000080oooo
00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo07d0oooo00D000000?oo
o`00000000000?ooo`02000000h0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool0303oool00`000000oooo000000020?ooo`030000003oool0000007d0oooo00<000000?oo
o`000000103oool00`000000oooo0?ooo`020?ooo`8000003P3oool00`000000oooo0?ooo`0;0?oo
o`040000003oool0000000000080oooo00D000000?ooo`000000oooo000000020?ooo`800000O@3o
ool2000000040?ooo`000000oooo0?ooo`8000003P3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool000000080oooo00<000000?ooo`000000O03o
ool010000000oooo0000000000030?ooo`8000000`3oool3000000h0oooo00<000000?ooo`3oool0
2`3oool010000000oooo0000000000020?ooo`070000003oool0oooo0000003oool000000?ooo`02
000007d0oooo00D000000?ooo`3oool000000?ooo`03000000h0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool0303oool00`000000oooo000000020?ooo`@00000N`3oool0
0`000000oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool0
0`000000oooo0?ooo`0<0?ooo`80000000T0oooo0000003oool0oooo0000003oool000000?ooo`00
00000P3oool2000007`0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000h0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0303oool4000000050?ooo`000000
00000?ooo`000000NP3oool010000000oooo0000000000030?ooo`8000000`3oool3000000l0oooo
00<000000?ooo`3oool0303oool010000000oooo0000000000020?ooo`030000003oool0oooo0080
00000P3oool2000007`0oooo00P000000?ooo`00000000000?ooo`000000oooo000000h0oooo00<0
00000?ooo`3oool00P3oool004/0oooo0P00000>0?ooo`<000000P3oool00`000000oooo0000001j
0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000?
0?ooo`030000003oool0oooo00d0oooo0P0000002@3oool000000?ooo`3oool000000?ooo`000000
oooo000000020?ooo`800000NP3oool2000000040?ooo`00000000000?ooo`8000003@3oool30000
00@0oooo001;0?ooo`030000003oool0oooo00d0oooo0`0000020?ooo`030000003oool0000007T0
oooo00@000000?ooo`00000000000`3oool2000000<0oooo0`00000@0?ooo`030000003oool0oooo
00d0oooo00@000000?ooo`00000000000P3oool00`000000oooo0?ooo`0200000080oooo0P00001j
0?ooo`040000003oool0oooo00000080oooo0P00000?0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000000P3oool4000007P0oooo00<00000
0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool000000100oooo00<00000
0?ooo`3oool03P3oool2000000060?ooo`000000oooo0?ooo`000000oooo0P0000030?ooo`800000
N@3oool010000000oooo0?ooo`0000020?ooo`8000003`3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000080oooo0P0000000`3oool00000
0?ooo`1f0?ooo`040000003oool00000000000<0oooo0P0000040?ooo`8000004@3oool00`000000
oooo0?ooo`0>0?ooo`80000000D0oooo0000003oool0oooo000000020?ooo`8000000P3oool20000
07T0oooo00D000000?ooo`00000000000?ooo`03000000l0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool03@3oool400000080oooo00<000000?ooo`000000M`3oool00`00
0000oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000004@3oool00`00
0000oooo0?ooo`0>0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`8000000`3o
ool2000007L0oooo0P000000103oool000000000003oool200000100oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool03P3oool300000080oooo00<000000?ooo`000000MP3o
ool010000000oooo0000000000030?ooo`800000103oool200000180oooo00<000000?ooo`3oool0
3`3oool2000000050?ooo`000000oooo0?ooo`0000000P3oool200000080oooo0P00001g0?ooo`04
0000003oool0oooo00000080oooo0P00000@0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo00h0oooo0`0000020?ooo`@00000M@3oool00`000000oooo000000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0?0?ooo`07
0000003oool000000?ooo`000000oooo000000020?ooo`8000000`3oool2000007H0oooo00@00000
0?ooo`3oool000000P3oool200000100oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo000000020?ooo`80000000<0oooo0000003oool0L`3oool0
10000000oooo0000000000030?ooo`800000103oool2000001<0oooo00<000000?ooo`3oool0403o
ool2000000050?ooo`000000oooo0?ooo`0000000P3oool200000080oooo0P00001f0?ooo`040000
003oool0000000000080oooo0P00000@0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo00h0oooo00D000000?ooo`00000000000?ooo`02000000030?ooo`000000oooo07<0
oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0000001<0
oooo00<000000?ooo`3oool0403oool01`000000oooo0000003oool000000?ooo`0000000P3oool2
000000<0oooo0P00001d0?ooo`80000000<0oooo0000000000000P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00l0oooo0`0000020?oo
o`030000003oool0000007<0oooo00@000000?ooo`00000000000`3oool2000000@0oooo0P00000D
0?ooo`030000003oool0oooo0140oooo0P0000001@3oool000000?ooo`3oool000000080oooo0P00
00020?ooo`030000003oool0000007<0oooo00<000000?ooo`3oool00P0000000`3oool000000000
000A0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00l0oooo0`000002
0?ooo`@00000LP3oool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`000000503oool00`000000oooo0?ooo`0A0?ooo`8000000P3oool00`000000oooo00000002
0?ooo`8000000`3oool2000007<0oooo00@000000?ooo`3oool000000P3oool200000140oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool03`3oool00`000000oooo00000002
0?ooo`80000000<0oooo0000003oool0L03oool010000000oooo0000000000030?ooo`030000003o
ool0oooo00<0oooo0P00000E0?ooo`030000003oool0oooo0180oooo0P0000001@3oool000000?oo
o`3oool000000080oooo0P0000020?ooo`030000003oool000000780oooo00@000000?ooo`000000
00000P3oool200000140oooo00<000000?ooo`3oool00P3oool004/0oooo0P00000@0?ooo`030000
003oool000000080oooo0P0000000`3oool000000?ooo`1`0?ooo`030000003oool0000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0000000E0?ooo`030000003oool0oooo0180oooo
0P0000020?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool200000740oooo
0P0000000`3oool00000000000020?ooo`030000003oool0oooo00h0oooo0`0000040?ooo`00B`3o
ool00`000000oooo0?ooo`0?0?ooo`@000000P3oool00`000000oooo0000001`0?ooo`040000003o
ool00000000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000E0?ooo`030000
003oool0oooo01<0oooo0P0000001@3oool000000?ooo`3oool000000080oooo0P0000030?ooo`80
0000L03oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool000000080oooo
0P0000000`3oool000000?ooo`1]0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00P3oool3000001H0oooo00<000000?ooo`3oool04`3oool200000080oooo00<000000?ooo`00
00000`3oool200000080oooo0P00001`0?ooo`030000003oool0oooo0080000000<0oooo00000000
00004P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool000000080oooo0P0000000`3oool000000?ooo`1]0?ooo`030000003oool0000000@0oooo
00<000000?ooo`3oool00P3oool2000000030?ooo`000000oooo01D0oooo00<000000?ooo`3oool0
503oool200000080oooo00<000000?ooo`0000000P3oool2000000<0oooo0P00001_0?ooo`040000
003oool0oooo00000080oooo0P00000B0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`0000000P3oool2000000030?ooo`000000oooo06`0oooo
00@000000?ooo`00000000000`3oool2000000@0oooo0`00000G0?ooo`030000003oool0oooo01@0
oooo0P0000020?ooo`030000003oool0000000<0oooo0P0000020?ooo`800000KP3oool00`000000
oooo0?ooo`0200000080oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0000000000080oooo0`00001/0?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool2000000030?ooo`000000oooo
01H0oooo00<000000?ooo`3oool05@3oool200000080oooo00<000000?ooo`0000000`3oool20000
0080oooo0P00001]0?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0140oooo00<000000?ooo`00
00000P3oool2000000030?ooo`000000oooo06X0oooo00<000000?ooo`000000103oool2000000@0
oooo0`00000H0?ooo`030000003oool0oooo01D0oooo0P0000020?ooo`030000003oool0000000<0
oooo0P0000030?ooo`800000K03oool00`000000oooo0?ooo`02000000030?ooo`000000000001<0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool04@3oool00`000000oooo
000000020?ooo`80000000<0oooo0000003oool0J@3oool010000000oooo0?ooo`0000030?ooo`80
0000103oool2000000030?ooo`000000oooo01L0oooo00<000000?ooo`3oool05P3oool200000080
oooo00<000000?ooo`0000000`3oool200000080oooo0P00001[0?ooo`050000003oool0oooo0?oo
o`0000000P3oool2000001<0oooo00<000000?ooo`3oool00P3oool002l0oooo00@0_g@000000000
0000M;oo0`3oool00`3ogi`0B00007Boo`050?ooo`030?oog`2LB000B9cO00X0oooo00<000000?oo
o`3oool04@3oool00`000000oooo000000030?ooo`030000003oool0000006X0oooo00<000000?oo
o`000000103oool2000000@0oooo0`00000I0?ooo`030000003oool0oooo01L0oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`8000000`3oool2000006X0oooo00<000000?ooo`3oool00P00
00020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool002h0oooo00H0gia8
001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00H0oooo00<0gia80018W03Oool0
2@3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000080oooo0P0000000`3oool0
00000?ooo`1W0?ooo`040000003oool00000000000<0oooo0P0000040?ooo`80000000<0oooo0000
003oool0603oool00`000000oooo0?ooo`0G0?ooo`8000000P3oool00`000000oooo000000030?oo
o`8000000`3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo008000000P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo000]0?ooo`030?oog`2LB000B9cO0080
oooo00<0okmd0000B02Lgol02P3oool00`3ogi`0B01809cOo`090?ooo`030000003oool0oooo0140
oooo00@000000?ooo`3oool000000P3oool2000000030?ooo`000000oooo06H0oooo00@000000?oo
o`3oool00000103oool2000000<0oooo00@000000?ooo`00000000006P3oool00`000000oooo0?oo
o`0H0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`8000000P3oool2000006P0
oooo00D000000?ooo`3oool0oooo000000020?ooo`800000503oool00`000000oooo0?ooo`020?oo
o`00;@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`D0oooo00<0okmd0000
00000000100000000`00B9`0gooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?oo
o`0000000P3oool2000000030?ooo`000000000006H0oooo00@000000?ooo`00000000000`3oool2
000000@0oooo0P0000000`3oool000000?ooo`0I0?ooo`030000003oool0oooo01P0oooo0P000002
0?ooo`030000003oool0000000<0oooo0P0000030?ooo`030000003oool0oooo06H0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`800000503oool00`000000oooo0?ooo`020?ooo`00;@3oool0
0`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00D0oooo00<0oooO09a8B02Lgol00P3oool0
0`2oM00007Bo0?ooo`080?ooo`030000003oool0oooo0180oooo00@000000?ooo`00000000000P3o
ool010000000oooo00000000001U0?ooo`040000003oool0oooo000000<0oooo0P0000040?ooo`04
0000003oool00000000001/0oooo00<000000?ooo`3oool06@3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000`3oool2000000<0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?oo
o`0200000080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`00;P3oool0
0`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00H0oooo00L0oono07@0M02oool0oooo0?no
M000B9`0gooo00P0oooo0`00000B0?ooo`040000003oool0oooo00000080oooo0P0000000`3oool0
00000?ooo`1T0?ooo`030000003oool0000000@0oooo0P0000040?ooo`80000000<0oooo0000003o
ool06P3oool00`000000oooo0?ooo`0J0?ooo`060000003oool0oooo0000003oool00000103oool0
10000000oooo0?ooo`3oool2000006D0oooo00@000000?ooo`3oool0oooo0P0000000`3oool00000
0000000C0?ooo`<00000103oool002h0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d
_`070?ooo`060?oOW018B9`0gooo0?oOW01804P0W=oo203oool00`000000oooo0?ooo`0B0?ooo`04
0000003oool0oooo00000080oooo0P0000000`3oool000000000001S0?ooo`040000003oool00000
000000<0oooo0P0000040?ooo`040000003oool00000000001`0oooo00<000000?ooo`3oool06P3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool2000000<0oooo00<000000?ooo`3o
ool0H`3oool01@000000oooo0?ooo`3oool000000080oooo0P00000E0?ooo`030000003oool0oooo
0080oooo000^0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01`3oool01@3o_g@0
07Bo0?oog`2LB000B9cO00P0oooo00<000000?ooo`3oool04`3oool010000000oooo000000000002
0?ooo`040000003oool0000000000680oooo00@000000?ooo`3oool000000`3oool00`000000oooo
000000040?ooo`80000000<0oooo0000003oool06`3oool00`000000oooo0?ooo`0K0?ooo`060000
003oool0oooo0000003oool00000103oool010000000oooo0?ooo`3oool2000006<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`02000001D0oooo00<000000?ooo`3oool00P3oool0
02h0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`080?ooo`040=nLB018W=l0
_g@0001d_`P0oooo00<000000?ooo`3oool04`3oool010000000oooo0?ooo`0000020?ooo`800000
00<0oooo0000003oool0H@3oool00`000000oooo000000040?ooo`800000103oool2000000030?oo
o`000000oooo01`0oooo00<000000?ooo`3oool06`3oool200000080oooo00<000000?ooo`000000
103oool010000000oooo0?ooo`3oool200000680oooo00@000000?ooo`3oool0oooo0P0000000`3o
ool000000000000F0?ooo`030000003oool0oooo0080oooo000_0?ooo`030?oOW0180000M;oo0080
oooo00<0gia8001d_`3oool02@3oool0103OW4P0M7Ad0000M02oool70?ooo`030000003oool0oooo
01<0oooo00@000000?ooo`3oool000000P3oool2000000030?ooo`00000000000600oooo00<00000
0?ooo`000000103oool00`000000oooo000000040?ooo`80000000<0oooo0000003oool0703oool0
0`000000oooo0?ooo`0L0?ooo`040000003oool0oooo0?ooo`800000103oool2000000<0oooo0P00
001Q0?ooo`050000003oool0oooo0?ooo`0000000P3oool2000001H0oooo00<000000?ooo`3oool0
0P3oool00300oooo00H0gia80000M02oool0oooO09a80018W=l;0?ooo`030;md000004P0W=oo00L0
oooo00<000000?ooo`3oool04`3oool2000000030?ooo`00000000000080oooo0P0000000`3oool0
00000?ooo`1N0?ooo`040000003oool0oooo000000@0oooo0P0000040?ooo`80000000<0oooo0000
003oool07@3oool00`000000oooo0?ooo`0L0?ooo`8000000P3oool00`000000oooo000000040?oo
o`040000003oool0oooo0?ooo`800000H03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo008000005P3oool00`000000oooo0?ooo`020?ooo`00<@3oool0103OW4P0000000000000M;l<
0?ooo`030?oog`2LB000B9cO00L0oooo00<000000?ooo`3oool0503oool010000000oooo00000000
00020?ooo`80000000<0oooo000000000000GP3oool00`000000oooo000000040?ooo`030000003o
ool0000000<0oooo0P0000000`3oool000000?ooo`0N0?ooo`030000003oool0oooo01d0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000@0oooo00@000000?ooo`3oool0oooo0P00001O0?oo
o`040000003oool0oooo0?ooo`80000000@0oooo0000003oool000005P3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo000000<0oooo00@0
00000?ooo`0000000000G@3oool00`000000oooo000000040?ooo`030000003oool0000000@0oooo
00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`0N0?ooo`060000003oool0oooo0000
003oool00000103oool00`000000oooo0?ooo`020?ooo`800000GP3oool01@000000oooo0?ooo`3o
ool000000080oooo0P00000G0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`0000000`3oool2000000030?ooo`000000oooo05`0oooo0`000003
0?ooo`030000003oool0000000@0oooo0P0000000`3oool000000?ooo`0O0?ooo`030000003oool0
oooo01h0oooo0P0000020?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1K0?ooo`040000003oool0oooo0?ooo`8000000P3oool2000001L0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool05@3oool010000000oooo00000000
00030?ooo`040000003oool00000000005/0oooo00<000000?ooo`000000103oool00`000000oooo
000000040?ooo`030000003oool000000240oooo00<000000?ooo`3oool07`3oool01P000000oooo
0?ooo`000000oooo000000@0oooo0P0000030?ooo`800000G03oool010000000oooo0?ooo`3oool2
000000040?ooo`000000oooo000001L0oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool05@3oool010000000oooo0?ooo`0000030?ooo`80000000<0oooo0000003oool0F@3o
ool00`000000oooo000000040?ooo`030000003oool0000000@0oooo00<000000?ooo`0000008P3o
ool00`000000oooo0?ooo`0P0?ooo`060000003oool0oooo0000003oool00000103oool00`000000
oooo0?ooo`020?ooo`800000F`3oool010000000oooo0?ooo`3oool2000000030?ooo`0000000000
01P0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool05@3oool200000003
0?ooo`000000oooo00<0oooo00<000000?ooo`000000F@3oool00`000000oooo000000040?ooo`03
0000003oool0000000D0oooo00<000000?ooo`0000008P3oool00`000000oooo0?ooo`0P0?ooo`80
00000P3oool2000000D0oooo00<000000?ooo`3oool00P3oool2000005T0oooo00@000000?ooo`3o
ool0oooo0P000000103oool0000000000000000H0?ooo`030000003oool0oooo0080oooo001;0?oo
o`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00
001G0?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0000000S0?ooo`030000003oool0oooo0240oooo00H000000?ooo`3oool000000?ooo`0000040?oo
o`800000103oool00`000000oooo0?ooo`1E0?ooo`030000003oool0000000<0oooo0P0000000`3o
ool000000000000I0?ooo`030000003oool0oooo0080oooo001;0?ooo`8000005`3oool200000003
0?ooo`000000oooo00<0oooo00<000000?ooo`000000E`3oool00`000000oooo000000030?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`000000903oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo008000001@3oool2000000@0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo000000040?ooo`80000000<0oooo0000000000005`3oool3000000@0oooo001;0?ooo`03
0000003oool0oooo01H0oooo0P0000000`3oool00000000000030?ooo`040000003oool0oooo0000
05D0oooo00<000000?ooo`000000103oool00`000000oooo000000040?ooo`80000000<0oooo0000
003oool08`3oool00`000000oooo0?ooo`0R0?ooo`040000003oool0oooo0?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0580oooo00<000000?ooo`0000000`3oool2
000000040?ooo`0000000000000001T0oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool05`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0000005@0oooo00<0
00000?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0000002D0oooo
00<000000?ooo`3oool08`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0000000@0oooo0P0000000`3o
ool000000000000J0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01L0
oooo0P0000000`3oool00000000000030?ooo`040000003oool0oooo00000580oooo00<000000?oo
o`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0000002H0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`02000000D0oooo0P0000040?ooo`030000003oool0
oooo0500oooo00<000000?ooo`0000000`3oool2000000040?ooo`0000000000000001X0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool05`3oool2000000030?ooo`000000
000000<0oooo0P0000000`3oool000000?ooo`1@0?ooo`040000003oool00000000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`80000000<0oooo0000003oool09@3oool00`000000oooo
0?ooo`0T0?ooo`040000003oool0oooo0?ooo`8000001@3oool2000000@0oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo000000040?ooo`80000000@0oooo00000000000000006P3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo0000
00@0oooo00@000000?ooo`3oool00000C`3oool010000000oooo0000000000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool2000000030?ooo`000000oooo02H0oooo00<000000?ooo`3oool0
9@3oool010000000oooo0?ooo`3oool2000000D0oooo0P0000040?ooo`030000003oool0oooo04d0
oooo0`0000030?ooo`8000000P3oool2000001/0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool0603oool2000000030?ooo`000000000000<0oooo0P0000020?ooo`030000
003oool0oooo04`0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0000002P0oooo00<000000?ooo`3oool09P3oool01P000000oooo0?ooo`000000oooo
000000D0oooo0P0000030?ooo`800000C@3oool00`000000oooo000000040?ooo`80000000@0oooo
00000000000000006`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0H
0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000004d0oooo00<0
00000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo0P0000000`3oool00000
0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`80
0000103oool2000004`0oooo0`0000030?ooo`8000000P3oool3000001/0oooo00<000000?ooo`3o
ool00P3oool004/0oooo00<000000?ooo`3oool06@3oool2000000030?ooo`000000000000<0oooo
0P0000020?ooo`030000003oool0oooo04T0oooo00@000000?ooo`00000000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo0P0000000`3oool000000?ooo`0X0?ooo`030000003oool0oooo
02L0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`800000103oool2000004X0oooo00<00000
0?ooo`000000103oool2000000040?ooo`0000000000000001`0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool06@3oool200000080oooo00<000000?ooo`3oool00P3oool2
000000030?ooo`000000000004T0oooo00@000000?ooo`00000000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo0P0000000`3oool000000?ooo`0Y0?ooo`030000003oool0oooo02P0oooo
00H000000?ooo`3oool000000?ooo`0000050?ooo`800000103oool2000004T0oooo0P0000040?oo
o`8000000P3oool3000001`0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`02000000<0oooo0P0000020?ooo`030000003oool0oooo04H0
oooo00@000000?ooo`0000000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0
000002/0oooo00<000000?ooo`3oool0:03oool200000080oooo0P0000060?ooo`800000103oool0
0`000000oooo0?ooo`160?ooo`<00000103oool200000080oooo00<000000?ooo`000000703oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0J0?ooo`8000000P3oool00`00
0000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo0?ooo`140?ooo`040000003oool00000
000000@0oooo00@000000?ooo`3oool00000103oool2000000030?ooo`000000oooo02X0oooo00<0
00000?ooo`3oool0:@3oool010000000oooo0?ooo`3oool2000000H0oooo0P0000040?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`000000103oool200000080oooo0`00000M0?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool00P00
00040?ooo`030000003oool0oooo00800000A03oool01@000000oooo0000003oool0000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`80000000<0oooo0000003oool0:`3oool00`000000
oooo0?ooo`0Z0?ooo`040000003oool0oooo0?ooo`8000001P3oool2000000@0oooo00<000000?oo
o`3oool0@`3oool3000000@0oooo0P0000020?ooo`030000003oool0000001d0oooo00<000000?oo
o`3oool00P3oool004/0oooo0P00000L0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`80
00000P3oool200000480oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool2000000030?ooo`000000oooo02`0oooo00<000000?ooo`3oool0:`3oool0
10000000oooo0?ooo`3oool2000000H0oooo0P0000040?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`000000103oool200000080oooo0`00000L0?ooo`<00000103oool004/0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`02000000@0oooo0P0000020?ooo`030000003oool0
oooo03h0oooo0P000000103oool000000?ooo`0000030?ooo`050000003oool0oooo0?ooo`000000
103oool2000000030?ooo`000000oooo02`0oooo00<000000?ooo`3oool0:`3oool2000000<0oooo
00<000000?ooo`3oool01@3oool2000000@0oooo00<000000?ooo`3oool0?`3oool010000000oooo
0000000000030?ooo`030000003oool000000080oooo00<000000?ooo`0000007P3oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0L0?ooo`8000000P3oool00`000000oooo
0?ooo`020?ooo`8000000`3oool00`000000oooo0?ooo`0l0?ooo`060000003oool0oooo0000003o
ool00000103oool010000000oooo0?ooo`0000040?ooo`80000000<0oooo0000003oool0;@3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool0
0`000000oooo000000040?ooo`030000003oool0oooo03d0oooo00@000000?ooo`0000000000103o
ool200000080oooo0P0000000`3oool000000?ooo`0M0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool00P0000040?ooo`8000000P3oool2
000003`0oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`040000003oool0oooo000000@0
oooo0P0000000`3oool000000?ooo`0^0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool0?03oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`0000000P3oool00`000000
oooo0000000O0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01h0oooo
00@000000?ooo`3oool000001@3oool200000080oooo00<000000?ooo`3oool0>@3oool01P000000
oooo0?ooo`000000oooo000000@0oooo00@000000?ooo`3oool00000103oool2000000030?ooo`00
0000oooo02l0oooo00<000000?ooo`3oool0;@3oool2000000@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo000000040?ooo`800000>`3oool2000000030?ooo`000000oooo0080oooo00<0
00000?ooo`0000000P3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo000000040?ooo`800000
0`3oool00`000000oooo0?ooo`0g0?ooo`060000003oool0oooo0000003oool00000103oool01000
0000oooo0?ooo`0000040?ooo`80000000<0oooo0000003oool0<03oool00`000000oooo0?ooo`0^
0?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003oool0000000@0oooo0P00000i
0?ooo`80000000<0oooo0000003oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool000000200oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`02000000@0oooo0P0000030?ooo`030000003oool0oooo03D0oooo00H00000
0?ooo`00000000000?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0000003oool000000340oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`000000103oool2000003L0oooo0P0000000`3o
ool000000?ooo`030?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000803oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0O0?ooo`040000003oool0oooo
0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0380oooo0P000000
1@3oool000000?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool000000?ooo`000000<P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo000000040?ooo`800000=@3oool010000000
oooo0000000000040?ooo`050000003oool0oooo0000003oool00P0000000`3oool000000?ooo`0P
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool00P0000040?ooo`800000103oool00`000000oooo0?ooo`0`0?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`000000oooo0000000c0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`040000003oool00000000000<0oooo0P00000c0?ooo`04
0000003oool00000000000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
000Q0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool00P0000040?ooo`800000103oool00`000000oooo0?ooo`0]0?ooo`80000000<0oooo
0000000000000P3oool010000000oooo0?ooo`3oool2000000<0oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`000000=03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
0080oooo0P0000060?ooo`040000003oool0oooo000000@0oooo0P00000`0?ooo`040000003oool0
0000000000@0oooo00@000000?ooo`3oool000000P3oool2000000030?ooo`000000oooo0240oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool08@3oool01P000000oooo0?oo
o`000000oooo000000@0oooo0P0000040?ooo`800000:`3oool200000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000=@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0080oooo
0P0000060?ooo`040000003oool0oooo000000@0oooo0P00000^0?ooo`040000003oool000000000
00D0oooo00<000000?ooo`0000000`3oool00`000000oooo0000000S0?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P0000050?ooo`80
0000103oool2000002T0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000`3oool00`00
0000oooo0?ooo`020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000003H0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`020?ooo`8000001P3oool00`000000oooo
0?ooo`02000000<0oooo0`00000Z0?ooo`80000000<0oooo0000000000001@3oool00`000000oooo
000000030?ooo`040000003oool0oooo000002<0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool08P3oool01P000000oooo0?ooo`000000oooo000000D0oooo0P0000040?oo
o`8000009P3oool200000080oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`000000=P3oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0080oooo0`0000050?ooo`050000003oool0
oooo0?ooo`0000000`3oool010000000oooo00000000000W0?ooo`030000003oool0oooo00800000
1@3oool00`000000oooo000000030?ooo`80000000<0oooo0000003oool08`3oool00`000000oooo
0?ooo`020?ooo`00B`3oool2000002@0oooo00H000000?ooo`3oool000000?ooo`0000060?ooo`03
0000003oool0oooo00<0oooo0P00000S0?ooo`030000003oool0oooo008000000P3oool2000000@0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`000000=`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000001@3oool200000080oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000000000S
0?ooo`80000000@0oooo00000000000000001@3oool00`000000oooo000000030?ooo`8000000P3o
ool00`000000oooo0?ooo`0P0?ooo`<00000103oool004/0oooo00<000000?ooo`3oool08`3oool2
00000080oooo0P0000070?ooo`030000003oool0oooo00<0oooo0`00000O0?ooo`80000000<0oooo
0000000000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`8000000`3o
ool01P000000oooo0?ooo`000000oooo000003P0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool00P0000030?ooo`80
000000<0oooo0000000000007`3oool200000080oooo00<000000?ooo`0000001P3oool2000000@0
oooo0P0000000`3oool000000?ooo`0T0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo02@0oooo00@000000?ooo`3oool0oooo0P0000070?ooo`030000003oool0oooo00<0
oooo1000000K0?ooo`80000000<0oooo0000000000000`3oool2000000@0oooo0P0000030?ooo`03
0000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`00000i0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000060?ooo`050000003oool0
oooo0?ooo`000000103oool2000000030?ooo`000000000001/0oooo0P0000020?ooo`80000000<0
oooo0000003oool01@3oool00`000000oooo000000030?ooo`8000000P3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02D0oooo00@00000
0?ooo`3oool0oooo0P0000070?ooo`030000003oool0oooo00@0oooo1@00000F0?ooo`D00000103o
ool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`020?ooo`060000003o
ool0oooo0000003oool00000>P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000001P3oool010000000oooo0?ooo`3oool2000000@0oooo0P000000103o
ool0000000000000000F0?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool0103oool0
0`000000oooo000000030?ooo`050000003oool000000?ooo`0000009P3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`0U0?ooo`8000000P3oool00`000000oooo00000007
0?ooo`8000001`3oool400000180oooo100000050?ooo`8000000`3oool2000000D0oooo00@00000
0?ooo`3oool0oooo0P0000020?ooo`030000003oool0000003/0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool00P3o
ool2000000@0oooo0P0000020?ooo`@000003@3oool5000000<0oooo00<000000?ooo`3oool00P00
00050?ooo`80000000<0oooo0000003oool00P3oool01@000000oooo0000003oool0000002L0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool09P3oool200000080oooo0P00
00080?ooo`800000203oool5000000P0oooo1`0000080?ooo`040000003oool0oooo0?ooo`800000
1P3oool01@000000oooo0?ooo`3oool0000000<0oooo0`00000l0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool00P3oool4000000D0oooo00<000000?ooo`3oool00`3oool2000000@0
oooo100000020?ooo`d000001P3oool2000000030?ooo`000000000000H0oooo00@000000?ooo`3o
ool00000103oool200000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`0V0?ooo`8000000`3oool2000000P0oooo0P00000:0?ooo`d0
00002P3oool200000080oooo0P0000070?ooo`050000003oool0oooo0?ooo`0000000`3oool20000
03h0oooo00<000000?ooo`3oool0?03oool2000000@0oooo00<000000?ooo`0000001@3oool20000
00D0oooo0P0000060?ooo`H000002@3oool6000000030?ooo`000000000000L0oooo00@000000?oo
o`3oool00000103oool200000080oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`0W0?ooo`8000000`3oool2000000T0oooo0`00000L0?oo
o`8000000P3oool2000000L0oooo0P0000030?ooo`030000003oool0oooo00<00000?`3oool00`00
0000oooo0?ooo`0m0?ooo`800000103oool00`000000oooo000000060?ooo`8000001@3oool20000
00X0oooo2@0000050?ooo`8000001`3oool200000080oooo00<000000?ooo`3oool00P3oool20000
00<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`020?ooo`00;`3oool0102oM000
00000000001d_ol30?ooo`030?oOW0180000M;oo00<0oooo00D0oooO09a8000000000000001d_`0:
0?ooo`030000003oool0oooo02P0oooo0P0000030?ooo`8000002P3oool4000001H0oooo0`000000
103oool000000000000000080?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool00000
0?ooo`0000100?ooo`030000003oool0oooo03h0oooo0P0000040?ooo`040000003oool000000000
00H0oooo0P0000050?ooo`<000004@3oool4000000P0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`8000000`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0080oooo000^0?oo
o`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`030?ooo`070=nLB000
M;l0oooo0?oo_`1d000004RL0=ooo`080?ooo`030000003oool0oooo02T0oooo0P0000030?ooo`80
00002`3oool5000000l0oooo10000000103oool000000000000000090?ooo`8000000`3oool20000
0080oooo00<000000?ooo`000000@@3oool00`000000oooo0?ooo`0o0?ooo`<000000`3oool00`00
0000oooo0?ooo`02000000H0oooo0P0000060?ooo`H000001@3oool6000000/0oooo00D000000?oo
o`3oool0oooo000000040?ooo`8000000`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo0080oooo000]0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol01P3oool00`3o
oml0W4P007Boo`020?ooo`030?oOW0180000B9cO00P0oooo00<000000?ooo`3oool0:P3oool20000
00<0oooo0P00000<0?ooo`80000000<0oooo0000000000003@0000020?ooo`<000002P3oool20000
00@0oooo00@000000?ooo`3oool0oooo0`0000120?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`0000000`3oool200000080oooo0P0000060?ooo`8000002P3oool5000000l0oooo0P000003
0?ooo`040000003oool0oooo0?ooo`<000000`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0080oooo000]0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo1@3o
ool00`3ookl0M00007Boo`030?ooo`030;md000007@0_ooo00L0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo000000040?ooo`030000003oool0oooo00/0oooo0`0000080?ooo`L00000303o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`800000A03oool00`000000oooo
0?ooo`110?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000070?ooo`80
00006P3oool2000000<0oooo0P0000030?ooo`030000003oool000000080oooo0P00000/0?ooo`03
0000003oool0oooo0080oooo000]0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol0
1@3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00L0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo000000040?ooo`030000003oool0oooo00d0oooo2000000A0?ooo`800000
103oool2000000<0oooo0P0000150?ooo`030000003oool0oooo0480oooo00@000000?ooo`000000
00000`3oool010000000oooo0?ooo`3oool2000000L0oooo0P00000E0?ooo`<00000103oool00`00
0000oooo0?ooo`020?ooo`030000003oool000000080oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`020?ooo`00;P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00H0
oooo00<0_g@00000M02oool00P3oool00`3OW4P0001809cOo`070?ooo`<00000;03oool00`000000
oooo000000040?ooo`800000903oool2000000@0oooo0P0000030?ooo`<00000AP3oool00`000000
oooo0?ooo`130?ooo`040000003oool0oooo000000<0oooo0P0000030?ooo`8000001`3oool40000
00`0oooo1@0000050?ooo`800000103oool00`000000oooo000000020?ooo`030000003oool0oooo
02/0oooo0`0000040?ooo`00;P3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00H0
oooo00P0okmd00000018W=l0oooo0?oog`2LB00004RL0=ooo`L0oooo00<000000?ooo`3oool0;@3o
ool2000000D0oooo0`00000P0?ooo`800000103oool2000000@0oooo00<000000?ooo`000000A`3o
ool00`000000oooo0?ooo`140?ooo`80000000<0oooo0000000000000`3oool2000000<0oooo0P00
00090?ooo``00000203oool2000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo0080oooo000^0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@0
0018W03Oool01@3oool00`3ooml0W4P000000002000000030000M02oool0oooo00L0oooo00<00000
0?ooo`3oool0;P3oool2000000H0oooo1000000J0?ooo`<00000103oool2000000@0oooo0P000000
0`3oool000000?ooo`170?ooo`030000003oool0oooo04H0oooo00@000000?ooo`3oool00000103o
ool2000000<0oooo0`00000G0?ooo`<000001@3oool2000000050?ooo`000000oooo0?ooo`000000
<@3oool00`000000oooo0?ooo`020?ooo`00;P3oool0103ooml0W4P00018W03Oool20?ooo`030=nL
B000B9`0gooo00H0oooo00<0oono07@00000M;l02`3oool00`000000oooo0?ooo`0_0?ooo`800000
1`3oool5000001@0oooo0`0000050?ooo`800000103oool2000000030?ooo`000000000004T0oooo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`02000000@0oooo0P0000040?ooo`@00000
3`3oool4000000L0oooo00D000000?ooo`00000000000?ooo`0200000380oooo00<000000?ooo`3o
ool00P3oool002l0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`070?ooo`030?oO
W0180000B9cO00X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`060?ooo`D00000
403oool2000000H0oooo0P0000050?ooo`040000003oool0oooo000004/0oooo00<000000?ooo`3o
ool0B03oool200000080oooo0P0000040?ooo`8000001P3oool4000000D0oooo1P0000090?ooo`@0
00000P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0080oooo000`0?ooo`060=nL
B00007@0_ooo0?oog`2LB000B9cO2@3oool0103ooml0W4P00000M02oool80?ooo`030000003oool0
oooo0380oooo0P0000090?oooa8000001@3oool3000000D0oooo0P0000000`3oool000000000001<
0?ooo`030000003oool0oooo04X0oooo0P0000020?ooo`030000003oool0oooo00<0oooo0`000007
0?ooo`D000003@3oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`020?ooo`00<@3oool0103OW4P0000000000000M;l<0?ooo`040?oo_`1d0000
000004RLg`H0oooo00<000000?ooo`3oool0<`3oool3000000/0oooo1000000;0?ooo`@000001P3o
ool2000000030?ooo`000000000004h0oooo00<000000?ooo`3oool0C03oool2000000030?ooo`00
0000000000H0oooo1000000B0?ooo`<0000000<0oooo0000000000000`3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo03D0oooo0`00000=
0?ooo`/00000203oool500000500oooo00<000000?ooo`3oool0CP3oool2000000040?ooo`000000
0000000000L0oooo1@0000080?ooo`D000000P3oool2000000<0oooo0P00000g0?ooo`030000003o
ool0oooo0080oooo001;0?ooo`030000003oool0oooo03L0oooo0`00000L0?ooo`@00000D`3oool0
0`000000oooo0?ooo`1@0?ooo`<0000000<0oooo0000000000000P0000080?ooo`P000001@3oool2
000000<0oooo0P00000i0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
03X0oooo1000000E0?ooo`@00000EP3oool00`000000oooo0?ooo`1C0?ooo`8000000`3oool40000
00X0oooo1`0000030?ooo`800000>`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`0l0?ooo`D000003`3oool3000005X0oooo00<000000?ooo`3oool0E@3oool2000000D0
oooo2P0000080?ooo`800000?@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`0n0?oooa<00000G03oool00`000000oooo0?ooo`1G0?ooo`D000003P3oool4000003l0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0A03oool800000640oooo00<0
00000?ooo`3oool0G03oool>000004<0oooo00<000000?ooo`3oool00P3oool004/0oooo0P00002^
0?ooo`030000003oool0oooo0:/0oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`2]0?oo
o`030000003oool0oooo0:d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool0[@3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo0:d0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1=0?ooo`030000003oool0
oooo04h0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080
oooo001;0?ooool00000HP0000040?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00cP3oool02@3ookl0M00000000018
W=l0oooo0?oo_`1d0000000004RLg`0D0?ooo`030?noM000000000000080000000<004RL0=ooo`3o
ool04P3oool01@2oM0000000000000000000B9cO0:H0oooo003>0?ooo`0:0?oo_`1d04P0W=oo0;md
0000M;l0oono07@0B02Lgol0_g@0001d_a80oooo00<0okmd00000018W=l00`3oool00`3ogi`0B018
09cOo`0C0?ooo`030?oog`2LB000B9cO0:L0oooo003A0?ooo`030?oo_`1d0000M;oo0080oooo00<0
oono07@0001d_ol04@3oool00`3o_g@0001d0;ooo`040?ooo`030=nLB000M;l0oooo01<0oooo00<0
gia80018W03Oool0YP3oool00=80oooo00<0gia80018W03Oool00P3oool00`3OW4P004RL0=ooo`0A
0?ooo`080;md000007@0_ooo0?ooo`3ooml0W4P000000018W=lD0?ooo`030?oOW01807@0_ooo0:H0
oooo002k0?ooo`030;md00000000000000D0000000<004RL0=ooo`3oool00`3oool0303ogi`0B000
00000000B9`0gooo0;md0000000007Bo0?ooo`3o_g@0001809cOo`80oooo00<0okmd0000B02Lgol0
0`3oool0202oM00000000000B02Lgol0oooo0=nLB000B9`0gooo0P3oool00`2oM0000000001d_`02
0?ooo`060?oo_`1d000000000000000007@0_ooo1@3oool00`3o_g@00000000000070000000907Bo
o`3oool0omnL04P000000000001d0;oo_`1d0000M;oo0080oooo00/0omnL04P00000000004RL0=oo
o`2oM0000000001d_`3oool0omnL04P000020000000907Boo`3OW4P000000018W03Oool0okmd0000
000004P0W=oo0080oooo00@0_g@00000000004P0W=oo0P3oool01@3o_g@000000000000004P0W=oo
00<0oooo00<0gia80018W03Oool00P3oool00`2oM0000000001d_`1f0?ooo`00_03oool0103ookl0
M0000018W03Oool30?ooo`030;md0000000007Bo00<0oooo00`0omnL04P0B02Lgol0omnL04Qd_`2o
M00007Bo0?noW02Lgol0oono07@00018W=l20?ooo`030?oo_`1d0000B9cO00<0oooo00P0gia80018
W03Ooml0W7BL0=ooo`3o_g@0001d0;ooo`80oooo00P0gia80018W03O_g@0M;oo0?ooo`3o_g@0001d
0;ooo`T0oooo00@0oooO09a80000B9`0gooo0`3oool02`3ooml0W4P00018W03Oool0_g@00018W03O
ool0oono07@0M01dM000B9cO0080oooo02@0omnL04P0B02Lgol0omnL04Qd_`2oM00007Bo0?noW02L
gol0_g@00018W03Oool0oooo0;md001dM7@0001d0;oOW02L_ol0okmd0000B02Lgml0W7BL0=ooo`3o
ool0gia80018W03Ooml0W7BL0=ooo`3ogi`0B01809cOo`3oool0omnL04P00000M;l20?ooo`030?no
M00007@0_ooo0080oooo00@0gia80018W03O_g@0M;ooM@3oool00;d0oooo00<0gia80000B02Lgol0
103oool03@3ookl0M0000018W03Oool0oooo0?oog`2LB000B9cO0?ooo`3o_g@0M7Ad0018W03Oool0
0P3oool00`2oM00004RL0=ooo`020?ooo`030;md0000B9`0gooo0080oooo00<0okmd0000B02Lgol0
0P3oool00`3ookl0M00004RLg`020?ooo`030?oOW01804P0W=oo00<0oooo00<0_g@007Boo`3oool0
2@3oool00`3o_g@0001809cOo`050?ooo`040=nLM02Lgol0_g@0001d_`80oooo0100oono07@00000
B9`0gooo0?ooo`3ooml0W4P004RLg`3oool0okmd07AdM000B9`0gooo0?ooo`2oM00007Bo0`3oool0
1`2oM000000007Boo`3oool0oono07@0001d_ol00`3oool00`3o_g@0001809cOo`020?ooo`030=nL
B000B9`0gooo0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0
B02Lgol0MP3oool00;d0oooo00<0omnL04P0001d_ol01@3oool00`3ogi`0B000001d_`020?ooo`07
0;md0000B9`0gooo0?ooo`2oM000001809cOo`020?ooo`030=nLB00007@0_ooo0080oooo00<0gia8
0000M02oool00P3oool00`3ookl0M00004RLg`020?ooo`080?oog`2LB000001d0;ooo`3oool0oooO
09a80018W=l20?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool01@3oool00`3ookl0
M00004RLg`070?ooo`030=nLB000B9`0gooo0080oooo00<0okmd0000M02oool00P3oool02`2oM000
04RL0=ooo`3oool0_g@00000B02Lgol0oooo0?noM00007@0_ooo0080oooo00<0oono07@00018W=l0
0P3oool00`2oM00007Bo0?ooo`020?ooo`030?oo_`1d0000B9cO0080oooo00<0okmd0000M02oool0
0`3oool02`3OW4P0001d0;ooo`3ooml0W4P00000M02oool0oooo0?oog`2LB000B9cO07H0oooo002m
0?ooo`030?oo_`1d000007Bo00H0oooo00/0_g@00000B02Lgol0oooo0?noM00007@0_ooo0?ooo`3o
okl0M00007Boo`020?ooo`030?oOW0180000M;oo0080oooo00<0omnL04P0001d_ol00`3oool00`2o
M00004RL0=ooo`020?ooo`030=nLB000B4P0B7Bo0080oooo00/0_g@0001d_`3oool0oooo0;md0000
B9`0gooo0?ooo`3ogi`0B00004RLg`060?ooo`030?oog`2LB00007Bo0080oooo00<0oono09bLg`3o
ool00P3oool00`3ogi`0B00007Boo`020?ooo`030?oo_`1d0000M;oo0080oooo00/0okmd0000M02o
ool0oooo0?oo_`1d0000M;oo0?ooo`3ookl0M00007Boo`030?ooo`070;md0000B9`0gooo0?ooo`3O
W4P004RL0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3ookl0M00007Boo`030?ooo`070?oOW018
04P0W=oo0?ooo`3OW4P004Q804Qd_`020?ooo`030;md0000M;l0oooo07D0oooo002n0?ooo`030;md
0000B9`0gooo00D0oooo00L0okmd00000018W=l0omoO0=oo_`1d0000M;oo0080oooo00L0_g@0001d
_`3oool0oooo0?oog`2LB000B9cO0080oooo00<0oooO09a80018W=l00`3oool00`3OW4P0001809cO
o`020?ooo`0;0?noM00007@0_kmd04RLg`3oool0okmd0000M02oool0oooo0;md0000M;l00`3oool0
0`3OW4P0001d0;ooo`060?ooo`060=nLB00007@0_ooo0?ooo`3ogi`0B7Bo103oool0302oM000001d
0;ooo`3oool0oooO09a80018W=l0oooo0?oOg`3Ookl0M00007Boo`80oooo00L0_g@0001d_`3oool0
oooo0?noM00007@0_ooo0080oooo00L0gia80000M02oool0oooo0?oOW01804P0W=oo00<0oooo00<0
gia80000B02Lgol00P3oool00`3OW4P0001d0;ooo`020?ooo`0<0?oo_`1d0000M;oo0?ooo`3o_g@0
001d0;noM018W=l0oooo0?noM00007@0_oooM@3oool00;h0oooo00<0okmd0000B02Lgol01@3oool0
1`3ogi`0B000001d_`3ogi`0B7Bo0;md0000M;l00P3oool00`3o_g@004RL0=ooo`020?ooo`030;md
0000B9`0gooo0080oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`020?ooo`0<0?oo
g`2LB000M;oo0=nLB000M;l0omnL04P0B02Lgol0oooo0?oOW0180000B9cO0P3oool00`3OW4P0001d
0;ooo`060?ooo`030?noM000000000000080000000<0001d0;ooo`3oool00P3oool0303ooml0W4P0
0018W03Oool0oono09a8B000B9`0gooo0?oOW018M;l0_g@0001d_`80oooo00<0okmd0018W03Oool0
0P3oool02`3OW4P0001d0;ooo`3oool0_g@00000B02Lgol0oooo0?oog`2LB000B9cO00<0oooo00<0
omnL04P00018W=l00`3oool0402oM000001d0;ooo`3oool0okmd0000M02oool0oooo0?oog`2LB000
M;oo0=nLB000M;l0omnL04P0B02Lgome0?ooo`00_P3oool00`3ogi`0B00007Boo`050?ooo`070?oO
W018000007Bo0?ooo`3o_g@00000001d_`020?ooo`050?oOW01804P0W=oo0?oo_`1d00000`000000
0`1d_kl0M000000000020000000?07Boo`3o_g@0000000000000B9`0gooo0?oo_`1d0000000004RL
g`3oool0okmd0000000004P0W=oo0080oooo00<0oono07@000000000100000000`18W=l0oooo0?oo
o`030?ooo`030?oo_`1d0000M;oo0080oooo00<0_gA809cOo`3oool0103oool02P3OW4P000000000
M02o_g@0001d0;ooo`3oool0okmd00000000M;l20?ooo`030?oOW01804P0W=oo00<0oooo00P0omnL
04P000000000B9bL07@00018W=l0oono07@000<0000000H0M;oo0?noM000000000000018W03Oool3
0?ooo`0?0?noM000000000000000001d_ol0oooo0?oo_`1d0000000004RLg`3oool0okmd00000000
04P0W=oo07D0oooo002n0?ooo`030?oog`2LB00007Bo00D0oooo00<0okmd00000018W=l02`3oool0
0`3o_g@0001809cOo`020?ooo`030?noM00004P0W=oo01l0oooo00H0_g@0001d_`3oool0oooo0?oO
W01dW=lO0?ooo`030?noM00007@0_ooo08d0oooo002o0?ooo`030;md0000B9`0gooo00<0oooo00@0
oooO09a8000007@0_ooo2`3oool00`3ooml0W4P0001d_`020?ooo`030?oog`2LB00007Bo01l0oooo
00<0gia80000M02oool0103oool00`3OW9`0_ooo0?ooo`0L0?ooo`030=nLM02Lgol0oooo08`0oooo
002o0?ooo`030=nLB00004P0W=oo0080oooo00@0oono07@000000000M;oo3@3oool00`3o_g@0001d
0;ooo`020?ooo`030?noM00007@0_ooo0080oooo00@0oono07@00000B9`0gooo603oool00`3o_g@0
001809cOo`030?ooo`030?oo_`1d04P0W=oo0280oooo00@0oono07@00000B9`0goooQP3oool00;h0
oooo00<0_g@0000000000000100000000`00B9`0gooo0?ooo`0>0?ooo`0:0=nLB000B9`0gooO09a8
0018W=l0gia80018W03Ooml0W4P004RLgaX0oooo00<0_g@00000000000001P0000000`1d_ol0oooo
0?ooo`2Z0?ooo`00e`3oool02@3OW4P000000000B02Lgol0oooo0=nLB0000000001809cOo`3@0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-1.56269, -0.878608, 0.00932809, \
0.00579557}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.499432 0.378176 0.499949 0.40113 [
[.12126 -0.0125 -9.34375 -15.6875 ]
[.12126 -0.0125 9.34375 0 ]
[.31034 -0.0125 -13.8438 -15.6875 ]
[.31034 -0.0125 13.8438 0 ]
[.49943 -0.0125 -5 -15.6875 ]
[.49943 -0.0125 5 0 ]
[.68852 -0.0125 -9.5 -15.6875 ]
[.68852 -0.0125 9.5 0 ]
[.87761 -0.0125 -5 -15.6875 ]
[.87761 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.9688 -31.375 ]
[.5 -0.0125 21.9688 -15.6875 ]
[-0.0125 .09882 -18.6875 -7.84375 ]
[-0.0125 .09882 0 7.84375 ]
[-0.0125 .29938 -27.6875 -7.84375 ]
[-0.0125 .29938 0 7.84375 ]
[-0.0125 .49995 -10 -7.84375 ]
[-0.0125 .49995 0 7.84375 ]
[-0.0125 .70051 -19 -7.84375 ]
[-0.0125 .70051 0 7.84375 ]
[-0.0125 .90108 -10 -7.84375 ]
[-0.0125 .90108 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -43.375 -20.4688 ]
[-0.01875 .5 -27.6875 20.4688 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -43.9375 0 ]
[.5 1.0125 43.9375 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12126 0 m
.12126 .00625 L
s
gsave
.12126 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.31034 0 m
.31034 .00625 L
s
gsave
.31034 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.49943 0 m
.49943 .00625 L
s
gsave
.49943 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.68852 0 m
.68852 .00625 L
s
gsave
.68852 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.87761 0 m
.87761 .00625 L
s
gsave
.87761 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.15907 0 m
.15907 .00375 L
s
.19689 0 m
.19689 .00375 L
s
.23471 0 m
.23471 .00375 L
s
.27253 0 m
.27253 .00375 L
s
.34816 0 m
.34816 .00375 L
s
.38598 0 m
.38598 .00375 L
s
.4238 0 m
.4238 .00375 L
s
.46161 0 m
.46161 .00375 L
s
.53725 0 m
.53725 .00375 L
s
.57507 0 m
.57507 .00375 L
s
.61288 0 m
.61288 .00375 L
s
.6507 0 m
.6507 .00375 L
s
.72634 0 m
.72634 .00375 L
s
.76415 0 m
.76415 .00375 L
s
.80197 0 m
.80197 .00375 L
s
.83979 0 m
.83979 .00375 L
s
.08344 0 m
.08344 .00375 L
s
.04562 0 m
.04562 .00375 L
s
.0078 0 m
.0078 .00375 L
s
.91543 0 m
.91543 .00375 L
s
.95324 0 m
.95324 .00375 L
s
.99106 0 m
.99106 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.9688 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
102.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .09882 m
.00625 .09882 L
s
gsave
-0.0125 .09882 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .29938 m
.00625 .29938 L
s
gsave
-0.0125 .29938 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .49995 m
.00625 .49995 L
s
gsave
-0.0125 .49995 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .70051 m
.00625 .70051 L
s
gsave
-0.0125 .70051 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .90108 m
.00625 .90108 L
s
gsave
-0.0125 .90108 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .13893 m
.00375 .13893 L
s
0 .17905 m
.00375 .17905 L
s
0 .21916 m
.00375 .21916 L
s
0 .25927 m
.00375 .25927 L
s
0 .3395 m
.00375 .3395 L
s
0 .37961 m
.00375 .37961 L
s
0 .41972 m
.00375 .41972 L
s
0 .45984 m
.00375 .45984 L
s
0 .54006 m
.00375 .54006 L
s
0 .58018 m
.00375 .58018 L
s
0 .62029 m
.00375 .62029 L
s
0 .6604 m
.00375 .6604 L
s
0 .74063 m
.00375 .74063 L
s
0 .78074 m
.00375 .78074 L
s
0 .82085 m
.00375 .82085 L
s
0 .86097 m
.00375 .86097 L
s
0 .05871 m
.00375 .05871 L
s
0 .01859 m
.00375 .01859 L
s
0 .94119 m
.00375 .94119 L
s
0 .98131 m
.00375 .98131 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -117 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
81.4688 11.8438 translate
90 rotate
-81.4688 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(velocity) show
99.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.12126 .99375 m
.12126 1 L
s
.31034 .99375 m
.31034 1 L
s
.49943 .99375 m
.49943 1 L
s
.68852 .99375 m
.68852 1 L
s
.87761 .99375 m
.87761 1 L
s
.125 Mabswid
.15907 .99625 m
.15907 1 L
s
.19689 .99625 m
.19689 1 L
s
.23471 .99625 m
.23471 1 L
s
.27253 .99625 m
.27253 1 L
s
.34816 .99625 m
.34816 1 L
s
.38598 .99625 m
.38598 1 L
s
.4238 .99625 m
.4238 1 L
s
.46161 .99625 m
.46161 1 L
s
.53725 .99625 m
.53725 1 L
s
.57507 .99625 m
.57507 1 L
s
.61288 .99625 m
.61288 1 L
s
.6507 .99625 m
.6507 1 L
s
.72634 .99625 m
.72634 1 L
s
.76415 .99625 m
.76415 1 L
s
.80197 .99625 m
.80197 1 L
s
.83979 .99625 m
.83979 1 L
s
.08344 .99625 m
.08344 1 L
s
.04562 .99625 m
.04562 1 L
s
.0078 .99625 m
.0078 1 L
s
.91543 .99625 m
.91543 1 L
s
.95324 .99625 m
.95324 1 L
s
.99106 .99625 m
.99106 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .09882 m
1 .09882 L
s
.99375 .29938 m
1 .29938 L
s
.99375 .49995 m
1 .49995 L
s
.99375 .70051 m
1 .70051 L
s
.99375 .90108 m
1 .90108 L
s
.125 Mabswid
.99625 .13893 m
1 .13893 L
s
.99625 .17905 m
1 .17905 L
s
.99625 .21916 m
1 .21916 L
s
.99625 .25927 m
1 .25927 L
s
.99625 .3395 m
1 .3395 L
s
.99625 .37961 m
1 .37961 L
s
.99625 .41972 m
1 .41972 L
s
.99625 .45984 m
1 .45984 L
s
.99625 .54006 m
1 .54006 L
s
.99625 .58018 m
1 .58018 L
s
.99625 .62029 m
1 .62029 L
s
.99625 .6604 m
1 .6604 L
s
.99625 .74063 m
1 .74063 L
s
.99625 .78074 m
1 .78074 L
s
.99625 .82085 m
1 .82085 L
s
.99625 .86097 m
1 .86097 L
s
.99625 .05871 m
1 .05871 L
s
.99625 .01859 m
1 .01859 L
s
.99625 .94119 m
1 .94119 L
s
.99625 .98131 m
1 .98131 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .49995 m
1 .49995 L
s
.49943 0 m
.49943 1 L
s
gsave
.5 1.0125 -104.938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Duffing) show
102.938 15.813 moveto
(Equation) show
146.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.72401 .2301 m
.59204 .19303 L
.45443 .15612 L
.41432 .14474 L
.36935 .13339 L
.32572 .12539 L
.28483 .12235 L
.23723 .12703 L
.21361 .13387 L
.18825 .14564 L
.1467 .17843 L
.11232 .2249 L
.0831 .29008 L
.07032 .33389 L
.06125 .37834 L
.05224 .46648 L
.05415 .56443 L
.06762 .65746 L
.09014 .7364 L
.11748 .79698 L
.15336 .85005 L
.19873 .89369 L
.22657 .91227 L
.2536 .92614 L
.283 .93768 L
.31041 .94591 L
.34261 .95326 L
.37354 .95861 L
.42904 .96549 L
.48102 .97012 L
.53858 .97396 L
.60014 .97618 L
.65906 .97479 L
.68854 .97191 L
.72051 .96637 L
.77584 .94828 L
.82467 .91889 L
.85251 .8937 L
.87703 .86428 L
.91701 .79382 L
.93532 .74579 L
.94916 .69663 L
.96066 .63821 L
.96833 .57268 L
.97063 .46778 L
.96004 .35859 L
.93849 .26653 L
.91031 .19635 L
.86918 .13379 L
.84293 .10775 L
Mistroke
.81718 .08925 L
.76754 .06773 L
.71282 .05888 L
.6813 .05862 L
.64812 .06105 L
.62 .06474 L
.58949 .06997 L
.46287 .09835 L
.4085 .11218 L
.35248 .1284 L
.30201 .14696 L
.25859 .16874 L
.23783 .18216 L
.21681 .19854 L
.18219 .23419 L
.165 .25772 L
.15041 .28224 L
.13612 .31217 L
.12347 .34644 L
.10809 .40992 L
.10124 .47142 L
.10183 .53757 L
.10574 .57351 L
.11158 .60518 L
.12833 .6598 L
.13922 .68356 L
.1528 .70647 L
.1803 .73865 L
.20902 .75952 L
.22741 .76826 L
.24532 .7742 L
.27968 .78023 L
.29911 .78133 L
.31713 .7813 L
.33688 .78042 L
.35778 .77888 L
.38966 .77606 L
.42371 .77345 L
.45562 .77226 L
.48487 .77269 L
.51743 .77507 L
.53605 .77728 L
.55354 .77985 L
.58916 .78609 L
.62876 .79353 L
.66536 .79936 L
.69965 .80238 L
.73256 .80157 L
.76702 .79492 L
.79686 .78234 L
Mistroke
.82328 .76372 L
.84978 .73473 L
.87425 .69308 L
.89432 .63765 L
.90251 .60181 L
.90785 .56626 L
.91158 .49735 L
.90662 .42236 L
.89284 .35165 L
.87234 .29131 L
.84841 .24416 L
.81754 .20151 L
.77883 .16452 L
.74009 .13869 L
.69228 .11627 L
.64471 .1002 L
.55603 .07817 L
.45471 .05789 L
.39997 .04904 L
.36837 .04526 L
.33853 .04305 L
.30709 .04268 L
.27833 .04463 L
.247 .05001 L
.21458 .06016 L
.16271 .08997 L
.11871 .13498 L
.07755 .20575 L
.05879 .255 L
.04489 .30512 L
.02702 .41984 L
.02381 .48144 L
.02493 .54976 L
.03867 .666 L
.06412 .76197 L
.08465 .81151 L
.10718 .85184 L
.15585 .9097 L
.18582 .93253 L
.21485 .9483 L
.24771 .96045 L
.28346 .96846 L
.31545 .97218 L
.34498 .97345 L
.37742 .97306 L
.41156 .9712 L
.4686 .966 L
.53027 .95864 L
.58444 .95084 L
.64126 .94027 L
Mistroke
.69343 .92638 L
.73918 .90835 L
.78516 .88122 L
.82488 .84627 L
.86337 .79564 L
.89709 .72627 L
.91035 .68632 L
.92179 .63938 L
.93381 .5479 L
.93411 .45702 L
.92447 .37707 L
.90566 .30513 L
.88086 .24935 L
.85388 .2104 L
.82095 .18009 L
.78201 .15981 L
.73902 .15046 L
.70184 .14996 L
.66129 .15491 L
.63889 .15937 L
.61487 .16507 L
.5723 .17653 L
.49646 .19693 L
.41328 .21369 L
.33973 .22437 L
.30995 .22946 L
.27856 .2369 L
.24535 .24893 L
.21588 .26543 L
.18718 .28993 L
.17408 .3053 L
.16096 .32455 L
.14138 .36483 L
.1281 .40869 L
.11991 .46072 L
.1183 .48821 L
.11855 .51886 L
.12417 .57255 L
.13527 .62022 L
.14453 .647 L
.15499 .67069 L
.17856 .71002 L
.19371 .72895 L
.20886 .74458 L
.22643 .7596 L
.24651 .77368 L
.28268 .79322 L
.31875 .80786 L
.39029 .83006 L
.472 .85267 L
Mistroke
.56809 .87938 L
.61251 .89035 L
.66134 .8994 L
.7082 .90306 L
.75091 .89984 L
.79816 .88554 L
.82383 .87118 L
.84654 .85325 L
.8847 .8076 L
.91833 .74043 L
.93957 .66971 L
.95365 .58239 L
.95768 .49384 L
.95316 .41205 L
.93912 .32554 L
.91379 .24143 L
.87782 .16936 L
.83744 .11814 L
.78683 .07802 L
.75968 .0636 L
.72891 .05145 L
.67283 .03742 L
.61922 .03027 L
.58647 .0277 L
.55527 .02603 L
.49654 .02423 L
.46365 .02381 L
.43317 .02386 L
.39974 .02459 L
.36428 .02652 L
.31027 .0331 L
.25326 .04793 L
.20173 .07279 L
.15764 .10788 L
.11413 .16298 L
.09271 .20228 L
.0753 .244 L
.04886 .34157 L
.03974 .4021 L
.03525 .45927 L
.03639 .56036 L
.04984 .66161 L
.07044 .73774 L
.10137 .8066 L
.14209 .8612 L
.16749 .88326 L
.19188 .89846 L
.24128 .9161 L
.2895 .92135 L
.33422 .9191 L
Mistroke
.38134 .91187 L
.42489 .90242 L
.46344 .89282 L
.63416 .84576 L
.67151 .83323 L
.7099 .81744 L
.74962 .79572 L
.78382 .76976 L
.80082 .75309 L
.818 .73261 L
.84517 .68897 L
.86575 .63899 L
.8789 .5875 L
.88561 .53689 L
.8869 .4888 L
.88281 .43754 L
.87226 .38649 L
.85614 .34225 L
.83403 .30404 L
.81177 .27855 L
.78475 .25787 L
.76844 .24913 L
.75019 .24181 L
.73254 .23667 L
.716 .2332 L
.6842 .22913 L
.65016 .22702 L
.61586 .22568 L
.59689 .2248 L
.57881 .22367 L
.55741 .22182 L
.53771 .21955 L
.49855 .21327 L
.46423 .20602 L
.42666 .19686 L
.39322 .18844 L
.35609 .17992 L
.33279 .17561 L
.31115 .17272 L
.29032 .17128 L
.26831 .17155 L
.23041 .1777 L
.19032 .19512 L
.15303 .22666 L
.12303 .2698 L
.10962 .29774 L
.09698 .33261 L
.08646 .37312 L
.07935 .41428 L
.07375 .49516 L
Mistroke
.07749 .57131 L
.09227 .65579 L
.11602 .72775 L
.14402 .78212 L
.17983 .82911 L
.21809 .86341 L
.25567 .88714 L
.30259 .9079 L
.35571 .92411 L
.40753 .93573 L
.45636 .94473 L
.5096 .95335 L
.56778 .96142 L
.62352 .96686 L
.67476 .96819 L
.73455 .96207 L
.76777 .95325 L
.7978 .9406 L
.84998 .90378 L
.8743 .87749 L
.89905 .84193 L
.92044 .80095 L
.93979 .751 L
.96485 .64665 L
.97285 .5823 L
.97619 .52026 L
.97519 .45166 L
.96877 .38001 L
.95889 .32112 L
.94395 .26219 L
.92617 .21238 L
.90696 .17208 L
.86447 .11142 L
.81297 .0686 L
.76041 .04545 L
.70091 .03474 L
.64407 .03406 L
.59158 .03835 L
.54022 .04514 L
.4944 .05239 L
.39463 .07119 L
.34056 .08469 L
.29259 .10104 L
.24255 .12589 L
.21873 .14202 L
.19391 .16304 L
.15594 .20725 L
.12197 .2675 L
.09776 .33577 L
.08337 .40529 L
Mistroke
.07691 .4788 L
.07902 .55634 L
.08789 .61848 L
.10455 .67939 L
.12928 .73306 L
.16214 .77599 L
.19736 .80265 L
.23185 .81664 L
.26554 .82236 L
.29714 .82262 L
.33163 .81889 L
.36782 .81205 L
.4327 .79669 L
.46578 .78918 L
.50044 .7826 L
.51975 .77971 L
.53722 .77761 L
.57114 .77494 L
.58928 .77417 L
.60899 .77371 L
.62759 .77349 L
.64481 .77331 L
.67828 .77236 L
.70838 .76979 L
.74256 .76314 L
.77362 .75156 L
.7893 .74282 L
.80577 .73084 L
.82198 .71542 L
.83597 .69823 L
.85779 .66049 L
.87546 .61084 L
.88242 .57928 L
.88727 .54281 L
.88914 .50693 L
.88846 .47322 L
.88585 .44287 L
.88081 .41 L
.87318 .37686 L
.86393 .34737 L
.84231 .29874 L
.82759 .27445 L
.81249 .2541 L
.78174 .22227 L
.74529 .19538 L
.70657 .17475 L
.66802 .15913 L
.59166 .13533 L
.50158 .11113 L
.44991 .09796 L
Mistroke
.40015 .08656 L
.3714 .0811 L
.34488 .07716 L
.31519 .07447 L
.28324 .07421 L
.25661 .07669 L
.22792 .08286 L
.17743 .10562 L
.13256 .14463 L
.09643 .19723 L
.0645 .27379 L
.042 .37275 L
.03324 .46933 L
.03485 .56197 L
.04743 .66004 L
.07248 .75369 L
.09144 .79968 L
.11154 .83681 L
.13609 .87157 L
.16447 .90167 L
.21637 .93808 L
.24755 .95199 L
.27748 .96137 L
.33444 .97167 L
.38725 .9755 L
.44848 .97619 L
.50656 .9749 L
.5383 .97363 L
.56808 .97203 L
.62336 .96741 L
.68206 .95831 L
.71447 .95017 L
.74366 .94004 L
.79083 .91578 L
.83873 .8761 L
.88259 .81742 L
.91582 .7461 L
.93072 .69892 L
.94317 .64319 L
.95109 .5874 L
.95496 .53426 L
.95301 .43364 L
.93812 .33408 L
.9257 .28818 L
.90915 .24411 L
.87215 .18017 L
.8474 .15265 L
.81945 .13092 L
.79444 .11773 L
.7663 .1083 L
Mistroke
.74142 .10377 L
.71491 .10207 L
.66745 .10514 L
.61718 .11427 L
.56359 .12777 L
.39322 .17512 L
.32141 .19659 L
.28345 .21139 L
.25065 .2283 L
.22215 .24802 L
.19385 .27485 L
.17037 .30589 L
.15198 .33965 L
.13568 .38324 L
.12416 .43523 L
.1195 .48693 L
.12069 .53449 L
.12798 .58491 L
.13476 .61158 L
.14267 .63477 L
.1629 .67601 L
.1764 .69555 L
.18984 .71107 L
.20421 .7245 L
.22033 .73659 L
.25109 .7534 L
.26899 .76047 L
.28616 .76591 L
.32638 .77529 L
.40157 .78813 L
.47464 .80293 L
.55462 .82423 L
.59125 .83451 L
.63213 .84492 L
.65611 .84994 L
.67843 .85351 L
.72277 .8562 L
.74537 .85455 L
.76994 .84972 L
.79511 .8407 L
.81786 .82806 L
.85697 .79254 L
.88896 .74314 L
.91195 .68582 L
.9293 .61147 L
.93773 .52089 L
.93755 .47334 L
.93384 .42097 L
.91848 .33248 L
.89457 .25841 L
Mistroke
.8658 .20123 L
.8281 .15114 L
.78335 .11216 L
.73812 .08637 L
.69336 .06927 L
.65136 .0581 L
.60174 .04859 L
.55406 .04163 L
.50131 .03528 L
.44477 .02971 L
.39603 .02641 L
.34219 .02572 L
.28455 .031 L
.25265 .03806 L
.22405 .0479 L
.17084 .07853 L
.12475 .12457 L
.08276 .19406 L
.06329 .24247 L
.04852 .2923 L
.03015 .39476 L
.02432 .51109 L
.03133 .6147 L
.04784 .70388 L
.07582 .78794 L
.11515 .8581 L
.16508 .90966 L
.19576 .92893 L
.22515 .94128 L
.28067 .95282 L
.30904 .95436 L
.34033 .9536 L
.39396 .94807 L
.45071 .93862 L
.54984 .91814 L
.64369 .89441 L
.69413 .87699 L
.73864 .85581 L
.7786 .829 L
.81178 .79782 L
.84545 .75264 L
.87161 .70088 L
.88988 .64673 L
.90271 .58413 L
.90804 .52836 L
.9078 .46721 L
.9006 .40461 L
.88549 .3446 L
.86513 .29715 L
.84235 .26272 L
Mistroke
.81326 .23437 L
.78347 .21679 L
.74911 .20609 L
.71115 .2024 L
.67342 .20427 L
.6546 .20653 L
.63419 .2096 L
.59818 .21569 L
.5661 .22089 L
.53407 .22499 L
.50417 .22732 L
.47278 .22793 L
.43869 .22653 L
.40864 .2239 L
.37645 .22033 L
.34647 .21713 L
.31772 .21507 L
.28181 .21534 L
.24927 .22004 L
.21523 .23192 L
.19678 .24253 L
.18044 .25524 L
.15307 .2862 L
.13195 .32318 L
.11313 .37587 L
.10192 .43357 L
.09882 .46637 L
.09779 .50343 L
.09943 .5426 L
.10345 .57889 L
.11654 .64133 L
.1384 .70173 L
.15388 .73182 L
.173 .76102 L
.19163 .7837 L
.21299 .80472 L
.23341 .82111 L
.25708 .8367 L
.30123 .85888 L
.34517 .87524 L
.38761 .88796 L
.48868 .91315 L
.54169 .925 L
.593 .9351 L
.62187 .93972 L
.65345 .94342 L
.70896 .94485 L
.75734 .93817 L
.80899 .9185 L
.85932 .88001 L
Mistroke
.90085 .82445 L
.93279 .7546 L
.95451 .67707 L
.96921 .57534 L
.97188 .47285 L
.96236 .36524 L
.93783 .25781 L
.92056 .21094 L
.89871 .16665 L
.85219 .10382 L
.80232 .06409 L
.74571 .03924 L
.69552 .02847 L
.63968 .02416 L
.60551 .02405 L
.57325 .02509 L
.51315 .02882 L
.47973 .03157 L
.44907 .03449 L
.41354 .03845 L
.38056 .04298 L
.32685 .05323 L
.29893 .06073 L
.26949 .07099 L
.23957 .08471 L
.21215 .10118 L
.16422 .14284 L
.1239 .19816 L
.10445 .23616 L
.089 .27527 L
.06748 .35615 L
.05553 .4501 L
.0548 .53642 L
.06258 .61383 L
.07985 .69041 L
.10717 .75856 L
.1442 .81268 L
.16781 .83476 L
.19091 .85008 L
.23536 .86689 L
.25839 .87067 L
.28398 .8719 L
.32793 .8684 L
.37449 .85936 L
.45514 .83743 L
.60046 .79973 L
.63619 .79184 L
.67329 .78302 L
.70657 .77333 L
.73678 .76166 L
Mistroke
.76319 .74785 L
.78996 .72856 L
.81219 .70647 L
.83048 .68192 L
.84781 .64998 L
.86273 .60953 L
.87307 .56248 L
.87746 .51566 L
.87619 .4635 L
.8727 .43492 L
.86789 .40985 L
.85418 .36424 L
.83653 .32644 L
.82465 .30742 L
.81084 .28941 L
.78334 .26235 L
.7667 .24994 L
.75048 .23991 L
.71152 .22166 L
.67572 .20947 L
.64056 .19971 L
.57173 .18238 L
.49203 .16076 L
.40131 .13518 L
.36301 .1261 L
.32085 .11905 L
.274 .11697 L
.23029 .1232 L
.19092 .13862 L
.15197 .16727 L
.12182 .20323 L
.09345 .25522 L
.06771 .33354 L
.05355 .41692 L
.04989 .46642 L
.04947 .52123 L
.05817 .61964 L
.077 .70528 L
.10694 .78335 L
.13935 .83756 L
.18071 .8835 L
.23204 .91946 L
.28291 .94117 L
.34109 .95588 L
.37109 .96084 L
.40456 .96505 L
.46094 .97016 L
.49291 .97235 L
.52236 .97403 L
.57684 .9761 L
Mistroke
.63437 .97583 L
.68599 .9716 L
.74031 .96017 L
.78985 .93977 L
.83241 .91052 L
.87787 .86038 L
.91922 .78498 L
.94826 .69471 L
.96464 .5988 L
.96993 .49038 L
.96138 .37574 L
.94055 .27828 L
.91209 .20385 L
.86977 .13793 L
.84256 .11081 L
.81577 .09179 L
.7641 .07032 L
.73435 .06459 L
.70715 .06247 L
.67823 .0628 L
.6478 .06537 L
.59398 .07384 L
.53746 .08593 L
.47744 .10039 L
.37489 .12767 L
.33221 .14148 L
.28718 .15998 L
.2478 .18188 L
.20926 .21195 L
.19072 .23103 L
.17226 .25437 L
.15774 .27691 L
.14353 .30402 L
.12264 .35964 L
.11428 .39269 L
.10854 .42465 L
.10337 .48346 L
.10514 .54561 L
.11396 .60273 L
.13068 .65702 L
.15229 .699 L
.1762 .72897 L
.20028 .74902 L
.22869 .7641 L
.25975 .77333 L
.28949 .77732 L
.32478 .77808 L
.34472 .77736 L
.36313 .77631 L
.3819 .7751 L
Mistroke
.39948 .77404 L
.43215 .77275 L
.46213 .77287 L
.49462 .77479 L
.52973 .77902 L
.56254 .78464 L
.5998 .79214 L
.64077 .80025 L
.66102 .80362 L
.68036 .80609 L
.71687 .80784 L
.75506 .80367 L
.77624 .79765 L
.79533 .78923 L
.81399 .77757 L
.83353 .76074 L
.85245 .73842 L
.86848 .71299 L
.89132 .65928 L
.90101 .62427 L
.90765 .58994 L
.91421 .51796 L
.91225 .44735 L
.90757 .40755 L
.89987 .36675 L
.87938 .29906 L
.86455 .26533 L
.84874 .23676 L
.82957 .20901 L
.80667 .18279 L
.76463 .1477 L
.72127 .12293 L
.6766 .10481 L
.63362 .09167 L
.53166 .06839 L
.47288 .05718 L
.41772 .04808 L
.37027 .04229 L
.31984 .03981 L
.26925 .04343 L
.21493 .05798 L
.16988 .08278 L
.12543 .12479 L
.08867 .18094 L
.0611 .24602 L
.03599 .34607 L
.02443 .45014 L
.02561 .5686 L
.03172 .62675 L
.04253 .68748 L
Mistroke
.0695 .77806 L
.10895 .85551 L
.15377 .90836 L
.19924 .94066 L
.25658 .96259 L
.3123 .97116 L
.3628 .9722 L
.41723 .96904 L
.47617 .96285 L
.5374 .95476 L
.58939 .9466 L
.64391 .93573 L
.69363 .92189 L
.73727 .90439 L
.77894 .88023 L
.81564 .84972 L
.85391 .8033 L
.88384 .74937 L
.90932 .67873 L
.92653 .59368 L
.93267 .5039 L
.92844 .42294 L
.9135 .34163 L
.9023 .30544 L
.8876 .27023 L
.85768 .22184 L
.82046 .18597 L
.78207 .16578 L
.74571 .15706 L
.7228 .15536 L
.69853 .15602 L
.65543 .16185 L
.63186 .16682 L
.61017 .17211 L
.56219 .18502 L
.52192 .19578 L
.48053 .20554 L
.40897 .21779 L
.3752 .22189 L
.33929 .22607 L
.30593 .23101 L
.27595 .23763 L
.24444 .24851 L
.21302 .2658 L
.19734 .27799 L
.18356 .29142 L
.16951 .30859 L
.15592 .32983 L
.13726 .37135 L
.12915 .39796 L
Mistroke
.12339 .42423 L
.1174 .47564 L
.1179 .53227 L
.12438 .58229 L
.13545 .62665 L
.15275 .67088 L
.17668 .71196 L
.20415 .74466 L
.23282 .76927 L
.26709 .79077 L
.30619 .80876 L
.38388 .83443 L
.45929 .85547 L
.5375 .87716 L
.5805 .88849 L
.62724 .89908 L
.6691 .90574 L
.71559 .9081 L
.75775 .90348 L
.7963 .89123 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00g03oool00`3ooml0W4P0000000020000000307Bo
o`3oool0oooo0<`0oooo003N0?ooo`030?noM00007@0_ooo0<l0oooo003N0?ooo`030?oo_`1d0000
M;oo0<l0oooo003N0?ooo`030?oog`2LB000B9cO0<l0oooo003O0?ooo`030=nLB000000000000080
000000<0M;oo0?ooo`3oool00P3oool01@3o_g@000000000000004P0W=oo0080oooo00<0oono07@0
000000000P0000003@18W=l0oooo0?ooo`3oool0_g@00000000004P0W=oo0?ooo`3o_g@000000000
B02Lgol00P3oool0102oM00000000000B02Lgol20?ooo`050?noM000000000000000B02Lgol00`3o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000000007Bo09H0oooo003O0?ooo`070?noM00004P0
W=oo0?ooo`3ooml0W4P0001d_`020?ooo`0?0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`3oool0
oooO09a8001d_ol0oooo0?oOW0180000M;oo0080oooo01L0gia80018W03Ooml0W7BL0=ooo`3o_g@0
001809cOg`2LM9`0gooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0
B000001d_`020?ooo`030?noM00007@0_ooo0080oooo00@0gia80018W03O_g@0M;ooU@3oool00=l0
oooo00<0oono07@0001d_ol00P3oool01`3ooml0W4P004RLg`3oool0gia80018W03Oool00P3oool0
2P3ogi`0B00004RLg`3oool0_gAd0;ooo`3oool0oono07@0001d_ol20?ooo`030?noM00004P0W=oo
0080oooo00<0oono07@0001d_ol00`3oool00`3o_g@0001809cOo`020?ooo`030=nLB000B9`0gooo
0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol0UP3o
ool00=l0oooo00<0oooO09a80018W=l00`3oool01P3ogi`0B01809cOo`3o_g@0001d0;ooo`<0oooo
00<0gia80000M02oool00`3oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo
00<0_g@0001d_`3oool00P3oool00`3ookl0M00004RLg`020?ooo`030?noM00007@0_ooo00<0oooo
00/0gia80000M02oool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`2F0?ooo`00h03oool0
0`3OW4P0001d0;ooo`020?ooo`060?oog`2LB000B9cO0?oo_`1d0000M;oo0`3oool00`3ogi`0B018
09cOo`020?ooo`030?noM00004P0W=oo00@0oooo00<0_g@00018W03Oool00P3oool00`3OW4P004RL
0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3ookl0M00007Boo`030?ooo`070?oOW01804P0W=oo
0?ooo`3OW4P004Q804Qd_`020?ooo`030;md0000M;l0oooo09D0oooo003P0?ooo`040?noM0000000
04RL0=ooo`80oooo00H0gia8001d_`3oool0gia80000M02oool20?ooo`0:0?oo_`1d0000M;oo0?oo
o`3ogi`0B01809cOo`3oool0giad09cOo`80oooo00<0gia80000B02Lgol00P3oool00`3ogi`0B018
09cOo`030?ooo`030=nLB00004P0W=oo0080oooo00<0gia80000M02oool00P3oool0303ookl0M000
07Boo`3oool0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;oooiD0oooo003P0?ooo`080?oo_`1d
0000M9bL04P0M02oool0oooO09a80000M;l20?ooo`0>0;md000007@0_ooo0?ooo`3o_g@0001d0;oo
o`3oool0omnL04P0B02Lgol0oooO09a8001d_ol20?ooo`030?oOW0180000B9cO0080oooo00<0oooO
09a80018W=l00`3oool00`3ogi`0B00004RLg`030?ooo`0@0;md000007@0_ooo0?ooo`3o_g@0001d
0;ooo`3oool0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOoiD0oooo003O0?ooo`090?oOW018
0000000004RLg`3ookl0M0000000000007@0_ooo00<0oooo00D0okmd000000000000000007Boo`03
0?ooo`070;md00000000000000000018W=l0oooo0?noM002000000040018W03Oool0oono07@000<0
000000H0M;oo0?noM000000000000018W03Oool30?ooo`0?0?noM000000000000000001d_ol0oooo
0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo09D0oooo003o0?ooo`40oooo00<0okmd
0000M02oool0[@3oool00?l0oooo0P3oool00`3OW7@0W=oo0?ooo`2/0?ooo`00n`3oool0103ookl0
M0000018W03Oool70?ooo`040?oo_`1d000004RL0=ooojH0oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo001h0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0=@3o
ool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00H0omnL04P000000000
00000018W03Ooola0?ooo`040;md00000000000007BoocP0oooo00@0_g@0000000000000M;oo0`3o
ool00`3ogi`0B00007Boo`020?ooo`060?oOW0180000000000000000B9`0gooo=@3oool00`3ookl0
M000000000020000000304RLg`3oool0oooo02d0oooo001j0?ooo`030?noM0000000M;oo03L0oooo
00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo0080oooo00H0okmd0000
001d_ol0oooo0?oOW018M;l`0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO=P3oool01P3OW4P0
07Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00P3oool01P3o_g@0000007Boo`3o
ool0omnL04Qd_cL0oooo00<0okmd0000001d_ol0<03oool007X0oooo00<0oooO09a80000M;l0=P3o
ool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00/0oooo00<0okmd04RLg`3oool0;@3o
ool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo03@0oooo00<0oooO09a80018W=l00P3o
ool00`3o_g@0001809cOo`0;0?ooo`030?noM018W=l0oooo03D0oooo00<0oooO09a80000M;l0<03o
ool007/0oooo00<0gia80018W03Oool0=@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB000
04RL0=ooo`X0oooo00<0oono07@0M02oool0;@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2L
B00004RL0=oooc<0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool:0?ooo`03
0?oo_`1d07@0_ooo03H0oooo00<0gia80018W03Oool0;`3oool006/0oooo00<0oooO09a800000000
1`0000000`18W=l0oooo0?ooo`030?ooo`030?oOW01804P0W=oo02P0oooo00<0oooO09a800000000
1`0000001P18W=l0oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol02P3oool00`3o
oml0W4P007Boo`0]0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol0<`3oool00`3o
oml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00X0oooo00<0oooO09a8001d_ol0=P3oool00`3o
gi`0B01809cOo`0_0?ooo`00N`3oool00`3ookl0M00007Boo`0f0?ooo`030;md0000B9`0gooo0080
oooo00<0omnL04P00018W=l02P3oool00`3ookl0M00004RLg`0^0?ooo`030;md0000B9`0gooo0080
oooo00<0omnL04P00018W=l0=03oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00X0
oooo00<0oono07@00018W=l0=P3oool00`3ookl0M00007Boo`0_0?ooo`00O03oool00`2oM00007Bo
0?ooo`0e0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l02P3oool00`3o_g@00000
07Boo`0^0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0=03oool00`3OW4P00018
09cOo`020?ooo`030?oog`2LB00007Bo00X0oooo00<0okmd0000001d_ol0=`3oool00`2oM00007Bo
0?ooo`0^0?ooo`00O03oool00`3OW4P004RL0=ooo`0e0?ooo`030?oOW0180000B9cO00<0oooo00<0
_g@00018W03Oool01P3oool01P3ogml0gooo0?noM0000000001d0;ooobh0oooo00<0omnL04P00018
W=l00`3oool00`2oM00004RL0=ooo`0c0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03O
ool01P3oool01P3ogml0gooo0?noM0000000001d0;ooocL0oooo00<0gia80018W03Oool0;P3oool0
07`0oooo00<0omnL04P0B02Lgol0=@3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0
gooo00H0oooo00D0oono07@000000000001809cOo`0_0?ooo`040?oog`2LB00004RL0=ooo`80oooo
00<0gia80018W03Oool0<`3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00H0
oooo00D0oono07@000000000001809cOo`0h0?ooo`030?oOW01804P0W=oo02h0oooo001l0?ooo`03
0?oo_`1d0000M;oo03H0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`070?ooo`03
0=nLW02oool0oooo0340oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`0d0?ooo`03
0?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01`3oool00`3OW9`0_ooo0?ooo`0i0?ooo`03
0?oo_`1d0000M;oo02h0oooo001m0?ooo`030;md0000M;l0oooo03H0oooo00H0gia80000M02oool0
oooO09a80018W=l80?ooo`030?oOW01dW=l0oooo0380oooo00H0gia80000M02oool0oooO09a80018
W=lf0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO203oool00`3ogi`0M9cO0?ooo`0j0?ooo`03
0;md0000M;l0oooo02d0oooo001k0?ooo`050?oo_`1d000000000000M02oool0=`3oool0103OW4P0
000000000000M;l:0?ooo`050;md00000000000000000018W=l0<03oool0103OW4P0000000000000
M;lh0?ooo`040=nLB00000000000001d_`X0oooo00D0_g@0000000000000000004RLg`0e0?ooo`05
0?oo_`1d000000000000M02oool0;@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool004/0ooooo`00001R000000@0oooo001;0?ooo`040000003oool0oooo0000
00`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000000@0oooo001;0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3o
ool0[@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`2]0?ooo`030000
003oool0oooo0:d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0[@3o
ool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0080oooo001;0?ooo`800000[P3oool0
0`000000oooo0?ooo`2[0?ooo`<00000103oool004/0oooo00<000000?ooo`3oool0[@3oool00`00
0000oooo0?ooo`2]0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0900
oooo9P00000G0?oooaH00000NP3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`1a0?ooob000000703oool00`000000oooo0?ooo`060?oooaL000005P3oool:00000700oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0I`3oool:000000<0oooo1P00
000G0?ooo`d000003P3oool@000000X0oooo2`00000L0?ooo`L00000J@3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`1O0?ooo`P000001`3oool6000002X0oooo3P000000
0`3oool000000?ooo`0R0?ooo`/00000603oool4000006D0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool0F@3oool6000000X0oooo1@00000W0?ooo``000001`3oool90000
02H0oooo7`0000020?ooo`D00000H03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`1E0?ooo`@00000303oool4000002<0oooo2@00000H0?ooo`040000003oool0oooo0?oo
o`H00000503oool<000000l0oooo1P00000:0?ooo`D000000P3oool4000005`0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool0D`3oool2000000`0oooo5@00000@0?ooo`H0
00008@3oool00`000000oooo0?ooo`070?ooo`H00000203oool600000240oooo1000000;0?ooo`X0
0000F03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1@0?ooo`<00000
203oool[000002L0oooo00<000000?ooo`3oool03@3oool8000002/0oooo1000000=0?ooo`H00000
EP3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1>0?ooo`8000001`3o
ool>000001@0oooo4`00000Q0?ooo`030000003oool0oooo00P0oooo1`0000060?ooo`P000009`3o
ool4000000h0oooo1000001C0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo04`0oooo0P0000050?ooo`X000006`3oool4000000P0oooo4000000I0?ooo`030000003oool0
oooo00P000005@3oool7000002@0oooo1000000>0?ooo`800000D@3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`1:0?ooo`8000000`3oool8000001`0oooo1@00000F0?oo
o``000003`3oool7000002@0oooo1P00000R0?ooo`<000003@3oool3000004h0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool0B03oool2000000030?ooo`000000000000L0
00006P3oool500000240oooo300000040?ooo`D00000103oool00`000000oooo0?ooo`0Z0?ooo`H0
00007`3oool3000000`0oooo0`00001<0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo04H0oooo0P0000000`3oool0000000000004000000030?ooo`000000000001L0oooo
1@00000/0?ooo``000001`3oool00`000000oooo0?ooo`0`0?ooo`@000007P3oool2000000d0oooo
0`0000190?ooo`030000003oool0oooo0080oooo001;0?ooo`800000AP3oool00`000000oooo0000
0003000000<0oooo0P00000E0?ooo`@00000<@3oool5000000030?ooo`000000000000<0000000<0
oooo0000000000000`0000020?ooo`030000003oool0oooo02l0oooo7@0000080?ooo`<00000303o
ool3000004D0oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`130?ooo`D00000103oool2
000001D0oooo0P00000`0?ooo`D000002`3oool5000000030?ooo`000000000000@00000:@3oool5
000000P0oooo500000000`3oool0000000000004000000D0oooo0P00000=0?ooo`800000A@3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`110?ooo`D00000103oool20000
01@0oooo0`00000]0?ooo`D000005@3oool500000080oooo1@00000O0?ooo`D00000103oool90000
00D0oooo1000000;0?ooo`d0000000<0oooo0000000000003@3oool2000004<0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool0@03oool010000000oooo0000000000040?oo
o`800000503oool2000002/0oooo1@00000M0?ooo`030000003oool0000000@000000P3oool50000
01@0oooo1P0000030?ooo`H000004P3oool3000000l0oooo2`00000<0?ooo`<00000@@3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0n0?ooo`D000000`3oool2000001<0
oooo0`00000Y0?ooo`@000008P3oool00`000000oooo0?ooo`040?ooo`D000000P3oool4000000/0
oooo1@0000030?ooo`H000006`3oool2000001<0oooo100000000`3oool000000000000<0?ooo`80
0000@03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0l0?ooo`D00000
0`3oool2000001<0oooo0P0000020?oooa@000004P3oool4000002H0oooo00<000000?ooo`3oool0
2@3oool5000000030?ooo`000000000000<000000P3oool400000080oooo1P00000S0?ooo`<00000
503oool2000000040?ooo`0000000000000000X0oooo0P00000o0?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo03X0oooo1P0000030?ooo`030000003oool0oooo00l0oooo
2000000D0?ooo`X00000103oool4000002X0oooo00<000000?ooo`3oool03P3oool>000002`0oooo
0P00000D0?ooo`H000002@3oool3000003d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool0>@3oool5000000<0oooo0P00000=0?ooo`L00000903oool8000002X0oooo00<0
00000?ooo`3oool03@3oool:000000030?ooo`000000000000<00000;@3oool3000001@0oooo1@00
00090?ooo`800000?03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0h
0?ooo`80000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`090?ooo`@000000`3oool2
00000280oooo100000080?ooo`D000009@3oool00`000000oooo0?ooo`090?ooo`T00000103oool4
000000<0oooo1000000/0?ooo`800000503oool6000000L0oooo0P00000k0?ooo`030000003oool0
oooo0080oooo000k0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0203oool00`00
0000oooo0?ooo`0g0?ooo`@00000103oool00`000000oooo0?ooo`080?ooo`8000001@3oool20000
0240oooo0`00000A0?ooo`D00000803oool00`000000oooo0?ooo`040?ooo`T000003@3oool40000
00<0oooo1@00000Y0?ooo`8000005@3oool5000000H0oooo0P00000j0?ooo`030000003oool0oooo
0080oooo000m0?ooo`030?noM0000000M;oo00/0oooo00<000000?ooo`3oool0=P3oool3000000@0
oooo0P0000090?ooo`8000001@3oool2000001l0oooo1000000I0?ooo`@00000703oool00`000000
oooo0?ooo`08000001H0oooo100000040?ooo`@000009`3oool2000001@0oooo00<000000?ooo`00
00000`0000050?ooo`800000>@3oool00`000000oooo0?ooo`020?ooo`00?@3oool00`3ooml0W4P0
001d_`0;0?ooo`030000003oool0oooo03D0oooo0P0000050?ooo`030000003oool0oooo00L0oooo
0P0000060?ooo`030000003oool0oooo01`0oooo0`00000Q0?ooo`@000005`3oool8000001h0oooo
100000040?ooo`@000009@3oool2000001<0oooo00<000000?ooo`3oool00`0000060?ooo`800000
=`3oool00`000000oooo0?ooo`020?ooo`00?P3oool00`3OW4P004RL0=ooo`0:0?ooo`030000003o
ool0oooo03@0oooo0P0000050?ooo`030000003oool0oooo00D0oooo0`0000060?ooo`800000703o
ool3000002P0oooo1000000>0?ooo`T000009P3oool4000000@0oooo0`00000T0?ooo`8000004P3o
ool010000000oooo0?ooo`3oool3000000D0oooo0P00000f0?ooo`030000003oool0oooo0080oooo
000^0?ooo`030?oog`2LB000000000L0000000<0B9cO0?ooo`3oool00`3oool00`3ogi`0B01809cO
o`0:0?ooo`030000003oool0oooo03<0oooo0P0000040?ooo`8000001P3oool2000000P0oooo00<0
00000?ooo`3oool0603oool4000002l0oooo100000060?ooo`@0000000<0oooo0000000000000P00
00000`3oool000000?ooo`0[0?ooo`@000000`3oool3000002<0oooo00<000000?ooo`3oool0403o
ool200000080oooo0`0000050?ooo`800000=@3oool00`000000oooo0?ooo`020?ooo`00?P3oool0
0`3ookl0M00007Boo`0:0?ooo`<00000<P3oool2000000@0oooo00<000000?ooo`3oool0103oool2
000000P0oooo0P00000I0?ooo`800000=`3oool6000000030?ooo`0000000000008000001@3oool0
0`000000oooo0?ooo`0^0?ooo`@000000P3oool300000240oooo0P00000B0?ooo`040000003oool0
oooo0?ooo`8000001P3oool00`000000oooo0?ooo`0_0?ooo`@00000103oool003l0oooo00<0_g@0
001d_`3oool02@3oool00`000000oooo0?ooo`0a0?ooo`800000103oool00`000000oooo0?ooo`03
0?ooo`8000002@3oool00`000000oooo0?ooo`0G0?ooo`800000=@3oool500000080oooo10000009
0?ooo`030000003oool0oooo0380oooo0P0000030?ooo`<000001`3ooolC000000H0oooo0P00000A
0?ooo`040000003oool0oooo0?ooo`<000001@3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo0080oooo000o0?ooo`030=nLB000B9`0gooo00T0oooo00<000000?ooo`3oool0<03oool2
000000<0oooo0P0000040?ooo`8000002P3oool00`000000oooo0?ooo`0F0?ooo`800000<`3oool4
000000@0oooo0`0000040?ooo`@000001@3oool00`000000oooo0?ooo`0d0?ooo`d000004`3oool4
000000@0oooo0P00000@0?ooo`040000003oool0oooo0?ooo`<000001@3oool200000340oooo00<0
00000?ooo`3oool00P3oool003l0oooo00<0omnL04P0B02Lgol02@3oool00`000000oooo0?ooo`0_
0?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo0P00000G
0?ooo`800000<03oool5000000@0oooo1000000;0?ooo`@0000000<0oooo0000003oool0<@3oool6
000000040?ooo`0000000000000000<0oooo0P00000I0?ooo`@000000P3oool2000000l0oooo00<0
00000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`000000<03oool00`000000oooo0?oo
o`020?ooo`00?`3oool00`3ookl0M00007Boo`090?ooo`030000003oool0oooo02h0oooo0P000003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0E
0?ooo`800000;P3oool4000000D0oooo1000000C0?ooo`<00000:`3oool6000000X0oooo0P000003
0?ooo`<000006P3oool3000000030?ooo`000000oooo00h0oooo0P0000030?ooo`800000103oool0
0`000000oooo0000000_0?ooo`030000003oool0oooo0080oooo00100?ooo`030;md0000M;l0oooo
00P0oooo00<000000?ooo`3oool0;@3oool2000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo0P00000]0?ooo`<000001P3oool30000
01P0oooo00<000000?ooo`0000000`00000R0?ooo`D000004P3oool3000000<0oooo0`00000J0?oo
o`@000003`3oool010000000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`000000;P3oool0
0`000000oooo0?ooo`020?ooo`00?P3oool01@3ookl0M0000000000007@0_ooo00P0oooo00<00000
0?ooo`3oool0;03oool2000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo01<0oooo3P00000O0?ooo`@000001@3oool4000001/0oooo00<00000
0?ooo`3oool00`3oool3000001/0oooo1000000J0?ooo`<000000`3oool2000001/0oooo0`00000>
0?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo0000000^0?ooo`030000003o
ool0oooo0080oooo001;0?ooo`030000003oool0oooo02/0oooo0P0000040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`P00000303oool<
00000100oooo0`0000060?ooo`<000007`3oool00`000000oooo0?ooo`060?ooo`@000004`3oool4
00000240oooo0P0000030?ooo`<000006@3oool010000000oooo00000000000=0?ooo`040000003o
ool0oooo0?ooo`8000000`3oool00`000000oooo0000000]0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo02X0oooo0P0000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01`3oool2000000`0oooo1@0000020?ooo`8000001`3oool;000000X0oooo2000
00050?ooo`<000001@3oool400000280oooo00<000000?ooo`3oool02P3oool3000000`0oooo1000
000W0?ooo`800000103oool2000001P0oooo0P0000000`3oool000000000000<0?ooo`040000003o
ool0oooo0?ooo`<000000P3oool00`000000oooo0000000/0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo02T0oooo0P0000040?ooo`040000003oool0oooo0?ooo`800000
2@3oool00`000000oooo0?ooo`0:0?ooo`8000001@3oool2000000030?ooo`000000000000H00000
2`3oool:000000P0oooo1P0000030?ooo`@000009P3oool00`000000oooo0?ooo`0=0?ooo`@00000
103oool4000002d0oooo0P0000040?ooo`800000603oool00`000000oooo0?ooo`02000000X0oooo
00<000000?ooo`3oool00P3oool300000080oooo00<000000?ooo`000000:`3oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0X0?ooo`800000103oool01@000000oooo0?oo
o`3oool0000000X0oooo00<000000?ooo`3oool02@3oool2000000@0oooo1P00000M0?ooo`D00000
00@0oooo00000000000000001@3oool4000002T0oooo00<000000?ooo`3oool04@3oool4000003<0
oooo0P0000040?ooo`8000005`3oool010000000oooo0?ooo`3oool2000000T0oooo00<000000?oo
o`3oool00`3oool2000000040?ooo`000000oooo000002/0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
000000X0oooo00<000000?ooo`3oool01`3oool300000080oooo1P00000U0?ooo`X00000103oool4
000002D0oooo00<000000?ooo`3oool03P3oool4000000<0oooo0`00000b0?ooo`800000103oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`80000000@0oooo0000003oool00000:P3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000002P3oool00`000000oooo0?ooo`060?ooo`80000000<0oooo0000000000000P00
00030?ooo`030000003oool0oooo0280oooo0`0000040?ooo`L000001`3oool400000240oooo00<0
00000?ooo`3oool02`3oool3000000X0oooo1000000`0?ooo`8000000`3oool2000001H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo0P00
0000103oool000000?ooo`00000Y0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000090?ooo`800000
1`3oool2000000030?ooo`000000000000H0oooo00<000000?ooo`3oool08@3oool2000000@0oooo
0`0000070?ooo`@000001`3oool4000001d0oooo00<000000?ooo`3oool01`3oool400000140oooo
0`00000_0?ooo`8000000`3oool2000001D0oooo00<000000?ooo`3oool00P3oool2000000P0oooo
00<000000?ooo`3oool00`3oool3000000030?ooo`000000oooo02P0oooo00<000000?ooo`3oool0
0P3oool004/0oooo0P00000W0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`050?ooo`80000000<0oooo0000000000001P3oool200000240oooo
0`0000030?ooo`<000003P3oool4000000L0oooo0`00000J0?ooo`030000003oool0oooo00@0oooo
0`00000H0?ooo`@00000;@3oool2000000<0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool01@000000oooo
0000003oool0000002H0oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`040?ooo`800000
00<0oooo0000000000001`3oool00`000000oooo0?ooo`0N0?ooo`<000000`3oool3000001D0oooo
100000060?ooo`@000005P3oool00`000000oooo0?ooo`04000001l0oooo0`00000/0?ooo`800000
0P3oool2000001@0oooo0P0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool2000000040?ooo`000000oooo000002L0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool0903oool2000000@0oooo00<000000?ooo`0000002@3oool00`000000oooo
0?ooo`040?ooo`040000003oool00000000000P0oooo00<000000?ooo`3oool07@3oool2000000@0
oooo0P00000L0?ooo`@000001P3oool3000001<0oooo0`00000V0?ooo`<00000:`3oool010000000
oooo0?ooo`3oool2000001@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo0`0000020?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo000000080?ooo`80
00007@3oool3000000<0oooo0`00000R0?ooo`@000001@3oool4000000/0oooo1@00000[0?ooo`@0
0000:03oool2000000<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`80
00001P3oool00`000000oooo0?ooo`020?ooo`80000000@0oooo0000003oool000009P3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`020?ooo`80000000<0oooo0000
003oool01`3oool00`000000oooo0?ooo`0K0?ooo`8000000`3oool3000002T0oooo0`0000060?oo
o`@00000103oool3000000@0oooo00<000000?ooo`3oool0;@3oool3000000d0oooo5`0000030?oo
o`050000003oool0oooo0?ooo`000000503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool2000000040?ooo`000000oooo000002D0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool08P3oool2000000<0oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0?ooo`020?ooo`040000003oool00000000000P0oooo
00<000000?ooo`3oool06P3oool2000000<0oooo0P00000_0?ooo`@000001P3oool4000000L0oooo
00<000000?ooo`3oool0<03oool3000000030?ooo`000000000000L000005`3oool600000080oooo
0P00000C0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`060000003oool0oooo0000003oool00000903oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00002@3oool010000000oooo0?ooo`3oool2000000030?ooo`000000oooo00L0oooo0P00000K0?oo
o`8000000P3oool3000003D0oooo1P0000030?ooo`@00000103oool00`000000oooo0?ooo`0`0?oo
o`L000002@3ooolF000000<0oooo1P00000B0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`80000000@0oooo0000003oool00000903oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0Q0?ooo`8000000`3oool00`00
0000oooo000000090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo01T0oooo0P0000020?ooo`800000=`3oool3000000030?ooo`000000
0000008000001P3oool3000000030?ooo`000000oooo02d0oooo100000070?ooo`T000005P3oool4
00000080oooo00<000000?ooo`0000000P00000A0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`80000000@0oooo0000003oool000008`3o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0Q0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0H0?ooo`8000000P3oool2000003D0oooo
100000080?ooo`@000001@3oool4000002P0oooo100000060?ooo`H000000P3oool2000001h0oooo
1@000000103oool0000000000000000@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool000008P3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`040000003oool0000000000080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0G0?ooo`8000000P3oool2000003@0oooo0`00
000@0?ooo`<000000`3oool00`000000oooo0?ooo`0300000240oooo100000060?ooo`@000002P3o
ool3000001l0oooo1`00000?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`80000000D0oooo0000003oool0oooo0000000Q0?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01l0oooo0P0000030?ooo`030000003o
ool0000000T0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01H0oooo0P0000020?ooo`800000<P3oool4000001H0oooo100000050?ooo`@000006@3o
ool4000000@0oooo1P00000A0?ooo`<000007P3oool4000000030?ooo`000000000000d0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P00
0000103oool000000?ooo`00000Q0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo01l0oooo00L000000?ooo`3oool0oooo0000003oool0000000T0oooo00<000000?ooo`00
00000P3oool2000000T0oooo00<000000?ooo`3oool0503ooolA000002H0oooo0`00000M0?ooo`D0
00001@3oool300000180oooo100000020?ooo`H000006P3oool2000001d0oooo00@000000?ooo`00
000000000P3oool2000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo0?ooo`8000000P3oool00`000000oooo0000000P0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo01h0oooo0P0000030?ooo`030000003oool00000
00T0oooo0P0000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool60000
00030?ooo`000000000000`0oooo1`00000K0?ooo`@00000803oool00`000000oooo0?ooo`020?oo
o`<000001@3oool4000000X0oooo100000030?ooo`<000008P3oool2000001`0oooo00<000000?oo
o`3oool00P0000020?ooo`8000002`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo
0?ooo`000000103oool2000000040?ooo`000000oooo00000200oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool07@3oool2000000<0oooo00<000000?ooo`0000002@3oool2
00000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`@000000P3oool0
0`000000oooo0?ooo`02000001D0oooo2000000@0?ooo`<00000903oool00`000000oooo0?ooo`05
0?ooo`@000001@3oool3000000@0oooo0`0000040?ooo`<000009`3oool2000001/0oooo00<00000
0?ooo`3oool00`0000020?ooo`8000002@3oool00`000000oooo0?ooo`060?ooo`050000003oool0
oooo0?ooo`000000103oool2000000040?ooo`000000oooo000001l0oooo00<000000?ooo`3oool0
0P3oool004/0oooo0P00000N0?ooo`030000003oool0oooo0080oooo0P0000090?ooo`050000003o
ool000000?ooo`0000002P3oool00`000000oooo0?ooo`0=0?ooo`800000103oool2000000030?oo
o`000000000001l0oooo1`0000050?ooo`@000009`3oool00`000000oooo0?ooo`090?ooo`@00000
103oool4000000<0oooo1000000/0?ooo`8000006P3oool010000000oooo0?ooo`3oool300000080
oooo0P0000080?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000103oool20000
00040?ooo`000000oooo000001d0oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`0L0?oo
o`8000000`3oool00`000000oooo000000080?ooo`050000003oool000000?ooo`0000002P3oool0
0`000000oooo0?ooo`0<0?ooo`8000001@3oool010000000oooo0?ooo`00000X0?ooo`D00000:`3o
ool00`000000oooo0?ooo`0=0?ooo`@00000103oool300000380oooo0P00000I0?ooo`060000003o
ool0oooo0?ooo`000000oooo0P0000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool010000000oooo0?ooo`0000040?ooo`80000000@0oooo0000003oool000007P3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0080oooo0P0000090?ooo`80000000<0oooo0000003oool02@3oool00`000000oooo0?ooo`0;0?oo
o`8000001P3oool010000000oooo0?ooo`00000W0?ooo`@000000P3oool4000002P0oooo00<00000
0?ooo`3oool02@3oool4000000@0oooo100000030?ooo`@00000<03oool00`000000oooo0?ooo`0G
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo00D0oooo00@000000?ooo`3oool000001@3oool01@000000oooo0000003oool00000
01h0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool06`3oool2000000<0
oooo0P0000090?ooo`8000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0
oooo0P0000060?ooo`80000000<0oooo000000000000903oool4000000X0oooo1000000T0?ooo`03
0000003oool0oooo00D0oooo100000050?ooo`@000000P3oool4000000@0oooo1000000]0?ooo`80
0000603oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000001`3oool0
0`000000oooo0?ooo`060?ooo`040000003oool0oooo000000@0oooo0P000000103oool000000?oo
o`00000M0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`8000000P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo0P0000070?ooo`040000003oool0oooo000002<0oooo
0`00000B0?ooo`@00000803oool010000000oooo0?ooo`3oool4000000D0oooo1000000:0?ooo`@0
0000103oool4000002/0oooo0P00000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000070?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000001@3o
ool3000000030?ooo`000000oooo01`0oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`020?ooo`800000203oool200000080oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`800000203oool010000000oooo0?ooo`00
000P0?ooo`@000006@3oool4000001`0oooo100000050?ooo`@000004P3oool3000000D0oooo1000
000Y0?ooo`8000005P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00001`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000@0oooo0P000000103o
ool000000?ooo`00000L0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`80000000<0oooo0000
003oool02@3oool00`000000oooo0?ooo`060?ooo`800000203oool2000000030?ooo`0000000000
01h0oooo0`00000Q0?ooo`D000004`3oool5000000@0oooo1000000I0?ooo`@000001@3oool40000
02L0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`0000030?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000050?ooo`<00000
00<0oooo0000003oool06`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo0080oooo0P0000080?ooo`80000000<0oooo0000003oool02@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000
7P3oool2000002T0oooo1000000:0?ooo`D00000103oool500000240oooo100000050?ooo`@00000
903oool2000001D0oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo00D0oooo00@000000?ooo`3oool000001@3oool01@000000oooo0000003o
ool0000001/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000002`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000703o
ool3000002l0oooo100000000`3oool0000000000003000000D0oooo1@00000Y0?ooo`<000001P3o
ool3000000h0oooo3@0000080?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool00000
0`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
00001@3oool3000000030?ooo`000000oooo01X0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`040?ooo`8000002@3oool010000000
oooo00000000000J0?ooo`<00000<`3oool700000080oooo1@0000040?ooo`030000003oool0oooo
02X0oooo100000050?ooo`h000003@3oool8000000030?ooo`000000000001@0oooo00@000000?oo
o`3oool000000`3oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool01@3oool0
10000000oooo0?ooo`0000050?ooo`050000003oool000000?ooo`0000006P3oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0000000:0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0000000J0?ooo`800000<@3oool5000000@0oooo1`00
00070?ooo`030000003oool0oooo02h0oooo3000000L0?ooo`@000004`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0000000D0oooo0`0000000`3oool000000?ooo`0I0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo01L0oooo0P0000040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`0000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`0000006@3oool2000002h0oooo1@0000040?ooo`D000001`3oool4000000<0oooo00<0
00000?ooo`3oool0:@3oool7000000030?ooo`0000000000008000001@3oool3000001`0oooo0`00
000B0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo000000040?ooo`030000
003oool0oooo00D0oooo00@000000?ooo`3oool000001@3oool01@000000oooo0000003oool00000
01T0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`020?ooo`800000203oool2000000/0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0000001P0oooo0P00000Z0?ooo`H00000103oool500000100
oooo1P00000S0?ooo`H00000303oool4000000@0oooo0`00000K0?ooo`@00000403oool010000000
oooo0?ooo`0000050?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo000000050?ooo`050000003oool000000?ooo`0000006@3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01P3oool2000000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0000001D0oooo8@0000090?ooo`H000001@3oool5000001P0oooo00<000000?oo
o`3oool01`00000F0?ooo`H000005P3oool3000000@0oooo0`00000J0?ooo`040000003oool00000
000000l0oooo00@000000?ooo`3oool000001@3oool2000000@0oooo00<000000?ooo`3oool01@3o
ool010000000oooo0?ooo`0000050?ooo`040000003oool00000000001T0oooo00<000000?ooo`3o
ool00P3oool004/0oooo0P00000G0?ooo`030000003oool0oooo0080oooo0P0000080?ooo`800000
2`3oool010000000oooo0?ooo`3oool2000000X0oooo00<000000?ooo`0000003`3oool9000001l0
oooo2@0000030?ooo`P000007@3oool00`000000oooo0?ooo`070?ooo`L000002@3oool6000001l0
oooo100000030?ooo`<00000603oool2000000030?ooo`000000000000d0oooo00@000000?ooo`3o
ool000001P3oool2000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000050?oo
o`050000003oool000000?ooo`0000005P3oool3000000@0oooo001;0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`8000002`3oool01@00
0000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`0000003P3oool2000000D0oooo0P00000M
0?oooa8000008`3oool00`000000oooo0?ooo`0>0?ooo`T00000:@3oool3000000<0oooo0`00000G
0?ooo`030000003oool0oooo00800000303oool010000000oooo0?ooo`0000060?ooo`8000000`3o
ool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000@0oooo0`0000000`3oool00000
0?ooo`0G0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01D0oooo0P00
00030?ooo`800000203oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`0000003@3oool2000000D0oooo0P00000I0?ooo`T000003`3oool8000001/0oooo
00<000000?ooo`3oool0103oool;000000H0oooo5`00000G0?ooo`@000000P3oool2000001H0oooo
00@000000?ooo`3oool0oooo0P00000;0?ooo`040000003oool0oooo000000H0oooo0P0000030?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`0000001@3oool010000000oooo00000000000H
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool00P3oool2000000L0oooo0P00000;0?ooo`040000003oool0oooo000000/0oooo00<00000
0?ooo`0000002`3oool3000000D0oooo0P00000E0?ooo`H00000803ooolR000002P0oooo3000000?
0?ooo`H000005@3oool00`000000oooo0?ooo`020?ooo`8000002P3oool00`000000oooo00000006
0?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000@0oooo00D00000
0?ooo`000000oooo0000000G0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo01@0oooo0P0000030?ooo`800000203oool00`000000oooo0?ooo`090?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`0000002P3oool2000000H0oooo0P00000B0?ooo`H00000@03o
ool00`000000oooo0?ooo`0h0?ooo``000001`3oool5000001<0oooo00<000000?ooo`3oool00`3o
ool2000000P0oooo00@000000?ooo`3oool000001P3oool2000000<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo000000040?ooo`<0000000<0oooo0000003oool05P3oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0D0?ooo`8000000`3oool2000000L0oooo0P00
000;0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`000000203oool3000000L0oooo
00<000000?ooo`3oool03@3oool6000004D0oooo00<000000?ooo`3oool0A03oool8000000@0oooo
0P00000B0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
000000060?ooo`030000003oool000000080oooo00<000000?ooo`3oool01P3oool00`000000oooo
000000040?ooo`040000003oool00000000001L0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool04`3oool2000000<0oooo0P0000080?ooo`030000003oool0oooo00T0oooo
00@000000?ooo`3oool000002P3oool00`000000oooo000000070?ooo`8000002@3oool00`000000
oooo0?ooo`0:0?ooo`H00000B@3oool00`000000oooo0?ooo`1<0?ooo`@000000P3oool200000140
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0000000H0
oooo0P0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000103oool300000003
0?ooo`000000oooo01D0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
4`3oool2000000<0oooo0P0000070?ooo`8000002`3oool00`000000oooo0000000;0?ooo`800000
1P3oool2000000T0oooo0P00000:0?ooo`D00000C@3oool00`000000oooo0?ooo`1@0?ooo`H00000
403oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000
1P3oool200000080oooo00<000000?ooo`3oool01P3oool00`000000oooo000000040?ooo`040000
003oool00000000001H0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
4P3oool300000080oooo0P0000080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000
2`3oool2000000D0oooo0P00000:0?ooo`030000003oool0oooo00L0oooo1@00001@0?ooo`030000
003oool0oooo05@0oooo1000000?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo000000060?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo000000040?ooo`050000003oool000000?ooo`0000005@3oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0B0?ooo`8000000`3oool2000000L0oooo
0P00000;0?ooo`030000003oool0000000X0oooo00<000000?ooo`000000103oool00`000000oooo
0?ooo`080?ooo`8000001`3oool4000005@0oooo00<000000?ooo`3oool0EP3oool3000000l0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0000000H0oooo
00D000000?ooo`000000oooo000000080?ooo`800000103oool3000000030?ooo`000000oooo01@0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool04P3oool2000000<0oooo
0P0000070?ooo`8000002P3oool00`000000oooo0000000;0?ooo`800000103oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00D0oooo0P00001H0?ooo`030000003oool0oooo05P0oooo
0`00000>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool2000000H0oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000@0oooo
00@000000?ooo`00000000005@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`0B0?ooo`8000000P3oool2000000L0oooo0P00000:0?ooo`030000003oool0000000/0oooo
0P0000030?ooo`8000002P3oool00`000000oooo0?ooo`040?ooo`800000FP3oool00`000000oooo
0?ooo`1J0?ooo`8000003P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`0000001P3oool01@000000oooo0000003oool0000000P0oooo0P0000040?ooo`<0
000000<0oooo0000003oool04`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`0A0?ooo`8000000`3oool2000000L0oooo0P00000:0?ooo`8000002`3oool2000000<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`800000G03oool00`000000oooo
0?ooo`1L0?ooo`8000003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`0000001@3oool00`000000oooo000000020?ooo`030000003oool0oooo00D0oooo
0P0000050?ooo`80000000<0oooo0000003oool04`3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`0A0?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`8000002P3o
ool00`000000oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo
0?ooo`020?ooo`800000GP3oool00`000000oooo0?ooo`1M0?ooo`<00000303oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001P3oool01@000000oooo
0000003oool0000000L0oooo00<000000?ooo`000000103oool010000000oooo00000000000D0?oo
o`030000003oool0oooo0080oooo001;0?ooo`8000004P3oool2000000<0oooo00<000000?ooo`3o
ool01@3oool2000000X0oooo0P00000;0?ooo`8000000P3oool00`000000oooo0?ooo`090?ooo`04
0000003oool0oooo0?ooo`<00000G`3oool00`000000oooo0?ooo`1O0?ooo`<000002P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001P3oool20000
0080oooo00<000000?ooo`3oool01@3oool2000000@0oooo0`0000000`3oool000000?ooo`0@0?oo
o`<00000103oool004/0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`3oool20000
00H0oooo0P00000:0?ooo`8000002`3oool200000080oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0300000640oooo00<000000?ooo`3oool0H03oool00`000000oooo0000000:0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000060?oo
o`050000003oool000000?ooo`0000001`3oool2000000D0oooo0P0000000`3oool000000?ooo`0B
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0100oooo0P0000030?oo
o`030000003oool0oooo00D0oooo0P00000:0?ooo`030000003oool0oooo00X0oooo00D000000?oo
o`3oool0oooo0000000:0?ooo`030000003oool0oooo00800000H`3oool00`000000oooo0?ooo`1Q
0?ooo`040000003oool00000000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000H0oooo0P0000020?ooo`030000003oool0oooo00@0oooo0P00
00050?ooo`80000000<0oooo0000003oool04P3oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`0@0?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00P0oooo0P00000;0?ooo`8000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00800000I03oool00`000000oooo0?ooo`1R0?ooo`040000003oool0oooo000000T0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0000000H0oooo00D0
00000?ooo`000000oooo000000070?ooo`800000103oool4000001<0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool0403oool200000080oooo0P0000060?ooo`8000002P3o
ool00`000000oooo0?ooo`090?ooo`8000000P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00800000I@3oool00`000000oooo0?ooo`1S0?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000H0oooo
0P0000000`3oool000000?ooo`060?ooo`8000001@3oool2000000030?ooo`000000oooo0140oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0403oool01@000000oooo0?oo
o`3oool0000000L0oooo0P0000090?ooo`030000003oool0oooo00X0oooo0P0000000`3oool00000
0?ooo`090?ooo`030000003oool0000000800000IP3oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo008000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
0P0000060?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`8000001@3oool2000000030?oo
o`000000oooo0140oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0403o
ool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`090?ooo`80000000<0oooo0000003oool02@3oool01@000000oooo0000003oool0000006L0
oooo00<000000?ooo`3oool0I@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0000000H0oooo0P0000000`3o
ool000000?ooo`060?ooo`8000001@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo00l0oooo0P0000030?ooo`030000003oool0oooo00@0
oooo0P0000090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`0000002P3oool00`000000
oooo00000002000006P0oooo00<000000?ooo`3oool0IP3oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`8000001P3oool20000
00030?ooo`000000oooo00H0oooo0P0000050?ooo`<000004P3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo0?ooo`8000001P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo0P0000000`3oool000000?ooo`090?oo
o`<00000JP3oool00`000000oooo0?ooo`1W0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`8000001`3oool2000000030?ooo`00
0000oooo00D0oooo0P0000050?ooo`80000000<0oooo0000003oool0403oool00`000000oooo0?oo
o`020?ooo`00;`3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00H0
omnL04P00000000000000018W03Oool:0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3o
ool0oooo000000070?ooo`030000003oool0oooo00L0oooo0P00000;0?ooo`030000003oool00000
00X0oooo0`00001[0?ooo`030000003oool0oooo06P0oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool2000000H0oooo0P000000
0`3oool000000?ooo`060?ooo`800000103oool2000000030?ooo`000000oooo0100oooo00<00000
0?ooo`3oool00P3oool002h0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW018
0000M;oo0080oooo00H0okmd0000001d_ol0oooo0?oOW018M;l:0?ooo`030000003oool0oooo00l0
oooo00D000000?ooo`3oool0oooo000000060?ooo`8000002@3oool00`000000oooo0?ooo`090?oo
o`<000002P3oool00`000000oooo0000001/0?ooo`030000003oool0oooo06T0oooo00D000000?oo
o`3oool0oooo000000050?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo0P00
00060?ooo`80000000<0oooo0000003oool01P3oool2000000D0oooo00<000000?ooo`0000004@3o
ool00`000000oooo0?ooo`020?ooo`00;@3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0
W=oo00/0oooo00<0okmd04RLg`3oool0203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0103oool2000000P0oooo0P00000;0?ooo`8000002P3oool0
0`000000oooo0000001]0?ooo`030000003oool0oooo06X0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`800000
00<0oooo0000003oool01@3oool2000000D0oooo00<000000?ooo`0000004@3oool00`000000oooo
0?ooo`020?ooo`00;@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`X0oooo
00<0oono07@0M02oool0203oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`00
00001`3oool00`000000oooo0?ooo`070?ooo`8000002P3oool3000000T0oooo0`00001^0?ooo`03
0000003oool0oooo06/0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`050?oo
o`040000003oool0oooo0?ooo`8000001P3oool2000000030?ooo`000000oooo00H0oooo0P000004
0?ooo`80000000<0oooo0000003oool03`3oool00`000000oooo0?ooo`020?ooo`00803oool00`3o
oml0W4P0000000070000000604RLg`3oool0oooo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cO
o`0:0?ooo`030?oog`2LB000M;oo00P0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?oo
o`3oool0000000H0oooo0P0000080?ooo`8000002`3oool2000000X0oooo0P00001_0?ooo`030000
003oool0oooo06`0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`060?ooo`04
0000003oool0oooo0?ooo`8000001P3oool3000000L0oooo0P0000040?ooo`80000000<0oooo0000
003oool03`3oool00`000000oooo0?ooo`020?ooo`00;P3oool00`2oM00004RL0=ooo`020?ooo`03
0?oOW0180000B9cO00X0oooo00<0oono07@00018W=l0203oool3000000h0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`800000203oool2000000X0oooo0`0000090?ooo`800000L03oool00`00
0000oooo0?ooo`1/0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`05
0?ooo`040000003oool0oooo0?ooo`8000001P3oool2000000030?ooo`000000oooo00D0oooo0P00
00040?ooo`80000000<0oooo0000003oool0303oool4000000@0oooo000^0?ooo`030=nLB00004P0
W=oo0080oooo00<0oooO09a80000M;l02P3oool00`3o_g@0000007Boo`080?ooo`030000003oool0
oooo00d0oooo0P0000030?ooo`030000003oool0oooo00@0oooo0P0000080?ooo`030000003oool0
oooo00T0oooo0P0000090?ooo`800000L@3oool00`000000oooo0?ooo`1]0?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo008000001`3o
ool3000000L0oooo0P0000040?ooo`030000003oool000000100oooo00<000000?ooo`3oool00P3o
ool002h0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`060?ooo`060?oOg`3Oool0
okmd0000000007@0_ooo203oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`00
00001P3oool2000000P0oooo0P00000:0?ooo`8000002P3oool00`000000oooo0?ooo`1`0?ooo`03
0000003oool0oooo06h0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00D0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`80000000<0oooo0000003oool01@3oool2
000000@0oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`020?ooo`00;P3oool0
103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00H0oooo00D0oono07@0000000000018
09cOo`090?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo000000060?ooo`80
0000203oool2000000X0oooo0P0000090?ooo`030000003oool0oooo0740oooo00<000000?ooo`3o
ool0K`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`02000000H0oooo0P0000000`3oool000000?ooo`050?ooo`800000103oool20000
00030?ooo`000000oooo00h0oooo00<000000?ooo`3oool00P3oool002l0oooo00<0omnL04P0001d
_ol00P3oool00`3OW4P007Bo0?ooo`070?ooo`030=nLW02oool0oooo00X0oooo00<000000?ooo`3o
ool03@3oool01@000000oooo0?ooo`3oool0000000H0oooo0P0000080?ooo`030000003oool0oooo
00P0oooo0P0000090?ooo`800000L`3oool00`000000oooo0?ooo`1`0?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02000000L0oooo0`000006
0?ooo`800000103oool2000000030?ooo`000000oooo00h0oooo00<000000?ooo`3oool00P3oool0
0300oooo00H0gia80000M02oool0oooO09a80018W=l80?ooo`030?oOW01dW=l0oooo00X0oooo00<0
00000?ooo`3oool0303oool2000000<0oooo00<000000?ooo`3oool00`3oool3000000L0oooo0P00
000:0?ooo`8000002@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0700oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0
oooo000000070?ooo`80000000<0oooo0000003oool01@3oool2000000<0oooo0P0000000`3oool0
00000?ooo`0>0?ooo`030000003oool0oooo0080oooo000a0?ooo`040=nLB00000000000001d_`X0
oooo00D0_g@0000000000000000004RLg`070?ooo`030000003oool0oooo00`0oooo0P0000020?oo
o`8000001@3oool2000000P0oooo0P00000:0?ooo`800000203oool2000007@0oooo00<000000?oo
o`3oool0L@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P0000060?ooo`80000000<0oooo0000003oool01@3oool2000000@0oooo00@00000
0?ooo`3oool000003P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0<
0?ooo`050000003oool0oooo0?ooo`0000001P3oool2000000P0oooo00<000000?ooo`3oool0203o
ool2000000P0oooo0P00001e0?ooo`030000003oool0oooo0740oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P0000070?ooo`030000
003oool0000000H0oooo0P0000040?ooo`80000000<0oooo0000003oool03@3oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`000000
1@3oool3000000L0oooo0P00000:0?ooo`800000203oool2000007D0oooo00<000000?ooo`3oool0
LP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool010000000
oooo0000000000070?ooo`80000000<0oooo0000003oool01@3oool2000000<0oooo0P0000000`3o
ool000000?ooo`0=0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00`0
oooo00D000000?ooo`3oool0oooo000000050?ooo`<000001`3oool00`000000oooo0?ooo`080?oo
o`800000203oool2000007H0oooo00<000000?ooo`3oool0LP3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02000000H0oooo0P000000
0`3oool000000?ooo`050?ooo`8000000`3oool2000000030?ooo`000000oooo00d0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020000
00D0oooo0P0000080?ooo`030000003oool0oooo00P0oooo0P0000080?ooo`030000003oool0oooo
07D0oooo00<000000?ooo`3oool0L`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool01@3oool010000000oooo0000000000060?ooo`80000000<0oooo0000003oool01@3o
ool2000000<0oooo0P0000000`3oool000000?ooo`0=0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo00/0oooo0P0000020?ooo`030000003oool0oooo00<0oooo0`000007
0?ooo`8000002@3oool00`000000oooo000000070?ooo`800000M`3oool00`000000oooo0?ooo`1c
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001`3oool010000000oooo00000000
00070?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00000=0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00/0oooo
0P0000020?ooo`030000003oool0oooo00<0oooo0`0000070?ooo`030000003oool0oooo00P0oooo
0P0000070?ooo`800000N03oool00`000000oooo0?ooo`1d0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000L0oooo0P0000000`3o
ool000000?ooo`050?ooo`030000003oool0oooo0080oooo0P0000000`3oool000000?ooo`0<0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3o
ool0oooo000000050?ooo`<000001`3oool00`000000oooo0?ooo`080?ooo`8000001`3oool20000
07P0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00L0oooo00@000000?ooo`00000000001P3oool2000000030?ooo`000000oooo00D0oooo0P000003
0?ooo`80000000<0oooo0000003oool0303oool00`000000oooo0?ooo`020?ooo`00B`3oool20000
00`0oooo00<000000?ooo`3oool00P0000050?ooo`8000001`3oool2000000T0oooo00<000000?oo
o`0000001P3oool2000007T0oooo00<000000?ooo`3oool0M@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0103oool010000000oooo0000000000070?ooo`030000003o
ool0000000H0oooo0P0000030?ooo`80000000<0oooo0000003oool02P3oool3000000@0oooo001;
0?ooo`030000003oool0oooo00X0oooo0P0000020?ooo`800000103oool3000000L0oooo0P000009
0?ooo`8000001`3oool2000007T0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000L0oooo00<000000?ooo`0000001`3oool00`000000oooo00000006
0?ooo`800000103oool00`000000oooo0000000=0?ooo`030000003oool0oooo0080oooo001;0?oo
o`030000003oool0oooo00X0oooo0P0000020?ooo`030000003oool0oooo00<0oooo0`0000070?oo
o`030000003oool0oooo00L0oooo0`0000060?ooo`800000NP3oool00`000000oooo0?ooo`1f0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0
0000000000H0oooo0P0000000`3oool000000?ooo`050?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000303oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`0:0?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`<000001`3oool00`000000oooo0?oo
o`070?ooo`8000001`3oool2000007X0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000H0oooo00@000000?ooo`00000000001P3oool2000000030?oo
o`000000oooo00D0oooo00<000000?ooo`3oool00P3oool2000000030?ooo`000000oooo00/0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02P3oool200000080oooo00<0
00000?ooo`3oool00`3oool2000000L0oooo0P0000090?ooo`8000001`3oool00`000000oooo0?oo
o`1i0?ooo`030000003oool0oooo07L0oooo00L000000?ooo`3oool0oooo0000003oool0000000L0
oooo00<000000?ooo`0000001`3oool00`000000oooo000000060?ooo`030000003oool0oooo0080
oooo0P0000000`3oool000000?ooo`0;0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00P0000050?ooo`8000001`3oool2000000T0oooo
0P0000060?ooo`800000N`3oool00`000000oooo0?ooo`1g0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`040?ooo`040000003oool00000000000H0oooo0`0000060?oo
o`8000000`3oool2000000030?ooo`000000oooo00/0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000060?ooo`8000001`3oool20000
00P0oooo0P0000070?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0N03oool01`00
0000oooo0?ooo`3oool000000?ooo`0000001P3oool010000000oooo0000000000060?ooo`<00000
1P3oool2000000@0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000D0oooo0`0000060?ooo`800000
2@3oool2000000H0oooo0P00001l0?ooo`030000003oool0oooo07P0oooo00L000000?ooo`3oool0
oooo0000003oool0000000H0oooo00@000000?ooo`00000000001P3oool3000000H0oooo0P000004
0?ooo`<00000303oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`090?oo
o`8000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000H0oooo0P0000090?oo
o`8000001P3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo07T0oooo00@000000?oo
o`3oool0oooo0P0000070?ooo`030000003oool0000000H0oooo0P0000000`3oool000000?ooo`04
0?ooo`800000103oool2000000030?ooo`000000oooo00X0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool02@3oool200000080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000060?ooo`800000203oool2000000H0oooo0P00001m0?ooo`030000003oool0oooo
07T0oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00@000000?ooo`0000000000
1@3oool010000000oooo0000000000060?ooo`030000003oool0oooo0080oooo0P0000000`3oool0
00000?ooo`0:0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00T0oooo
0P0000000`3oool00000000000050?ooo`8000001`3oool2000000P0oooo0P0000060?ooo`800000
O@3oool00`000000oooo0?ooo`1i0?ooo`070000003oool0oooo0?ooo`000000oooo000000060?oo
o`040000003oool00000000000H0oooo0`0000060?ooo`030000003oool0oooo0080oooo0P000000
0`3oool000000?ooo`0:0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00P0000050?ooo`8000001P3oool2000000T0oooo0P0000050?oo
o`<00000O@3oool00`000000oooo0?ooo`1j0?ooo`040000003oool0oooo0?ooo`8000001`3oool3
000000H0oooo0`0000060?ooo`8000000`3oool2000000030?ooo`000000oooo00X0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`000005
0?ooo`<000001P3oool2000000P0oooo0`0000050?ooo`800000OP3oool00`000000oooo0?ooo`1j
0?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`<000001P3oool3000000H0oooo
0P0000040?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool02@3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000H0oooo
0P0000080?ooo`8000001P3oool2000007h0oooo00<000000?ooo`3oool0NP3oool01`000000oooo
0?ooo`3oool000000?ooo`0000001P3oool010000000oooo0000000000050?ooo`030000003oool0
000000H0oooo0P0000040?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3o
ool004/0oooo0P00000:0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000001P3o
ool2000000P0oooo0P0000050?ooo`<00000OP3oool00`000000oooo0?ooo`1k0?ooo`040000003o
ool0oooo0?ooo`8000001P3oool010000000oooo0000000000050?ooo`040000003oool000000000
00D0oooo0P0000040?ooo`80000000<0oooo0000003oool01`3oool3000000@0oooo001;0?ooo`03
0000003oool0oooo00P0oooo0P0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00001P3oool2000000P0oooo0P0000050?ooo`800000O`3oool00`000000oooo0?ooo`1k0?ooo`04
0000003oool0oooo0?ooo`8000001`3oool3000000D0oooo00@000000?ooo`00000000001@3oool2
000000@0oooo0P0000000`3oool000000?ooo`090?ooo`030000003oool0oooo0080oooo001;0?oo
o`030000003oool0oooo00P0oooo0P0000020?ooo`030000003oool0oooo00<0oooo0P0000060?oo
o`800000203oool3000000D0oooo0P00001o0?ooo`030000003oool0oooo07/0oooo00<000000?oo
o`3oool00P3oool2000000H0oooo0`0000060?ooo`<000001P3oool00`000000oooo0?ooo`020?oo
o`80000000<0oooo0000003oool02@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000001@3oool2000000H0oooo0P0000080?oo
o`8000001@3oool3000007l0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`020?oo
o`8000001P3oool3000000H0oooo0`0000060?ooo`8000000`3oool2000000030?ooo`000000oooo
00T0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`02000000D0oooo0P0000060?ooo`800000203oool2000000D0oooo0`00001o0?ooo`03
0000003oool0oooo07`0oooo00@000000?ooo`3oool0oooo0P0000070?ooo`<000001@3oool30000
00H0oooo0P0000030?ooo`80000000<0oooo0000003oool02@3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000D0oooo0`0000060?oo
o`800000203oool2000000D0oooo0P0000200?ooo`030000003oool0oooo07`0oooo00@000000?oo
o`3oool0oooo0P0000070?ooo`<000001@3oool00`000000oooo000000060?ooo`8000000`3oool2
000000030?ooo`000000oooo00T0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000H0oooo0P000008
0?ooo`800000103oool00`000000oooo000000200?ooo`030000003oool0oooo07`0oooo00L00000
0?ooo`3oool0oooo0000003oool0000000H0oooo0`0000050?ooo`040000003oool00000000000D0
oooo0P0000030?ooo`80000000<0oooo0000003oool02@3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`070?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000H0oooo00<000000?ooo`3oool01P3oool3000000@0oooo0`0000200?ooo`030000
003oool0oooo07d0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`<000001@3oool010000000
oooo0000000000050?ooo`8000000`3oool2000000030?ooo`000000oooo00T0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool01`3oool200000080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo000000060?ooo`030000003oool0oooo00H0oooo0P0000050?ooo`<0
0000P03oool00`000000oooo0?ooo`1m0?ooo`040000003oool0oooo0?ooo`8000001`3oool30000
00D0oooo0`0000050?ooo`800000103oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo00L0oooo0P0000020?ooo`030000003oool0oooo
00<0oooo0P0000070?ooo`030000003oool0oooo00H0oooo0P0000050?ooo`800000P@3oool00`00
0000oooo0?ooo`1m0?ooo`040000003oool0oooo0?ooo`8000001`3oool3000000D0oooo0`000006
0?ooo`8000000`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo00L0oooo0P0000020?ooo`030000003oool0oooo00<0oooo0P000006
0?ooo`800000203oool2000000@0oooo0`0000210?ooo`030000003oool0oooo07h0oooo00H00000
0?ooo`3oool000000?ooo`0000060?ooo`<000001@3oool3000000H0oooo0P0000030?ooo`800000
00<0oooo0000003oool0203oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`070?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`<000001P3oool2000000P0oooo0P00
00040?ooo`<00000P@3oool00`000000oooo0?ooo`1n0?ooo`060000003oool0oooo0000003oool0
00001P3oool3000000D0oooo0`0000060?ooo`8000000`3oool2000000030?ooo`000000oooo00P0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01`3oool200000080oooo
00<000000?ooo`3oool00P3oool3000000H0oooo0P0000070?ooo`<00000103oool300000840oooo
00<000000?ooo`3oool0OP3oool01P000000oooo0?ooo`000000oooo000000H0oooo0`0000050?oo
o`80000000<0oooo0000003oool0103oool2000000<0oooo0P0000000`3oool000000?ooo`080?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00H0oooo0P0000020?ooo`80
0000103oool3000000H0oooo0P0000070?ooo`<00000103oool300000840oooo00<000000?ooo`3o
ool0OP3oool010000000oooo0?ooo`3oool2000000H0oooo00<000000?ooo`0000001@3oool20000
00030?ooo`000000oooo00@0oooo0P0000030?ooo`80000000<0oooo0000003oool0203oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`060?ooo`8000000P3oool2000000@0
oooo0`0000060?ooo`8000001`3oool2000000@0oooo0`0000220?ooo`030000003oool0oooo07l0
oooo00<000000?ooo`3oool00P0000060?ooo`040000003oool00000000000D0oooo00<000000?oo
o`0000001@3oool2000000<0oooo0P0000000`3oool000000?ooo`080?ooo`030000003oool0oooo
0080oooo001;0?ooo`8000001`3oool200000080oooo00<000000?ooo`3oool00`3oool3000000H0
oooo0P0000070?ooo`800000103oool300000880oooo00<000000?ooo`3oool0O`3oool00`000000
oooo0?ooo`02000000L0oooo0`0000050?ooo`<000001@3oool2000000<0oooo0P0000000`3oool0
00000?ooo`060?ooo`<00000103oool000`0oooo00<0oono07Ad_`3oool0?03oool00`000000oooo
0?ooo`060?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`8000001`3oool00`000000oooo
0?ooo`060?ooo`800000103oool300000880oooo00<000000?ooo`3oool0O`3oool00`000000oooo
0?ooo`02000000L0oooo0`0000050?ooo`<000001P3oool010000000oooo0?ooo`3oool200000003
0?ooo`000000oooo00P0oooo00<000000?ooo`3oool00P3oool000`0oooo00@0omnL04P0000004P0
W=oo>`3oool00`000000oooo0?ooo`060?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`80
00001`3oool00`000000oooo0?ooo`050?ooo`<00000103oool300000880oooo00<000000?ooo`3o
ool0O`3oool00`000000oooo0?ooo`02000000L0oooo0`0000050?ooo`<000001P3oool010000000
oooo0?ooo`3oool2000000030?ooo`000000oooo00P0oooo00<000000?ooo`3oool00P3oool000h0
oooo00<0_g@00000000000000`0000000`0007@0_ooo0?ooo`0d0?ooo`030000003oool0oooo00H0
oooo0P0000020?ooo`030000003oool0oooo00<0oooo0P0000070?ooo`030000003oool0oooo00D0
oooo0`0000040?ooo`800000P`3oool00`000000oooo0?ooo`200?ooo`050000003oool000000?oo
o`0000001P3oool3000000D0oooo0`0000060?ooo`040000003oool0oooo0?ooo`80000000<0oooo
0000003oool0203oool00`000000oooo0?ooo`020?ooo`004P3oool00`3ogi`0B00007Boo`0f0?oo
o`030000003oool0oooo00H0oooo0P0000020?ooo`030000003oool0oooo0080oooo0`0000070?oo
o`030000003oool0oooo00D0oooo0`0000040?ooo`800000P`3oool00`000000oooo0?ooo`200?oo
o`030000003oool0oooo008000001P3oool3000000D0oooo0`0000060?ooo`040000003oool0oooo
0?ooo`@000002@3oool00`000000oooo0?ooo`020?ooo`004@3oool00`3OW4P0001d0;ooo`0g0?oo
o`030000003oool0oooo00H0oooo0P0000020?ooo`030000003oool0oooo0080oooo0`0000060?oo
o`8000001`3oool3000000@0oooo0P0000230?ooo`030000003oool0oooo0800oooo00<000000?oo
o`3oool00P0000060?ooo`<000001@3oool2000000030?ooo`000000oooo00@0oooo0P0000030?oo
o`80000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`020?ooo`00303oool01P3ogi`0
B01809cOo`3o_g@0000004RLgcT0oooo00<000000?ooo`3oool01P3oool200000080oooo00<00000
0?ooo`3oool00P3oool3000000H0oooo0P0000070?ooo`<000000`3oool3000008<0oooo00<00000
0?ooo`3oool0P03oool00`000000oooo0?ooo`02000000H0oooo0P0000000`3oool000000?ooo`03
0?ooo`80000000<0oooo0000003oool0103oool2000000<0oooo0P0000000`3oool000000?ooo`07
0?ooo`030000003oool0oooo0080oooo000<0?ooo`040?oOW01800000000001d_c/0oooo00<00000
0?ooo`3oool01P3oool200000080oooo00<000000?ooo`3oool00P3oool2000000L0oooo0P000007
0?ooo`800000103oool3000008<0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`02
000000H0oooo0P0000000`3oool000000?ooo`030?ooo`80000000<0oooo0000003oool0103oool2
000000<0oooo0P0000000`3oool000000?ooo`070?ooo`030000003oool0oooo0080oooo001;0?oo
o`030000003oool0oooo00H0oooo0P0000000`3oool00000000000040?ooo`8000001`3oool20000
00L0oooo0P0000040?ooo`<00000P`3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo
008000001P3oool2000000030?ooo`000000oooo00<0oooo0P0000000`3oool000000?ooo`040?oo
o`8000000`3oool2000000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool01P3oool2000000030?ooo`000000000000@0oooo0P0000070?ooo`80
00001`3oool2000000@0oooo0`0000230?ooo`030000003oool0oooo0800oooo00<000000?ooo`3o
ool00P0000060?ooo`80000000<0oooo0000003oool0103oool3000000D0oooo0P0000030?ooo`80
000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`020?ooo`003`3oool01P3OW4P00000
000000000000001809cOocH0oooo00<000000?ooo`3oool01P3oool2000000030?ooo`0000000000
00@0oooo0P0000070?ooo`8000001P3oool00`000000oooo000000040?ooo`800000Q03oool00`00
0000oooo0?ooo`200?ooo`030000003oool0oooo008000001P3oool2000000030?ooo`000000oooo
00@0oooo0`0000050?ooo`8000000`3oool2000000030?ooo`000000oooo00L0oooo00<000000?oo
o`3oool00P3oool000d0oooo00T0oono07@00018W=l0omnL09boo`3oool0gia80018W03Oool0=@3o
ool00`000000oooo0?ooo`050?ooo`<0000000<0oooo000000000000103oool2000000L0oooo0P00
00060?ooo`030000003oool0000000@0oooo0P0000240?ooo`030000003oool0oooo0840oooo00@0
00000?ooo`3oool000001`3oool00`000000oooo000000050?ooo`<000001@3oool2000000<0oooo
0P0000000`3oool000000?ooo`070?ooo`030000003oool0oooo0080oooo000=0?ooo`090;mdM02o
ool0oooo0?noW02Lgol0oooo0?oo_`1d07@0_ooo03D0oooo00<000000?ooo`3oool01@3oool20000
0080oooo00<000000?ooo`3oool00P3oool3000000L0oooo0P0000060?ooo`030000003oool00000
00@0oooo0P0000240?ooo`030000003oool0oooo0840oooo00@000000?ooo`3oool000001`3oool0
0`000000oooo000000050?ooo`<000001@3oool2000000<0oooo0P0000000`3oool000000?ooo`07
0?ooo`030000003oool0oooo0080oooo000<0?ooo`090?oOW02L_ol0oooo0?oog`2LM9`0gooo0?oo
o`3ogi`0B7Bo03H0oooo00<000000?ooo`3oool01@3oool200000080oooo00<000000?ooo`3oool0
0P3oool3000000L0oooo0P0000060?ooo`<00000103oool2000008@0oooo00<000000?ooo`3oool0
P@3oool010000000oooo0?ooo`0000070?ooo`030000003oool0000000D0oooo0`0000050?ooo`80
00000`3oool2000000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool00P3oool000`0oooo
00T0oknL09cOo`3oool0_g@007Boo`3oool0gia80000M02oool0=P3oool2000000H0oooo0P000002
0?ooo`030000003oool0oooo0080oooo0`0000070?ooo`030000003oool0oooo00D0oooo0`000004
0?ooo`800000Q03oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo008000001P3oool3
000000D0oooo0P0000000`3oool000000?ooo`030?ooo`8000000`3oool4000000H0oooo0`000004
0?ooo`00303oool0103ookl0M0000000001d_olk0?ooo`030000003oool0oooo00D0oooo0P000002
0?ooo`030000003oool0oooo0080oooo0`0000070?ooo`030000003oool0oooo00D0oooo0`000003
0?ooo`<00000Q03oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo008000001P3oool3
000000D0oooo0P0000000`3oool000000?ooo`030?ooo`8000000`3oool4000000P0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01@3oool200000080oooo00<000000?oo
o`3oool00P3oool3000000L0oooo00<000000?ooo`3oool01@3oool3000000<0oooo0`0000240?oo
o`030000003oool0oooo0840oooo00<000000?ooo`3oool00P0000060?ooo`<000001@3oool20000
00030?ooo`000000oooo00<0oooo0P0000030?ooo`@00000203oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`050?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`<0
00001`3oool00`000000oooo0?ooo`050?ooo`800000103oool3000008@0oooo00<000000?ooo`3o
ool0P@3oool00`000000oooo0?ooo`02000000H0oooo0`0000050?ooo`80000000<0oooo0000003o
ool00`3oool2000000<0oooo100000080?ooo`030000003oool0oooo0080oooo000@0?ooo`060?no
M000000000000000000007@0_ooo=@3oool00`000000oooo0?ooo`050?ooo`8000000P3oool00`00
0000oooo0?ooo`020?ooo`<000001`3oool00`000000oooo0?ooo`050?ooo`800000103oool30000
08@0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`02000000H0oooo0`0000050?oo
o`80000000<0oooo0000003oool00`3oool2000000@0oooo0`0000080?ooo`030000003oool0oooo
0080oooo00080?ooo`060;nLW03Oool0oooo0?ooo`3ogi`0B0000`0000001000B9`0gooo0?oo_`1d
M;lf0?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`030000003oool0oooo0080oooo0`00
00060?ooo`8000001`3oool2000000@0oooo0P0000250?ooo`030000003oool0oooo0840oooo00<0
00000?ooo`3oool00P0000060?ooo`<000001@3oool2000000030?ooo`000000oooo00<0oooo00<0
00000?ooo`0000000`3oool3000000P0oooo00<000000?ooo`3oool00P3oool000L0oooo00<0oooO
09a8000000000`0000000`00M;l0oooo0?ooo`020?ooo`030?noM00007@0_ooo03H0oooo00<00000
0?ooo`3oool01@3oool200000080oooo00<000000?ooo`3oool00P3oool3000000H0oooo0P000007
0?ooo`800000103oool2000008D0oooo00<000000?ooo`3oool0P@3oool01@000000oooo0?ooo`3o
ool0000000H0oooo0`0000050?ooo`80000000<0oooo0000003oool00`3oool00`000000oooo0000
00030?ooo`<00000203oool00`000000oooo0?ooo`020?ooo`001`3oool00`3ookl0M00004RLg`11
0?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`030000003oool0oooo0080oooo0`000006
0?ooo`8000001`3oool2000000@0oooo0P0000250?ooo`030000003oool0oooo0840oooo00D00000
0?ooo`3oool0oooo000000060?ooo`<000001@3oool2000000030?ooo`000000oooo00<0oooo00<0
00000?ooo`0000000`3oool3000000P0oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool01@3oool200000080oooo00<000000?ooo`3oool00P3oool3000000H0oooo0P000007
0?ooo`800000103oool2000008D0oooo00<000000?ooo`3oool0P@3oool01@000000oooo0?ooo`3o
ool0000000H0oooo0`0000050?ooo`80000000<0oooo0000003oool00`3oool00`000000oooo0000
00030?ooo`<00000203oool00`000000oooo0?ooo`020?ooo`003`3oool01P3ogi`0B00000000000
0000001809cOobP0oooo00@0_g@0000000000000M;oo2P3oool00`000000oooo0?ooo`050?ooo`80
00000P3oool00`000000oooo0?ooo`020?ooo`<000001P3oool2000000H0oooo00<000000?ooo`00
0000103oool2000008D0oooo00<000000?ooo`3oool0P@3oool01@000000oooo0?ooo`3oool00000
00H0oooo0`0000060?ooo`030000003oool0000000D0oooo0P0000030?ooo`<00000203oool00`00
0000oooo0?ooo`020?ooo`003P3oool00`2oM000000007Boo`020?ooo`030?oog`2LM9`0gooo02H0
oooo00H0gia8001d_`3oool0omnL04P00018W=l90?ooo`030000003oool0oooo00D0oooo0P000002
0?ooo`030000003oool0oooo0080oooo0`0000060?ooo`8000001P3oool00`000000oooo00000004
0?ooo`800000Q@3oool00`000000oooo0?ooo`210?ooo`050000003oool0oooo0?ooo`0000001P3o
ool3000000H0oooo00<000000?ooo`0000001@3oool2000000<0oooo0`0000080?ooo`030000003o
ool0oooo0080oooo000=0?ooo`030=nLB018W=l0oooo00@0oooo00<0gibL0;ooo`3oool0903oool0
0`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00P0oooo00<000000?ooo`3oool01@3oool2
00000080oooo00<000000?ooo`3oool00P3oool3000000H0oooo0P0000060?ooo`030000003oool0
000000@0oooo0P0000250?ooo`030000003oool0oooo0840oooo00@000000?ooo`3oool0oooo0P00
00050?ooo`<000001P3oool00`000000oooo000000050?ooo`8000000`3oool3000000P0oooo00<0
00000?ooo`3oool00P3oool000`0oooo00<0omnL07BLg`3oool0103oool00`3ooml0W7BL0=ooo`0U
0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo1`3oool00`000000oooo0?oo
o`050?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`<000001P3oool2000000H0oooo00<0
00000?ooo`000000103oool2000008D0oooo00<000000?ooo`3oool0P@3oool010000000oooo0?oo
o`3oool2000000D0oooo0`0000060?ooo`030000003oool0000000D0oooo0P0000030?ooo`<00000
203oool00`000000oooo0?ooo`020?ooo`00303oool00`3o_i`0W=oo0?ooo`030?ooo`030?oog`2L
B000M;oo02H0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`070?ooo`030000003o
ool0oooo00D0oooo0P0000020?ooo`030000003oool0oooo0080oooo0`0000060?ooo`8000001P3o
ool00`000000oooo000000040?ooo`800000Q@3oool00`000000oooo0?ooo`210?ooo`040000003o
ool0oooo0?ooo`8000001@3oool3000000H0oooo00<000000?ooo`0000001@3oool2000000<0oooo
0`0000080?ooo`030000003oool0oooo0080oooo000<0?ooo`030?oOW018M;l0oooo0080oooo00<0
gia800000018W=l0:03oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00L0ooooo`00
001R000000@0oooo000=0?ooo`060?noM0000000000000000000B9`0gooo:@3oool00`3OW4P00018
09cOo`020?ooo`030?oog`2LB00007Bo00L0oooo00<000000?ooo`3oool01@3oool200000080oooo
00<000000?ooo`3oool00P3oool3000000H0oooo0P0000060?ooo`030000003oool0000000@0oooo
0P0000250?ooo`030000003oool0oooo0840oooo00@000000?ooo`3oool0oooo0P0000050?ooo`<0
00001P3oool00`000000oooo000000050?ooo`8000000`3oool3000000P0oooo00<000000?ooo`3o
ool00P3oool003`0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`060?ooo`030000
003oool0oooo00D0oooo0P0000020?ooo`030000003oool0oooo0080oooo0`0000060?ooo`800000
1P3oool00`000000oooo000000040?ooo`800000Q@3oool00`000000oooo0?ooo`210?ooo`040000
003oool0oooo0?ooo`8000001@3oool3000000H0oooo00<000000?ooo`0000001@3oool2000000<0
oooo0`0000080?ooo`030000003oool0oooo0080oooo000l0?ooo`040?oog`2LB00004RL0=ooo`80
oooo00<0gia80018W03Oool01P3oool00`000000oooo0?ooo`050?ooo`8000000P3oool00`000000
oooo0?ooo`020?ooo`<000001P3oool2000000H0oooo00<000000?ooo`000000103oool2000008D0
oooo00<000000?ooo`3oool0P@3oool010000000oooo0?ooo`3oool2000000D0oooo0`0000060?oo
o`030000003oool0000000D0oooo0P0000030?ooo`<00000203oool00`000000oooo0?ooo`020?oo
o`003`3oool01P3ogi`0B000000000000000001809cOobP0oooo00<0omnL04P0001d_ol00P3oool0
0`3OW4P007Bo0?ooo`060?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`8000000`3oool3
000000H0oooo0P0000060?ooo`030000003oool0000000@0oooo0P0000250?ooo`030000003oool0
oooo0840oooo00@000000?ooo`3oool0oooo0P0000050?ooo`<000001P3oool00`000000oooo0000
00050?ooo`8000000`3oool3000000P0oooo00<000000?ooo`3oool00P3oool000d0oooo00@0oooO
09a80000B9`0gooo0P3oool00`3o_g@004RL0=ooo`0X0?ooo`060=nLB00007@0_ooo0?oog`2LB000
B9cO1`3oool00`000000oooo0?ooo`050?ooo`8000000P3oool2000000<0oooo0`0000060?ooo`80
00001P3oool00`000000oooo000000040?ooo`800000Q@3oool00`000000oooo0?ooo`210?ooo`06
0000003oool0oooo0000003oool000001@3oool3000000H0oooo00<000000?ooo`0000001@3oool2
000000<0oooo0`0000080?ooo`030000003oool0oooo0080oooo000=0?ooo`030;mdB02Lgol0oooo
00<0oooo00<0oooO09a8M02oool0:@3oool0103OW4P0000000000000M;l80?ooo`030000003oool0
oooo00D0oooo0P0000020?ooo`8000000`3oool00`000000oooo000000060?ooo`8000001P3oool0
10000000oooo0000000000030?ooo`800000Q@3oool00`000000oooo0?ooo`210?ooo`060000003o
ool0oooo0000003oool000001@3oool3000000H0oooo00<000000?ooo`0000001@3oool010000000
oooo0?ooo`3oool4000000P0oooo00<000000?ooo`3oool00P3oool000`0oooo00<0omnL09boo`3o
ool0103oool00`3ogi`0B7Bo0?ooo`0e0?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`80
00000`3oool00`000000oooo000000060?ooo`030000003oool0000000D0oooo00@000000?ooo`00
000000000`3oool2000008D0oooo00<000000?ooo`3oool0P@3oool01P000000oooo0?ooo`000000
oooo000000D0oooo0`0000060?ooo`030000003oool0000000D0oooo00H000000?ooo`3oool0oooo
0000003oool2000000P0oooo00<000000?ooo`3oool00P3oool000`0oooo00<0oknL09cOo`3oool0
0`3oool00`3ogi`0B4RL0=ooo`0f0?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`800000
0`3oool00`000000oooo000000060?ooo`030000003oool0000000D0oooo00@000000?ooo`000000
00000`3oool2000008D0oooo00<000000?ooo`3oool0P@3oool01P000000oooo0?ooo`000000oooo
000000D0oooo0`0000060?ooo`030000003oool0000000D0oooo00@000000?ooo`3oool0oooo0P00
00000`3oool000000?ooo`070?ooo`030000003oool0oooo0080oooo000<0?ooo`040?oo_`1d0000
000007Booc/0oooo00<000000?ooo`3oool01@3oool200000080oooo0P0000030?ooo`030000003o
ool0000000H0oooo00<000000?ooo`0000001P3oool3000000<0oooo0P0000250?ooo`030000003o
ool0oooo0840oooo00<000000?ooo`3oool00P0000060?ooo`<000001@3oool2000000030?ooo`00
0000oooo00@0oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`070?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`8000000`3o
ool00`000000oooo000000060?ooo`030000003oool0000000H0oooo0`0000030?ooo`800000Q@3o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo008000001P3oool3000000D0oooo0P00
00000`3oool000000?ooo`040?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool0
1`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo008000000`3oool00`000000oooo000000060?ooo`030000003oool0000000H0oooo0`00
00030?ooo`<00000Q03oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo008000001P3o
ool00`000000oooo000000050?ooo`80000000<0oooo0000003oool0103oool010000000oooo0?oo
o`3oool2000000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool00P3oool000`0oooo00<0
oono09bLg`3oool00`3oool0103o_g@000000000M02ooole0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P0000030?ooo`030000003oool0000000L0oooo0P0000060?ooo`<00000
0`3oool3000008@0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`02000000H0oooo
00<000000?ooo`0000001@3oool2000000030?ooo`000000oooo00@0oooo00@000000?ooo`3oool0
oooo0P0000000`3oool000000?ooo`070?ooo`030000003oool0oooo0080oooo000<0?ooo`040?oo
_`2LW=l0oono07@000@0000000<004RL0=ooo`3oool0=03oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00800000103oool2000000L0oooo0P0000060?ooo`<000000`3oool3000008@0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`02000000H0oooo0P0000060?ooo`<0
00001P3oool010000000oooo0?ooo`3oool2000000030?ooo`000000oooo00L0oooo00<000000?oo
o`3oool00P3oool000`0oooo00T0omnL04P000000000001809cOo`3oool0oooO09a8M02oool0=P3o
ool2000000L0oooo00<000000?ooo`3oool00P0000040?ooo`8000001`3oool2000000H0oooo0`00
00030?ooo`<00000Q03oool00`000000oooo0?ooo`200?ooo`040000003oool0oooo0?ooo`800000
1P3oool2000000H0oooo0`0000060?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003o
ool01@3oool3000000@0oooo00080?ooo`040?oog`2LB000001d0;ooocl0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`02000000@0oooo0P0000070?ooo`8000001P3oool3000000@0
oooo0P0000240?ooo`030000003oool0oooo0800oooo00@000000?ooo`3oool0oooo0P0000050?oo
o`<000001P3oool3000000H0oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`07
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P0000040?ooo`8000001`3oool2000000H0oooo0`0000040?ooo`800000Q03oool00`00
0000oooo0?ooo`200?ooo`040000003oool0oooo0?ooo`8000001@3oool3000000H0oooo0`000006
0?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool01`3oool00`000000oooo0?oo
o`020?ooo`00303oool01@3ogkl0_moo0?ooo`3oool0_g@000<0000000<0001d0;ooo`3oool0=03o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00800000103oool2000000L0oooo0P00
00060?ooo`<00000103oool2000008@0oooo00<000000?ooo`3oool0P03oool010000000oooo0?oo
o`3oool2000000D0oooo0`0000060?ooo`<000001@3oool2000000<0oooo0P0000000`3oool00000
0?ooo`070?ooo`030000003oool0oooo0080oooo000<0?ooo`030;md0000000000000080000000D0
001d0;ooo`3oool0_ibL0=ooo`0e0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P0000040?ooo`<000001P3oool2000000H0oooo0`0000040?ooo`800000Q03oool00`000000oooo
0?ooo`200?ooo`060000003oool0oooo0000003oool000001@3oool3000000H0oooo0`0000050?oo
o`8000000`3oool3000000T0oooo00<000000?ooo`3oool00P3oool000X0oooo00D0_g@000000000
000004RL0=ooo`030?ooo`030?oog`2LB000M;oo0080oooo00<0_g@00018W03Oool0<@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00800000103oool3000000H0oooo0P0000060?oo
o`<00000103oool2000008@0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`020000
00H0oooo0`0000060?ooo`<000001@3oool2000000<0oooo0`0000090?ooo`030000003oool0oooo
0080oooo000<0?ooo`030?noW02Lgol0oooo00P0oooo00<0omnL04Qd_`3oool0<@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00800000103oool3000000H0oooo0P0000060?ooo`04
0000003oool00000000000<0oooo0P0000240?ooo`030000003oool0oooo0800oooo00<000000?oo
o`3oool00P0000060?ooo`<000001P3oool3000000D0oooo0P0000030?ooo`<000002@3oool00`00
0000oooo0?ooo`020?ooo`00303oool00`3ookl0M7Bo0?ooo`070?ooo`030?noM000B9`0gooo0380
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02000000@0oooo0`0000060?ooo`80
00001P3oool010000000oooo0000000000040?ooo`800000P`3oool00`000000oooo0?ooo`200?oo
o`030000003oool0oooo008000001P3oool3000000H0oooo00<000000?ooo`0000001@3oool20000
00<0oooo0`0000090?ooo`030000003oool0oooo0080oooo000<0?ooo`040?oOW0180000001d0;oo
o`D0oooo00<0gia8001d_`3oool0<`3oool00`000000oooo0?ooo`060?ooo`80000000<0oooo0000
00000000103oool3000000H0oooo0P0000070?ooo`<00000103oool2000008<0oooo00<000000?oo
o`3oool0P03oool00`000000oooo0?ooo`02000000H0oooo0`0000060?ooo`030000003oool00000
00D0oooo00<000000?ooo`3oool00P3oool3000000T0oooo00<000000?ooo`3oool00P3oool000d0
oooo00<0omnL04P0000000001@0000000`18W=l0oooo0?ooo`0c0?ooo`030000003oool0oooo00H0
oooo0P0000000`3oool00000000000040?ooo`<000001P3oool2000000L0oooo0`0000040?ooo`80
0000P`3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo008000001P3oool3000000H0
oooo0P0000060?ooo`030000003oool0oooo0080oooo0`0000090?ooo`030000003oool0oooo0080
oooo000B0?ooo`030?noM00004P0W=oo03H0oooo00<000000?ooo`3oool01P3oool2000000030?oo
o`000000000000@0oooo0`0000060?ooo`030000003oool0000000H0oooo0`0000040?ooo`800000
P`3oool00`000000oooo0?ooo`1o0?ooo`040000003oool0oooo0?ooo`8000001P3oool3000000H0
oooo0P0000060?ooo`030000003oool0oooo0080oooo0`0000090?ooo`030000003oool0oooo0080
oooo000A0?ooo`030;md0000M;l0oooo03L0oooo00<000000?ooo`3oool01P3oool2000000030?oo
o`000000000000D0oooo0P0000060?ooo`030000003oool0000000H0oooo0`0000040?ooo`800000
P`3oool00`000000oooo0?ooo`1o0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000
oooo000000060?ooo`<000001P3oool00`000000oooo0?ooo`020?ooo`<000002@3oool00`000000
oooo0?ooo`020?ooo`00303oool01P3ogi`0B00007Boo`3o_g@0000007BoocT0oooo00<000000?oo
o`3oool01P3oool200000080oooo0P0000040?ooo`8000001P3oool00`000000oooo000000060?oo
o`<00000103oool2000008<0oooo00<000000?ooo`3oool0O`3oool01@000000oooo0?ooo`3oool0
000000H0oooo00<000000?ooo`0000001P3oool3000000D0oooo0P0000030?ooo`@000002@3oool0
0`000000oooo0?ooo`020?ooo`00303oool0103ogi`0B00000000000M;lk0?ooo`030000003oool0
oooo00H0oooo0P0000020?ooo`800000103oool3000000D0oooo00<000000?ooo`0000001P3oool2
000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`1o
0?ooo`030000003oool0oooo008000001P3oool3000000H0oooo0`0000050?ooo`8000000`3oool4
000000T0oooo00<000000?ooo`3oool00P3oool004/0oooo0P0000070?ooo`8000000P3oool20000
00@0oooo0`0000050?ooo`030000003oool0000000H0oooo0P0000000`3oool000000?ooo`030?oo
o`800000PP3oool00`000000oooo0?ooo`1n0?ooo`040000003oool0oooo0?ooo`8000001P3oool3
000000H0oooo0`0000050?ooo`8000000`3oool4000000L0oooo0`0000040?ooo`00B`3oool00`00
0000oooo0?ooo`060?ooo`8000000P3oool2000000@0oooo0`0000060?ooo`8000001P3oool01000
0000oooo0000000000040?ooo`800000PP3oool00`000000oooo0?ooo`1n0?ooo`040000003oool0
oooo0?ooo`8000001P3oool3000000H0oooo00<000000?ooo`0000001@3oool2000000<0oooo1000
00090?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00L0oooo0P000000
0`3oool00000000000040?ooo`<000001P3oool2000000H0oooo00@000000?ooo`0000000000103o
ool200000880oooo00<000000?ooo`3oool0OP3oool010000000oooo0?ooo`3oool2000000H0oooo
0`0000060?ooo`030000003oool0000000D0oooo0P0000030?ooo`80000000<0oooo0000003oool0
203oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`070?ooo`80000000<0
oooo000000000000103oool3000000H0oooo00<000000?ooo`0000001P3oool3000000D0oooo00<0
00000?ooo`3oool0P03oool00`000000oooo0?ooo`1n0?ooo`050000003oool0oooo0?ooo`000000
1`3oool3000000H0oooo00<000000?ooo`0000001@3oool2000000<0oooo0P0000000`3oool00000
0?ooo`080?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00L0oooo0P00
00000`3oool00000000000040?ooo`030000003oool0000000H0oooo00<000000?ooo`0000001P3o
ool3000000D0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`1m0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool010000000oooo0000000000060?ooo`030000
003oool0000000D0oooo00<000000?ooo`3oool00P3oool2000000030?ooo`000000oooo00P0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01`3oool200000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000060?ooo`030000003oool0000000H0oooo0P00
00000`3oool000000?ooo`030?ooo`800000P@3oool00`000000oooo0?ooo`1m0?ooo`040000003o
ool0oooo0?ooo`8000001P3oool2000000030?ooo`000000oooo00D0oooo00<000000?ooo`000000
1@3oool00`000000oooo0?ooo`020?ooo`<000002P3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`070?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000H0oooo00<000000?ooo`0000001P3oool2000000030?ooo`000000oooo00<0oooo0P00
00210?ooo`030000003oool0oooo07d0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`<00000
1`3oool2000000H0oooo00<000000?ooo`3oool00P3oool3000000X0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool01`3oool200000080oooo0P0000030?ooo`030000003o
ool0000000L0oooo0P0000070?ooo`<000001@3oool00`000000oooo0?ooo`1o0?ooo`030000003o
ool0oooo07d0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`<000001`3oool2000000D0oooo
0P0000040?ooo`<000002P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`070?ooo`8000000P3oool2000000<0oooo00@000000?ooo`00000000001P3oool2000000L0oooo
0`0000050?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0O03oool00`000000oooo
0?ooo`020?ooo`8000001P3oool3000000H0oooo0`0000050?ooo`800000103oool3000000X0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01`3oool200000080oooo0P00
00040?ooo`<000001P3oool2000000L0oooo0`0000050?ooo`800000P03oool00`000000oooo0?oo
o`1l0?ooo`040000003oool0oooo0?ooo`8000001`3oool3000000H0oooo00<000000?ooo`000000
1@3oool2000000@0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`070?ooo`<0000000<0oooo000000000000103oool3000000H0oooo00<0
00000?ooo`0000001P3oool2000000030?ooo`000000oooo00<0oooo0P0000200?ooo`030000003o
ool0oooo07`0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`80000000<0oooo0000003oool0
1@3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo0P0000000`3oool00000
0?ooo`090?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00L0oooo0`00
00000`3oool00000000000040?ooo`030000003oool0000000H0oooo00<000000?ooo`0000001`3o
ool3000000@0oooo0P0000200?ooo`030000003oool0oooo07`0oooo00@000000?ooo`3oool0oooo
0P0000060?ooo`80000000<0oooo0000003oool01@3oool00`000000oooo000000050?ooo`030000
003oool0oooo0080oooo0P0000000`3oool000000?ooo`090?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo00P0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000001P3oool00`000000oooo000000070?ooo`<000001@3oool00`000000oooo0?oo
o`1n0?ooo`030000003oool0oooo07/0oooo00L000000?ooo`3oool0oooo0000003oool0000000H0
oooo0`0000070?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool3000000/0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0203oool200000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000070?ooo`8000001`3oool2000000030?oo
o`000000oooo00<0oooo0P00001o0?ooo`030000003oool0oooo07/0oooo00@000000?ooo`3oool0
oooo0P0000070?ooo`<000001P3oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3o
ool00P3oool3000000/0oooo00<000000?ooo`3oool00P3oool004/0oooo0P0000090?ooo`800000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000L0oooo0P0000070?ooo`040000
003oool00000000000@0oooo0P00001o0?ooo`030000003oool0oooo07/0oooo00@000000?ooo`3o
ool0oooo0P0000070?ooo`030000003oool0000000H0oooo0`0000060?ooo`030000003oool0oooo
0080oooo0`0000090?ooo`<00000103oool004/0oooo00<000000?ooo`3oool0203oool200000080
oooo00<000000?ooo`3oool00P3oool010000000oooo0000000000060?ooo`030000003oool00000
00L0oooo0`0000040?ooo`800000O`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo
0080oooo0P0000060?ooo`80000000<0oooo0000003oool01@3oool3000000H0oooo00<000000?oo
o`3oool00P3oool3000000/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool0203oool200000080oooo0P0000030?ooo`040000003oool00000000000H0oooo00<000000?oo
o`0000001`3oool2000000030?ooo`000000oooo00<0oooo0P00001n0?ooo`030000003oool0oooo
07X0oooo00@000000?ooo`3oool0oooo0P0000070?ooo`80000000<0oooo0000003oool01@3oool3
000000D0oooo0P0000030?ooo`80000000<0oooo0000003oool02P3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`080?ooo`8000000P3oool2000000@0oooo0`0000060?oo
o`030000003oool0000000L0oooo00@000000?ooo`0000000000103oool2000007h0oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`020?ooo`8000001`3oool3000000L0oooo00<00000
0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`80000000<0oooo0000003oool02P3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`080?ooo`<000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000H0oooo00<000000?ooo`0000001`3oool01000
0000oooo0000000000050?ooo`800000O@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0
oooo0080oooo0P0000070?ooo`030000003oool0000000H0oooo0`0000060?ooo`030000003oool0
oooo0080oooo0P0000000`3oool000000?ooo`0:0?ooo`030000003oool0oooo0080oooo001;0?oo
o`030000003oool0oooo00T0oooo0P0000020?ooo`030000003oool0oooo0080oooo00@000000?oo
o`00000000001P3oool00`000000oooo000000070?ooo`<000001@3oool2000007d0oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`0000001P3oool3000000H0oooo00<000000?ooo`3oool00P3oool2000000030?ooo`000000
oooo00X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02@3oool20000
0080oooo00<000000?ooo`3oool00P3oool010000000oooo0000000000060?ooo`030000003oool0
000000L0oooo0P0000000`3oool000000?ooo`030?ooo`800000O@3oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo0080oooo0P0000080?ooo`8000001`3oool3000000H0oooo00<00000
0?ooo`3oool00P3oool3000000`0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool02@3oool200000080oooo00<000000?ooo`3oool00`3oool3000000H0oooo00<000000?oo
o`0000001`3oool010000000oooo0000000000050?ooo`800000O03oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool3000000L0oooo0`000006
0?ooo`060000003oool0oooo0?ooo`000000oooo0P00000<0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo00T0oooo0P0000020?ooo`030000003oool0oooo00<0oooo0`00
00060?ooo`030000003oool0000000L0oooo00@000000?ooo`00000000001@3oool2000007`0oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`0000001`3oool2000000H0oooo0P0000030?ooo`040000003oool00000000000`0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02@3oool200000080oooo
00<000000?ooo`3oool00`3oool3000000H0oooo00@000000?ooo`3oool000001`3oool200000003
0?ooo`000000oooo00@0oooo0P00001k0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3o
ool00P3oool2000000P0oooo00<000000?ooo`0000001P3oool3000000H0oooo0P0000030?ooo`@0
0000303oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`090?ooo`800000
0P3oool00`000000oooo0?ooo`030?ooo`040000003oool00000000000D0oooo00@000000?ooo`3o
ool000001`3oool010000000oooo0000000000050?ooo`800000N`3oool00`000000oooo0?ooo`1g
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool2000000L0oooo0`000006
0?ooo`030000003oool0oooo0080oooo0P0000000`3oool000000?ooo`0;0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo00X0oooo0P0000020?ooo`030000003oool0oooo
00<0oooo0`0000060?ooo`030000003oool0000000L0oooo00@000000?ooo`00000000001@3oool3
000007X0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`020?ooo`800000203oool0
0`000000oooo000000070?ooo`<000001P3oool00`000000oooo0?ooo`020?ooo`80000000<0oooo
0000003oool02`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0:0?oo
o`8000000P3oool00`000000oooo0?ooo`030?ooo`<000001P3oool010000000oooo0?ooo`000007
0?ooo`80000000<0oooo0000003oool0103oool2000007X0oooo00<000000?ooo`3oool0MP3oool0
0`000000oooo0?ooo`020?ooo`800000203oool00`000000oooo000000070?ooo`<000001P3oool0
0`000000oooo0?ooo`020?ooo`<000003@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`00
0000oooo0?ooo`0:0?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`<000001P3oool01000
0000oooo0?ooo`0000070?ooo`040000003oool00000000000D0oooo00<000000?ooo`000000N@3o
ool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool2000000P0oooo0P0000070?ooo`060000003oool0oooo0?ooo`000000oooo0P00000=0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`8000002`3oool200000080oooo00<000000?ooo`3oool0
0`3oool2000000030?ooo`000000oooo00@0oooo00@000000?ooo`3oool00000203oool3000000D0
oooo0`00001i0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool00P3oool2000000P0
oooo00<000000?ooo`0000001`3oool3000000H0oooo00<000000?ooo`3oool00P3oool4000000/0
oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`0:0?ooo`8000000P3oool00`000000oooo
0?ooo`030?ooo`040000003oool00000000000H0oooo00<000000?ooo`000000203oool200000003
0?ooo`000000oooo00@0oooo00<000000?ooo`000000N03oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo000000070?ooo`<0
00001P3oool00`000000oooo0?ooo`020?ooo`@000003@3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000H0oooo0`0000060?ooo`04
0000003oool0oooo000000L0oooo00@000000?ooo`00000000001@3oool00`000000oooo0000001h
0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool2000000P0oooo00<00000
0?ooo`000000203oool3000000H0oooo00<000000?ooo`3oool00P3oool3000000h0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02`3oool200000080oooo00<000000?oo
o`3oool00`3oool3000000H0oooo00@000000?ooo`3oool00000203oool2000000030?ooo`000000
oooo00@0oooo00<000000?ooo`000000M`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo000000080?ooo`8000001`3oool0
0`000000oooo0?ooo`020?ooo`<000003P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`00
0000oooo0?ooo`0;0?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`<000001`3oool00`00
0000oooo000000080?ooo`040000003oool00000000000D0oooo00<000000?ooo`000000M`3oool0
0`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo0P0000090?ooo`8000002@3oool2
000000H0oooo0P0000030?ooo`040000003oool00000000000h0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool02`3oool200000080oooo00<000000?ooo`3oool00`3oool0
10000000oooo0000000000060?ooo`030000003oool0000000P0oooo00D000000?ooo`000000oooo
000000050?ooo`030000003oool0000007H0oooo00<000000?ooo`3oool0LP3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000203oool3000000H0oooo
00<000000?ooo`3oool00P3oool010000000oooo00000000000>0?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo00/0oooo0P0000020?ooo`8000001@3oool3000000L0oooo
00<000000?ooo`000000203oool010000000oooo0000000000050?ooo`030000003oool0000007H0
oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`020?ooo`8000002@3oool2000000T0
oooo0`0000060?ooo`030000003oool0oooo0080oooo0`00000?0?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo00/0oooo0P0000030?ooo`030000003oool0oooo00<0oooo
0`0000070?ooo`030000003oool0000000P0oooo00D000000?ooo`000000oooo000000050?ooo`03
0000003oool0000007D0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00P0oooo0P0000090?ooo`8000001`3oool00`000000oooo0?ooo`020?ooo`<0
00003`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0<0?ooo`800000
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000L0oooo00<000000?ooo`000000
203oool00`000000oooo0?ooo`02000000D0oooo0`00001e0?ooo`030000003oool0oooo0740oooo
00<000000?ooo`3oool00P3oool2000000T0oooo00<000000?ooo`0000002@3oool2000000H0oooo
0P0000040?ooo`<000003`3oool00`000000oooo0?ooo`020?ooo`00;`3oool0102oM00000000000
001d_ol30?ooo`030?oOW0180000M;oo0080oooo00H0omnL04P00000000000000018W03Oool:0?oo
o`030000003oool0oooo00`0oooo0P0000020?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`00000000001`3oool00`000000oooo000000080?ooo`030000003oool0oooo008000001@3oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool00P3oool2
000000X0oooo0P0000090?ooo`<000001P3oool00`000000oooo0?ooo`030?ooo`<000003`3oool0
0`000000oooo0?ooo`020?ooo`00;P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0
omnL04P0001d_ol00P3oool01P3o_g@0000007Boo`3oool0omnL04Qd_`X0oooo00<000000?ooo`3o
ool0303oool200000080oooo0P0000050?ooo`<000001`3oool00`000000oooo000000080?ooo`03
0000003oool0oooo008000001@3oool2000000030?ooo`000000oooo0780oooo00<000000?ooo`3o
ool0K`3oool00`000000oooo0?ooo`030?ooo`8000002@3oool3000000T0oooo0`0000060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`020?ooo`00
;@3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00/0oooo00<0okmd04RLg`3oool0
203oool00`000000oooo0?ooo`0<0?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`<00000
1`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo008000001@3oool010000000
oooo0?ooo`00001b0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool00P3oool20000
00X0oooo0P0000090?ooo`<000001`3oool00`000000oooo0?ooo`020?ooo`<00000403oool00`00
0000oooo0?ooo`020?ooo`00;@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=oo
o`X0oooo00<0oono07@0M02oool0203oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo000000080?ooo`030000003oool0000000P0oooo00<00000
0?ooo`3oool00P0000060?ooo`030000003oool000000780oooo00<000000?ooo`3oool0KP3oool0
0`000000oooo0?ooo`030?ooo`8000002P3oool2000000T0oooo0`0000060?ooo`030000003oool0
oooo00<0oooo0`00000@0?ooo`030000003oool0oooo0080oooo000]0?ooo`030?oog`2LB00007Bo
00<0oooo00<0gia80000B02Lgol02P3oool00`3ooml0W4P007Boo`080?ooo`030000003oool0oooo
00d0oooo0P0000020?ooo`800000103oool010000000oooo0000000000070?ooo`040000003oool0
oooo000000L0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`80000000<0oooo0000003oool0
L03oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00<0oooo0P00000:0?ooo`030000
003oool0000000T0oooo0P0000070?ooo`030000003oool0oooo00<0oooo0`00000@0?ooo`030000
003oool0oooo0080oooo000^0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l02P3o
ool00`3ookl0M00004RLg`080?ooo`<000003@3oool200000080oooo0P0000050?ooo`<000001`3o
ool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000
oooo0?ooo`00001`0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0000000:0?ooo`8000002@3oool3000000L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0000000>0?ooo`@00000103oool002h0oooo00<0gia80000B02Lgol00P3oool00`3ooml0
W4P0001d_`0:0?ooo`030?noM0000000M;oo00P0oooo00<000000?ooo`3oool03@3oool2000000<0
oooo00<000000?ooo`3oool00`3oool010000000oooo0000000000070?ooo`030000003oool00000
00P0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`8000000P3oool00`000000oooo0?ooo`1]
0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool00`3oool2000000X0oooo0`000009
0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`<000004@3oool00`000000oooo0?ooo`02
0?ooo`00;P3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00H0oooo00H0omoO0=oo
o`3o_g@000000000M02oool80?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool0oooo
0P0000040?ooo`040000003oool00000000000L0oooo00@000000?ooo`3oool000001`3oool00`00
0000oooo0?ooo`020?ooo`8000001@3oool200000080oooo00<000000?ooo`3oool0K03oool00`00
0000oooo0?ooo`1[0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000002P3oool20000
00X0oooo0P0000070?ooo`030000003oool0oooo00<0oooo0`00000A0?ooo`030000003oool0oooo
0080oooo000^0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool01P3oool01@3o
okl0M0000000000004P0W=oo00T0oooo00<000000?ooo`3oool03P3oool200000080oooo0P000004
0?ooo`040000003oool00000000000L0oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`020?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`1Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000002P3oool3000000T0oooo
0P0000080?ooo`030000003oool0oooo0080oooo00@000000?ooo`00000000004@3oool00`000000
oooo0?ooo`020?ooo`00;`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00L0oooo
00<0gibL0;ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`8000000P3oool2000000D0oooo
0P0000000`3oool000000?ooo`060?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo000000040?ooo`8000000`3oool00`000000oooo0?ooo`1Z0?ooo`03
0000003oool0oooo06T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000;0?ooo`80
00002P3oool2000000P0oooo00<000000?ooo`3oool00P3oool300000180oooo00<000000?ooo`3o
ool00P3oool00300oooo00H0gia80000M02oool0oooO09a80018W=l80?ooo`030?oOW01dW=l0oooo
00X0oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`3oool2000000@0oooo00@00000
0?ooo`00000000001`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0080oooo
0P0000050?ooo`8000000`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo06P0oooo
00<000000?ooo`3oool0103oool00`000000oooo0000000:0?ooo`<000002@3oool2000000P0oooo
0P0000040?ooo`<000004P3oool00`000000oooo0?ooo`020?ooo`00<@3oool0103OW4P000000000
0000M;l:0?ooo`050;md00000000000000000018W=l01`3oool00`000000oooo0?ooo`0?0?ooo`80
00000P3oool2000000D0oooo0P0000000`3oool000000?ooo`060?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool00`3oool2000000D0oooo0P0000030?ooo`030000003oool0oooo06P0
oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000X0
oooo0`00000:0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`040000003oool000000000
0180oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool03`3oool200000080
oooo0P0000050?ooo`80000000<0oooo0000003oool01P3oool010000000oooo0?ooo`0000080?oo
o`030000003oool0oooo00<0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`1W0?oo
o`030000003oool0oooo06H0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000:
0?ooo`<000002P3oool2000000P0oooo00<000000?ooo`3oool00P3oool010000000oooo00000000
000B0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00l0oooo0P000002
0?ooo`8000001@3oool01@000000oooo0000003oool0000000H0oooo00@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo0P0000040?ooo`030000
003oool0oooo06H0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`040?ooo`040000
003oool0oooo000000X0oooo0`00000:0?ooo`800000203oool2000000@0oooo0`00000C0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0100oooo0P0000020?ooo`800000
1@3oool2000000030?ooo`000000oooo00H0oooo00@000000?ooo`3oool00000203oool00`000000
oooo0?ooo`030?ooo`030000003oool0000000@0oooo0P0000040?ooo`030000003oool0oooo06D0
oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`030?ooo`8000000`3oool00`000000
oooo0?ooo`080?ooo`<000002P3oool2000000P0oooo00<000000?ooo`3oool00`3oool3000001<0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0403oool200000080oooo
0P0000050?ooo`80000000<0oooo0000003oool01P3oool010000000oooo0?ooo`0000080?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`000000103oool2000000@0oooo00<000000?ooo`3o
ool0I03oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`080?ooo`<000002`3oool2000000P0oooo00<000000?ooo`3o
ool00P3oool010000000oooo00000000000C0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo0100oooo0P0000020?ooo`8000001P3oool010000000oooo0?ooo`0000070?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo00000004
0?ooo`800000103oool2000006@0oooo00<000000?ooo`3oool0H@3oool2000000D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`<000002P3oool2000000T0oooo00<00000
0?ooo`3oool00P3oool2000000030?ooo`000000oooo0180oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool0403oool3000000040?ooo`000000oooo000000D0oooo0P000000
0`3oool000000?ooo`060?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000040?ooo`8000001@3oool00`000000oooo0?ooo`1Q0?ooo`030000
003oool0oooo0600oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool0
203oool3000000/0oooo0P0000080?ooo`800000103oool3000001@0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool04@3oool200000080oooo0P0000050?ooo`8000000P3o
ool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`0000030?ooo`8000001P3oool00`000000oooo0?ooo`1P0?ooo`03
0000003oool0oooo05l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00P0oooo00@000000?ooo`00000000002P3oool2000000T0oooo00<000000?oo
o`3oool00P3oool010000000oooo00000000000D0?ooo`030000003oool0oooo0080oooo001;0?oo
o`8000004P3oool200000080oooo0P0000060?ooo`040000003oool0oooo000000L0oooo00D00000
0?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P00
00020?ooo`8000001P3oool200000600oooo00<000000?ooo`3oool0G@3oool2000000@0oooo0P00
00060?ooo`030000003oool0oooo00P0oooo00@000000?ooo`00000000002`3oool2000000T0oooo
00<000000?ooo`3oool00P3oool400000180oooo0`0000040?ooo`00B`3oool00`000000oooo0?oo
o`0A0?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`80000000<0oooo0000003o
ool01`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo0P0000020?oo
o`030000003oool0oooo008000001`3oool2000005h0oooo00<000000?ooo`3oool0G03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool01000
0000oooo0?ooo`00000<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool2
000000030?ooo`000000oooo01<0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool04P3oool2000000040?ooo`000000oooo000000H0oooo00@000000?ooo`3oool000001`3o
ool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool01P3oool010000000oooo
0?ooo`0000020?ooo`800000203oool2000005`0oooo00<000000?ooo`3oool0FP3oool2000000@0
oooo0P0000080?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000303oool20000
00T0oooo00<000000?ooo`3oool00P3oool010000000oooo00000000000E0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo0180oooo0P0000020?ooo`030000003oool00000
00D0oooo0P0000000`3oool000000?ooo`070?ooo`050000003oool0oooo0?ooo`000000203oool0
0`000000oooo0?ooo`060?ooo`040000003oool0oooo00000080oooo0`0000080?ooo`800000FP3o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0080oooo0P0000090?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00P00000<0?ooo`030000003oool0oooo00L0oooo0P00
00040?ooo`040000003oool00000000001D0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool04P3oool01`000000oooo0000003oool000000?ooo`0000001P3oool010000000
oooo0?ooo`0000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`070?ooo`80000000@0oooo000000000000oooo0`0000090?ooo`800000F03oool0
0`000000oooo0?ooo`1G0?ooo`8000000`3oool2000000X0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`02000000`0oooo0P0000090?ooo`030000003oool0oooo00<0oooo0P000000
0`3oool000000?ooo`0D0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
0180oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo0P000000
0`3oool000000?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080000000<0oooo0000000000002P3oool2
000005H0oooo00<000000?ooo`3oool0E@3oool200000080oooo0`00000;0?ooo`030000003oool0
oooo00L0oooo00H000000?ooo`3oool000000?ooo`00000<0?ooo`800000203oool2000000@0oooo
00D000000?ooo`000000oooo0000000E0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo01<0oooo0P0000001@3oool000000?ooo`3oool0000000D0oooo0P0000020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00P0oooo0P0000020?ooo`030000003oool00000008000002P3oool400000580
oooo00<000000?ooo`3oool0D`3oool200000080oooo0P00000=0?ooo`030000003oool0oooo00L0
oooo00H000000?ooo`3oool000000?ooo`00000<0?ooo`8000002@3oool00`000000oooo0?ooo`03
0?ooo`@000005P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0C0?oo
o`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00X0oooo0P0000001P3oool00000000000000000oooo000000d0oooo0`00001?0?ooo`03
0000003oool0oooo0540oooo0P000000103oool0000000000000000>0?ooo`030000003oool0oooo
00L0oooo00H000000?ooo`3oool000000?ooo`00000<0?ooo`<00000203oool2000000D0oooo0P00
00000`3oool000000?ooo`0E0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo01<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo0P00
00020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00/0oooo0P0000000`3oool0000000000003000000h0oooo0`00
001<0?ooo`030000003oool0oooo04l0oooo1@00000@0?ooo`030000003oool0oooo00L0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`8000002@3oool00`000000oooo
0?ooo`030?ooo`050000003oool000000?ooo`0000005P3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0C0?ooo`<000000P3oool00`000000oooo000000060?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00`0oooo0P0000001@3oool000000000003oool000000100oooo0`0000190?oo
o`030000003oool0oooo04`0oooo1@00000B0?ooo`030000003oool0oooo00L0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`<00000203oool2000000D0oooo0P000000
0`3oool000000?ooo`0F0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
01@0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo0P000002
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00h0oooo1`00000A0?ooo`@00000A@3oool00`000000oooo0?ooo`19
0?ooo`@000005@3oool00`000000oooo0?ooo`060?ooo`80000000<0oooo0000000000000P3oool0
0`000000oooo0?ooo`0:0?ooo`<000002@3oool00`000000oooo0?ooo`040?ooo`80000000<0oooo
0000003oool05P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool000000080oooo00<000000?ooo`0000001@3oool2000000<0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0403oool800000140oooo0`00000]0?ooo`X000002`3oool00`000000oooo0?ooo`110?oo
o`T000005`3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo000000080?ooo`8000001P3oool010000000oooo0?ooo`00
000G0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01@0oooo0`000002
0?ooo`040000003oool0oooo000000D0oooo0P0000020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo1000
00000`3oool0000000000005000000d0oooo1000000B0?ooocD000002`3oool`000000<0oooo0`00
000I0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`0;0?ooo`80000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`040?ooo`800000
00<0oooo0000003oool05`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`0E0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`800000
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0B0?ooo`T000000P3oool;000000H0oooo7P00000P0?ooo`L00000
0P3oool;000002l0oooo1000000J0?ooo`8000001`3oool200000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0000000P0oooo0P0000060?ooo`040000
003oool0oooo000001P0oooo00<000000?ooo`3oool00P3oool004/0oooo0P00000F0?ooo`<00000
0P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0503oool010000000oooo0000000000030?ooo`L000001P3ooolH000002`0oooo00@000000?oo
o`3oool0oooo2@0000030?ooo`H00000:@3oool4000001d0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`02000000@0oooo00<000000?ooo`3oool02`3oool2000000030?ooo`000000
oooo00L0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`00000F0?ooo`<00000103o
ool004/0oooo00<000000?ooo`3oool05P3oool200000080oooo00@000000?ooo`3oool000001@3o
ool2000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`8000001@3o
ool00`000000oooo0?ooo`0D0?ooo`80000000<0oooo0000003oool0203oool=000000X0oooo1`00
000Z0?ooo`H000002@3oool6000000<0oooo1P00000O0?ooo`@00000803oool00`000000oooo0?oo
o`050?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo0P00
00000`3oool000000?ooo`070?ooo`8000001P3oool2000000030?ooo`000000oooo01P0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool05P3oool300000080oooo00<00000
0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00@00000
0?ooo`00000000009@3oool6000001h0oooo1P0000020?ooo`030000003oool0oooo0100oooo1`00
00020?ooo`H000005@3oool400000280oooo0P0000060?ooo`8000000P3oool2000000D0oooo00<0
00000?ooo`3oool0303oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00D0oooo
00@000000?ooo`3oool000006@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`0G0?ooo`8000000P3oool010000000oooo0?ooo`0000050?ooo`800000103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0E0?ooo`80000000<0oooo000000000000:@3oool6000001<0oooo1@0000080?ooo`03
0000003oool0oooo01L0oooo1P0000020?ooo`@000003@3oool4000002D0oooo00<000000?ooo`3o
ool00`3oool300000080oooo0P0000060?ooo`030000003oool0oooo00`0oooo0P0000000`3oool0
00000?ooo`070?ooo`8000001P3oool200000080oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0G0?ooo`<000000P3oool00`000000oooo
000000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`070?ooo`800000103oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo000000000000
;@3oool5000000X0oooo1000000=0?ooo`030000003oool0oooo01d0oooo2`0000030?ooo`D00000
:03oool00`000000oooo0?ooo`020?ooo`8000000`3oool2000000P0oooo00<000000?ooo`3oool0
303oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3o
ool000006P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0H0?ooo`80
00000P3oool010000000oooo0?ooo`0000050?ooo`800000103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?oo
o`80000000<0oooo000000000000<03oool5000000030?ooo`0000000000008000004@3oool00`00
0000oooo0?ooo`0S0?ooo`/00000:03oool200000080oooo0`0000030?ooo`8000002@3oool00`00
0000oooo0?ooo`0<0?ooo`80000000<0oooo0000003oool01`3oool2000000H0oooo0P0000020?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool0603oool300000080oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`80
00006@3oool2000000030?ooo`000000000002l0oooo2P00000@0?ooo`030000003oool0oooo02<0
oooo2@0000020?ooo`H000008@3oool5000000<0oooo0`00000:0?ooo`030000003oool0oooo00`0
oooo0P0000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool01@000000
oooo0?ooo`3oool0000001X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool06@3oool200000080oooo00@000000?ooo`3oool000001@3oool2000000D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`800000103oool00`000000oooo0?ooo`0H0?oo
o`H00000:03oool4000000X0oooo1@00000;0?ooo`030000003oool0oooo01l0oooo100000090?oo
o`@00000103oool9000001D0oooo100000050?ooo`800000303oool00`000000oooo0?ooo`0<0?oo
o`050000003oool000000?ooo`000000203oool2000000H0oooo0P0000020?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool06@3oool30000
0080oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool02P3oool2000000<0oooo00<000000?ooo`3oool06P3oool20000
00040?ooo`000000000000000200oooo1@00000C0?ooo`@000001`3oool00`000000oooo0?ooo`0K
0?ooo`@000004@3oool4000000T0oooo5P0000050?ooo`<000003@3oool00`000000oooo0?ooo`0;
0?ooo`80000000@0oooo0000003oool000002@3oool00`000000oooo0?ooo`050?ooo`8000000P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo01X0oooo0P0000020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo0P0000020?ooo`030000003o
ool0oooo01/0oooo0P0000020?ooo`8000006@3oool5000001`0oooo100000030?ooo`030000003o
ool0oooo01L0oooo1000000I0?ooo`l00000303oool9000000l0oooo00<000000?ooo`3oool02`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00H0oooo0P0000060?ooo`800000
0P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo01X0oooo0`0000020?ooo`030000003oool0000000H0oooo0P0000050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0303oool2000000030?ooo`000000oooo01d0oooo0`00
0000103oool0000000000000000B0?ooo`@000009@3oool4000001D0oooo1000000/0?ooo`d00000
5P3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`050?ooo`8000000P3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01/0oooo0P0000020?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00h0oooo0`00000P0?ooo`<0000000@0oooo00000000000000002`3oool40000
02`0oooo1000000>0?ooo`@00000>03oool2000001P0oooo00<000000?ooo`3oool02`3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000002@3oool2000000H0oooo0P0000020?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool06`3oool3
00000080oooo00<000000?ooo`0000001P3oool2000000D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0@0?ooo`8000008@3oool3000000040?ooo`0000000000000000@0oooo1000
000`0?ooo`040000003oool0oooo0?ooo`<000001`3oool4000003X0oooo0P00000I0?ooo`030000
003oool0oooo00/0oooo00L000000?ooo`3oool0oooo0000003oool0000000T0oooo0P0000070?oo
o`8000000P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo01`0oooo0P0000020?ooo`040000003oool0oooo000000H0oooo0P0000050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool400000200oooo0`0000000`3o
ool0000000000002000003@0oooo00<000000?ooo`3oool0103oool7000003/0oooo0`00000J0?oo
o`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00L0oooo0P0000060?ooo`8000000P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo01`0oooo0`0000020?ooo`040000003oool0oooo
000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool01P00000E0?ooo`/0000000<0oooo0000000000000P00000a
0?ooo`030000003oool0oooo00<0oooo10000000103oool0000000000000000i0?ooo`800000703o
ool00`000000oooo0?ooo`0:0?ooo`8000000`3oool010000000oooo0?ooo`0000090?ooo`800000
1`3oool200000080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`00B`3o
ool2000001h0oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000001@3oool2000000H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo
5@00000;0?ooo`<000000P3oool3000002h0oooo00<000000?ooo`0000000`0000080?ooo`@00000
<`3oool2000001d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000T0oooo00<000000?ooo`0000001P3oool200000080oooo00<000000?ooo`3oool0
6`3oool3000000@0oooo001;0?ooo`030000003oool0oooo01d0oooo0`0000020?ooo`040000003o
ool0oooo000000H0oooo0P0000060?ooo`8000001@3oool00`000000oooo0?ooo`0B0?ooo`800000
:03oool300000080oooo0`00000Y0?ooo`@00000403oool4000002`0oooo0`00000N0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000090?ooo`030000
003oool0000000H0oooo0`0000000`3oool000000?ooo`0O0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo01h0oooo0P0000020?ooo`050000003oool0oooo0?ooo`000000
1@3oool00`000000oooo000000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0X0?ooo`<000000P3oool300000280oooo100000020?ooo`030000
003oool0oooo01<0oooo1000000V0?ooo`800000803oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`0000002@3oool00`000000oooo000000070?ooo`800000
0P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo01h0oooo0`0000020?ooo`050000003oool0oooo0?ooo`0000001@3oool2000000P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`800000:`3oool300000080oooo
0`00000K0?ooo`@000001P3oool00`000000oooo0?ooo`0G0?ooo`@00000803oool200000200oooo
0P00000;0?ooo`8000001@3oool010000000oooo0?ooo`0000080?ooo`030000003oool0000000L0
oooo0P0000020?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool07`3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0D0?ooo`800000;03oool300000080oooo1000000C0?ooo`@000002P3oool00`000000oooo
0?ooo`0K0?ooo`@000006@3oool300000240oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0000000T0oooo00<000000?ooo`0000001`3oool200000080oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`0O0?ooo`<000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`000000
203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
;03oool3000000<0oooo1000000<0?ooo`<000003P3oool00`000000oooo0?ooo`0O0?ooo`@00000
4P3oool3000002<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0000000T0oooo00<000000?ooo`0000001`3oool200000080oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0P0?ooo`8000000`3o
ool01@000000oooo0?ooo`3oool0000000D0oooo0P0000090?ooo`800000103oool00`000000oooo
0?ooo`0E0?ooo`800000;`3oool4000000<0oooo0`0000050?ooo`@000004@3oool00`000000oooo
0?ooo`0S0?ooo`<000002`3oool4000002@0oooo0P00000;0?ooo`8000001`3oool00`000000oooo
000000090?ooo`030000003oool0000000P0oooo00D000000?ooo`3oool0oooo0000000R0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0200oooo0`0000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000X0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0F0?ooo`800000<@3oool3000000<0oooo1@00000E0?ooo`030000
003oool0oooo02H0oooo100000040?ooo`<000009`3oool00`000000oooo0?ooo`090?ooo`800000
203oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000L0oooo00D000000?oo
o`3oool0oooo0000000S0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
0240oooo0P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0000000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool20000
0380oooo1@0000020?ooo`<000004`3oool00`000000oooo0?ooo`0Z0?ooo`@00000:03oool20000
00T0oooo0`00000:0?ooo`030000003oool0000000P0oooo00@000000?ooo`3oool000001`3oool2
00000080oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`00
0000oooo0?ooo`0Q0?ooo`<000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo0P00000;
0?ooo`8000000`3oool2000001T0oooo0P00000^0?ooo`<000000P3oool3000000@0oooo1000000?
0?ooo`030000003oool0oooo02L0oooo100000030?ooo`@000008`3oool00`000000oooo0?ooo`06
0?ooo`<00000303oool00`000000oooo000000090?ooo`030000003oool0000000P0oooo00@00000
0?ooo`3oool000009@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0R
0?ooo`800000103oool01@000000oooo0?ooo`3oool0000000D0oooo0P00000<0?ooo`8000000`3o
ool00`000000oooo0?ooo`0H0?ooo`800000:03oool4000000P0oooo100000040?ooo`@000002`3o
ool00`000000oooo0?ooo`0T0?ooo`<000002`3oool6000001`0oooo00@000000?ooo`3oool0oooo
1P00000>0?ooo`030000003oool0000000T0oooo00<000000?ooo`000000203oool200000080oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`8000003@3oool200000080oooo00<000000?ooo`3oool06@3oool2000002<0oooo0`00
000@0?ooo`<000001@3oool3000000P0oooo00<000000?ooo`3oool0803oool4000001@0oooo2`00
000=0?ooo`P000004`3oool00`000000oooo000000090?ooo`040000003oool0oooo000000L0oooo
0P0000020?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool08`3oool3000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`8000003P3oool4000001`0oooo0P00000M0?ooo`@000005P3oool3000000D0oooo1000
00040?ooo`030000003oool0oooo01d0oooo0`00000S0?ooo`l000005`3oool4000000T0oooo00@0
00000?ooo`3oool000001`3oool01@000000oooo0000003oool0000002L0oooo00<000000?ooo`3o
ool00P3oool004/0oooo00<000000?ooo`3oool0903oool2000000@0oooo00D000000?ooo`3oool0
oooo000000060?ooo`800000403oool3000001`0oooo0`00000F0?ooo`@000007@3oool4000000D0
oooo1@00000K0?ooo`@00000<@3oool2000001P0oooo00<000000?ooo`0000002@3oool200000080
oooo00<000000?ooo`3oool01P3oool2000000030?ooo`000000oooo02L0oooo00<000000?ooo`3o
ool00P3oool004/0oooo0P00000V0?ooo`800000103oool01@000000oooo0?ooo`3oool0000000D0
oooo00<000000?ooo`0000004@3oool3000001d0oooo0P00000>0?ooo`H000009@3oool4000000D0
oooo1000000E0?ooo`<00000<`3oool2000001T0oooo00<000000?ooo`0000002@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0`0000000`3oool000000?ooo`0U0?ooo`<0
0000103oool004/0oooo00<000000?ooo`3oool09P3oool2000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000140oooo00<000000?ooo`000000
0P00000L0?ooo`<000001@3oool6000002l0oooo100000000`3oool000000?ooo`020?ooo`<00000
3P3oool4000003@0oooo0P00000I0?ooo`80000000<0oooo0000003oool0203oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo0`0000000`3oool000000?ooo`0X0?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02L0oooo0P0000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000A0?ooo`8000000P3o
ool5000001T0oooo1P00000i0?ooo`@00000103oool4000000L0oooo0`00000e0?ooo`<000006P3o
ool010000000oooo0?ooo`0000080?ooo`800000103oool00`000000oooo0?ooo`050?ooo`<00000
00<0oooo0000003oool0:@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool000000180oooo0P0000050?ooo`T00000203oool8000000<0oooo0`00
000j0?ooo`030000003oool0oooo00@00000103oool7000003H0oooo0P00000L0?ooo`040000003o
ool0oooo000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`<00000
00<0oooo0000003oool0:P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`0X0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`800000103oool010000000oooo0000
0000000B0?ooo`030000003oool0oooo00/0oooo2000000>0?ooo`800000>03oool00`000000oooo
0?ooo`040?ooo`L0000000<0oooo0000000000000P00000c0?ooo`800000703oool2000000030?oo
o`000000000000L0oooo0P0000060?ooo`030000003oool0oooo00D0oooo0`0000000`3oool00000
0?ooo`0Z0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02T0oooo0`00
00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`00000B0?ooo`8000008`3oool3000003D0oooo00<000000?ooo`3oool0103oool3000000030?oo
o`000000000000800000103oool4000002`0oooo0`00000M0?ooo`040000003oool0oooo000000L0
oooo0P0000070?ooo`030000003oool0oooo00D0oooo0`0000000`3oool000000?ooo`0[0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02X0oooo0`0000030?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool08`3oool400000340oooo00<000000?ooo`3oool0100000080?ooo`@0
0000103oool3000002H0oooo0`00000O0?ooo`040000003oool0oooo000000H0oooo0P0000080?oo
o`030000003oool0oooo00D0oooo0`0000000`3oool000000?ooo`0/0?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo02/0oooo0`0000030?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0140oooo0P00000W0?oo
o`@00000;@3oool300000100oooo100000030?ooo`@000007`3oool300000200oooo0P0000020?oo
o`030000003oool0oooo00<0oooo0P0000080?ooo`8000001`3oool3000000030?ooo`000000oooo
02d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0;03oool3000000<0
oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool04P3oool2000002T0oooo1000000U0?ooo`D000005P3oool4000000<0oooo1000000H0?oo
o`<000008@3oool200000080oooo0P0000040?ooo`8000002@3oool00`000000oooo0?ooo`050?oo
o`@000000P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0080oooo000k0?ooo`03
0?oo_`1d000000000080000000<0B9cO0?ooo`3oool0203oool00`000000oooo0?ooo`0]0?ooo`<0
00000P3oool00`000000oooo0?ooo`040?ooo`8000000P3oool200000080oooo00<000000?ooo`3o
ool04`3oool2000002/0oooo0`00000O0?ooo`<00000103oool00`000000oooo0?ooo`0H0?ooo`<0
0000103oool400000140oooo0`00000S0?ooo`030000003oool0oooo008000000P3oool4000000X0
oooo00<000000?ooo`3oool01@3oool01`000000oooo0000003oool000000?ooo`000000;`3oool0
0`000000oooo0?ooo`020?ooo`00?@3oool00`3o_g@0000007Boo`0;0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0D0?ooo`800000;03oool4000001L0oooo10000007
0?ooo`030000003oool0oooo01/0oooo100000040?ooo`@000002P3oool3000002@0oooo0P000000
103oool000000000003oool3000000<0oooo0P0000080?ooo`030000003oool0oooo00D0oooo00L0
00000?ooo`000000oooo0000003oool000000300oooo00<000000?ooo`3oool00P3oool003d0oooo
00<0oooO09a80000M;l02`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool000000080oooo
00<000000?ooo`3oool01@3oool200000080oooo0P0000000`3oool000000?ooo`0F0?ooo`800000
;P3oool4000000l0oooo1000000;0?ooo`030000003oool0oooo01l0oooo100000040?ooo`H00000
00@0oooo00000000000000009@3oool200000080oooo100000030?ooo`<000002@3oool00`000000
oooo0?ooo`040?ooo`80000000H0oooo0000003oool000000?ooo`00000a0?ooo`030000003oool0
oooo0080oooo000n0?ooo`030=nLB000B9`0gooo00X0oooo00<000000?ooo`3oool0;`3oool20000
00050?ooo`000000oooo0?ooo`000000203oool200000080oooo1000000G0?ooo`800000<03oool4
000000L0oooo1000000?0?ooo`030000003oool0oooo02<0oooo100000030?ooo`T000008P3oool0
0`000000oooo00000003000000@0oooo0P00000:0?ooo`8000001P3oool020000000oooo0?ooo`00
0000oooo0000003oool00000<P3oool00`000000oooo0?ooo`020?ooo`00?P3oool00`3ogi`0B018
09cOo`0:0?ooo`030000003oool0oooo0300oooo0P0000001@3oool000000?ooo`3oool0000000T0
oooo0P0000020?ooo`030000003oool0000001P0oooo0`00000a0?ooo`L000004`3oool00`000000
oooo0?ooo`0V0?ooo`L000001P3oool;00000100oooo2P0000040?ooo`<000002`3oool00`000000
oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`8000000P3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0080oooo000n0?ooo`030?oo_`1d0000M;oo00X0oooo0`00000a0?ooo`80
000000D0oooo0000003oool0oooo0000000:0?ooo`H000006P3oool2000002d0oooo100000020?oo
o`@000004P3oool00`000000oooo0?ooo`0S0?ooo`<000001`3oool8000000T0oooo400000030?oo
o`80000000<0oooo0000000000000`3oool3000000d0oooo00<000000?ooo`3oool01@3oool01000
0000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool0;P3oool4000000@0oooo000o0?oo
o`030;md0000M;l0oooo00T0oooo00<000000?ooo`3oool0<P3oool010000000oooo0?ooo`000002
0?ooo`8000002`3oool5000001X0oooo0P00000W0?ooo`@000002P3oool4000000h0oooo00<00000
0?ooo`3oool07`3oool400000180oooo3000000>0?ooo`X000003`3oool00`000000oooo0?ooo`04
0?ooo`8000000`3oool200000080oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`02
0?ooo`00?`3oool00`3OW4P004RL0=ooo`090?ooo`030000003oool0oooo03<0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`0;0?ooo`<000006`3oool300000200oooo1000000B
0?ooo`@000002P3oool00`000000oooo0?ooo`0K0?ooo`@000008P3ooolA000001D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`80000000<0oooo000000000000=@3oool0
0`000000oooo0?ooo`020?ooo`00?`3oool00`3ogi`0B01809cOo`090?ooo`030000003oool0oooo
03@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0<0?ooo`@000006`3oool3
000001T0oooo1000000J0?ooo`@000001P3oool00`000000oooo0?ooo`0H0?ooo`<00000;`3oool3
000000030?ooo`000000000001D0oooo0P0000060?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000=`3oool00`000000oooo0?ooo`020?ooo`00?`3oool00`3ookl0M00007Boo`09
0?ooo`030000003oool0oooo03D0oooo0P0000000`3oool00000000000020?ooo`8000003P3oool5
000001/0oooo0`00000@0?ooo`H000008P3oool5000000030?ooo`000000oooo01D0oooo1000000`
0?ooo`8000000P3oool2000001H0oooo00<000000?ooo`3oool0103oool2000000<0oooo0P000000
0`3oool000000000000h0?ooo`030000003oool0oooo0080oooo00100?ooo`030;md0000M;l0oooo
00P0oooo00<000000?ooo`3oool0=P3oool200000080oooo00D000000?ooo`3oool0oooo0000000>
0?ooo`<0000000<0oooo0000000000001000000H0?ooo`@00000103oool8000002d0oooo1000000@
0?ooo`@00000<@3oool300000080oooo0P00000F0?ooo`8000001P3oool00`000000oooo0?ooo`02
0?ooo`80000000<0oooo0000003oool0>@3oool00`000000oooo0?ooo`020?ooo`00?P3oool01@3o
okl0M0000000000007@0_ooo00P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`02
00000080oooo00<000000?ooo`3oool03@3oool3000000D0oooo2000000<0?ooo``00000=P3oool0
0`000000oooo0?ooo`05000000L0oooo1000000c0?ooo`8000000P3oool3000001H0oooo0P000006
0?ooo`8000000`3oool5000003/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool0>@3oool200000080oooo0P0000000`3oool000000000000?0?ooo`<000002`3oool<0000
00/0oooo0`00000d0?ooo`030000003oool0oooo00D0oooo1`00000d0?ooo`<000000P3oool20000
01L0oooo0P0000060?ooo`800000103oool4000003d0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool0>P3oool2000000<0oooo00@000000?ooo`3oool00000403oool30000
02<0oooo1000000`0?ooo`030000003oool0oooo0080oooo1@0000020?ooo`D00000;P3oool40000
00<0oooo0P00000G0?ooo`8000001@3oool3000000@0oooo0`0000000`3oool000000?ooo`0m0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo03/0oooo0P0000030?ooo`80
000000<0oooo000000000000403oool3000002D0oooo1000000/0?ooo`D00000303oool4000002L0
oooo0`0000040?ooo`<000005`3oool2000000D0oooo0P0000060?ooo`80000000<0oooo00000000
0000?`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0m0?ooo`800000
0`3oool2000000030?ooo`000000oooo0100oooo0`00000W0?ooo`D000008P3oool6000001@0oooo
1@00000N0?ooo`@000000`3oool4000001P0oooo0P0000040?ooo`<000001P3oool3000000030?oo
o`000000oooo0400oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0?P3o
ool2000000@0oooo0`00000B0?ooo`@00000:@3oool4000001T0oooo1@0000050?ooo`030000003o
ool0oooo01L0oooo1000000F0?ooo`@000000`3oool4000001X0oooo0P0000030?ooo`<00000203o
ool2000000030?ooo`00000000000480oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool0?`3oool2000000D0oooo0`00000B0?ooo`@00000:`3oool5000000l0oooo1@00000:
0?ooo`030000003oool0oooo01/0oooo2000000:0?ooo`@000000`3oool4000001`0oooo0P000003
0?ooo`8000002@3oool200000080oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`110?ooo`8000001P3oool200000180oooo1@00000]0?oo
o`H000000`3oool6000000l0oooo00<000000?ooo`3oool08`3oool:000000<0oooo1000000M0?oo
o`P000002@3oool200000080oooo0P0000150?ooo`030000003oool0oooo0080oooo001;0?ooo`80
0000A03oool2000000H0oooo1000000@0?ooo`H00000;@3oool900000180oooo00<000000?ooo`3o
ool0903oool4000000<0oooo1P00000J0?ooo`P000003@3oool3000000030?ooo`000000000004D0
oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`150?ooo`<000001@3oool7000000l0oooo
1P00000R0?ooo`L000002@3oool6000000`0oooo00<000000?ooo`3oool07`3oool5000000030?oo
o`000000000000@000001P3ooolJ000000040?ooo`0000000000000000l0oooo0`0000000`3oool0
0000000000190?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo04L0oooo
100000040?ooo`8000000`3oool5000000h0oooo1P00000F0?ooo`P000005P3oool6000000H0oooo
00<000000?ooo`3oool06P3oool;000002D0oooo0P00000@0?ooo`H00000B`3oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1:0?ooo`<00000103oool2000000H0oooo1@00
000=0?ooo`P000001`3oool9000002@0oooo1`00000F0?ooo`X00000:@3oool3000000l0oooo1P00
001>0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo04`0oooo10000003
0?ooo`<00000203oool7000000X0oooo2`00000c0?ooo`L000002P3oool9000002`0oooo1000000@
0?ooo`H00000D03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1>0?oo
o`D000000`3oool3000000`0oooo2`0000030?ooo`/00000;`3oool00`000000oooo0?ooo`040?oo
o`d00000;P3oool400000180oooo1@00001C0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo0540oooo1@0000030?ooo`@000006`3oool5000000030?ooo`000000000000D0
0000:03oool00`000000oooo0?ooo`0B000002P0oooo1@00000C0?ooo`@00000E`3oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1C0?ooo`P000000P3oool4000001`0oooo
4P00000I0?ooo``000003P3oool8000001T0oooo1`00000@0?ooo`T00000FP3oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1H0?ooo`h000007`3ooolD000000L0oooo3P00
000L0?ooo`X00000203oool7000000d0oooo3`00001N0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo05h0oooo3P00000T0?oooaH000001`3oool00`000000oooo0?ooo`0T
0?oooa`000001P3oool600000640oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool0I03oool@000001<0oooo4P0000000`3oool000000000000D000001X0oooo2P00000M0?oo
o`L00000I@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1Z0?oooal0
0000703ooolU000001`0oooo3000001[0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo07`0oooo>@00000:0?ooob`00000LP3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool00P3o
ool004/0oooo0P00002^0?ooo`030000003oool0oooo0:/0oooo0`0000040?ooo`00B`3oool00`00
0000oooo0?ooo`2]0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0[@3oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`020?ooo`00B`3oool010000000oooo0?ooo`00
000<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo000000040?ooo`00B`3o
ool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0
oooo000000040?ooo`00B`3ooooo000006800000103oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00<h0oooo00T0oono
07@000000000B9cO0?ooo`3ookl0M00000000018W=l0503oool00`3o_g@000000000000200000003
0018W03Oool0oooo0180oooo00D0_g@0000000000000000004RLg`2V0?ooo`00cP3oool02P3ookl0
M01809cOo`2oM00007Bo0?oo_`1d04P0W=oo0;md0000M;lB0?ooo`030?noM0000000B9cO00<0oooo
00<0omnL04P0B02Lgol04`3oool00`3ooml0W4P004RLg`2W0?ooo`00d@3oool00`3ookl0M00007Bo
o`020?ooo`030?oo_`1d0000M;oo0140oooo00<0okmd0000M02oool0103oool00`3OW4P007Bo0?oo
o`0C0?ooo`030=nLB000B9`0gooo0:H0oooo003B0?ooo`030=nLB000B9`0gooo0080oooo00<0gia8
0018W03Oool04@3oool0202oM000001d0;ooo`3oool0oooO09a800000000B9cO503oool00`3ogi`0
B01d0;ooo`2V0?ooo`00^`3oool00`2oM000000000000005000000030018W03Oool0oooo00<0oooo
00`0omnL04P00000000004RL0=ooo`2oM0000000001d_`3oool0okmd0000B02Lgol20?ooo`030?no
M00004P0W=oo00<0oooo00P0_g@00000000004P0W=oo0?ooo`3OW4P004RL0=ooo`80oooo00<0_g@0
00000000M;l00P3oool01P3ookl0M000000000000000001d0;ooo`D0oooo00<0okmd000000000000
1`0000002@1d_ol0oooo0?oOW018000000000000M02ookl0M00007Boo`020?ooo`0;0?oOW0180000
00000018W03Oool0_g@000000000M;l0oooo0?oOW01800000P0000002@1d_ol0gia800000000B9`0
gooo0?noM0000000001809cOo`020?ooo`040;md00000000001809cOo`80oooo00D0okmd00000000
0000001809cOo`030?ooo`030=nLB000B9`0gooo0080oooo00<0_g@000000000M;l0MP3oool00;`0
oooo00@0oono07@00000B9`0gooo0`3oool00`2oM0000000001d_`030?ooo`0<0?oOW01804P0W=oo
0?oOW018M;l0_g@0001d_`3o_i`0W=oo0?oo_`1d0000B9cO0P3oool00`3ookl0M00004RLg`030?oo
o`080=nLB000B9`0gooO09adW03Oool0okmd0000M02oool20?ooo`080=nLB000B9`0gkmd07Boo`3o
ool0okmd0000M02oool90?ooo`040?oog`2LB00004RL0=ooo`<0oooo00/0oooO09a80000B9`0gooo
0;md0000B9`0gooo0?oo_`1d07@0M7@004RLg`020?ooo`0T0?oOW01804P0W=oo0?oOW018M;l0_g@0
001d_`3o_i`0W=oo0;md0000B9`0gooo0?ooo`2oM000M7Ad0000M02ogi`0W;oo0?noM00004P0W=oO
09adW03Oool0oooo0=nLB000B9`0gooO09adW03Oool0omnL04P0B02Lgol0oooo0?oOW018000007Bo
0P3oool00`3o_g@0001d0;ooo`020?ooo`040=nLB000B9`0gkmd07BoogD0oooo002m0?ooo`030=nL
B00004P0W=oo00@0oooo00d0oono07@00000B9`0gooo0?ooo`3ooml0W4P004RLg`3oool0okmd07Ad
M000B9`0gooo0080oooo00<0_g@00018W03Oool00P3oool00`2oM00004RL0=ooo`020?ooo`030?no
M00004P0W=oo0080oooo00<0oono07@00018W=l00P3oool00`3ogi`0B01809cOo`030?ooo`030;md
001d_ol0oooo00T0oooo00<0okmd0000B02Lgol01@3oool0103OW7@0W=oo0;md0000M;l20?ooo`0@
0?oo_`1d000004RL0=ooo`3oool0oooO09a80018W=l0oooo0?noM01dM7@004RL0=ooo`3oool0_g@0
001d_`<0oooo00L0_g@00000001d_ol0oooo0?oo_`1d0000M;oo00<0oooo00<0okmd0000B02Lgol0
0P3oool00`3OW4P004RL0=ooo`020?ooo`070?oOW0180000B9cO0?ooo`3ookl0M00004RLg`020?oo
o`030?oOW01804P0W=oo07H0oooo002m0?ooo`030?oOW0180000M;oo00D0oooo00<0omnL04P00000
M;l00P3oool01`2oM00004RL0=ooo`3oool0_g@00000B02Lgol00P3oool00`3OW4P0001d0;ooo`02
0?ooo`030=nLB00007@0_ooo0080oooo00<0oono07@00018W=l00P3oool0203ooml0W4P00000M02o
ool0oooo0?oog`2LB000B9cO0P3oool00`3ookl0M000000000020000000307Boo`3oool0oooo00D0
oooo00<0oono07@00018W=l01`3oool00`3OW4P004RL0=ooo`020?ooo`030?noM00007@0_ooo0080
oooo00/0_g@00018W03Oool0oooo0;md000004P0W=oo0?ooo`3o_g@0001d0;ooo`020?ooo`030?oo
_`1d0000B9cO0080oooo00<0_g@0001d_`3oool00P3oool00`3ookl0M00004RLg`020?ooo`030?no
M00007@0_ooo00<0oooo00/0gia80000M02oool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RL
g`1f0?ooo`00_@3oool00`3ookl0M000001d_`060?ooo`0;0;md000004P0W=oo0?ooo`3o_g@0001d
0;ooo`3oool0oono07@0001d_ol00P3oool00`3ogi`0B00007Boo`020?ooo`030?oOW0180000M;oo
00<0oooo00<0_g@00018W03Oool00P3oool00`3OW4P004Q804Qd_`020?ooo`0;0;md0000M;l0oooo
0?ooo`2oM00004RL0=ooo`3oool0omnL04P00018W=l01P3oool00`3ooml0W4P0001d_`020?ooo`03
0?oo_`2LW=l0oooo0080oooo00<0omnL04P0001d_ol00P3oool00`3ookl0M00007Boo`020?ooo`0;
0?noM00007@0_ooo0?ooo`3ookl0M00007Boo`3oool0oono07@0001d_ol00`3oool01`2oM00004RL
0=ooo`3oool0gia80018W03Oool00`3oool01`2oM00004RL0=ooo`3oool0oono07@0001d_ol00`3o
ool01`3ogi`0B01809cOo`3oool0gia80018B018M;l00P3oool00`2oM00007Bo0?ooo`1e0?ooo`00
_P3oool00`2oM00004RL0=ooo`050?ooo`070?noM0000000B9cO0?oOg`3Ookl0M00007Boo`020?oo
o`070;md0000M;l0oooo0?ooo`3ooml0W4P004RLg`020?ooo`030?oog`2LB000B9cO00<0oooo00<0
gia80000B02Lgol00P3oool02`3o_g@0001d0;noM018W=l0oooo0?noM00007@0_ooo0?ooo`2oM000
07Bo00<0oooo00<0gia80000M02oool01P3oool01P3OW4P0001d0;ooo`3oool0omnL04Qd_`@0oooo
00`0_g@00000M02oool0oooo0?oog`2LB000B9cO0?ooo`3ogml0gono07@0001d_ol20?ooo`070;md
0000M;l0oooo0?ooo`3o_g@0001d0;ooo`020?ooo`070=nLB00007@0_ooo0?ooo`3ogi`0B01809cO
o`030?ooo`030=nLB00004P0W=oo0080oooo00<0gia80000M02oool00P3oool0303ookl0M00007Bo
o`3oool0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;ooogD0oooo002n0?ooo`030?noM00004P0
W=oo00D0oooo00L0omnL04P00000M;l0omnL04Qd_`2oM00007Bo0080oooo00<0okmd0018W03Oool0
0P3oool00`2oM00004RL0=ooo`020?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0
0P3oool0303ooml0W4P007Boo`3OW4P007Bo0?oOW01804P0W=oo0?ooo`3ogi`0B00004RLg`80oooo
00<0gia80000M02oool01P3oool00`3o_g@0000000000002000000030000M02oool0oooo0080oooo
00`0oooO09a80000B9`0gooo0?oo_`2LB4P004RL0=ooo`3ogi`0B7Bo0;md0000M;l20?ooo`030?no
M000B9`0gooo0080oooo00/0gia80000M02oool0oooo0;md000004P0W=oo0?ooo`3ooml0W4P004RL
g`030?ooo`030?oOW0180000B9cO00<0oooo0100_g@00000M02oool0oooo0?noM00007@0_ooo0?oo
o`3ooml0W4P007Boo`3OW4P007Bo0?oOW01804P0W=ooM@3oool00;h0oooo00<0omnL04P0001d_ol0
1@3oool01`3ogi`0B000001d_`3oool0okmd00000000M;l00P3oool01@3ogi`0B01809cOo`3ookl0
M00000<0000000<0M;no07@0000000000P0000003`1d_ol0okmd00000000000004RL0=ooo`3ookl0
M00000000018W=l0oooo0?noM0000000001809cOo`020?ooo`030?oo_`1d0000000000@0000000<0
B9cO0?ooo`3oool00`3oool00`3ookl0M00007Boo`020?ooo`030;mdB02Lgol0oooo00@0oooo00X0
gia80000000007@0_kmd0000M02oool0oooo0?noM000000007Bo0P3oool00`3ogi`0B01809cOo`03
0?ooo`080?oOW0180000000004RLW01d0000B9cO0?oo_`1d00030000000607Boo`3o_g@000000000
0000B9`0gooo0`3oool03`3o_g@00000000000000000M;oo0?ooo`3ookl0M00000000018W=l0oooo
0?noM0000000001809cOo`1e0?ooo`00_P3oool00`3ooml0W4P0001d_`050?ooo`030?noM0000000
B9cO00/0oooo00<0okmd0000B02Lgol00P3oool00`3o_g@0001809cOo`0O0?ooo`060;md0000M;l0
oooo0?ooo`3ogi`0M9cO7`3oool00`3o_g@0001d0;ooo`2=0?ooo`00_`3oool00`2oM00004RL0=oo
o`030?ooo`040?oog`2LB000001d0;ooo`/0oooo00<0oooO09a80000M;l00P3oool00`3ooml0W4P0
001d_`0O0?ooo`030=nLB00007@0_ooo00@0oooo00<0gibL0;ooo`3oool0703oool00`3OW7@0W=oo
0?ooo`2<0?ooo`00_`3oool00`3OW4P0001809cOo`020?ooo`040?oo_`1d0000000007Boo`d0oooo
00<0okmd0000M02oool00P3oool00`3o_g@0001d0;ooo`020?ooo`040?oo_`1d000004RL0=oooaP0
oooo00<0okmd0000B02Lgol00`3oool00`3ookl0M01809cOo`0R0?ooo`040?oo_`1d000004RL0=oo
ohH0oooo002n0?ooo`030;md00000000000000@0000000<004RL0=ooo`3oool03P3oool02P3OW4P0
04RL0=oog`2LB000B9cO0=nLB000B9`0gooO09a80018W=lJ0?ooo`030;md00000000000000H00000
00<0M;oo0?ooo`3oool0ZP3oool00=L0oooo00T0gia80000000004P0W=oo0?ooo`3OW4P000000000
B02Lgol0d03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-1.88788, -1.6112, 0.0112806, \
0.0106351}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.500497 0.232588 0.499707 0.146774 [
[.03532 -0.0125 -9.34375 -15.6875 ]
[.03532 -0.0125 9.34375 0 ]
[.26791 -0.0125 -9.34375 -15.6875 ]
[.26791 -0.0125 9.34375 0 ]
[.5005 -0.0125 -5 -15.6875 ]
[.5005 -0.0125 5 0 ]
[.73309 -0.0125 -5 -15.6875 ]
[.73309 -0.0125 5 0 ]
[.96567 -0.0125 -5 -15.6875 ]
[.96567 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.9688 -31.375 ]
[.5 -0.0125 21.9688 -15.6875 ]
[-0.0125 .05939 -18.6875 -7.84375 ]
[-0.0125 .05939 0 7.84375 ]
[-0.0125 .20616 -18.6875 -7.84375 ]
[-0.0125 .20616 0 7.84375 ]
[-0.0125 .35293 -18.6875 -7.84375 ]
[-0.0125 .35293 0 7.84375 ]
[-0.0125 .49971 -10 -7.84375 ]
[-0.0125 .49971 0 7.84375 ]
[-0.0125 .64648 -10 -7.84375 ]
[-0.0125 .64648 0 7.84375 ]
[-0.0125 .79325 -10 -7.84375 ]
[-0.0125 .79325 0 7.84375 ]
[-0.0125 .94003 -10 -7.84375 ]
[-0.0125 .94003 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -34.375 -20.4688 ]
[-0.01875 .5 -18.6875 20.4688 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -43.9375 0 ]
[.5 1.0125 43.9375 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03532 0 m
.03532 .00625 L
s
gsave
.03532 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.26791 0 m
.26791 .00625 L
s
gsave
.26791 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5005 0 m
.5005 .00625 L
s
gsave
.5005 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.73309 0 m
.73309 .00625 L
s
gsave
.73309 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.96567 0 m
.96567 .00625 L
s
gsave
.96567 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.08184 0 m
.08184 .00375 L
s
.12836 0 m
.12836 .00375 L
s
.17487 0 m
.17487 .00375 L
s
.22139 0 m
.22139 .00375 L
s
.31443 0 m
.31443 .00375 L
s
.36094 0 m
.36094 .00375 L
s
.40746 0 m
.40746 .00375 L
s
.45398 0 m
.45398 .00375 L
s
.54702 0 m
.54702 .00375 L
s
.59353 0 m
.59353 .00375 L
s
.64005 0 m
.64005 .00375 L
s
.68657 0 m
.68657 .00375 L
s
.7796 0 m
.7796 .00375 L
s
.82612 0 m
.82612 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.91916 0 m
.91916 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.9688 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
102.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05939 m
.00625 .05939 L
s
gsave
-0.0125 .05939 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
0 .20616 m
.00625 .20616 L
s
gsave
-0.0125 .20616 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .35293 m
.00625 .35293 L
s
gsave
-0.0125 .35293 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .49971 m
.00625 .49971 L
s
gsave
-0.0125 .49971 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .64648 m
.00625 .64648 L
s
gsave
-0.0125 .64648 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .79325 m
.00625 .79325 L
s
gsave
-0.0125 .79325 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .94003 m
.00625 .94003 L
s
gsave
-0.0125 .94003 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08874 m
.00375 .08874 L
s
0 .1181 m
.00375 .1181 L
s
0 .14745 m
.00375 .14745 L
s
0 .1768 m
.00375 .1768 L
s
0 .23551 m
.00375 .23551 L
s
0 .26487 m
.00375 .26487 L
s
0 .29422 m
.00375 .29422 L
s
0 .32358 m
.00375 .32358 L
s
0 .38229 m
.00375 .38229 L
s
0 .41164 m
.00375 .41164 L
s
0 .441 m
.00375 .441 L
s
0 .47035 m
.00375 .47035 L
s
0 .52906 m
.00375 .52906 L
s
0 .55842 m
.00375 .55842 L
s
0 .58777 m
.00375 .58777 L
s
0 .61713 m
.00375 .61713 L
s
0 .67584 m
.00375 .67584 L
s
0 .70519 m
.00375 .70519 L
s
0 .73454 m
.00375 .73454 L
s
0 .7639 m
.00375 .7639 L
s
0 .82261 m
.00375 .82261 L
s
0 .85196 m
.00375 .85196 L
s
0 .88132 m
.00375 .88132 L
s
0 .91067 m
.00375 .91067 L
s
0 .03003 m
.00375 .03003 L
s
0 .00068 m
.00375 .00068 L
s
0 .96938 m
.00375 .96938 L
s
0 .99874 m
.00375 .99874 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -108 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
81.4688 11.8438 translate
90 rotate
-81.4688 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(velocity) show
99.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03532 .99375 m
.03532 1 L
s
.26791 .99375 m
.26791 1 L
s
.5005 .99375 m
.5005 1 L
s
.73309 .99375 m
.73309 1 L
s
.96567 .99375 m
.96567 1 L
s
.125 Mabswid
.08184 .99625 m
.08184 1 L
s
.12836 .99625 m
.12836 1 L
s
.17487 .99625 m
.17487 1 L
s
.22139 .99625 m
.22139 1 L
s
.31443 .99625 m
.31443 1 L
s
.36094 .99625 m
.36094 1 L
s
.40746 .99625 m
.40746 1 L
s
.45398 .99625 m
.45398 1 L
s
.54702 .99625 m
.54702 1 L
s
.59353 .99625 m
.59353 1 L
s
.64005 .99625 m
.64005 1 L
s
.68657 .99625 m
.68657 1 L
s
.7796 .99625 m
.7796 1 L
s
.82612 .99625 m
.82612 1 L
s
.87264 .99625 m
.87264 1 L
s
.91916 .99625 m
.91916 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .05939 m
1 .05939 L
s
.99375 .20616 m
1 .20616 L
s
.99375 .35293 m
1 .35293 L
s
.99375 .49971 m
1 .49971 L
s
.99375 .64648 m
1 .64648 L
s
.99375 .79325 m
1 .79325 L
s
.99375 .94003 m
1 .94003 L
s
.125 Mabswid
.99625 .08874 m
1 .08874 L
s
.99625 .1181 m
1 .1181 L
s
.99625 .14745 m
1 .14745 L
s
.99625 .1768 m
1 .1768 L
s
.99625 .23551 m
1 .23551 L
s
.99625 .26487 m
1 .26487 L
s
.99625 .29422 m
1 .29422 L
s
.99625 .32358 m
1 .32358 L
s
.99625 .38229 m
1 .38229 L
s
.99625 .41164 m
1 .41164 L
s
.99625 .441 m
1 .441 L
s
.99625 .47035 m
1 .47035 L
s
.99625 .52906 m
1 .52906 L
s
.99625 .55842 m
1 .55842 L
s
.99625 .58777 m
1 .58777 L
s
.99625 .61713 m
1 .61713 L
s
.99625 .67584 m
1 .67584 L
s
.99625 .70519 m
1 .70519 L
s
.99625 .73454 m
1 .73454 L
s
.99625 .7639 m
1 .7639 L
s
.99625 .82261 m
1 .82261 L
s
.99625 .85196 m
1 .85196 L
s
.99625 .88132 m
1 .88132 L
s
.99625 .91067 m
1 .91067 L
s
.99625 .03003 m
1 .03003 L
s
.99625 .00068 m
1 .00068 L
s
.99625 .96938 m
1 .96938 L
s
.99625 .99874 m
1 .99874 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .49971 m
1 .49971 L
s
.5005 0 m
.5005 1 L
s
gsave
.5 1.0125 -104.938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Duffing) show
102.938 15.813 moveto
(Equation) show
146.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.62876 .37829 m
.57975 .35609 L
.5181 .33146 L
.45689 .31022 L
.41928 .29973 L
.38295 .29249 L
.33863 .28923 L
.31623 .2908 L
.29192 .29577 L
.25036 .31542 L
.21667 .3484 L
.19157 .39465 L
.17748 .44751 L
.17374 .51635 L
.18353 .58318 L
.20752 .64825 L
.24003 .69831 L
.28789 .74386 L
.34078 .77597 L
.39498 .7988 L
.44825 .81583 L
.50984 .83147 L
.57779 .84441 L
.64853 .85102 L
.72452 .84419 L
.79271 .81531 L
.84725 .76235 L
.87463 .71599 L
.89477 .66393 L
.91005 .59827 L
.91752 .5219 L
.90851 .39092 L
.89161 .32188 L
.86876 .26435 L
.8098 .17896 L
.7417 .12745 L
.65798 .09414 L
.60856 .08222 L
.56257 .07386 L
.51657 .06716 L
.46716 .06137 L
.41233 .05685 L
.36141 .05533 L
.27019 .06459 L
.21996 .08115 L
.1753 .10735 L
.10217 .1919 L
.0535 .31784 L
.03369 .45938 L
.04155 .6209 L
Mistroke
.0832 .77265 L
.11886 .83803 L
.15697 .88384 L
.24222 .94031 L
.32992 .96451 L
.42842 .97381 L
.48485 .97538 L
.53754 .97545 L
.59316 .97389 L
.64353 .97014 L
.70093 .96118 L
.75382 .94556 L
.84097 .89149 L
.90778 .80116 L
.95637 .65494 L
.9682 .56748 L
.97026 .46714 L
.96048 .36794 L
.93811 .27383 L
.91041 .20592 L
.87277 .14706 L
.82546 .10137 L
.76991 .07084 L
.71464 .05557 L
.66334 .04986 L
.6109 .04931 L
.56273 .05176 L
.51028 .05645 L
.45552 .06304 L
.36567 .07878 L
.31641 .0922 L
.27208 .10958 L
.19606 .16027 L
.16242 .1974 L
.13033 .24851 L
.09028 .36281 L
.07592 .48827 L
.07866 .56091 L
.08994 .63324 L
.12918 .74122 L
.15962 .78604 L
.19203 .81743 L
.23085 .84125 L
.27477 .85622 L
.35088 .8633 L
.39394 .86064 L
.43324 .85556 L
.50359 .84209 L
.57475 .82378 L
.6347 .80329 L
Mistroke
.68682 .77857 L
.73811 .74244 L
.78403 .69032 L
.81647 .62671 L
.8341 .55883 L
.83828 .48119 L
.83372 .43958 L
.82556 .4046 L
.80178 .34997 L
.76592 .30777 L
.72565 .2841 L
.68565 .27421 L
.64596 .27298 L
.60919 .2771 L
.56998 .28547 L
.52991 .29704 L
.46197 .3215 L
.39743 .34978 L
.34079 .38216 L
.3158 .40169 L
.29662 .42148 L
.28276 .44111 L
.27362 .45985 L
.26763 .48073 L
.26589 .50234 L
.26683 .51344 L
.26876 .52314 L
.27222 .53379 L
.27662 .54323 L
.28695 .55845 L
.29407 .56612 L
.30137 .57264 L
.31882 .58481 L
.34088 .59633 L
.39335 .61726 L
.50676 .65872 L
.54619 .67205 L
.56674 .67824 L
.58642 .68345 L
.62446 .69085 L
.64503 .69292 L
.66706 .69319 L
.7069 .68687 L
.72839 .67846 L
.74707 .66714 L
.77745 .6364 L
.80144 .59007 L
.81367 .53818 L
.81575 .48443 L
.80701 .42425 L
Mistroke
.78518 .36402 L
.7525 .31328 L
.72966 .28884 L
.70586 .26884 L
.6521 .23604 L
.61906 .22116 L
.58734 .20919 L
.52799 .19086 L
.45941 .17439 L
.39182 .16349 L
.3277 .1609 L
.28906 .16511 L
.2482 .17662 L
.21142 .19585 L
.18001 .22202 L
.13029 .29627 L
.09782 .40724 L
.09115 .47376 L
.09245 .54739 L
.11676 .67331 L
.14421 .73875 L
.17753 .78991 L
.21237 .82656 L
.25442 .85727 L
.33144 .89169 L
.40883 .91153 L
.49731 .92619 L
.54828 .93232 L
.59557 .93628 L
.68589 .9359 L
.73651 .92767 L
.78233 .9119 L
.82837 .88403 L
.86679 .84671 L
.90538 .78789 L
.93439 .71692 L
.96256 .56957 L
.95939 .39914 L
.92994 .2671 L
.87386 .1557 L
.79435 .08112 L
.74429 .05662 L
.69651 .04227 L
.60076 .02844 L
.5082 .02403 L
.41034 .02427 L
.35547 .02767 L
.30558 .03464 L
.21694 .06396 L
.13307 .13145 L
Mistroke
.07359 .23401 L
.03843 .36382 L
.02801 .52751 L
.0512 .69577 L
.10972 .83352 L
.15406 .88618 L
.19988 .91954 L
.29102 .95056 L
.33868 .95582 L
.39158 .9567 L
.48236 .9514 L
.57834 .94028 L
.66613 .92292 L
.74242 .89481 L
.80865 .8496 L
.8681 .7745 L
.90872 .67659 L
.92889 .5702 L
.92968 .43782 L
.90309 .30814 L
.85621 .21578 L
.79994 .16136 L
.73396 .13236 L
.66917 .12371 L
.59763 .12699 L
.52245 .13851 L
.4468 .15538 L
.37881 .17573 L
.3218 .19971 L
.26556 .23542 L
.21746 .28476 L
.18322 .34306 L
.15918 .41911 L
.15124 .50567 L
.15914 .57811 L
.17785 .63664 L
.20871 .68645 L
.25031 .72142 L
.27646 .73339 L
.30157 .74008 L
.3297 .74335 L
.35971 .74306 L
.40942 .73627 L
.43687 .73004 L
.46186 .72319 L
.54399 .69468 L
.619 .66012 L
.65348 .63924 L
.68099 .61797 L
.7057 .59232 L
Mistroke
.71682 .577 L
.72514 .56264 L
.73591 .53561 L
.73938 .52039 L
.74093 .50665 L
.73985 .48269 L
.73748 .47154 L
.73359 .46018 L
.72299 .44163 L
.71018 .42805 L
.70204 .42185 L
.69248 .41609 L
.67356 .40779 L
.65447 .40193 L
.63304 .39679 L
.5919 .38771 L
.49831 .36018 L
.46969 .3506 L
.437 .3403 L
.40484 .33177 L
.37314 .32592 L
.33504 .32391 L
.30071 .32896 L
.26505 .34488 L
.2469 .35952 L
.23199 .3769 L
.21255 .41297 L
.19983 .46223 L
.19798 .52042 L
.20761 .57613 L
.22652 .62551 L
.25698 .67265 L
.29379 .70945 L
.33362 .73715 L
.3775 .7596 L
.42036 .7767 L
.46998 .79282 L
.52514 .80745 L
.58844 .81992 L
.64831 .82567 L
.71297 .82093 L
.74873 .8107 L
.78069 .79472 L
.8329 .74675 L
.87039 .67999 L
.89679 .57873 L
.90152 .46941 L
.88557 .36234 L
.84727 .26359 L
.79492 .19361 L
Mistroke
.73707 .14926 L
.66159 .11595 L
.61629 .10303 L
.57302 .09345 L
.49146 .07977 L
.40197 .07013 L
.35279 .06848 L
.30755 .07082 L
.25849 .0797 L
.20832 .09905 L
.13193 .16298 L
.09588 .22004 L
.06897 .28709 L
.04085 .44014 L
.04392 .59216 L
.08112 .74938 L
.1435 .85799 L
.21132 .9165 L
.29516 .95164 L
.3877 .96798 L
.47662 .97424 L
.56006 .97619 L
.63661 .97389 L
.7195 .9618 L
.8028 .9284 L
.87807 .8602 L
.93963 .73997 L
.97138 .5873 L
.97333 .43434 L
.94261 .2692 L
.91159 .19391 L
.87607 .13888 L
.79856 .07298 L
.70666 .04253 L
.61482 .0361 L
.5146 .04075 L
.42146 .05049 L
.33736 .06573 L
.25794 .0932 L
.19194 .13625 L
.12758 .2156 L
.08428 .32154 L
.06214 .46295 L
.07091 .61631 L
.10293 .72833 L
.15839 .81645 L
.23339 .86904 L
.27915 .88278 L
.32186 .88809 L
.40528 .88537 L
Mistroke
.48269 .87398 L
.5464 .86069 L
.61367 .84236 L
.67961 .81674 L
.73596 .78298 L
.78178 .7399 L
.81625 .68918 L
.84375 .62188 L
.85903 .5421 L
.85914 .45895 L
.84263 .37821 L
.81356 .31724 L
.77854 .27768 L
.73042 .24994 L
.70139 .24204 L
.67407 .23877 L
.6236 .24045 L
.57136 .24952 L
.52261 .26251 L
.47275 .27917 L
.43194 .29526 L
.39206 .31377 L
.35642 .33396 L
.32788 .35425 L
.30314 .37686 L
.28386 .40018 L
.26655 .42977 L
.25501 .46236 L
.2507 .49001 L
.25167 .51857 L
.25879 .5457 L
.26519 .55872 L
.2723 .56906 L
.28902 .58497 L
.30748 .59519 L
.32459 .60077 L
.34431 .60435 L
.36543 .60615 L
.38545 .60695 L
.4039 .60758 L
.42156 .60853 L
.44218 .61047 L
.46146 .6133 L
.50746 .62381 L
.56291 .63994 L
.5907 .64738 L
.6215 .65369 L
.64859 .65657 L
.67855 .65552 L
.71006 .64747 L
Mistroke
.72672 .63907 L
.74092 .62866 L
.76469 .60055 L
.78094 .56464 L
.78929 .52318 L
.78973 .48101 L
.78168 .4336 L
.76345 .38551 L
.73648 .34327 L
.69876 .30497 L
.65633 .27556 L
.61267 .2533 L
.55985 .23247 L
.49755 .21308 L
.46454 .20462 L
.42829 .19689 L
.39332 .19134 L
.36109 .18838 L
.30231 .1905 L
.24194 .20841 L
.19475 .24137 L
.15135 .30003 L
.11959 .38855 L
.10773 .50365 L
.12005 .61515 L
.15036 .70565 L
.19598 .77741 L
.24864 .82572 L
.31445 .86171 L
.39062 .88662 L
.46724 .90313 L
.54188 .91481 L
.61043 .92161 L
.68516 .92149 L
.77027 .90273 L
.84186 .85708 L
.90931 .75885 L
.94882 .62134 L
.9578 .47162 L
.94085 .33548 L
.89693 .21046 L
.82813 .11847 L
.74466 .06583 L
.69404 .04912 L
.64631 .03924 L
.55632 .02913 L
.46023 .02435 L
.40879 .02386 L
.35398 .02597 L
.25696 .04295 L
Mistroke
.20032 .06747 L
.1506 .10487 L
.11055 .15267 L
.07391 .22072 L
.03074 .3871 L
.02602 .56643 L
.03957 .66526 L
.06147 .74595 L
.09647 .82344 L
.1374 .87966 L
.18223 .9185 L
.2338 .9454 L
.33187 .96666 L
.38744 .9691 L
.43972 .96812 L
.4968 .9649 L
.55784 .95958 L
.64941 .94626 L
.6998 .93363 L
.74515 .91641 L
.8292 .85798 L
.86948 .80762 L
.90016 .74971 L
.93703 .6204 L
.94582 .4604 L
.92323 .31829 L
.87945 .21533 L
.81268 .14195 L
.73894 .1078 L
.66911 .09823 L
.59239 .10135 L
.51089 .11296 L
.46655 .12156 L
.42728 .13052 L
.35382 .1524 L
.28951 .18168 L
.23512 .22125 L
.18697 .27923 L
.15587 .34243 L
.13473 .42336 L
.12894 .51636 L
.14236 .61033 L
.17145 .683 L
.20871 .73083 L
.26136 .76452 L
.29004 .77338 L
.32248 .77806 L
.38019 .77646 L
.43323 .76744 L
.46263 .76029 L
Mistroke
.49265 .75174 L
.54364 .7346 L
.59486 .71359 L
.6439 .68786 L
.68147 .66138 L
.7103 .6336 L
.73348 .60207 L
.74943 .56965 L
.76026 .53017 L
.76273 .49443 L
.76126 .47677 L
.75759 .45863 L
.75165 .44145 L
.74434 .42727 L
.7271 .40623 L
.71579 .39747 L
.70479 .39129 L
.68185 .38358 L
.65928 .38063 L
.64627 .38036 L
.63255 .38089 L
.6083 .38314 L
.58249 .38628 L
.56859 .38784 L
.55561 .38901 L
.53244 .38998 L
.51138 .38934 L
.49139 .38731 L
.46912 .38362 L
.42 .37276 L
.39207 .36696 L
.37588 .36438 L
.36082 .36277 L
.33281 .36262 L
.30659 .36721 L
.28375 .37678 L
.2614 .39413 L
.24234 .42075 L
.23432 .43922 L
.22899 .45793 L
.22456 .49851 L
.22823 .53955 L
.23877 .57789 L
.25716 .61618 L
.27832 .64584 L
.30674 .67458 L
.34258 .70107 L
.38616 .7251 L
.47588 .76037 L
.52972 .77617 L
Mistroke
.56207 .7839 L
.59247 .78973 L
.62497 .79401 L
.66039 .79572 L
.72404 .78753 L
.77597 .76379 L
.82548 .7147 L
.8635 .63575 L
.88146 .54169 L
.88292 .48315 L
.87694 .4195 L
.8642 .36212 L
.84676 .31359 L
.8007 .23727 L
.73751 .18018 L
.70063 .15901 L
.65866 .14114 L
.57825 .11763 L
.52702 .10676 L
.47714 .09811 L
.43153 .09184 L
.3811 .08737 L
.33644 .0866 L
.28835 .09085 L
.20421 .11943 L
.13181 .18479 L
.08097 .28441 L
.05108 .4294 L
.04817 .52058 L
.05507 .60515 L
.07209 .68877 L
.09553 .75622 L
.13063 .82104 L
.17028 .86876 L
.24698 .92193 L
.33666 .95104 L
.41662 .96328 L
.50663 .97051 L
.60416 .97331 L
.659 .97105 L
.70877 .96453 L
.79731 .93395 L
.88021 .86198 L
.94251 .73971 L
.96507 .64998 L
.97619 .55842 L
.97066 .38515 L
.92995 .22579 L
.86936 .1241 L
.7991 .06644 L
Mistroke
.71376 .03584 L
.61827 .02629 L
.51614 .02834 L
.45882 .03213 L
.40622 .03727 L
.31187 .05415 L
.26594 .06914 L
.21741 .09355 L
.14278 .16147 L
.08191 .27849 L
.05144 .42465 L
.05103 .57009 L
.0748 .69613 L
.1222 .801 L
.18194 .86552 L
.24396 .89787 L
.32125 .91223 L
.40629 .9103 L
.4853 .90012 L
.5561 .88688 L
.62627 .86915 L
.68852 .84626 L
.75125 .80968 L
.80915 .75153 L
.85443 .66712 L
.87869 .56859 L
.88265 .47419 L
.86773 .37767 L
.8523 .33306 L
.83123 .29301 L
.78392 .24112 L
.72422 .21178 L
.6883 .20502 L
.65432 .20358 L
.59313 .20943 L
.53904 .22071 L
.47972 .23763 L
.42723 .25629 L
.3837 .27532 L
.34163 .29875 L
.30966 .32213 L
.27933 .35213 L
.25353 .38919 L
.2345 .43369 L
.22556 .47764 L
.22515 .51691 L
.23258 .5554 L
.24834 .58916 L
.26902 .6126 L
.29124 .62668 L
Mistroke
.31989 .6354 L
.33663 .63721 L
.35216 .63731 L
.38047 .63455 L
.39444 .63218 L
.40951 .62913 L
.46387 .61694 L
.47859 .61416 L
.49226 .61206 L
.50435 .61068 L
.51739 .60975 L
.54102 .60958 L
.55427 .61026 L
.56636 .61128 L
.59043 .614 L
.61342 .61672 L
.63534 .61855 L
.65901 .61864 L
.67242 .61735 L
.68492 .61495 L
.70732 .60669 L
.72851 .59166 L
.74462 .57142 L
.75702 .54237 L
.76074 .52536 L
.76261 .50519 L
.76023 .46977 L
.75182 .43666 L
.73579 .40154 L
.71171 .36766 L
.68518 .34136 L
.65648 .31976 L
.62104 .29884 L
.57919 .27909 L
.52939 .25987 L
.47247 .24196 L
.44119 .23394 L
.40583 .22676 L
.37298 .22237 L
.34195 .22084 L
.31048 .22268 L
.28106 .22843 L
.22865 .25266 L
.18012 .3027 L
.1584 .34277 L
.14306 .38686 L
.12944 .47396 L
.13271 .56145 L
.15431 .65241 L
.19639 .73398 L
Mistroke
.25316 .79327 L
.28594 .81549 L
.32428 .83505 L
.39703 .86074 L
.46888 .87822 L
.54983 .89264 L
.59167 .89787 L
.63823 .90108 L
.72057 .89563 L
.79469 .8689 L
.83595 .83815 L
.87116 .79669 L
.92192 .68541 L
.93897 .60695 L
.94626 .52764 L
.94429 .43832 L
.93076 .34677 L
.88374 .21598 L
.84635 .16043 L
.80679 .12125 L
.72499 .07458 L
.63119 .04981 L
.54373 .03849 L
.46059 .03231 L
.36855 .03069 L
.27078 .04254 L
.18059 .08206 L
.10797 .15749 L
.04983 .29108 L
.03231 .37593 L
.02381 .47745 L
.03612 .64717 L
.08354 .7998 L
.15291 .89671 L
.22946 .94642 L
.31034 .96857 L
.38776 .97516 L
.47319 .9747 L
.56387 .96973 L
.6577 .95824 L
.743 .93432 L
.81409 .89301 L
.8805 .81779 L
.93332 .69431 L
.95659 .55265 L
.94947 .38194 L
.91088 .24396 L
.85396 .15446 L
.78931 .10521 L
.71142 .08089 L
Mistroke
.62583 .07695 L
.57681 .08047 L
.53228 .0858 L
.48414 .09321 L
.43442 .10257 L
.35371 .12325 L
.31015 .13941 L
.27151 .15882 L
.20617 .21045 L
.15794 .27838 L
.1207 .38097 L
.10768 .4924 L
.11705 .59927 L
.13149 .65344 L
.15025 .6975 L
.20024 .76328 L
.23347 .78677 L
.26593 .80075 L
.3261 .8113 L
.39252 .80831 L
.45376 .79742 L
.50826 .78347 L
.57278 .76245 L
.62862 .73883 L
.67385 .7131 L
.71635 .67877 L
.73532 .65783 L
.7533 .63241 L
.76856 .60342 L
.77931 .57457 L
.78967 .5208 L
.7904 .49094 L
.78799 .46486 L
.77711 .42351 L
.76023 .3919 L
.73599 .36654 L
.70533 .34997 L
.67245 .34307 L
.65558 .34247 L
.63714 .34352 L
.60507 .34859 L
.57642 .35554 L
.39478 .3922 L
.37189 .39302 L
.35907 .39374 L
.34735 .39481 L
.32624 .39836 L
.30501 .40543 L
.28768 .41559 L
.27359 .42896 L
Mistroke
.26136 .44813 L
.25299 .47366 L
.25085 .48953 L
.25058 .50511 L
.25229 .52288 L
.25646 .5422 L
.26275 .56063 L
.2707 .57769 L
.29064 .608 L
.31645 .63526 L
.34498 .65769 L
.38104 .67967 L
.4239 .7005 L
.46613 .71762 L
.51578 .73464 L
.56587 .74846 L
.61439 .75766 L
.65914 .7609 L
.70839 .75577 L
.75749 .73647 L
.79854 .70181 L
.83434 .64292 L
.85666 .56036 L
.8605 .47991 L
.84755 .39172 L
.81455 .30737 L
.78866 .26816 L
.76133 .23805 L
.69985 .19327 L
.63449 .1642 L
.57413 .14577 L
.50452 .12975 L
.42893 .11698 L
.35647 .11091 L
.28845 .11507 L
.22807 .1328 L
.16393 .17734 L
.11328 .24904 L
.07573 .35857 L
.06128 .49978 L
.07199 .62315 L
.10719 .74302 L
.16691 .83832 L
.20785 .87592 L
.24871 .90152 L
.32954 .93162 L
.41937 .94857 L
.51137 .95833 L
.56401 .96182 L
.61286 .96325 L
Mistroke
.70237 .95753 L
.79399 .92882 L
.86798 .87018 L
.92437 .77873 L
.96441 .63902 L
.97494 .46227 L
.94719 .28372 L
.91572 .20081 L
.87838 .13967 L
.79562 .06686 L
.74421 .04459 L
.69586 .03266 L
.60213 .02381 L
.50001 .02428 L
.4042 .0298 L
.31767 .04227 L
.23957 .06776 L
.16297 .12041 L
.10258 .20266 L
.06269 .30675 L
.03987 .45487 L
.04804 .62217 L
.08553 .75721 L
.14044 .84667 L
.21012 .90135 L
.28213 .92505 L
.36383 .93095 L
.45174 .92479 L
.53702 .91266 L
.6236 .89463 L
.69382 .87165 L
.76451 .83211 L
.80155 .79915 L
.83254 .76018 L
.87712 .66656 L
.89288 .60421 L
.90078 .54295 L
.90183 .47457 L
.89434 .40478 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00e@3oool00`3ooml0W4P0000000020000000307Bo
o`3oool0oooo0=<0oooo003G0?ooo`030?noM00007@0_ooo0=H0oooo003G0?ooo`030?oo_`1d0000
M;oo0=H0oooo003G0?ooo`030?oog`2LB000B9cO0=H0oooo003H0?ooo`030=nLB000000000000080
000000<0M;oo0?ooo`3oool00P3oool01@3o_g@000000000000004P0W=oo0080oooo00<0oono07@0
000000000P0000003@18W=l0oooo0?ooo`3oool0_g@00000000004P0W=oo0?ooo`3o_g@000000000
B02Lgol00P3oool0102oM00000000000B02Lgol20?ooo`050?noM000000000000000B02Lgol00`3o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000000007Bo09d0oooo003H0?ooo`070?noM00004P0
W=oo0?ooo`3ooml0W4P0001d_`020?ooo`0?0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`3oool0
oooO09a8001d_ol0oooo0?oOW0180000M;oo0080oooo01L0gia80018W03Ooml0W7BL0=ooo`3o_g@0
001809cOg`2LM9`0gooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0
B000001d_`020?ooo`030?noM00007@0_ooo0080oooo00@0gia80018W03O_g@0M;ooW03oool00=P0
oooo00<0oono07@0001d_ol00P3oool01`3ooml0W4P004RLg`3oool0gia80018W03Oool00P3oool0
2P3ogi`0B00004RLg`3oool0_gAd0;ooo`3oool0oono07@0001d_ol20?ooo`030?noM00004P0W=oo
0080oooo00<0oono07@0001d_ol00`3oool00`3o_g@0001809cOo`020?ooo`030=nLB000B9`0gooo
0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol0W@3o
ool00=P0oooo00<0oooO09a80018W=l00`3oool01P3ogi`0B01809cOo`3o_g@0001d0;ooo`<0oooo
00<0gia80000M02oool00`3oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo
00<0_g@0001d_`3oool00P3oool00`3ookl0M00004RLg`020?ooo`030?noM00007@0_ooo00<0oooo
00/0gia80000M02oool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`2M0?ooo`00f@3oool0
0`3OW4P0001d0;ooo`020?ooo`060?oog`2LB000B9cO0?oo_`1d0000M;oo0`3oool00`3ogi`0B018
09cOo`020?ooo`030?noM00004P0W=oo00@0oooo00<0_g@00018W03Oool00P3oool00`3OW4P004RL
0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3ookl0M00007Boo`030?ooo`070?oOW01804P0W=oo
0?ooo`3OW4P004Q804Qd_`020?ooo`030;md0000M;l0oooo09`0oooo003I0?ooo`040?noM0000000
04RL0=ooo`80oooo00H0gia8001d_`3oool0gia80000M02oool20?ooo`0:0?oo_`1d0000M;oo0?oo
o`3ogi`0B01809cOo`3oool0giad09cOo`80oooo00<0gia80000B02Lgol00P3oool00`3ogi`0B018
09cOo`030?ooo`030=nLB00004P0W=oo0080oooo00<0gia80000M02oool00P3oool0303ookl0M000
07Boo`3oool0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;oooi`0oooo003I0?ooo`080?oo_`1d
0000M9bL04P0M02oool0oooO09a80000M;l20?ooo`0>0;md000007@0_ooo0?ooo`3o_g@0001d0;oo
o`3oool0omnL04P0B02Lgol0oooO09a8001d_ol20?ooo`030?oOW0180000B9cO0080oooo00<0oooO
09a80018W=l00`3oool00`3ogi`0B00004RLg`030?ooo`0@0;md000007@0_ooo0?ooo`3o_g@0001d
0;ooo`3oool0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOoi`0oooo003H0?ooo`090?oOW018
0000000004RLg`3ookl0M0000000000007@0_ooo00<0oooo00D0okmd000000000000000007Boo`03
0?ooo`070;md00000000000000000018W=l0oooo0?noM002000000040018W03Oool0oono07@000<0
000000H0M;oo0?noM000000000000018W03Oool30?ooo`0?0?noM000000000000000001d_ol0oooo
0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo09`0oooo003i0?ooo`030?noM00007@0
_ooo0;@0oooo003j0?ooo`030=nLM02Lgol0oooo0;<0oooo003d0?ooo`040?oo_`1d000004RL0=oo
o`L0oooo00@0oono07@00000B9`0gooo[@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool005<0oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`180?ooo`030?oo_`1d
000000000080000000<0B9cO0?ooo`3oool0AP3oool0102oM00000000000001d_om;0?ooo`030?oo
_`1d000000000080000000<0B9cO0?ooo`3oool0BP3oool00`3OW4P00000000000030000000304RL
g`3oool0oooo01@0oooo001D0?ooo`030?noM000M;l0oooo0080oooo00<0_gAd0;ooo`3oool0BP3o
ool00`3o_g@0000007Boo`180?ooo`060=nLB000M;l0oooo0?oOW0180000B9cOC03oool00`3o_g@0
000007Boo`1>0?ooo`030?noM000M;l0oooo0080oooo00<0_gAd0;ooo`3oool0503oool005D0oooo
00<0okmd001d_`3oool0CP3oool00`3ooml0W4P0001d_`170?ooo`030?oog`2LB000B9cO0080oooo
00<0okmd0000B02Lgol0B`3oool00`3ooml0W4P0001d_`1?0?ooo`030?noM000M;l0oooo01P0oooo
001F0?ooo`030?noM000M;l0oooo04h0oooo00<0gia80018W03Oool0AP3oool00`3ooml0W4P004RL
g`020?ooo`040?oog`2LB00004RL0=oood/0oooo00<0gia80018W03Oool0C`3oool00`3o_g@007Bo
0?ooo`0G0?ooo`00AP3oool00`3ooml0W4P0000000070000000304RLg`3oool0oooo00@0oooo00<0
okmd04RLg`3oool0?@3oool00`3ooml0W4P0000000070000000304RLg`3oool0oooo00<0oooo00<0
omnL04P0B02Lgol0AP3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo04/0oooo00<0
omnL04P0B02Lgol0D03oool00`3o_g@0B9cO0?ooo`0F0?ooo`00F03oool00`3OW4P0B9cO0?ooo`1<
0?ooo`030?oo_`1d0000M;oo04L0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`1;
0?ooo`030?oo_`1d0000M;oo0540oooo00<0gia804RLg`3oool05@3oool005T0oooo00<0_g@007Bo
o`3oool0C03oool00`2oM00007Bo0?ooo`160?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a8
0000M;l0C03oool00`2oM00007Bo0?ooo`1A0?ooo`030;md001d_ol0oooo01@0oooo001I0?ooo`03
0?oOW01807@0_ooo04`0oooo00<0gia80018W03Oool0AP3oool00`3ogi`0B00004RLg`030?ooo`03
0;md0000B9`0gooo04/0oooo00<0gia80018W03Oool0D@3oool00`3ogi`0B01d0;ooo`0D0?ooo`00
F@3oool00`3ooml0W4P007Boo`1<0?ooo`030?oOW01804P0W=oo04H0oooo00@0oooO09a80000B9`0
gooo0P3oool00`3OW4P004RL0=ooo`1;0?ooo`030?oOW01804P0W=oo0540oooo00<0oooO09a8001d
_ol0503oool005T0oooo00<0oono07@00018W=l0C03oool00`3ookl0M00007Boo`170?ooo`030?oO
W0180000M;oo0080oooo00<0gia8001d_`3oool0B`3oool00`3ookl0M00007Boo`1A0?ooo`030?oo
_`1d0000B9cO01@0oooo001E0?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cOo`1=0?ooo`03
0;md0000M;l0oooo04L0oooo00H0gia80000M02oool0oooO09a80018W=m=0?ooo`030;md0000M;l0
oooo04`0oooo00L0okmd0018W03Oool0oooo0=nLB00004P0W=oo01@0oooo001F0?ooo`050?oOW018
000000000000001d_ol0C03oool01@3ookl0M0000000000007@0_ooo04P0oooo00@0gia800000000
000007BoC03oool01@3ookl0M0000000000007@0_ooo04d0oooo00D0omnL04P000000000000007Bo
o`0E0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00A03o
oooo0000068000002`3oool004@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`00A03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2]0?ooo`03
0000003oool0oooo0:d0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0
[@3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003o
ool0oooo0:d0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool02@3oool0
04@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo
00T0oooo00140?ooo`030000003oool0oooo08@0ooooD`0000260?ooo`030000003oool0oooo00T0
oooo00140?ooo`030000003oool0oooo07P0oooo4@00000;0?oooa`00000203ooolZ000007/0oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0LP3oool=000000X0oooo2`00
000F0?oooa`000000P3oool<000000P0oooo4@00001`0?ooo`030000003oool0oooo00T0oooo0014
0?ooo`800000K@3oool:000000D0oooo;`0000030?ooo`030000003oool0oooo01D0oooo20000007
0?ooo`L000002@3oool8000000030?ooo`000000000000D00000I`3oool3000000/0oooo00140?oo
o`030000003oool0oooo06L0oooo1`0000040?ooo`T000000P3oool6000000h0oooo2P00000<0?oo
o`h00000603oool8000000H0oooo1P00000;0?ooo``00000I@3oool00`000000oooo0?ooo`090?oo
o`00A03oool00`000000oooo0?ooo`1Q0?ooo`L000000P3oool8000000D0oooo1P00000=0?ooo`L0
0000703oool00`000000oooo0?ooo`050?ooo`/00000103ooolJ000000<0oooo1`00000<0?ooo`L0
0000HP3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`1K0?ooo`l00000
1`3oool6000000d0oooo1P00000S0?oooa/000005@3ooolB000000/0oooo1000001O0?ooo`030000
003oool0oooo00T0oooo00140?ooo`030000003oool0oooo05L0oooo2`00000:0?ooo`D000003P3o
ool500000280oooo2000000J0?ooo`P000004`3oool6000000D0oooo2P0000050?ooo`D00000F`3o
ool00`000000oooo0?ooo`090?ooo`00=03oool00`3ookl0M000000000020000000307Boo`3oool0
oooo00P0oooo00<000000?ooo`3oool0E@3oool200000080oooo1@00000;0?ooo`<000003@3oool6
000001l0oooo200000070?ooo`030000003oool0oooo0200oooo2000000A0?ooo`H000001@3oool7
000000D0oooo1@00001H0?ooo`030000003oool0oooo00T0oooo000d0?ooo`030?noM000000007Bo
0080oooo00<0_gA809cOo`3oool0203oool00`000000oooo0?ooo`1C0?ooo`8000000P3oool40000
00/0oooo0`00000;0?ooo`D000007@3oool8000000l0oooo00<000000?ooo`3oool0703ooolO0000
00@0oooo100000050?ooo`H000001@3oool4000005H0oooo00<000000?ooo`3oool02@3oool003T0
oooo00<0omnL04Q8W03Oool0203oool00`000000oooo0?ooo`1A0?ooo`8000000P3oool3000000/0
oooo0`0000080?ooo`H000006`3oool7000001L0oooo00<000000?ooo`3oool03`3oool=00000140
oooo1000000:0?ooo`/000001@3oool6000000D0oooo1000001C0?ooo`030000003oool0oooo00T0
oooo000i0?ooo`030?oo_`1d0000M;oo00P0oooo00<000000?ooo`3oool0C`3oool2000000040?oo
o`0000000000000000/0oooo0`0000070?ooo`@000002`3oool<000000@0oooo1P00000N0?ooo`03
0000003oool0oooo00H0oooo2@00000R0?ooo`@000003`3oool6000000@0oooo1P0000050?ooo`<0
0000D@3oool00`000000oooo0?ooo`090?ooo`009`3oool00`3ooml0W4P0000000070000000304RL
g`3oool0oooo00D0oooo00<0omnL04P0001d_ol0203oool00`000000oooo0?ooo`1<0?ooo`L00000
2@3oool4000000L0oooo0`0000070?ooo`P000002P3oool@000001X0oooo2@00000_0?ooo`<00000
4@3oool4000000D0oooo100000060?ooo`<00000CP3oool00`000000oooo0?ooo`090?ooo`00>03o
ool0103ogi`0B0000000B02Lgol80?ooo`<00000BP3oool6000000T0oooo0`0000080?ooo`<00000
0P3oool8000000`0oooo1P00000@0?ooo`X000001P3oool;000003X0oooo1000000@0?ooo`D00000
103oool4000000H0oooo0`0000190?ooo`<000002`3oool003H0oooo00D0omnL04P0000000000000
07Boo`090?ooo`030000003oool0oooo04P0oooo0`0000000`3oool00000000000080?ooo`<00000
1`3oool9000000h0oooo1P00000N0?ooo`/000001`3oool00`000000oooo0?ooo`0l0?ooo`@00000
3`3oool5000000<0oooo1@0000060?ooo`<00000B03oool00`000000oooo0?ooo`090?ooo`00>03o
ool00`3ookl0M000001d_`090?ooo`030000003oool0oooo04H0oooo0`0000000`3oool000000000
00070?ooo`<000001@3oool600000180oooo1000000O0?ooo`D000002`3oool900000440oooo0`00
000?0?ooo`D000000P3oool2000000040?ooo`0000000000000000D0oooo0`0000160?ooo`030000
003oool0oooo00T0oooo000j0?ooo`030=nLB000M;l0oooo00L0oooo00<000000?ooo`3oool0A03o
ool6000000L0oooo0P0000040?ooo`H000004`3ooolB000000l0oooo1@00000G0?ooo`030000003o
ool0000000L00000?03oool4000000d0oooo0P0000000`3oool000000000000400000080oooo0`00
00040?ooo`800000A@3oool00`000000oooo0?ooo`090?ooo`00>P3oool00`3ogi`0B01809cOo`07
0?ooo`030000003oool0oooo0480oooo0P0000000`3oool00000000000080?ooo`8000000`3oool3
00000080oooo0P00000<0?ooo`/00000403oool?000001`0oooo00<000000?ooo`3oool01`3oool8
000003P0oooo1000000;0?ooo`030000003oool0oooo0080oooo100000030?ooo`<000000P3oool2
000004@0oooo00<000000?ooo`3oool02@3oool003L0oooo00H0_g@007Boo`3oool0gia80000B02L
gol70?ooo`030000003oool0oooo0440oooo00@000000?ooo`00000000002@3oool00`000000oooo
0?ooo`03000000<0oooo0P0000080?ooo`H00000103oool3000001P0oooo1@0000060?ooo`X00000
4P3oool00`000000oooo0?ooo`0?0?ooo`L00000=@3oool2000000X0oooo0P0000040?ooo`@00000
103oool2000000040?ooo`000000000000000480oooo00<000000?ooo`3oool02@3oool003P0oooo
00@0_g@0000000000000B9cO203oool00`000000oooo0?ooo`100?ooo`@00000203oool5000000@0
oooo0P0000040?ooo`H000001`3oool3000001H0oooo1@00000E0?ooo`X00000203oool00`000000
oooo0?ooo`0F0?ooo`D000001P3ooolG000001D0oooo0P00000:0?ooo`030000003oool0oooo00<0
oooo100000040?ooo`030000003oool0000000800000@@3oool00`000000oooo0?ooo`090?ooo`00
A03oool00`000000oooo0?ooo`0n0?ooo`<0000000<0oooo0000003oool01`3oool2000000H0oooo
0P0000020?ooo`@000002P3oool3000001@0oooo1@00000T0?ooo`T000005`3oool<000001L0oooo
4@0000060?ooo`8000002@3oool2000000D0oooo100000030?ooo`030000003oool0oooo00800000
@03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0m0?ooo`80000000<0
oooo0000000000001`3oool2000000H0oooo0P0000020?ooo`8000002`3oool3000001<0oooo1000
000a0?ooo`H000002P3oool8000000`0oooo1@00000S0?ooo`<000001@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool2000000030?ooo`00
0000000003l0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0?03oool0
10000000oooo0?ooo`0000080?ooo`030000003oool0oooo00@0oooo0P000000103oool000000000
0000000;0?ooo`8000003P3oool;00000380oooo00<000000?ooo`3oool00`3oool:000001T0oooo
1000000R0?ooo`<000000`3oool2000000T0oooo0P0000050?ooo`<00000103oool010000000oooo
00000000000n0?ooo`030000003oool0oooo00T0oooo00140?ooo`800000>`3oool200000080oooo
00<000000?ooo`3oool01@3oool2000000D0oooo0P0000000`3oool000000000000;0?ooo`<00000
203oool;000000P0oooo4@00000Q0?ooo`030000003oool0oooo00H000000`3oool6000001/0oooo
1@00000P0?ooo`<000000P3oool2000000T0oooo00<000000?ooo`3oool0103oool2000000@0oooo
00<000000?ooo`0000000P00000j0?ooo`<000002`3oool004@0oooo00<000000?ooo`3oool0>@3o
ool200000080oooo00<000000?ooo`3oool0103oool2000000D0oooo1@00000:0?ooo`<000001@3o
ool6000000<0oooo1000000M0?ooo`d000004@3oool6000000l0oooo1P00000J0?ooo`@000007`3o
ool3000000030?ooo`000000000000P0oooo0P0000060?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`000000oooo0000000k0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003o
ool0oooo03L0oooo0`0000020?ooo`030000003oool0oooo00@0oooo0P0000050?ooo`<000002`3o
ool2000000D0oooo0`0000070?ooo`800000;P3oool8000000@0oooo1@0000030?ooo`030000003o
ool0oooo01D0oooo1@00000I0?ooo`@000007P3oool4000000T0oooo0P0000050?ooo`8000000`3o
ool01@000000oooo0000003oool0000003X0oooo00<000000?ooo`3oool02@3oool004@0oooo00<0
00000?ooo`3oool0=P3oool010000000oooo0000003oool2000000D0oooo0P0000050?ooo`800000
303oool2000000@0oooo0`0000070?ooo`<00000=P3oool9000000D0oooo00<000000?ooo`3oool0
6P3oool5000001<0oooo2P00000M0?ooo`<00000203oool00`000000oooo0?ooo`030?ooo`<00000
0P3oool01@000000oooo0000003oool0000003T0oooo00<000000?ooo`3oool02@3oool004@0oooo
00<000000?ooo`3oool0=@3oool01@000000oooo0000003oool0000000H0oooo0P0000040?ooo`<0
0000303oool010000000oooo0?ooo`3oool3000000P0oooo0P00000c0?ooo`H000002@3oool60000
0240oooo4`0000070?ooo`T000006@3oool4000000H0oooo0P0000040?ooo`050000003oool00000
0000003oool00`0000000`3oool000000?ooo`0g0?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo03<0oooo0P000000103oool000000?ooo`0000050?ooo`8000001@3oool0
0`000000oooo0000000;0?ooo`80000000@0oooo0000000000000000203oool300000340oooo1000
000D0?ooo`L000005P3oool>000001@0oooo0P0000040?ooo`H000005@3oool00`000000oooo0000
0002000000D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`D00000
=P3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0b0?ooo`060000003o
ool0oooo0000003oool00000103oool3000000D0oooo0`00000;0?ooo`@000002@3oool200000300
oooo1000000H0?ooo`030000003oool0oooo00@0oooo1@00000:0?ooo`L000003P3oool3000001<0
oooo0P0000080?ooo`H00000403oool200000080oooo0P0000040?ooo`8000000`3oool010000000
oooo0?ooo`0000020?ooo`050000003oool000000?ooo`000000=@3oool00`000000oooo0?ooo`09
0?ooo`00A03oool00`000000oooo0?ooo`0a0?ooo`060000003oool0oooo0000003oool00000103o
ool2000000D0oooo0`00000;0?ooo`<000002P3oool2000002h0oooo1000000L0?ooo`030000003o
ool0oooo00T0oooo2P00000H0?ooo`<000004P3oool3000000/0oooo1@00000=0?ooo`8000000P3o
ool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool020000000oooo
0?ooo`000000oooo0000003oool00000=03oool00`000000oooo0?ooo`090?ooo`00A03oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo00<00000103oool2000000D0oooo00<000000?oo
o`0000002@3oool3000000/0oooo0P00000C0?oooa8000001`3oool400000200oooo00<000000?oo
o`3oool01@3oool7000000030?ooo`000000000000<00000703oool400000140oooo0P00000>0?oo
o`8000003@3oool2000000030?ooo`000000000000@0oooo0P0000020?ooo`040000003oool0oooo
00000080oooo00D000000?ooo`000000oooo0000000c0?ooo`030000003oool0oooo00T0oooo0014
0?ooo`030000003oool0oooo0300oooo00@000000?ooo`00000000001@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0000000L0oooo1@00000;0?ooo`030000003oool0oooo00D0oooo3P00
000B0?ooo``000007`3oool00`000000oooo00000005000000d0oooo1000000L0?ooo`<00000403o
ool3000000d0oooo0P00000=0?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`03000000030?ooo`000000oooo0340oooo00<000000?ooo`3o
ool02@3oool004@0oooo0P00000`0?ooo`040000003oool00000000000@0oooo0P0000060?ooo`03
0000003oool0000000D0oooo0`0000000`3oool000000000000;0?ooo`8000001@3oool3000001l0
oooo100000090?ooo`T000004`3oool5000001L0oooo1000000K0?ooo`<00000403oool2000000d0
oooo0P00000<0?ooo`80000000<0oooo0000003oool0103oool2000000050?ooo`000000oooo0?oo
o`0000000`3oool2000000030?ooo`000000000002h0oooo0`00000;0?ooo`00A03oool00`000000
oooo0?ooo`0^0?ooo`040000003oool00000000000@0oooo0P0000060?ooo`030000003oool00000
00@0oooo0P0000030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool30000
01h0oooo1000000F0?ooo`H000001`3oool6000000<0oooo00<000000?ooo`3oool06P3oool30000
01/0oooo0P00000@0?ooo`8000003@3oool2000000`0oooo100000050?ooo`060000003oool00000
0000003oool000000`3oool200000080oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`090?ooo`00A03oool00`000000oooo0?ooo`0]0?ooo`040000003oool00000000000@0oooo00<0
00000?ooo`000000103oool2000000030?ooo`000000oooo00<0oooo00@000000?ooo`3oool0oooo
0P00000;0?ooo`8000000P3oool3000001d0oooo1000000P0?ooo`L000002@3oool00`000000oooo
0?ooo`0M0?ooo`@000004@3oool:00000100oooo0`00000<0?ooo`800000303oool00`000000oooo
000000050?ooo`060000003oool0oooo0000003oool000000`3oool200000080oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0/0?ooo`04
0000003oool00000000000D0oooo0P0000040?ooo`040000003oool0oooo000000@0oooo00D00000
0?ooo`3oool0oooo0000000<0?ooo`D000007P3oool200000280oooo100000030?ooo`D000001P3o
ool00`000000oooo0?ooo`0Q0?ooo`<000000P3oool<000000X0oooo2000000;0?ooo`800000303o
ool3000000X0oooo00<000000?ooo`0000001@3oool01@000000oooo0?ooo`000000oooo00800000
0P3oool200000080oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`00A03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0000000H0oooo0P0000040?ooo`040000003o
ool00000000000@0oooo00<000000?ooo`3oool00P00000;0?ooo`<000007`3oool3000001l0oooo
1@00000<0?ooo`L000007P3oool;000001P0oooo0P0000030?ooo`P000001@3oool2000000d0oooo
0P0000090?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00<0000000<0oooo0000003oool0:`3oool00`000000oooo0?ooo`090?ooo`00
A03oool00`000000oooo0?ooo`0[0?ooo`8000001P3oool2000000@0oooo00<000000?ooo`000000
1@3oool010000000oooo0?ooo`00000:0?ooo`<000007`3oool3000001h0oooo1000000G0?ooo`D0
0000503oool6000000/0oooo0`00000G0?ooo`8000002@3oool500000080oooo00<000000?ooo`3o
ool0303oool2000000P0oooo00@000000?ooo`00000000000`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool01000000/0?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo02X0oooo0P0000060?ooo`800000103oool00`000000oooo000000050?oo
o`040000003oool00000000000T0oooo1000000N0?ooo`8000007P3oool3000001/0oooo00<00000
0?ooo`3oool00P3oool5000000P0oooo1`00000D0?ooo`<000005P3oool3000000/0oooo0P000000
0`3oool000000000000>0?ooo`8000001`3oool010000000oooo0?ooo`0000030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool3000002/0oooo00<000000?ooo`3o
ool02@3oool004@0oooo00<000000?ooo`3oool0:@3oool3000000H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000040?ooo`80000000<0oooo0000003oool0203oool2000000030?oo
o`000000oooo01`0oooo0`00000M0?ooo`<000007P3oool00`000000oooo0?ooo`070?ooo`P00000
7P3oool4000001D0oooo0P00000;0?ooo`80000000<0oooo0000003oool03P3oool2000000H0oooo
00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool0oooo0P00000[0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
02P0oooo0`0000060?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool00`3oool0
10000000oooo0?ooo`0000090?ooo`040000003oool00000000001`0oooo0P00000M0?ooo`<00000
8@3oool00`000000oooo0?ooo`030?ooo`H000000P3oool500000240oooo0`00000D0?ooo`<00000
2P3oool300000100oooo0P0000050?ooo`030000003oool0oooo0080000000<0oooo0000003oool0
0`3oool010000000oooo0?ooo`0000030?ooo`800000:P3oool00`000000oooo0?ooo`090?ooo`00
A03oool00`000000oooo0?ooo`0W0?ooo`80000000<0oooo0000003oool0103oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000080?oo
o`80000000<0oooo0000003oool06`3oool2000001/0oooo1000000T0?ooo`030000003oool00000
00<000003@3oool5000001l0oooo0`00000D0?ooo`8000002P3oool300000100oooo0P0000040?oo
o`8000000P3oool00`000000oooo000000040?ooo`040000003oool0oooo000000<0oooo0P00000Y
0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo02H0oooo0P0000000`3o
ool000000?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000001`3oool010000000oooo00000000000K0?ooo`800000
6P3oool3000002D0oooo1@00000F0?ooo`@000007P3oool2000001@0oooo0P00000:0?ooo`800000
4@3oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool00000103oool01000
0000oooo0?ooo`0000020?ooo`800000:@3oool00`000000oooo0?ooo`090?ooo`00A03oool20000
02L0oooo00<000000?ooo`0000001@3oool200000080oooo00@000000?ooo`3oool00000103oool0
1@000000oooo0?ooo`3oool0000000H0oooo0P0000000`3oool000000?ooo`0J0?ooo`8000006@3o
ool3000002@0oooo100000030?ooo`030000003oool0oooo01T0oooo0`00000M0?ooo`<000004`3o
ool2000000X0oooo0P00000@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`00
00040?ooo`040000003oool0oooo00000080oooo0P00000V0?ooo`<000002`3oool004@0oooo00<0
00000?ooo`3oool09@3oool010000000oooo0?ooo`0000050?ooo`050000003oool0oooo0000003o
ool00P0000040?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000oooo00000000000J
0?ooo`800000603oool300000280oooo1@0000070?ooo`030000003oool0oooo01`0oooo0`00000M
0?ooo`8000004`3oool00`000000oooo0?ooo`080?ooo`<000003`3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo0?ooo`800000103oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0903o
ool010000000oooo0?ooo`0000050?ooo`060000003oool000000000003oool000001@3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`0000006P3oool2000001L0oooo0`00000Q
0?ooo`@00000303oool00`000000oooo0?ooo`0O0?ooo`<00000703oool300000140oooo0P00000:
0?ooo`<000003P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000001@3o
ool00`000000oooo000000020?ooo`8000009`3oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`0S0?ooo`050000003oool0oooo0?ooo`000000103oool300000080oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000D0oooo1000000I0?ooo`800000
5`3oool200000200oooo1000000@0?ooo`030000003oool0oooo0280oooo0`00000L0?ooo`800000
4@3oool00`000000oooo0?ooo`080?ooo`040000003oool00000000000`0oooo00<000000?ooo`3o
ool0103oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`0000000P3oool20000
02H0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool08`3oool010000000
oooo0?ooo`0000040?ooo`<000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0000000J0?ooo`030000003oool0oooo01D0oooo0P00000N
0?ooo`@00000503oool00`000000oooo0?ooo`0U0?ooo`<000006`3oool200000100oooo00<00000
0?ooo`3oool0203oool2000000030?ooo`000000000000/0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`02000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo0280oooo00D000000?oo
o`3oool0oooo000000030?ooo`<000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`0I0?ooo`030000003o
ool0oooo00/0oooo800000080?ooo`<00000603oool00`000000oooo0?ooo`0X0?ooo`<000006P3o
ool2000000l0oooo0P00000:0?ooo`030000003oool0oooo008000002P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00800000103oool00`000000oooo000000020?ooo`8000009@3o
ool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0R0?ooo`040000003oool0
oooo000000<0oooo0`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool05`3oool2000000H0oooo
200000060?ooo`800000603oool8000001/0oooo00<000000?ooo`3oool0:`3oool3000001T0oooo
0P00000?0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P0000050?ooo`030000003oool000000080
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo
0?ooo`0Q0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`00000000000P3oool01000
0000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool00P3oool4000000`0oooo0P00000K0?ooo`@0000000<0oooo
0000000000001000000G0?ooo`030000003oool0oooo02h0oooo0P00000I0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0203oool200000080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00800000103oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool08@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0000000000080oooo
00D000000?ooo`3oool0oooo000000050?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool05`3oool00`000000oooo00000003000000h0oooo0P00000J0?ooo`<000002`3oool60000
0140oooo00<000000?ooo`3oool0<03oool2000001P0oooo0P00000>0?ooo`8000002P3oool01000
0000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P000004
0?ooo`030000003oool000000080oooo0P00000S0?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo0200oooo00@000000?ooo`3oool000000P3oool010000000oooo00000000
00030?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`00000000000`3oool00`000000
oooo0?ooo`0F0?ooo`@000003`3oool3000001P0oooo1000000D0?ooo`D00000303oool00`000000
oooo0?ooo`0b0?ooo`<000005`3oool2000000h0oooo00<000000?ooo`3oool0203oool010000000
oooo0?ooo`00000:0?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`090?ooo`00A03oool200000240oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`80
00000P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000@0oooo00<000000?oo
o`3oool05@3oool200000140oooo0P00000H0?ooo`<000007@3oool4000000P0oooo00<000000?oo
o`3oool0=@3oool2000001L0oooo0P00000=0?ooo`030000003oool0oooo00P0oooo0P0000000`3o
ool000000?ooo`090?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool07P3oool3000000/0oooo0014
0?ooo`030000003oool0oooo01l0oooo0P0000001P3oool000000?ooo`3oool000000?ooo`800000
0`3oool00`000000oooo000000060?ooo`8000001@3oool00`000000oooo0?ooo`0C0?ooo`<00000
403oool2000001P0oooo0P00000T0?ooo`@00000103oool00`000000oooo0?ooo`0g0?ooo`800000
5`3oool00`000000oooo0?ooo`0;0?ooo`8000002P3oool00`000000oooo000000090?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P0000030?ooo`040000003oool0oooo00000080
oooo0P00000Q0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`0000000P3oool010000000oooo0000000000030?ooo`030000003oool0000000H0
oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0B0?ooo`80000000<0oooo0000003o
ool03P3oool2000001L0oooo0`00000Z0?ooo`D00000>`3oool2000001H0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0000000T0oooo00<000000?ooo`3o
ool00P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0
oooo01h0oooo0P000000203oool000000?ooo`000000oooo0000003oool000000`3oool2000000H0
oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0B0?ooo`040000003oool000000000
00h0oooo0P00000G0?ooo`800000<@3oool4000003X0oooo0`00000D0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo0080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`040000003oool0oooo00000080
oooo0P00000P0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01d0oooo
0P000000103oool000000?ooo`0000020?ooo`8000000`3oool2000000H0oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`0A0?ooo`80000000<0oooo0000003oool03P3oool00`000000
oooo0?ooo`0?0?oooa000000:`3oool010000000oooo0?ooo`3oool4000003T0oooo0P00000C0?oo
o`8000003@3oool2000000P0oooo00@000000?ooo`3oool000002@3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`80
00007`3oool00`000000oooo0?ooo`090?ooo`00=03oool00`3OW4P00000000000030000000304RL
g`3oool0oooo00L0oooo00<000000?ooo`3oool07@3oool2000000030?ooo`00000000000080oooo
0P0000040?ooo`8000001@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0100
oooo0P0000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool<000000<0
oooo0P00000;0?ooo`T000008P3oool00`000000oooo0?ooo`050?ooo`@00000=`3oool2000001<0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
0000203oool01@000000oooo0?ooo`3oool000000080oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool02@3oool003D0oooo00<0
okmd001d_`3oool00P3oool00`2oM7@0_ooo0?ooo`070?ooo`030000003oool0oooo01`0oooo0P00
0000203oool000000?ooo`000000oooo0000003oool000000`3oool2000000H0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`0?0?ooo`8000000`3oool00`000000oooo0?ooo`0<0?oo
o`8000000`3oool4000000`0oooo0`00000F0?ooo`H00000703oool00`000000oooo0?ooo`090?oo
o`<00000=P3oool200000180oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`8000007P3o
ool00`000000oooo0?ooo`090?ooo`00=P3oool00`3o_g@007Bo0?ooo`0;0?ooo`030000003oool0
oooo01`0oooo0P0000001`3oool000000000003oool000000?ooo`000000103oool2000000D0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo0?ooo`80
00003P3oool00`000000oooo0?ooo`03000000h0oooo0P00000O0?ooo`H000005P3oool00`000000
oooo0?ooo`0<0?ooo`<00000=@3oool200000140oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool010000000
oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?oo
o`00000N0?ooo`030000003oool0oooo00T0oooo000g0?ooo`030?noM000M;l0oooo00X0oooo00<0
00000?ooo`3oool06`3oool02P000000oooo000000000000oooo0000003oool000000?ooo`000003
0?ooo`8000001@3oool00`000000oooo000000030?ooo`030000003oool0oooo00l0oooo00D00000
0?ooo`3oool0oooo0000000?0?ooo`@000003`3oool2000002L0oooo1000000B0?ooo`030000003o
ool0oooo00l0oooo0`00000d0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool01000
0000oooo00000000000M0?ooo`030000003oool0oooo00T0oooo000W0?ooo`030?oog`2LB0000000
00L0000000<0B9cO0?ooo`3oool0103oool00`3o_g@0B9cO0?ooo`090?ooo`030000003oool0oooo
01/0oooo0`0000001P3oool000000?ooo`000000oooo000000@0oooo0P0000040?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool03@3oool2000000<0oooo00<000000?ooo`3oool0
2`3oool300000140oooo0P00000]0?ooo`@000003P3oool00`000000oooo0?ooo`0B0?ooo`<00000
<P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`02000000<0oooo00@000000?ooo`3oool000007@3oool00`00
0000oooo0?ooo`090?ooo`00>@3oool00`3OW4P0B9cO0?ooo`080?ooo`<000006P3oool01`000000
oooo000000000000oooo0000003oool00P0000040?ooo`800000103oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool0oooo0P00000:0?ooo`D00000
4P3oool00`000000oooo0?ooo`0a0?ooo`@000002P3oool00`000000oooo0?ooo`0E0?ooo`<00000
5P3ooolE000000D0oooo0P00000@0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0
00000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`00000000006P3o
ool3000000/0oooo000j0?ooo`030;md001d_ol0oooo00L0oooo00<000000?ooo`3oool06P3oool3
00000080oooo0P0000000`3oool000000?ooo`030?ooo`8000000`3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`800000
0`3oool00`000000oooo0?ooo`0?0?ooo`800000>03oool4000000H0oooo00<000000?ooo`3oool0
603oool3000000T0oooo2P00000E0?ooo`H0000000<0oooo0000003oool03`3oool2000000`0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02000000<0oooo00@000000?ooo`3o
ool00000703oool00`000000oooo0?ooo`090?ooo`00>P3oool00`3ogi`0B01d0;ooo`070?ooo`03
0000003oool0oooo01T0oooo00L000000?ooo`00000000000?ooo`000000oooo00800000103oool2
000000@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0;0?ooo`8000000`3o
ool00`000000oooo0?ooo`080?ooo`040000003oool0oooo0?ooo`8000004@3oool00`000000oooo
0?ooo`0l0?ooo`@000000P3oool00`000000oooo0?ooo`0K0?ooo`T000009@3oool400000100oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01@3oool01P000000oooo0?ooo`000000oooo000000<0oooo0P0000030?oo
o`040000003oool00000000001/0oooo00<000000?ooo`3oool02@3oool003X0oooo00<0oooO09a8
001d_ol01`3oool00`000000oooo0?ooo`0I0?ooo`<000000P3oool3000000D0oooo0P0000030?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo0P0000030?ooo`030000003oool0oooo00l0oooo0P000013
0?ooo`<000006@3oool500000080oooo0`00000[0?ooo`<000003`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0
oooo008000006P3oool00`000000oooo0?ooo`090?ooo`00>P3oool00`3ookl0M00004RLg`070?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`0000000`3oool3000000@0oooo0P0000030?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo04D0oooo1000000B0?ooo`@000002P3oool2000002/0oooo0`00000>
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`02
000000<0oooo00@000000?ooo`00000000006P3oool00`000000oooo0?ooo`090?ooo`00=P3oool0
1`3o_g@004RL0=ooo`3oool0gia80000B02Lgol01`3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool000000080oooo00<000000?ooo`0000001@3oool2000000<0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`090?ooo`8000001@3oool00`000000oooo0?ooo`060?ooo`04
0000003oool0oooo0?ooo`8000004@3oool00`000000oooo0?ooo`160?ooo`040000003oool0oooo
0?ooo`<000002P3oool500000100oooo0`00000Y0?ooo`@000003@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0
0000008000006@3oool00`000000oooo0?ooo`090?ooo`00=`3oool01@3ogi`0B000000000000000
M;oo00P0oooo00<000000?ooo`3oool05`3oool00`000000oooo000000030?ooo`<00000103oool2
000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool2000000<0oooo00<000000?ooo`3oool03`3o
ool2000000@0oooo6`00000Z0?ooo`030000003oool0oooo00@0oooo0`0000030?ooo`@00000603o
ool3000002P0oooo00@000000?ooo`0000000000303oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool000000080oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo0080
00006@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0G0?ooo`030000
003oool000000080oooo00<000000?ooo`0000001@3oool2000000<0oooo00<000000?ooo`000000
103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`000000
1000000K0?ooo`H00000903oool00`000000oooo0?ooo`060?ooo`D000007P3oool2000002L0oooo
00<000000?ooo`3oool00P00000;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000
0`3oool010000000oooo0000000000030?ooo`050000003oool000000?ooo`000000603oool00`00
0000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0000000<0
oooo00<000000?ooo`000000103oool2000000<0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo1000000V0?ooo`H000007P3oool00`00
0000oooo0?ooo`030?ooo`<000001@3oool3000001d0oooo0P00000V0?ooo`8000000P3oool20000
00X0oooo0P0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`050?ooo`8000000`3oool01@000000oooo0000003oool000000080oooo00<00000
0?ooo`0000000P00000H0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`0000000`3oool2000000D0oooo0P0000030?ooo`030000003oool00000
00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo0P0000040?ooo`030000003oool0oooo00h0oooo0P00000_0?ooo`H00000603oool00`00
0000oooo00000003000000/0oooo0`00000L0?ooo`8000009P3oool010000000oooo0?ooo`3oool2
000000X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo000000030?ooo`80000000<0oooo
0000003oool00P3oool010000000oooo00000000000H0?ooo`030000003oool0oooo00T0oooo0014
0?ooo`030000003oool0oooo01H0oooo0`0000020?ooo`030000003oool0000000@0oooo0P000004
0?ooo`800000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo0P00000g
0?ooo`D000004P3oool300000180oooo0`00000K0?ooo`8000009@3oool00`000000oooo0?ooo`02
0?ooo`8000002@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`8000000`3oool01@000000oooo0000003o
ool000000080oooo00<000000?ooo`0000000P00000G0?ooo`030000003oool0oooo00T0oooo0014
0?ooo`8000005`3oool2000000<0oooo0P0000050?ooo`8000000`3oool2000000@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`800000?P3oool4000000X0oooo10000000
0`3oool000000?ooo`0E0?ooo`<000006P3oool2000002@0oooo0P0000040?ooo`800000203oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`800000103oool2000000030?ooo`000000oooo0080oooo00@00000
0?ooo`00000000005@3oool3000000/0oooo00140?ooo`030000003oool0oooo01D0oooo0`000003
0?ooo`800000103oool2000000@0oooo0P0000040?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0103oool010000000oooo0?ooo`3oool2000000H0oooo00<000000?ooo`3oool02P3o
ool3000004<0oooo100000030?ooo`<000001@3oool00`000000oooo0?ooo`0G0?ooo`8000006@3o
ool=000001X0oooo00<000000?ooo`3oool00`3oool2000000L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool2000000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo00000000000G0?ooo`03
0000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01D0oooo0P0000030?ooo`030000
003oool0000000@0oooo0P0000030?ooo`800000103oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00T0
oooo0P0000000`3oool000000?ooo`170?ooo`<00000203oool00`000000oooo0?ooo`0I0?ooo`<0
00002P3oool<000000<0oooo0P0000080?ooo`L00000503oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool2000000@0oooo0P0000001P3oool0
00000?ooo`3oool000000?ooo`8000005`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`00
0000oooo0?ooo`0E0?ooo`8000000`3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`0000001`3oool00`000000oooo0?ooo`080?ooo`8000000P3oool00`000000oooo0?ooo`14
0?ooo`<000000`3oool3000000D0oooo00<000000?ooo`3oool0703oool3000000030?ooo`000000
000000@000004@3oool2000000d0oooo0`00000B0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`8000001@3oool010000000oooo0?ooo`00
00020?ooo`040000003oool00000000001H0oooo00<000000?ooo`3oool02@3oool004@0oooo00<0
00000?ooo`3oool05@3oool200000080oooo00<000000?ooo`000000103oool2000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00@0
00000?ooo`3oool000001`3oool00`000000oooo0?ooo`070?ooo`8000000`3oool00`000000oooo
0?ooo`110?ooo`@000002@3oool4000000030?ooo`000000oooo01/0oooo1`00000H0?ooo`030000
003oool0oooo00d0oooo1000000?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`800000103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool00000000001H0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3o
ool0503oool2000000<0oooo0`0000030?ooo`800000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`3oool01P3oool2000000@0oooo00<000000?ooo`3oool0?`3oool30000
0140oooo0`00000E0?ooo`H000001`3oool3000001H0oooo0P00000A0?ooo`8000003P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool20000
00D0oooo00@000000?ooo`3oool000000P3oool3000001H0oooo00<000000?ooo`3oool02@3oool0
04@0oooo00<000000?ooo`3oool0503oool2000000<0oooo0P0000040?ooo`800000103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0103oool2000000D0oooo00<00000
0?ooo`3oool0?@3oool3000001D0oooo00<000000?ooo`0000000P00000>0?ooo`@00000403oool2
000001H0oooo0P00000A0?ooo`800000303oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0103oool2000000@0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo00000000000E0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003o
ool0oooo01@0oooo0P0000020?ooo`030000003oool0000000<0oooo0P0000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`040000003o
ool0oooo000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo03/0oooo0`00000H0?ooo`030000003oool0oooo0080oooo100000060?ooo`@00000
5P3oool2000001H0oooo00<000000?ooo`3oool0403oool2000000/0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1@3oool01@000000oooo0?ooo`3oool0000000H0oooo0P0000040?ooo`080000003oool0oooo0?oo
o`000000oooo0000003oool2000001D0oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool0503oool200000080oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00
00070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0j0?ooo`8000006`3oool00`000000oooo0?ooo`060?ooo`H00000703oool2000001D0oooo0P00
000B0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?oo
o`3oool0000000H0oooo00<000000?ooo`3oool00P3oool200000080oooo00H000000?ooo`3oool0
00000?ooo`00000E0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01<0
oooo0P0000030?ooo`8000000`3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000001`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3oool20000
01d0oooo00<000000?ooo`3oool0103oool4000000030?ooo`000000000001l0oooo0P00000E0?oo
o`8000004@3oool2000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0
000000H0oooo0P0000040?ooo`080000003oool0oooo0?ooo`000000oooo0000003oool2000001@0
oooo00<000000?ooo`3oool02@3oool004@0oooo0P00000D0?ooo`8000000P3oool3000000<0oooo
0P0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo03P0oooo0P00000O0?ooo`040000003oool0oooo0?oo
o`<000001`3oool3000001h0oooo0P00000E0?ooo`8000004@3oool2000000T0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool000000080oooo0`00000B0?ooo`<000002`3oool004@0oooo00<00000
0?ooo`3oool04P3oool300000080oooo0P0000030?ooo`8000001@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0g0?ooo`8000008@3oool4000000d0oooo0P00000N0?ooo`8000005@3oool00`000000oooo0?oo
o`0@0?ooo`800000203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`8000000`3oool010000000oooo0000
003oool2000001<0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool04P3o
ool3000000040?ooo`0000000000000000<0oooo0P0000040?ooo`800000103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000001`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0=P3oool200000240
oooo0`00000B0?ooo`<000007@3oool2000001@0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000090?oo
o`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000050?ooo`800000103oool0
1@000000oooo0?ooo`3oool000000080oooo0`00000C0?ooo`030000003oool0oooo00T0oooo0014
0?ooo`030000003oool0oooo0180oooo0P0000020?ooo`<000000P3oool2000000D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0=@3oool200000200oooo0`0000020?ooo`030000003oool0oooo01<0oooo0`00
000D0?oooaH000001`3oool00`000000oooo0?ooo`0A0?ooo`8000001P3oool00`000000oooo0?oo
o`050?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000000P3oool3000001<0oooo00<000000?ooo`3oool02@3oool004@0oooo
00<000000?ooo`3oool04@3oool300000080oooo0P0000030?ooo`800000103oool2000000D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000L0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03@0oooo
0P00000O0?ooo`<000001@3oool00`000000oooo0?ooo`0F0?ooo`8000002@3oool9000000X0oooo
00<000000?ooo`3oool02@3oool4000000@0oooo00<000000?ooo`3oool04P3oool2000000D0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00D0
oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo0P0000030?oo
o`030000003oool00000008000004`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000
oooo0?ooo`0A0?ooo`<0000000@0oooo00000000000000000P3oool2000000D0oooo0P0000040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000006
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0c
0?ooo`8000007P3oool3000000P0oooo00<000000?ooo`3oool0603oool300000080oooo1000000D
0?ooo`8000003@3oool300000080oooo0P00000D0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01@3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`800000
0`3oool010000000oooo0000003oool200000180oooo00<000000?ooo`3oool02@3oool004@0oooo
00<000000?ooo`3oool0403oool01@000000oooo000000000000oooo008000000`3oool2000000D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0<P3oool2000001h0oooo0P00000;0?ooo`030000003oool0oooo01T0
oooo1000000J0?ooo`030000003oool0oooo00d0oooo1@00000D0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo0P0000020?ooo`030000003oool0oooo00<000004P3oool00`000000oooo0?ooo`090?oo
o`00A03oool00`000000oooo0?ooo`0@0?ooo`<000000P3oool2000000<0oooo00<000000?ooo`3o
ool00`3oool2000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0340oooo0P00000N0?ooo`8000003@3oool00`000000oooo0?ooo`0E0?ooo`@0
0000103oool2000001T0oooo0P00000A0?ooo`800000503oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00D0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2000000<0oooo0P0000020?oo
o`030000003oool0oooo00<000004P3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000
oooo0?ooo`0?0?ooo`050000003oool000000000003oool00`0000020?ooo`8000001@3oool20000
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`8000001`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<03oool20000
01d0oooo0`00000?0?ooo`030000003oool0oooo0140oooo1000000:0?ooo`8000006@3oool00`00
0000oooo0?ooo`0@0?ooo`8000004`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool2000000<0oooo00<0
00000?ooo`0000000P00000B0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0
oooo00l0oooo00D000000?ooo`00000000000?ooo`02000000<0oooo0P0000040?ooo`8000001@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool07`3ooolA000001d0oooo
0P00000B0?ooo`030000003oool0oooo00h0oooo0`00000@0?ooo`800000603oool200000140oooo
0`00000A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
000000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`8000000`3oool200000080oooo00D000000?ooo`000000oooo0000000B0?ooo`03
0000003oool0oooo00T0oooo00140?ooo`800000403oool00`000000oooo00000002000000030?oo
o`000000oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`8000001`3oool01@000000oooo0?ooo`3oool0000000L0
oooo00<000000?ooo`3oool0703oool4000000d0oooo0P0000020?ooo``000003`3oool2000001@0
oooo00<000000?ooo`3oool02P3oool4000001D0oooo0P00000H0?ooo`030000003oool0oooo00l0
oooo00@000000?ooo`0000000000403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool2000000<0oooo0P0000020?ooo`030000003oool0oooo
00800000403oool3000000/0oooo00140?ooo`030000003oool0oooo00l0oooo0`000000103oool0
00000000000000030?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo
000000P0oooo00<000000?ooo`3oool0603oool4000000l0oooo0P00000@0?ooo`H000001P3oool3
000001H0oooo00<000000?ooo`3oool01`3oool3000001/0oooo0P00000G0?ooo`800000403oool0
10000000oooo0?ooo`00000@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool2000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`030000003oool0oooo00<00000
4@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0>0?ooo`050000003o
ool000000000003oool00P0000030?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool0
0000203oool00`000000oooo0?ooo`0G0?ooo`8000004P3oool00`000000oooo0?ooo`0F0?ooo`H0
00006@3oool00`000000oooo0?ooo`050?ooo`800000803oool2000001L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`02000000l0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000030?ooo`8000000P3oool00`000000
oooo0000000200000140oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo00000002000000030?ooo`000000oooo0080oooo0P0000040?ooo`800000
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo000000090?ooo`030000003oool0oooo01D0oooo0P00000B0?ooo`800000
6`3oool2000000040?ooo`0000000000000001L0oooo00<000000?ooo`3oool00P3oool3000002@0
oooo0P00000F0?ooo`8000003`3oool010000000oooo0?ooo`3oool2000000h0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`8000000`3oool2
00000080oooo00D000000?ooo`000000oooo0000000A0?ooo`030000003oool0oooo00T0oooo0014
0?ooo`030000003oool0oooo00h0oooo0`000000103oool000000000000000030?ooo`030000003o
ool0oooo0080oooo0P0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool2000000L0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`0D0?ooo`8000004`3o
ool00`000000oooo0?ooo`0H0?ooo`<000001P3oool4000001<0oooo00<000000?ooo`0000000P00
000Y0?ooo`8000005P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo0P00
000=0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo000000070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000
0P3oool200000080oooo00<000000?ooo`3oool00P00000A0?ooo`030000003oool0oooo00T0oooo
00140?ooo`030000003oool0oooo00h0oooo0`000000103oool000000000000000030?ooo`030000
003oool0oooo0080oooo0P0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`060?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0
4`3oool2000001@0oooo00<000000?ooo`3oool05`3oool2000000d0oooo0`00000@0?ooo`800000
;P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000
oooo000000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`3oool200000080oooo00D000000?ooo`000000oooo000000020?ooo`8000004@3oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0>0?ooo`@0000000<0oooo0000
000000000`3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000090?oo
o`030000003oool0oooo0140oooo0P00000D0?ooo`800000603oool200000180oooo0`00000:0?oo
o`@00000<03oool2000001D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0
000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`070000003oool0
oooo0?ooo`000000oooo000000020?ooo`8000000P3oool010000000oooo00000000000A0?ooo`03
0000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000
0P0000000`3oool000000?ooo`020?ooo`8000000`3oool2000000D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`8000001`3oool00`000000oooo000000080?ooo`030000
003oool0oooo0100oooo0P00000E0?ooo`030000003oool0oooo01H0oooo0P00000G0?ooo`800000
1@3oool3000000<0oooo00<000000?ooo`3oool0<03oool2000001@0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0
oooo000000070?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000020?ooo`8000000P3oool01@000000
oooo0000003oool000000100oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3o
ool03@3oool400000080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`8000001@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo000000090?ooo`030000003oool0oooo00h0oooo0P00000F0?ooo`030000003oool0oooo
01D0oooo0P00000K0?ooo`D000001P3oool00`000000oooo0?ooo`0b0?ooo`8000004`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool01000
0000oooo0?ooo`0000080?ooo`8000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00<0oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000080oooo0P00000@0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
00d0oooo100000000`3oool00000000000030?ooo`070000003oool0oooo0?ooo`000000oooo0000
00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0D0?ooo`8000005P3oool2000001d0oooo1P0000050?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo000000080?ooo`030000003oool0000000H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P00
00020?ooo`80000000@0oooo0000003oool0oooo0P00000@0?ooo`030000003oool0oooo00T0oooo
00140?ooo`030000003oool0oooo00d0oooo100000000`3oool00000000000030?ooo`040000003o
ool0oooo0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
0P0000060?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06P3oool3000000H0oooo
0P0000030?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool010000000oooo
0?ooo`0000080?ooo`8000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool200000080oooo0P0000020?ooo`040000003oool000000000
0100oooo00<000000?ooo`3oool02@3oool004@0oooo0P00000>0?ooo`@0000000<0oooo00000000
00000`3oool010000000oooo0?ooo`3oool2000000D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo0P0000090?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`T000001P3oool20000
01/0oooo0P00000;0?ooo`@00000>03oool200000140oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`000000203oool20000
00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo0P0000020?ooo`060000003oool000000?ooo`000000oooo0`00000=0?ooo`<000002`3o
ool004@0oooo00<000000?ooo`3oool0303oool3000000030?ooo`000000oooo008000000P3oool2
000000<0oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00H000002@3oool9000001P0oooo0P00000@
0?ooo`<00000>03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000P0oooo0P00
00060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`080000003oool0oooo0000003oool000000?ooo`0000020?ooo`8000003`3oool00`00
0000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0<0?ooo`@000000P3oool010000000
oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool2000000T0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0C0?ooo`D000004@3oool2000000D0oooo1P00000?0?oo
o`<000004P3oool00`000000oooo0?ooo`02000003L0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo000000080?ooo`8000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool200000080oooo0P000000103oool000000?ooo`3oool2
000000l0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0303oool40000
0080oooo00D000000?ooo`3oool0oooo000000030?ooo`8000001@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo00000008
0?ooo`030000003oool0oooo00/0oooo0P00000D0?ooo`<00000503oool00`000000oooo0?ooo`0;
0?ooo`D00000203oool2000001D0oooo00<000000?ooo`3oool00P3oool3000003D0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0203oool00`000000oooo000000090?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P000002
0?ooo`040000003oool0000000000080oooo0P00000?0?ooo`030000003oool0oooo00T0oooo0014
0?ooo`030000003oool0oooo00`0oooo100000000`3oool00000000000030?ooo`040000003oool0
oooo0?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool2000000T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0A0?ooo`<0000000<0oooo0000003oool04P3oool2000001<0oooo100000020?ooo`8000005`3o
ool00`000000oooo0?ooo`050?ooo`<00000<`3oool200000100oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000203o
ool2000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00T000000?ooo`3oool000000?ooo`000000oooo0000003oool00`00000>0?oo
o`030000003oool0oooo00T0oooo000d0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3o
ool0203oool00`000000oooo0?ooo`0<0?ooo`80000000<0oooo0000003oool00P0000020?ooo`80
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000P0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0?0?ooo`<000000`3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01L0oooo1000000G0?ooo`030000003oool0oooo00P0oooo0P00000c0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo0?ooo`80000000@0oooo0000003oool0oooo0P00000>0?ooo`030000003oool0
oooo00T0oooo000f0?ooo`030?noM0000000M;oo00/0oooo00<000000?ooo`3oool02`3oool30000
00030?ooo`000000oooo008000000P3oool2000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool20000
00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`8000001@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo0`0000040?ooo`<00000503oool00`00
0000oooo0?ooo`0:0?ooo`<00000903oool6000000L0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool20000
00T0oooo0P0000060?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo00000005
0?ooo`040000003oool0oooo0?ooo`80000000@0oooo0000003oool0oooo0P00000>0?ooo`030000
003oool0oooo00T0oooo000f0?ooo`030?oog`2LB00007Bo00/0oooo00<000000?ooo`3oool02`3o
ool3000000030?ooo`000000oooo008000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`8000001P3o
ool2000000P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`8000001P3o
ool00`000000oooo0?ooo`0@0?ooo`8000005P3oool2000000X0oooo1000000@0?ooo`030000003o
ool0oooo00d0oooo0`00000K0?ooo`H000001P3oool600000080oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo000000080?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool200000080oooo0P000000103oool000000?oo
o`3oool2000000h0oooo00<000000?ooo`3oool02@3oool003L0oooo00<0gia80018W03Oool02P3o
ool00`000000oooo0?ooo`0;0?ooo`<0000000@0oooo0000003oool000000`3oool010000000oooo
0?ooo`3oool2000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo01@0oooo0P00000@0?ooo`@00000303oool00`000000oooo0?ooo`0@0?ooo`<0
00004P3oool600000180oooo1P00000>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`8000002@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo008000000P3oool00`000000oooo00000002000000d0oooo00<000000?ooo`3o
ool02@3oool002L0oooo00<0oooO09a8000000001`0000000`18W=l0oooo0?ooo`030?ooo`030?oO
W01804P0W=oo00X0oooo00<000000?ooo`3oool02`3oool2000000050?ooo`000000oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo0P0000080?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool04`3oool2000001H0oooo0`0000090?ooo`030000003oool0oooo
01<0oooo0P00000;0?ooo`D00000703oool00`000000oooo00000002000000/0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo0P0000090?oo
o`8000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`3oool2000000040?ooo`000000oooo0?ooo`8000003@3o
ool00`000000oooo0?ooo`090?ooo`00=`3oool00`3ookl0M00007Boo`0:0?ooo`<000002`3oool2
000000050?ooo`000000oooo0?ooo`0000000P3oool2000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`8000001`3o
ool00`000000oooo0?ooo`0?0?ooo`800000503oool2000001/0oooo0P0000070?ooo`030000003o
ool0oooo01D0oooo0`0000030?ooo`D000008P3oool010000000oooo0?ooo`3oool2000000X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo
0P0000080?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00001@3oool010000000oooo0?ooo`3oool2000000040?ooo`000000oooo0?ooo`8000002`3oool3
000000/0oooo000h0?ooo`030;md0000M;l0oooo00T0oooo00<000000?ooo`3oool02P3oool30000
00030?ooo`000000oooo008000000P3oool200000080oooo0P0000040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`8000007`3oool30000
00@0oooo00<000000?ooo`3oool05P3oool5000002P0oooo00<000000?ooo`3oool00P3oool20000
00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo0P0000080?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`0000001@3oool010000000oooo0?ooo`3oool2000000040?ooo`000000oooo0?ooo`800000
3@3oool00`000000oooo0?ooo`090?ooo`00>03oool00`3OW4P004RL0=ooo`090?ooo`030000003o
ool0oooo00X0oooo0`0000000`3oool000000?ooo`0200000080oooo00@000000?ooo`3oool0oooo
0P0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0A0?ooo`800000903oool200000080oooo00<000000?ooo`3oool04@3oool5000000D0oooo
0P00000W0?ooo`030000003oool0oooo00<0oooo0P0000070?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`800000203oool2000000L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0P0000030?ooo`080000003oool0oooo0000003oool000000?ooo`00000<0?ooo`030000003oool0
oooo00T0oooo000h0?ooo`030?oOW01804P0W=oo00T0oooo00<000000?ooo`3oool02P3oool20000
0080oooo00@000000?ooo`00000000000P3oool010000000oooo0?ooo`3oool2000000<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`8000001P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000001P00000:0?ooo`800000:03o
ool3000000h0oooo1@00000<0?ooo`8000009P3oool00`000000oooo0?ooo`040?ooo`8000001P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool2000000P0oooo0P0000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`8000000`3oool01@000000oooo0?ooo`000000oooo00<00000
303oool00`000000oooo0?ooo`090?ooo`00>03oool00`3ookl0M00007Boo`090?ooo`030000003o
ool0oooo00X0oooo0P0000020?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool0oooo
0P0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool4000000L0oooo
3@00000Y0?ooo`D000001@3oool5000001<0oooo0P00000U0?ooo`030000003oool0oooo00D0oooo
0P0000050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo0P0000070?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`3oool0oooo000000050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`02000000`0oooo00<000000?ooo`3oool02@3oool003T0oooo00<0_g@0001d_`3o
ool0203oool00`000000oooo0?ooo`0:0?ooo`8000000P3oool00`000000oooo000000020?ooo`80
00000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool500000140oooo0P0000040?ooo`H000008`3oool00`000000oooo0?ooo`020?ooo`D0
00006P3oool2000002@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`80
0000203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3o
ool0oooo000000050?ooo`040000003oool0oooo0?ooo`80000000@0oooo0000003oool0oooo0P00
000<0?ooo`030000003oool0oooo00T0oooo000g0?ooo`050?oo_`1d000000000000M02oool0203o
ool00`000000oooo0?ooo`090?ooo`<0000000D0oooo0000003oool0oooo000000020?ooo`800000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`800000203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`800000
0P3oool00`000000oooo0?ooo`0?0?ooo`800000303oool5000001h0oooo1@0000040?ooo`<00000
6P3oool2000002<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo0P0000060?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0
oooo000000050?ooo`040000003oool0oooo0?ooo`8000000P3oool01@000000oooo0000003oool0
000000/0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool02@3oool01P00
0000oooo0000003oool000000?ooo`8000000P3oool010000000oooo0?ooo`3oool2000000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`<000000`3oool00`000000oooo
0?ooo`0>0?ooo`8000004`3oool5000001D0oooo1@00000;0?ooo`@00000603oool200000240oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
0P0000070?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000050?ooo`03
0000003oool0oooo0080oooo00P000000?ooo`3oool000000?ooo`000000oooo000000/0oooo00<0
00000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool02@3oool01P000000oooo0000003o
ool000000?ooo`8000000P3oool010000000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo0P0000080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00D0oooo0P0000050?ooo`030000003oool0oooo00d0oooo0P00000J0?ooo`@0
0000303oool5000000@0oooo00<000000?ooo`3oool03@3oool4000001H0oooo0P00000P0?ooo`03
0000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo0P000003
0?ooo`080000003oool0oooo0000003oool000000?ooo`00000;0?ooo`030000003oool0oooo00T0
oooo00140?ooo`030000003oool0oooo00T0oooo00H000000?ooo`000000oooo0000003oool20000
00030?ooo`000000000000<0oooo0P0000030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`050?ooo`800000203oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool200000200oooo100000030?oo
o`D000002@3oool00`000000oooo0?ooo`0A0?ooo`<000005@3oool2000001l0oooo00<000000?oo
o`3oool01`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool2000000<0oooo0P00
00000`3oool000000?ooo`03000000/0oooo00<000000?ooo`3oool02@3oool004@0oooo0P00000:
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`8000000`3oool2000000<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
0P0000070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0280oooo1P00000=0?ooo`030000003oool0oooo01@0oooo
1000000@0?oooa4000004P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
0P0000070?ooo`8000001P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00001@3oool010000000oooo0?ooo`3oool200000080oooo0`0000000`3oool000000?ooo`070?oo
o`<000002`3oool004@0oooo00<000000?ooo`3oool0203oool2000000060?ooo`000000oooo0000
003oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo0P000008
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo01h0oooo1@0000060?ooo`H000001`3oool00`000000oooo0?ooo`0H
0?ooo`@000000`3oool900000140oooo1P00000<0?ooo`030000003oool0oooo00L0oooo00D00000
0?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool2000000L0oooo0P0000060?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo
000000050?ooo`040000003oool0oooo0?ooo`8000000P3oool01@000000oooo0000003oool00000
00X0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0203oool300000080
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`8000001P3oool2000000P0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool02P3oool2000001`0
oooo1@00000A0?ooo`P000005P3oool<000001l0oooo0P00000;0?ooo`030000003oool0oooo00L0
oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo0?ooo`8000000P3o
ool01@000000oooo0000003oool0000000X0oooo00<000000?ooo`3oool02@3oool004@0oooo00<0
00000?ooo`3oool0203oool3000000050?ooo`000000oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`8000001P3oool2000000L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05`3oool5000001d0oooo
5`00000<0?ooo`D00000703oool3000000T0oooo00<000000?ooo`3oool01`3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool2000000L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`000000103oool010000000oooo0?ooo`3oool200000080oooo00D000000?ooo`000000oooo0000
000:0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00P0oooo00H00000
0?ooo`000000oooo0000003oool2000000030?ooo`000000000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1@3oool2000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01`3ooolA00000280oooo00<000000?ooo`3oool09@3oool5000001X0
oooo0P0000080?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo0P0000070?ooo`8000001@3oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`3o
ool2000000<0oooo0P0000000`3oool000000?ooo`090?ooo`030000003oool0oooo00T0oooo0014
0?ooo`030000003oool0oooo00P0oooo00H000000?ooo`000000oooo0000003oool2000000030?oo
o`000000000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`050000
003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`080?ooo`800000103oool6000003<0
oooo00<000000?ooo`3oool0:P3oool4000001P0oooo0P0000060?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo0P0000070?ooo`8000001P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?oo
o`000000103oool2000000<0oooo00@000000?ooo`3oool0oooo1000000:0?ooo`030000003oool0
oooo00T0oooo00140?ooo`030000003oool0oooo00P0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`8000001`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000
1000000i0?ooo`030000003oool0oooo02h0oooo1000000F0?ooo`8000001@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`8000001`3oool2000000H0oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`3oool0000000@0oooo0P0000030?ooo`040000003oool0oooo0?ooo`@000002P3oool00`00
0000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`080?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`8000001`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo00P0oooo0`00000n0?ooo`030000003o
ool0oooo0380oooo0`00000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo000000090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`8000001P3oool00`000000oooo0?ooo`030?ooo`050000003o
ool0oooo0?ooo`0000001@3oool01@000000oooo0?ooo`3oool0000000<0oooo1000000:0?ooo`03
0000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00P0oooo00L000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000H0oooo0P0000070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01`3oool300000400oooo00<00000
0?ooo`3oool0=@3oool400000180oooo0P0000030?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`0000002@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo0P000007
0?ooo`8000001@3oool2000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000000`3oool4000000X0oooo00<000000?ooo`3oool02@3o
ool004@0oooo00<000000?ooo`3oool0203oool020000000oooo0000003oool000000?ooo`000000
oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`8000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000T0
oooo00<000000?ooo`3oool01@3oool300000480oooo00<000000?ooo`3oool0>@3oool300000140
oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0000000T0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`8000001`3oool2000000D0oooo0P0000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000<0oooo1000000:0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
00P0oooo00D000000?ooo`00000000000?ooo`02000000030?ooo`000000000000@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P000006
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`04
0?ooo`80000000<0oooo0000003oool0@P3oool00`000000oooo0?ooo`0l0?ooo`800000403oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`8000001`3oool2000000D0oooo0P0000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo
1000000:0?ooo`030000003oool0oooo00T0oooo00140?ooo`8000002@3oool01@000000oooo0000
00000000oooo0080000000<0oooo0000003oool0103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
203oool2000000X0oooo00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0n0?ooo`8000003`3oool010000000oooo0?ooo`0000090?ooo`80
00002@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool2000000D0oooo0P0000050?ooo`050000003oool0oooo0?ooo`000000103oool20000
0080oooo0P0000020?ooo`@00000203oool3000000/0oooo00140?ooo`030000003oool0oooo00P0
oooo00H000000?ooo`00000000000?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000T0oooo00@00000
0?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0@03o
ool2000000h0oooo00<000000?ooo`0000002@3oool00`000000oooo000000090?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0000000@0oooo0P0000050?ooo`050000003oool0oooo0?ooo`000000103oool200000080oooo
0P0000020?ooo`@000002P3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?oo
o`080?ooo`070000003oool000000000003oool000000?ooo`02000000D0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0103oool20000
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00P0oooo0P0000090?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo0480oooo0P00000<0?ooo`040000003oool0oooo000000T0oooo0P00
00090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool00000000000X0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0
203oool01`000000oooo000000000000oooo0000003oool00P0000040?ooo`800000103oool01@00
0000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0000
00090?ooo`8000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo0P00
00070?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`000000
00002P3oool00`000000oooo0?ooo`090?ooo`004`3oool00`3ookl0M7Bo0?ooo`0^0?ooo`030000
003oool0oooo00P0oooo00P000000?ooo`00000000000?ooo`000000oooo000000D0oooo0P000004
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo0P0000090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`150?ooo`8000002`3oool00`000000oooo000000090?ooo`800000
2@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo0P0000070?ooo`800000
1@3oool2000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo00000000000:0?ooo`030000003oool0oooo
00T0oooo000C0?ooo`040?oOW0180000001809cOobd0oooo00<000000?ooo`3oool01`3oool30000
00060?ooo`000000oooo0000003oool000001@3oool2000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00T0oooo0P0000090?ooo`8000002@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool2000000D0oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`00000000002P3oool00`000000
oooo0?ooo`090?ooo`005@3oool00`2oM000000000000003000000030000M02oool0oooo02H0oooo
00<000000?ooo`3oool01`3oool4000000050?ooo`00000000000?ooo`0000001@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P0000090?ooo`030000003oool0000000D0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`0000002@3oool2000000P0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo0P0000050?ooo`800000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000020?ooo`050000003oool0oooo0000
003oool00`0000090?ooo`030000003oool0oooo00T0oooo000I0?ooo`030?oOW0180000M;oo02P0
oooo00<000000?ooo`3oool01`3oool01P000000oooo000000000000oooo00000080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool2000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool2000000T0oooo0P000006
0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`08
0?ooo`8000002@3oool2000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo0P0000050?ooo`800000103oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo0?ooo`8000000P3oool01@000000oooo0?ooo`000000oooo00<00000
2@3oool00`000000oooo0?ooo`090?ooo`00603oool00`3OW4P0001d0;ooo`0Y0?ooo`030000003o
ool0oooo00L0oooo00H000000?ooo`00000000000?ooo`0000020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo0P0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo000000050?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0000000P0oooo0P0000090?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`800000103oool2000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00D000000?ooo`000000oooo000000090?ooo`030000003oool0oooo00T0oooo000C0?oo
o`060?oOW01804P0W=oo0?noM0000000B9cO:`3oool00`000000oooo0?ooo`070?ooo`060000003o
ool000000000003oool000000P3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`070?ooo`8000002@3oool2000000H0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo00P0oooo0P0000080?ooo`8000002@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo0P0000070?ooo`8000001@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000020?ooo`050000003oool000000?ooo`0000002@3oool00`000000oooo0?ooo`09
0?ooo`004`3oool0103ogi`0B00000000000M;l]0?ooo`800000203oool01P000000oooo00000000
0000oooo00000080oooo00<000000?ooo`3oool00P3oool2000000@0oooo00D000000?ooo`3oool0
oooo000000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool2000000T0
oooo0P0000050?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`070?ooo`8000002@3oool2000000P0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo0P0000050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
000000H0oooo0000003oool000000?ooo`0000070?ooo`<000002`3oool004@0oooo00<000000?oo
o`3oool01`3oool01P000000oooo000000000000oooo00000080oooo00<000000?ooo`3oool00P3o
ool2000000@0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00@0oooo
0P0000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo0P0000050?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`060?ooo`8000002@3oool2000000P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080000000H0oooo0000003oool000000?ooo`0000090?oo
o`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00L0oooo00<000000?ooo`00
00000`0000020?ooo`030000003oool0oooo0080oooo0P0000040?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`040?ooo`8000001P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?oo
o`8000001@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool01`3oool2000000P0oooo0P0000080?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`8000001@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020000
00060?ooo`000000oooo0000003oool000002@3oool00`000000oooo0?ooo`090?ooo`005P3oool0
1P3OW4P00000000000000000001809cOobP0oooo00<000000?ooo`3oool01`3oool010000000oooo
0000003oool200000080oooo00<000000?ooo`3oool00P3oool2000000@0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool20000
00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool01P3oool2000000T0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool20000
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P0000001P3oool000000?ooo`000000oooo000000T0oooo00<0
00000?ooo`3oool02@3oool001@0oooo00T0oono07@00018W=l0omnL09boo`3oool0gia80018W03O
ool09`3oool00`000000oooo0?ooo`070?ooo`040000003oool000000?ooo`8000000P3oool00`00
0000oooo0?ooo`020?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`800000203oool20000
00D0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool2000000L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool20000
00050?ooo`00000000000?ooo`0000000P3oool3000000P0oooo00<000000?ooo`3oool02@3oool0
01@0oooo00T0_gAd0;ooo`3oool0oknL09cOo`3oool0oono07@0M02oool09`3oool00`000000oooo
0?ooo`070?ooo`040000003oool000000?ooo`8000000P3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool2000000050?ooo`00000000000?ooo`0000000P3oool3000000P0oooo00<0
00000?ooo`3oool02@3oool001<0oooo00T0omnL09boo`3oool0oooO09adW03Oool0oooo0?oOW018
M;l0:03oool00`000000oooo0?ooo`070?ooo`040000003oool000000?ooo`8000000P3oool01000
0000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo00H0oooo0P0000080?ooo`800000203oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`03
0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P000000
1@3oool000000000003oool000000080oooo0`0000080?ooo`030000003oool0oooo00T0oooo000C
0?ooo`090?noW02Lgol0oooo0;md001d_ol0oooo0=nLB00007@0_ooo02P0oooo00<000000?ooo`3o
ool01P3oool2000000030?ooo`000000oooo008000000P3oool010000000oooo0?ooo`3oool20000
00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01`3oool2000000P0oooo0P0000040?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`050?ooo`8000002@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000001@3oool000000000003oool0
00000080oooo0`0000080?ooo`030000003oool0oooo00T0oooo000C0?ooo`040?oo_`1d00000000
07Boobd0oooo00<000000?ooo`3oool01P3oool2000000030?ooo`000000oooo008000000P3oool0
10000000oooo0?ooo`3oool2000000@0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool2000000P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool2000000030?ooo`000000oooo008000000P3oool3000000P0oooo00<000000?ooo`3oool0
2@3oool004@0oooo00<000000?ooo`3oool01P3oool4000000030?ooo`00000000000080oooo00@0
00000?ooo`3oool0oooo0P0000040?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000
oooo0?ooo`040?ooo`8000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01`3oool2000000P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool200000003
0?ooo`000000oooo008000000P3oool3000000P0oooo00<000000?ooo`3oool02@3oool004@0oooo
0P0000070?ooo`@0000000<0oooo0000000000000P3oool010000000oooo0?ooo`3oool2000000@0
oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00@0oooo0P0000060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo0500oooo00<000000?ooo`3oool01@3oool2000000P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool300000080oooo0`0000060?oo
o`<000002`3oool001L0oooo00H0okmd00000000000000000000M02ooolW0?ooo`030000003oool0
oooo00H0oooo100000000`3oool00000000000020?ooo`040000003oool0oooo0?ooo`800000103o
ool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0103oool2000000H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
0P0000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`1@0?ooo`030000003oool0oooo00D0oooo0P0000080?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`8000001`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`8000000P3oool300000080oooo0`0000080?ooo`030000003oool0oooo00T0oooo
000?0?ooo`060;nLW03Oool0oooo0?ooo`3ogi`0B0000`0000001000B9`0gooo0?oo_`1dM;lX0?oo
o`030000003oool0oooo00H0oooo10000000103oool000000000003oool2000000<0oooo0P000004
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool2000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo0500oooo00<000000?ooo`3oool01@3oool2000000P0oooo0P0000080?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool2000000L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool200000080oooo0`0000020?ooo`<00000203oool00`000000oooo0?ooo`090?ooo`003P3oool0
0`3ooml0W4P00000000300000003001d_`3oool0oooo0080oooo00<0okmd0000M02oool0:03oool0
0`000000oooo0?ooo`060?ooo`@0000000@0oooo000000000000oooo0P0000030?ooo`8000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool2000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo0P0000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00D0oooo0P0000080?ooo`800000203o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo0P0000070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo0P0000020?ooo`<000000P3oool3000000P0oooo00<000000?ooo`3oool02@3o
ool000h0oooo00<0oono07@00018W=l0<`3oool00`000000oooo0?ooo`060?ooo`@0000000@0oooo
000000000000oooo0P0000030?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool2000000H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo0P0000080?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1A0?ooo`030000003o
ool0oooo00@0oooo0P0000090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`8000000P3o
ool300000080oooo0`0000080?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0
oooo00H0oooo100000020?ooo`040000003oool00000000000<0oooo0P0000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000H0oooo0P0000060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`8000001`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0D@3o
ool00`000000oooo0?ooo`040?ooo`8000002@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool2000000L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0300000080oooo0P0000090?ooo`030000003oool0oooo00T0oooo000F
0?ooo`060?oOW018000000000000000004P0W=oo6P3oool0102oM00000000000001d_ol:0?ooo`03
0000003oool0oooo00H0oooo0`0000001@3oool000000?ooo`000000oooo008000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool20000
00H0oooo0P0000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`060?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`040?ooo`8000002@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool20000
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02000000030?ooo`000000oooo
008000002@3oool00`000000oooo0?ooo`090?ooo`005@3oool00`2oM000000007Boo`020?ooo`03
0?oog`2LM9`0gooo01P0oooo00H0gia8001d_`3oool0omnL04P00018W=l90?ooo`030000003oool0
oooo00H0oooo0`0000001@3oool000000?ooo`000000oooo008000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`050?ooo`8000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool2000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool200000080oooo0P00
00000`3oool000000?ooo`02000000T0oooo00<000000?ooo`3oool02@3oool001@0oooo00<0gia8
04RLg`3oool0103oool00`3OW9`0_ooo0?ooo`0F0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd
0000B02Lgol0203oool00`000000oooo0?ooo`060?ooo`<0000000D0oooo0000003oool000000?oo
o`02000000<0oooo0P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`050?ooo`8000001@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1A0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool2000000L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool200000080oooo0P0000000`3oool000000?ooo`02000000T0oooo00<000000?ooo`3oool02@3o
ool001<0oooo00<0omnL07BLg`3oool0103oool00`3ooml0W7BL0=ooo`0G0?ooo`030?oog`2LB000
B9cO0080oooo00@0oooO09a80000B9`0gooo1`3oool00`000000oooo0?ooo`060?ooo`<0000000D0
oooo0000003oool000000?ooo`02000000<0oooo0P0000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
0P0000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000020?ooo`80000000<0oooo0000003oool0
0P0000090?ooo`030000003oool0oooo00T0oooo000C0?ooo`030?noW02Lgol0oooo00<0oooo00<0
oooO09a8001d_ol0603oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00L0oooo00<0
00000?ooo`3oool01P3oool3000000050?ooo`000000oooo0000003oool00P0000030?ooo`800000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000
0P3oool01@000000oooo0?ooo`000000oooo008000002@3oool00`000000oooo0?ooo`090?ooo`00
4`3oool00`3ogi`0B7Bo0?ooo`020?ooo`030=nLB0000000B9cO01X0oooo00<0_g@00018W03Oool0
0P3oool00`3ogi`0B00004RLg`070?ooool00000HP00000;0?ooo`00503oool01P3o_g@000000000
0000000004RL0=oooa/0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`070?ooo`03
0000003oool0oooo00L0oooo0P0000001@3oool000000?ooo`000000oooo008000000`3oool20000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`8000001@3oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool200000080oooo00D00000
0?ooo`3oool000000?ooo`02000000T0oooo00<000000?ooo`3oool02@3oool003D0oooo00<0omnL
04P00018W=l00`3oool00`2oM00004RL0=ooo`060?ooo`030000003oool0oooo00L0oooo00L00000
0?ooo`3oool000000?ooo`000000oooo008000000`3oool2000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`800000103oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo0P0000050?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0
oooo000000040?ooo`8000000P3oool01@000000oooo0?ooo`000000oooo008000002@3oool00`00
0000oooo0?ooo`090?ooo`00=@3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo
00H0oooo00<000000?ooo`3oool01`3oool01`000000oooo0?ooo`000000oooo0000003oool00P00
00030?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo0P00
00040?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool2000000D0oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo0P0000020?ooo`050000
003oool0oooo0000003oool00P0000090?ooo`030000003oool0oooo00T0oooo000F0?ooo`060?oO
W018000000000000000004P0W=oo6P3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo
00H0oooo00<000000?ooo`3oool01`3oool01`000000oooo0?ooo`000000oooo0000003oool00P00
00030?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P00
00060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool2000000@0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00<0oooo0P00
00090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`050000003oool0oooo0?ooo`000000103oool200000080oooo00D000000?ooo`3oool0
00000?ooo`02000000T0oooo00<000000?ooo`3oool02@3oool001@0oooo00@0oooO09a80000B9`0
gooo0P3oool00`3o_g@004RL0=ooo`0J0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO1`3oool0
0`000000oooo0?ooo`070?ooo`070000003oool0oooo0000003oool000000?ooo`02000000<0oooo
0P0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool2000000H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`800000103oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0103oool2000000T0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`3oool0oooo000000040?ooo`8000000P3oool01@000000oooo0?ooo`000000oooo
00<00000203oool00`000000oooo0?ooo`090?ooo`00503oool00`2oM4P0W=oo0?ooo`030?ooo`03
0?oog`2LB7@0_ooo01/0oooo00@0gia800000000000007Bo203oool00`000000oooo0?ooo`070?oo
o`050000003oool0oooo0000003oool0100000030?ooo`8000000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0103oool2000000T0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`8000000P3oool01@000000oooo0?ooo`000000oooo00<00000
203oool00`000000oooo0?ooo`090?ooo`004`3oool00`3ogi`0W;oo0?ooo`040?ooo`030?oOW018
M;l0oooo02L0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`000000oooo00@00000
0`3oool2000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo0P0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`800000203oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo04h0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`040?ooo`800000
2@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool01@000000oooo0?ooo`3oool0000000@0oooo0P0000020?ooo`050000003oool0oooo0000
003oool00`0000080?ooo`030000003oool0oooo00T0oooo000C0?ooo`030?noW02Lgol0oooo00<0
oooo00<0omnL04Q8W03Oool0:03oool00`000000oooo0?ooo`060?ooo`8000000P3oool00`000000
oooo00000003000000@0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool2000000H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo0P0000080?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo
00@0oooo0P0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool20000
00D0oooo00D000000?ooo`3oool0oooo000000040?ooo`8000000P3oool01@000000oooo0?ooo`00
0000oooo00<00000203oool00`000000oooo0?ooo`090?ooo`004`3oool0103ookl0M0000000001d
_ol]0?ooo`030000003oool0oooo00H0oooo0P0000020?ooo`030000003oool0000000<00000103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`8000001P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`800000103o
ool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0103o
ool2000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`8000001@3o
ool01@000000oooo0?ooo`3oool0000000@0oooo0P0000020?ooo`80000000<0oooo0000003oool0
0`0000080?ooo`030000003oool0oooo00T0oooo00140?ooo`8000001`3oool200000080oooo00<0
00000?ooo`0000000`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo0P0000060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo0P0000040?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`050?ooo`800000203oool2000000L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3o
ool2000000D0oooo00D000000?ooo`3oool0oooo000000040?ooo`8000000P3oool2000000030?oo
o`000000oooo00<000001P3oool3000000/0oooo00140?ooo`030000003oool0oooo00H0oooo0P00
00020?ooo`030000003oool0000000<00000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool2000000D0oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`050000003o
ool0oooo0?ooo`000000103oool200000080oooo0P0000000`3oool000000?ooo`03000000P0oooo
00<000000?ooo`3oool02@3oool001<0oooo00<0oono09bLg`3oool00`3oool0103o_g@000000000
M02ooolW0?ooo`030000003oool0oooo00H0oooo0P0000020?ooo`030000003oool0000000<00000
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
D03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo0P0000020?ooo`80000000<0oooo0000003oool00`0000080?ooo`030000
003oool0oooo00T0oooo000C0?ooo`040?oo_`2LW=l0oono07@000@0000000<004RL0=ooo`3oool0
9P3oool00`000000oooo0?ooo`060?ooo`<0000000<0oooo0000003oool00P0000000`3oool00000
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool2000000P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0500oooo
00<000000?ooo`3oool0103oool2000000T0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0P0000020?ooo`80000000<0oooo0000003oool00`0000080?ooo`030000003oool0oooo00T0oooo
000C0?ooo`090?oOW018000000000000B02Lgol0oooo0?oog`2LB7@0_ooo02P0oooo00<000000?oo
o`3oool01P3oool300000080oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool2000000P0oooo0P0000050?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo0P0000070?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`80000000<0oooo0000003oool00`00
00080?ooo`030000003oool0oooo00T0oooo000?0?ooo`040?oog`2LB000001d0;oooc40oooo00<0
00000?ooo`3oool01P3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`000000
103oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool2000000P0oooo0P0000050?ooo`030000
003oool0oooo04`0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo0P0000070?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`80000000<0oooo0000003o
ool00`0000080?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000000@0oooo0P0000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`8000001P3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo04h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`80
00001P3oool2000000D0oooo0P0000040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool0oooo0P0000020?ooo`060000003oool000000?ooo`000000oooo0`0000080?ooo`030000003o
ool0oooo00T0oooo000C0?ooo`050?oO_`2ogol0oooo0?ooo`2oM0000`0000000`0007@0_ooo0?oo
o`0V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000@0oooo0P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P0000080?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool2000000H0oooo00<000000?ooo`3oool0
103oool2000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool200000080
oooo00H000000?ooo`000000oooo0000003oool3000000P0oooo00<000000?ooo`3oool02@3oool0
01<0oooo00<0_g@00000000000000P0000001@0007@0_ooo0?ooo`2oW9`0gooo02L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo000000020?ooo`050000003oool000000?ooo`000000103o
ool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool2000000P0oooo0P0000060?ooo`030000003o
ool0oooo04X0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`800000103o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000000P3oool01P000000oooo
0000003oool000000?ooo`<00000203oool00`000000oooo0?ooo`090?ooo`004@3oool01@2oM000
000000000000B9`0gooo00<0oooo00<0oooO09a8001d_ol00P3oool00`2oM00004RL0=ooo`0S0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0
000000@0oooo0P0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`8000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0
oooo00D0oooo0P0000090?ooo`800000203oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool200000080oooo00H0
00000?ooo`000000oooo0000003oool3000000P0oooo00<000000?ooo`3oool02@3oool001<0oooo
00<0oknL09cOo`3oool0203oool00`3ogi`0B7Bo0?ooo`0S0?ooo`8000001`3oool00`000000oooo
000000020?ooo`050000003oool000000?ooo`000000103oool2000000<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo0P0000060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo0P0000070?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`050?ooo`8000002@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo0?ooo`8000000P3oool01P000000oooo0000003oool000000?ooo`<000001P3o
ool3000000/0oooo000C0?ooo`030?oo_`1dM;l0oooo00L0oooo00<0okmd0018W03Oool0903oool0
0`000000oooo0?ooo`060?ooo`0:0000003oool000000000003oool000000?ooo`000000oooo0000
00@0oooo0P0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`8000001P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool2000000T0oooo0P0000070?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`060?ooo`8000002@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`8000000P3oool200000080oooo00<00000
0?ooo`0000000P0000080?ooo`030000003oool0oooo00T0oooo000C0?ooo`040?oOW0180000001d
0;ooo`D0oooo00<0gia8001d_`3oool09@3oool00`000000oooo0?ooo`060?ooo`0:0000003oool0
00000000003oool000000?ooo`000000oooo000000D0oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool2000000H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P000009
0?ooo`800000203oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo04`0oooo00<00000
0?ooo`3oool01@3oool2000000X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3o
ool200000080oooo0P0000020?ooo`030000003oool0000000800000203oool00`000000oooo0?oo
o`090?ooo`00503oool00`3ogi`0B000000000050000000304RLg`3oool0oooo02D0oooo00<00000
0?ooo`3oool01P3oool02@000000oooo000000000000oooo0000003oool000000?ooo`02000000@0
oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool2000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00P0oooo0P0000090?ooo`800000203oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo04/0oooo00<000000?ooo`3oool01P3oool2000000X0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool2000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`050000003oool0oooo0?ooo`0000000`3oool200000080oooo00<000000?ooo`0000000P000008
0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030?noM00004P0W=oo02P0oooo00<000000?oo
o`3oool01P3oool02@000000oooo000000000000oooo0000003oool000000?ooo`02000000@0oooo
00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`8000002@3oool00`000000oooo000000080?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0000000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool2000000H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`3oool20000
0080oooo00<000000?ooo`0000000P0000080?ooo`030000003oool0oooo00T0oooo000H0?ooo`03
0;md0000M;l0oooo02T0oooo00<000000?ooo`3oool01P3oool02@000000oooo000000000000oooo
0000003oool000000?ooo`02000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`8000002@3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo04<0oooo
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`060?ooo`8000002P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`8000000P3oool00`000000oooo00000002000000P0
oooo00<000000?ooo`3oool02@3oool001<0oooo00H0omnL04P0001d_ol0okmd0000001d_ol[0?oo
o`030000003oool0oooo00H0oooo00T000000?ooo`00000000000?ooo`000000oooo0000003oool0
0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`8000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`8000002@3oool010000000oooo
0?ooo`0000080?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0BP3oool00`000000
oooo0?ooo`050?ooo`030000003oool0000000T0oooo0P0000080?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`8000001@3oool2000000@0
oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo0P0000020?oo
o`@000002@3oool00`000000oooo0?ooo`090?ooo`004`3oool0103ogi`0B00000000000M;l]0?oo
o`030000003oool0oooo00L0oooo0`000000103oool000000?ooo`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo0P0000060?ooo`8000001P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0203oool2000000T0oooo00D000000?ooo`3oool0oooo0000
00080?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0000000X0oooo0P0000080?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo0P00
00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`000000oooo000000090?ooo`030000003oool0oooo00T0
oooo00140?ooo`030000003oool0oooo00L0oooo0P0000001@3oool000000000003oool000000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000
oooo000000090?ooo`050000003oool0oooo0?ooo`000000203oool200000440oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000T0oooo0P000009
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool2000000H0oooo0P000006
0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`050000003oool000000?ooo`0000002@3oool00`000000oooo
0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`070?ooo`80000000D0oooo000000000000oooo
000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`080?ooo`8000002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`0000002P3oool2000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo0P0000060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0000003oool0000000T0oooo00<000000?ooo`3oool02@3oool004@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo00000002000000050?ooo`000000oooo0?oo
o`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`0000002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00D0oooo00@000000?oo
o`3oool000002@3oool2000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo0P0000060?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01@000000oooo0000003oool0000000T0oooo00<000000?ooo`3oool02@3oool004@0oooo0P00
00080?ooo`030000003oool000000080000000D0oooo0000003oool0oooo000000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0203oool2000000X0oooo00<000000?ooo`3oool0
0P3oool2000000P0oooo0P00000m0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
1@3oool010000000oooo0?ooo`00000:0?ooo`8000002@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool0000000L0oooo0`00000;
0?ooo`00A03oool00`000000oooo0?ooo`070?ooo`030000003oool000000080000000D0oooo0000
003oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool0
0`000000oooo000000090?ooo`030000003oool0oooo00@0oooo0P0000080?ooo`800000>`3oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000
00090?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`8000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080000000L0
oooo0000003oool0oooo0000003oool0000000T0oooo00<000000?ooo`3oool02@3oool004@0oooo
00<000000?ooo`3oool01`3oool01@000000oooo000000000000oooo008000000`3oool010000000
oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00D0oooo0P0000070?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000T0oooo00<000000?oo
o`3oool01@3oool3000000L0oooo0P00000i0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0103oool2000000<0oooo00<000000?ooo`3oool0203oool2000000T0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`8000001`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo0?ooo`80000000<0oooo0000003oool0100000090?ooo`030000003oool0
oooo00T0oooo00140?ooo`030000003oool0oooo00P0oooo0`000000103oool00000000000000002
0?ooo`040000003oool0oooo0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01@3oool2000000L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`080?ooo`<000001P3oool3000003H0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool2000000H0oooo0P0000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo00000003000000T0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0
203oool3000000040?ooo`000000oooo00000080oooo00@000000?ooo`3oool0oooo0P0000040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0:
0?ooo`D00000103oool2000003@0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool2000000T0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000`00
00090?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00P0oooo0P000000
1@3oool000000000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P0000070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00h0
oooo2@00000a0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool00`3oool2000000H0
oooo00<000000?ooo`3oool01`3oool00`000000oooo000000090?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool2000000L0oooo00<000000?ooo`3oool0103oool2000000D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo00000002000000X0oooo00<000000?ooo`3oool02@3oool004@0
oooo00<000000?ooo`3oool0203oool2000000050?ooo`00000000000?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool05@3oool>000002D0oooo00<00000
0?ooo`3oool0@@3oool010000000oooo0?ooo`3oool2000000L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo000000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3o
ool2000000L0oooo00<000000?ooo`3oool0103oool2000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`<0
00002P3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`080?ooo`800000
00D0oooo000000000000oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01@3oool2000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01P0oooo0`0000070?ooo`d00000603oool00`000000oooo0?ooo`020?ooo``0
0000<P3oool00`000000oooo0?ooo`02000000T0oooo00<000000?ooo`3oool01`3oool00`000000
oooo000000090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool2000000L0
oooo00<000000?ooo`3oool0103oool2000000@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080000000@0oooo0000003oool0oooo0`00000:0?oo
o`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00P0oooo0P000000103oool0
00000000003oool2000000030?ooo`000000000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool20000
00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01X0oooo0`00000A0?ooo`L00000303oool:000000`0oooo2`00000V0?ooo`@000002P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`8000001P3oool2000000H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P0000001@3o
ool000000?ooo`000000oooo008000002P3oool00`000000oooo0?ooo`090?ooo`00A03oool00`00
0000oooo0?ooo`080?ooo`80000000@0oooo000000000000oooo0P0000020?ooo`050000003oool0
oooo0?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool2000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool2000000H0oooo00<0
00000?ooo`3oool0703oool2000001H0oooo1P0000000`3oool0000000000003000000D0oooo00<0
00000?ooo`3oool06@3oool8000001`0oooo0`00000<0?ooo`030000003oool0oooo00L0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`0000001P3oool00`000000oooo0?ooo`040?ooo`8000001@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000020?ooo`80000000D0oooo0000003oool0
00000?ooo`02000000X0oooo00<000000?ooo`3oool02@3oool004@0oooo0P00000:0?ooo`050000
003oool000000000003oool00P0000020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P0000070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01d0oooo0`00000E0?ooo`X000001@3oool00`000000oooo0?ooo`0Q0?oooad000003@3oool00`00
0000oooo0?ooo`070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`050?ooo`8000001`3oool00`000000oooo0?ooo`040?ooo`800000103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P0000020?ooo`80000000D0oooo
0000003oool000000?ooo`02000000P0oooo0`00000;0?ooo`00A03oool00`000000oooo0?ooo`09
0?ooo`050000003oool000000000003oool00P0000020?ooo`050000003oool0oooo0?ooo`000000
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1@3oool2000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0103oool2000000D0oooo00<000000?ooo`3oool0
7`3oool2000000h0oooo1@00000:0?ooo`H00000?P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01P3oool2000000L0oooo00<000000?ooo`3oool0103oool2000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`8000000P3oool200000003
0?ooo`000000oooo00@000002P3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo
0?ooo`090?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo0P00
00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool2000000@0oooo00<0
00000?ooo`3oool0803oool3000000L0oooo1000000D0?ooo`D00000>03oool2000000h0oooo00<0
00000?ooo`3oool01`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01P3oool2000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000030?oo
o`000000oooo008000000P3oool2000000030?ooo`000000oooo00T0oooo00<000000?ooo`3oool0
2@3oool004@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`03000000030?ooo`00
0000oooo008000000P3oool2000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`070?ooo`8000000`3oool00`000000oooo0?ooo`0R0?ooo`L00000603oool00`000000oooo0?oo
o`020?ooo`<00000=03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00D0
00000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo000000060?ooo`8000001@3oool2000000D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool2000000040?ooo`000000oooo0?ooo`80
000000<0oooo0000003oool02@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo
0?ooo`090?ooo`80000000@0oooo000000000000oooo0P0000020?ooo`050000003oool0oooo0?oo
o`0000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo0`0000000`3o
ool000000?ooo`0O0?ooo`D0000000<0oooo0000000000006P3oool00`000000oooo0?ooo`050?oo
o`<00000<03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00D000000?oo
o`3oool0oooo000000090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool2
000000L0oooo00<000000?ooo`3oool0103oool2000000D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`8000000P3oool2000000080?ooo`000000oooo0000003oool00000
0?ooo`00000:0?ooo`030000003oool0oooo00T0oooo000d0?ooo`030?oo_`1d0000000000800000
00<0B9cO0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`80000000@0oooo000000000000
oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool2000000P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02`3oool4000001T0oooo1@0000080?ooo`<000005`3oool00`000000oooo0?ooo`080?oo
o`@00000:`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01P3oool2000000L0oooo00<000000?ooo`3oool0103oool2000000@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`8000000P3oool2000000080?ooo`000000oooo
0000003oool000000?ooo`00000:0?ooo`030000003oool0oooo00T0oooo000f0?ooo`030?noM000
0000M;oo00/0oooo00<000000?ooo`3oool02@3oool2000000090?ooo`00000000000?ooo`000000
oooo0000003oool0000000<0oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool03@3oool5000000h0oooo1`00000@0?ooo`<00000503oool00`000000oooo0?ooo`0<0?oo
o`<000009P3oool200000100oooo00<000000?ooo`3oool01@3oool2000000@0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo0P0000020?ooo`80000000D0oooo0000003oool000000?ooo`02
000000/0oooo00<000000?ooo`3oool02@3oool003H0oooo00<0oooO09a80000M;l02`3oool00`00
0000oooo0?ooo`0:0?ooo`040000003oool000000?ooo`80000000@0oooo0000003oool00000103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool2000000L0oooo0P0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool0oooo
3P00000J0?ooo`8000004P3oool00`000000oooo0?ooo`0?0?ooo`<000008P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool2000000L0oooo
0P0000050?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00L000000?ooo`3oool0oooo0000003oool000000080oooo1000000;0?ooo`030000003oool0oooo
00T0oooo000g0?ooo`030=nLB000B9`0gooo00X0oooo00<000000?ooo`3oool02P3oool01P000000
oooo0000003oool000000?ooo`80000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`05
0?ooo`8000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`800000:`3oool3000000l0oooo00<00000
0?ooo`3oool04P3oool3000001h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`04
0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P000002
0?ooo`80000000@0oooo0000003oool0oooo1000000;0?ooo`030000003oool0oooo00T0oooo000g
0?ooo`030?oOW01804P0W=oo00X0oooo00<000000?ooo`3oool02P3oool01P000000oooo0000003o
ool000000?ooo`8000000P3oool010000000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0P0000090?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0:`3oool3000000`0oooo00<000000?ooo`3o
ool05@3oool3000001T0oooo0P00000A0?ooo`030000003oool0oooo00@0oooo0P0000060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00D0oooo0P0000060?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo0P0000020?ooo`80000000@0oooo0000003oool0oooo1000000;0?oo
o`030000003oool0oooo00T0oooo000g0?ooo`030?oo_`1d0000M;oo00X0oooo0`00000:0?ooo`03
0000003oool0oooo0080000000<0oooo0000000000000P3oool010000000oooo0?ooo`3oool20000
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`8000001`3oool20000
00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0]0?ooo`8000002P3oool00`00
0000oooo0?ooo`0H0?ooo`@000004`3oool200000180oooo00<000000?ooo`3oool00`3oool20000
00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00H0oooo0P0000070?ooo`8000001@3oool00`000000oooo000000040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000T0oooo0`00000;0?ooo`00>03oool00`2oM00007Bo0?oo
o`090?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool000000?ooo`02000000040?oo
o`000000oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo0P0000070?ooo`8000002P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo02h0oooo0`0000070?ooo`030000003oool0oooo01`0oooo1000000>0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0100000090?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`0000001@3oool2000000D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000002`3oool00`000000oooo0?ooo`090?ooo`00>03oool00`3OW4P004RL0=ooo`09
0?ooo`030000003oool0oooo00X0oooo00L000000?ooo`3oool000000?ooo`000000oooo00800000
00<0oooo0000003oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000T0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool03`3oool200000340oooo0`0000040?ooo`030000003oool0oooo0200oooo
1P0000060?ooo`8000004@3oool6000000`0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00H0oooo0P0000070?ooo`8000001P3oool2000000D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`00
0000oooo000000020?ooo`<0000000<0oooo0000003oool02P3oool00`000000oooo0?ooo`090?oo
o`00>03oool00`3ogi`0B01809cOo`090?ooo`030000003oool0oooo00X0oooo0P0000001@3oool0
00000?ooo`000000oooo0080000000<0oooo0000000000000`3oool2000000D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001`3oool2000000X0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0a0?ooo`8000000P3oool00`000000oooo0?ooo`0V0?oo
o`L000002P3oool8000000030?ooo`000000oooo00l0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo000000050?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`8000000`3oool00`000000oooo000000020?ooo`@00000303oool00`00
0000oooo0?ooo`090?ooo`00>03oool00`3ookl0M00007Boo`090?ooo`030000003oool0oooo00/0
oooo00H000000?ooo`000000oooo0000003oool200000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2
000000L0oooo0P00000;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0<P3oool3
000002X0oooo0P0000030?ooo`X00000203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`8000001`3oool0
0`000000oooo000000050?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`02000000030?ooo`000000oooo00/0oooo00<000000?ooo`3oool02@3oool003T0oooo00<0_g@0
001d_`3oool0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool000000080oooo00H00000
0?ooo`00000000000?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo0P00000:0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0100oooo0P00000d0?ooo`@000009@3oool2000001H0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
1P3oool2000000L0oooo00@000000?ooo`3oool000001@3oool2000000D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool01`00
0000oooo0000003oool000000?ooo`000000303oool00`000000oooo0?ooo`090?ooo`00=`3oool0
1@3ookl0M0000000000007@0_ooo00P0oooo00<000000?ooo`3oool02`3oool300000080oooo00H0
00000?ooo`00000000000?ooo`0000040?ooo`8000001@3oool01@000000oooo0?ooo`3oool00000
00H0oooo0P0000070?ooo`8000002`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0A0?ooo`800000<P3oool01000
0000oooo0?ooo`3oool4000001l0oooo0P00000G0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo0P000007
0?ooo`030000003oool0000000H0oooo0P0000050?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000P00
00000`3oool000000?ooo`0;0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0
oooo00/0oooo0P0000001@3oool000000?ooo`000000oooo0080000000<0oooo0000003oool0103o
ool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo
0?ooo`060?ooo`8000002P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool01@3oool3000001X0oooo0P00000G0?ooo`800000403oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool2000000L0oooo
00@000000?ooo`3oool000001@3oool00`000000oooo000000050?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`80000000@0oooo0000003oool0oooo0P000000
0`3oool000000?ooo`0<0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
00/0oooo0P0000001@3oool000000?ooo`000000oooo0080000000<0oooo000000000000103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool2
000000L0oooo0P00000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0180oooo0P00000_0?ooo`030000003oool0
oooo00P0oooo1000000D0?ooo`800000603oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
000000L0oooo00@000000?ooo`3oool000001@3oool00`000000oooo000000040?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`80000000P0oooo0000003oool0
00000?ooo`000000oooo000000d0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?oo
o`3oool0303oool300000080oooo00<000000?ooo`0000000`0000040?ooo`030000003oool0oooo
00@0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool0303oool3000000h0oooo0`00000H0?ooo`8000004P3oool00`000000oooo0?ooo`03
0?ooo`800000403oool00`000000oooo0?ooo`060?ooo`030000003oool0000000H0oooo00@00000
0?ooo`3oool000001P3oool2000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo0000003oool000000?oo
o`0000003@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0<0?ooo`<0
00000P3oool01P000000oooo000000000000oooo000000D0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool01P3oool2000000/0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool04`3oool2000002`0oooo00<000000?ooo`3oool03`3oool4000000P0oooo0P00
000J0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00P3oool200000180oooo00<0
00000?ooo`3oool01@3oool00`000000oooo000000070?ooo`040000003oool0oooo000000H0oooo
0P0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000d0oooo00<00000
0?ooo`3oool02@3oool004@0oooo0P00000=0?ooo`<000000P3oool01P000000oooo000000000000
oooo000000D0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool2000001D0oooo0P00000Z0?ooo`030000
003oool0oooo01<0oooo0`0000030?ooo`8000006`3oool00`000000oooo0?ooo`0A0?ooo`040000
003oool0oooo0?ooo`8000004`3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000H0
oooo00@000000?ooo`3oool000001P3oool2000000D0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`3oool200000080oooo0P0000020?ooo`80000000@0oooo0000003oool00000303o
ool3000000/0oooo00140?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000000P3oool0
1P000000oooo0?ooo`000000oooo000000D0oooo00<000000?ooo`3oool0103oool01@000000oooo
0?ooo`3oool0000000L0oooo00<000000?ooo`3oool01P3oool2000000`0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0503oool2000002P0oooo00<000000?ooo`3oool05P3oool4000001X0oooo0P00000C0?ooo`03
0000003oool0oooo008000005@3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000L0
oooo00@000000?ooo`3oool000001P3oool2000000D0oooo00<000000?ooo`3oool0103oool01@00
0000oooo0?ooo`3oool0000000<0oooo0P000000203oool000000?ooo`000000oooo0000003oool0
00003P3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0=0?ooo`800000
0`3oool00`000000oooo00000003000000@0oooo00<000000?ooo`3oool0103oool01@000000oooo
0?ooo`3oool0000000L0oooo0P0000080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo0P00000F0?ooo`80
00009P3oool00`000000oooo0?ooo`0D0?ooo`<000000`3oool4000001D0oooo00<000000?ooo`3o
ool04P3oool4000001H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000060?oo
o`040000003oool0oooo000000H0oooo0P0000050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000000080?ooo`000000oooo0000003oool0
00000?ooo`00000>0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00d0
oooo0P0000030?ooo`030000003oool0000000<000001@3oool00`000000oooo0?ooo`040?ooo`05
0000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`800000303oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0E0?ooo`800000903oool00`000000oooo0?ooo`0B0?ooo`8000002P3oool40000
00l0oooo0P00000A0?ooo`@000006P3oool00`000000oooo0?ooo`050?ooo`030000003oool00000
00L0oooo00@000000?ooo`3oool000001P3oool2000000D0oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`3oool200000080oooo00@000000?ooo`000000oooo0P0000001@3oool00000
0000003oool0000000h0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0
3@3oool300000080oooo00<000000?ooo`0000000`0000050?ooo`030000003oool0oooo00@0oooo
00D000000?ooo`3oool0oooo000000070?ooo`800000203oool2000000`0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool05P3oool200000280oooo00<000000?ooo`3oool0403oool200000100oooo1@0000090?ooo`03
0000003oool0oooo00d0oooo100000000`3oool000000?ooo`0J0?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3oool000001P3oool010000000oooo0?ooo`0000060?ooo`8000001P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P0000020?ooo`8000000P3oool2
000000040?ooo`0000000000000000l0oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool03P3oool200000080oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`800000
203oool2000000d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0100oooo0P00000H0?ooo`800000803oool00`000000oooo0?ooo`0>0?ooo`800000
5`3oool6000000030?ooo`000000000000/0oooo1@0000040?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000070?ooo`040000003oool0oooo0000
00H0oooo0P0000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`3oool200000080oooo0P000000103oool000000?ooo`00000?0?ooo`030000003o
ool0oooo00T0oooo00140?ooo`030000003oool0oooo00h0oooo0P0000030?ooo`030000003oool0
000000<000001@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001`3o
ool2000000P0oooo0P00000=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01L0oooo0P00000N0?ooo`030000003o
ool0oooo00/0oooo0`00000N0?ooo`l00000203oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00D0oooo00@000000?ooo`3oool000001P3oool010000000oooo0?ooo`0000060?ooo`80
00001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool0oooo0P0000020?ooo`060000003oool0oooo0000003oool000003`3oool00`000000oooo0?oo
o`090?ooo`00A03oool00`000000oooo0?ooo`0>0?ooo`8000000`3oool00`000000oooo00000003
000000D0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000L0oooo0P00
00080?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0140oooo0P00000I0?ooo`800000703oool00`000000oooo0?oo
o`080?ooo`<000007`3oool2000001D0oooo0P00000L0?ooo`030000003oool0oooo00D0oooo00@0
00000?ooo`3oool000001`3oool00`000000oooo000000070?ooo`8000001P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00P000000?ooo`3oool0oooo0000003oool00000
0?ooo`80000000D0oooo000000000000oooo0000000?0?ooo`030000003oool0oooo00T0oooo0014
0?ooo`030000003oool0oooo00h0oooo0`0000020?ooo`030000003oool0000000<000001@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool0
0`000000oooo000000080?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0603oool3
000001T0oooo00<000000?ooo`3oool01P3oool200000200oooo0P00000F0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000070?ooo`040000003oool0
oooo000000H0oooo0P0000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`3oool200000080oooo0P000000103oool0000000000000000@0?ooo`03
0000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00l0oooo0P0000030?ooo`040000
003oool000000?ooo`800000103oool2000000H0oooo00D000000?ooo`3oool0oooo000000070?oo
o`030000003oool0000000L0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04P3oool2000001/0oooo0P00000G
0?ooo`030000003oool0oooo00<0oooo0`00000P0?ooo`8000005`3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0000
00070?ooo`8000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P00
00030?ooo`8000000P3oool00`000000oooo0?ooo`0300000100oooo00<000000?ooo`3oool02@3o
ool004@0oooo0P00000@0?ooo`8000000`3oool010000000oooo0000003oool2000000D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`000000203oool010000000oooo0?ooo`00000=0?ooo`8000001@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo01<0oooo0P00000K0?ooo`<00000503oool00`000000oooo
0?ooo`0300000240oooo0P00000H0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
1@3oool010000000oooo0?ooo`0000070?ooo`040000003oool0oooo000000H0oooo0P0000060?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool200000080oooo0P0000030?oo
o`060000003oool000000000003oool000003P3oool3000000/0oooo00140?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`0000000P3oool01P000000oooo000000000000oooo000000D0oooo
00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`00
00001`3oool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01/0oooo0P00000B0?oo
o`<000008P3oool2000001P0oooo0P00000N0?ooo`030000003oool0oooo00D0oooo00@000000?oo
o`3oool00000203oool00`000000oooo000000070?ooo`8000001P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo0P0000030?ooo`8000000`3oool01P000000oooo00000000
0000oooo00000100oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0403o
ool200000080oooo00D000000?ooo`3oool000000?ooo`02000000@0oooo0P0000060?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000070?ooo`04
0000003oool0oooo000000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?oo
o`8000005@3oool2000001d0oooo0`00000<0?ooo`@000008P3oool2000001T0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo0?ooo`050?oo
o`040000003oool0oooo000000H0oooo0P0000070?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool2000000<0oooo0P0000020?ooo`030000003oool0oooo00<000004@3oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0@0?ooo`<000000P3oool00`00
0000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000001P3oool0
1@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo01@0oooo0P00000N0?ooo`800000203oool2000000<0oooo00<0
00000?ooo`3oool07@3oool3000001X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0000
00060?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`<00000
4@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool000000080oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0000000L0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01d0oooo
0`0000020?ooo`<000001@3oool00`000000oooo0?ooo`0K0?ooo`8000006`3oool2000001l0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00@000000?ooo`3oool000001P3oool2000000L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`8000000`3oool2000000<0oooo00@000000?ooo`000000oooo0P00000A0?oo
o`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo0100oooo00<000000?ooo`00
00000P3oool010000000oooo0000000000020?ooo`030000003oool0oooo0080oooo0P0000060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`000006
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00`0oooo0P00000F0?ooo`8000007`3oool4000000L0oooo00<00000
0?ooo`3oool0603oool3000001/0oooo0P00000P0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000000`3oool010000000oooo0?ooo`3oool2000000050?ooo`00000000000?ooo`00
00004@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0A0?ooo`<00000
00D0oooo0000003oool0oooo000000020?ooo`030000003oool0oooo0080oooo0P0000060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool2000000<0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0E0?ooo`8000006P3oool3000000@0oooo0`0000040?oo
o`030000003oool0oooo01H0oooo0P00000L0?ooo`8000008@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0
000000H0oooo0P0000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool300000180oooo00<0
00000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool04@3oool00`000000oooo00000002
0?ooo`030000003oool000000080oooo0P0000040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000001@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo0P0000020?ooo`030000003o
ool0oooo00h0oooo0P00000G0?ooo`8000005@3oool3000000X0oooo0`0000000`3oool000000?oo
o`0D0?ooo`<000007@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000
1P3oool00`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`000000
oooo0P00000B0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo0140oooo
00P000000?ooo`00000000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0@0?ooo`80000000<0oooo0000003oool0403oool00`000000oooo0?ooo`0F0?ooo`800000403o
ool300000100oooo0`00000A0?ooo`<000007P3oool200000280oooo00<000000?ooo`3oool00`3o
ool2000000H0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000L0oooo
0P0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo00000000000B0?oo
o`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo0180oooo0`0000001@3oool0
00000?ooo`3oool000000080oooo0P0000040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`<000004@3oool00`000000oooo0?ooo`0G
0?ooo`<000002@3oool4000001@0oooo00<000000?ooo`0000000P00000<0?ooo`8000007`3oool2
000002@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0000000000180oooo
00<000000?ooo`3oool02@3oool004@0oooo0P00000C0?ooo`030000003oool00000008000000P3o
ool00`000000oooo0?ooo`02000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000
003oool0oooo00<0oooo0P00000C0?ooo`@000003`3oool2000001X0oooo0`0000000`3oool00000
00000003000001P0oooo00<000000?ooo`3oool00P3oool3000000H0oooo0`00000O0?ooo`800000
9@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0P0000060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`80
00000`3oool00`000000oooo0?ooo`0300000140oooo0`00000;0?ooo`00A03oool00`000000oooo
0?ooo`0B0?ooo`080000003oool000000000003oool000000?ooo`0000030?ooo`030000003oool0
oooo0080oooo0P0000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0000000<000003@3oool00`000000oooo0?ooo`0D0?ooo`P00000703o
ool00`000000oooo0?ooo`050?ooo`H00000803oool2000002H0oooo00@000000?ooo`3oool0oooo
0P0000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool0oooo0P0000000`3oool0
00000?ooo`02000001<0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0
4P3oool010000000oooo0000003oool2000000030?ooo`000000oooo0080oooo0P0000040?ooo`80
00001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3o
ool0oooo000000050?ooo`030000003oool0oooo00@0oooo0P00000C0?ooo`030000003oool0oooo
0080oooo1`0000070?ooo`800000303oool8000000P0oooo0`00000I0?ooo`030000003oool0oooo
00D0oooo0`000000103oool0000000000000000M0?ooo`8000009`3oool00`000000oooo0?ooo`02
000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00D0oooo0P0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000020?ooo`8000000`3oool01@000000oooo0?ooo`000000oooo00800000
4`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool00000008000000P3oool00`000000oooo0?ooo`02000000@0oooo0P0000060?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00P0oooo5@00000C0?ooo`<000005P3oool00`000000oooo0?ooo`020?ooo`<000001`3o
ool3000001P0oooo0P00000X0?ooo`@000002P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo000000050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`800000
0P3oool200000080oooo0`00000D0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`0000000P0000020?ooo`040000003oool0oooo0?ooo`800000
103oool2000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`050000
003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`050?ooo`8000004P3oool00`000000
oooo0?ooo`0B0?ooo`8000007P3oool2000001@0oooo00<000000?ooo`0000000P00000=0?ooo`@0
00004P3oool2000002P0oooo0`00000<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`050?ooo`8000001P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
0?ooo`80000000<0oooo0000003oool00P00000D0?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo01<0oooo00@000000?ooo`000000oooo0P0000000`3oool000000?ooo`02
0?ooo`800000103oool00`000000oooo000000050?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0@0?ooo`800000503oool2000001h0oooo0`00000@0?ooo`<00000503o
ool4000000/0oooo0`00000X0?ooo`<000003@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo000000050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`800000
0`3oool00`000000oooo0?ooo`03000001D0oooo00<000000?ooo`3oool02@3oool004@0oooo00<0
00000?ooo`3oool0503oool00`000000oooo00000002000000030?ooo`00000000000080oooo00<0
00000?ooo`000000103oool2000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`8000004P3oool2000001@0oooo0P00000O0?ooo`<000002P3oool3000000030?ooo`00
0000oooo01P0oooo1P0000030?ooo`800000:03oool4000000h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`0200000080oooo0P0000020?ooo`<000005@3oool00`000000oooo0?ooo`090?ooo`00A03o
ool00`000000oooo0?ooo`0D0?ooo`050000003oool000000?ooo`0000000P3oool010000000oooo
0?ooo`3oool2000000@0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool2000001@0oooo0P00000P0?ooo`80
00001@3oool3000000@0oooo00<000000?ooo`3oool07@3oool6000002D0oooo0P0000000`3oool0
00000000000>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000P3oool2
00000080oooo0P00000F0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
01D0oooo0P000000103oool000000?ooo`3oool200000080oooo00<000000?ooo`000000103oool2
000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`050000003oool0
oooo0?ooo`0000001`3oool00`000000oooo0?ooo`070?ooo`8000004`3oool00`000000oooo0?oo
o`0C0?ooo`800000803oool5000000L0oooo00<000000?ooo`3oool06`3oool2000000H0oooo2P00
000A0?ooo`X000000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool00P0000020?ooo`8000000P3oool3000001H0oooo00<000000?ooo`3oool02@3oool004@0oooo
00<000000?ooo`3oool05@3oool01@000000oooo0000003oool000000080oooo00@000000?ooo`3o
ool0oooo0P0000050?ooo`8000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool04@3oool2000001D0oooo0`00000K0?ooo`<000000P3oool30000
00H0oooo00<000000?ooo`3oool06@3oool200000180oooo4@00000;0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo0P0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo0P0000020?ooo`8000000P3oool2
000001L0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool05P3oool20000
00040?ooo`000000oooo0?ooo`8000000P3oool00`000000oooo000000040?ooo`030000003oool0
000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`8000004`3oool2
000001H0oooo0P00000F0?ooo`<00000203oool3000000<0oooo00<000000?ooo`3oool05P3oool3
000002h0oooo0P00000>0?ooo`8000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`8000000`3o
ool200000080oooo0P00000G0?ooo`030000003oool0oooo00T0oooo00140?ooo`8000005`3oool2
000000030?ooo`000000oooo0080oooo00@000000?ooo`3oool0oooo0P0000050?ooo`8000001P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo0P00000C0?ooo`030000003o
ool0oooo01D0oooo0`00000?0?ooo`@000003P3oool4000001D0oooo0`00000`0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0103oool2000000H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo0P0000020?ooo`800000
0P3oool2000001H0oooo0`00000;0?ooo`00A03oool00`000000oooo0?ooo`0G0?ooo`040000003o
ool0000000000080oooo0P0000020?ooo`8000001P3oool2000000H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000
003oool0oooo00/0oooo0`00000A0?ooo`800000603oool2000000P0oooo1@00000E0?ooo`<00000
3`3oool400000340oooo0P00000?0?ooo`030000003oool0oooo00<0oooo0P0000070?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`80
00000`3oool200000080oooo0P00000H0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000
003oool0oooo01L0oooo0P0000000`3oool000000?ooo`020?ooo`8000000P3oool2000000D0oooo
00<000000?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo
1000000?0?ooo`800000603oool8000001X0oooo00<000000?ooo`3oool00`0000090?ooo`<00000
=03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo0P0000080?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`08
0000003oool0oooo0?ooo`000000oooo0000003oool2000001T0oooo00<000000?ooo`3oool02@3o
ool004@0oooo00<000000?ooo`3oool05`3oool2000000030?ooo`000000000000<0oooo00<00000
0?ooo`3oool00P0000060?ooo`8000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0100oooo1000000=0?ooo`8000004P3oool6000000030?ooo`000000000001d0oooo00<00000
0?ooo`3oool00`3oool3000000<0oooo0`00000f0?ooo`030000003oool0oooo00h0oooo00@00000
0?ooo`3oool0oooo0P0000090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`8000000`3oool200000080oooo0P00000I0?ooo`030000
003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3oool00000
0`3oool200000080oooo0P0000050?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0C0?ooo`H000002@3oool2000000<0oooo3@0000090?ooo`<00000
6P3oool00`000000oooo0?ooo`050?ooo`@00000=`3oool200000100oooo00<000000?ooo`000000
0P00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo0080oooo0P0000000`3oool000000000000J0?ooo`03
0000003oool0oooo00T0oooo000d0?ooo`030=nLB0000000000000<0000000<0B9cO0?ooo`3oool0
1`3oool00`000000oooo0?ooo`0H0?ooo`80000000<0oooo0000000000000`3oool00`000000oooo
0?ooo`02000000H0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01P0oooo3P00000I0?ooo`<000005`3oool00`000000oooo0?ooo`020?ooo`<00000
103oool400000340oooo0P00000A0?ooo`<00000303oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000000`3oool2000000<0oooo00@000000?ooo`000000
oooo0P00000J0?ooo`030000003oool0oooo00T0oooo000e0?ooo`030?noM000M;l0oooo0080oooo
00<0_gAd0;ooo`3oool01`3oool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00P0000060?ooo`8000001P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool2000000@0oooo00<000000?ooo`3o
ool0903oool2000001/0oooo0`00000D0?ooo`030000003oool00000008000002`3oool4000002/0
oooo0P00000B0?ooo`8000003@3oool00`000000oooo0?ooo`020?ooo`8000001P3oool01@000000
oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`800000103oool2000000030?ooo`000000000001/0oooo00<000000?ooo`3oool02@3oool0
03H0oooo00<0okmd001d_`3oool02`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
008000000`3oool00`000000oooo0?ooo`02000000H0oooo00<000000?ooo`0000001P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo02D0oooo0`00000K0?ooo`800000403oool40000
0180oooo1@00000T0?ooo`8000004P3oool2000000h0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0000000<0oooo0P0000030?ooo`040000003oool000000?ooo`8000006`3o
ool00`000000oooo0?ooo`090?ooo`00=`3oool00`3o_g@007Bo0?ooo`0:0?ooo`030000003oool0
oooo01X0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`02000000H0oooo00<0
00000?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo0P00
00070?ooo`8000000`3oool00`000000oooo0?ooo`0W0?ooo`8000006`3oool3000000T0oooo1000
00020?ooo`030000003oool0oooo01H0oooo1@00000L0?ooo`<000003`3oool5000000l0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000
2`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo0P0000040?ooo`03
0000003oool0000000800000703oool00`000000oooo0?ooo`090?ooo`00>03oool00`3o_g@0B9cO
0?ooo`090?ooo`030000003oool0oooo01X0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`02000000H0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool200000080oooo00<000000?ooo`3o
ool0:03oool3000001/0oooo0`0000020?ooo`@000001P3oool00`000000oooo0?ooo`0K0?ooo`P0
00004P3oool2000000X0oooo200000020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000303oool00`00
0000oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3oool01000
0000oooo0000003oool2000001`0oooo00<000000?ooo`3oool02@3oool003T0oooo00<0gia804RL
g`3oool0203oool3000001X0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P0000060?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo0P0000000`3oool000000?ooo`0[0?oo
o`8000006P3oool5000000T0oooo00<000000?ooo`3oool08`3oool<000000<0oooo0`0000040?oo
o`P00000203oool200000100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`040000003oool0oooo000000`0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P00000K0?ooo`<000002`3o
ool003X0oooo00<0_g@007Boo`3oool01`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00800000103oool010000000oooo0000000000070?ooo`800000203oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool4000002`0oooo0P00
000D0?ooo`@000001@3oool4000000D0oooo00<000000?ooo`3oool0;`3oool:000000h0oooo0P00
000A0?ooo`040000003oool0oooo0?ooo`800000203oool010000000oooo0?ooo`00000<0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`03
0000003oool0oooo00<000007@3oool00`000000oooo0?ooo`090?ooo`00>P3oool00`3ogi`0B01d
0;ooo`070?ooo`030000003oool0oooo01/0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo008000001P3oool00`000000oooo000000080?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`800000;@3oool3000000/0
oooo1P00000=0?ooo`@0000000<0oooo0000003oool0;`3oool2000001H0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`02000000T0oooo00@000000?ooo`3oool00000303oool00`00
0000oooo0?ooo`040?ooo`060000003oool0oooo0000003oool000000P3oool010000000oooo0?oo
o`0000020?ooo`<000007P3oool00`000000oooo0?ooo`090?ooo`00>P3oool00`3ooml0W4P007Bo
o`070?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00P0000040?ooo`040000003o
ool00000000000L0oooo00<000000?ooo`000000203oool2000000<0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0;0?ooo`D00000:`3oool3000000<0oooo1@00000G0?ooo`@00000
:`3oool3000001H0oooo0P00000B0?ooo`040000003oool00000000000X0oooo00@000000?ooo`3o
ool000003@3oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool000000P3o
ool01@000000oooo0?ooo`3oool000000080oooo0`00000N0?ooo`030000003oool0oooo00T0oooo
000j0?ooo`030?oo_`1d0000B9cO00L0oooo00<000000?ooo`3oool0703oool01@000000oooo0?oo
o`3oool0000000@0oooo0P0000000`3oool00000000000070?ooo`8000002P3oool01@000000oooo
0?ooo`3oool0000000/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`07000002@0
oooo1P00000M0?ooo`030000003oool0oooo00@000009@3oool2000001L0oooo0P00000C0?ooo`<0
00002`3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00@0oooo00H000000?oo
o`3oool000000?ooo`0000020?ooo`040000003oool0oooo00000080oooo0`00000O0?ooo`030000
003oool0oooo00T0oooo000f0?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cOo`070?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool00P0000040?ooo`050000003oool000000?oo
o`0000001P3oool00`000000oooo0000000:0?ooo`050000003oool0oooo0?ooo`0000002`3oool0
0`000000oooo0?ooo`0<0?ooo`8000001`3oool7000000l0oooo3P0000060?ooo`@000006@3oool0
0`000000oooo0?ooo`040?ooo`D000007@3oool3000001P0oooo00<000000?ooo`3oool04P3oool2
000000`0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`040?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo000000030?ooo`<000007`3oool00`000000
oooo0?ooo`090?ooo`00=`3oool01@3ogi`0B000000000000000M;oo00P0oooo00<000000?ooo`3o
ool07@3oool2000000030?ooo`000000000000@0oooo0P000000103oool000000?ooo`0000060?oo
o`030000003oool0000000X0oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00/0oooo3`00000H0?ooo`<000005P3oool00`000000oooo0?ooo`09
0?ooo`H00000503oool3000001T0oooo0P00000B0?ooo`<000003@3oool010000000oooo0?ooo`00
000=0?ooo`030000003oool0oooo00@0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`04
0000003oool0oooo00000080oooo0`00000P0?ooo`030000003oool0oooo00T0oooo00140?ooo`03
0000003oool0oooo01h0oooo0P0000000`3oool00000000000040?ooo`030000003oool000000080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000;0?ooo`040000003oool0oooo0000
00`0oooo0P00000>0?ooo`800000=@3oool3000001<0oooo00<000000?ooo`3oool03`3oool50000
00d0oooo0P00000J0?ooo`8000004@3oool5000000d0oooo00@000000?ooo`3oool000003P3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo0P0000000`3oool000000?ooo`0O0?ooo`030000003oool0oooo00T0
oooo00140?ooo`030000003oool0oooo01h0oooo0P0000000`3oool00000000000050?ooo`030000
003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000;0?ooo`040000
003oool0oooo000000d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0e0?ooo`@0
00003`3oool00`000000oooo0?ooo`0D0?ooo`H00000103oool3000001X0oooo0P00000@0?ooo`<0
000000<0oooo0000000000003@3oool2000000030?ooo`000000000000h0oooo00<000000?ooo`3o
ool00`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`040000003oool0000000000240oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool07`3oool2000000030?ooo`000000000000@0oooo0`0000030?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`00000000002P3oool2000000030?ooo`000000oooo00`0oooo00<0
00000?ooo`3oool03@3oool2000003T0oooo1000000;0?ooo`030000003oool0oooo01X0oooo2000
000G0?ooo`8000003`3oool3000000<0oooo00<000000?ooo`3oool0303oool010000000oooo0000
0000000?0?ooo`030000003oool0oooo00@0oooo00H000000?ooo`3oool000000?ooo`0000040?oo
o`030000003oool000000080oooo0P0000000`3oool000000?ooo`0P0?ooo`030000003oool0oooo
00T0oooo00140?ooo`800000803oool01P000000oooo000000000000oooo000000@0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002`3o
ool00`000000oooo0000000=0?ooo`030000003oool0oooo00h0oooo0P00000k0?ooo`@000001`3o
ool00`000000oooo0?ooo`0I0?ooo`8000001`3oool:000000X0oooo0`0000040?ooo`d00000103o
ool2000000h0oooo0`00000@0?ooo`030000003oool0oooo00@0oooo00H000000?ooo`3oool00000
0?ooo`0000040?ooo`030000003oool000000080oooo00@000000?ooo`0000000000803oool30000
00/0oooo00140?ooo`030000003oool0oooo0200oooo0P0000000`3oool00000000000040?ooo`80
000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000002`3oool3000000d0oooo00<000000?ooo`3oool03`3oool2000003d0oooo100000030?oo
o`030000003oool0oooo01D0oooo1000000C0?oooa4000003`3oool2000000h0oooo0`00000B0?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool000000280oooo00<000000?ooo`3o
ool02@3oool004@0oooo00<000000?ooo`3oool0803oool01P000000oooo000000000000oooo0000
00@0oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool0oooo0P00000;0?ooo`8000003@3oool200000140oooo0P00000o0?ooo`@000004`3oool4
000001`0oooo0`00000G0?ooo`030000003oool0oooo00`0oooo0`00000C0?ooo`030000003oool0
oooo00<0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00L000000?ooo`3oool0
00000?ooo`000000oooo00<000008`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0000000800000103oool200000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool30000
00d0oooo0P00000A0?ooo`800000@03oool6000000X0oooo1000000M0?ooo`<00000603oool20000
00`0oooo0`0000000`3oool000000?ooo`0B0?ooo`030000003oool0oooo00<0oooo00L000000?oo
o`3oool0oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000P3oool01@000000oooo
0000003oool0000002<0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0
8P3oool3000000030?ooo`000000oooo00<0oooo0P0000000`3oool000000?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`<00000
3P3oool200000140oooo0P00000n0?ooo`030000003oool0oooo00<0oooo1@0000000`3oool00000
00000002000001l0oooo0P00000I0?ooo`800000303oool2000000<0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool01@000000oooo0?ooo`000000oooo00<00000903oool00`000000oooo0?ooo`09
0?ooo`00A03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0000000800000103oool20000
0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo0P00000;
0?ooo`<000003P3oool00`000000oooo0?ooo`0@0?ooo`800000?03oool00`000000oooo0?ooo`05
0?ooo`L000007@3oool3000001T0oooo0P00000<0?ooo`8000000`3oool2000001@0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo
00@000000?ooo`000000oooo0P0000000`3oool000000?ooo`0S0?ooo`030000003oool0oooo00T0
oooo00140?ooo`030000003oool0oooo02<0oooo00<000000?ooo`0000000P0000040?ooo`800000
0P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`090?ooo`<000003P3oool200000180oooo0`00000i0?ooo`040000003oool0oooo0?oo
o`@000001`3oool5000001H0oooo0P00000K0?ooo`030000003oool0oooo00T0oooo0`0000030?oo
o`8000005@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool000000080oooo0`00000U0?ooo`030000003o
ool0oooo00T0oooo00140?ooo`030000003oool0oooo02@0oooo00D000000?ooo`000000oooo0000
00040?ooo`8000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0:0?ooo`<000003P3oool2000001<0oooo0`00000e0?ooo`D00000
403oool5000000h0oooo0`00000K0?ooo`8000002P3oool2000000@0oooo0P00000F0?ooo`030000
003oool0oooo0080oooo0P0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool01P000000oooo000000000000oooo000002D0oooo00<000000?ooo`3oool02@3o
ool004@0oooo00<000000?ooo`3oool09@3oool3000000030?ooo`000000oooo0080oooo0P000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`800000303o
ool3000000h0oooo0P00000D0?ooo`<00000;@3oool5000000030?ooo`000000oooo01L0oooo2@00
00000`3oool0000000000002000001`0oooo0P0000040?ooo`P00000103oool2000001L0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
00L000000?ooo`3oool0oooo0000003oool000000080oooo0`00000V0?ooo`030000003oool0oooo
00T0oooo00140?ooo`030000003oool0oooo02D0oooo00<000000?ooo`0000000P0000040?ooo`80
00000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0;0?ooo`@000003@3oool2000001D0oooo0P00000W0?ooo`@000001P3oool00`00
0000oooo0?ooo`0M0?ooo`h000003@3oool>000000X0oooo0P00000I0?ooo`050000003oool0oooo
0?ooo`000000103oool010000000oooo0?ooo`0000020?ooo`070000003oool0oooo0?ooo`000000
oooo000000020?ooo`80000000<0oooo0000003oool09@3oool00`000000oooo0?ooo`090?ooo`00
A03oool00`000000oooo0?ooo`0V0?ooo`030000003oool00000008000000`3oool00`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`80
00003@3oool00`000000oooo00000003000000/0oooo00<000000?ooo`3oool0503oool3000001l0
oooo1@00000:0?ooo`030000003oool0oooo01X0oooo0`00000>0?ooo`d000000`3oool300000100
oooo0P00000J0?ooo`030000003oool0oooo00800000103oool010000000oooo0?ooo`0000020?oo
o`070000003oool0oooo0?ooo`000000oooo000000020?ooo`040000003oool00000000002L0oooo
00<000000?ooo`3oool02@3oool004@0oooo0P00000X0?ooo`80000000<0oooo0000000000000`3o
ool010000000oooo0000000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo0P0000030?ooo`<000002@3oool2000001L0
oooo0`00000G0?ooo`D000003`3oool00`000000oooo0?ooo`0F0?ooo`@000007`3oool200000140
oooo0P00000J0?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`060000003oool0oooo0000
003oool000000`3oool010000000oooo0?ooo`0000020?ooo`80000000<0oooo0000003oool0903o
ool3000000/0oooo00140?ooo`030000003oool0oooo02L0oooo00H000000?ooo`00000000000?oo
o`0000020?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`050000003oool0oooo
0?ooo`0000002@3oool00`000000oooo0?ooo`0<0?ooo`800000103oool6000000D0oooo0P00000H
0?ooo`<000003P3oool6000001@0oooo00<000000?ooo`3oool04`3oool300000200oooo0`00000A
0?ooo`8000006`3oool00`000000oooo0?ooo`02000000H0oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`0000000000:03oool00`00
0000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0X0?ooo`060000003oool000000000
003oool000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool010000000oooo
0?ooo`3oool2000000P0oooo0P00000>0?ooo`800000203oool9000001T0oooo0`0000040?ooo`L0
00006P3oool00`000000oooo0?ooo`0?0?ooo`@00000803oool300000180oooo0P00000K0?ooo`80
00000P3oool00`000000oooo0?ooo`050?ooo`060000003oool000000000003oool000000`3oool0
10000000oooo0?ooo`0000020?ooo`050000003oool000000?ooo`000000:03oool00`000000oooo
0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool00000008000000`3o
ool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool2000000l0oooo2@00000<0?ooo`/0
00008@3oool00`000000oooo0?ooo`0;0?ooo`@000008@3oool3000001<0oooo0P00000L0?ooo`05
0000003oool0oooo0?ooo`0000001P3oool2000000050?ooo`000000oooo0?ooo`0000000`3oool0
10000000oooo0?ooo`0000030?ooo`80000000<0oooo0000003oool0:03oool00`000000oooo0?oo
o`090?ooo`00A03oool00`000000oooo0?ooo`0Y0?ooo`040000003oool000000?ooo`8000000`3o
ool010000000oooo0?ooo`3oool3000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00h0oooo0P00000?0?ooo`<00000103oool<000000/0oooo
1000000M0?ooo`030000003oool0oooo00D0oooo1P00000S0?ooo`800000503oool2000001`0oooo
0P0000020?ooo`8000001P3oool010000000oooo0000000000020?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`02000000030?ooo`000000oooo02T0oooo00<000000?oo
o`3oool02@3oool004@0oooo00<000000?ooo`3oool0:P3oool01P000000oooo000000000000oooo
000000<0oooo0P0000030?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool01`3oool2
00000100oooo0`00000?0?ooo`<00000703oool4000001T0oooo00<000000?ooo`3oool01@00000V
0?ooo`<00000503oool2000001d0oooo00<000000?ooo`3oool00P0000060?ooo`@000000`3oool0
0`000000oooo0?ooo`02000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000002/0oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0:`3oool01P000000oooo0000
00000000oooo000000@0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000P3oool00`00
0000oooo0?ooo`080?ooo`8000004@3oool200000100oooo0`00000M0?ooo`@000004P3oool60000
02P0oooo0`00000E0?ooo`8000007@3oool2000000030?ooo`000000000000L0oooo00<000000?oo
o`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@00000;03oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0/0?ooo`80000000@0oooo0000
003oool00000103oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool2000000030?oo
o`000000oooo00X0oooo1000000?0?ooo`8000004@3oool3000001h0oooo100000080?ooo`H00000
0`3oool00`000000oooo0?ooo`0T0?ooo`@000005@3oool3000001h0oooo100000070?ooo`@00000
103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<00000;P3oool00`000000
oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0/0?ooo`070000003oool000000?ooo`00
0000oooo000000040?ooo`040000003oool0oooo0?ooo`<000001P3oool3000000h0oooo1000000=
0?ooo`8000004P3oool3000001l0oooo200000090?ooo`030000003oool0oooo0200oooo1000000G
0?ooo`8000007`3oool3000000T0oooo00<000000?ooo`0000001P3oool00`000000oooo00000005
0?ooo`030000003oool0000000800000;`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`00
0000oooo0?ooo`0]0?ooo`040000003oool000000?ooo`8000001@3oool00`000000oooo0?ooo`02
0?ooo`<000001P3oool300000100oooo1000000;0?ooo`<000004P3oool3000001L0oooo1P000003
0?ooo`D00000203oool00`000000oooo0?ooo`0L0?ooo`@00000603oool3000001l0oooo0P00000:
0?ooo`@000001P3oool00`000000oooo000000050?ooo`050000003oool000000?ooo`000000<03o
ool00`000000oooo0?ooo`090?ooo`00A03oool2000002l0oooo0P000000103oool000000?ooo`00
00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001`3oool300000180oooo1P00
00080?ooo`8000004`3oool3000000d0oooo1`00000>0?ooo`H000000P3oool00`000000oooo0?oo
o`0H0?ooo`@000006@3oool3000001l0oooo1000000:0?ooo`030000003oool0000000L0oooo00<0
00000?ooo`0000001@3oool01@000000oooo0000003oool0000002l0oooo0`00000;0?ooo`00A03o
ool00`000000oooo0?ooo`0_0?ooo`80000000@0oooo0000003oool000001@3oool00`000000oooo
0?ooo`020?ooo`@000001P3oool3000001L0oooo200000020?ooo`8000003`3ooolB000001/0oooo
1P00000C0?ooo`@000006P3oool300000200oooo0P0000000`3oool000000?ooo`090?ooo`@00000
1`3oool00`000000oooo000000050?ooo`050000003oool000000?ooo`000000<P3oool00`000000
oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0`0?ooo`80000000<0oooo0000003oool0
0P0000040?ooo`800000103oool00`000000oooo000000070?ooo`<000007@3ooolC000000P0oooo
1000000S0?ooo`040000003oool0oooo0?ooo`H000001`3oool6000001/0oooo0`00000P0?ooo`<0
000000<0oooo0000000000002P3oool00`000000oooo000000080?ooo`<000001P3oool4000003<0
oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0<@3oool2000000050?oo
o`00000000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`040000003oool000000000
00L0oooo0`00000Q0?ooo`<000005P3oool4000001l0oooo00<000000?ooo`3oool01`3oool70000
01l0oooo0P00000P0?ooo`<000000`3oool00`000000oooo0?ooo`080?ooo`@00000203oool20000
00L0oooo0`00000e0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo0380
oooo0P0000020?ooo`040000003oool00000000000@0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000080?ooo`8000008`3oool4000001H0oooo1000000K0?ooo`030000003oool0
oooo0080oooo1P0000050?ooo`H000005`3oool300000200oooo0P0000040?ooo`8000002P3oool3
000000T0oooo0P0000060?ooo`@00000=P3oool00`000000oooo0?ooo`090?ooo`00A03oool00`00
0000oooo0?ooo`0c0?ooo`8000000P3oool2000000030?ooo`000000oooo00<0oooo00<000000?oo
o`3oool00P3oool2000000030?ooo`000000oooo00P0oooo0P00000U0?ooo`@000005P3oool50000
01D0oooo1P00000A0?ooo`L00000303oool4000001X0oooo2@0000040?ooo`8000002P3oool30000
00T0oooo0P0000060?ooo`<0000000<0oooo0000003oool0=P3oool00`000000oooo0?ooo`090?oo
o`00A03oool00`000000oooo0?ooo`0d0?ooo`8000000`3oool010000000oooo0000000000030?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`00000000002@3oool3000002H0oooo1000000G
0?ooo`@000002P3oool7000000030?ooo`000000oooo01/0oooo3000000@0?ooo`h000002P3oool3
000000/0oooo0`0000080?ooo`8000001`3oool01@000000oooo0000003oool0000003P0oooo00<0
00000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0=P3oool01@000000oooo0?ooo`3o
ool000000080oooo00D000000?ooo`3oool0oooo000000050?ooo`80000000<0oooo0000003oool0
2@3oool7000002@0oooo1000000G0?ooo`X00000203oool00`000000oooo0?ooo`0L0?ooo`D00000
1@3oool@000001D0oooo0`00000<0?ooo`<00000203oool3000000H0oooo100000000`3oool00000
0?ooo`0h0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo03L0oooo0P00
00020?ooo`80000000<0oooo0000000000000P3oool00`000000oooo0?ooo`040?ooo`@000002P3o
ool2000000<0oooo1@00000S0?ooo`@000003`3oool7000000030?ooo`000000000000@00000203o
ool00`000000oooo0?ooo`0G0?ooo`D00000;03oool3000000/0oooo100000090?ooo`<000001`3o
ool01P000000oooo000000000000oooo000003X0oooo00<000000?ooo`3oool02@3oool004@0oooo
00<000000?ooo`3oool0>03oool2000000<0oooo00@000000?ooo`3oool000000P3oool2000000L0
oooo0`00000:0?ooo`<000001@3oool500000280oooo100000040?ooo`L000003P3oool700000003
0?ooo`000000oooo01<0oooo1@00000^0?ooo`<000002P3oool4000000030?ooo`000000000000T0
oooo0`0000060?ooo`80000000<0oooo0000000000000P00000k0?ooo`030000003oool0oooo00T0
oooo00140?ooo`800000>P3oool300000080oooo0P0000000`3oool00000000000020?ooo`030000
003oool0oooo00H0oooo1000000:0?ooo`800000203oool600000180oooo4P00000L0?ooo`H00000
2`3oool500000300oooo0`0000090?ooo`@00000103oool00`000000oooo0?ooo`070?ooo`<00000
1P3oool200000080oooo0`00000k0?ooo`<000002`3oool004@0oooo00<000000?ooo`3oool0>`3o
ool2000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0000000<00000203oool3000000/0oooo4P00000B0?ooo`D00000603oool00`000000oooo
0?ooo`020?ooo`/00000<P3oool3000000L0oooo1@0000060?ooo`800000203oool3000000L0oooo
00<000000?ooo`3oool01000000n0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003o
ool0oooo03`0oooo0`0000020?ooo`80000000@0oooo000000000000oooo0P0000080?ooo`030000
003oool0oooo0080oooo0`0000080?ooo`800000<P3oool5000001<0oooo00<000000?ooo`000000
1`0000020?ooo`T00000:P3oool3000000H0oooo100000090?ooo`800000203oool3000000L0oooo
0P0000020?ooo`@00000?`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0000000<0oooo0P000000103oool000000?ooo`3oool2000000L0oooo
0P0000050?ooo`<000001`3oool3000003@0oooo1P0000080?ooo`L000004`3oool<000001/0oooo
0`0000050?ooo`@000002`3oool2000000L0oooo0`0000080?ooo`8000000`3oool2000000030?oo
o`000000oooo03l0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0?P3o
ool4000000<0oooo100000020?ooo`8000001`3oool2000000H0oooo0`0000070?ooo`<00000=`3o
ool8000000D0oooo00<000000?ooo`3oool07P3ooolS000000`0oooo0`0000050?ooo`H00000203o
ool00`000000oooo0?ooo`020?ooo`80000000<0oooo0000003oool0@03oool00`000000oooo0?oo
o`090?ooo`00A03oool00`000000oooo0?ooo`100?ooo`<000001@3oool300000080oooo0`000006
0?ooo`<000001P3oool9000000030?ooo`000000000002X0oooo2`0000050?ooo`D000000`3oool0
0`000000oooo0?ooo`0a0?ooo`@000005@3oool3000000D0oooo0`0000020?ooo`800000203oool2
000000<0oooo1@0000120?ooo`030000003oool0oooo00T0oooo000d0?ooo`030?oo_`1d00000000
0080000000<0M;oo0?ooo`3oool0203oool00`000000oooo0?ooo`120?ooo`<000001@3oool40000
0080oooo0P0000070?ooo`<00000303oool>000000l0oooo4000000E0?ooo`L00000;03oool40000
01L0oooo0P0000040?ooo`@000000`3oool2000000P0oooo0P0000040?ooo`@00000A03oool00`00
0000oooo0?ooo`090?ooo`00=03oool00`3o_g@00000001d_`020?ooo`030;mdB02Lgol0oooo00P0
oooo00<000000?ooo`3oool0A03oool2000000H0oooo00<000000?ooo`0000000P0000000`3oool0
0000000000080?ooo`@000003P3oool2000000H0oooo3`00000X0?ooo`040000003oool0oooo0?oo
o`T000007`3oool4000001P0oooo2@0000050?ooo`8000002@3oool00`000000oooo0?ooo`020?oo
o`<0000000<0oooo0000003oool0A03oool00`000000oooo0?ooo`090?ooo`00>@3oool00`3ogi`0
B4RL0=ooo`080?ooo`030000003oool0oooo04H0oooo0P0000050?ooo`8000000P3oool5000000X0
oooo0`00000=0?ooo`D00000>03oool00`000000oooo0?ooo`0:0?ooo`d000003@3oool5000001T0
oooo1P0000090?ooo`8000002@3oool200000080oooo100000000`3oool00000000000160?ooo`03
0000003oool0oooo00T0oooo000i0?ooo`030?oo_`1d0000M;oo00P0oooo00<000000?ooo`3oool0
B03oool2000000D0oooo00<000000?ooo`3oool00P3oool5000000X0oooo0`00000?0?ooo`H00000
<P3oool00`000000oooo0?ooo`0G0?ooob/00000303oool3000000X0oooo00<000000?ooo`000000
0`000000103oool000000000000000180?ooo`030000003oool0oooo00T0oooo000i0?ooo`030?oO
W0180000M;oo00P0oooo0`0000190?ooo`<00000103oool2000000D0oooo1000000;0?ooo`<00000
4P3oool6000002`0oooo00<000000?ooo`3oool0703oool4000001/0oooo0`00000<0?ooo`@00000
2`3oool9000004T0oooo0`00000;0?ooo`00>03oool0103ogi`0B0000000B02Lgol80?ooo`030000
003oool0oooo04/0oooo0`0000040?ooo`8000001P3oool3000000`0oooo0`00000E0?ooo`L00000
9@3oool00`000000oooo0?ooo`0D0?ooo`P00000703oool3000000`0oooo0`00000<0?ooo`<00000
00<0oooo0000000000000`00001>0?ooo`030000003oool0oooo00T0oooo000f0?ooo`050?oOW018
000000000000001d_ol02@3oool00`000000oooo0?ooo`1<0?ooo`H000000P3oool4000000D0oooo
0`00000<0?ooo`@00000603oool6000001l0oooo00<000000?ooo`3oool02@3oool;00000200oooo
1000000<0?ooo`<00000303oool4000000030?ooo`000000000000800000D@3oool00`000000oooo
0?ooo`090?ooo`00>03oool00`3ookl0M000001d_`090?ooo`030000003oool0oooo04h0oooo0P00
00020?ooo`@000000P3oool4000000@0oooo0`00000=0?ooo`<000006`3oool7000001P0oooo3000
000U0?ooo`H00000303oool4000000`0oooo2@00001D0?ooo`030000003oool0oooo00T0oooo000j
0?ooo`030=nLB000M;l0oooo00L0oooo00<000000?ooo`3oool0D03oool400000080oooo10000002
0?ooo`@000000P3oool6000000/0oooo1000000N0?ooo`P000000`3oool>000002P0oooo2000000?
0?ooo`<000003@3oool5000000030?ooo`000000000000800000EP3oool00`000000oooo0?ooo`09
0?ooo`00>P3oool00`3ogi`0B01809cOo`070?ooo`030000003oool0oooo05@0oooo0`0000030?oo
o`D0000000<0oooo0000000000003P0000070?ooo`H000004`3ooolE000000P0oooo00<000000?oo
o`3oool07P3oool8000001@0oooo0`00000<0?ooo`H000000P3oool3000005T0oooo00<000000?oo
o`3oool02@3oool003L0oooo00H0_g@007Boo`3oool0gia80000B02Lgol70?ooo`030000003oool0
oooo05L0oooo100000040?ooo`@0000000<0oooo0000000000000P0000000`3oool0000000000004
000000030?ooo`000000000001h000005@3oool9000001P0oooo2000000H0?ooo`@00000303oool6
00000080oooo0`00001L0?ooo`030000003oool0oooo00T0oooo000h0?ooo`040;md000000000000
04RLg`P0oooo00<000000?ooo`3oool0F`3oool3000000D0oooo2@0000030?ooo`H000003@3oool6
000002D0oooo3@0000020?ooo`X000006P3oool6000000L0oooo300000020?ooo`<00000G`3oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`1N0?ooo`@000001P3oool80000
00D0oooo1`00000<0?ooo`H000007`3oool00`000000oooo0?ooo`020?oooaX00000303ooolE0000
00@0oooo1@0000000`3oool000000000000300000640oooo00<000000?ooo`3oool02@3oool004@0
oooo00<000000?ooo`3oool0HP3oool3000000L0oooo2`0000050?ooo`H00000303oool:000000/0
oooo3`00000J0?oooa4000003@3oool>000006D0oooo00<000000?ooo`3oool02@3oool004@0oooo
00<000000?ooo`3oool0I@3oool4000000L0oooo6`0000040?oooaT000001@3oool00`000000oooo
0?ooo`0H0?ooo`P000004`3oool?000006/0oooo00<000000?ooo`3oool02@3oool004@0oooo0P00
001Z0?ooo`P000002`3ooolI000001<0oooo8000000?0?oooa<00000L@3oool3000000/0oooo0014
0?ooo`030000003oool0oooo0740oooo3P00000@0?oooa400000303oool@000000D0oooo8000001l
0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo07l0ooooD@00002=0?oo
o`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3o
ool0[@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2]0?ooo`030000
003oool0oooo0:d0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0[@3o
ool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0
oooo0:d0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`00
0000oooo0?ooo`2]0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool02@3oool004@0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`00A03oool2000000/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00L0oooo0`00000;0?ooo`00A03ooooo0000068000002`3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00<L0oooo00T0oono07@000000000B9cO0?ooo`3ookl0M00000000018W=l0503o
ool00`3o_g@0000000000002000000030018W03Oool0oooo0180oooo00D0_g@00000000000000000
04RLg`2]0?ooo`00a`3oool02P3ookl0M01809cOo`2oM00007Bo0?oo_`1d04P0W=oo0;md0000M;lB
0?ooo`030?noM0000000B9cO00<0oooo00<0omnL04P0B02Lgol04`3oool00`3ooml0W4P004RLg`2^
0?ooo`00bP3oool00`3ookl0M00007Boo`020?ooo`030?oo_`1d0000M;oo0140oooo00<0okmd0000
M02oool0103oool00`3OW4P007Bo0?ooo`0C0?ooo`030=nLB000B9`0gooo0:d0oooo003;0?ooo`03
0=nLB000B9`0gooo0080oooo00<0gia80018W03Oool04@3oool0202oM000001d0;ooo`3oool0oooO
09a800000000B9cO503oool00`3ogi`0B01d0;ooo`2]0?ooo`00]03oool00`2oM000000000000005
000000030018W03Oool0oooo00<0oooo00`0omnL04P00000000004RL0=ooo`2oM0000000001d_`3o
ool0okmd0000B02Lgol20?ooo`030?noM00004P0W=oo00<0oooo00P0_g@00000000004P0W=oo0?oo
o`3OW4P004RL0=ooo`80oooo00<0_g@000000000M;l00P3oool01P3ookl0M000000000000000001d
0;ooo`D0oooo00<0okmd0000000000001`0000002@1d_ol0oooo0?oOW018000000000000M02ookl0
M00007Boo`020?ooo`0;0?oOW018000000000018W03Oool0_g@000000000M;l0oooo0?oOW0180000
0P0000002@1d_ol0gia800000000B9`0gooo0?noM0000000001809cOo`020?ooo`040;md00000000
001809cOo`80oooo00D0okmd000000000000001809cOo`030?ooo`030=nLB000B9`0gooo0080oooo
00<0_g@000000000M;l0O@3oool00;D0oooo00@0oono07@00000B9`0gooo0`3oool00`2oM0000000
001d_`030?ooo`0<0?oOW01804P0W=oo0?oOW018M;l0_g@0001d_`3o_i`0W=oo0?oo_`1d0000B9cO
0P3oool00`3ookl0M00004RLg`030?ooo`080=nLB000B9`0gooO09adW03Oool0okmd0000M02oool2
0?ooo`080=nLB000B9`0gkmd07Boo`3oool0okmd0000M02oool90?ooo`040?oog`2LB00004RL0=oo
o`<0oooo00/0oooO09a80000B9`0gooo0;md0000B9`0gooo0?oo_`1d07@0M7@004RLg`020?ooo`0T
0?oOW01804P0W=oo0?oOW018M;l0_g@0001d_`3o_i`0W=oo0;md0000B9`0gooo0?ooo`2oM000M7Ad
0000M02ogi`0W;oo0?noM00004P0W=oO09adW03Oool0oooo0=nLB000B9`0gooO09adW03Oool0omnL
04P0B02Lgol0oooo0?oOW018000007Bo0P3oool00`3o_g@0001d0;ooo`020?ooo`040=nLB000B9`0
gkmd07Boog`0oooo002f0?ooo`030=nLB00004P0W=oo00@0oooo00d0oono07@00000B9`0gooo0?oo
o`3ooml0W4P004RLg`3oool0okmd07AdM000B9`0gooo0080oooo00<0_g@00018W03Oool00P3oool0
0`2oM00004RL0=ooo`020?ooo`030?noM00004P0W=oo0080oooo00<0oono07@00018W=l00P3oool0
0`3ogi`0B01809cOo`030?ooo`030;md001d_ol0oooo00T0oooo00<0okmd0000B02Lgol01@3oool0
103OW7@0W=oo0;md0000M;l20?ooo`0@0?oo_`1d000004RL0=ooo`3oool0oooO09a80018W=l0oooo
0?noM01dM7@004RL0=ooo`3oool0_g@0001d_`<0oooo00L0_g@00000001d_ol0oooo0?oo_`1d0000
M;oo00<0oooo00<0okmd0000B02Lgol00P3oool00`3OW4P004RL0=ooo`020?ooo`070?oOW0180000
B9cO0?ooo`3ookl0M00004RLg`020?ooo`030?oOW01804P0W=oo07d0oooo002f0?ooo`030?oOW018
0000M;oo00D0oooo00<0omnL04P00000M;l00P3oool01`2oM00004RL0=ooo`3oool0_g@00000B02L
gol00P3oool00`3OW4P0001d0;ooo`020?ooo`030=nLB00007@0_ooo0080oooo00<0oono07@00018
W=l00P3oool0203ooml0W4P00000M02oool0oooo0?oog`2LB000B9cO0P3oool00`3ookl0M0000000
00020000000307Boo`3oool0oooo00D0oooo00<0oono07@00018W=l01`3oool00`3OW4P004RL0=oo
o`020?ooo`030?noM00007@0_ooo0080oooo00/0_g@00018W03Oool0oooo0;md000004P0W=oo0?oo
o`3o_g@0001d0;ooo`020?ooo`030?oo_`1d0000B9cO0080oooo00<0_g@0001d_`3oool00P3oool0
0`3ookl0M00004RLg`020?ooo`030?noM00007@0_ooo00<0oooo00/0gia80000M02oool0oooO09a8
000007@0_ooo0?ooo`3ooml0W4P004RLg`1m0?ooo`00]P3oool00`3ookl0M000001d_`060?ooo`0;
0;md000004P0W=oo0?ooo`3o_g@0001d0;ooo`3oool0oono07@0001d_ol00P3oool00`3ogi`0B000
07Boo`020?ooo`030?oOW0180000M;oo00<0oooo00<0_g@00018W03Oool00P3oool00`3OW4P004Q8
04Qd_`020?ooo`0;0;md0000M;l0oooo0?ooo`2oM00004RL0=ooo`3oool0omnL04P00018W=l01P3o
ool00`3ooml0W4P0001d_`020?ooo`030?oo_`2LW=l0oooo0080oooo00<0omnL04P0001d_ol00P3o
ool00`3ookl0M00007Boo`020?ooo`0;0?noM00007@0_ooo0?ooo`3ookl0M00007Boo`3oool0oono
07@0001d_ol00`3oool01`2oM00004RL0=ooo`3oool0gia80018W03Oool00`3oool01`2oM00004RL
0=ooo`3oool0oono07@0001d_ol00`3oool01`3ogi`0B01809cOo`3oool0gia80018B018M;l00P3o
ool00`2oM00007Bo0?ooo`1l0?ooo`00]`3oool00`2oM00004RL0=ooo`050?ooo`070?noM0000000
B9cO0?oOg`3Ookl0M00007Boo`020?ooo`070;md0000M;l0oooo0?ooo`3ooml0W4P004RLg`020?oo
o`030?oog`2LB000B9cO00<0oooo00<0gia80000B02Lgol00P3oool02`3o_g@0001d0;noM018W=l0
oooo0?noM00007@0_ooo0?ooo`2oM00007Bo00<0oooo00<0gia80000M02oool01P3oool01P3OW4P0
001d0;ooo`3oool0omnL04Qd_`@0oooo00`0_g@00000M02oool0oooo0?oog`2LB000B9cO0?ooo`3o
gml0gono07@0001d_ol20?ooo`070;md0000M;l0oooo0?ooo`3o_g@0001d0;ooo`020?ooo`070=nL
B00007@0_ooo0?ooo`3ogi`0B01809cOo`030?ooo`030=nLB00004P0W=oo0080oooo00<0gia80000
M02oool00P3oool0303ookl0M00007Boo`3oool0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;oo
og`0oooo002g0?ooo`030?noM00004P0W=oo00D0oooo00L0omnL04P00000M;l0omnL04Qd_`2oM000
07Bo0080oooo00<0okmd0018W03Oool00P3oool00`2oM00004RL0=ooo`020?ooo`030;md0000B9`0
gooo0080oooo00<0omnL04P00018W=l00P3oool0303ooml0W4P007Boo`3OW4P007Bo0?oOW01804P0
W=oo0?ooo`3ogi`0B00004RLg`80oooo00<0gia80000M02oool01P3oool00`3o_g@0000000000002
000000030000M02oool0oooo0080oooo00`0oooO09a80000B9`0gooo0?oo_`2LB4P004RL0=ooo`3o
gi`0B7Bo0;md0000M;l20?ooo`030?noM000B9`0gooo0080oooo00/0gia80000M02oool0oooo0;md
000004P0W=oo0?ooo`3ooml0W4P004RLg`030?ooo`030?oOW0180000B9cO00<0oooo0100_g@00000
M02oool0oooo0?noM00007@0_ooo0?ooo`3ooml0W4P007Boo`3OW4P007Bo0?oOW01804P0W=ooO03o
ool00;L0oooo00<0omnL04P0001d_ol01@3oool01`3ogi`0B000001d_`3oool0okmd00000000M;l0
0P3oool01@3ogi`0B01809cOo`3ookl0M00000<0000000<0M;no07@0000000000P0000003`1d_ol0
okmd00000000000004RL0=ooo`3ookl0M00000000018W=l0oooo0?noM0000000001809cOo`020?oo
o`030?oo_`1d0000000000@0000000<0B9cO0?ooo`3oool00`3oool00`3ookl0M00007Boo`020?oo
o`030;mdB02Lgol0oooo00@0oooo00X0gia80000000007@0_kmd0000M02oool0oooo0?noM0000000
07Bo0P3oool00`3ogi`0B01809cOo`030?ooo`080?oOW0180000000004RLW01d0000B9cO0?oo_`1d
00030000000607Boo`3o_g@0000000000000B9`0gooo0`3oool03`3o_g@00000000000000000M;oo
0?ooo`3ookl0M00000000018W=l0oooo0?noM0000000001809cOo`1l0?ooo`00]`3oool00`3ooml0
W4P0001d_`050?ooo`030?noM0000000B9cO00/0oooo00<0okmd0000B02Lgol00P3oool00`3o_g@0
001809cOo`0O0?ooo`060;md0000M;l0oooo0?ooo`3ogi`0M9cO7`3oool00`3o_g@0001d0;ooo`2D
0?ooo`00^03oool00`2oM00004RL0=ooo`030?ooo`040?oog`2LB000001d0;ooo`/0oooo00<0oooO
09a80000M;l00P3oool00`3ooml0W4P0001d_`0O0?ooo`030=nLB00007@0_ooo00@0oooo00<0gibL
0;ooo`3oool0703oool00`3OW7@0W=oo0?ooo`2C0?ooo`00^03oool00`3OW4P0001809cOo`020?oo
o`040?oo_`1d0000000007Boo`d0oooo00<0okmd0000M02oool00P3oool00`3o_g@0001d0;ooo`02
0?ooo`040?oo_`1d000004RL0=oooaP0oooo00<0okmd0000B02Lgol00`3oool00`3ookl0M01809cO
o`0R0?ooo`040?oo_`1d000004RL0=ooohd0oooo002g0?ooo`030;md00000000000000@0000000<0
04RL0=ooo`3oool03P3oool02P3OW4P004RL0=oog`2LB000B9cO0=nLB000B9`0gooO09a80018W=lJ
0?ooo`030;md00000000000000H0000000<0M;oo0?ooo`3oool0/@3oool00=00oooo00T0gia80000
000004P0W=oo0?ooo`3OW4P000000000B02Lgol0e`3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-2.99164, -4.40173, 0.0183417, \
0.0290655}}]
}, Closed]]
}, Closed]],

Cell[TextData[{
  "Once again, we use the Poincar\[EAcute] map to analyze the phase-space \
filling pattern.  The figures below show that the Poincar\[EAcute] map for ",
  Cell[BoxData[
      \(TraditionalForm\`{k, \[Alpha], \[Gamma], f, \[Omega]} = {1, 1, 0, 1, 
          0.5}\)]],
  " is again a relatively simple closed curve but it is populated by 9 \
interleaved qausisinusoidal recurrence relations ",
  Cell[BoxData[
      \(TraditionalForm\`x\_k \[Rule] x\_\(k + 9\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[sol];\)\), "\[IndentingNewLine]", 
    \(\(sol[
          t_] = \(duffingSol[1, 1, 0, 1, 0.5, 0, 1, 10000, 
            MaxSteps \[Rule] 5\[Times]10\^5]\)[
          t];\)\), "\[IndentingNewLine]", 
    \(\(pts = poincare[sol[t], 0.5, 0, 10000];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[pts, Frame \[Rule] True, 
        FrameLabel \[Rule] {\*"\"\<\!\(x\_k\)\>\"", \*"\"\<\!\(x\_k\%\[Prime]\
\)\>\""}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.412775 0.413136 0.30902 0.148911 [
[.20621 -0.0125 -13.8438 -15.6875 ]
[.20621 -0.0125 13.8438 0 ]
[.41278 -0.0125 -5 -15.6875 ]
[.41278 -0.0125 5 0 ]
[.61934 -0.0125 -9.5 -15.6875 ]
[.61934 -0.0125 9.5 0 ]
[.82591 -0.0125 -5 -15.6875 ]
[.82591 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -7.125 -31.375 ]
[.5 -0.0125 7.125 -15.6875 ]
[-0.0125 .0112 -18.6875 -7.84375 ]
[-0.0125 .0112 0 7.84375 ]
[-0.0125 .16011 -18.6875 -7.84375 ]
[-0.0125 .16011 0 7.84375 ]
[-0.0125 .30902 -10 -7.84375 ]
[-0.0125 .30902 0 7.84375 ]
[-0.0125 .45793 -10 -7.84375 ]
[-0.0125 .45793 0 7.84375 ]
[-0.0125 .60684 -10 -7.84375 ]
[-0.0125 .60684 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.375 -7.125 ]
[-0.01875 .30902 -18.6875 7.125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20621 0 m
.20621 .00625 L
s
gsave
.20621 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.41278 0 m
.41278 .00625 L
s
gsave
.41278 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.61934 0 m
.61934 .00625 L
s
gsave
.61934 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.82591 0 m
.82591 .00625 L
s
gsave
.82591 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.04095 0 m
.04095 .00375 L
s
.08227 0 m
.08227 .00375 L
s
.12358 0 m
.12358 .00375 L
s
.16489 0 m
.16489 .00375 L
s
.24752 0 m
.24752 .00375 L
s
.28883 0 m
.28883 .00375 L
s
.33015 0 m
.33015 .00375 L
s
.37146 0 m
.37146 .00375 L
s
.45409 0 m
.45409 .00375 L
s
.4954 0 m
.4954 .00375 L
s
.53672 0 m
.53672 .00375 L
s
.57803 0 m
.57803 .00375 L
s
.66066 0 m
.66066 .00375 L
s
.70197 0 m
.70197 .00375 L
s
.74328 0 m
.74328 .00375 L
s
.7846 0 m
.7846 .00375 L
s
.86722 0 m
.86722 .00375 L
s
.90854 0 m
.90854 .00375 L
s
.94985 0 m
.94985 .00375 L
s
.99117 0 m
.99117 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -68.125 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 17.688 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
73.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0112 m
.00625 .0112 L
s
gsave
-0.0125 .0112 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .16011 m
.00625 .16011 L
s
gsave
-0.0125 .16011 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .45793 m
.00625 .45793 L
s
gsave
-0.0125 .45793 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .60684 m
.00625 .60684 L
s
gsave
-0.0125 .60684 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04098 m
.00375 .04098 L
s
0 .07076 m
.00375 .07076 L
s
0 .10054 m
.00375 .10054 L
s
0 .13033 m
.00375 .13033 L
s
0 .18989 m
.00375 .18989 L
s
0 .21967 m
.00375 .21967 L
s
0 .24946 m
.00375 .24946 L
s
0 .27924 m
.00375 .27924 L
s
0 .3388 m
.00375 .3388 L
s
0 .36858 m
.00375 .36858 L
s
0 .39837 m
.00375 .39837 L
s
0 .42815 m
.00375 .42815 L
s
0 .48771 m
.00375 .48771 L
s
0 .5175 m
.00375 .5175 L
s
0 .54728 m
.00375 .54728 L
s
0 .57706 m
.00375 .57706 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -94.6563 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.125 11.8438 translate
90 rotate
-68.125 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 18.625 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
68.563 11.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\242) show
73.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.20621 .61178 m
.20621 .61803 L
s
.41278 .61178 m
.41278 .61803 L
s
.61934 .61178 m
.61934 .61803 L
s
.82591 .61178 m
.82591 .61803 L
s
.125 Mabswid
.04095 .61428 m
.04095 .61803 L
s
.08227 .61428 m
.08227 .61803 L
s
.12358 .61428 m
.12358 .61803 L
s
.16489 .61428 m
.16489 .61803 L
s
.24752 .61428 m
.24752 .61803 L
s
.28883 .61428 m
.28883 .61803 L
s
.33015 .61428 m
.33015 .61803 L
s
.37146 .61428 m
.37146 .61803 L
s
.45409 .61428 m
.45409 .61803 L
s
.4954 .61428 m
.4954 .61803 L
s
.53672 .61428 m
.53672 .61803 L
s
.57803 .61428 m
.57803 .61803 L
s
.66066 .61428 m
.66066 .61803 L
s
.70197 .61428 m
.70197 .61803 L
s
.74328 .61428 m
.74328 .61803 L
s
.7846 .61428 m
.7846 .61803 L
s
.86722 .61428 m
.86722 .61803 L
s
.90854 .61428 m
.90854 .61803 L
s
.94985 .61428 m
.94985 .61803 L
s
.99117 .61428 m
.99117 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0112 m
1 .0112 L
s
.99375 .16011 m
1 .16011 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45793 m
1 .45793 L
s
.99375 .60684 m
1 .60684 L
s
.125 Mabswid
.99625 .04098 m
1 .04098 L
s
.99625 .07076 m
1 .07076 L
s
.99625 .10054 m
1 .10054 L
s
.99625 .13033 m
1 .13033 L
s
.99625 .18989 m
1 .18989 L
s
.99625 .21967 m
1 .21967 L
s
.99625 .24946 m
1 .24946 L
s
.99625 .27924 m
1 .27924 L
s
.99625 .3388 m
1 .3388 L
s
.99625 .36858 m
1 .36858 L
s
.99625 .39837 m
1 .39837 L
s
.99625 .42815 m
1 .42815 L
s
.99625 .48771 m
1 .48771 L
s
.99625 .5175 m
1 .5175 L
s
.99625 .54728 m
1 .54728 L
s
.99625 .57706 m
1 .57706 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.41278 0 m
.41278 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.41278 .45793 Mdot
.32938 .34147 Mdot
.35079 .22303 Mdot
.4971 .11476 Mdot
.72871 .06129 Mdot
.89599 .07629 Mdot
.96708 .10291 Mdot
.96984 .0957 Mdot
.89905 .05169 Mdot
.70731 .01508 Mdot
.38042 .05057 Mdot
.06696 .19893 Mdot
.09912 .45097 Mdot
.43309 .57817 Mdot
.74448 .60101 Mdot
.91549 .55877 Mdot
.97331 .51863 Mdot
.96148 .51749 Mdot
.87822 .54628 Mdot
.69632 .55389 Mdot
.46705 .4897 Mdot
.3414 .37779 Mdot
.33388 .25933 Mdot
.43687 .14457 Mdot
.65896 .06932 Mdot
.85599 .06725 Mdot
.95361 .09712 Mdot
.97556 .10247 Mdot
.93092 .0675 Mdot
.78188 .02096 Mdot
.49035 .03028 Mdot
.14264 .13625 Mdot
.04094 .37982 Mdot
.32185 .55315 Mdot
.66244 .60314 Mdot
.8778 .57465 Mdot
.96426 .52745 Mdot
.97166 .51346 Mdot
.91316 .53654 Mdot
.76253 .55802 Mdot
.53278 .51688 Mdot
.3644 .41391 Mdot
.32669 .29562 Mdot
.38989 .17803 Mdot
.58582 .08498 Mdot
.80592 .06124 Mdot
.93325 .0887 Mdot
.97541 .10517 Mdot
.95311 .0818 Mdot
.84208 .03253 Mdot
.59331 .01839 Mdot
.24138 .09013 Mdot
.02418 .29817 Mdot
.21412 .51733 Mdot
.56737 .59734 Mdot
.82772 .58895 Mdot
.94815 .53974 Mdot
.97599 .51318 Mdot
.93928 .52695 Mdot
.81996 .55565 Mdot
.60493 .53787 Mdot
.40075 .44899 Mdot
.32774 .33187 Mdot
.3572 .21349 Mdot
.51479 .10771 Mdot
.74602 .06041 Mdot
.90495 .0789 Mdot
.96959 .10387 Mdot
.96726 .09325 Mdot
.88876 .04748 Mdot
.68517 .01472 Mdot
.35087 .05744 Mdot
.05249 .21825 Mdot
.12012 .46709 Mdot
.46213 .58329 Mdot
.76382 .59925 Mdot
.92361 .55458 Mdot
.97464 .51696 Mdot
.95773 .51912 Mdot
.86734 .54864 Mdot
.67762 .55155 Mdot
.45138 .48165 Mdot
.33725 .36816 Mdot
.33732 .24969 Mdot
.45167 .13623 Mdot
.67798 .06644 Mdot
.86756 .06944 Mdot
.95781 .09895 Mdot
.97463 .10106 Mdot
.92348 .06339 Mdot
.7635 .01875 Mdot
.46163 .03483 Mdot
.11974 .15122 Mdot
.05271 .40013 Mdot
.35139 .56072 Mdot
.68556 .60332 Mdot
.88894 .57049 Mdot
.96731 .52475 Mdot
.96954 .51418 Mdot
.90479 .53919 Mdot
.74571 .55762 Mdot
.51446 .5102 Mdot
.35707 .40437 Mdot
.32776 .28599 Mdot
.40096 .16889 Mdot
.60529 .08009 Mdot
.82021 .06241 Mdot
.93939 .09113 Mdot
.976 .10485 Mdot
.94806 .07823 Mdot
.82746 .02903 Mdot
.56691 .02074 Mdot
.21365 .1009 Mdot
.02421 .32025 Mdot
.24186 .52809 Mdot
.59376 .59969 Mdot
.84232 .58544 Mdot
.95319 .53618 Mdot
.9754 .51287 Mdot
.93313 .52938 Mdot
.80566 .55682 Mdot
.58548 .53297 Mdot
.3897 .43984 Mdot
.32668 .32224 Mdot
.36454 .20396 Mdot
.53312 .10105 Mdot
.76283 .06002 Mdot
.91331 .08155 Mdot
.9717 .10459 Mdot
.96421 .09054 Mdot
.8776 .04332 Mdot
.66203 .01491 Mdot
.32134 .06503 Mdot
.04077 .23857 Mdot
.14304 .48204 Mdot
.49084 .58783 Mdot
.78218 .59704 Mdot
.93104 .55047 Mdot
.97556 .51556 Mdot
.95351 .52096 Mdot
.85573 .55084 Mdot
.65855 .54866 Mdot
.43657 .47329 Mdot
.33381 .35851 Mdot
.34149 .24004 Mdot
.46739 .12817 Mdot
.6967 .06411 Mdot
.87844 .07181 Mdot
.96155 .10058 Mdot
.97327 .09936 Mdot
.91528 .05917 Mdot
.74401 .01699 Mdot
.43241 .03999 Mdot
.09865 .16746 Mdot
.06733 .41955 Mdot
.3811 .56762 Mdot
.70781 .60294 Mdot
.89927 .56625 Mdot
.96988 .52229 Mdot
.96699 .51518 Mdot
.89572 .54183 Mdot
.72822 .55672 Mdot
.49662 .50308 Mdot
.35063 .39474 Mdot
.32943 .27631 Mdot
.41312 .15986 Mdot
.62488 .0757 Mdot
.83384 .06392 Mdot
.945 .09344 Mdot
.97619 .10423 Mdot
.94238 .07446 Mdot
.81175 .02579 Mdot
.53959 .0237 Mdot
.18669 .11278 Mdot
.02751 .34234 Mdot
.27055 .53796 Mdot
.61952 .60146 Mdot
.85605 .58167 Mdot
.95769 .53281 Mdot
.97439 .51284 Mdot
.92638 .53194 Mdot
.79055 .55763 Mdot
.56602 .52753 Mdot
.3796 .43049 Mdot
.32618 .31254 Mdot
.37289 .19443 Mdot
.55204 .09478 Mdot
.77912 .06009 Mdot
.9211 .0842 Mdot
.9734 .10504 Mdot
.96063 .08756 Mdot
.86546 .03924 Mdot
.63776 .01566 Mdot
.2918 .07344 Mdot
.03195 .25985 Mdot
.16779 .4959 Mdot
.51927 .59182 Mdot
.79967 .5944 Mdot
.93784 .54643 Mdot
.97607 .51444 Mdot
.94877 .523 Mdot
.84332 .55283 Mdot
.63911 .5452 Mdot
.42263 .46462 Mdot
.33104 .34879 Mdot
.34648 .23034 Mdot
.48404 .12039 Mdot
.71513 .0623 Mdot
.8887 .07432 Mdot
.96486 .10199 Mdot
.97147 .09737 Mdot
.90631 .0549 Mdot
.72344 .01571 Mdot
.4028 .04579 Mdot
.07966 .18498 Mdot
.08458 .43793 Mdot
.41085 .57388 Mdot
.72912 .60203 Mdot
.90882 .56198 Mdot
.972 .5201 Mdot
.964 .51641 Mdot
.88597 .54441 Mdot
.71015 .5553 Mdot
.47942 .49556 Mdot
.34504 .38506 Mdot
.33173 .2666 Mdot
.42633 .15103 Mdot
.64443 .07185 Mdot
.84677 .06573 Mdot
.95011 .09561 Mdot
.97597 .10332 Mdot
.93605 .07052 Mdot
.79501 .02288 Mdot
.51158 .02725 Mdot
.16091 .12579 Mdot
.03404 .36405 Mdot
.29981 .54697 Mdot
.64445 .60264 Mdot
.86885 .5777 Mdot
.96164 .52965 Mdot
.97296 .5131 Mdot
.919 .53457 Mdot
.77469 .55802 Mdot
.54679 .52158 Mdot
.37049 .42099 Mdot
.32626 .30282 Mdot
.38227 .18496 Mdot
.57136 .08896 Mdot
.79478 .0606 Mdot
.92829 .08681 Mdot
.9747 .10522 Mdot
.9565 .08432 Mdot
.85235 .0353 Mdot
.61249 .01701 Mdot
.26256 .08271 Mdot
.02627 .28178 Mdot
.19402 .50865 Mdot
.5472 .59522 Mdot
.81619 .59139 Mdot
.944 .54252 Mdot
.97617 .51361 Mdot
.94348 .52523 Mdot
.83011 .55457 Mdot
.61941 .54117 Mdot
.40962 .45568 Mdot
.3289 .33903 Mdot
.35233 .22061 Mdot
.50153 .11293 Mdot
.73315 .06102 Mdot
.89831 .07694 Mdot
.96774 .10316 Mdot
.9692 .09509 Mdot
.89647 .0506 Mdot
.70169 .01494 Mdot
.3728 .05228 Mdot
.06298 .20381 Mdot
.10433 .45524 Mdot
.4406 .57955 Mdot
.74955 .6006 Mdot
.91764 .55769 Mdot
.97368 .51818 Mdot
.96054 .5179 Mdot
.87545 .54691 Mdot
.69147 .55333 Mdot
.46288 .48763 Mdot
.34024 .37528 Mdot
.3347 .25682 Mdot
.44064 .14237 Mdot
.66395 .06852 Mdot
.85907 .0678 Mdot
.95474 .09761 Mdot
.97534 .10212 Mdot
.92902 .06642 Mdot
.77712 .02033 Mdot
.48281 .03142 Mdot
.13642 .14008 Mdot
.04377 .38527 Mdot
.32963 .55522 Mdot
.66863 .60324 Mdot
.88082 .57356 Mdot
.9651 .52672 Mdot
.97112 .51364 Mdot
.91098 .53725 Mdot
.7581 .55796 Mdot
.52784 .51514 Mdot
.36235 .41137 Mdot
.32692 .29305 Mdot
.39274 .17558 Mdot
.59101 .08362 Mdot
.8098 .06151 Mdot
.93494 .08936 Mdot
.9756 .1051 Mdot
.9518 .08085 Mdot
.83823 .03156 Mdot
.58627 .01897 Mdot
.23383 .09294 Mdot
.02387 .30412 Mdot
.22151 .52033 Mdot
.57455 .59803 Mdot
.83174 .58803 Mdot
.94956 .53877 Mdot
.97586 .51308 Mdot
.93766 .52761 Mdot
.81614 .55601 Mdot
.59964 .53659 Mdot
.39765 .44652 Mdot
.32739 .32926 Mdot
.3591 .2109 Mdot
.51971 .10586 Mdot
.75065 .06026 Mdot
.90727 .07962 Mdot
.97019 .10409 Mdot
.96647 .09253 Mdot
.88579 .04633 Mdot
.67894 .01472 Mdot
.34279 .05945 Mdot
.049 .22372 Mdot
.12621 .4713 Mdot
.47002 .58459 Mdot
.76894 .59869 Mdot
.92571 .55345 Mdot
.97493 .51655 Mdot
.95662 .51961 Mdot
.86423 .54927 Mdot
.67242 .55081 Mdot
.44722 .47939 Mdot
.33623 .36552 Mdot
.33839 .24705 Mdot
.45589 .13399 Mdot
.68315 .06575 Mdot
.87061 .07007 Mdot
.95888 .09942 Mdot
.97429 .10062 Mdot
.92129 .06223 Mdot
.75823 .01822 Mdot
.45362 .03619 Mdot
.11373 .15557 Mdot
.05647 .40558 Mdot
.35956 .56269 Mdot
.69178 .60327 Mdot
.89186 .56933 Mdot
.96806 .52405 Mdot
.96887 .51444 Mdot
.90234 .53992 Mdot
.74093 .55742 Mdot
.50946 .50827 Mdot
.3552 .40171 Mdot
.32816 .28331 Mdot
.40422 .16637 Mdot
.61071 .07882 Mdot
.82405 .0628 Mdot
.94099 .09178 Mdot
.97609 .1047 Mdot
.94653 .0772 Mdot
.82318 .0281 Mdot
.55937 .02151 Mdot
.20603 .1041 Mdot
.0248 .32642 Mdot
.24978 .53093 Mdot
.60101 .60024 Mdot
.84623 .58442 Mdot
.95449 .53523 Mdot
.97514 .51284 Mdot
.93128 .5301 Mdot
.80147 .55709 Mdot
.57998 .53149 Mdot
.38675 .43722 Mdot
.32648 .31951 Mdot
.36679 .20127 Mdot
.53839 .09924 Mdot
.76747 .05999 Mdot
.91555 .0823 Mdot
.97221 .10474 Mdot
.96324 .08971 Mdot
.87425 .04215 Mdot
.65524 .01506 Mdot
.31293 .06733 Mdot
.03795 .24453 Mdot
.14991 .48609 Mdot
.49895 .58902 Mdot
.78724 .59633 Mdot
.93303 .54931 Mdot
.97574 .51522 Mdot
.9522 .52153 Mdot
.85227 .55143 Mdot
.65304 .54773 Mdot
.4325 .47085 Mdot
.33295 .35574 Mdot
.34283 .23728 Mdot
.47205 .12592 Mdot
.702 .06354 Mdot
.88143 .07251 Mdot
.96254 .101 Mdot
.9728 .09882 Mdot
.9128 .05796 Mdot
.73825 .01657 Mdot
.42398 .04158 Mdot
.093 .17234 Mdot
.07199 .42491 Mdot
.3896 .56948 Mdot
.71399 .60274 Mdot
.90208 .56503 Mdot
.97053 .52164 Mdot
.96618 .51551 Mdot
.89301 .54257 Mdot
.72311 .55637 Mdot
.49163 .50097 Mdot
.34894 .39198 Mdot
.33002 .27354 Mdot
.41679 .15732 Mdot
.63047 .07454 Mdot
.83761 .06441 Mdot
.94651 .09408 Mdot
.97617 .104 Mdot
.94063 .07335 Mdot
.80707 .02492 Mdot
.53165 .02465 Mdot
.17918 .11639 Mdot
.02905 .3486 Mdot
.27887 .54063 Mdot
.62674 .60185 Mdot
.8598 .58056 Mdot
.95887 .53188 Mdot
.97401 .51289 Mdot
.92431 .53269 Mdot
.78605 .55778 Mdot
.56045 .52587 Mdot
.37687 .42776 Mdot
.32615 .30975 Mdot
.37549 .19169 Mdot
.55757 .09305 Mdot
.78369 .06019 Mdot
.92322 .08496 Mdot
.97381 .10512 Mdot
.95948 .08664 Mdot
.86176 .03808 Mdot
.63053 .01599 Mdot
.28328 .07603 Mdot
.02997 .26614 Mdot
.17525 .49971 Mdot
.52742 .59286 Mdot
.80455 .59357 Mdot
.93968 .54529 Mdot
.97614 .51417 Mdot
.94728 .52364 Mdot
.83955 .55337 Mdot
.63339 .54408 Mdot
.41874 .46204 Mdot
.33035 .34595 Mdot
.34809 .22751 Mdot
.48905 .11818 Mdot
.72042 .06187 Mdot
.89156 .07508 Mdot
.96574 .10235 Mdot
.97085 .09673 Mdot
.90351 .05364 Mdot
.71718 .01543 Mdot
.39404 .04762 Mdot
.07451 .19037 Mdot
.09012 .44311 Mdot
.41957 .57561 Mdot
.7352 .60167 Mdot
.91148 .56072 Mdot
.97253 .51952 Mdot
.96303 .51683 Mdot
.88295 .54516 Mdot
.70471 .55478 Mdot
.47447 .49327 Mdot
.34355 .38219 Mdot
.33253 .26372 Mdot
.43043 .14846 Mdot
.65019 .07081 Mdot
.85046 .06631 Mdot
.95152 .09621 Mdot
.97582 .10299 Mdot
.93404 .06932 Mdot
.78983 .02208 Mdot
.50314 .02842 Mdot
.15351 .12989 Mdot
.03659 .3704 Mdot
.30859 .54949 Mdot
.65169 .60288 Mdot
.87248 .57649 Mdot
.96271 .52876 Mdot
.97245 .51324 Mdot
.91668 .53536 Mdot
.76983 .55805 Mdot
.54111 .51971 Mdot
.36797 .41814 Mdot
.32639 .29992 Mdot
.38527 .18216 Mdot
.57718 .08732 Mdot
.79931 .06083 Mdot
.93032 .08758 Mdot
.975 .10521 Mdot
.95514 .0833 Mdot
.84822 .03416 Mdot
.60473 .01754 Mdot
.25389 .08567 Mdot
.02521 .28844 Mdot
.20213 .51225 Mdot
.55546 .59612 Mdot
.82094 .59042 Mdot
.94572 .54139 Mdot
.97611 .51343 Mdot
.94177 .52594 Mdot
.82596 .55504 Mdot
.61344 .53984 Mdot
.4059 .45293 Mdot
.32838 .33608 Mdot
.35428 .21767 Mdot
.50695 .11075 Mdot
.73849 .06074 Mdot
.90108 .07774 Mdot
.96852 .10346 Mdot
.96841 .09433 Mdot
.8933 .04929 Mdot
.69486 .01481 Mdot
.36365 .05439 Mdot
.05842 .20977 Mdot
.11079 .46026 Mdot
.4496 .58115 Mdot
.75556 .60007 Mdot
.92017 .55639 Mdot
.97409 .51766 Mdot
.95937 .51841 Mdot
.87206 .54766 Mdot
.68564 .55261 Mdot
.45796 .48512 Mdot
.33893 .37228 Mdot
.33576 .25381 Mdot
.44524 .13976 Mdot
.66989 .0676 Mdot
.86269 .06848 Mdot
.95605 .09818 Mdot
.97504 .10167 Mdot
.92667 .06512 Mdot
.77133 .01963 Mdot
.47375 .03285 Mdot
.12915 .14478 Mdot
.04742 .3917 Mdot
.33895 .55763 Mdot
.67595 .60331 Mdot
.88435 .57225 Mdot
.96606 .52587 Mdot
.97044 .51387 Mdot
.90831 .5381 Mdot
.75273 .55784 Mdot
.52197 .51301 Mdot
.35999 .40832 Mdot
.32725 .28998 Mdot
.39625 .17265 Mdot
.59722 .08205 Mdot
.81437 .06188 Mdot
.93689 .09013 Mdot
.97578 .10499 Mdot
.95016 .07969 Mdot
.83351 .03042 Mdot
.57773 .01972 Mdot
.22482 .0964 Mdot
.02381 .31127 Mdot
.23047 .52383 Mdot
.5831 .5988 Mdot
.83648 .5869 Mdot
.95118 .53762 Mdot
.97564 .51299 Mdot
.93562 .52842 Mdot
.81142 .5564 Mdot
.5932 .53498 Mdot
.39397 .4435 Mdot
.32703 .32607 Mdot
.3615 .20775 Mdot
.52575 .10365 Mdot
.7562 .06012 Mdot
.91003 .08048 Mdot
.97088 .10431 Mdot
.96543 .09161 Mdot
.88203 .04492 Mdot
.67115 .01477 Mdot
.33283 .06199 Mdot
.04499 .23055 Mdot
.1339 .47635 Mdot
.47969 .58613 Mdot
.77513 .59795 Mdot
.9282 .55207 Mdot
.97522 .51609 Mdot
.95516 .52025 Mdot
.86024 .55003 Mdot
.66587 .54983 Mdot
.44212 .47652 Mdot
.33504 .3622 Mdot
.3398 .24373 Mdot
.46126 .13122 Mdot
.68957 .06494 Mdot
.87434 .07088 Mdot
.96015 .09996 Mdot
.9738 .10001 Mdot
.91843 .06075 Mdot
.75143 .0176 Mdot
.44342 .03799 Mdot
.10633 .16122 Mdot
.06152 .41237 Mdot
.36993 .56511 Mdot
.69955 .60315 Mdot
.89547 .56786 Mdot
.96894 .5232 Mdot
.96795 .5148 Mdot
.89911 .54087 Mdot
.7347 .55711 Mdot
.5031 .50574 Mdot
.35289 .39829 Mdot
.32874 .27987 Mdot
.40853 .16316 Mdot
.61767 .07725 Mdot
.8289 .06333 Mdot
.94297 .09259 Mdot
.97613 .10446 Mdot
.94446 .07582 Mdot
.81749 .02691 Mdot
.54948 .02257 Mdot
.19625 .10839 Mdot
.02595 .33443 Mdot
.26016 .53452 Mdot
.61034 .60089 Mdot
.8512 .58306 Mdot
.9561 .53401 Mdot
.97475 .51285 Mdot
.92878 .53105 Mdot
.79589 .55739 Mdot
.57279 .52949 Mdot
.38301 .43377 Mdot
.32629 .31594 Mdot
.36985 .19775 Mdot
.54536 .09692 Mdot
.77348 .06001 Mdot
.91841 .08326 Mdot
.97281 .10489 Mdot
.96187 .08858 Mdot
.86967 .04061 Mdot
.6461 .01534 Mdot
.30181 .07049 Mdot
.0346 .25253 Mdot
.1592 .49132 Mdot
.50965 .59052 Mdot
.79382 .59535 Mdot
.93557 .5478 Mdot
.9759 .51481 Mdot
.95037 .52233 Mdot
.8475 .5522 Mdot
.64557 .54641 Mdot
.42714 .46753 Mdot
.33188 .35202 Mdot
.34473 .23356 Mdot
.47842 .12294 Mdot
.70905 .06284 Mdot
.88535 .07347 Mdot
.96378 .10152 Mdot
.97207 .09802 Mdot
.90927 .05628 Mdot
.73019 .01607 Mdot
.41239 .04385 Mdot
.08555 .17919 Mdot
.07873 .43211 Mdot
.40124 .57193 Mdot
.72232 .60238 Mdot
.9058 .56337 Mdot
.97133 .5208 Mdot
.96496 .51602 Mdot
.8891 .54361 Mdot
.71589 .5558 Mdot
.48476 .49797 Mdot
.34671 .38812 Mdot
.33093 .26966 Mdot
.42205 .15379 Mdot
.63826 .073 Mdot
.84276 .06512 Mdot
.94853 .09493 Mdot
.97605 .10361 Mdot
.93804 .07174 Mdot
.80025 .02373 Mdot
.52025 .0261 Mdot
.16869 .12167 Mdot
.03169 .35743 Mdot
.29076 .54429 Mdot
.63687 .60234 Mdot
.86499 .57895 Mdot
.96045 .53061 Mdot
.9734 .51302 Mdot
.92125 .53379 Mdot
.77949 .55795 Mdot
.5525 .52341 Mdot
.37311 .42384 Mdot
.32617 .30573 Mdot
.37936 .18779 Mdot
.56554 .09065 Mdot
.79015 .0604 Mdot
.92618 .08603 Mdot
.97432 .10517 Mdot
.95772 .08527 Mdot
.85624 .03643 Mdot
.61991 .01656 Mdot
.27101 .07993 Mdot
.02759 .27535 Mdot
.18626 .50505 Mdot
.53913 .59429 Mdot
.81146 .5923 Mdot
.94224 .54366 Mdot
.97614 .51385 Mdot
.94499 .52461 Mdot
.83388 .55412 Mdot
.62496 .54236 Mdot
.41318 .45822 Mdot
.32944 .34178 Mdot
.35059 .22335 Mdot
.49653 .115 Mdot
.72812 .06133 Mdot
.89565 .07619 Mdot
.96694 .10283 Mdot
.96983 .09571 Mdot
.89919 .05176 Mdot
.70768 .01509 Mdot
.38095 .05045 Mdot
.06725 .19859 Mdot
.09875 .45066 Mdot
.43254 .57807 Mdot
.74409 .60104 Mdot
.9153 .55886 Mdot
.97323 .5187 Mdot
.96146 .51751 Mdot
.87825 .54628 Mdot
.6964 .5539 Mdot
.46713 .48974 Mdot
.34142 .37785 Mdot
.33385 .25938 Mdot
.43679 .14461 Mdot
.65884 .06934 Mdot
.85589 .06723 Mdot
.95355 .09709 Mdot
.9755 .10242 Mdot
.93084 .06746 Mdot
.78173 .02094 Mdot
.49014 .03031 Mdot
.14247 .13635 Mdot
.04101 .37997 Mdot
.32204 .5532 Mdot
.66258 .60314 Mdot
.87785 .57463 Mdot
.96424 .52746 Mdot
.97158 .51351 Mdot
.91297 .5366 Mdot
.7622 .55802 Mdot
.53242 .51675 Mdot
.36424 .41373 Mdot
.3267 .29544 Mdot
.39008 .17786 Mdot
.58618 .08488 Mdot
.80618 .06125 Mdot
.93334 .08873 Mdot
.97537 .10512 Mdot
.95292 .08167 Mdot
.84161 .03242 Mdot
.59249 .01846 Mdot
.24051 .09045 Mdot
.02414 .29885 Mdot
.21495 .51767 Mdot
.56817 .59742 Mdot
.82815 .58885 Mdot
.94827 .53965 Mdot
.97592 .51321 Mdot
.93898 .52708 Mdot
.81932 .55572 Mdot
.60407 .53766 Mdot
.40024 .44859 Mdot
.32767 .33145 Mdot
.35749 .21308 Mdot
.51556 .10742 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{242.688, 149.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005/0000h2000`400?l00000o`00003oo`3ooom]
0?ooo`00o`3ooom]0?ooo`00o`3ooom]0?ooo`00o`3ooom]0?ooo`00dP3oool01`2oM4P0W=oo0?oo
o`3ogi`0B0000000001d_ol0T`3oool00=80oooo00P0okmd04RLg`3oool0gia8001d_`3oool0_ibL
0=oooi80oooo00390?ooo`0>0=nLB000000007Bo0?ooo`3ooml0W4P00000001d_ol0oooo0?oo_`1d
B4P0B7BL09a8001d_onE0?ooo`00b`3oool0303o_g@0M;oo0?oOW01804P0W=oo0;mdM02oool0oooO
09a8M02o_g@0001d0;oooiD0oooo003<0?ooo`040;mdM02LW4P004RL0=ooo`<0oooo00@0gia807Bo
o`3ookl0M7BoU@3oool00<`0oooo00<0oono07@00000M;l0103oool0103ogi`0B7Bo0?oog`2LB002
0000000307Boo`3oool0oooo0900oooo003<0?ooo`030?oo_`1d0000M;oo00@0oooo00<0oooO09a8
M02oool0UP3oool00<`0oooo00@0okmd00000000B9`0gooo103oool00`3OW4P0M;oo0?ooo`2E0?oo
o`00c03oool01@2oM00004RL0=oOW018B9`0gooo0080oooo00<0gia800000000M;l0UP3oool00<X0
oooo00T0okmd000000000000M;oo0?ooo`3ogi`0B0000018W03Oool0V@3oool00?l0ooooK@3oool0
0?l0ooooK@3oool00?l0ooooK@3oool00?l0ooooK@3oool00?l0ooooK@3oool00?l0ooooK@3oool0
0?l0ooooK@3oool00?l0ooooK@3oool00?l0ooooK@3oool00?l0ooooK@3oool00?l0ooooK@3oool0
0?l0ooooK@3oool00?l0ooooK@3oool00?l0ooooK@3oool00?l0ooooK@3oool00?l0ooooK@3oool0
0800oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`060?oOW0180000
000000000000B9`0gooo9@3oool0102oM00000000000001d_ol]0?ooo`040;md00000000000007Bo
o`<0oooo00<0omnL04P0001d_ol00P3oool01P3ogi`0B00000000000000004RL0=ooobX0oooo00<0
oono07@0000000000P0000000`18W=l0oooo0?ooo`100?ooo`00O`3oool01P3OW4P007Bo0?ooo`3o
gi`0B00004RLg`80oooo00<0omnL04P0001d_ol00P3oool01P3o_g@0000007Boo`3oool0omnL04Qd
_b@0oooo00H0gia8001d_`3oool0omnL04P00018W=l[0?ooo`060=nLB000M;l0oooo0?oOW0180000
B9cO0P3oool00`3ogi`0B00007Boo`020?ooo`060?noM0000000M;oo0?ooo`3ogi`0B7Bo;03oool0
0`3o_g@0000007Boo`130?ooo`00OP3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo
00/0oooo00<0okmd04RLg`3oool08@3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo
02T0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`0;0?ooo`030?noM018W=l0oooo
02X0oooo00<0oooO09a80000M;l0@`3oool007h0oooo00<0oooO09a80018W=l00P3oool0103ooml0
W4P00018W03Oool:0?ooo`030?oo_`1d07@0_ooo0240oooo00<0oooO09a80018W=l00P3oool0103o
oml0W4P00018W03OoolX0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo2P3o
ool00`3ookl0M01d0;ooo`0[0?ooo`030=nLB000B9`0gooo0480oooo001a0?ooo`030?oog`2LB000
000000L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`030=nLB00004P0W=oo00X0oooo
00<0oooO09a8001d_ol08@3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo02P0oooo
00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`0:0?ooo`030?oog`2LB000M;oo02/0oooo
00<0omnL04P0B02Lgol0@P3oool007l0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RL
g`0:0?ooo`030?oo_`1d0000B9cO0280oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RL
g`0Y0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l02P3oool00`3ookl0M00004RL
g`0[0?ooo`030?oo_`1d0000M;oo0480oooo001o0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO
09a80000M;l02P3oool00`3o_g@0000007Boo`0R0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO
09a80000M;l0:@3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00X0oooo00<0okmd
0000001d_ol0;03oool00`2oM00007Bo0?ooo`110?ooo`00O`3oool00`3ogi`0B00004RLg`030?oo
o`030;md0000B9`0gooo00H0oooo00H0omoO0=ooo`3o_g@000000000M02ooolR0?ooo`030?oOW018
0000B9cO00<0oooo00<0_g@00018W03Oool0:03oool00`3ogi`0B00004RLg`030?ooo`030;md0000
B9`0gooo00H0oooo00H0omoO0=ooo`3o_g@000000000M02oool/0?ooo`030=nLB000B9`0gooo0440
oooo001o0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool01P3oool01@3ookl0
M0000000000004P0W=oo02<0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`0X
0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool01P3oool01@3ookl0M0000000
000004P0W=oo02d0oooo00<0omnL04P0B02Lgol0@@3oool00800oooo00<0omnL04P0001d_ol00P3o
ool00`3OW4P007Bo0?ooo`070?ooo`030=nLW02oool0oooo02D0oooo00<0omnL04P0001d_ol00P3o
ool00`3OW4P007Bo0?ooo`0Y0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01`3o
ool00`3OW9`0_ooo0?ooo`0^0?ooo`030?oo_`1d0000M;oo0440oooo00210?ooo`060=nLB00007@0
_ooo0?oog`2LB000B9cO203oool00`3ogi`0M9cO0?ooo`0V0?ooo`060=nLB00007@0_ooo0?oog`2L
B000B9cO:`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`P0oooo00<0omnL07BLg`3oool0;`3o
ool00`2oM00007Bo0?ooo`100?ooo`00PP3oool0103OW4P0000000000000M;l:0?ooo`050;md0000
0000000000000018W=l0903oool0103OW4P0000000000000M;l]0?ooo`040=nLB00000000000001d
_`X0oooo00D0_g@0000000000000000004RLg`0Z0?ooo`050?oo_`1d000000000000M02oool0@03o
ool00?l0ooooK@3oool00?l0ooooK@3oool00?l0ooooK@3oool00?l0ooooK@3oool00?l0ooooK@3o
ool00?l0ooooK@3oool003d0oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`3o0?oo
obL0oooo000n0?ooo`030?noM000M;l0oooo0080oooo00<0_gAd0;ooo`3oool0o`3ooolW0?ooo`00
?`3oool00`3o_g@007Bo0?ooo`0:0?ooool000003000000E0?ooo`00@03oool00`3o_g@007Bo0?oo
o`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0000001D0oooo000`0?ooo`030?oog`2LB000000000L0000000<0B9cO
0?ooo`3oool0103oool00`3o_g@0B9cO0?ooo`080?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0C0?ooo`00@P3oool00`3OW4P0B9cO0?ooo`070?oo
o`<00000J`3oool00`000000oooo0?ooo`2H0?ooo`8000005@3oool004<0oooo00<0_g@007Boo`3o
ool01P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo02`0oooo00d000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`80000000@0oooo0000003oool0
oooo0P0000001`3oool000000?ooo`000000oooo0000003oool00P0000100?ooo`030000003oool0
oooo01<0oooo00130?ooo`030?oOW01807@0_ooo00H0oooo00<000000?ooo`3oool0J`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P0000030?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`80000000@0oooo0000003oool0oooo
0P0000001`3oool000000?ooo`000000oooo0000003oool00P0000000`3oool000000?ooo`020000
00040?ooo`000000oooo000003L0oooo00<000000?ooo`3oool04`3oool004<0oooo00<0oooO09a8
001d_ol01P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`0000000P3oool01@000000oooo0000003oool000000080oooo00@000000?ooo`3oool00000;P3o
ool01`000000oooo000000000000oooo0000003oool00P0000001@3oool000000000003oool00000
0340oooo00<000000?ooo`3oool04`3oool004<0oooo00<0oono07@00018W=l01P3oool00`000000
oooo0?ooo`1[0?ooo`030000003oool0oooo01@0oooo00H000000?ooo`3oool000000?ooo`000002
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0?P3oool01@000000oooo00000000
0000oooo0080000000<0oooo000000000000;@3oool00`000000oooo0?ooo`0C0?ooo`00?`3oool0
1`3o_g@004RL0=ooo`3oool0gia80000B02Lgol01P3oool00`000000oooo0?ooo`1[0?ooo`030000
003oool0oooo00d0oooo00D000000?ooo`000000oooo000000020?ooo`060000003oool0oooo0000
003oool00000CP3oool01@000000oooo000000000000oooo00<00000:@3oool00`000000oooo0?oo
o`0C0?ooo`00@03oool01@3ogi`0B000000000000000M;oo00L0oooo00<000000?ooo`3oool0J`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo
0000001K0?ooo`@0000000<0oooo0000000000009@3oool00`000000oooo0?ooo`0C0?ooo`00C03o
ool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0080oooo00P000000?ooo`3oool00000
0?ooo`000000oooo000006H0oooo00<000000?ooo`0000001000000R0?ooo`030000003oool0oooo
01<0oooo001<0?ooo`800000J`3oool2000000050?ooo`000000oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`1/0?ooo`D000007`3oool2000001D0oooo001<0?ooo`030000003oool0oooo06D0
oooo00D000000?ooo`3oool000000?ooo`02000000030?ooo`000000oooo07H0oooo1@00000M0?oo
o`030000003oool0oooo01<0oooo001<0?ooo`030000003oool0oooo0680oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00001k0?ooo`H000006P3oool00`000000oooo0?ooo`0C
0?ooo`00C03oool00`000000oooo0?ooo`1M0?ooo`060000003oool0oooo0000003oool00000203o
ool00`000000oooo0?ooo`1l0?ooo`D00000603oool00`000000oooo0?ooo`0C0?ooo`00C03oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool000000080oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`1o0?ooo`@000005P3oool00`000000oooo0?ooo`0C0?ooo`00C03oool0
0`000000oooo0?ooo`1E0?ooo`060000003oool0oooo0000003oool00000403oool00`000000oooo
0?ooo`1;0?ooo`050000003oool000000000003oool0100000001P3oool000000000003oool00000
0?ooo`80000000D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000003oool0
0`00000E0?ooo`@00000503oool00`000000oooo0?ooo`0C0?ooo`00C03oool00`000000oooo0?oo
o`1B0?ooo`040000003oool0oooo000001D0oooo00<000000?ooo`3oool0@`3oool2000000030?oo
o`000000oooo0080000000<0oooo0000003oool00P0000000`3oool0000000000002000000060?oo
o`00000000000?ooo`000000oooo0P0000001@3oool00000000000000000oooo00<0000000D0oooo
00000000000000000?ooo`03000000030?ooo`000000000000@00000403oool400000180oooo00<0
00000?ooo`3oool04`3oool004`0oooo00<000000?ooo`3oool0C@3oool01P000000oooo0?ooo`00
0000oooo000001P0oooo00<000000?ooo`3oool0?03oool01`000000oooo000000000000oooo0000
003oool00P0000000`3oool000000?ooo`02000002<0oooo200000000`3oool000000000000=0?oo
o`@00000403oool00`000000oooo0?ooo`0C0?ooo`00C03oool2000004/0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03H0oooo00P000000?oo
o`000000oooo0000003oool000000?ooo`80000000<0oooo0000003oool0;`3oool3000000030?oo
o`000000000000@000002P3oool5000000d0oooo0P00000E0?ooo`00C03oool00`000000oooo0?oo
o`180?ooo`030000003oool000000200oooo00<000000?ooo`3oool0<`3oool020000000oooo0000
00000000oooo0000003oool00000?@3oool8000000P0oooo1000000=0?ooo`030000003oool0oooo
01<0oooo001<0?ooo`030000003oool0oooo04D0oooo00@000000?ooo`3oool000008P3oool00`00
0000oooo0?ooo`0^0?ooo`080000003oool000000000003oool000000?ooo`0000160?ooo`L00000
1`3oool3000000`0oooo00<000000?ooo`3oool04`3oool004`0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo000000020?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0:P3o
ool3000000030?ooo`000000oooo00800000CP3oool5000000L0oooo0`00000:0?ooo`030000003o
ool0oooo01<0oooo001<0?ooo`030000003oool0oooo0400oooo00<000000?ooo`000000:03oool0
0`000000oooo0?ooo`0W0?ooo`80000000@0oooo0000000000000000E@3oool7000000@0oooo0`00
00090?ooo`030000003oool0oooo01<0oooo001<0?ooo`030000003oool0oooo03/0oooo0`00000]
0?ooo`030000003oool0oooo02<0oooo00@000000?ooo`000000oooo0P00001L0?ooo`H000000`3o
ool3000000P0oooo00<000000?ooo`3oool04`3oool004`0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`03000002d0oooo00<000000?ooo`3oool0803oool2000000040?ooo`000000
oooo00000680oooo1P000000103oool000000000000000070?ooo`030000003oool0oooo01<0oooo
001<0?ooo`030000003oool0oooo03D0oooo00@000000?ooo`3oool00000<P3oool00`000000oooo
0?ooo`0N0?ooo`040000003oool00000000006T0oooo200000060?ooo`030000003oool0oooo01<0
oooo001<0?ooo`800000=03oool00`000000oooo0000000e0?ooo`030000003oool0oooo01X0oooo
00D000000?ooo`000000oooo0000001^0?ooo`L00000103oool2000001D0oooo001<0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`000000=`3oool00`000000oooo0?ooo`0H0?ooo`<00000
00<0oooo0000003oool0L@3oool5000000D0oooo00<000000?ooo`3oool04`3oool004`0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool00P00001h0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3o
ool004`0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo01<0oooo0`0000230?ooo`030000003oool0oooo01<0oooo001<0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`0A0?ooo`040000003oool00000
000008@0oooo00<000000?ooo`3oool04`3oool004`0oooo00<000000?ooo`3oool0:@3oool01000
0000oooo0?ooo`00000n0?ooo`030000003oool0oooo00h0oooo0P0000000`3oool000000?ooo`26
0?ooo`030000003oool0oooo01<0oooo001<0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`000000@@3oool00`000000oooo0?ooo`0<0?ooo`040000003oool00000000008T0oooo00<00000
0?ooo`3oool04`3oool004`0oooo00<000000?ooo`3oool09@3oool00`000000oooo000000130?oo
o`030000003oool0oooo00/0oooo0P00002<0?ooo`030000003oool0oooo01<0oooo001<0?ooo`80
00009P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00P0oooo0P0000000`3oool0
00000?ooo`2;0?ooo`8000005@3oool004`0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`160?ooo`030000003oool0oooo00L0oooo0`00002?0?ooo`030000003oool0oooo01<0oooo
001<0?ooo`030000003oool0oooo0240oooo0P0000180?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`000000T@3oool00`000000oooo0?ooo`0C0?ooo`00?@3oool00`3ookl0M00000000002
0000000304RLg`3oool0oooo00L0oooo00<000000?ooo`3oool07`3oool00`000000oooo00000019
0?ooo`030000003oool0oooo00<0oooo0`00002C0?ooo`030000003oool0oooo01<0oooo000o0?oo
o`030?noM0000000M;oo00X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`190?oo
o`060000003oool0oooo0?ooo`000000oooo0P00002D0?ooo`030000003oool0oooo01<0oooo000o
0?ooo`030?oog`2LB00007Bo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo00800000U`3oool00`000000oooo0?ooo`0C0?ooo`00@03oool00`3O
W4P004RL0=ooo`090?ooo`030000003oool0oooo01/0oooo0P00001>0?ooo`040000003oool00000
000009P0oooo00<000000?ooo`3oool04`3oool00300oooo00<0oooO09a8000000001`0000000`18
W=l0oooo0?ooo`030?ooo`030?oOW01804P0W=oo00T0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`1<0?ooo`80000000<0oooo0000003oool0V03oool00`000000oooo0?ooo`0C0?oo
o`00@03oool00`3ookl0M00007Boo`090?ooo`<000006@3oool00`000000oooo0?ooo`1=0?ooo`<0
0000VP3oool2000001D0oooo00110?ooo`030;md0000M;l0oooo00P0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0000001>0?ooo`80000000<0oooo0000003oool0VP3oool00`000000oooo
0?ooo`0C0?ooo`00@@3oool00`3OW4P004RL0=ooo`080?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0C@3oool200000080oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?oo
o`0C0?ooo`00@@3oool00`3ogi`0B01809cOo`080?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0C@3oool3000000<0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0C
0?ooo`00@@3oool00`3ookl0M00007Boo`080?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`000000CP3oool3000000@0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0C0?oo
o`00@P3oool00`2oM00007Bo0?ooo`070?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0C@3oool2000000H0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0C0?ooo`00
@03oool01@3ookl0M0000000000007@0_ooo00L0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`1=0?ooo`8000001`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo01<0
oooo001<0?ooo`030000003oool0oooo0100oooo00<000000?ooo`000000CP3oool2000000P0oooo
00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0C0?ooo`00C03oool200000140oooo00<0
00000?ooo`3oool0C@3oool2000000T0oooo00<000000?ooo`3oool0V03oool2000001D0oooo001<
0?ooo`030000003oool0oooo05l0oooo0P00000:0?ooo`030000003oool0oooo09T0oooo00<00000
0?ooo`3oool04`3oool004`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1=0?oo
o`8000002`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo01<0oooo001<0?ooo`03
0000003oool0oooo00d0oooo0P00001?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0V@3oool00`000000oooo0?ooo`0C0?ooo`00C03oool00`000000oooo0?ooo`0<0?ooo`800000
C`3oool2000000`0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0C0?ooo`00C03o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04d0oooo0P00000=0?ooo`030000003o
ool0oooo09T0oooo00<000000?ooo`3oool04`3oool004`0oooo00<000000?ooo`3oool0G03oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool04`3oool0
04`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1=0?ooo`8000003`3oool00`00
0000oooo0?ooo`2I0?ooo`030000003oool0oooo01<0oooo001<0?ooo`8000002P3oool2000004l0
oooo0P00000?0?ooo`030000003oool0oooo09P0oooo0P00000E0?ooo`00C03oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo04d0oooo0P00000@0?ooo`030000003oool0oooo09T0oooo
00<000000?ooo`3oool04`3oool004`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`1>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?oo
o`0C0?ooo`00C03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04d0oooo0P00000A
0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool04`3oool004`0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0V@3oool00`000000oooo0?ooo`0C0?ooo`00C03oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo04d0oooo0P00000B0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool04`3oool004`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0C0?ooo`00C03o
ool2000000L0oooo00<000000?ooo`3oool0C@3oool2000001<0oooo00<000000?ooo`3oool0V03o
ool2000001D0oooo001<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool04`3oool0
04`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0C0?ooo`00C03oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo04d0oooo0P00000D0?ooo`030000003oool0oooo09T0
oooo00<000000?ooo`3oool04`3oool004`0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0V@3oool00`000000oooo
0?ooo`0C0?ooo`00C03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo01<0oooo001<
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0C@3oool2000001D0oooo00<00000
0?ooo`3oool0V@3oool00`000000oooo0?ooo`0C0?ooo`00C03oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2I0?oo
o`030000003oool0oooo01<0oooo001<0?ooo`8000001@3oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0V03oool2000001D0oooo000S0?ooo`030=nL
B00007@0_ooo02H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0C0?ooo`00703o
ool00`3ookl0M7Bo0?ooo`040?ooo`030?oo_`1dB9`0gooo02H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0V@3o
ool00`000000oooo0?ooo`0C0?ooo`00703oool00`3ogi`0B01d0;ooo`030?ooo`030?noM00007@0
_ooo01X0oooo00@0_g@0000000000000M;oo2@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2I0?ooo`030000003o
ool0oooo01<0oooo000L0?ooo`070?oOW018000000000000B02Lgol0omnL04Qd_`0K0?ooo`060=nL
B000M;l0oooo0?oOW0180000B9cO203oool00`000000oooo0?ooo`1C0?ooo`8000005P3oool00`00
0000oooo0?ooo`2I0?ooo`030000003oool0oooo01<0oooo000N0?ooo`030?oo_`1d000000000080
000000<0M;oo0?ooo`3oool05`3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1=0?ooo`8000005P3oool00`000000
oooo0?ooo`2I0?ooo`030000003oool0oooo01<0oooo000M0?ooo`090?oo_`1d07@0_ooo0?ooo`3o
oml0W4P00000000007@0_ooo01L0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03O
ool60?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool04`3oool001`0oooo00<0oono
07@0M02oool0103oool00`3ogi`0B7Bo0?ooo`0G0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia8
0000B02Lgol01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo01<0oooo000L0?oo
o`030?noM0000000M;oo00<0oooo00<0oono07A8W03Oool06@3oool00`2oM00004RL0=ooo`020?oo
o`030?oOW0180000B9cO00H0ooooo`00000<000001D0oooo000n0?ooo`030=nLB00004P0W=oo0080
oooo00<0oooO09a80000M;l01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo01<0
oooo000V0?ooo`040?noM0000000001d0;oooa@0oooo00<0omnL04P00018W=l00`3oool00`2oM000
04RL0=ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0C@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool04`3oool001/0oooo
00P0gia80000001d_ol0oooo0?oog`2LW;l0oooO09a800<0000000<007Bo0?ooo`3oool05@3oool0
103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0V@3o
ool00`000000oooo0?ooo`0C0?ooo`00603oool0103OW4P0000000000000M;l30?ooo`040?oo_`1d
0000001809cOo`80oooo00<0_ibL0=ooo`3oool05`3oool00`3ogi`0B00007Boo`020?ooo`030=nL
B000M;l0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1=0?ooo`800000
5P3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo01<0oooo000G0?ooo`040?oo_`1d
000004RL0=ooo`P0oooo00D0gmoO0;md000000000000001d_`0H0?ooo`060=nLB00007@0_ooo0?oo
g`2LB000B9cO1P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo01<0oooo000R0?oo
o`030?oog`2LB000M;oo0080oooo00<0gia80000M02oool05`3oool0103OW4P0000000000000M;l7
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool04`3oool00280oooo00<0oooO09ad
W03Oool00P3oool00`3OW7@0W=oo0?ooo`0R0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo09T0oooo00<000000?oo
o`3oool04`3oool004`0oooo0P0000040?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`2H0?ooo`8000005@3oool004`0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
V@3oool00`000000oooo0?ooo`0C0?ooo`00C03oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2I0?ooo`030000003o
ool0oooo01<0oooo001<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0C@3oool2
000001D0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0C0?ooo`00C03oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0V@3oool00`00
0000oooo0?ooo`0C0?ooo`00C03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo01<0
oooo001<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0C@3oool2000001@0oooo
00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0C0?ooo`00C03oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`2I0?ooo`030000003oool0oooo01<0oooo001<0?ooo`8000001P3oool2000004l0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`2H0?ooo`8000005@3oool004`0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`1=0?ooo`8000004`3oool00`000000oooo0?ooo`2I0?oo
o`030000003oool0oooo01<0oooo001<0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo01<0oooo001<0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0C@3oool200000180oooo00<000000?ooo`3oool0
V@3oool00`000000oooo0?ooo`0C0?ooo`00C03oool00`000000oooo0?ooo`070?ooo`800000C`3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool04`3o
ool004`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1=0?ooo`8000004@3oool0
0`000000oooo0?ooo`2I0?ooo`030000003oool0oooo01<0oooo001<0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
09T0oooo00<000000?ooo`3oool04`3oool004`0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`1=0?ooo`800000403oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo01<0
oooo001<0?ooo`8000002`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0V03oool2000001D0oooo001<0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0C@3oool3000000h0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?oo
o`0C0?ooo`00C03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04d0oooo0P00000>
0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool04`3oool004`0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0000001>0?ooo`8000003@3oool00`000000oooo0?ooo`2I0?oo
o`030000003oool0oooo01<0oooo001<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool04`3oool004`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1<0?ooo`800000
303oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo01<0oooo001<0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0C@3oool2000000/0oooo00<000000?ooo`3oool0V@3o
ool00`000000oooo0?ooo`0C0?ooo`00C03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo04`0oooo0P00000:0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool04`3oool0
04`0oooo0P00000A0?ooo`030000003oool0oooo04d0oooo0`0000080?ooo`030000003oool0oooo
09P0oooo0P00000E0?ooo`00C03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04d0
oooo0P0000080?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool04`3oool004`0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0000001>0?ooo`8000001`3oool00`000000oooo
0?ooo`2I0?ooo`030000003oool0oooo01<0oooo000m0?ooo`030?oo_`1d000000000080000000<0
B9cO0?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04d0oooo0P00
00060?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool04`3oool003l0oooo00<0okmd
0000001d_ol02P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04d0oooo0P000005
0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool04`3oool003l0oooo00<0oooO09a8
0000M;l02P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04h0oooo0`0000030?oo
o`030000003oool0oooo09T0oooo00<000000?ooo`3oool04`3oool00400oooo00<0gia80018W03O
ool02@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04`0oooo0P000000103oool0
00000?ooo`00002K0?ooo`030000003oool0oooo01<0oooo00100?ooo`030?oOW01804P0W=oo00T0
oooo00<000000?ooo`3oool05`3oool200000500oooo0`00002K0?ooo`030000003oool0oooo01<0
oooo00100?ooo`030?oo_`1d0000M;oo00T0oooo0`00000H0?ooo`030000003oool0000004l0oooo
0P00002J0?ooo`8000005@3oool00440oooo00<0_g@0001d_`3oool0203oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo04d0oooo1000002I0?ooo`030000003oool0oooo01<0oooo0011
0?ooo`030=nLB000B9`0gooo00P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1<
0?ooo`@00000V03oool00`000000oooo0?ooo`0C0?ooo`00@@3oool00`3ogi`0B01809cOo`080?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`000000C03oool01P000000oooo0?ooo`000000
oooo000009H0oooo00<000000?ooo`3oool04`3oool00440oooo00<0oono07@0001d_ol0203oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool00P3oool2
000009D0oooo00<000000?ooo`3oool04`3oool00480oooo00<0_g@0001d_`3oool01`3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool00`3oool20000
00030?ooo`000000oooo0940oooo00<000000?ooo`3oool04`3oool00400oooo00D0oono07@00000
0000001d0;ooo`070?ooo`030000003oool0oooo0200oooo00@000000?ooo`3oool00000A`3oool0
0`000000oooo0?ooo`040?ooo`040000003oool0000000000940oooo00<000000?ooo`3oool04`3o
ool004`0oooo00<000000?ooo`3oool08`3oool2000004H0oooo00<000000?ooo`3oool01`3oool2
00000900oooo00<000000?ooo`3oool04`3oool004`0oooo0P00000U0?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool0203oool010000000oooo00000000002<0?ooo`8000005@3oool0
04`0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
00X0oooo0P0000000`3oool000000?ooo`2:0?ooo`030000003oool0oooo01<0oooo001<0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`000000@@3oool00`000000oooo0?ooo`0=0?ooo`80
000000<0oooo0000003oool0Q`3oool00`000000oooo0?ooo`0C0?ooo`00C03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0000003l0oooo00<000000?ooo`3oool03P3oool010000000oooo
0000000000270?ooo`030000003oool0oooo01<0oooo001<0?ooo`030000003oool0oooo02/0oooo
00@000000?ooo`3oool00000?03oool00`000000oooo0?ooo`0A0?ooo`040000003oool000000000
08@0oooo00<000000?ooo`3oool04`3oool004`0oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0000000j0?ooo`030000003oool0oooo01<0oooo0P0000000`3oool000000?ooo`210?ooo`03
0000003oool0oooo01<0oooo001<0?ooo`030000003oool0oooo0300oooo00<000000?ooo`000000
>03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0MP3oool3000000D0oooo
00<000000?ooo`3oool04`3oool004`0oooo00<000000?ooo`3oool0<P3oool010000000oooo0?oo
o`00000e0?ooo`030000003oool0oooo01L0oooo00@000000?ooo`000000oooo0P00001b0?ooo`D0
00001@3oool00`000000oooo0?ooo`0C0?ooo`00C03oool2000003H0oooo0`00000c0?ooo`030000
003oool0oooo01/0oooo0P0000020?ooo`030000003oool0oooo06X0oooo200000040?ooo`800000
5@3oool004`0oooo00<000000?ooo`3oool0=P3oool200000080oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0O0?ooo`80000000<0oooo0000003oool0IP3oool5000000040?ooo`00
00000000000000H0oooo00<000000?ooo`3oool04`3oool004`0oooo00<000000?ooo`3oool0>P3o
ool010000000oooo0?ooo`00000]0?ooo`030000003oool0oooo0200oooo00@000000?ooo`000000
oooo0P00001R0?ooo`D000000P3oool3000000L0oooo00<000000?ooo`3oool04`3oool004`0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0000000[0?ooo`030000003oool0oooo02@0oooo
0P000000103oool000000?ooo`00001K0?ooo`H000000`3oool3000000P0oooo00<000000?ooo`3o
ool04`3oool004`0oooo00<000000?ooo`3oool0?`3oool010000000oooo0?ooo`00000X0?ooo`03
0000003oool0oooo02L0oooo00H000000?ooo`00000000000?ooo`00001F0?ooo`D00000103oool4
000000T0oooo00<000000?ooo`3oool04`3oool004`0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0000000V0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`000000oooo0`000000
0`3oool000000?ooo`1;0?ooo`L000001@3oool4000000X0oooo00<000000?ooo`3oool04`3oool0
04`0oooo00<000000?ooo`3oool0A03oool010000000oooo0?ooo`00000S0?ooo`030000003oool0
oooo02h0oooo0`0000001@3oool000000000003oool0000004D0oooo200000060?ooo`@00000303o
ool00`000000oooo0?ooo`0C0?ooo`00C03oool00`000000oooo0?ooo`170?ooo`060000003oool0
oooo0000003oool000007P3oool00`000000oooo0?ooo`0c0?ooo`060000003oool000000?ooo`00
0000oooo0P00000m0?ooo`030000003oool0000000@000002@3oool3000000h0oooo00<000000?oo
o`3oool04`3oool004`0oooo0P00001;0?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0g0?ooo`0<0000003oool000000000003oool000000?ooo`00
0000oooo0000003oool00000;`3oool00`000000oooo00000004000000030?ooo`000000oooo00X0
oooo1000000>0?ooo`8000005@3oool004`0oooo00<000000?ooo`3oool0C`3oool010000000oooo
0?ooo`00000H0?ooo`030000003oool0oooo03`0oooo00H000000?ooo`000000oooo0000003oool2
000000030?ooo`000000oooo0080000000<0oooo0000003oool07P3oool00`000000oooo00000004
000000030?ooo`000000oooo00@000003@3oool400000100oooo00<000000?ooo`3oool04`3oool0
04`0oooo00<000000?ooo`3oool0DP3oool00`000000oooo000000020?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0@`3oool010000000oooo0000003oool2000000030?ooo`000000
oooo0080000000H0oooo000000000000oooo0000003oool2000000030?ooo`000000000000800000
00D0oooo00000000000000000?ooo`03000000040?ooo`00000000000?ooo`@0000000<0oooo0000
000000000`0000000`3oool000000?ooo`0>0?ooo`D000004P3oool00`000000oooo0?ooo`0C0?oo
o`00C03oool00`000000oooo0?ooo`1D0?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`1<0?ooo`80000000H0oooo000000000000oooo0000003o
ool2000000030?ooo`00000000000080000000D0oooo00000000000000000?ooo`03000000040?oo
o`00000000000?ooo`<000005`3oool4000001@0oooo00<000000?ooo`3oool04`3oool004`0oooo
00<000000?ooo`3oool0FP3oool00`000000oooo000000020?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0OP3oool5000001H0oooo00<000000?ooo`3oool04`3oool004`0oooo00<0
00000?ooo`3oool0G03oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000H0oooo
00<000000?ooo`3oool0O03oool5000001P0oooo00<000000?ooo`3oool04`3oool004`0oooo00<0
00000?ooo`3oool0HP3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000
N`3oool5000001/0oooo00<000000?ooo`3oool04`3oool004`0oooo00<000000?ooo`3oool0I`3o
ool00`000000oooo0?ooo`03000007P0oooo1@00000M0?ooo`030000003oool0oooo01<0oooo001<
0?ooo`800000J`3oool3000000<0oooo00D000000?ooo`000000oooo0000001]0?ooo`D000007`3o
ool2000001D0oooo001<0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000H`3oool2000000030?ooo`00
00000000008000008P3oool00`000000oooo0?ooo`0C0?ooo`00C03oool00`000000oooo0?ooo`1[
0?ooo`030000003oool0oooo00X0oooo00D000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo05P0oooo0P0000001P3oool00000000000000000oooo000002D0oooo00<000000?ooo`3o
ool04`3oool003d0oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`060?ooo`030000
003oool0oooo06/0oooo00<000000?ooo`3oool03P3oool01P000000oooo0?ooo`000000oooo0000
0080oooo00@000000?ooo`3oool00000C@3oool3000000060?ooo`00000000000000003oool00000
:@3oool00`000000oooo0?ooo`0C0?ooo`00?P3oool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02o
ool0oooo00H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0C0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool0000003d0
oooo00L000000?ooo`00000000000?ooo`000000oooo00<0000000<0oooo0000003oool0;03oool0
0`000000oooo0?ooo`0C0?ooo`00?`3oool00`3o_g@007Bo0?ooo`0:0?ooo`030000003oool0oooo
06/0oooo00<000000?ooo`3oool06`3oool020000000oooo0?ooo`000000oooo0000003oool00000
0`3oool200000080oooo00@000000?ooo`3oool00000:P3oool01`000000oooo000000000000oooo
0000003oool00P0000001@3oool000000000003oool0000003<0oooo00<000000?ooo`3oool04`3o
ool00400oooo00<0okmd001d_`3oool02@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0
oooo02H0oooo0P0000020?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000
003oool000000P3oool01@000000oooo0000003oool000000080oooo018000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool20000
0080oooo0P0000000`3oool000000?ooo`02000000040?ooo`000000oooo000003T0oooo00<00000
0?ooo`3oool04`3oool00440oooo00<0okmd04RLg`3oool0203oool00`000000oooo0?ooo`1[0?oo
o`030000003oool0oooo02l0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000020?ooo`0B0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0P0000020?ooo`800000@P3oool0
0`000000oooo0?ooo`0C0?ooo`00@P3oool00`3OW4P0B9cO0?ooo`070?ooo`<00000J`3oool00`00
0000oooo0?ooo`2H0?ooo`8000005@3oool004<0oooo00<0_g@007Boo`3oool01P3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool04`3oool004<0oooo
00<0omnL04P0M02oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0000000E0?ooo`00@`3oool00`3ooml0W4P007Bo
o`060?ooool000003000000E0?ooo`00@`3oool00`3ookl0M00004RLg`3o0?ooobL0oooo000o0?oo
o`070?noM000B9`0gooo0?ooo`3OW4P0001809cOo`3o0?ooobL0oooo00100?ooo`050?oOW0180000
00000000001d_ol0o`3ooolX0?ooo`00o`3ooom]0?ooo`00o`3ooom]0?ooo`00o`3ooom]0?ooo`00
o`3ooom]0?ooo`00o`3ooom]0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 363}, {223.875, 0}} -> {-1.69346, -3.34513, \
0.0136246, 0.0377999}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ListPlot[First /@ pts, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<k\>", \*"\"\<\!\(x\_k\)\>\""}];\)\), "\
\[IndentingNewLine]", 
    \(\(ListPlot[Last /@ pts, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<k\>", \
\*"\"\<\!\(x\_k\%\[Prime]\)\>\""}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.00119646 0.255109 0.255332 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.2631 -0.0125 -11 -15.6875 ]
[.2631 -0.0125 11 0 ]
[.50239 -0.0125 -11 -15.6875 ]
[.50239 -0.0125 11 0 ]
[.74168 -0.0125 -11 -15.6875 ]
[.74168 -0.0125 11 0 ]
[.98098 -0.0125 -11 -15.6875 ]
[.98098 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4.9375 -31.375 ]
[.5 -0.0125 4.9375 -15.6875 ]
[-0.0125 .12744 -27.6875 -7.84375 ]
[-0.0125 .12744 0 7.84375 ]
[-0.0125 .25511 -10 -7.84375 ]
[-0.0125 .25511 0 7.84375 ]
[-0.0125 .38278 -19 -7.84375 ]
[-0.0125 .38278 0 7.84375 ]
[-0.0125 .51044 -10 -7.84375 ]
[-0.0125 .51044 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -43.375 -7.125 ]
[-0.01875 .30902 -27.6875 7.125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2631 0 m
.2631 .00625 L
s
gsave
.2631 -0.0125 -72 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.50239 0 m
.50239 .00625 L
s
gsave
.50239 -0.0125 -72 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
.74168 0 m
.74168 .00625 L
s
gsave
.74168 -0.0125 -72 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(600) show
1.000 setlinewidth
grestore
.98098 0 m
.98098 .00625 L
s
gsave
.98098 -0.0125 -72 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(800) show
1.000 setlinewidth
grestore
.125 Mabswid
.08363 0 m
.08363 .00375 L
s
.14346 0 m
.14346 .00375 L
s
.20328 0 m
.20328 .00375 L
s
.32292 0 m
.32292 .00375 L
s
.38275 0 m
.38275 .00375 L
s
.44257 0 m
.44257 .00375 L
s
.56222 0 m
.56222 .00375 L
s
.62204 0 m
.62204 .00375 L
s
.68186 0 m
.68186 .00375 L
s
.80151 0 m
.80151 .00375 L
s
.86133 0 m
.86133 .00375 L
s
.92115 0 m
.92115 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65.9375 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
68.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12744 m
.00625 .12744 L
s
gsave
-0.0125 .12744 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .25511 m
.00625 .25511 L
s
gsave
-0.0125 .25511 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .38278 m
.00625 .38278 L
s
gsave
-0.0125 .38278 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .51044 m
.00625 .51044 L
s
gsave
-0.0125 .51044 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02531 m
.00375 .02531 L
s
0 .05084 m
.00375 .05084 L
s
0 .07638 m
.00375 .07638 L
s
0 .10191 m
.00375 .10191 L
s
0 .15298 m
.00375 .15298 L
s
0 .17851 m
.00375 .17851 L
s
0 .20404 m
.00375 .20404 L
s
0 .22958 m
.00375 .22958 L
s
0 .28064 m
.00375 .28064 L
s
0 .30618 m
.00375 .30618 L
s
0 .33171 m
.00375 .33171 L
s
0 .35724 m
.00375 .35724 L
s
0 .40831 m
.00375 .40831 L
s
0 .43384 m
.00375 .43384 L
s
0 .45937 m
.00375 .45937 L
s
0 .48491 m
.00375 .48491 L
s
0 .53597 m
.00375 .53597 L
s
0 .56151 m
.00375 .56151 L
s
0 .58704 m
.00375 .58704 L
s
0 .61257 m
.00375 .61257 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -103.656 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.125 11.8438 translate
90 rotate
-68.125 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 17.688 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
73.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2631 .61178 m
.2631 .61803 L
s
.50239 .61178 m
.50239 .61803 L
s
.74168 .61178 m
.74168 .61803 L
s
.98098 .61178 m
.98098 .61803 L
s
.125 Mabswid
.08363 .61428 m
.08363 .61803 L
s
.14346 .61428 m
.14346 .61803 L
s
.20328 .61428 m
.20328 .61803 L
s
.32292 .61428 m
.32292 .61803 L
s
.38275 .61428 m
.38275 .61803 L
s
.44257 .61428 m
.44257 .61803 L
s
.56222 .61428 m
.56222 .61803 L
s
.62204 .61428 m
.62204 .61803 L
s
.68186 .61428 m
.68186 .61803 L
s
.80151 .61428 m
.80151 .61803 L
s
.86133 .61428 m
.86133 .61803 L
s
.92115 .61428 m
.92115 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .12744 m
1 .12744 L
s
.99375 .25511 m
1 .25511 L
s
.99375 .38278 m
1 .38278 L
s
.99375 .51044 m
1 .51044 L
s
.125 Mabswid
.99625 .02531 m
1 .02531 L
s
.99625 .05084 m
1 .05084 L
s
.99625 .07638 m
1 .07638 L
s
.99625 .10191 m
1 .10191 L
s
.99625 .15298 m
1 .15298 L
s
.99625 .17851 m
1 .17851 L
s
.99625 .20404 m
1 .20404 L
s
.99625 .22958 m
1 .22958 L
s
.99625 .28064 m
1 .28064 L
s
.99625 .30618 m
1 .30618 L
s
.99625 .33171 m
1 .33171 L
s
.99625 .35724 m
1 .35724 L
s
.99625 .40831 m
1 .40831 L
s
.99625 .43384 m
1 .43384 L
s
.99625 .45937 m
1 .45937 L
s
.99625 .48491 m
1 .48491 L
s
.99625 .53597 m
1 .53597 L
s
.99625 .56151 m
1 .56151 L
s
.99625 .58704 m
1 .58704 L
s
.99625 .61257 m
1 .61257 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .25511 m
1 .25511 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02501 .25511 Mdot
.0262 .20357 Mdot
.0274 .2168 Mdot
.0286 .30723 Mdot
.02979 .45037 Mdot
.03099 .55375 Mdot
.03218 .59769 Mdot
.03338 .59939 Mdot
.03458 .55564 Mdot
.03577 .43714 Mdot
.03697 .23511 Mdot
.03817 .04138 Mdot
.03936 .06126 Mdot
.04056 .26767 Mdot
.04176 .46012 Mdot
.04295 .5658 Mdot
.04415 .60154 Mdot
.04535 .59423 Mdot
.04654 .54277 Mdot
.04774 .43035 Mdot
.04894 .28865 Mdot
.05013 .211 Mdot
.05133 .20635 Mdot
.05252 .27 Mdot
.05372 .40726 Mdot
.05492 .52903 Mdot
.05611 .58936 Mdot
.05731 .60293 Mdot
.05851 .57534 Mdot
.0597 .48323 Mdot
.0609 .30305 Mdot
.0621 .08815 Mdot
.06329 .0253 Mdot
.06449 .19891 Mdot
.06569 .40941 Mdot
.06688 .54251 Mdot
.06808 .59595 Mdot
.06927 .60052 Mdot
.07047 .56436 Mdot
.07167 .47127 Mdot
.07286 .32928 Mdot
.07406 .22521 Mdot
.07526 .20191 Mdot
.07645 .24096 Mdot
.07765 .36206 Mdot
.07885 .49809 Mdot
.08004 .57678 Mdot
.08124 .60284 Mdot
.08244 .58905 Mdot
.08363 .52043 Mdot
.08483 .36669 Mdot
.08603 .14918 Mdot
.08722 .01495 Mdot
.08842 .13233 Mdot
.08961 .35065 Mdot
.09081 .51156 Mdot
.09201 .58599 Mdot
.0932 .6032 Mdot
.0944 .58051 Mdot
.0956 .50676 Mdot
.09679 .37387 Mdot
.09799 .24768 Mdot
.09919 .20255 Mdot
.10038 .22076 Mdot
.10158 .31816 Mdot
.10278 .46107 Mdot
.10397 .55929 Mdot
.10517 .59924 Mdot
.10637 .5978 Mdot
.10756 .54928 Mdot
.10876 .42346 Mdot
.10995 .21685 Mdot
.11115 .03244 Mdot
.11235 .07424 Mdot
.11354 .28561 Mdot
.11474 .47207 Mdot
.11594 .57082 Mdot
.11713 .60236 Mdot
.11833 .59191 Mdot
.11953 .53605 Mdot
.12072 .41879 Mdot
.12192 .27897 Mdot
.12312 .20843 Mdot
.12431 .20847 Mdot
.12551 .27915 Mdot
.1267 .41902 Mdot
.1279 .53618 Mdot
.1291 .59196 Mdot
.13029 .60235 Mdot
.13149 .57074 Mdot
.13269 .47187 Mdot
.13388 .2853 Mdot
.13508 .074 Mdot
.13628 .03258 Mdot
.13747 .21717 Mdot
.13867 .4237 Mdot
.13987 .5494 Mdot
.14106 .59783 Mdot
.14226 .59921 Mdot
.14346 .55919 Mdot
.14465 .46088 Mdot
.14585 .31796 Mdot
.14704 .22068 Mdot
.14824 .20257 Mdot
.14944 .24781 Mdot
.15063 .37409 Mdot
.15183 .50692 Mdot
.15303 .58057 Mdot
.15422 .6032 Mdot
.15542 .58594 Mdot
.15662 .5114 Mdot
.15781 .35037 Mdot
.15901 .13204 Mdot
.16021 .01496 Mdot
.1614 .14948 Mdot
.1626 .36696 Mdot
.1638 .52058 Mdot
.16499 .5891 Mdot
.16619 .60283 Mdot
.16738 .57671 Mdot
.16858 .49792 Mdot
.16978 .36184 Mdot
.17097 .24085 Mdot
.17217 .2019 Mdot
.17337 .2253 Mdot
.17456 .32948 Mdot
.17576 .47145 Mdot
.17696 .56445 Mdot
.17815 .60054 Mdot
.17935 .59591 Mdot
.18055 .54239 Mdot
.18174 .40916 Mdot
.18294 .1986 Mdot
.18413 .02519 Mdot
.18533 .08841 Mdot
.18653 .30335 Mdot
.18772 .48342 Mdot
.18892 .57541 Mdot
.19012 .60293 Mdot
.19131 .5893 Mdot
.19251 .52887 Mdot
.19371 .40701 Mdot
.1949 .26981 Mdot
.1961 .20631 Mdot
.1973 .21105 Mdot
.19849 .28886 Mdot
.19969 .43059 Mdot
.20089 .54291 Mdot
.20208 .59427 Mdot
.20328 .60151 Mdot
.20447 .56568 Mdot
.20567 .45982 Mdot
.20687 .26724 Mdot
.20806 .06097 Mdot
.20926 .04161 Mdot
.21046 .23554 Mdot
.21165 .43745 Mdot
.21285 .55578 Mdot
.21405 .59942 Mdot
.21524 .59763 Mdot
.21644 .55359 Mdot
.21764 .45006 Mdot
.21883 .30693 Mdot
.22003 .2167 Mdot
.22123 .2036 Mdot
.22242 .25532 Mdot
.22362 .3862 Mdot
.22481 .51534 Mdot
.22601 .58404 Mdot
.22721 .60332 Mdot
.2284 .58242 Mdot
.2296 .50169 Mdot
.2308 .33349 Mdot
.23199 .11538 Mdot
.23319 .017 Mdot
.23439 .16721 Mdot
.23558 .38289 Mdot
.23678 .52907 Mdot
.23798 .59188 Mdot
.23917 .6022 Mdot
.24037 .57253 Mdot
.24156 .48858 Mdot
.24276 .34982 Mdot
.24396 .2346 Mdot
.24515 .20159 Mdot
.24635 .23046 Mdot
.24755 .34118 Mdot
.24874 .48152 Mdot
.24994 .56927 Mdot
.25114 .6016 Mdot
.25233 .5937 Mdot
.25353 .53489 Mdot
.25473 .39415 Mdot
.25592 .18034 Mdot
.25712 .01974 Mdot
.25832 .1037 Mdot
.25951 .32093 Mdot
.26071 .49422 Mdot
.2619 .57962 Mdot
.2631 .60325 Mdot
.2643 .58637 Mdot
.26549 .5212 Mdot
.26669 .39499 Mdot
.26789 .2612 Mdot
.26908 .20459 Mdot
.27028 .21414 Mdot
.27148 .29915 Mdot
.27267 .44197 Mdot
.27387 .54925 Mdot
.27507 .59632 Mdot
.27626 .6004 Mdot
.27746 .56013 Mdot
.27866 .44711 Mdot
.27985 .24894 Mdot
.28105 .04923 Mdot
.28224 .05227 Mdot
.28344 .25392 Mdot
.28464 .45062 Mdot
.28583 .56168 Mdot
.28703 .60073 Mdot
.28823 .59579 Mdot
.28942 .54756 Mdot
.29062 .4389 Mdot
.29182 .2963 Mdot
.29301 .21325 Mdot
.29421 .20502 Mdot
.29541 .26348 Mdot
.2966 .39828 Mdot
.2978 .52334 Mdot
.29899 .5872 Mdot
.30019 .60318 Mdot
.30139 .57851 Mdot
.30258 .49134 Mdot
.30378 .31618 Mdot
.30498 .09945 Mdot
.30617 .02104 Mdot
.30737 .18529 Mdot
.30857 .39829 Mdot
.30976 .53698 Mdot
.31096 .59433 Mdot
.31216 .60132 Mdot
.31335 .56798 Mdot
.31455 .47879 Mdot
.31575 .33793 Mdot
.31694 .22898 Mdot
.31814 .20164 Mdot
.31933 .23626 Mdot
.32053 .35312 Mdot
.32173 .4912 Mdot
.32292 .57372 Mdot
.32412 .6024 Mdot
.32532 .59115 Mdot
.32651 .52678 Mdot
.32771 .37854 Mdot
.32891 .16227 Mdot
.3301 .01624 Mdot
.3313 .11991 Mdot
.3325 .33819 Mdot
.33369 .50443 Mdot
.33489 .58342 Mdot
.33609 .6033 Mdot
.33728 .5831 Mdot
.33848 .51304 Mdot
.33967 .38282 Mdot
.34087 .25316 Mdot
.34207 .20327 Mdot
.34326 .21775 Mdot
.34446 .30996 Mdot
.34566 .45311 Mdot
.34685 .55519 Mdot
.34805 .5981 Mdot
.34925 .599 Mdot
.35044 .55405 Mdot
.35164 .43367 Mdot
.35284 .23041 Mdot
.35403 .03892 Mdot
.35523 .06448 Mdot
.35642 .27231 Mdot
.35762 .46325 Mdot
.35882 .56713 Mdot
.36001 .60177 Mdot
.36121 .59365 Mdot
.36241 .54106 Mdot
.3636 .42735 Mdot
.3648 .28607 Mdot
.366 .21028 Mdot
.36719 .20686 Mdot
.36839 .27233 Mdot
.36959 .41034 Mdot
.37078 .53093 Mdot
.37198 .59006 Mdot
.37318 .60279 Mdot
.37437 .57416 Mdot
.37557 .48029 Mdot
.37676 .29839 Mdot
.37796 .08431 Mdot
.37916 .02705 Mdot
.38035 .20372 Mdot
.38155 .41324 Mdot
.38275 .54437 Mdot
.38394 .59647 Mdot
.38514 .60019 Mdot
.38634 .56302 Mdot
.38753 .46853 Mdot
.38873 .32622 Mdot
.38993 .22394 Mdot
.39112 .20205 Mdot
.39232 .24273 Mdot
.39352 .36526 Mdot
.39471 .50048 Mdot
.39591 .57782 Mdot
.3971 .60295 Mdot
.3983 .58824 Mdot
.3995 .51805 Mdot
.40069 .36233 Mdot
.40189 .14451 Mdot
.40309 .01475 Mdot
.40428 .1369 Mdot
.40548 .35509 Mdot
.40668 .51405 Mdot
.40787 .58686 Mdot
.40907 .60311 Mdot
.41027 .5795 Mdot
.41146 .5044 Mdot
.41266 .3706 Mdot
.41385 .24576 Mdot
.41505 .20234 Mdot
.41625 .22194 Mdot
.41744 .3212 Mdot
.41864 .46392 Mdot
.41984 .56073 Mdot
.42103 .59961 Mdot
.42223 .59731 Mdot
.42343 .54745 Mdot
.42462 .41961 Mdot
.42582 .21185 Mdot
.42702 .03028 Mdot
.42821 .078 Mdot
.42941 .29049 Mdot
.43061 .47523 Mdot
.4318 .57212 Mdot
.433 .60254 Mdot
.43419 .59122 Mdot
.43539 .53412 Mdot
.43659 .41558 Mdot
.43778 .2764 Mdot
.43898 .2078 Mdot
.44018 .20914 Mdot
.44137 .28176 Mdot
.44257 .42221 Mdot
.44377 .53807 Mdot
.44496 .59262 Mdot
.44616 .60215 Mdot
.44736 .56939 Mdot
.44855 .46861 Mdot
.44975 .28035 Mdot
.45095 .07029 Mdot
.45214 .0349 Mdot
.45334 .22222 Mdot
.45453 .42755 Mdot
.45573 .5512 Mdot
.45693 .59829 Mdot
.45812 .5988 Mdot
.45932 .55768 Mdot
.46052 .45792 Mdot
.46171 .31486 Mdot
.46291 .21952 Mdot
.46411 .20282 Mdot
.4653 .24982 Mdot
.4665 .37744 Mdot
.4677 .50929 Mdot
.46889 .58156 Mdot
.47009 .60326 Mdot
.47128 .58499 Mdot
.47248 .50876 Mdot
.47368 .34571 Mdot
.47487 .12733 Mdot
.47607 .01533 Mdot
.47727 .15438 Mdot
.47846 .37145 Mdot
.47966 .523 Mdot
.48086 .58991 Mdot
.48205 .60267 Mdot
.48325 .57557 Mdot
.48445 .49534 Mdot
.48564 .35845 Mdot
.48684 .23902 Mdot
.48804 .20177 Mdot
.48923 .22669 Mdot
.49043 .33275 Mdot
.49162 .47432 Mdot
.49282 .56584 Mdot
.49402 .60086 Mdot
.49521 .59531 Mdot
.49641 .54031 Mdot
.49761 .40496 Mdot
.4988 .1934 Mdot
.5 .02346 Mdot
.5012 .09265 Mdot
.50239 .30837 Mdot
.50359 .48654 Mdot
.50479 .57664 Mdot
.50598 .60304 Mdot
.50718 .58849 Mdot
.50838 .52673 Mdot
.50957 .4036 Mdot
.51077 .2673 Mdot
.51196 .20578 Mdot
.51316 .21188 Mdot
.51436 .29174 Mdot
.51555 .43386 Mdot
.51675 .54475 Mdot
.51795 .59488 Mdot
.51914 .60122 Mdot
.52034 .56414 Mdot
.52154 .45626 Mdot
.52273 .26204 Mdot
.52393 .05748 Mdot
.52513 .04449 Mdot
.52632 .24079 Mdot
.52752 .44127 Mdot
.52872 .55751 Mdot
.52991 .59982 Mdot
.53111 .59713 Mdot
.5323 .55191 Mdot
.5335 .44691 Mdot
.5347 .30385 Mdot
.53589 .21566 Mdot
.53709 .20396 Mdot
.53829 .25759 Mdot
.53948 .38965 Mdot
.54068 .51767 Mdot
.54188 .58498 Mdot
.54307 .6033 Mdot
.54427 .58134 Mdot
.54547 .49879 Mdot
.54666 .32858 Mdot
.54786 .11074 Mdot
.54905 .01795 Mdot
.55025 .17235 Mdot
.55145 .38735 Mdot
.55264 .53139 Mdot
.55384 .59261 Mdot
.55504 .60197 Mdot
.55623 .57126 Mdot
.55743 .48581 Mdot
.55863 .34638 Mdot
.55982 .23292 Mdot
.56102 .20157 Mdot
.56222 .23206 Mdot
.56341 .34459 Mdot
.56461 .48435 Mdot
.56581 .57058 Mdot
.567 .60185 Mdot
.5682 .59299 Mdot
.56939 .5326 Mdot
.57059 .38969 Mdot
.57179 .17508 Mdot
.57298 .01852 Mdot
.57418 .10831 Mdot
.57538 .32596 Mdot
.57657 .49724 Mdot
.57777 .58076 Mdot
.57897 .60328 Mdot
.58016 .58545 Mdot
.58136 .51887 Mdot
.58256 .39146 Mdot
.58375 .25879 Mdot
.58495 .20417 Mdot
.58615 .21513 Mdot
.58734 .30225 Mdot
.58854 .44525 Mdot
.58973 .55102 Mdot
.59093 .59686 Mdot
.59213 .60002 Mdot
.59332 .5584 Mdot
.59452 .44324 Mdot
.59572 .24353 Mdot
.59691 .04605 Mdot
.59811 .0557 Mdot
.59931 .25931 Mdot
.6005 .45438 Mdot
.6017 .56332 Mdot
.6029 .60106 Mdot
.60409 .59518 Mdot
.60529 .54569 Mdot
.60648 .43553 Mdot
.60768 .29324 Mdot
.60888 .21232 Mdot
.61007 .20551 Mdot
.61127 .26602 Mdot
.61247 .40184 Mdot
.61366 .52561 Mdot
.61486 .58807 Mdot
.61606 .60309 Mdot
.61725 .57727 Mdot
.61845 .48814 Mdot
.61965 .31096 Mdot
.62084 .09487 Mdot
.62204 .02262 Mdot
.62324 .19072 Mdot
.62443 .40277 Mdot
.62563 .53922 Mdot
.62682 .59499 Mdot
.62802 .60101 Mdot
.62922 .56654 Mdot
.63041 .47578 Mdot
.63161 .33442 Mdot
.63281 .22742 Mdot
.634 .20172 Mdot
.6352 .23811 Mdot
.6364 .35671 Mdot
.63759 .494 Mdot
.63879 .57497 Mdot
.63999 .60258 Mdot
.64118 .59031 Mdot
.64238 .52423 Mdot
.64358 .37374 Mdot
.64477 .15691 Mdot
.64597 .01558 Mdot
.64716 .12493 Mdot
.64836 .34329 Mdot
.64956 .50737 Mdot
.65075 .58449 Mdot
.65195 .60327 Mdot
.65315 .58205 Mdot
.65434 .51047 Mdot
.65554 .37913 Mdot
.65674 .25086 Mdot
.65793 .20295 Mdot
.65913 .21896 Mdot
.66033 .31331 Mdot
.66152 .45641 Mdot
.66272 .5569 Mdot
.66391 .59858 Mdot
.66511 .59851 Mdot
.66631 .55209 Mdot
.6675 .42945 Mdot
.6687 .22475 Mdot
.6699 .03611 Mdot
.67109 .06847 Mdot
.67229 .27787 Mdot
.67349 .46696 Mdot
.67468 .5687 Mdot
.67588 .60202 Mdot
.67708 .59292 Mdot
.67827 .53896 Mdot
.67947 .42375 Mdot
.68067 .28303 Mdot
.68186 .20947 Mdot
.68306 .20751 Mdot
.68425 .27517 Mdot
.68545 .41401 Mdot
.68665 .53317 Mdot
.68784 .59087 Mdot
.68904 .60261 Mdot
.69024 .57272 Mdot
.69143 .47671 Mdot
.69263 .29279 Mdot
.69383 .07982 Mdot
.69502 .02931 Mdot
.69622 .20948 Mdot
.69742 .41776 Mdot
.69861 .54656 Mdot
.69981 .59706 Mdot
.70101 .59977 Mdot
.7022 .56137 Mdot
.7034 .46521 Mdot
.70459 .3226 Mdot
.70579 .22248 Mdot
.70699 .20225 Mdot
.70818 .2449 Mdot
.70938 .3691 Mdot
.71058 .50331 Mdot
.71177 .57903 Mdot
.71297 .60306 Mdot
.71417 .58723 Mdot
.71536 .51513 Mdot
.71656 .35706 Mdot
.71776 .13895 Mdot
.71895 .01472 Mdot
.72015 .14244 Mdot
.72134 .36038 Mdot
.72254 .51697 Mdot
.72374 .58786 Mdot
.72493 .60298 Mdot
.72613 .57824 Mdot
.72733 .50148 Mdot
.72852 .36662 Mdot
.72972 .24349 Mdot
.73092 .20211 Mdot
.73211 .22342 Mdot
.73331 .32493 Mdot
.73451 .46736 Mdot
.7357 .56243 Mdot
.7369 .60003 Mdot
.7381 .59667 Mdot
.73929 .54512 Mdot
.74049 .41479 Mdot
.74168 .2057 Mdot
.74288 .02781 Mdot
.74408 .08275 Mdot
.74527 .29647 Mdot
.74647 .47906 Mdot
.74767 .57366 Mdot
.74886 .60272 Mdot
.75006 .59032 Mdot
.75126 .53166 Mdot
.75245 .41153 Mdot
.75365 .27325 Mdot
.75485 .20707 Mdot
.75604 .21001 Mdot
.75724 .28508 Mdot
.75844 .42618 Mdot
.75963 .54037 Mdot
.76083 .5934 Mdot
.76202 .60184 Mdot
.76322 .56762 Mdot
.76442 .46441 Mdot
.76561 .27405 Mdot
.76681 .06572 Mdot
.76801 .03802 Mdot
.7692 .22863 Mdot
.7704 .43235 Mdot
.7716 .55343 Mdot
.77279 .59884 Mdot
.77399 .59823 Mdot
.77519 .55568 Mdot
.77638 .45407 Mdot
.77758 .31093 Mdot
.77877 .2181 Mdot
.77997 .20317 Mdot
.78117 .25248 Mdot
.78236 .38174 Mdot
.78356 .51229 Mdot
.78476 .58279 Mdot
.78595 .60328 Mdot
.78715 .58371 Mdot
.78835 .50524 Mdot
.78954 .3396 Mdot
.79074 .12129 Mdot
.79194 .01604 Mdot
.79313 .16079 Mdot
.79433 .37721 Mdot
.79553 .52607 Mdot
.79672 .5909 Mdot
.79792 .60243 Mdot
.79911 .57402 Mdot
.80031 .49189 Mdot
.80151 .35401 Mdot
.8027 .23671 Mdot
.8039 .20166 Mdot
.8051 .22858 Mdot
.80629 .33705 Mdot
.80749 .47803 Mdot
.80869 .56761 Mdot
.80988 .60123 Mdot
.81108 .59447 Mdot
.81228 .53749 Mdot
.81347 .39931 Mdot
.81467 .18653 Mdot
.81587 .02138 Mdot
.81706 .09839 Mdot
.81826 .31498 Mdot
.81945 .49061 Mdot
.82065 .57822 Mdot
.82185 .60314 Mdot
.82304 .58736 Mdot
.82424 .52378 Mdot
.82544 .39899 Mdot
.82663 .26399 Mdot
.82783 .20511 Mdot
.82903 .21306 Mdot
.83022 .29568 Mdot
.83142 .43822 Mdot
.83262 .54718 Mdot
.83381 .59565 Mdot
.83501 .60077 Mdot
.8362 .56196 Mdot
.8374 .45128 Mdot
.8386 .25487 Mdot
.83979 .05287 Mdot
.84099 .04866 Mdot
.84219 .24798 Mdot
.84338 .44642 Mdot
.84458 .55981 Mdot
.84578 .60032 Mdot
.84697 .59638 Mdot
.84817 .54949 Mdot
.84937 .44245 Mdot
.85056 .2996 Mdot
.85176 .21428 Mdot
.85296 .20453 Mdot
.85415 .26084 Mdot
.85535 .39447 Mdot
.85654 .52085 Mdot
.85774 .58622 Mdot
.85894 .60323 Mdot
.86013 .57974 Mdot
.86133 .49458 Mdot
.86253 .32153 Mdot
.86372 .10426 Mdot
.86492 .01959 Mdot
.86612 .1797 Mdot
.86731 .3936 Mdot
.86851 .53459 Mdot
.86971 .59359 Mdot
.8709 .60159 Mdot
.8721 .56936 Mdot
.8733 .48175 Mdot
.87449 .34146 Mdot
.87569 .23059 Mdot
.87688 .20159 Mdot
.87808 .23445 Mdot
.87928 .34952 Mdot
.88047 .48834 Mdot
.88167 .57241 Mdot
.88287 .60216 Mdot
.88406 .59191 Mdot
.88526 .52919 Mdot
.88646 .38313 Mdot
.88765 .16749 Mdot
.88885 .01705 Mdot
.89005 .11512 Mdot
.89124 .3332 Mdot
.89244 .50151 Mdot
.89363 .58234 Mdot
.89483 .60329 Mdot
.89603 .58404 Mdot
.89722 .51537 Mdot
.89842 .38624 Mdot
.89962 .25536 Mdot
.90081 .2036 Mdot
.90201 .21668 Mdot
.90321 .30687 Mdot
.9044 .45 Mdot
.9056 .55354 Mdot
.9068 .5976 Mdot
.90799 .59939 Mdot
.90919 .55573 Mdot
.91039 .43737 Mdot
.91158 .23544 Mdot
.91278 .04156 Mdot
.91397 .06103 Mdot
.91517 .26732 Mdot
.91637 .45987 Mdot
.91756 .56568 Mdot
.91876 .60149 Mdot
.91996 .59421 Mdot
.92115 .54279 Mdot
.92235 .4304 Mdot
.92355 .2887 Mdot
.92474 .21101 Mdot
.92594 .20633 Mdot
.92714 .26995 Mdot
.92833 .40718 Mdot
.92953 .52897 Mdot
.93073 .58932 Mdot
.93192 .60289 Mdot
.93312 .57529 Mdot
.93431 .48314 Mdot
.93551 .30292 Mdot
.93671 .08805 Mdot
.9379 .02535 Mdot
.9391 .19903 Mdot
.9403 .4095 Mdot
.94149 .54254 Mdot
.94269 .59593 Mdot
.94389 .60047 Mdot
.94508 .56425 Mdot
.94628 .47106 Mdot
.94748 .32905 Mdot
.94867 .22512 Mdot
.94987 .20191 Mdot
.95106 .24108 Mdot
.95226 .36228 Mdot
.95346 .49824 Mdot
.95465 .57683 Mdot
.95585 .60281 Mdot
.95705 .58894 Mdot
.95824 .52014 Mdot
.95944 .36618 Mdot
.96064 .14864 Mdot
.96183 .01492 Mdot
.96303 .13285 Mdot
.96423 .35115 Mdot
.96542 .51183 Mdot
.96662 .58607 Mdot
.96782 .60315 Mdot
.96901 .58032 Mdot
.97021 .50637 Mdot
.9714 .37334 Mdot
.9726 .24736 Mdot
.9738 .20251 Mdot
.97499 .22094 Mdot
.97619 .31864 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{366.375, 226.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008U0001Db000`400?l00000o`00003oo`3ooooo
0?ooobL0oooo003o0?ooool0oooo9`3oool00?l0ooooo`3ooolW0?ooo`00o`3ooooo0?ooobL0oooo
003o0?ooool0oooo9`3oool00?l0ooooo`3ooolW0?ooo`00o`3ooooo0?ooobL0oooo003o0?ooobl0
oooo00P0_g@0001d_`3oool0oooo0?noM0000000001d0;ooonl0oooo003o0?ooobl0oooo00P0okmd
0000M02oool0oooo0;md0000M;l0oono07Ad_nl0oooo003o0?ooobl0oooo00H0omnL04P0B02Lgol0
oooO09a80018W=oa0?ooo`00o`3oool_0?ooo`060?oog`2LB00004Qd0;noW01804P0W=ool@3oool0
0?l0oooo<03oool01@3OW4P004Qd07A8000007@0_ooo0?40oooo003o0?oooc00oooo00D0okmd0000
M02oool0_g@007Boo`3a0?ooo`00o`3oool`0?ooo`060?oo_`1d0000M;oo0?ooo`2oM4P0W=ool03o
ool00?l0oooo<@3oool0102oM00007Bo0?oo_`1d000200000003001d_`3oool0oooo0>`0oooo003o
0?oooc40oooo00<0okmd0018W03Oool0lP3oool00?l0oooo<@3oool00`3ogi`0B01809cOo`3b0?oo
o`00o`3ooola0?ooo`030?oog`2LB000B9cO0?80oooo003o0?oooc80oooo00<0_g@0001d_`3oool0
l@3oool00?l0oooo<03oool01@3ooml0W4P00000000007@0_ooo0?40oooo003o0?ooool0oooo9`3o
ool00?l0ooooo`3ooolW0?ooo`00o`3ooooo0?ooobL0oooo003o0?ooool0oooo9`3oool00?l0oooo
o`3ooolW0?ooo`00o`3ooooo0?ooobL0oooo003o0?ooool0oooo9`3oool00?l0ooooo`3ooolW0?oo
o`00o`3ooooo0?ooobL0oooo003o0?ooool0oooo9`3oool005@0oooo00@0_g@0000000000000M;oo
H03oool00`3OW4P00000000000030000000304RLg`3oool0oooo0080oooo00@0_g@0000000000000
M;oo1@3oool0102oM00000000000001d_omI0?ooo`030?oog`2LB000B9cO00D0oooo00@0_g@00000
00000000M;oo1@3oool0102oM00000000000001d_omH0?ooo`050?oog`2LB000000000000000M;l0
1@3oool0102oM00000000000001d_ol50?ooo`040;md00000000000007BooeP0oooo00H0oono07@0
0000000000000018W03Oool40?ooo`040;md00000000000007Boo`D0oooo00@0_g@0000000000000
M;oo2@3oool005<0oooo00H0gia8001d_`3oool0omnL04P00018W=mP0?ooo`030?noM000M;l0oooo
0080oooo00X0_gAd0;ooo`3oool0oooo0=nLB000M;l0oooo0?oOW0180000B9cO0`3oool01P3OW4P0
07Bo0?ooo`3ogi`0B00004RLgeT0oooo00<0gia80018W03Oool00`3oool01P3OW4P007Bo0?ooo`3o
gi`0B00004RLg`<0oooo00H0gia8001d_`3oool0omnL04P00018W=mG0?ooo`070=nLB000M;l0oooo
0?oo_`1d000004RL0=ooo`020?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0`3oool01P3OW4P0
07Bo0?ooo`3ogi`0B00004RLgeH0oooo00<0oono07@00018W=l00P3oool00`3OW4P0001d0;ooo`02
0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RL
g`P0oooo001B0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0H03oool00`3o_g@0
07Bo0?ooo`040?ooo`030?oog`2LB000B9cO0080oooo00L0okmd0000B02Lgol0oooo0?oog`2LB000
B9cO0080oooo00<0okmd0000B02Lgol0F03oool00`3ogi`0B01809cOo`020?ooo`030?oog`2LB000
B9cO0080oooo00L0okmd0000B02Lgol0oooo0?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0
E@3oool00`3ooml0W4P007Boo`020?ooo`070?oOW0180000B9cO0?ooo`3ooml0W4P004RLg`020?oo
o`070?noM00004P0W=oo0?ooo`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo05D0oooo00<0
okmd0018W03Oool00`3oool01P2oM000B9cO0?ooo`3ooml0W4P004RLg`80oooo00L0okmd0000B02L
gol0oooo0?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol01`3oool00580oooo00<0oooO09a8
0018W=l00P3oool0103ooml0W4P00018W03OoomP0?ooo`030?noM000M;l0oooo00<0oooo00<0oooO
09a80018W=l00P3oool01`3ooml0W4P00018W03Oool0oooO09a80018W=l00P3oool0103ooml0W4P0
0018W03OoomC0?ooo`030?noM0000000000000@0000000D004RL0=ooo`3ooml0W4P004RLg`020?oo
o`070?oog`2LB00004RL0=ooo`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=oooe@0oooo
00<0oono07@0001d_ol00`3oool01P2oM000001d0;ooo`3ooml0W4P004RLg`80oooo00L0oooO09a8
0000B9`0gooo0?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0goooE03oool00`3o_g@004RL
0=ooo`030?ooo`060;md0000M;l0oooo0?oog`2LB000B9cO0P3oool01`3ooml0W4P00018W03Oool0
oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool60?ooo`00DP3oool00`3ooml0W4P0001d
_`030?ooo`030=nLB00004P0W=oo0640oooo00<0okmd04RLg`3oool00P3oool00`3ooml0W4P0001d
_`030?ooo`060=nLB00004P0W=oo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`1C0?ooo`03
0?oog`2LB4P0W=oo0080oooo00L0_g@0001d_`3oool0oooo0?oog`2LB00007Bo00<0oooo00H0gia8
0000B02Lgol0oooO09a80000M;l30?ooo`030=nLB00004P0W=oo05@0oooo00<0oooO09a80000M;l0
0`3oool01P3OW4P0001809cOo`3ooml0W4P0001d_`<0oooo00H0gia80000B02Lgol0oooO09a80000
M;l30?ooo`030=nLB00004P0W=oo05@0oooo00<0oooO09a8001d_ol00P3oool01`3ookl0M00004RL
g`3oool0oooO09a80000M;l00`3oool01P3OW4P0001809cOo`3ooml0W4P0001d_`<0oooo00<0gia8
0000B02Lgol01P3oool005<0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`1R0?oo
o`030=nLB018W=l0oooo0080oooo00<0_g@00018W03Oool00P3oool01`3ogi`0B00004RLg`3oool0
_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`1D0?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@0
04RL0=ooo`020?ooo`030;md0000B9`0gooo0080oooo00L0omnL04P00018W=l0oooo0;md0000B9`0
gooo0080oooo00<0omnL04P00018W=l0E@3oool00`2oM000001d0;ooo`020?ooo`070=nLB00004P0
W=oo0?ooo`2oM00004RL0=ooo`020?ooo`070?oOW0180000B9cO0?ooo`2oM00004RL0=ooo`020?oo
o`030?oOW0180000B9cO05H0oooo00H0_g@00000B02Lgml0W4P00000M02oool20?ooo`030;md0000
B9`0gooo0080oooo00L0omnL04P00018W=l0oooo0;md0000B9`0gooo0080oooo00<0omnL04P00018
W=l01P3oool005<0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`1S0?ooo`070;md
001d_ol0oooo0?ooo`3OW4P0001809cOo`020?ooo`070?oog`2LB00007Bo0?ooo`3OW4P0001809cO
o`020?ooo`030?oog`2LB00007Bo05D0oooo00H0omnL04Q8W03Oool0omnL04P0B02Lgol20?ooo`03
0=nLB00004P0W=oo0080oooo00L0oooO09a80000M;l0oooo0=nLB00004P0W=oo0080oooo00<0oooO
09a80000M;l0E@3oool0303o_g@0000004RLg`3oool0oooO09a80000B9`0gooo0?ooo`3OW4P00018
09cOo`80oooo00L0oooO09a80000M;l0oooo0=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0
E`3oool01@3ooml0W4P000000000B9`0gooo0080oooo00<0gia80000B02Lgol00P3oool01`3ooml0
W4P0001d_`3oool0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`060?ooo`00D`3oool00`3o
gi`0B00004RLg`030?ooo`030;md0000B9`0gooo0680oooo00L0omnL04P0M02oool0oooo0?oOW018
0000B9cO00<0oooo00H0_g@00018W03Oool0omnL04P00018W=l30?ooo`030;md0000B9`0gooo05D0
oooo00D0okmd001d_`3ooml0W4P004RLg`020?ooo`030?oOW0180000B9cO00<0oooo00H0_g@00018
W03Oool0omnL04P00018W=l30?ooo`030;md0000B9`0gooo05@0oooo00<0oooO09a8000000000P00
00001`0007@0_ooo0?ooo`3oool0omnL04P00018W=l00`3oool01P2oM00004RL0=ooo`3ogi`0B000
04RLg`<0oooo00<0_g@00018W03Oool0EP3oool02P2oM000001809cOo`3ogi`0B4RL0=ooo`3oool0
omnL04P00018W=l30?ooo`060;md0000B9`0gooo0?oOW0180000B9cO0`3oool00`2oM00004RL0=oo
o`050?ooo`00D`3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo0680oooo00P0
oooO09a8001d_ol0oooo0?oog`2LB00004RL0=ooo`80oooo00L0gia80018W03Oool0oooO09a80000
B9`0gooo0080oooo00<0gia80018W03Oool0EP3oool0103OW4P0B9cO0;md0000M;l20?ooo`040?oo
g`2LB00004RL0=ooo`80oooo00L0gia80018W03Oool0oooO09a80000B9`0gooo0080oooo00<0gia8
0018W03Oool0E@3oool00`3ookl0M000001d_`050?ooo`040?oog`2LB00004RL0=ooo`80oooo00L0
gia80018W03Oool0oooO09a80000B9`0gooo0080oooo00<0gia80018W03Oool0E@3oool00`3ogi`0
B00007Boo`020?ooo`070?noM018W=l0oooo0?oog`2LB00004RL0=ooo`020?ooo`070=nLB000B9`0
gooo0?oog`2LB00004RL0=ooo`020?ooo`030=nLB000B9`0gooo00D0oooo001D0?ooo`030?oOW018
0000M;oo0080oooo00<0gia8001d_`3oool0HP3oool00`3ookl0M00004RLg`020?ooo`030?oOW018
0000M;oo0080oooo00L0gia8001d_`3oool0oooo0?oOW0180000M;oo0080oooo00<0gia8001d_`3o
ool0E`3oool0103OW4P0M7Ad0000M02oool20?ooo`030?oOW0180000M;oo0080oooo00L0gia8001d
_`3oool0oooo0?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0EP3oool00`3ogi`0B00004RL
g`050?ooo`030?oOW0180000M;oo0080oooo00L0gia8001d_`3oool0oooo0?oOW0180000M;oo0080
oooo00<0gia8001d_`3oool0E@3oool00`3ogi`0B01809cOo`020?ooo`070?noM000B9`0gooo0?oo
o`3ogi`0B00007Boo`020?ooo`070=nLB000M;l0oooo0?ooo`3ogi`0B00007Boo`020?ooo`030=nL
B000M;l0oooo00D0oooo001E0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cOG`3oool01`3o_g@0
04RL0=ooo`3oool0gia80000B02Lgol00`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`<0oooo
00H0gia80000M02oool0oooO09a80018W=mI0?ooo`030;md000004P0W=oo00<0oooo00H0gia80000
M02oool0oooO09a80018W=l30?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cOF03oool0103ooml0
W4P00000M02oool40?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO0`3oool01P3OW4P0001d0;oo
o`3ooml0W4P004RLgeH0oooo00<0oooO09a80018W=l00P3oool00`2oM00007Bo0?ooo`020?ooo`06
0=nLB00007@0_ooo0?oog`2LB000B9cO0`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`H0oooo
001F0?ooo`040=nLB00000000000001d_f40oooo00D0omnL04P000000000000007Boo`050?ooo`04
0=nLB00000000000001d_`D0oooo00@0gia800000000000007BoFP3oool00`3ooml0W4P004RLg`04
0?ooo`040=nLB00000000000001d_`D0oooo00@0gia800000000000007BoF`3oool0103ookl0M000
00000018W=l30?ooo`040=nLB00000000000001d_`D0oooo00@0gia800000000000007BoF03oool0
1@3ooml0W4P000000000000007Bo00D0oooo00@0gia800000000000007Bo1@3oool0103OW4P00000
00000000M;l70?ooo`00o`3ooooo0?ooobL0oooo003o0?ooool0oooo9`3oool00?l0ooooo`3ooolW
0?ooo`00o`3ooooo0?ooobL0oooo003o0?ooool0oooo9`3oool00?l0ooooo`3ooolW0?ooo`00o`3o
oooo0?ooobL0oooo003o0?ooool0oooo9`3oool00?l0ooooo`3ooolW0?ooo`00o`3ooooo0?ooobL0
oooo003o0?ooool0oooo9`3oool004`0ooooo`00003@000000X0oooo001<0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00P0oooo001<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0J`3oool00`00
0000oooo0?ooo`1/0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0J`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo06`0
oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0
oooo001<0?ooo`030000003oool0oooo0?l0ooooc03oool00`000000oooo0?ooo`080?ooo`00C03o
ool00`000000oooo0?ooo`3o0?oool`0oooo00<000000?ooo`3oool0203oool004`0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo06h0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool0903oool3000001h0oooo0`00000P0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool07P3oool3000001h0oooo0`00000P0?oo
o`030000003oool0oooo02T0oooo0`00000O0?ooo`<000007P3oool3000002/0oooo00<000000?oo
o`3oool07P3oool300000100oooo00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo0`0000090?ooo`03
0000003oool0oooo01h0oooo0`00000P0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool07P3oool3000000T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`<0
0000803oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool01`3oool3000001D0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00L0oooo0`00000E0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool3000000T0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`1c0?ooo`030000003o
ool0oooo01<0oooo0`00001G0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool04`3o
ool3000005L0oooo0`00000D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0203o
ool004`0oooo0P00000K0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`1E0?ooo`<00000=`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool0603oool3000000X0oooo001<0?ooo`030000003oool0oooo
01T0oooo0`00000d0?ooo`<00000F@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
06h0oooo00<000000?ooo`3oool0EP3oool3000001/0oooo00<000000?ooo`3oool0203oool004`0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo05L0
oooo0`00000D0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool04P3oool3000005P0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0KP3oool00`000000oooo
0?ooo`0B0?ooo`<00000N@3oool3000001@0oooo00<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`0_0?ooo`<00000203oool3000008D0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo08X0oooo00<0
00000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo08h0oooo0`00001S0?ooo`030000003oool0oooo09H0oooo00<00000
0?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo0640oooo0`00000[0?ooo`030000003oool0oooo06T0oooo00<000000?oo
o`3oool0203oool004`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1<0?ooo`03
0000003oool0oooo03l0oooo0`00002@0?ooo`030000003oool0oooo02T0oooo0`0000110?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool0
3@3oool3000004`0oooo0`0000110?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0
?`3oool3000002L0oooo00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203o
ool004`0oooo00<000000?ooo`3oool0kP3oool3000001h0oooo0`00002i0?ooo`030000003oool0
oooo00P0oooo001<0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0KP3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`080?ooo`00C03oool2000007h0oooo0`00003o0?ooo`40oooo0`0000160?ooo`<0
00002P3oool004`0oooo00<000000?ooo`3oool0OP3oool300000?l0oooo0`0000180?ooo`030000
003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0S`3o
ool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0203o
ool004`0oooo00<000000?ooo`3oool0k`3oool00`000000oooo0?ooo`0N0?ooo`<00000^03oool0
0`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0S`3oool300000200oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo00d0
oooo0`00001;0?ooo`<00000T@3oool00`000000oooo0?ooo`2`0?ooo`<000009P3oool00`000000
oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?oo
o`2P0?ooo`<00000^`3oool3000006X0oooo00<000000?ooo`3oool0203oool004`0oooo00<00000
0?ooo`3oool0X@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0J@3oool00`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`3=0?oo
o`030000003oool0oooo0680oooo0`00002F0?ooo`030000003oool0oooo00P0oooo001<0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2>0?ooo`<0
0000I03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000
003oool0oooo02l0oooo0`0000080?ooo`<00000T03oool00`000000oooo0?ooo`3k0?ooo`030000
003oool0oooo00P0oooo001<0?ooo`800000<@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo08@0oooo00<000000?ooo`3oool0o`3oool50?ooo`<000002P3oool004`0oooo00<00000
0?ooo`3oool0`@3oool3000007T0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`08
0?ooo`00C03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo07L0oooo0`00000E0?oo
o`030000003oool0oooo07@0oooo00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3o
ool0Z`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01<0oooo0`00001e0?ooo`03
0000003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo0:X0oooo0`00002W0?ooo`030000
003oool0oooo07@0oooo00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0o`3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0
oooo01P0oooo0`00000f0?ooo`<00000o`3ooomI0?ooo`<00000703oool00`000000oooo0?ooo`08
0?ooo`00C03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0203oool004`0oooo00<000000?ooo`3oool0h`3oool3000003D0oooo00<000000?ooo`3o
ool0[@3oool00`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`3T0?ooo`030000
003oool0oooo03<0oooo0`00002^0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000003o
ool0oooo08T0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo0580oooo00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool0R03oool3
00000>X0oooo0`00001C0?ooo`030000003oool0oooo00P0oooo001<0?ooo`800000M@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0>X0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0j0?ooo`<000002P3oool004`0oooo00<000000?ooo`3oool0L`3oool300000?l0
oooo5P3oool3000003d0oooo00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`3j0?ooo`030000003o
ool0oooo00P0oooo0`0000330?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0
oooo0?T0oooo0`00000:0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0203oool0
04`0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`080?ooo`00C03oool00`000000
oooo0?ooo`1W0?ooo`<00000o`3oool^0?ooo`<00000<@3oool00`000000oooo0?ooo`080?ooo`00
;P3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00H0omnL04P00000
000000000018W03Oool<0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`3o0?ooo`40oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`08
0?ooo`00;@3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00P3o
ool01P3o_g@0000007Boo`3oool0omnL04Qd_``0oooo00<000000?ooo`3oool0U03oool300000=<0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`080?ooo`00;03oool00`3ooml0W4P0
04RLg`020?ooo`030?noM00004P0W=oo00/0oooo00<0okmd04RLg`3oool02P3oool00`000000oooo
0?ooo`2E0?ooo`030000003oool0oooo0=40oooo0`00001O0?ooo`030000003oool0oooo00P0oooo
000/0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo2P3oool00`3ookl0M01d
0;ooo`0:0?ooo`030000003oool0oooo0?l0oooo:@3oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool0203oool001l0oooo00<0oooO09a8000000001`00
00001P18W=l0oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol02P3oool00`3ooml0
W4P007Boo`0:0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0C03oool300000:40
oooo00<000000?ooo`3oool0203oool002d0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B000
04RLg`0:0?ooo`030?oo_`1d0000B9cO00X0oooo0`00003G0?ooo`<00000CP3oool00`000000oooo
0?ooo`2M0?ooo`@000002P3oool002d0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d
_`0:0?ooo`030?noM0000000M;oo00X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0g`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00P0oooo000]0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@0
0018W03Oool01P3oool01P3ogml0gooo0?noM0000000001d0;ooo`X0oooo00<000000?ooo`3oool0
903oool3000001h0oooo0`00003o0?ooog80oooo0`00000?0?ooo`030000003oool0oooo00P0oooo
000]0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool01P3oool01@3ookl0M000
0000000004P0W=oo00/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo06h0oooo00<000000?ooo`3oool0o`3oool10?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0203oool002h0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo
0?ooo`070?ooo`030=nLW02oool0oooo00`0oooo00<000000?ooo`3oool0]P3oool3000008l0oooo
00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`080?ooo`00;`3oool01P3OW4P0001d0;oo
o`3ooml0W4P004RLg`P0oooo00<0omnL07BLg`3oool0303oool00`000000oooo0?ooo`2g0?ooo`03
0000003oool0oooo08d0oooo0`0000210?ooo`030000003oool0oooo00P0oooo000`0?ooo`040=nL
B00000000000001d_`X0oooo00D0_g@0000000000000000004RLg`090?ooo`030000003oool0oooo
0?l0ooooB@3oool200000840oooo00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3o
ool0]P3oool00`000000oooo0?ooo`2?0?ooo`<00000P03oool00`000000oooo0?ooo`080?ooo`00
C03oool00`000000oooo0?ooo`2e0?ooo`<00000T@3oool00`000000oooo0?ooo`1o0?ooo`030000
003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0?l0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`0S0?ooo`<00000803oool3
00000?l0ooooK`3oool300000140oooo00<000000?ooo`3oool0203oool004`0oooo0P00000U0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`3L0?oo
o`030000003oool0oooo00h0oooo0`00000:0?ooo`00C03oool00`000000oooo0?ooo`3H0?ooo`<0
0000l03oool00`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`3I0?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`080?ooo`00C03o
ool00`000000oooo0?ooo`3o0?ooobH0oooo0`0000130?ooo`030000003oool0oooo05d0oooo00<0
00000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo0440oooo0`00001N0?ooo`030000003oool0oooo00P0oooo001<0?oo
o`030000003oool0oooo09<0oooo0`00003E0?ooo`030000003oool0oooo05d0oooo00<000000?oo
o`3oool0203oool004`0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo0?l0oooo0@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00P0
oooo001<0?ooo`030000003oool0oooo06P0oooo0`00003o0?ooob`0oooo0`00000b0?ooo`030000
003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0o`3o
ool/0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0203oool004`0oooo00<00000
0?ooo`3oool0n`3oool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo00P0oooo001<0?oo
o`030000003oool0oooo0?X0oooo0`0000080?ooo`030000003oool0oooo0<<0oooo00<000000?oo
o`3oool0203oool004`0oooo00<000000?ooo`3oool0n`3oool00`000000oooo0?ooo`060?ooo`<0
0000a03oool00`000000oooo0?ooo`080?ooo`00C03oool2000007@0oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo03T0oooo0`00000:0?ooo`00C03o
ool00`000000oooo0?ooo`1b0?ooo`<00000o`3ooolH0?ooo`<00000?03oool00`000000oooo0?oo
o`080?ooo`00C03oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0?l0oooo603oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo
08X0oooo00<000000?ooo`3oool0j03oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
00P0oooo001<0?ooo`030000003oool0oooo08T0oooo0`00003X0?ooo`<00000E03oool00`000000
oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00P0oooo
001<0?ooo`030000003oool0oooo0><0oooo00<000000?ooo`3oool0=@3oool300000:d0oooo00<0
00000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool0hP3oool3000003L0oooo00<00000
0?ooo`3oool0[03oool00`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`3S0?oo
o`030000003oool0oooo0>D0oooo00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0?l0ooooG03oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo01T0oooo
0`0000030?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool0oooo0`00000K0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0I0?ooo`<0
00000`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`3oool3000000T0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`<000000`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo0`00000N0?ooo`<000002@3oool00`000000
oooo0?ooo`0?0?ooo`040000003oool0oooo0?ooo`<000002@3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00L0oooo0`00000E0?ooo`030000003oool0oooo00L0oooo0`0000090?oo
o`030000003oool0oooo0180oooo0`00000:0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool01`3oool3000001D0oooo00<000000?ooo`3oool01`3oool3000001l0oooo0`0000090?oo
o`030000003oool0oooo00l0oooo00@000000?ooo`3oool0oooo0`0000090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool004`0oooo0P0000080?ooo`<000002P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo0`00000D0?ooo`<000002@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo0`0000090?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo0`00000?0?ooo`<000000`3oool00`000000oooo0?ooo`070?ooo`<00000503oool30000
00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`<000002@3oool00`00
0000oooo0?ooo`070?ooo`<000002@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo0`00000C0?ooo`<000002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00h0oooo0`0000090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo0`0000090?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01`3oool3000000P0oooo0`00000:0?ooo`00C03oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo0`00000D0?ooo`030000003oool0oooo00P0
oooo0P00000:0?ooo`030000003oool0oooo0180oooo0`00000:0?ooo`030000003oool0oooo0180
oooo0`0000080?ooo`<00000503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool04P3oool3000000X0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`070?ooo`<000005@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0303oool3000000@0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0B0?ooo`<000002@3oool3000001@0oooo00<000000?ooo`3oool01`3oool3000001D0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01d0oooo1000000O0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N0?ooo`<000007P3oool300000200oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0N0?ooo`<00000103oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0080oooo0`00000P0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00P0oooo
001<0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool07`3oool200000240oooo00<0
00000?ooo`3oool0BP3oool3000001T0oooo00<000000?ooo`3oool00`3oool300000200oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0N0?ooo`<000000`3oool3000001T0oooo0`00
001<0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0203oool004`0oooo00<00000
0?ooo`3oool04P3oool300000480oooo0`00000O0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0G0?ooo`<000001@3oool00`000000oooo0?ooo`0N
0?ooo`<00000:@3oool300000200oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0N
0?ooo`<000008@3oool00`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?oo
o`<00000203oool3000003/0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1R0?oo
o`<000001`3oool3000001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo00P0oooo0`00000S0?ooo`<0
00002P3oool3000002<0oooo0`00000E0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`1E0?ooo`<00000503oool300000200oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool04`3oool3000002`0oooo00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0O0?ooo`050000003oool0oooo0?ooo`000000303oool01@000000
oooo0?ooo`3oool000000240oooo00<000000?ooo`3oool0=@3oool3000003D0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01h0oooo0`00000d0?oo
o`<00000=`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0203oool004`0oooo00<000000?ooo`3oool0:P3oool300000180oooo0`00001I0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`03000005T0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0E`3oool3000000X0oooo00<000000?ooo`3oool0203oool004`0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00P0oooo
0`00000>0?ooo`<000000P3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00h0oooo
0`0000090?ooo`<00000HP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool07P3oool3000002X0oooo0`00
001R0?ooo`<000002P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`0<0?ooo`<00000403oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0600oooo0`00000F0?ooo`030000003oool0oooo00P0oooo001<
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:P3oool3000003l0oooo0`00000>
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0203oool004`0oooo0P00001_0?oo
o`030000003oool0oooo01d0oooo0`00000>0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03/0oooo0`00000>0?oo
o`<000007P3oool00`000000oooo0?ooo`0e0?ooo`<000002P3oool004`0oooo00<000000?ooo`3o
ool0K@3oool3000001l0oooo00<000000?ooo`3oool0303oool3000005h0oooo0`00001N0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0703oool3000003P0oooo00<000000?ooo`3o
ool0203oool004`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo00`0oooo0P00000Q0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
G03oool3000006h0oooo00<000000?ooo`3oool07`3oool3000000h0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`0<0?ooo`<00000CP3o
ool3000000`0oooo0`00000P0?ooo`<00000K@3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo04T0oooo0`00000Q0?ooo`030000003oool0oooo00`0oooo0`00000W0?ooo`030000003o
ool0oooo00P0oooo001<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0^0?ooo`<00000B`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool07`3oool30000
02P0oooo0`00001U0?ooo`030000003oool0oooo02L0oooo0`00000@0?ooo`<00000<03oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0203oool004`0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo06<0
oooo0`00000Y0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0HP3oool3000001D0
oooo00<000000?ooo`3oool0203oool003`0oooo00@0_g@0000000000000M;oo303oool00`000000
oooo0?ooo`2b0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0D03oool300000340
oooo0`0000070?ooo`<00000I03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0203oool003/0oooo00H0gia8001d_`3oool0omnL04P00018W=l;0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo03X0oooo0`00001B0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo03P0oooo0`00000;0?oo
o`030000003oool0oooo00P0oooo000j0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02L
gol02P3oool00`000000oooo0?ooo`0Y0?ooo`<00000503oool3000003X0oooo0`00000l0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`1B0?ooo`<0
0000>P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo000j0?ooo`030?oo
g`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo2@3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0>P3oool2000001X0oooo00<000000?ooo`3o
ool0=@3oool3000005H0oooo0`00000g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`080?ooo`00>P3oool00`3ooml0W4P0001d_`030?ooo`030=nL
B00004P0W=oo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01P0oooo0`00000H0?ooo`<00000=`3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo03D0oooo0`00000I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`080?ooo`00>`3oool00`2oM00004RL0=ooo`020?ooo`030?oOW018
0000B9cO00T0ooooo`00003@000000X0oooo000k0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO
09a80000M;l02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0SP3oool3000001<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1/
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`08
0?ooo`00>`3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00P0oooo00<000000?oo
o`3oool0N03oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool04@3oool3000000@0oooo0`00001d0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0203oool003/0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`080?oo
o`030000003oool0oooo07L0oooo0`00000;0?ooo`030000003oool0oooo06D0oooo0`00000J0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`080?oo
o`<00000@P3oool00`000000oooo0?ooo`080?ooo`00?03oool00`3ogi`0B00007Boo`020?ooo`03
0=nLB000M;l0oooo00P0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`090?ooo`<0
0000I`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0600oooo0`00000:0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0203oool003d0oooo00H0gia80000M02oool0
oooO09a80018W=l90?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0:`3oool30000
0680oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
00P0oooo000n0?ooo`040=nLB00000000000001d_`X0oooo00<000000?ooo`3oool03P3oool30000
00@0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`020?ooo`<00000R@3oool30000
02d0oooo00<000000?ooo`3oool0R03oool3000000@0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080
oooo0`00000n0?ooo`<00000103oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool00P3oool300000200oooo00<000000?ooo`3oool0203oool004`0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo04L0oooo
0`0000030?ooo`<00000T03oool00`000000oooo0?ooo`0L0?ooo`<000000`3oool00`000000oooo
0?ooo`180?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0203oool004`0oooo00<0
00000?ooo`3oool0X@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0KP3oool3000001h0oooo00@000000?ooo`3oool0oooo0`00001[0?ooo`030000
003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo03D0oooo0P00002?0?ooo`<00000JP3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0JP3o
ool00`000000oooo0?ooo`080?ooo`00C03oool2000003D0oooo1000002?0?ooo`8000000`3oool0
0`000000oooo0?ooo`1S0?ooo`<00000U03oool3000000X0oooo001<0?ooo`030000003oool0oooo
03D0oooo0P00002@0?ooo`<0000000@0oooo0000000000000000I@3oool01@000000oooo0?ooo`3o
ool0000009<0oooo00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0803oool0
1@000000oooo0?ooo`3oool0000006T0oooo0`00000Q0?ooo`030000003oool0oooo06h0oooo00<0
00000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool0<03oool3000000H0oooo0`00001X
0?ooo`<00000T03oool00`000000oooo0?ooo`0O0?ooo`<00000K`3oool00`000000oooo0?ooo`08
0?ooo`00C03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`0B0?ooo`<0
0000@P3oool3000006P0oooo0`00000U0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool0IP3oool300000280oooo00<000000?ooo`3oool0203oool00180oooo00<0gia80000M02oool0
=`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
J03oool00`000000oooo0?ooo`0S0?ooo`<00000:@3oool00`000000oooo0?ooo`0T0?ooo`<00000
J03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030?oo_`1d
M;l0oooo00@0oooo00<0oono07A8W03Oool0=`3oool00`000000oooo0?ooo`230?ooo`030000003o
ool0oooo06@0oooo00<000000?ooo`3oool09`3oool3000002H0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0203o
ool000/0oooo00<0omnL04P0M02oool00`3oool00`3o_g@0001d0;ooo`0h0?ooo`030000003oool0
oooo07X0oooo00<000000?ooo`3oool01@3oool3000002D0oooo00<000000?ooo`3oool0J03oool0
0`000000oooo0?ooo`0l0?ooo`<00000903oool3000004d0oooo00<000000?ooo`3oool0203oool0
00/0oooo00L0omnL04P000000000001809cOo`3ogi`0B7Bo03X0oooo00<000000?ooo`3oool0N@3o
ool3000000L0oooo00<000000?ooo`3oool08`3oool300000:T0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0203o
ool000d0oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`0g0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1f0?ooo`<000009@3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00P0oooo000<0?ooo`090?oo_`1d07@0_ooo
0?ooo`3ooml0W4P00000000007@0_ooo03L0oooo00<000000?ooo`3oool05`3oool3000003P0oooo
0`00002O0?ooo`030000003oool0oooo01@0oooo0`00001h0?ooo`030000003oool0oooo02<0oooo
0`00000L0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030?oo_`1d07@0_ooo00@0oooo00<0
omnL04Qd_`3oool0=`3oool2000000/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0S`3oool3000001H0oooo00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01T0oooo0`00
000:0?ooo`002`3oool00`3o_g@0000007Boo`030?ooo`030?oo_`1dB9`0gooo03P0oooo00<00000
0?ooo`3oool02@3oool3000005@0oooo0`00000i0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`2V0?ooo`<00000:`3oool00`000000oooo0?ooo`08
0?ooo`00C03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool0=`3oool3000004H0oooo0`00000d0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00P0oooo000C0?ooo`04
0?noM0000000001d0;ooocD0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo0380oooo0`00000A0?ooo`030000003oool0oooo0380oooo0`00001U0?oo
o`030000003oool0oooo00P0oooo000<0?ooo`040?oog`2LW;l0oooO09a800<0000000<007Bo0?oo
o`3oool0=P3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`<00000=03oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0540oooo00<000000?ooo`3oool0203oool000`0oooo00@0oono07@00000
04P0W=oo0P3oool00`2oW9`0gooo0?ooo`0g0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`150?ooo`<00000AP3oool3000005X0oooo00<000000?oo
o`3oool0A@3oool3000004L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`00403oool01@3Ogml0_g@000000000000007Bo03L0oooo00<000000?ooo`3oool0:P3oool30000
0180oooo0`00000b0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`2R0?ooo`030000003oool0oooo04D0oooo0`0000090?ooo`030000003oool0oooo
00P0oooo000?0?ooo`030?oog`2LB000M;oo0080oooo00<0gia80000M02oool0=@3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0<03oool3000004L0
oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`003`3oool00`3ooml0W7BL
0=ooo`020?ooo`030=nLM02Lgol0oooo03D0oooo00<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`150?ooo`<00000PP3oool3000000/0oooo00<000000?ooo`3oool0>03oool3000003h0oooo
00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`090?ooo`<00000>P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00P0oooo001<
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1O
0?ooo`<00000A`3oool00`000000oooo0?ooo`090?ooo`<00000A`3oool00`000000oooo0?ooo`1P
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0203oool004`0oooo00<000000?oo
o`3oool07@3oool3000002`0oooo0`00001Q0?ooo`030000003oool0oooo04D0oooo0`00000;0?oo
o`030000003oool0oooo0:P0oooo0`00000G0?ooo`030000003oool0oooo00P0oooo001<0?ooo`80
00007`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0M@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0D0?ooo`<000002P3oool004`0oooo00<000000?ooo`3oool0
IP3oool3000007D0oooo0`00000o0?ooo`030000003oool0oooo07@0oooo0`00000a0?ooo`030000
003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0?@3o
ool3000004l0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo00P0oooo001<0?ooo`030000003oool0oooo08d0oooo0`0000050?ooo`<00000R03oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo00@0oooo0`00001H0?ooo`030000003oool0
oooo00P0oooo001<0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0<l0oooo0`0000060?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`080?ooo`00C03oool00`000000
oooo0?ooo`1^0?ooo`<00000T03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool0903oool3000003P0oooo00<000000?ooo`3oool0203oool004`0oooo
00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo02D0oooo
1000000T0?ooo`<00000I`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00P0oooo
001<0?ooo`030000003oool0oooo0=H0oooo0`00000U0?ooo`@000009P3oool00`000000oooo0?oo
o`2P0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo06L0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`0U0?oo
o`<00000703oool3000002D0oooo0`00000Q0?ooo`030000003oool0oooo0?l0oooo0`00000T0?oo
o`<000003`3oool00`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0O0?ooo`<0
00009P3oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000
003oool0oooo0900oooo00<000000?ooo`3oool0903oool3000006T0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0S0?ooo`<00000FP3oool00`000000oooo0?ooo`080?ooo`00C03o
ool200000;T0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`120?ooo`<000008P3o
ool3000002D0oooo00<000000?ooo`3oool0E`3oool3000000X0oooo001<0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`2>0?ooo`<00000A03oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool000000800oooo00<000000?ooo`3oool0203oool0
04`0oooo00<000000?ooo`3oool07`3oool3000002P0oooo0`00001Y0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0J@3oool3000006T0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0300000980oooo00<000000?ooo`3o
ool0I`3oool3000000030?ooo`000000oooo0140oooo00<000000?ooo`3oool0203oool004`0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo06L0oooo
0`0000020?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo
0000000200000140oooo00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool08`3o
ool300000200oooo0`00001Y0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`050?ooo`<00000J@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00P0oooo001<0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`1`0?ooo`<000007@3oool00`000000oooo0?ooo`1V0?ooo`<000001`3oool0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo00P0oooo000^0?ooo`040;md000000000000
07Boo`<0oooo00<0omnL04P0001d_ol00P3oool01P3ogi`0B00000000000000004RL0=ooo``0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo07H0oooo
00<000000?ooo`3oool06`3oool3000004X0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool002d0oooo00H0
gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo0080oooo00H0okmd0000001d
_ol0oooo0?oOW018M;l<0?ooo`030000003oool0oooo02P0oooo0`00000F0?ooo`<00000UP3oool0
0`000000oooo0?ooo`180?ooo`<00000A03oool00`000000oooo0?ooo`1=0?ooo`<00000303oool0
0`000000oooo0?ooo`080?ooo`00;03oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo
00/0oooo00<0okmd04RLg`3oool02P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0m0?ooo`<00000C`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo000/0?ooo`030?oog`2LB000B9cO0080
oooo00@0oooO09a80000B9`0gooo2P3oool00`3ookl0M01d0;ooo`0:0?ooo`030000003oool0oooo
09<0oooo0`00000m0?ooo`<00000E03oool3000003l0oooo00<000000?ooo`3oool0G03oool00`00
0000oooo0?ooo`080?ooo`00;03oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00X0
oooo00<0oooO09a8001d_ol02P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo05@0
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool0203oool002d0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B000
04RLg`0:0?ooo`030?oo_`1d0000B9cO00X0oooo0`00001X0?ooo`<00000;@3oool300000<X0oooo
0`00000]0?ooo`<00000<03oool4000000X0oooo000]0?ooo`030=nLB00004P0W=oo0080oooo00<0
oooO09a80000M;l02P3oool00`3o_g@0000007Boo`0:0?ooo`030000003oool0oooo06@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool0J03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`080?ooo`00;@3oool00`3ogi`0B00004RLg`03
0?ooo`030;md0000B9`0gooo00H0oooo00H0omoO0=ooo`3o_g@000000000M02oool:0?ooo`030000
003oool0oooo06<0oooo0`00002@0?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000
oooo0?ooo`2D0?ooo`<00000;@3oool00`000000oooo0?ooo`080?ooo`00;@3oool0103ooml0W4P0
0018W03Oool20?ooo`030=nLB000B9`0gooo00H0oooo00D0oono07@000000000001809cOo`0;0?oo
o`030000003oool0oooo06@0oooo00<000000?ooo`3oool0SP3oool3000000<0oooo00<000000?oo
o`3oool01@3oool3000000@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo00P0oooo000^0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3o
ool01`3oool00`3OW9`0_ooo0?ooo`0<0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3o
ool0P@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo0`00001l0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`080?ooo`00
;`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`P0oooo00<0omnL07BLg`3oool0303oool00`00
0000oooo0?ooo`1a0?ooo`<00000103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
07X0oooo0`0000020?ooo`<00000?03oool00`000000oooo0?ooo`080?ooo`00<03oool0103OW4P0
000000000000M;l:0?ooo`050;md00000000000000000018W=l02@3oool00`000000oooo0?ooo`1b
0?ooo`030000003oool0oooo0080oooo0`00000;0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0nP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`090?oo
o`<000000`3oool300000>L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0D`3oool3000000<0oooo0`00001?0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000
003oool0oooo0>80oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0[0?ooo`<00000
0`3oool3000005D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`280?ooo`<000000`3oool3000002d0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0203o
ool004`0oooo00<000000?ooo`3oool0503oool3000000@0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`020?ooo`<00000RP3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0;h0oooo0`0000030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0203oool0
04`0oooo0P00000F0?ooo`030000003oool0oooo0080oooo0`00000b0?ooo`<00000103oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0C`3oool01000
0000oooo0?ooo`3oool3000001P0oooo0`00000:0?ooo`00C03oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0D`3oool3000000@0oooo00<000000?oo
o`3oool0R@3oool00`000000oooo0?ooo`0K0?ooo`<00000E@3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool00P3oool3000001L0oooo00<000000?ooo`3oool0K`3oool3000001P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000
003oool0oooo0:d0oooo00<000000?ooo`3oool05@3oool300000740oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0@0?ooo`<00000MP3oool00`000000oooo0?ooo`080?ooo`00C03o
ool00`000000oooo0?ooo`0d0?ooo`040000003oool0oooo000008T0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1e0?ooo`<000004P3oool00`000000oooo0?ooo`1e0?ooo`030000
003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo03<0oooo1P0000270?ooo`<000001P3o
ool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0203o
ool004`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`040?ooo`<00000J`3o
ool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0
oooo02h0oooo0`00000:0?ooo`<00000R`3oool00`000000oooo0?ooo`1Y0?ooo`<000008`3oool0
0`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0Q0?ooo`<00000KP3oool00`00
0000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool0A`3oool3000002L0oooo0`00001Q0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00P0
oooo001<0?ooo`030000003oool0oooo0140oooo0`0000140?ooo`<00000B@3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo05l0oooo0`00000^0?ooo`030000003oool0oooo0480oooo
0`00000R0?ooo`030000003oool0oooo00P0oooo001<0?ooo`8000004`3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0;03oool3000004@0oooo00<0
00000?ooo`3oool07`3oool3000000X0oooo001<0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`0m0?ooo`<00000B@3oool3000002L0oooo0`00001:
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`08
0?ooo`00C03oool00`000000oooo0?ooo`0<0?ooo`<00000CP3oool3000002<0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool0I@3oool00`000000oooo0?ooo`0P0?ooo`<00000:03oool00`000000oooo0?ooo`080?oo
o`00C03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`050?ooo`<00000J`3oool00`000000oooo0?ooo`290?ooo`<0
00008P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000
003oool0oooo07T0oooo0`0000070?ooo`030000003oool0oooo06T0oooo0`00000M0?ooo`030000
003oool0oooo06/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`130?ooo`030000
003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0000000800000L@3oool00`000000oooo0000
0002000004@0oooo00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool0O@3oool0
0`000000oooo0?ooo`1c0?ooo`030000003oool0oooo01D0oooo0`0000000`3oool000000?ooo`1`
0?ooo`<0000000<0oooo0000003oool0A03oool00`000000oooo0?ooo`080?ooo`00C03oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0603oool30000
00030?ooo`000000oooo0700oooo0`00000G0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00P0oooo001<0?ooo`03
0000003oool0oooo00T0oooo0`00001D0?ooo`<000006P3oool00`000000oooo0000000200000740
oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0K0?ooo`<00000:`3oool00`000000
oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo07<0oooo
00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0H0?ooo`<000007@3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo09/0oooo0`00
001?0?ooo`030000003oool0oooo0240oooo0`00000J0?ooo`030000003oool0oooo0340oooo0`00
000J0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0203oool004`0oooo00<00000
0?ooo`3oool0W03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01P0oooo0`00000S
0?ooo`030000003oool0oooo01P0oooo0`00000c0?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool0203oool004`0oooo0P00000A0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0780oooo0`00000J0?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0R0?oo
o`<000002P3oool004`0oooo00<000000?ooo`3oool03`3oool3000001T0oooo0`00000@0?ooo`<0
00006@3oool3000004D0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`3?0?ooo`<0
00009@3oool00`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo04<0oooo0`00000J0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
203oool004`0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0H0?ooo`<00000M03o
ool00`000000oooo0?ooo`0:0?ooo`<00000303oool00`000000oooo0?ooo`0:0?ooo`<00000J`3o
ool00`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`2_0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1T0?ooo`<00000303oool0
0`000000oooo0?ooo`0:0?ooo`<00000303oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0
oooo00P0oooo001<0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0G@3oool30000
01X0oooo0`00001V0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0G`3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo01`0
oooo0`00000A0?ooo`<000001P3oool300000140oooo0`00001O0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3>0?ooo`<000005`3oool00`000000
oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0780oooo
00<000000?ooo`3oool06@3oool3000003h0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`1c0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0203oool004`0oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`<000006`3oool00`000000oooo0?oo
o`0l0?ooo`<000006@3oool3000003@0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`080?ooo`00C03oool00`000000oooo0?ooo`2=0?ooo`<000006P3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo01T0oooo0`00001G0?ooo`030000003oool0oooo00P0oooo001<0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo01P0oooo0`00002X0?ooo`<000006`3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`080?oo
o`00C03oool00`000000oooo0?ooo`0G0?ooo`<00000>@3oool00`000000oooo0?ooo`0H0?ooo`<0
0000>@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3o
ool0=`3oool3000001T0oooo0`00000M0?ooo`030000003oool0oooo00P0oooo001<0?ooo`800000
6@3oool00`000000oooo0?ooo`0g0?ooo`<000006P3oool00`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`0000000P00002=0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool06P3oool3000000X0oooo001<0?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`1e0?ooo`<000005P3oool3000000030?ooo`00
0000oooo01L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo00P0oooo001<0?ooo`030000003oool0oooo06/0oooo0`00000J0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo01P0oooo0`00001B0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0603oool3
000003H0oooo00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool0K03oool00`00
0000oooo0?ooo`0H0?ooo`<000001P3oool3000008L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`170?ooo`<000001P3oool3000001X0oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo04<0
oooo0`0000190?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0m0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`<00000I03oool3000002T0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1T0?ooo`<00000:03oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo0200oooo0`00
000V0?ooo`<00000:@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0:0?ooo`<00000PP3oool00`000000oooo0?oo
o`0V0?ooo`<00000503oool00`000000oooo0?ooo`080?ooo`00>P3oool00`3ookl0M00000000002
0000000304RLg`3oool0oooo00X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0B@3oool3000004<0oooo0`00000<
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool003`0oooo00<0okmd0000
001d_ol03@3oool00`000000oooo0?ooo`1U0?ooo`<00000;`3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo00@0oooo0`0000190?ooo`<00000<03oool00`000000oooo0?ooo`080?oo
o`00?03oool00`3ooml0W4P0001d_`0=0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02d0oooo0`00000Q0?ooo`<0
0000Q`3oool3000000H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`00
?@3oool00`3OW4P004RL0=ooo`0<0?ooo`030000003oool0oooo02L0oooo0`00000G0?ooo`<00000
D`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0200oooo0`00001A0?ooo`<00000
303oool00`000000oooo0?ooo`080?ooo`00?@3oool00`3ogi`0B01809cOo`0<0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`2@0?ooo`@00000C`3o
ool4000003d0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00P0oooo000m0?ooo`030?oo_`1d0000M;oo00`0oooo0`00000V0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0h0?ooo`@00000D@3oool4
000003X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0:0?ooo`@000002P3oool0
03h0oooo00<0_g@0001d_`3oool02`3oool00`000000oooo0?ooo`0U0?ooo`<00000703oool30000
01d0oooo00<000000?ooo`3oool0<@3oool3000001d0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0703oool30000
0380oooo00<000000?ooo`3oool0703oool3000000h0oooo00<000000?ooo`3oool0203oool003h0
oooo00<0gia80018W03Oool02`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool06`3oool3000003<0oooo00<000000?ooo`3oool06`3oool3000003`0
oooo00<000000?ooo`3oool0C@3oool3000000030?ooo`000000oooo01/0oooo00<000000?ooo`3o
ool0<03oool3000001h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`00
?P3oool00`3ogi`0B01809cOo`0;0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0
CP3oool010000000oooo0?ooo`00000l0?ooo`<000004@3oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0000000800000C`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00P0
oooo000n0?ooo`030?oo_`1d0000M;oo00/0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0>P3oool3000003l0oooo
00<000000?ooo`3oool03`3oool3000003l0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0203oool003l0oooo00<0
_g@0001d_`3oool02P3oool00`000000oooo0?ooo`0R0?ooo`<000008P3oool3000002`0oooo0`00
000=0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?oo
o`0;0?ooo`<00000;03oool300000180oooo00<000000?ooo`3oool0203oool003d0oooo00D0oono
07@000000000001d0;ooo`0:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00/0oooo0`00001A0?ooo`<00000?03o
ool00`000000oooo0?ooo`090?ooo`<00000A@3oool00`000000oooo0?ooo`090?ooo`<000003@3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0203o
ool004`0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0]0?ooo`<000002`3oool0
0`000000oooo0?ooo`130?ooo`<000002`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo00P0oooo001<0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0?03oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo02D0oooo0`00001A0?ooo`<00000;`3oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo01D0
oooo0`00000l0?ooo`<000004P3oool3000002L0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1A0?ooo`030000003oool0oooo03X0oooo0`00000A0?ooo`<000007`3oool00`000000
oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0380oooo
0`00000L0?ooo`030000003oool0oooo0380oooo0`0000050?ooo`<00000=03oool00`000000oooo
0?ooo`0J0?ooo`<00000=03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?oo
o`0d0?ooo`040000003oool0oooo000003T0oooo0`00000H0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool06P3oool3000003@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0b0?ooo`<00000703oool00`000000oooo0?ooo`0b0?ooo`<00000>`3oool00`000000oooo
0?ooo`080?ooo`00C03oool2000003@0oooo1P00000i0?ooo`030000003oool0oooo01H0oooo0`00
000h0?ooo`040000003oool0oooo000005@0oooo00<000000?ooo`3oool05@3oool01@000000oooo
0?ooo`3oool0000003T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0h0?ooo`<0
00002P3oool004`0oooo00<000000?ooo`3oool0=03oool010000000oooo0?ooo`00001D0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool08@3oool3000001L0oooo00<000000?ooo`3o
ool0>03oool3000001D0oooo0`00000T0?ooo`030000003oool0oooo01@0oooo0`00001E0?ooo`03
0000003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
A`3oool3000002<0oooo00<000000?ooo`3oool05@3oool3000003X0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0R0?ooo`<000005P3oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`080?ooo`00C03o
ool00`000000oooo0?ooo`0A0?ooo`<000001P3oool300000380oooo0`0000060?ooo`<00000B@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`160?ooo`<000001`3oool3000001T0oooo00<000000?ooo`3oool0203o
ool004`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo02L0oooo0`00000A0?ooo`030000003oool0oooo02L0oooo0`00000V0?ooo`<00000:@3oool0
0`000000oooo0?ooo`0?0?ooo`<00000:@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`080?ooo`00C03oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`030?ooo`<00000:@3oool00`000000oooo0?ooo`0?0?ooo`<00000:@3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0oooo0`00000A0?ooo`030000003oool0oooo
02L0oooo0`0000050?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0203oool004`0
oooo00<000000?ooo`3oool0;@3oool3000000`0oooo0`00000k0?ooo`<000001@3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo00<0oooo0`0000150?ooo`030000003oool0oooo00P0
oooo001<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo02d0oooo0`00000P0?ooo`<00000603oool300000200oooo
0`00000_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo00X0oooo0`00
001B0?ooo`<00000>`3oool3000002l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0;@3oool4000003X0oooo1000
000Y0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo00/0oooo0`00001@
0?ooo`<00000>`3oool300000380oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0;`3oool4000003X0oooo1000000X
0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool03`3oool3000001d0oooo0`00000K0?ooo`<000007@3oool300000380oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool0203oool004`0oooo0P00000/0?ooo`<00000403oool3000003/0oooo0`0000000`3oool0
00000?ooo`0]0?ooo`030000003oool0oooo00/0oooo0`00000A0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00<0
0000A03oool3000000X0oooo001<0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
;03oool00`000000oooo00000002000002`0oooo0`00000=0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Z0?ooo`<00000303oool3000002`0oooo
0`0000020?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo0`00
000^0?ooo`<000002`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00T0oooo0`00
000S0?ooo`<000002P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`<00000603oool00`000000oooo0?oo
o`080?ooo`00C03oool00`000000oooo0?ooo`0?0?ooo`<000002`3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo00T0oooo0`00000C0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool04@3oool3000002L0oooo00<000000?ooo`3oool04@3oool3000000/0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`<000004`3oool00`000000oooo0?ooo`0U
0?ooo`<000004P3oool3000001`0oooo00<000000?ooo`3oool04@3oool3000000X0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo0140oooo0`00000J0?ooo`<000004`3oool00`000000oooo0?ooo`0U0?oo
o`<000004`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0A0?ooo`<000009`3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo01X0oooo0`00000C0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0203oool004`0oooo00<000000?ooo`3oool0<@3oool3000000@0oooo0`00000`0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0^0?ooo`<0
00000P3oool300000300oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool07`3oool01@000000oooo0?ooo`3oool00000
03H0oooo00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0C0?ooo`<00000903oool3000001D0oooo00<000000?ooo`3oool05`3oool3000001H0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool04`3oool3000001P0oooo0`00000E0?ooo`<000008`3oool3000001H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo
0?ooo`0F0?ooo`<00000203oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00H0oooo
0`00000E0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool04`3oool3000000P0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0D0?ooo`<00000203oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo00H0oooo0`00000E0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0D0?ooo`<00000203oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool01P3oool3000000D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`030?ooo`<00000203oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`<000001@3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo00H0oooo0`00000a0?ooo`<00000203oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00<0oooo0`00000Y0?ooo`<00000403oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo00H0oooo0`0000040?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`03
0?ooo`<00000603oool3000000D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0;
0?ooo`<00000403oool3000002T0oooo00<000000?ooo`3oool00`3oool3000001T0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01L0oooo0`000005
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool03P3oool3000000h0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`<000003@3oool00`000000oooo0?ooo`08
0?ooo`00C03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool07`3oool3000000d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0<0?oo
o`8000008@3oool00`000000oooo0?ooo`0G0?ooo`<00000803oool3000000`0oooo0`00000P0?oo
o`<000006@3oool00`000000oooo0?ooo`0O0?ooo`8000008@3oool00`000000oooo0?ooo`0<0?oo
o`<00000803oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo001<0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0M0?ooo`<0
00003`3oool00`000000oooo0?ooo`0M0?ooo`@000007`3oool00`000000oooo0?ooo`0I0?ooo`80
0000803oool2000000h0oooo00<000000?ooo`0000007P3oool3000003/0oooo1000000O0?ooo`03
0000003oool0oooo00h0oooo0`00000N0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0203oool004`0oooo0P00000S0?ooo`040000003oool0oooo0?ooo`<000006P3oool3000000<0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0=0?ooo`<000003`3oool00`000000
oooo0?ooo`0=0?ooo`8000006`3oool010000000oooo0?ooo`3oool3000001X0oooo0`00000?0?oo
o`030000003oool0oooo00`0oooo0`00000?0?ooo`<000003P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo01/0oooo00D000000?ooo`3oool0oooo0000000K0?ooo`800000403oool0
0`000000oooo0?ooo`0<0?ooo`<00000403oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00<00000303oool3000000X0oooo001<0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0203oool3000000<0oooo00<000000?ooo`3oool06P3oool010000000oooo0?ooo`3oool3
000000X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0=0?ooo`<000002P3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo0`0000030?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00P0oooo0`00000>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0303oool3
000000X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`<0000000@0oooo
00000000000000002P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo0`00
000>0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0203oool300000080oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`0E
0?ooo`<000002P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`<000004`3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo00P0oooo0`00000B0?ooo`<000002P3oool00`000000oooo0?ooo`0=
0?ooo`<000000`3oool00`000000oooo0?ooo`0=0?ooo`<000002P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`08
0?ooo`<000003P3oool010000000oooo0?ooo`3oool3000000/0oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`<000000`3oool00`000000oooo0?ooo`0=0?ooo`<000002P3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo0180oooo0`00000:0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01T0oooo0`0000020?ooo`<000006`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00`0oooo0`0000050?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool06P3oool010000000oooo0?ooo`3oool3000000l0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo0`0000040?ooo`<00000
3`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
303oool3000000<0oooo00<000000?ooo`3oool06P3oool010000000oooo0?ooo`3oool3000000l0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00`3oool3000000l0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00P0oooo001<0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool3000000T0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00L0oooo0`0000040?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00`3oool3000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`<00000503oool3000000T0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01<0oooo0`0000080?ooo`<00000103oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`020?ooo`<000001`3oool3000001D0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04`3oool3000000P0oooo
0`0000040?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00P3oool3000000P0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`0:0?ooo`<00000103oool00`000000oooo0?oo
o`070?ooo`<000003P3oool3000000h0oooo0`00000>0?ooo`<000002@3oool00`000000oooo0?oo
o`020?ooo`<000003`3oool00`000000oooo0?ooo`060?ooo`<00000103oool3000000P0oooo00<0
00000?ooo`3oool03P3oool2000000@0oooo00<000000?ooo`3oool01`3oool3000000l0oooo0`00
000>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`<000006@3oool3000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0>0?ooo`8000003P3oool3000000l0oooo0`00000>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`<00000203oool00`000000oooo0?oo
o`0>0?ooo`<00000103oool00`000000oooo0?ooo`060?ooo`<000006@3oool00`000000oooo0?oo
o`080?ooo`00C03oool00`000000oooo0?ooo`0;0?ooo`<000000`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00d0oooo0`00000>0?ooo`<000003`3oool00`000000oooo0?ooo`08
0?ooo`040000003oool0oooo0?ooo`<000002P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00P0oooo0P0000040?ooo`8000002P3oool00`000000oooo0?ooo`0<0?ooo`@000000`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo0`00000:0?ooo`040000003o
ool0oooo0?ooo`<000003`3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo0?ooo`<0
00002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo0`0000030?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool4000000<0oooo00<000000?ooo`3o
ool01`3oool3000000h0oooo0`00000:0?ooo`040000003oool0oooo0?ooo`<000003`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo0P00000:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool3000000<0oooo00<000000?ooo`3oool0203oool20000
01T0oooo00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool0303oool010000000
oooo0?ooo`3oool3000000@0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool3000000<0oooo00<000000?ooo`3oool00P3oool3
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000000P3oool3
000000@0oooo00<000000?ooo`3oool00P3oool300000080oooo0`0000040?ooo`030000003oool0
oooo0080oooo0`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool2
000000<0oooo0`0000040?ooo`040000003oool0oooo0?ooo`<00000103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool3000000<0oooo00<000000?ooo`3oool00P3oool3000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000000P3oool3000000@0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`3oool3000000@0oooo00<000000?ooo`3oool0
0P3oool3000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`800000
0`3oool3000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo0`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<00000
0P3oool3000000@0oooo00<000000?ooo`3oool00P3oool3000000<0oooo0`0000030?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`030000003oool0oooo0080
oooo0`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`080?ooo`00C03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo
0`0000030?ooo`030000003oool0oooo0080oooo0`0000020?ooo`<00000203oool3000000@0oooo
0`0000080?ooo`<000000P3oool3000000@0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`03
0000003oool0oooo00L0oooo0`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool3000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`<0
0000103oool010000000oooo0?ooo`3oool3000000<0oooo0`0000090?ooo`030000003oool0oooo
0080oooo0`0000030?ooo`030000003oool0oooo0080oooo0`0000020?ooo`<000002@3oool30000
00@0oooo00<000000?ooo`3oool01`3oool300000080oooo0`0000040?ooo`040000003oool0oooo
0?ooo`<00000103oool00`000000oooo0?ooo`070?ooo`<00000103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo0`0000090?ooo`030000003oool0oooo0080oooo0`000004
0?ooo`040000003oool0oooo0?ooo`<000000`3oool3000000T0oooo00<000000?ooo`3oool00P3o
ool3000000P0oooo0`0000020?ooo`<000002@3oool3000000@0oooo00<000000?ooo`3oool01`3o
ool300000080oooo0`0000040?ooo`040000003oool0oooo0?ooo`<00000103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo0`0000040?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool0oooo0`0000090?ooo`030000003oool0oooo0080oooo0`0000040?ooo`04
0000003oool0oooo0?ooo`<000000`3oool3000000d0oooo00<000000?ooo`3oool0203oool004`0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0
oooo001<0?ooo`030000003oool0oooo0?l0ooooc03oool00`000000oooo0?ooo`080?ooo`00C03o
ool00`000000oooo0?ooo`3o0?oool`0oooo00<000000?ooo`3oool0203oool004`0oooo0P000009
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1/
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0103oool3000000X0oooo001<0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00P0oooo001<0?ooool00000d000000:0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 548.563}, {338.625, 0}} -> {-157.439, -1.4467, \
2.71126, 0.0127047}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.00119646 0.30902 0.148911 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.2631 -0.0125 -11 -15.6875 ]
[.2631 -0.0125 11 0 ]
[.50239 -0.0125 -11 -15.6875 ]
[.50239 -0.0125 11 0 ]
[.74168 -0.0125 -11 -15.6875 ]
[.74168 -0.0125 11 0 ]
[.98098 -0.0125 -11 -15.6875 ]
[.98098 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4.9375 -31.375 ]
[.5 -0.0125 4.9375 -15.6875 ]
[-0.0125 .0112 -18.6875 -7.84375 ]
[-0.0125 .0112 0 7.84375 ]
[-0.0125 .16011 -18.6875 -7.84375 ]
[-0.0125 .16011 0 7.84375 ]
[-0.0125 .30902 -10 -7.84375 ]
[-0.0125 .30902 0 7.84375 ]
[-0.0125 .45793 -10 -7.84375 ]
[-0.0125 .45793 0 7.84375 ]
[-0.0125 .60684 -10 -7.84375 ]
[-0.0125 .60684 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.375 -7.125 ]
[-0.01875 .30902 -18.6875 7.125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2631 0 m
.2631 .00625 L
s
gsave
.2631 -0.0125 -72 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.50239 0 m
.50239 .00625 L
s
gsave
.50239 -0.0125 -72 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
.74168 0 m
.74168 .00625 L
s
gsave
.74168 -0.0125 -72 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(600) show
1.000 setlinewidth
grestore
.98098 0 m
.98098 .00625 L
s
gsave
.98098 -0.0125 -72 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(800) show
1.000 setlinewidth
grestore
.125 Mabswid
.08363 0 m
.08363 .00375 L
s
.14346 0 m
.14346 .00375 L
s
.20328 0 m
.20328 .00375 L
s
.32292 0 m
.32292 .00375 L
s
.38275 0 m
.38275 .00375 L
s
.44257 0 m
.44257 .00375 L
s
.56222 0 m
.56222 .00375 L
s
.62204 0 m
.62204 .00375 L
s
.68186 0 m
.68186 .00375 L
s
.80151 0 m
.80151 .00375 L
s
.86133 0 m
.86133 .00375 L
s
.92115 0 m
.92115 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65.9375 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
68.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0112 m
.00625 .0112 L
s
gsave
-0.0125 .0112 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .16011 m
.00625 .16011 L
s
gsave
-0.0125 .16011 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .45793 m
.00625 .45793 L
s
gsave
-0.0125 .45793 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .60684 m
.00625 .60684 L
s
gsave
-0.0125 .60684 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04098 m
.00375 .04098 L
s
0 .07076 m
.00375 .07076 L
s
0 .10054 m
.00375 .10054 L
s
0 .13033 m
.00375 .13033 L
s
0 .18989 m
.00375 .18989 L
s
0 .21967 m
.00375 .21967 L
s
0 .24946 m
.00375 .24946 L
s
0 .27924 m
.00375 .27924 L
s
0 .3388 m
.00375 .3388 L
s
0 .36858 m
.00375 .36858 L
s
0 .39837 m
.00375 .39837 L
s
0 .42815 m
.00375 .42815 L
s
0 .48771 m
.00375 .48771 L
s
0 .5175 m
.00375 .5175 L
s
0 .54728 m
.00375 .54728 L
s
0 .57706 m
.00375 .57706 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -94.6563 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.125 11.8438 translate
90 rotate
-68.125 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 18.625 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
68.563 11.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\242) show
73.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2631 .61178 m
.2631 .61803 L
s
.50239 .61178 m
.50239 .61803 L
s
.74168 .61178 m
.74168 .61803 L
s
.98098 .61178 m
.98098 .61803 L
s
.125 Mabswid
.08363 .61428 m
.08363 .61803 L
s
.14346 .61428 m
.14346 .61803 L
s
.20328 .61428 m
.20328 .61803 L
s
.32292 .61428 m
.32292 .61803 L
s
.38275 .61428 m
.38275 .61803 L
s
.44257 .61428 m
.44257 .61803 L
s
.56222 .61428 m
.56222 .61803 L
s
.62204 .61428 m
.62204 .61803 L
s
.68186 .61428 m
.68186 .61803 L
s
.80151 .61428 m
.80151 .61803 L
s
.86133 .61428 m
.86133 .61803 L
s
.92115 .61428 m
.92115 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0112 m
1 .0112 L
s
.99375 .16011 m
1 .16011 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45793 m
1 .45793 L
s
.99375 .60684 m
1 .60684 L
s
.125 Mabswid
.99625 .04098 m
1 .04098 L
s
.99625 .07076 m
1 .07076 L
s
.99625 .10054 m
1 .10054 L
s
.99625 .13033 m
1 .13033 L
s
.99625 .18989 m
1 .18989 L
s
.99625 .21967 m
1 .21967 L
s
.99625 .24946 m
1 .24946 L
s
.99625 .27924 m
1 .27924 L
s
.99625 .3388 m
1 .3388 L
s
.99625 .36858 m
1 .36858 L
s
.99625 .39837 m
1 .39837 L
s
.99625 .42815 m
1 .42815 L
s
.99625 .48771 m
1 .48771 L
s
.99625 .5175 m
1 .5175 L
s
.99625 .54728 m
1 .54728 L
s
.99625 .57706 m
1 .57706 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02501 .45793 Mdot
.0262 .34147 Mdot
.0274 .22303 Mdot
.0286 .11476 Mdot
.02979 .06129 Mdot
.03099 .07629 Mdot
.03218 .10291 Mdot
.03338 .0957 Mdot
.03458 .05169 Mdot
.03577 .01508 Mdot
.03697 .05057 Mdot
.03817 .19893 Mdot
.03936 .45097 Mdot
.04056 .57817 Mdot
.04176 .60101 Mdot
.04295 .55877 Mdot
.04415 .51863 Mdot
.04535 .51749 Mdot
.04654 .54628 Mdot
.04774 .55389 Mdot
.04894 .4897 Mdot
.05013 .37779 Mdot
.05133 .25933 Mdot
.05252 .14457 Mdot
.05372 .06932 Mdot
.05492 .06725 Mdot
.05611 .09712 Mdot
.05731 .10247 Mdot
.05851 .0675 Mdot
.0597 .02096 Mdot
.0609 .03028 Mdot
.0621 .13625 Mdot
.06329 .37982 Mdot
.06449 .55315 Mdot
.06569 .60314 Mdot
.06688 .57465 Mdot
.06808 .52745 Mdot
.06927 .51346 Mdot
.07047 .53654 Mdot
.07167 .55802 Mdot
.07286 .51688 Mdot
.07406 .41391 Mdot
.07526 .29562 Mdot
.07645 .17803 Mdot
.07765 .08498 Mdot
.07885 .06124 Mdot
.08004 .0887 Mdot
.08124 .10517 Mdot
.08244 .0818 Mdot
.08363 .03253 Mdot
.08483 .01839 Mdot
.08603 .09013 Mdot
.08722 .29817 Mdot
.08842 .51733 Mdot
.08961 .59734 Mdot
.09081 .58895 Mdot
.09201 .53974 Mdot
.0932 .51318 Mdot
.0944 .52695 Mdot
.0956 .55565 Mdot
.09679 .53787 Mdot
.09799 .44899 Mdot
.09919 .33187 Mdot
.10038 .21349 Mdot
.10158 .10771 Mdot
.10278 .06041 Mdot
.10397 .0789 Mdot
.10517 .10387 Mdot
.10637 .09325 Mdot
.10756 .04748 Mdot
.10876 .01472 Mdot
.10995 .05744 Mdot
.11115 .21825 Mdot
.11235 .46709 Mdot
.11354 .58329 Mdot
.11474 .59925 Mdot
.11594 .55458 Mdot
.11713 .51696 Mdot
.11833 .51912 Mdot
.11953 .54864 Mdot
.12072 .55155 Mdot
.12192 .48165 Mdot
.12312 .36816 Mdot
.12431 .24969 Mdot
.12551 .13623 Mdot
.1267 .06644 Mdot
.1279 .06944 Mdot
.1291 .09895 Mdot
.13029 .10106 Mdot
.13149 .06339 Mdot
.13269 .01875 Mdot
.13388 .03483 Mdot
.13508 .15122 Mdot
.13628 .40013 Mdot
.13747 .56072 Mdot
.13867 .60332 Mdot
.13987 .57049 Mdot
.14106 .52475 Mdot
.14226 .51418 Mdot
.14346 .53919 Mdot
.14465 .55762 Mdot
.14585 .5102 Mdot
.14704 .40437 Mdot
.14824 .28599 Mdot
.14944 .16889 Mdot
.15063 .08009 Mdot
.15183 .06241 Mdot
.15303 .09113 Mdot
.15422 .10485 Mdot
.15542 .07823 Mdot
.15662 .02903 Mdot
.15781 .02074 Mdot
.15901 .1009 Mdot
.16021 .32025 Mdot
.1614 .52809 Mdot
.1626 .59969 Mdot
.1638 .58544 Mdot
.16499 .53618 Mdot
.16619 .51287 Mdot
.16738 .52938 Mdot
.16858 .55682 Mdot
.16978 .53297 Mdot
.17097 .43984 Mdot
.17217 .32224 Mdot
.17337 .20396 Mdot
.17456 .10105 Mdot
.17576 .06002 Mdot
.17696 .08155 Mdot
.17815 .10459 Mdot
.17935 .09054 Mdot
.18055 .04332 Mdot
.18174 .01491 Mdot
.18294 .06503 Mdot
.18413 .23857 Mdot
.18533 .48204 Mdot
.18653 .58783 Mdot
.18772 .59704 Mdot
.18892 .55047 Mdot
.19012 .51556 Mdot
.19131 .52096 Mdot
.19251 .55084 Mdot
.19371 .54866 Mdot
.1949 .47329 Mdot
.1961 .35851 Mdot
.1973 .24004 Mdot
.19849 .12817 Mdot
.19969 .06411 Mdot
.20089 .07181 Mdot
.20208 .10058 Mdot
.20328 .09936 Mdot
.20447 .05917 Mdot
.20567 .01699 Mdot
.20687 .03999 Mdot
.20806 .16746 Mdot
.20926 .41955 Mdot
.21046 .56762 Mdot
.21165 .60294 Mdot
.21285 .56625 Mdot
.21405 .52229 Mdot
.21524 .51518 Mdot
.21644 .54183 Mdot
.21764 .55672 Mdot
.21883 .50308 Mdot
.22003 .39474 Mdot
.22123 .27631 Mdot
.22242 .15986 Mdot
.22362 .0757 Mdot
.22481 .06392 Mdot
.22601 .09344 Mdot
.22721 .10423 Mdot
.2284 .07446 Mdot
.2296 .02579 Mdot
.2308 .0237 Mdot
.23199 .11278 Mdot
.23319 .34234 Mdot
.23439 .53796 Mdot
.23558 .60146 Mdot
.23678 .58167 Mdot
.23798 .53281 Mdot
.23917 .51284 Mdot
.24037 .53194 Mdot
.24156 .55763 Mdot
.24276 .52753 Mdot
.24396 .43049 Mdot
.24515 .31254 Mdot
.24635 .19443 Mdot
.24755 .09478 Mdot
.24874 .06009 Mdot
.24994 .0842 Mdot
.25114 .10504 Mdot
.25233 .08756 Mdot
.25353 .03924 Mdot
.25473 .01566 Mdot
.25592 .07344 Mdot
.25712 .25985 Mdot
.25832 .4959 Mdot
.25951 .59182 Mdot
.26071 .5944 Mdot
.2619 .54643 Mdot
.2631 .51444 Mdot
.2643 .523 Mdot
.26549 .55283 Mdot
.26669 .5452 Mdot
.26789 .46462 Mdot
.26908 .34879 Mdot
.27028 .23034 Mdot
.27148 .12039 Mdot
.27267 .0623 Mdot
.27387 .07432 Mdot
.27507 .10199 Mdot
.27626 .09737 Mdot
.27746 .0549 Mdot
.27866 .01571 Mdot
.27985 .04579 Mdot
.28105 .18498 Mdot
.28224 .43793 Mdot
.28344 .57388 Mdot
.28464 .60203 Mdot
.28583 .56198 Mdot
.28703 .5201 Mdot
.28823 .51641 Mdot
.28942 .54441 Mdot
.29062 .5553 Mdot
.29182 .49556 Mdot
.29301 .38506 Mdot
.29421 .2666 Mdot
.29541 .15103 Mdot
.2966 .07185 Mdot
.2978 .06573 Mdot
.29899 .09561 Mdot
.30019 .10332 Mdot
.30139 .07052 Mdot
.30258 .02288 Mdot
.30378 .02725 Mdot
.30498 .12579 Mdot
.30617 .36405 Mdot
.30737 .54697 Mdot
.30857 .60264 Mdot
.30976 .5777 Mdot
.31096 .52965 Mdot
.31216 .5131 Mdot
.31335 .53457 Mdot
.31455 .55802 Mdot
.31575 .52158 Mdot
.31694 .42099 Mdot
.31814 .30282 Mdot
.31933 .18496 Mdot
.32053 .08896 Mdot
.32173 .0606 Mdot
.32292 .08681 Mdot
.32412 .10522 Mdot
.32532 .08432 Mdot
.32651 .0353 Mdot
.32771 .01701 Mdot
.32891 .08271 Mdot
.3301 .28178 Mdot
.3313 .50865 Mdot
.3325 .59522 Mdot
.33369 .59139 Mdot
.33489 .54252 Mdot
.33609 .51361 Mdot
.33728 .52523 Mdot
.33848 .55457 Mdot
.33967 .54117 Mdot
.34087 .45568 Mdot
.34207 .33903 Mdot
.34326 .22061 Mdot
.34446 .11293 Mdot
.34566 .06102 Mdot
.34685 .07694 Mdot
.34805 .10316 Mdot
.34925 .09509 Mdot
.35044 .0506 Mdot
.35164 .01494 Mdot
.35284 .05228 Mdot
.35403 .20381 Mdot
.35523 .45524 Mdot
.35642 .57955 Mdot
.35762 .6006 Mdot
.35882 .55769 Mdot
.36001 .51818 Mdot
.36121 .5179 Mdot
.36241 .54691 Mdot
.3636 .55333 Mdot
.3648 .48763 Mdot
.366 .37528 Mdot
.36719 .25682 Mdot
.36839 .14237 Mdot
.36959 .06852 Mdot
.37078 .0678 Mdot
.37198 .09761 Mdot
.37318 .10212 Mdot
.37437 .06642 Mdot
.37557 .02033 Mdot
.37676 .03142 Mdot
.37796 .14008 Mdot
.37916 .38527 Mdot
.38035 .55522 Mdot
.38155 .60324 Mdot
.38275 .57356 Mdot
.38394 .52672 Mdot
.38514 .51364 Mdot
.38634 .53725 Mdot
.38753 .55796 Mdot
.38873 .51514 Mdot
.38993 .41137 Mdot
.39112 .29305 Mdot
.39232 .17558 Mdot
.39352 .08362 Mdot
.39471 .06151 Mdot
.39591 .08936 Mdot
.3971 .1051 Mdot
.3983 .08085 Mdot
.3995 .03156 Mdot
.40069 .01897 Mdot
.40189 .09294 Mdot
.40309 .30412 Mdot
.40428 .52033 Mdot
.40548 .59803 Mdot
.40668 .58803 Mdot
.40787 .53877 Mdot
.40907 .51308 Mdot
.41027 .52761 Mdot
.41146 .55601 Mdot
.41266 .53659 Mdot
.41385 .44652 Mdot
.41505 .32926 Mdot
.41625 .2109 Mdot
.41744 .10586 Mdot
.41864 .06026 Mdot
.41984 .07962 Mdot
.42103 .10409 Mdot
.42223 .09253 Mdot
.42343 .04633 Mdot
.42462 .01472 Mdot
.42582 .05945 Mdot
.42702 .22372 Mdot
.42821 .4713 Mdot
.42941 .58459 Mdot
.43061 .59869 Mdot
.4318 .55345 Mdot
.433 .51655 Mdot
.43419 .51961 Mdot
.43539 .54927 Mdot
.43659 .55081 Mdot
.43778 .47939 Mdot
.43898 .36552 Mdot
.44018 .24705 Mdot
.44137 .13399 Mdot
.44257 .06575 Mdot
.44377 .07007 Mdot
.44496 .09942 Mdot
.44616 .10062 Mdot
.44736 .06223 Mdot
.44855 .01822 Mdot
.44975 .03619 Mdot
.45095 .15557 Mdot
.45214 .40558 Mdot
.45334 .56269 Mdot
.45453 .60327 Mdot
.45573 .56933 Mdot
.45693 .52405 Mdot
.45812 .51444 Mdot
.45932 .53992 Mdot
.46052 .55742 Mdot
.46171 .50827 Mdot
.46291 .40171 Mdot
.46411 .28331 Mdot
.4653 .16637 Mdot
.4665 .07882 Mdot
.4677 .0628 Mdot
.46889 .09178 Mdot
.47009 .1047 Mdot
.47128 .0772 Mdot
.47248 .0281 Mdot
.47368 .02151 Mdot
.47487 .1041 Mdot
.47607 .32642 Mdot
.47727 .53093 Mdot
.47846 .60024 Mdot
.47966 .58442 Mdot
.48086 .53523 Mdot
.48205 .51284 Mdot
.48325 .5301 Mdot
.48445 .55709 Mdot
.48564 .53149 Mdot
.48684 .43722 Mdot
.48804 .31951 Mdot
.48923 .20127 Mdot
.49043 .09924 Mdot
.49162 .05999 Mdot
.49282 .0823 Mdot
.49402 .10474 Mdot
.49521 .08971 Mdot
.49641 .04215 Mdot
.49761 .01506 Mdot
.4988 .06733 Mdot
.5 .24453 Mdot
.5012 .48609 Mdot
.50239 .58902 Mdot
.50359 .59633 Mdot
.50479 .54931 Mdot
.50598 .51522 Mdot
.50718 .52153 Mdot
.50838 .55143 Mdot
.50957 .54773 Mdot
.51077 .47085 Mdot
.51196 .35574 Mdot
.51316 .23728 Mdot
.51436 .12592 Mdot
.51555 .06354 Mdot
.51675 .07251 Mdot
.51795 .101 Mdot
.51914 .09882 Mdot
.52034 .05796 Mdot
.52154 .01657 Mdot
.52273 .04158 Mdot
.52393 .17234 Mdot
.52513 .42491 Mdot
.52632 .56948 Mdot
.52752 .60274 Mdot
.52872 .56503 Mdot
.52991 .52164 Mdot
.53111 .51551 Mdot
.5323 .54257 Mdot
.5335 .55637 Mdot
.5347 .50097 Mdot
.53589 .39198 Mdot
.53709 .27354 Mdot
.53829 .15732 Mdot
.53948 .07454 Mdot
.54068 .06441 Mdot
.54188 .09408 Mdot
.54307 .104 Mdot
.54427 .07335 Mdot
.54547 .02492 Mdot
.54666 .02465 Mdot
.54786 .11639 Mdot
.54905 .3486 Mdot
.55025 .54063 Mdot
.55145 .60185 Mdot
.55264 .58056 Mdot
.55384 .53188 Mdot
.55504 .51289 Mdot
.55623 .53269 Mdot
.55743 .55778 Mdot
.55863 .52587 Mdot
.55982 .42776 Mdot
.56102 .30975 Mdot
.56222 .19169 Mdot
.56341 .09305 Mdot
.56461 .06019 Mdot
.56581 .08496 Mdot
.567 .10512 Mdot
.5682 .08664 Mdot
.56939 .03808 Mdot
.57059 .01599 Mdot
.57179 .07603 Mdot
.57298 .26614 Mdot
.57418 .49971 Mdot
.57538 .59286 Mdot
.57657 .59357 Mdot
.57777 .54529 Mdot
.57897 .51417 Mdot
.58016 .52364 Mdot
.58136 .55337 Mdot
.58256 .54408 Mdot
.58375 .46204 Mdot
.58495 .34595 Mdot
.58615 .22751 Mdot
.58734 .11818 Mdot
.58854 .06187 Mdot
.58973 .07508 Mdot
.59093 .10235 Mdot
.59213 .09673 Mdot
.59332 .05364 Mdot
.59452 .01543 Mdot
.59572 .04762 Mdot
.59691 .19037 Mdot
.59811 .44311 Mdot
.59931 .57561 Mdot
.6005 .60167 Mdot
.6017 .56072 Mdot
.6029 .51952 Mdot
.60409 .51683 Mdot
.60529 .54516 Mdot
.60648 .55478 Mdot
.60768 .49327 Mdot
.60888 .38219 Mdot
.61007 .26372 Mdot
.61127 .14846 Mdot
.61247 .07081 Mdot
.61366 .06631 Mdot
.61486 .09621 Mdot
.61606 .10299 Mdot
.61725 .06932 Mdot
.61845 .02208 Mdot
.61965 .02842 Mdot
.62084 .12989 Mdot
.62204 .3704 Mdot
.62324 .54949 Mdot
.62443 .60288 Mdot
.62563 .57649 Mdot
.62682 .52876 Mdot
.62802 .51324 Mdot
.62922 .53536 Mdot
.63041 .55805 Mdot
.63161 .51971 Mdot
.63281 .41814 Mdot
.634 .29992 Mdot
.6352 .18216 Mdot
.6364 .08732 Mdot
.63759 .06083 Mdot
.63879 .08758 Mdot
.63999 .10521 Mdot
.64118 .0833 Mdot
.64238 .03416 Mdot
.64358 .01754 Mdot
.64477 .08567 Mdot
.64597 .28844 Mdot
.64716 .51225 Mdot
.64836 .59612 Mdot
.64956 .59042 Mdot
.65075 .54139 Mdot
.65195 .51343 Mdot
.65315 .52594 Mdot
.65434 .55504 Mdot
.65554 .53984 Mdot
.65674 .45293 Mdot
.65793 .33608 Mdot
.65913 .21767 Mdot
.66033 .11075 Mdot
.66152 .06074 Mdot
.66272 .07774 Mdot
.66391 .10346 Mdot
.66511 .09433 Mdot
.66631 .04929 Mdot
.6675 .01481 Mdot
.6687 .05439 Mdot
.6699 .20977 Mdot
.67109 .46026 Mdot
.67229 .58115 Mdot
.67349 .60007 Mdot
.67468 .55639 Mdot
.67588 .51766 Mdot
.67708 .51841 Mdot
.67827 .54766 Mdot
.67947 .55261 Mdot
.68067 .48512 Mdot
.68186 .37228 Mdot
.68306 .25381 Mdot
.68425 .13976 Mdot
.68545 .0676 Mdot
.68665 .06848 Mdot
.68784 .09818 Mdot
.68904 .10167 Mdot
.69024 .06512 Mdot
.69143 .01963 Mdot
.69263 .03285 Mdot
.69383 .14478 Mdot
.69502 .3917 Mdot
.69622 .55763 Mdot
.69742 .60331 Mdot
.69861 .57225 Mdot
.69981 .52587 Mdot
.70101 .51387 Mdot
.7022 .5381 Mdot
.7034 .55784 Mdot
.70459 .51301 Mdot
.70579 .40832 Mdot
.70699 .28998 Mdot
.70818 .17265 Mdot
.70938 .08205 Mdot
.71058 .06188 Mdot
.71177 .09013 Mdot
.71297 .10499 Mdot
.71417 .07969 Mdot
.71536 .03042 Mdot
.71656 .01972 Mdot
.71776 .0964 Mdot
.71895 .31127 Mdot
.72015 .52383 Mdot
.72134 .5988 Mdot
.72254 .5869 Mdot
.72374 .53762 Mdot
.72493 .51299 Mdot
.72613 .52842 Mdot
.72733 .5564 Mdot
.72852 .53498 Mdot
.72972 .4435 Mdot
.73092 .32607 Mdot
.73211 .20775 Mdot
.73331 .10365 Mdot
.73451 .06012 Mdot
.7357 .08048 Mdot
.7369 .10431 Mdot
.7381 .09161 Mdot
.73929 .04492 Mdot
.74049 .01477 Mdot
.74168 .06199 Mdot
.74288 .23055 Mdot
.74408 .47635 Mdot
.74527 .58613 Mdot
.74647 .59795 Mdot
.74767 .55207 Mdot
.74886 .51609 Mdot
.75006 .52025 Mdot
.75126 .55003 Mdot
.75245 .54983 Mdot
.75365 .47652 Mdot
.75485 .3622 Mdot
.75604 .24373 Mdot
.75724 .13122 Mdot
.75844 .06494 Mdot
.75963 .07088 Mdot
.76083 .09996 Mdot
.76202 .10001 Mdot
.76322 .06075 Mdot
.76442 .0176 Mdot
.76561 .03799 Mdot
.76681 .16122 Mdot
.76801 .41237 Mdot
.7692 .56511 Mdot
.7704 .60315 Mdot
.7716 .56786 Mdot
.77279 .5232 Mdot
.77399 .5148 Mdot
.77519 .54087 Mdot
.77638 .55711 Mdot
.77758 .50574 Mdot
.77877 .39829 Mdot
.77997 .27987 Mdot
.78117 .16316 Mdot
.78236 .07725 Mdot
.78356 .06333 Mdot
.78476 .09259 Mdot
.78595 .10446 Mdot
.78715 .07582 Mdot
.78835 .02691 Mdot
.78954 .02257 Mdot
.79074 .10839 Mdot
.79194 .33443 Mdot
.79313 .53452 Mdot
.79433 .60089 Mdot
.79553 .58306 Mdot
.79672 .53401 Mdot
.79792 .51285 Mdot
.79911 .53105 Mdot
.80031 .55739 Mdot
.80151 .52949 Mdot
.8027 .43377 Mdot
.8039 .31594 Mdot
.8051 .19775 Mdot
.80629 .09692 Mdot
.80749 .06001 Mdot
.80869 .08326 Mdot
.80988 .10489 Mdot
.81108 .08858 Mdot
.81228 .04061 Mdot
.81347 .01534 Mdot
.81467 .07049 Mdot
.81587 .25253 Mdot
.81706 .49132 Mdot
.81826 .59052 Mdot
.81945 .59535 Mdot
.82065 .5478 Mdot
.82185 .51481 Mdot
.82304 .52233 Mdot
.82424 .5522 Mdot
.82544 .54641 Mdot
.82663 .46753 Mdot
.82783 .35202 Mdot
.82903 .23356 Mdot
.83022 .12294 Mdot
.83142 .06284 Mdot
.83262 .07347 Mdot
.83381 .10152 Mdot
.83501 .09802 Mdot
.8362 .05628 Mdot
.8374 .01607 Mdot
.8386 .04385 Mdot
.83979 .17919 Mdot
.84099 .43211 Mdot
.84219 .57193 Mdot
.84338 .60238 Mdot
.84458 .56337 Mdot
.84578 .5208 Mdot
.84697 .51602 Mdot
.84817 .54361 Mdot
.84937 .5558 Mdot
.85056 .49797 Mdot
.85176 .38812 Mdot
.85296 .26966 Mdot
.85415 .15379 Mdot
.85535 .073 Mdot
.85654 .06512 Mdot
.85774 .09493 Mdot
.85894 .10361 Mdot
.86013 .07174 Mdot
.86133 .02373 Mdot
.86253 .0261 Mdot
.86372 .12167 Mdot
.86492 .35743 Mdot
.86612 .54429 Mdot
.86731 .60234 Mdot
.86851 .57895 Mdot
.86971 .53061 Mdot
.8709 .51302 Mdot
.8721 .53379 Mdot
.8733 .55795 Mdot
.87449 .52341 Mdot
.87569 .42384 Mdot
.87688 .30573 Mdot
.87808 .18779 Mdot
.87928 .09065 Mdot
.88047 .0604 Mdot
.88167 .08603 Mdot
.88287 .10517 Mdot
.88406 .08527 Mdot
.88526 .03643 Mdot
.88646 .01656 Mdot
.88765 .07993 Mdot
.88885 .27535 Mdot
.89005 .50505 Mdot
.89124 .59429 Mdot
.89244 .5923 Mdot
.89363 .54366 Mdot
.89483 .51385 Mdot
.89603 .52461 Mdot
.89722 .55412 Mdot
.89842 .54236 Mdot
.89962 .45822 Mdot
.90081 .34178 Mdot
.90201 .22335 Mdot
.90321 .115 Mdot
.9044 .06133 Mdot
.9056 .07619 Mdot
.9068 .10283 Mdot
.90799 .09571 Mdot
.90919 .05176 Mdot
.91039 .01509 Mdot
.91158 .05045 Mdot
.91278 .19859 Mdot
.91397 .45066 Mdot
.91517 .57807 Mdot
.91637 .60104 Mdot
.91756 .55886 Mdot
.91876 .5187 Mdot
.91996 .51751 Mdot
.92115 .54628 Mdot
.92235 .5539 Mdot
.92355 .48974 Mdot
.92474 .37785 Mdot
.92594 .25938 Mdot
.92714 .14461 Mdot
.92833 .06934 Mdot
.92953 .06723 Mdot
.93073 .09709 Mdot
.93192 .10242 Mdot
.93312 .06746 Mdot
.93431 .02094 Mdot
.93551 .03031 Mdot
.93671 .13635 Mdot
.9379 .37997 Mdot
.9391 .5532 Mdot
.9403 .60314 Mdot
.94149 .57463 Mdot
.94269 .52746 Mdot
.94389 .51351 Mdot
.94508 .5366 Mdot
.94628 .55802 Mdot
.94748 .51675 Mdot
.94867 .41373 Mdot
.94987 .29544 Mdot
.95106 .17786 Mdot
.95226 .08488 Mdot
.95346 .06125 Mdot
.95465 .08873 Mdot
.95585 .10512 Mdot
.95705 .08167 Mdot
.95824 .03242 Mdot
.95944 .01846 Mdot
.96064 .09045 Mdot
.96183 .29885 Mdot
.96303 .51767 Mdot
.96423 .59742 Mdot
.96542 .58885 Mdot
.96662 .53965 Mdot
.96782 .51321 Mdot
.96901 .52708 Mdot
.97021 .55572 Mdot
.9714 .53766 Mdot
.9726 .44859 Mdot
.9738 .33145 Mdot
.97499 .21308 Mdot
.97619 .10742 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{366.375, 226.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008U0001Db000`400?l00000o`00003oo`3ooooo
0?ooobL0oooo003o0?ooool0oooo9`3oool00?l0ooooo`3ooolW0?ooo`00o`3ooooo0?ooobL0oooo
003o0?ooool0oooo9`3oool00?l0ooooo`3ooolW0?ooo`00o`3ooooo0?ooobL0oooo003o0?ooobP0
oooo00P0_g@0001d_`3oool0oooo0?noM0000000001d0;ooooH0oooo003o0?ooobP0oooo00P0okmd
0000M02oool0oooo0;md0000M;l0oono07Ad_oH0oooo003o0?ooobP0oooo00H0omnL04P0B02Lgol0
oooO09a80018W=oh0?ooo`00o`3ooolX0?ooo`060?oog`2LB00004Qd0;noW01804P0W=oon03oool0
0?l0oooo:@3oool01@3OW4P004Qd07A8000007@0_ooo0?P0oooo003o0?ooobT0oooo00D0okmd0000
M02oool0_g@007Boo`3h0?ooo`00o`3ooolY0?ooo`060?oo_`1d0000M;oo0?ooo`2oM4P0W=oom`3o
ool00?l0oooo:P3oool0102oM00007Bo0?oo_`1d000200000003001d_`3oool0oooo0?<0oooo003o
0?ooobX0oooo00<0okmd0018W03Oool0n@3oool00?l0oooo:P3oool00`3ogi`0B01809cOo`3i0?oo
o`00o`3ooolZ0?ooo`030?oog`2LB000B9cO0?T0oooo003o0?ooob/0oooo00<0_g@0001d_`3oool0
n03oool00?l0oooo:@3oool01@3ooml0W4P00000000007@0_ooo0?P0oooo003o0?ooool0oooo9`3o
ool00?l0ooooo`3ooolW0?ooo`00o`3ooooo0?ooobL0oooo003o0?ooool0oooo9`3oool00?l0oooo
o`3ooolW0?ooo`00o`3ooooo0?ooobL0oooo003o0?ooool0oooo9`3oool00?l0ooooo`3ooolW0?oo
o`00o`3ooooo0?ooobL0oooo003o0?ooool0oooo9`3oool00580oooo00@0_g@0000000000000M;oo
G@3oool00`3OW4P00000000000030000000304RLg`3oool0oooo0080oooo00@0_g@0000000000000
M;oo1@3oool0102oM00000000000001d_omG0?ooo`030?oog`2LB000B9cO00D0oooo00@0_g@00000
00000000M;oo1@3oool0102oM00000000000001d_omF0?ooo`050?oog`2LB000000000000000M;l0
1@3oool0102oM00000000000001d_ol50?ooo`040;md00000000000007BooeD0oooo00H0oono07@0
0000000000000018W03Oool40?ooo`040;md00000000000007Boo`D0oooo00@0_g@0000000000000
M;oo5@3oool00540oooo00H0gia8001d_`3oool0omnL04P00018W=mM0?ooo`030?noM000M;l0oooo
0080oooo00X0_gAd0;ooo`3oool0oooo0=nLB000M;l0oooo0?oOW0180000B9cO0`3oool01P3OW4P0
07Bo0?ooo`3ogi`0B00004RLgeL0oooo00<0gia80018W03Oool00`3oool01P3OW4P007Bo0?ooo`3o
gi`0B00004RLg`<0oooo00H0gia8001d_`3oool0omnL04P00018W=mE0?ooo`070=nLB000M;l0oooo
0?oo_`1d000004RL0=ooo`020?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0`3oool01P3OW4P0
07Bo0?ooo`3ogi`0B00004RLge<0oooo00<0oono07@00018W=l00P3oool00`3OW4P0001d0;ooo`02
0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RL
ga@0oooo001@0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0G@3oool00`3o_g@0
07Bo0?ooo`040?ooo`030?oog`2LB000B9cO0080oooo00L0okmd0000B02Lgol0oooo0?oog`2LB000
B9cO0080oooo00<0okmd0000B02Lgol0EP3oool00`3ogi`0B01809cOo`020?ooo`030?oog`2LB000
B9cO0080oooo00L0okmd0000B02Lgol0oooo0?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0
D`3oool00`3ooml0W4P007Boo`020?ooo`070?oOW0180000B9cO0?ooo`3ooml0W4P004RLg`020?oo
o`070?noM00004P0W=oo0?ooo`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo0580oooo00<0
okmd0018W03Oool00`3oool01P2oM000B9cO0?ooo`3ooml0W4P004RLg`80oooo00L0okmd0000B02L
gol0oooo0?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol04`3oool00500oooo00<0oooO09a8
0018W=l00P3oool0103ooml0W4P00018W03OoomM0?ooo`030?noM000M;l0oooo00<0oooo00<0oooO
09a80018W=l00P3oool01`3ooml0W4P00018W03Oool0oooO09a80018W=l00P3oool0103ooml0W4P0
0018W03OoomA0?ooo`030?noM0000000000000@0000000D004RL0=ooo`3ooml0W4P004RLg`020?oo
o`070?oog`2LB00004RL0=ooo`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=oooe80oooo
00<0oono07@0001d_ol00`3oool01P2oM000001d0;ooo`3ooml0W4P004RLg`80oooo00L0oooO09a8
0000B9`0gooo0?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0goooD@3oool00`3o_g@004RL
0=ooo`030?ooo`060;md0000M;l0oooo0?oog`2LB000B9cO0P3oool01`3ooml0W4P00018W03Oool0
oooO09a80018W=l00P3oool0103ooml0W4P00018W03OoolB0?ooo`00D03oool00`3ooml0W4P0001d
_`030?ooo`030=nLB00004P0W=oo05h0oooo00<0okmd04RLg`3oool00P3oool00`3ooml0W4P0001d
_`030?ooo`060=nLB00004P0W=oo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`1A0?ooo`03
0?oog`2LB4P0W=oo0080oooo00L0_g@0001d_`3oool0oooo0?oog`2LB00007Bo00<0oooo00H0gia8
0000B02Lgol0oooO09a80000M;l30?ooo`030=nLB00004P0W=oo0580oooo00<0oooO09a80000M;l0
0`3oool01P3OW4P0001809cOo`3ooml0W4P0001d_`<0oooo00H0gia80000B02Lgol0oooO09a80000
M;l30?ooo`030=nLB00004P0W=oo0540oooo00<0oooO09a8001d_ol00P3oool01`3ookl0M00004RL
g`3oool0oooO09a80000M;l00`3oool01P3OW4P0001809cOo`3ooml0W4P0001d_`<0oooo00<0gia8
0000B02Lgol04P3oool00540oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`1O0?oo
o`030=nLB018W=l0oooo0080oooo00<0_g@00018W03Oool00P3oool01`3ogi`0B00004RLg`3oool0
_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`1B0?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@0
04RL0=ooo`020?ooo`030;md0000B9`0gooo0080oooo00L0omnL04P00018W=l0oooo0;md0000B9`0
gooo0080oooo00<0omnL04P00018W=l0D`3oool00`2oM000001d0;ooo`020?ooo`070=nLB00004P0
W=oo0?ooo`2oM00004RL0=ooo`020?ooo`070?oOW0180000B9cO0?ooo`2oM00004RL0=ooo`020?oo
o`030?oOW0180000B9cO05<0oooo00H0_g@00000B02Lgml0W4P00000M02oool20?ooo`030;md0000
B9`0gooo0080oooo00L0omnL04P00018W=l0oooo0;md0000B9`0gooo0080oooo00<0omnL04P00018
W=l04P3oool00540oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`1P0?ooo`070;md
001d_ol0oooo0?ooo`3OW4P0001809cOo`020?ooo`070?oog`2LB00007Bo0?ooo`3OW4P0001809cO
o`020?ooo`030?oog`2LB00007Bo05<0oooo00H0omnL04Q8W03Oool0omnL04P0B02Lgol20?ooo`03
0=nLB00004P0W=oo0080oooo00L0oooO09a80000M;l0oooo0=nLB00004P0W=oo0080oooo00<0oooO
09a80000M;l0D`3oool0303o_g@0000004RLg`3oool0oooO09a80000B9`0gooo0?ooo`3OW4P00018
09cOo`80oooo00L0oooO09a80000M;l0oooo0=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0
E03oool01@3ooml0W4P000000000B9`0gooo0080oooo00<0gia80000B02Lgol00P3oool01`3ooml0
W4P0001d_`3oool0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0B0?ooo`00D@3oool00`3o
gi`0B00004RLg`030?ooo`030;md0000B9`0gooo05l0oooo00L0omnL04P0M02oool0oooo0?oOW018
0000B9cO00<0oooo00H0_g@00018W03Oool0omnL04P00018W=l30?ooo`030;md0000B9`0gooo05<0
oooo00D0okmd001d_`3ooml0W4P004RLg`020?ooo`030?oOW0180000B9cO00<0oooo00H0_g@00018
W03Oool0omnL04P00018W=l30?ooo`030;md0000B9`0gooo0580oooo00<0oooO09a8000000000P00
00001`0007@0_ooo0?ooo`3oool0omnL04P00018W=l00`3oool01P2oM00004RL0=ooo`3ogi`0B000
04RLg`<0oooo00<0_g@00018W03Oool0D`3oool02P2oM000001809cOo`3ogi`0B4RL0=ooo`3oool0
omnL04P00018W=l30?ooo`060;md0000B9`0gooo0?oOW0180000B9cO0`3oool00`2oM00004RL0=oo
o`0A0?ooo`00D@3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo05l0oooo00P0
oooO09a8001d_ol0oooo0?oog`2LB00004RL0=ooo`80oooo00L0gia80018W03Oool0oooO09a80000
B9`0gooo0080oooo00<0gia80018W03Oool0E03oool0103OW4P0B9cO0;md0000M;l20?ooo`040?oo
g`2LB00004RL0=ooo`80oooo00L0gia80018W03Oool0oooO09a80000B9`0gooo0080oooo00<0gia8
0018W03Oool0D`3oool00`3ookl0M000001d_`050?ooo`040?oog`2LB00004RL0=ooo`80oooo00L0
gia80018W03Oool0oooO09a80000B9`0gooo0080oooo00<0gia80018W03Oool0DP3oool00`3ogi`0
B00007Boo`020?ooo`070?noM018W=l0oooo0?oog`2LB00004RL0=ooo`020?ooo`070=nLB000B9`0
gooo0?oog`2LB00004RL0=ooo`020?ooo`030=nLB000B9`0gooo0140oooo001B0?ooo`030?oOW018
0000M;oo0080oooo00<0gia8001d_`3oool0G`3oool00`3ookl0M00004RLg`020?ooo`030?oOW018
0000M;oo0080oooo00L0gia8001d_`3oool0oooo0?oOW0180000M;oo0080oooo00<0gia8001d_`3o
ool0E@3oool0103OW4P0M7Ad0000M02oool20?ooo`030?oOW0180000M;oo0080oooo00L0gia8001d
_`3oool0oooo0?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0E03oool00`3ogi`0B00004RL
g`050?ooo`030?oOW0180000M;oo0080oooo00L0gia8001d_`3oool0oooo0?oOW0180000M;oo0080
oooo00<0gia8001d_`3oool0DP3oool00`3ogi`0B01809cOo`020?ooo`070?noM000B9`0gooo0?oo
o`3ogi`0B00007Boo`020?ooo`070=nLB000M;l0oooo0?ooo`3ogi`0B00007Boo`020?ooo`030=nL
B000M;l0oooo0140oooo001C0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cOG03oool01`3o_g@0
04RL0=ooo`3oool0gia80000B02Lgol00`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`<0oooo
00H0gia80000M02oool0oooO09a80018W=mG0?ooo`030;md000004P0W=oo00<0oooo00H0gia80000
M02oool0oooO09a80018W=l30?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cOEP3oool0103ooml0
W4P00000M02oool40?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO0`3oool01P3OW4P0001d0;oo
o`3ooml0W4P004RLge<0oooo00<0oooO09a80018W=l00P3oool00`2oM00007Bo0?ooo`020?ooo`06
0=nLB00007@0_ooo0?oog`2LB000B9cO0`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLga80oooo
001D0?ooo`040=nLB00000000000001d_eh0oooo00D0omnL04P000000000000007Boo`050?ooo`04
0=nLB00000000000001d_`D0oooo00@0gia800000000000007BoF03oool00`3ooml0W4P004RLg`04
0?ooo`040=nLB00000000000001d_`D0oooo00@0gia800000000000007BoF@3oool0103ookl0M000
00000018W=l30?ooo`040=nLB00000000000001d_`D0oooo00@0gia800000000000007BoE@3oool0
1@3ooml0W4P000000000000007Bo00D0oooo00@0gia800000000000007Bo1@3oool0103OW4P00000
00000000M;lC0?ooo`00o`3ooooo0?ooobL0oooo003o0?ooool0oooo9`3oool00?l0ooooo`3ooolW
0?ooo`00o`3ooooo0?ooobL0oooo003o0?ooool0oooo9`3oool00?l0ooooo`3ooolW0?ooo`00o`3o
oooo0?ooobL0oooo003o0?ooool0oooo9`3oool00?l0ooooo`3ooolW0?ooo`00o`3ooooo0?ooobL0
oooo003o0?ooool0oooo9`3oool003P0oooo00<0gia80000000000000`0000000`18W=l0oooo0?oo
o`090?ooool00000aP00000F0?ooo`00>@3oool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0503oool003X0oooo00<0okmd001d_`3oool03@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0J@3oool00`00
0000oooo0?ooo`1Y0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0D0?ooo`00>`3oool00`3o_g@007Bo0?ooo`0<0?ooo`030000003oool0oooo0?l0
oooo`P3oool00`000000oooo0?ooo`0D0?ooo`00:`3oool00`3ooml0W4P0000000070000000304RL
g`3oool0oooo00@0oooo00<0okmd04RLg`3oool02`3oool00`000000oooo0?ooo`3o0?oool80oooo
00<000000?ooo`3oool0503oool003d0oooo00<0gia804RLg`3oool02P3oool4000002d0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`3n0?ooo`@000005P3oool003h0oooo00<0_g@0
07Boo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01d0oooo0`00000O
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo01d0oooo0`00000O0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0503oool003h0oooo00<0omnL04P0M02oool02@3oool00`000000oooo0?ooo`0<0?oo
o`<00000503oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool04P3oool3000000T0oooo00<000000?ooo`3oool04P3oool3000000P0oooo0`00000D0?oo
o`030000003oool0oooo00L0oooo0`00000D0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`<000001`3oool3000001<0oooo0`0000080?oo
o`<00000503oool00`000000oooo0?ooo`070?ooo`<000007P3oool3000000T0oooo00<000000?oo
o`3oool04P3oool3000000P0oooo0`00000C0?ooo`<00000203oool3000001@0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0D0?ooo`00?P3oool00`3ooml0W4P007Boo`090?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`<0
00004`3oool3000000T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`<0
0000503oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0180oooo0`0000090?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool300000180oooo0`00000E0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0180oooo0`0000090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo0`00000D0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool300000140oooo00<000000?ooo`3o
ool0503oool003h0oooo00<0oono07@00018W=l02@3oool00`000000oooo0?ooo`0G0?ooo`<00000
2@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo0`00000D0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`<00000
2P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0180oooo0`0000080?ooo`<00000
503oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03h0oooo0`0000090?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0503oool003X0oooo00L0okmd0018W03Oool0oooo
0=nLB00004P0W=oo00T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo01d0oooo0P00000N0?ooo`<000007`3oool00`000000oooo0?ooo`0Y0?ooo`<0
00007P3oool2000001h0oooo0`00000O0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool07@3oool3000001l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01@0oooo000k0?ooo`050?oOW018000000000000001d_ol02P3oool00`000000
oooo0?ooo`1S0?ooo`@000007P3oool2000004`0oooo00<000000?ooo`3oool0703oool4000001h0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0M0?ooo`<00000?@3oool00`000000
oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01h0oooo
0P00000O0?ooo`<00000BP3oool00`000000oooo0?ooo`0N0?ooo`800000803oool00`000000oooo
0?ooo`180?ooo`<000007P3oool3000003d0oooo00<000000?ooo`3oool0503oool004X0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0W0?ooo`<00000@@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool07@3oool300000400oooo0`00
000Y0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0D0?ooo`00BP3oool00`000000oooo0?ooo`0G0?ooo`<00000203oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo0600oooo0`0000070?ooo`<000007`3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`06
0?ooo`<00000H03oool3000000P0oooo0`00000A0?ooo`030000003oool0oooo01@0oooo001:0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool3000001D0oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`1C0?ooo`<00000503oool3000000P0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo01<0oooo0`00001D0?ooo`<00000=@3oool3000003@0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0<P3oool300000380oooo00<000000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0380oooo0`00001F0?ooo`<00000
4`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
503oool004X0oooo0`00001>0?ooo`030000003oool0oooo00P0oooo0`00000B0?ooo`<00000K03o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0A0?ooo`<00000D@3oool3000001H0oooo001:0?ooo`030000003oool0
oooo04d0oooo0`00000:0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0JP3oool3
000000T0oooo0`00001P0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0?@3oool3000002X0oooo0`0000170?ooo`030000003oool0oooo
01@0oooo001:0?ooo`030000003oool0oooo02`0oooo0`00001;0?ooo`<00000?P3oool3000004/0
oooo0`00000N0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo00`0oooo
0P00000O0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool07@3oool2000001l0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0L0?ooo`<00000J`3oool00`000000oooo
0000000W0?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo00/0oooo1000
002;0?ooo`@00000J`3oool00`000000oooo0?ooo`0N0?ooo`800000JP3oool5000002H0oooo00<0
00000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool0303oool2000006`0oooo00<00000
0?ooo`3oool07P3oool2000006/0oooo0`00000O0?ooo`<00000B@3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0000002L0oooo00<000000?ooo`3oool0503oool004X0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`180?ooo`<00000K03oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0A`3oool3000004T0oooo00<000000?oo
o`3oool0503oool004X0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`080?ooo`03
0000003oool0000000800000703oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool07P3oool010000000oooo0?ooo`00000M0?ooo`030000003oool0oooo
00T0oooo0`00000B0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0180
oooo0`0000080?ooo`<0000000<0oooo0000003oool0203oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo0`00000:0?ooo`<000004@3oool3000000T0oooo00<000000?ooo`3o
ool04P3oool3000000P0oooo0`00000D0?ooo`030000003oool0oooo00L0oooo1P0000080?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool3000000/0oooo00<000000?ooo`3o
ool0403oool3000000T0oooo00<000000?ooo`3oool04P3oool3000000P0oooo0`00000D0?ooo`03
0000003oool0oooo00L0oooo0`0000000`3oool000000?ooo`070?ooo`<000001`3oool00`000000
oooo0?ooo`070?ooo`<00000203oool00`000000oooo0?ooo`0B0?ooo`<000002@3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool004X0oooo
00<000000?ooo`3oool02@3oool3000001@0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`090?ooo`<000001P3oool3000000T0oooo00@000000?ooo`3oool000001`3oool00`000000
oooo000000080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool3000001@0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`<000002@3oool010000000
oooo0?ooo`0000080?ooo`<000001P3oool3000000T0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool30000
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00D0oooo0`0000090?ooo`030000003oool00000008000001@3oool010000000oooo0?ooo`000007
0?ooo`<000002@3oool00`000000oooo0?ooo`060?ooo`<000002P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo0`00000C0?ooo`<00000503oool00`000000oooo0?ooo`0D
0?ooo`00BP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo0P00000N0?oo
o`030000003oool0000000P0oooo00<000000?ooo`3oool02P3oool3000000D0oooo0`0000080?oo
o`<00000503oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`000000203oool00`000000oooo0?ooo`0C0?ooo`030000003oool0000000P0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`040?ooo`<00000203oool3000001@0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0M0?ooo`030000003oool00000008000001`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo0`00000:0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0203oool3000001<0oooo00<000000?ooo`3oool02@3oool20000
00P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000
oooo0?ooo`0E0?ooo`@00000703oool3000001L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo01d0oooo0`00000N0?ooo`D00000703oool3000001H0
oooo0`0000060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07@3oool4000001`0
oooo0`0000000`3oool000000?ooo`0L0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool07@3oool4000001d0oooo00<000000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool0
503oool4000001d0oooo0`00000O0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`000000
7@3oool4000001d0oooo0`00000G0?ooo`030000003oool0oooo0300oooo1@00000L0?ooo`<00000
7`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
6`3oool4000001h0oooo00<000000?ooo`3oool0503oool004X0oooo0`00000E0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool07@3oool3000000/0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo1@00000M0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo01X0oooo0`0000000`3oool000000?ooo`0M0?ooo`030000003oool0oooo01d0oooo0`00
000F0?ooo`<000001P3oool00`000000oooo0?ooo`070?ooo`@000007@3oool00`000000oooo0?oo
o`0L0?ooo`<000005P3oool004X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo00P0oooo100000090?ooo`<000001@3oool3000000T0oooo00<00000
0?ooo`000000G`3oool3000000P0oooo00<000000?ooo`0000000P00000:0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`<000001`3oool4
000001@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`00
0000oooo0?ooo`0:0?ooo`<000007`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01/0oooo1000000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0c0?ooo`040000003oool0oooo000001<0oooo00<000000?ooo`3oool01P3oool3
000000030?ooo`000000oooo00T0oooo0`0000050?ooo`<000007`3oool00`000000oooo0?ooo`0c
0?ooo`@000004`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01<0oooo0`00000Y
0?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool07@3oool3000001<0oooo1000000M0?ooo`030000003oool0oooo03<0oooo0`00000F0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool6000001`0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01d0oooo0`00000E0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool4000002d0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01@0oooo001:0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`@0
00002@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0503oool3000000H0oooo0`00000C0?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo100000070?oo
o`<000004`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0200oooo0`00000M0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0503oool004X0oooo00<000000?ooo`3o
ool0803oool4000001d0oooo00<000000?ooo`3oool0203oool3000001l0oooo00<000000?ooo`3o
ool07`3oool3000001/0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0M0?oo
o`<000007`3oool00`000000oooo0?ooo`0N0?ooo`<00000703oool4000000T0oooo00<000000?oo
o`3oool07@3oool300000200oooo00<000000?ooo`000000703oool400000180oooo00<000000?oo
o`3oool0503oool004X0oooo00<000000?ooo`3oool07`3oool4000002X0oooo00<000000?ooo`3o
ool07@3oool3000001l0oooo0`00000K0?ooo`<00000:`3oool00`000000oooo0?ooo`0M0?ooo`<0
00007P3oool3000000030?ooo`000000oooo01/0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`0N0?ooo`<00000703oool4000001<0oooo00<000000?ooo`3oool0503oool004X0oooo
00<000000?ooo`3oool0803oool2000004`0oooo0`00000M0?ooo`<000007@3oool00`000000oooo
0000000[0?ooo`030000003oool0oooo01d0oooo0`00000L0?ooo`L00000B@3oool00`000000oooo
0?ooo`0L0?ooo`<000007P3oool2000001@0oooo00<000000?ooo`3oool0503oool004X0oooo00<0
00000?ooo`3oool0803oool3000000030?ooo`000000oooo01`0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01/0oooo0`00000O0?ooo`<000007`3o
ool00`000000oooo0?ooo`070?ooo`<000007`3oool00`000000oooo0?ooo`0L0?ooo`8000000P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool07@3o
ool3000001d0oooo0P00000O0?ooo`<0000000<0oooo0000003oool0403oool00`000000oooo0?oo
o`0D0?ooo`00BP3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool00000008000001`3oool0
0`000000oooo0?ooo`0A0?ooo`<000002@3oool3000001<0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool04P3oool3
000000T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool04@3oool3000000T0oooo0`00000C0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool06`3oool300000200oooo00<000000?ooo`0000000P00000@
0?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`050?ooo`<000004`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0140oooo0`0000080?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`<000001P3oool3000001@0oooo00<000000?oo
o`3oool07@3oool3000000H0oooo0`00000E0?ooo`030000003oool0oooo01<0oooo0`00000C0?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool04@3oool3000001l0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`0;0?oo
o`<00000203oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool01P3oool3000000/0oooo00<000000?ooo`3oool01P3oool3000001<0oooo0`0000090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00H0oooo0`00000E0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02P3oool3000001`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00H0oooo0`00000D0?ooo`<00000203oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool01P3oool3000001l0oooo0P00000<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool02@3oool2000001<0oooo00<000000?ooo`3oool02@3oool3000000P0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`070?ooo`<000007`3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00T0oooo0`00000N0?ooo`<00000203oool00`000000oooo0?ooo`0M0?ooo`<0
0000303oool00`000000oooo0?ooo`0@0?ooo`8000004P3oool3000000X0oooo0`0000080?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool3000001h0oooo00<000000?ooo`3o
ool0503oool004X0oooo0`00000;0?ooo`030000003oool0oooo00P0oooo0P00000N0?ooo`@00000
2P3oool3000000@0oooo0`0000090?ooo`@000007P3oool2000001l0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0M0?ooo`<000004@3oool3000000X0oooo0`00000O0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool07@3oool2000001h0oooo1000000B0?ooo`030000
003oool0oooo00T0oooo0P00000O0?ooo`030000003oool0oooo00P0oooo0P00000L0?ooo`<00000
5P3oool004X0oooo00<000000?ooo`3oool02P3oool3000000T0oooo0`0000080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool2000000T0oooo00@000000?ooo`3oool00000
1P3oool2000000X0oooo0P0000090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1`3oool3000000T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`<00000
203oool3000000T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`0000001P3oool00`000000oooo0000000:0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`<00000
203oool3000000T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`<00000
2@3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000T0oooo0P00000:0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool3000000X0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`060?ooo`<000002@3oool3000000T0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01P3oool3000000P0oooo0`00000C0?ooo`<00000203o
ool3000001<0oooo0`0000080?ooo`<000002@3oool00`000000oooo0?ooo`070?ooo`<00000203o
ool3000000T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`<000001`3o
ool4000001<0oooo1@0000060?ooo`<000004`3oool3000000P0oooo0`0000090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01`3oool3000000P0oooo0`0000090?ooo`030000003o
ool0oooo00L0oooo0`0000060?ooo`D000004`3oool3000000P0oooo0`0000080?ooo`030000003o
ool0oooo00P0oooo0`0000080?ooo`<00000203oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00L0oooo0`0000070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0503o
ool004X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`060?ooo`<000005@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`050?ooo`@000005@3oool00`000000oooo000000080?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
000001D0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`050?ooo`<000002@3oool0
0`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0g0?ooo`<00000DP3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo06H0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`2;0?ooo`<00000>@3oool00`000000
oooo0?ooo`1L0?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0F03oool3000002l0oooo0`00001J0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01@0oooo
001:0?ooo`030000003oool0oooo00T0oooo0`00001J0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool0F03oool300000100oooo00<000000?ooo`3oool0R`3oool3000002X0oooo00<0
00000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1Z
0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool03P3oool3000008d0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`1f0?oo
o`<00000S@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`1g0?ooo`03
0000003oool0oooo0?T0oooo0`00000<0?ooo`<00000?03oool00`000000oooo0?ooo`0D0?ooo`00
BP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
503oool004X0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0/0?ooo`<00000G03o
ool300000=X0oooo00<000000?ooo`3oool0503oool004X0oooo0`00001E0?ooo`<00000;P3oool0
0`000000oooo0?ooo`1L0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`1Y0?ooo`<000005P3oool004X0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`1[0?ooo`030000003oool0oooo04d0oooo0`00000k0?ooo`<00000K03oool00`00
0000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0R`3oool3000004l0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0503oool004X0oooo
00<000000?ooo`3oool0603oool3000001T0oooo0`00002=0?ooo`030000003oool0oooo0=`0oooo
0`00000K0?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo08P0oooo00<0
00000?ooo`3oool0K`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01@0oooo001:
0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool00`0000280?ooo`<00000S@3oool0
0`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
08/0oooo0`0000020?ooo`030000003oool0oooo08P0oooo00D000000?ooo`3oool0oooo0000001Y
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0503oool004X0oooo00<000000?oo
o`3oool04`3oool3000008d0oooo00<000000?ooo`3oool0S`3oool3000006L0oooo0`00000O0?oo
o`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0nP3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0D0?ooo`00>03oool00`3ookl0M000000000020000000304RL
g`3oool0oooo00X0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo08/0oooo0`00002^0?ooo`030000003oool0oooo01@0oooo000j0?ooo`030?noM000
0000M;oo00d0oooo00<000000?ooo`3oool0>@3oool3000004D0oooo0`00002=0?ooo`030000003o
ool0oooo06/0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0D0?ooo`00>P3oool0
0`3ooml0W4P0001d_`0=0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo0;<0oooo0`0000100?ooo`030000003oool0
oooo01@0oooo000k0?ooo`030=nLB000B9`0gooo00`0oooo00<000000?ooo`3oool0a`3oool30000
02H0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
01@0oooo000[0?ooo`030?oog`2LB000000000L0000000<0B9cO0?ooo`3oool00`3oool00`3ogi`0
B01809cOo`0<0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0I03oool00`000000
oooo0?ooo`0T0?ooo`<00000c`3oool00`000000oooo0?ooo`0D0?ooo`00>`3oool00`3ookl0M000
07Boo`0<0?ooo`@00000G`3oool3000008d0oooo00<000000?ooo`3oool0I03oool00`000000oooo
0?ooo`1T0?ooo`@000005P3oool003`0oooo00<0_g@0001d_`3oool02`3oool00`000000oooo0?oo
o`1Q0?ooo`030000003oool0oooo0?80oooo0`0000050?ooo`030000003oool0oooo0600oooo00<0
00000?ooo`3oool0503oool003`0oooo00<0gia80018W03Oool02`3oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`03
0?ooo`<00000H@3oool00`000000oooo0?ooo`0D0?ooo`00?03oool00`3ogi`0B01809cOo`0;0?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool05`3oool300000740oooo0`00002=0?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool0503oool003`0oooo00<0oono07@0001d
_ol02`3oool00`000000oooo0?ooo`0o0?ooo`<000006@3oool00`000000oooo0?ooo`1a0?ooo`03
0000003oool0oooo0>l0oooo00<000000?ooo`3oool0503oool003d0oooo00<0_g@0001d_`3oool0
2P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0
D@3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo01@0oooo000k0?ooo`050?oo_`1d
000000000000M02oool02P3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo03L0oooo
0`00001A0?ooo`<00000PP3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo08/0oooo0`00000i0?ooo`030000003oool0oooo0540oooo00<0
00000?ooo`3oool0JP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo001:
0?ooo`030000003oool0oooo01h0oooo0`00002=0?ooo`030000003oool0oooo0<L0oooo00<00000
0?ooo`3oool0;P3oool3000001D0oooo00<000000?ooo`3oool0503oool004X0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`3j0?ooo`030000003oool0oooo05P0oooo0`00000`0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool004X0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo08/0oooo0`00001J0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool0
N`3oool3000000h0oooo0`00002=0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0
503oool004X0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0?T0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool3
00000?/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1k0?ooo`<00000=03oool3
000001H0oooo001:0?ooo`030000003oool0oooo0?X0oooo0`00000<0?ooo`<00000O@3oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo06`0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0;@0
oooo00<000000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool0J`3oool300000?X0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0n03oool3000002l0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`0=
0?ooo`<00000bP3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo02d0oooo0`00000V
0?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo03T0oooo0`00002m0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0503oool004X0oooo00<000000?ooo`3o
ool0BP3oool3000004l0oooo0`00000k0?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3o
ool0503oool004X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo0:L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0D0?ooo`00BP3o
ool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0603o
ool3000007P0oooo00<000000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`2;0?ooo`<00000K`3oool3000001X0oooo00<000000?ooo`3oool0J`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo
02T0oooo0`00002=0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0QP3oool30000
00X0oooo00<000000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3oool0S03oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo02h0oooo
0`00001W0?ooo`030000003oool0oooo08X0oooo0`00002I0?ooo`030000003oool0oooo01@0oooo
001:0?ooo`<00000;`3oool00`000000oooo0?ooo`1U0?ooo`<00000S03oool00`000000oooo0?oo
o`2F0?ooo`<000005P3oool004X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo00P0oooo0`00002b0?oo
o`<00000d`3oool3000002/0oooo00<000000?ooo`3oool0503oool004X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool0R`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool0R`3oool3000004@0oooo00<000000?ooo`3oool0
LP3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`1f0?ooo`<00000S@3o
ool00`000000oooo0?ooo`120?ooo`<000009@3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo01@0oooo001:0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0dP3oool0
0`000000oooo0?ooo`0S0?ooo`<00000C03oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`00
0000oooo0?ooo`3U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0R`3oool300000=X0oooo00<000000?ooo`3oool0503oool004X0oooo
00<000000?ooo`3oool0C`3oool3000000<0oooo0`00002=0?ooo`030000003oool0oooo0=T0oooo
00<000000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?oo
o`1/0?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo0<@0oooo00<00000
0?ooo`3oool05`3oool300000700oooo0`00001]0?ooo`030000003oool0oooo01@0oooo001:0?oo
o`030000003oool0oooo0<<0oooo0`00000I0?ooo`030000003oool0oooo0700oooo00<000000?oo
o`3oool0K03oool00`000000oooo0?ooo`0D0?ooo`00BP3oool3000003D0oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`3h0?ooo`<000005P3oool004X0oooo00<000000?ooo`3oool0
=03oool300000?X0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`1A0?ooo`030000
003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0n03o
ool3000003T0oooo0`00001B0?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0
oooo0:<0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`1J0?ooo`030000003oool0oooo02h0oooo0`00003j0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool04`3oool3000005X0
oooo0`00000`0?ooo`030000003oool0oooo0?P0oooo0`00000P0?ooo`030000003oool0oooo01@0
oooo001:0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0FP3oool00`000000oooo
0?ooo`2L0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo07/0oooo00<0
00000?ooo`3oool0303oool300000:l0oooo00<000000?ooo`3oool0503oool004X0oooo00<00000
0?ooo`3oool0P@3oool3000007/0oooo0`00000>0?ooo`030000003oool0oooo0:h0oooo00<00000
0?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`1k0?oo
o`030000003oool0oooo07/0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0D0?oo
o`00BP3oool00`000000oooo0?ooo`3_0?ooo`030000003oool0oooo08/0oooo0`0000110?ooo`03
0000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo0>h0oooo0`00002=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0D0?ooo`00BP3o
ool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0V`3o
ool300000340oooo00<000000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool0H03oool3
00000?X0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo01@0oooo001:0?ooo`<00000H@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
0<L0oooo0`00001P0?ooo`<000005P3oool004X0oooo00<000000?ooo`3oool0T@3oool3000003X0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo01@0
oooo001:0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`0h0?ooo`<00000l@3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?oo
o`0o0?ooo`<00000S03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`3M
0?ooo`<000006@3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo01@0oooo001:0?oo
o`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0G0?oo
o`<00000P`3oool00`000000oooo0?ooo`0D0?ooo`007P3oool00`3OW4P0001d0;ooo`0Y0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0RP3oool3000008d0oooo00<000000?ooo`3o
ool0J`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo000G0?ooo`030?oo
_`1dM;l0oooo00@0oooo00<0oono07A8W03Oool0:@3oool00`000000oooo0?ooo`0N0?ooo`<00000
S03oool00`000000oooo0?ooo`3i0?ooo`<000005@3oool00`000000oooo0?ooo`0D0?ooo`005`3o
ool00`3ogi`0B01d0;ooo`030?ooo`030?noM00007@0_ooo01X0oooo00@0_g@0000000000000M;oo
303oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
m03oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0D0?ooo`005`3oool01`3ogi`0B0000000000004P0W=oo0?oOW018
M;l06`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`/0oooo00<000000?ooo`3oool08`3oool3
00000?@0oooo0`00002A0?ooo`<00000403oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`3o
okl0M000000000020000000307Boo`3oool0oooo01L0oooo00<0oooO09a80018W=l00P3oool00`3o
_g@0001809cOo`0:0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo000H0?ooo`090?oo_`1d07@0_ooo0?oo
o`3ooml0W4P00000000007@0_ooo01L0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018
W03Oool90?ooo`030000003oool0oooo08/0oooo0`00000T0?ooo`<00000e03oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo01@0oooo000G0?ooo`030?oo_`1d07@0_ooo00@0oooo00<0
omnL04Qd_`3oool05`3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00T0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0=80oooo0`00
000f0?ooo`030000003oool0oooo01@0oooo000G0?ooo`030?noM0000000M;oo00<0oooo00<0oono
07A8W03Oool06@3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00T0ooooo`000036
000001H0oooo000i0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l02@3oool00`00
0000oooo0?ooo`1[0?ooo`030000003oool0oooo08/0oooo0`0000150?ooo`<00000O@3oool00`00
0000oooo0?ooo`0D0?ooo`008@3oool0103o_g@000000000M02ooolD0?ooo`030?oOW0180000B9cO
00<0oooo00<0_g@00018W03Oool0203oool00`000000oooo0?ooo`1Z0?ooo`<00000S@3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0503oool001D0
oooo00<0gia80000001d_ol00P3oool0103ooml0W9bo0?oog`2LB00300000003001d_`3oool0oooo
01D0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`080?ooo`030000003oool0
oooo06/0oooo00<000000?ooo`3oool0nP3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo01@0oooo000B0?ooo`040=nLB00000000000001d_`@0oooo00@0oono07@0000004P0W=oo0P3o
ool00`2oW9`0gooo0?ooo`0G0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0203o
ool00`000000oooo0?ooo`3I0?ooo`030000003oool0oooo08/0oooo0`00001G0?ooo`030000003o
ool0oooo01@0oooo000A0?ooo`040?oo_`1d000004RL0=ooo`T0oooo00D0gmoO0;md000000000000
001d_`0H0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO2@3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0R`3oool3000008d0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0D0?ooo`007@3oool00`3ooml0W4P007Boo`020?ooo`03
0=nLB00007@0_ooo01L0oooo00@0gia800000000000007Bo2P3oool00`000000oooo0?ooo`140?oo
o`<000000P3oool3000008d0oooo00<000000?ooo`3oool0i@3oool00`000000oooo0?ooo`0D0?oo
o`007@3oool00`3ooml0W7BL0=ooo`020?ooo`030=nLM02Lgol0oooo02D0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3o
ool0L03oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000
003oool0oooo0=<0oooo0`00001`0?ooo`<00000N03oool00`000000oooo0?ooo`0D0?ooo`00BP3o
ool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0L03o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0RP3oool300000?/0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`0Y0?ooo`<00000S03oool00`00
0000oooo0?ooo`2W0?ooo`030000003oool0oooo04l0oooo0`00000:0?ooo`030000003oool0oooo
01@0oooo001:0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0n@3oool00`000000
oooo0?ooo`0h0?ooo`<00000D@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01@0
oooo001:0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0R`3oool3000003X0oooo
00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0D0?ooo`00BP3oool3000000T0oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`0]0?ooo`<00000S@3oool00`000000oooo0?oo
o`1[0?ooo`030000003oool0oooo02P0oooo0`00000F0?ooo`00BP3oool00`000000oooo0?ooo`08
0?ooo`<00000FP3oool3000002l0oooo00<000000?ooo`3oool0n@3oool3000002/0oooo00<00000
0?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1J0?oo
o`030000003oool0oooo09`0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`0<0?ooo`<00000^P3oool00`000000oooo0?ooo`0D0?ooo`00
BP3oool00`000000oooo0?ooo`1e0?ooo`<00000O03oool3000000h0oooo00<000000?ooo`3oool0
^@3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`1f0?ooo`030000003o
ool0oooo07`0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo01@0oooo001:0?ooo`030000003oool0oooo0?l0ooooL`3oool3000004`0oooo00<00000
0?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool0i03oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0D0?oo
o`00BP3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo08/0oooo0`00002L0?ooo`<0
0000?03oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`1D0?ooo`<00000
S@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool0a`3oool3000006d0oooo00<000000?ooo`3oool0503o
ool004X0oooo00<000000?ooo`3oool0QP3oool3000003X0oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`1/0?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0h0?ooo`<00000o03oool00`00
0000oooo0?ooo`0D0?ooo`00BP3oool3000003<0oooo0`00002=0?ooo`030000003oool0oooo0500
oooo00<000000?ooo`3oool0YP3oool3000001H0oooo001:0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0gP3oool3000001T0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool05`3oool3000008h0oooo00<000000?ooo`3oool0503oool004X0oooo00<00000
0?ooo`3oool0X@3oool3000008d0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0D
0?ooo`00BP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`3i0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`0B0?ooo`<0
00000`3oool300000?D0oooo00<000000?ooo`3oool0RP3oool3000000<0oooo0`00000K0?ooo`03
0000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`3c0?ooo`<00000S03oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0[P3o
ool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`200?ooo`<00000903oool3
00000=@0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`00
0000oooo0?ooo`210?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0dP3oool30000
0440oooo00<000000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool0k`3oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo08/0oooo
0`0000150?ooo`<00000R03oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?oo
o`1O0?ooo`<00000S@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo08L0oooo00<0
00000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`3j
0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0503oool004X0oooo0`00000j0?oo
o`030000003oool0oooo0940oooo00<000000?ooo`3oool0R`3oool300000600oooo0`00000F0?oo
o`00BP3oool00`000000oooo0?ooo`0i0?ooo`<00000T@3oool3000008d0oooo00<000000?ooo`3o
ool0H@3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0?00oooo00<000000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool0?P3o
ool3000008L0oooo0`00001a0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0503o
ool004X0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`270?ooo`030000003oool0
oooo06l0oooo0`0000230?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo
0:d0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
06H0oooo00<000000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`2;0?ooo`<00000Z03oool3000004l0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`0M0?ooo`<00000S@3oool00`000000oooo
0?ooo`2X0?ooo`030000003oool0oooo04d0oooo0`00000F0?ooo`030000003oool0oooo01@0oooo
001:0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`2m0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0D0?ooo`00BP3oool00`000000oooo0?ooo`1J0?ooo`<00000;`3oool00`000000oooo0?ooo`2;
0?ooo`<00000Y03oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`1K0?oo
o`030000003oool0oooo02d0oooo0`00002=0?ooo`030000003oool0oooo06X0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool0VP3oool3000003L0oooo00<000000?ooo`3o
ool0503oool004X0oooo00<000000?ooo`3oool0j@3oool3000000h0oooo00<000000?ooo`3oool0
R`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01@0oooo001:0?ooo`<00000J`3o
ool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00`0oooo0`0000330?ooo`<000005P3o
ool004X0oooo00<000000?ooo`3oool0JP3oool3000008d0oooo00<000000?ooo`3oool0O03oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo
06/0oooo00<000000?ooo`3oool0n@3oool00`000000oooo0?ooo`0>0?ooo`<00000AP3oool00`00
0000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0oooo08X0
oooo0`00000@0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0503oool004X0oooo
00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`1I0?ooo`<00000S03oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool0;P3oool3000005/0oooo00<000000?ooo`3oool0i@3oool00`000000oooo0?oo
o`0D0?ooo`00BP3oool00`000000oooo0?ooo`190?ooo`<00000<03oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0D
0?ooo`00BP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0;d0oooo0`00000h0?oo
o`<00000N@3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`2h0?ooo`03
0000003oool0oooo0500oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1[0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0503oool003P0oooo00<0oono07@000000000
0P0000000`18W=l0oooo0?ooo`0:0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
R`3oool300000>00oooo00<000000?ooo`3oool05P3oool3000000/0oooo00<000000?ooo`3oool0
503oool003X0oooo00<0okmd0000001d_ol03@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo01L0oooo0`00002=0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0L@3o
ool3000001P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0D0?ooo`00>P3oool0
0`3ooml0W4P0001d_`0=0?ooo`030000003oool0oooo00d0oooo0`00000I0?ooo`030000003oool0
oooo0740oooo00<000000?ooo`3oool0Q03oool3000007<0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0D0?ooo`00>`3oool00`3OW4P004RL0=ooo`0<0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`020?ooo`<00000QP3oool00`00
0000oooo0?ooo`2I0?ooo`030000003oool0oooo01@0oooo000k0?ooo`030?oOW01804P0W=oo00`0
oooo100000070?ooo`030000003oool0oooo08/0oooo0`0000040?ooo`030000003oool0oooo0?<0
oooo00<000000?ooo`3oool0:03oool4000001H0oooo000k0?ooo`030?oo_`1d0000M;oo00`0oooo
00<000000?ooo`3oool01`3oool3000008d0oooo00<000000?ooo`3oool0TP3oool00`000000oooo
0?ooo`1S0?ooo`<00000;03oool00`000000oooo0?ooo`0D0?ooo`00?03oool00`2oM00007Bo0?oo
o`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0n@3oool00`000000oooo0?oo
o`0T0?ooo`<00000I@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01@0oooo000l
0?ooo`030=nLB000B9`0gooo00/0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`2:
0?ooo`<000009P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo01@0oooo000l0?oo
o`030?oOW01804P0W=oo00/0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`130?oo
o`<00000S03oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool0503oool003`0oooo00<0oono07@0001d_ol02`3oool00`000000oooo0?ooo`0^0?ooo`<0
0000A@3oool00`000000oooo0?ooo`3h0?ooo`<00000C@3oool00`000000oooo0?ooo`0D0?ooo`00
?@3oool00`2oM00007Bo0?ooo`0:0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`0D0?ooo`00>`3oool01@3ookl0M0000000000007@0_ooo00X0oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1U0?ooo`<000008P3oool300000=`0oooo
00<000000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool0E03oool3000006L0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`1W0?ooo`050000003oool0oooo0?ooo`000000
K`3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo06X0oooo00<000000?ooo`3oool0Q`3oool3000000040?ooo`0000000000000006h0oooo
00<000000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`2:0?ooo`<00000R@3oool01@000000oooo0?ooo`3oool0000006l0oooo00<000000?ooo`3oool0
503oool004X0oooo00<000000?ooo`3oool0<`3oool3000001X0oooo00<000000?ooo`3oool0K`3o
ool00`000000oooo0?ooo`3l0?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0603oool3000008d0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo
0500oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0i0?ooo`<00000CP3oool30000
08l0oooo00<000000?ooo`3oool0503oool004X0oooo0`00000C0?ooo`030000003oool0oooo08/0
oooo0`00000k0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0J`3oool00`000000
oooo0?ooo`0N0?ooo`<000005P3oool004X0oooo00<000000?ooo`3oool04P3oool3000008d0oooo
00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0/0?ooo`<000008@3oool00`000000oooo
0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?T0oooo00<0
00000?ooo`3oool0F`3oool3000002h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0D0?ooo`00BP3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0RP3oool3000005d0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0D
0?ooo`00BP3oool00`000000oooo0?ooo`1`0?ooo`<000003@3oool3000008`0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo01@0oooo001:0?ooo`03
0000003oool0oooo0740oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1Z0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0N@3oool300000480oooo00<000000?ooo`3o
ool0503oool004X0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`2:0?ooo`<00000
3`3oool3000007/0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0D0?ooo`00BP3o
ool00`000000oooo0?ooo`1O0?ooo`<00000S03oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo05T0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo01@0oooo001:0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0JP3oool0
0`000000oooo0?ooo`2;0?ooo`<00000<03oool300000300oooo00<000000?ooo`3oool0503oool0
04X0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo
03L0oooo0`00002=0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`0n0?ooo`<00000D03oool3000003T0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo01@0
oooo001:0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01@3oool010000000oooo
0?ooo`00000E0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo1000000E0?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01@0
oooo001:0?ooo`030000003oool0oooo01/0oooo100000070?ooo`<000002@3oool00`000000oooo
0?ooo`070?ooo`<00000203oool3000000T0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`070?ooo`<00000203oool3000000T0oooo00<000000?ooo`3oool01`3oool3000000P0oooo
0`00000C0?ooo`<00000203oool3000000P0oooo00<000000?ooo`3oool0203oool3000000L0oooo
0`0000090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool3000000P0oooo
0`00000:0?ooo`030000003oool0oooo00H0oooo0`0000070?ooo`@000004`3oool5000000H0oooo
0`0000090?ooo`030000003oool0oooo00L0oooo0`0000080?ooo`<00000203oool3000000T0oooo
00<000000?ooo`3oool01`3oool3000000P0oooo0`00000C0?ooo`@000001`3oool3000000d0oooo
00<000000?ooo`3oool0503oool004X0oooo0`00000A0?ooo`030000003oool0oooo00P0oooo1000
00050?ooo`030000003oool0000000T0oooo0`0000090?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01`3oool3000000P0oooo0`0000090?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01`3oool3000000T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`070?ooo`8000002P3oool3000000P0oooo00<000000?ooo`3oool01P3oool3000000X0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`<000002@3oool3000000P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`<00000203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo0P0000090?ooo`030000003oool0000000P0oooo00<0
00000?ooo`3oool01`3oool3000000T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00L0oooo0`0000090?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`@000001@3oool00`000000oooo0000
000<0?ooo`<000005P3oool004X0oooo00<000000?ooo`3oool0403oool3000000/0oooo00<00000
0?ooo`3oool00`3oool3000000X0oooo0`00000O0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool07@3oool2000000/0oooo00<000000?ooo`3oool0403oool4000000X0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`8000007`3oool2000000T0oooo0P00000O
0?ooo`8000002`3oool00`000000oooo0?ooo`0@0?ooo`@000007P3oool2000002X0oooo00<00000
0?ooo`3oool07@3oool3000000/0oooo00<000000?ooo`3oool00`3oool3000000l0oooo00<00000
0?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool07@3oool3000000P0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`060?ooo`<000002P3oool300000180oooo0P00000A0?oo
o`<000002`3oool3000001h0oooo0`0000070?ooo`<000005@3oool00`000000oooo0?ooo`060?oo
o`<000002P3oool300000180oooo0P00000B0?ooo`030000003oool0oooo00X0oooo0`0000080?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool3000000/0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0503oool004X0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00H0oooo0`00000D0?ooo`<00000203oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool3000000P0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool01@3oool3000000`0oooo00<000000?ooo`3oool01P3oool3000001@0oooo0`0000080?ooo`03
0000003oool0oooo00T0oooo0`0000080?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0503oool004X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0140oooo0`0000080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01d0oooo0`00000C0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool04@3oool3000002/0oooo0`0000080?ooo`030000
003oool0oooo01d0oooo0`00000B0?ooo`<000001`3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`<00000
4`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
503oool004X0oooo00<000000?ooo`3oool06P3oool3000000T0oooo0`00000C0?ooo`030000003o
ool0oooo00H0oooo1000000P0?ooo`<000007@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0140oooo0`0000090?ooo`<000004`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool04@3oool3000000P0oooo0`00000=0?ooo`030000003o
ool0oooo01@0oooo001:0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0L0?ooo`@000007`3oool2000001d0oooo0`00000O0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool06`3oool00`000000oooo00000002000001h0oooo0P00000N
0?ooo`<00000:P3oool3000001l0oooo0`00000M0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01@0oooo001:0?oo
o`030000003oool0oooo04P0oooo0P00000N0?ooo`<000007P3oool2000004P0oooo0`000000103o
ool0000000000000000L0?ooo`@000007P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`0000000P00000M0?ooo`<00000>@3oool00`000000oooo0?ooo`0D
0?ooo`00BP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02L0oooo1000000L0?oo
o`<000007`3oool3000002/0oooo00<000000?ooo`3oool06P3oool01@000000oooo0000003oool0
000001h0oooo0P00000P0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool06@3oool5
000001l0oooo0`00000O0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0503oool0
04X0oooo00<000000?ooo`3oool0703oool3000000T0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`050?ooo`@000007@3oool200000240oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`070?ooo`@00000703oool300000400oooo0`00000O0?ooo`030000003oool0oooo
00L0oooo1000000K0?ooo`030000003oool000000240oooo00<000000?ooo`3oool07@3oool30000
00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo1000000C0?ooo`<000001`3oool00`000000
oooo0?ooo`0L0?ooo`<00000;@3oool00`000000oooo0?ooo`0A0?ooo`<000001`3oool4000001@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000C0?ooo`<000001`3oool4000001@0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`060?ooo`030000003oool000000080
00002`3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`0U0?ooo`@00000
5@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
:P3oool4000001<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`<00000
7`3oool00`000000oooo0?ooo`040?ooo`<00000:`3oool5000001<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0C0?ooo`<000007`3oool00`000000oooo0?ooo`0A0?ooo`040000
003oool0oooo000001`0oooo0`0000000`3oool000000?ooo`0;0?ooo`030000003oool0oooo01@0
oooo001:0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0=03oool3000001D0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`@00000=@3oool00`000000oooo
0?ooo`0M0?ooo`<000001P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000T0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0000000e0?ooo`030000003oool0oooo01d0oooo
0`0000060?ooo`030000003oool0oooo00P0oooo1P00000L0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo0180oooo100000070?ooo`<000001`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0140oooo1@0000070?ooo`<000007`3oool00`000000oooo0?oo
o`0m0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool3000000X0oooo
00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01@0
oooo001:0?ooo`<000004@3oool3000001l0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0K0?ooo`@000002@3oool00`000000oooo0?ooo`050?ooo`<000005@3oool3000001l0oooo
00<000000?ooo`3oool07@3oool4000001d0oooo00<000000?ooo`0000002@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo01D0oooo0`00000O0?ooo`800000703oool600000100oooo
00<000000?ooo`3oool05@3oool300000200oooo0`00000F0?ooo`00BP3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo01d0oooo0`00000M0?ooo`@000007@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool07@3oool3000001d0oooo1000
000a0?ooo`<000005`3oool2000001d0oooo1@00000L0?ooo`040000003oool00000000002X0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool4000001`0oooo1@00
000O0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0L0?ooo`@000007@3oool3000001l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01H0oooo0`00000K0?ooo`D000007P3oool3000001l0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0503oool004X0oooo00<000000?ooo`3oool04@3oool3000000D0oooo0`00000<
0?ooo`030000003oool0oooo00D0oooo1000000E0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`0000002P3oool00`000000oooo0?ooo`0B0?ooo`<000002@3oool00`000000oooo0?ooo`0B
0?ooo`<00000203oool3000000H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`05
0?ooo`@000007`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo0`000009
0?ooo`<000004`3oool00`000000oooo0?ooo`070?ooo`030000003oool0000001@0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool04P3oool3000000P0oooo0`0000050?ooo`<00000303oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`0000001`3oool010000000oooo0?ooo`0000090?ooo`<000001`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00L0oooo0`00000C0?ooo`<000002@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00L0oooo0`0000090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo000000060?ooo`<0000000<0oooo0000003oool0203oool3
000000L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0180oooo0`0000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo0`0000070?ooo`<000001`3oool0
10000000oooo0?ooo`0000090?ooo`<00000503oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0180oooo0`0000090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo000000070?ooo`040000003oool0oooo000000T0oooo0`00000<0?ooo`030000
003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo00l0oooo0`00000:0?ooo`<000002@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool00000008000002@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00L0oooo0`00000D0?ooo`030000003oool0oooo00L0oooo0`00
000A0?ooo`<00000203oool00`000000oooo00000002000000T0oooo00<000000?ooo`3oool04P3o
ool3000000P0oooo0`00000D0?ooo`030000003oool0oooo00L0oooo0`00000B0?ooo`030000003o
ool0oooo00T0oooo0`0000080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3o
ool6000000T0oooo00<000000?ooo`3oool04P3oool3000000P0oooo0`00000D0?ooo`030000003o
ool0oooo00L0oooo0`00000A0?ooo`<000002P3oool3000000T0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool06P3oool3000000030?ooo`000000oooo02X0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0K0?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0@0?ooo`<000002`3oool00`000000oooo0?oo
o`0J0?ooo`040000003oool0oooo00000200oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0503oool004X0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0o0?ooo`<00000B@3oool300000200oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo01h0oooo0`00
00150?ooo`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo05`0oooo0P00000P
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool07P3oool3000006T0oooo0`00000P
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0503oool004X0oooo00<000000?oo
o`3oool0F`3oool4000006`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000001[0?oo
o`<00000IP3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo01d0oooo0P00001/0?ooo`<00000703oool3000004`0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool0503oool004X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0M0?ooo`<00000
?`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`1:0?ooo`<00000?P3oool3000002/0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`0J0?ooo`<000007`3o
ool00`000000oooo0?ooo`0m0?ooo`<00000:P3oool3000005l0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0:@3o
ool3000001T0oooo00<000000?ooo`3oool0503oool004X0oooo0`00000?0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0G@3oool3000000T0oooo0`00001/0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0F0?ooo`<000005P3oool0
04X0oooo00<000000?ooo`3oool03P3oool3000007L0oooo0`00000C0?ooo`030000003oool0oooo
05D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0E@3oool300000180oooo0`00000U0?ooo`030000003oool0oooo
01@0oooo001:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04@3oool3000005D0
oooo0`00000c0?ooo`<00000=P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo
0?ooo`0_0?ooo`<000005@3oool00`000000oooo0?ooo`0M0?ooo`<00000=03oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo03@0oooo0`00001K0?ooo`030000003oool0oooo01@0oooo
001:0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool04`3oool3000000P0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00L0oooo0`00
000C0?ooo`<00000K03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`0D0?ooo`00BP3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01P3oool300000600oooo0`000009
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1O
0?ooo`<000001`3oool300000680oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0D
0?ooo`00BP3oool00`000000oooo0?ooo`0U0?ooo`<00000:@3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0X0?oo
o`<00000@03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01d0oooo0`00000>0?oo
o`030000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0B03oool3000001h0oooo0`00001;0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool07@3oool3000004T0oooo0`00000O0?ooo`<000007`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo01@0oooo001:0?ooo`030000003oool0oooo0740oooo0`00000O0?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool07@3oool3000001l0oooo00<000000?ooo`3oool0
B@3oool2000001h0oooo0`00000`0?ooo`030000003oool0oooo01@0oooo000h0?ooo`030=nLB000
0000000000<0000000<0B9cO0?ooo`3oool02@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`<000007`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01d0oooo0`00000O0?ooo`030000003o
ool0oooo01d0oooo0`00000O0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07@3o
ool3000001h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo01@0oooo000i0?ooo`030?noM000M;l0oooo0080oooo00<0_gAd0;ooo`3oool02@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo0`00000:0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0203oool3000003l0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0B0?ooo`<00000203oool3000001@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04P3oool3
000000P0oooo0`00000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0A0?ooo`<000003`3oool00`000000oooo0?ooo`0D0?ooo`00>P3oool00`3o
_g@007Bo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo0`0000080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool3000000P0oooo00<000000?ooo`3oool01`3oool30000
00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`<000002@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`070?ooo`<00000503oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`<000002@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`070?ooo`<00000503oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0180oooo0`0000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0D0?ooo`00>`3oool00`3o_g@007Bo0?ooo`0<0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool01P3oool3000001D0oooo00<000000?ooo`3oool01P3oool3000000T0
oooo00<000000?ooo`3oool04P3oool3000000P0oooo0`00000C0?ooo`<00000203oool3000001@0
oooo00<000000?ooo`3oool01`3oool3000001h0oooo0`0000090?ooo`030000003oool0oooo0180
oooo0`0000080?ooo`<000004`3oool3000000P0oooo0`00000D0?ooo`030000003oool0oooo00L0
oooo0`00000N0?ooo`<000002@3oool00`000000oooo0?ooo`0B0?ooo`<00000203oool3000001@0
oooo00<000000?ooo`3oool01`3oool3000001T0oooo00<000000?ooo`3oool0503oool003`0oooo
00<0okmd04RLg`3oool02`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0D0?ooo`00?@3oool00`3OW4P0B9cO0?oo
o`0:0?ooo`@00000o`3ooonn0?ooo`@000005P3oool003h0oooo00<0_g@007Boo`3oool02@3oool0
0`000000oooo0?ooo`3o0?oool80oooo00<000000?ooo`3oool0503oool003h0oooo00<0omnL04P0
M02oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06T0oooo00<000000?oo
o`3oool0J@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo06T0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0D0?ooo`00?P3oool00`3ooml0W4P007Boo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01@0oooo000n0?ooo`030?oo_`1d0000B9cO00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
503oool003X0oooo00L0okmd0018W03Oool0oooo0=nLB00004P0W=oo00T0ooooo`000036000001H0
oooo000k0?ooo`050?oOW018000000000000001d_ol0o`3ooooV0?ooo`00o`3ooooo0?ooobL0oooo
003o0?ooool0oooo9`3oool00?l0ooooo`3ooolW0?ooo`00o`3ooooo0?ooobL0oooo003o0?ooool0
oooo9`3oool00001\
\>"],
  ImageRangeCache->{{{0, 548.563}, {338.625, 0}} -> {-157.663, -2.85875, \
2.77513, 0.0222974}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[First /@ Take[pts, {1, Length[pts], 9}], Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<k\>", \*"\"\<\!\(x\_\(6  k\)\)\>\""}];\)\)], \
"Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.0107009 0.255036 0.25547 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.23783 -0.0125 -8 -15.6875 ]
[.23783 -0.0125 8 0 ]
[.45185 -0.0125 -8 -15.6875 ]
[.45185 -0.0125 8 0 ]
[.66586 -0.0125 -8 -15.6875 ]
[.66586 -0.0125 8 0 ]
[.87988 -0.0125 -8 -15.6875 ]
[.87988 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4.9375 -31.375 ]
[.5 -0.0125 4.9375 -15.6875 ]
[-0.0125 .1273 -27.6875 -7.84375 ]
[-0.0125 .1273 0 7.84375 ]
[-0.0125 .25504 -10 -7.84375 ]
[-0.0125 .25504 0 7.84375 ]
[-0.0125 .38277 -19 -7.84375 ]
[-0.0125 .38277 0 7.84375 ]
[-0.0125 .51051 -10 -7.84375 ]
[-0.0125 .51051 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -43.375 -10.125 ]
[-0.01875 .30902 -27.6875 10.125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.23783 0 m
.23783 .00625 L
s
gsave
.23783 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.45185 0 m
.45185 .00625 L
s
gsave
.45185 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.66586 0 m
.66586 .00625 L
s
gsave
.66586 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.87988 0 m
.87988 .00625 L
s
gsave
.87988 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.125 Mabswid
.07731 0 m
.07731 .00375 L
s
.13082 0 m
.13082 .00375 L
s
.18432 0 m
.18432 .00375 L
s
.29133 0 m
.29133 .00375 L
s
.34484 0 m
.34484 .00375 L
s
.39834 0 m
.39834 .00375 L
s
.50535 0 m
.50535 .00375 L
s
.55886 0 m
.55886 .00375 L
s
.61236 0 m
.61236 .00375 L
s
.71937 0 m
.71937 .00375 L
s
.77287 0 m
.77287 .00375 L
s
.82638 0 m
.82638 .00375 L
s
.93339 0 m
.93339 .00375 L
s
.98689 0 m
.98689 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65.9375 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
68.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .1273 m
.00625 .1273 L
s
gsave
-0.0125 .1273 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .25504 m
.00625 .25504 L
s
gsave
-0.0125 .25504 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .38277 m
.00625 .38277 L
s
gsave
-0.0125 .38277 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .51051 m
.00625 .51051 L
s
gsave
-0.0125 .51051 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02511 m
.00375 .02511 L
s
0 .05066 m
.00375 .05066 L
s
0 .07621 m
.00375 .07621 L
s
0 .10175 m
.00375 .10175 L
s
0 .15285 m
.00375 .15285 L
s
0 .1784 m
.00375 .1784 L
s
0 .20394 m
.00375 .20394 L
s
0 .22949 m
.00375 .22949 L
s
0 .28058 m
.00375 .28058 L
s
0 .30613 m
.00375 .30613 L
s
0 .33168 m
.00375 .33168 L
s
0 .35722 m
.00375 .35722 L
s
0 .40832 m
.00375 .40832 L
s
0 .43386 m
.00375 .43386 L
s
0 .45941 m
.00375 .45941 L
s
0 .48496 m
.00375 .48496 L
s
0 .53605 m
.00375 .53605 L
s
0 .5616 m
.00375 .5616 L
s
0 .58715 m
.00375 .58715 L
s
0 .61269 m
.00375 .61269 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -106.656 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
71.125 11.8438 translate
90 rotate
-71.125 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 17.688 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
73.000 17.688 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
74.563 17.688 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
79.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.23783 .61178 m
.23783 .61803 L
s
.45185 .61178 m
.45185 .61803 L
s
.66586 .61178 m
.66586 .61803 L
s
.87988 .61178 m
.87988 .61803 L
s
.125 Mabswid
.07731 .61428 m
.07731 .61803 L
s
.13082 .61428 m
.13082 .61803 L
s
.18432 .61428 m
.18432 .61803 L
s
.29133 .61428 m
.29133 .61803 L
s
.34484 .61428 m
.34484 .61803 L
s
.39834 .61428 m
.39834 .61803 L
s
.50535 .61428 m
.50535 .61803 L
s
.55886 .61428 m
.55886 .61803 L
s
.61236 .61428 m
.61236 .61803 L
s
.71937 .61428 m
.71937 .61803 L
s
.77287 .61428 m
.77287 .61803 L
s
.82638 .61428 m
.82638 .61803 L
s
.93339 .61428 m
.93339 .61803 L
s
.98689 .61428 m
.98689 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .1273 m
1 .1273 L
s
.99375 .25504 m
1 .25504 L
s
.99375 .38277 m
1 .38277 L
s
.99375 .51051 m
1 .51051 L
s
.125 Mabswid
.99625 .02511 m
1 .02511 L
s
.99625 .05066 m
1 .05066 L
s
.99625 .07621 m
1 .07621 L
s
.99625 .10175 m
1 .10175 L
s
.99625 .15285 m
1 .15285 L
s
.99625 .1784 m
1 .1784 L
s
.99625 .20394 m
1 .20394 L
s
.99625 .22949 m
1 .22949 L
s
.99625 .28058 m
1 .28058 L
s
.99625 .30613 m
1 .30613 L
s
.99625 .33168 m
1 .33168 L
s
.99625 .35722 m
1 .35722 L
s
.99625 .40832 m
1 .40832 L
s
.99625 .43386 m
1 .43386 L
s
.99625 .45941 m
1 .45941 L
s
.99625 .48496 m
1 .48496 L
s
.99625 .53605 m
1 .53605 L
s
.99625 .5616 m
1 .5616 L
s
.99625 .58715 m
1 .58715 L
s
.99625 .61269 m
1 .61269 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .25504 m
1 .25504 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.03451 .25504 Mdot
.04521 .43716 Mdot
.05591 .54285 Mdot
.06661 .60305 Mdot
.07731 .59606 Mdot
.08801 .49815 Mdot
.09872 .35063 Mdot
.10942 .22067 Mdot
.12012 .03225 Mdot
.13082 .27891 Mdot
.14152 .47191 Mdot
.15222 .55928 Mdot
.16292 .60332 Mdot
.17362 .58921 Mdot
.18432 .4715 Mdot
.19502 .30331 Mdot
.20572 .21096 Mdot
.21643 .06079 Mdot
.22713 .30688 Mdot
.23783 .50175 Mdot
.24853 .57263 Mdot
.25923 .60171 Mdot
.26993 .57972 Mdot
.28063 .442 Mdot
.29133 .25384 Mdot
.30203 .20492 Mdot
.31273 .09929 Mdot
.32343 .3379 Mdot
.33414 .52686 Mdot
.34484 .58321 Mdot
.35554 .59821 Mdot
.36624 .56723 Mdot
.37694 .41035 Mdot
.38764 .20362 Mdot
.39834 .20194 Mdot
.40904 .14438 Mdot
.41974 .37059 Mdot
.43044 .54753 Mdot
.44114 .59133 Mdot
.45185 .59273 Mdot
.46255 .55129 Mdot
.47325 .37743 Mdot
.48395 .15425 Mdot
.49465 .20167 Mdot
.50535 .1933 Mdot
.51605 .40361 Mdot
.52675 .56424 Mdot
.53745 .59724 Mdot
.54815 .58508 Mdot
.55886 .53146 Mdot
.56956 .34457 Mdot
.58026 .10816 Mdot
.59096 .20407 Mdot
.60166 .24345 Mdot
.61236 .43556 Mdot
.62306 .57737 Mdot
.63376 .60112 Mdot
.64446 .57507 Mdot
.65516 .50743 Mdot
.66586 .31327 Mdot
.67657 .0683 Mdot
.68727 .20937 Mdot
.69797 .29274 Mdot
.70867 .46525 Mdot
.71937 .58734 Mdot
.73007 .60309 Mdot
.74077 .56252 Mdot
.75147 .4791 Mdot
.76217 .28502 Mdot
.77287 .03783 Mdot
.78357 .218 Mdot
.79428 .33957 Mdot
.80498 .49194 Mdot
.81568 .59458 Mdot
.82638 .60326 Mdot
.83708 .54726 Mdot
.84778 .44645 Mdot
.85848 .26077 Mdot
.86918 .01939 Mdot
.87988 .23051 Mdot
.89058 .38312 Mdot
.90128 .51544 Mdot
.91199 .5995 Mdot
.92269 .6016 Mdot
.93339 .52905 Mdot
.94409 .40951 Mdot
.95479 .241 Mdot
.96549 .01472 Mdot
.97619 .24729 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{439.75, 271.813},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:C0001Ub000`400?l00000o`00003oo`3ooooo
0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo
003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooof/0
oooo00P0_g@0001d_`3oool0oooo0?noM0000000001d0;ooool0oooo8P3oool00?l0ooooJ`3oool0
203o_g@0001d0;ooo`3oool0_g@0001d_`3ookl0M7Boo`3ooolR0?ooo`00o`3ooom[0?ooo`060?oO
W01804P0W=oo0?oog`2LB000B9cOo`3ooolT0?ooo`00o`3ooom[0?ooo`060?oog`2LB00004Qd0;no
W01804P0W=ooo`3ooolT0?ooo`00o`3ooom/0?ooo`050=nLB000B7@0M4P00000M02oool0o`3ooolT
0?ooo`00o`3ooom/0?ooo`050?noM00007@0_ooo0;md001d_ol0o`3ooolT0?ooo`00o`3ooom/0?oo
o`060?oo_`1d0000M;oo0?ooo`2oM4P0W=ooo`3ooolS0?ooo`00o`3ooom]0?ooo`040;md0000M;l0
oono07@00080000000<007Bo0?ooo`3oool0o`3ooolO0?ooo`00o`3ooom]0?ooo`030?noM000B9`0
gooo0?l0oooo9@3oool00?l0ooooK@3oool00`3ogi`0B01809cOo`3o0?ooobD0oooo003o0?ooofd0
oooo00<0oooO09a80018W=l0o`3ooolU0?ooo`00o`3ooom^0?ooo`030;md0000M;l0oooo0?l0oooo
903oool00?l0ooooK03oool01@3ooml0W4P00000000007@0_ooo0?l0oooo903oool00?l0ooooo`3o
oonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00
o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oo
oiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00G@3oool0102oM00000000000
001d_om_0?ooo`030=nLB0000000000000<0000000<0B9cO0?ooo`3oool00P3oool0102oM0000000
0000001d_om^0?ooo`030?oog`2LB000B9cO00D0oooo00@0_g@0000000000000M;ooK03oool01@3o
oml0W4P000000000000007Bo00D0oooo00@0_g@0000000000000M;ooK03oool01P3ookl0M0000000
0000000004RL0=ooo`@0oooo00@0_g@0000000000000M;ooAP3oool005`0oooo00H0gia8001d_`3o
ool0omnL04P00018W=m_0?ooo`030?noM000M;l0oooo0080oooo00X0_gAd0;ooo`3oool0oooo0=nL
B000M;l0oooo0?oOW0180000B9cOKP3oool00`3OW4P004RL0=ooo`030?ooo`060=nLB000M;l0oooo
0?oOW0180000B9cOJ`3oool01`3OW4P007Bo0?ooo`3ookl0M0000018W03Oool00P3oool01P3OW4P0
07Bo0?ooo`3ogi`0B00004RLgfX0oooo00<0oono07@00018W=l00P3oool00`3OW4P0001d0;ooo`02
0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cOA@3oool005/0oooo00<0oooO09a80018W=l00P3o
ool00`3o_g@0001809cOo`1_0?ooo`030?noM000M;l0oooo00@0oooo00<0oooO09a80018W=l00P3o
ool00`3o_g@0001809cOo`1]0?ooo`030?oOW01804P0W=oo0080oooo00<0oooO09a80018W=l00P3o
ool00`3o_g@0001809cOo`1Y0?ooo`030?oog`2LB000M;oo0080oooo00L0omnL04P00018W=l0oooo
0?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0J@3oool00`3o_g@004RL0=ooo`030?ooo`06
0;md0018W=l0oooo0?oog`2LB000B9cO0P3oool00`3o_g@0001809cOo`140?ooo`00F`3oool00`3o
oml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooofl0oooo00<0okmd001d_`3oool00`3oool0
0`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooofP0oooo00<0okmd0000000000001000
00001@00B9`0gooo0?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0goooJ03oool00`3ookl0
M00007Boo`030?ooo`060;md000007@0_ooo0?oog`2LB000B9cO0P3oool0103ooml0W4P00018W03O
oomX0?ooo`030?noM000B9`0gooo00<0oooo00H0_g@0001d_`3oool0oooO09a80018W=l20?ooo`04
0?oog`2LB00004RL0=oood<0oooo001K0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02L
gol0L03oool00`3o_g@0B9cO0?ooo`020?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02L
gol0J03oool00`3ooml0W4Q809cOo`020?ooo`070;md0000M;l0oooo0?ooo`3ooml0W4P0001d_`03
0?ooo`030=nLB00004P0W=oo06P0oooo00<0oooO09a80000M;l00`3oool01P3OW4P0001809cOo`3o
oml0W4P0001d_`<0oooo00<0gia80000B02Lgol0J03oool00`3ooml0W4P007Boo`020?ooo`070?oo
_`1d0000B9cO0?ooo`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo04<0oooo001L0?ooo`03
0;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0L@3oool00`3OW4P0B9cO0?ooo`020?ooo`03
0;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0J@3oool01`3ookl0M01d0;ooo`3oool0okmd
0018W03Oool00P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO06T0oooo00<0_g@0
0000M02oool00P3oool01`3OW4P0001809cOo`3oool0_g@00018W03Oool00P3oool00`3ogi`0B000
04RLg`1Z0?ooo`060;md000004P0W=oO09a8000007@0_ooo0P3oool00`2oM00004RL0=ooo`020?oo
o`030?oOW0180000B9cO04<0oooo001L0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000
M;l0LP3oool01`2oM000M;oo0?ooo`3oool0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`1Z
0?ooo`060?oOW018B9`0gooo0?oOW01804P0W=oo0P3oool00`3OW4P0001809cOo`020?ooo`030?oo
g`2LB00007Bo06T0oooo00`0okmd00000018W=l0oooo0?oog`2LB00004RL0=ooo`3oool0gia80000
B02Lgol20?ooo`030?oog`2LB00007Bo06/0oooo00D0oooO09a80000000004RL0=ooo`020?ooo`03
0=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0@`3oool005`0oooo00<0omnL04P00018W=l0
0`3oool00`2oM00004RL0=ooo`1a0?ooo`070?oOW01807@0_ooo0?ooo`3ogi`0B00004RLg`030?oo
o`030;md0000B9`0gooo06X0oooo00D0okmd001d_`3ooml0W4P004RLg`020?ooo`030?oOW0180000
B9cO00<0oooo00<0_g@00018W03Oool0J03oool00`3ooml0W4P000000002000000070000M02oool0
oooo0?ooo`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo06X0oooo00X0_g@00000B02Lgol0
omnL04Q8W03Oool0oooo0?oOW0180000B9cO0`3oool00`2oM00004RL0=ooo`120?ooo`00G03oool0
103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo0740oooo00P0oooO09a8001d_ol0oooo
0?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0J`3oool0103OW4P0B9cO0;md0000M;l2
0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0J@3oool00`3ookl0M000001d
_`050?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0J@3oool00`3ogi`0B000
07Boo`020?ooo`070?noM018W=l0oooo0?oog`2LB00004RL0=ooo`020?ooo`030=nLB000B9`0gooo
0480oooo001M0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0L@3oool00`3ookl0
M00004RLg`020?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0K03oool0103OW4P0
M7Ad0000M02oool20?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0JP3oool00`3o
gi`0B00004RLg`050?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0J@3oool00`3o
gi`0B01809cOo`020?ooo`070?noM000B9`0gooo0?ooo`3ogi`0B00007Boo`020?ooo`030=nLB000
M;l0oooo0480oooo001N0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cOKP3oool01`3o_g@004RL
0=ooo`3oool0gia80000B02Lgol00`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLgfh0oooo00<0
_g@00000B02Lgol00`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLgf`0oooo00@0oooO09a80000
07@0_ooo103oool01P3OW4P0001d0;ooo`3ooml0W4P004RLgfX0oooo00<0oooO09a80018W=l00P3o
ool00`2oM00007Bo0?ooo`020?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO@`3oool005l0oooo
00@0gia800000000000007BoL03oool01@3ogi`0B000000000000000M;oo00D0oooo00@0gia80000
0000000007BoK`3oool00`3ooml0W4P004RLg`040?ooo`040=nLB00000000000001d_fl0oooo00@0
oono07@000000000B9cO0`3oool0103OW4P0000000000000M;m/0?ooo`050?oog`2LB00000000000
0000M;l01@3oool0103OW4P0000000000000M;m40?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0
ooooU@3oool00?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool0
0?l0ooooo`3ooonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3o
oonE0?ooo`00o`3ooooo0?oooiD0oooo003o0?ooool0ooooU@3oool00?l0ooooo`3ooonE0?ooo`00
D@3ooooo00000?l00000?P0000060?ooo`00D@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00@0oooo001A0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`1g0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0oooo
o`3ooolj0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3o
oolj0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooolU
0?ooo`8000004`3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?oo
ool0oooo903oool400000180oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3o
ool0o`3ooooo0?ooob@0oooo1000000B0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000
003oool0oooo0?l0ooook@3oool2000003D0oooo0P00000C0?ooo`030000003oool0oooo00@0oooo
001A0?ooo`030000003oool0oooo0?l0ooook03oool4000004T0oooo00<000000?ooo`3oool0103o
ool00540oooo00<000000?ooo`3oool0o`3oooo/0?ooo`@00000B@3oool00`000000oooo0?ooo`04
0?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooond0oooo0P00001:0?ooo`030000003oool0oooo
00@0oooo001A0?ooo`@00000o`3ooooo0?ooocL0oooo0`0000060?ooo`00D@3oool00`000000oooo
0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?oo
o`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`11
0?ooo`800000o`3oooof0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo
0400oooo1000003o0?ooooD0oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3o
ool0@03oool400000?l0oooom@3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo
0?ooo`110?ooo`800000o`3ooomc0?ooo`800000P@3oool00`000000oooo0?ooo`040?ooo`00D@3o
ool00`000000oooo0?ooo`3o0?oookD0oooo100000200?ooo`030000003oool0oooo00@0oooo001A
0?ooo`030000003oool0oooo0?l0oooo]@3oool400000800oooo00<000000?ooo`3oool0103oool0
0540oooo00<000000?ooo`3oool0o`3ooonf0?ooo`800000P@3oool00`000000oooo0?ooo`040?oo
o`00D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`040?ooo`00
D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`040?ooo`00D@3o
ool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`040?ooo`00D@3oool0
0`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`00
0000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`040?ooo`00D@3oool400000?l0
ooooo`3ooolg0?ooo`<000001P3oool00540oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo
00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo00<0
00000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo00<00000
0?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0N03oool200000?l0oooo_`3oool00`00
0000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`1g0?ooo`@00000o`3ooonn0?ooo`03
0000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo07L0oooo1000003o0?oookh0oooo
00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0N03oool200000?l0oooo_`3o
ool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool0
0`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooh00oooo0P00002g0?oo
o`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooO`3oool400000;H0
oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0o`3ooomo0?ooo`@00000
]P3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooh00oooo0P00
002g0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooolj
0?ooo`030000003oool0oooo00@0oooo001A0?ooo`@00000o`3ooooo0?ooocL0oooo0`0000060?oo
o`00D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`040?ooo`00
D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`040?ooo`00D@3o
ool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`040?ooo`00D@3oool0
0`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`00
0000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000
oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo
0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?oo
o`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o
0?ooool0oooo>P3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?oo
ool0oooo>P3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooool0
oooo>P3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`2_0?ooo`800000
o`3ooon80?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0:h0oooo1000
003o0?ooohL0oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0[P3oool4
00000?l0ooooQ`3oool00`000000oooo0?ooo`040?ooo`00D@3oool400000:h0oooo0P00003o0?oo
ohH0oooo0`0000060?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000
oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooodT0oooo0P00003^0?ooo`030000
003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooB03oool400000>d0oooo00<0
00000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0o`3ooom80?ooo`@00000k@3oool0
0`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooodT0oooo0P00003^0?oo
o`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`03
0000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000
003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003o
ool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0
oooo00@0oooo000c0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol00P3oool0
1P3ogi`0B00000000000000004RL0=ooo``0oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo
00<000000?ooo`3oool0103oool00380oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`03
0?oOW0180000M;oo0080oooo00H0okmd0000001d_ol0oooo0?oOW018M;l<0?ooo`030000003oool0
oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo000a0?ooo`030?oog`2LB000B9cO
0080oooo00<0okmd0000B02Lgol02`3oool00`3o_g@0B9cO0?ooo`0:0?ooo`030000003oool0oooo
0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo000a0?ooo`030?oog`2LB000B9cO0080
oooo00@0oooO09a80000B9`0gooo2P3oool00`3ookl0M01d0;ooo`0:0?ooo`030000003oool0oooo
0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo000T0?ooo`030?oog`2LB000000000L0
000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`030=nLB00004P0W=oo00X0oooo00<0oooO
09a8001d_ol02P3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`04
0?ooo`00<P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00X0oooo00<0oono07@0
0018W=l02P3oool500000?l0ooooo`3ooold0?ooo`D000001P3oool00380oooo00<0gia80000B02L
gol00P3oool00`3ooml0W4P0001d_`0:0?ooo`030?noM0000000M;oo00X0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooocX0oooo00<000000?ooo`3oool0103oool00380oooo00<0omnL04P00018W=l0
0`3oool00`2oM00004RL0=ooo`060?ooo`060?oOg`3Oool0okmd0000000007@0_ooo2P3oool00`00
0000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`040?ooo`00<P3oool0103ooml0
W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00H0oooo00D0oono07@000000000001809cOo`0;
0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo000c0?oo
o`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01`3oool00`3OW9`0_ooo0?ooo`0<0?oo
o`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo000d0?ooo`06
0=nLB00007@0_ooo0?oog`2LB000B9cO203oool00`3ogi`0M9cO0?ooo`0<0?ooo`030000003oool0
oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo000e0?ooo`040=nLB00000000000
001d_`X0oooo00D0_g@0000000000000000004RLg`090?ooo`030000003oool0oooo0?l0ooooo`3o
oolj0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooolj
0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0>H0oooo0P00003o0?oo
oe40oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0i@3oool400000?l0
ooooD03oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3U0?ooo`@00000
o`3ooom@0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0>H0oooo0P00
003o0?oooe40oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0o`3ooooo
0?ooocX0oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0o`3ooooo0?oo
ocX0oooo00<000000?ooo`3oool0103oool00540oooo1000003o0?oooa40oooo0P00003o0?ooob@0
oooo0`0000060?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooa40oooo1000003o0?ooobD0oooo
00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0o`3ooolA0?ooo`@00000o`3o
oolU0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0oooo4P3oool2
00000?l0oooo9P3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?oo
ool0oooo>P3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooool0
oooo>P3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooool0oooo
>P3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3o
ool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool0
0`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`00
0000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000
oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo
0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?oo
o`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`04
0?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`040?oo
o`00D@3oool400000?l0ooooo`3ooolg0?ooo`<000001P3oool00540oooo00<000000?ooo`3oool0
o`3ooooo0?ooocX0oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0o`3o
oooo0?ooocX0oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0o`3ooooo
0?ooocX0oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0o`3ooooo0?oo
ocX0oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0
oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo
00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0o`3ooolN0?ooo`800000o`3o
oolJ0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0oooo7@3oool4
00000?l0oooo6@3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?oo
oad0oooo1000003o0?oooaT0oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3o
ool0o`3ooolN0?ooo`800000o`3ooolJ0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000
003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003o
ool0oooo0>00oooo0P00000e0?ooo`800000o`3ooolP0?ooo`030000003oool0oooo00@0oooo001A
0?ooo`030000003oool0oooo0=X0oooo0P0000030?ooo`@00000<`3oool4000003@0oooo0P00003X
0?ooo`030000003oool0oooo00@0oooo001A0?ooo`@00000Z03oool2000002h0oooo100000020?oo
o`@00000<`3oool4000003<0oooo1000003U0?ooo`<000001P3oool00540oooo00<000000?ooo`3o
ool0Z03oool4000002d0oooo100000030?ooo`800000=@3oool2000003@0oooo1000003W0?ooo`03
0000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0:P0oooo1000000^0?ooo`800000
LP3oool2000003D0oooo0P00002a0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003o
ool0oooo0780oooo0P00000e0?ooo`800000f@3oool400000;00oooo00<000000?ooo`3oool0103o
ool00540oooo00<000000?ooo`3oool0L@3oool400000?l0oooo403oool400000;00oooo00<00000
0?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0L@3oool400000?l0oooo4@3oool20000
0;40oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0LP3oool200000?l0
ooooa@3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?oookd0oooo
0P00001j0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0oooo_03o
ool4000007T0oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0>`3oool2
00000?l0ooooO`3oool4000007T0oooo00<000000?ooo`3oool0103oool00540oooo00<000000?oo
o`3oool0>P3oool400000?l0ooooO`3oool2000007X0oooo00<000000?ooo`3oool0103oool00540
oooo00<000000?ooo`3oool0>P3oool400000?l0oooon`3oool00`000000oooo0?ooo`040?ooo`00
D@3oool00`000000oooo0?ooo`0k0?ooo`800000o`3ooool0?ooo`030000003oool0oooo00@0oooo
001A0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo001A
0?ooo`030000003oool0oooo0?l0oooom03oool2000004<0oooo00<000000?ooo`3oool0103oool0
0540oooo1000003o0?oooo80oooo100000100?ooo`<000001P3oool00540oooo00<000000?ooo`3o
ool0o`3ooooc0?ooo`@00000@P3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo
0?ooo`3o0?oooo@0oooo0P0000130?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0
oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo
0?l0ooooo`3ooolO0?ooo`8000006@3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000
oooo0?ooo`3o0?ooool0oooo7P3oool4000001P0oooo00<000000?ooo`3oool0103oool00540oooo
00<000000?ooo`3oool0o`3ooomE0?ooo`800000aP3oool4000001P0oooo00<000000?ooo`3oool0
103oool00540oooo00<000000?ooo`3oool0o`3ooomD0?ooo`@00000aP3oool2000001T0oooo00<0
00000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0o`3ooomD0?ooo`@00000dP3oool2
000000d0oooo00<000000?ooo`3oool0103oool00400oooo00@0_g@0000000000000M;oo3@3oool0
0`000000oooo0?ooo`3o0?oooeD0oooo0P00003B0?ooo`@00000303oool00`000000oooo0?ooo`04
0?ooo`00?`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg``0oooo00<000000?ooo`3oool0o`3o
oooo0?ooobX0oooo1000000<0?ooo`030000003oool0oooo00@0oooo000n0?ooo`030?oog`2LB000
B9cO0080oooo00<0okmd0000B02Lgol02`3oool00`000000oooo0?ooo`3o0?ooool0oooo:`3oool2
000000d0oooo00<000000?ooo`3oool0103oool003h0oooo00<0oooO09a80018W=l00P3oool0103o
oml0W4P00018W03Oool:0?ooo`030000003oool0oooo0100oooo0P00002A0?ooo`800000o`3ooonD
0?ooo`030000003oool0oooo00@0oooo000n0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000
B02Lgol02P3ooooo00000?l00000?P0000060?ooo`00?`3oool00`2oM00004RL0=ooo`020?ooo`03
0?oOW0180000B9cO00X0oooo00<000000?ooo`3oool03`3oool4000008l0oooo1000003o0?oooi<0
oooo00<000000?ooo`3oool0103oool003l0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0
001d_`0:0?ooo`030000003oool0oooo0100oooo0P00002A0?ooo`800000o`3ooom20?ooo`800000
D03oool00`000000oooo0?ooo`040?ooo`00?`3oool00`3ogi`0B00004RLg`030?ooo`030;md0000
B9`0gooo00T0oooo00<000000?ooo`3oool0o`3ooooV0?ooo`@00000C`3oool00`000000oooo0?oo
o`040?ooo`00?`3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00T0oooo00<0
00000?ooo`3oool0o`3ooooV0?ooo`@00000C`3oool00`000000oooo0?ooo`040?ooo`00@03oool0
0`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00T0oooo00<000000?ooo`3oool0o`3ooooW
0?ooo`800000D03oool00`000000oooo0?ooo`040?ooo`00@@3oool01P3OW4P0001d0;ooo`3ooml0
W4P004RLg`X0oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo00<000000?ooo`3oool0103o
ool00480oooo00@0gia800000000000007Bo2`3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3o
ool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool0
0`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`00
0000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000
oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo
0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?oo
o`040?ooo`00D@3oool00`000000oooo0?ooo`170?ooo`800000o`3oooo`0?ooo`030000003oool0
oooo00@0oooo001A0?ooo`030000003oool0oooo04H0oooo1000003o0?ooonl0oooo00<000000?oo
o`3oool0103oool00540oooo100000150?ooo`@00000o`3oooo]0?ooo`<000001P3oool00540oooo
00<000000?ooo`3oool0A`3oool200000?l0ooooI`3oool2000008L0oooo00<000000?ooo`3oool0
103oool00540oooo00<000000?ooo`3oool0o`3ooon_0?ooo`@00000QP3oool00`000000oooo0?oo
o`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooojl0oooo100000260?ooo`030000003oool0
oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0oooo/03oool2000008L0oooo00<000000?oo
o`3oool0103oool001D0oooo00<0gia80000M02oool0>@3oool00`000000oooo0?ooo`3o0?ooool0
oooo>P3oool00`000000oooo0?ooo`040?ooo`003P3oool00`3ookl0M7Bo0?ooo`040?ooo`030?oo
_`1dB9`0gooo03T0oooo00<000000?ooo`3oool0o`3ooon<0?ooo`800000Z`3oool00`000000oooo
0?ooo`040?ooo`003P3oool00`3ogi`0B01d0;ooo`030?ooo`030?noM00007@0_ooo03X0oooo00<0
00000?ooo`3oool0o`3ooon;0?ooo`@00000ZP3oool00`000000oooo0?ooo`040?ooo`003P3oool0
1`3ogi`0B0000000000004P0W=oo0?oOW018M;l0?03oool00`000000oooo0?ooo`3o0?oooh/0oooo
1000002Z0?ooo`030000003oool0oooo00@0oooo000@0?ooo`030?oo_`1d000000000080000000<0
M;oo0?ooo`3oool0>@3oool00`000000oooo0?ooo`3o0?oooh`0oooo0P00002[0?ooo`030000003o
ool0oooo00@0oooo000?0?ooo`090?oo_`1d07@0_ooo0?ooo`3ooml0W4P00000000007@0_ooo03T0
oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo00<000000?ooo`3oool0103oool000h0oooo
00<0oono07@0M02oool0103oool00`3ogi`0B7Bo0?ooo`0i0?ooo`030000003oool0oooo0?l0oooo
o`3ooolj0?ooo`030000003oool0oooo00@0oooo000>0?ooo`030?noM0000000M;oo00<0oooo00<0
oono07A8W03Oool0>P3oool00`000000oooo0?ooo`1/0?ooo`800000o`3oooo;0?ooo`030000003o
ool0oooo00@0oooo001A0?ooo`030000003oool0oooo06/0oooo1000003o0?ooolX0oooo00<00000
0?ooo`3oool0103oool001D0oooo00D0_g@0000000000000000007Boo`0g0?ooo`030000003oool0
oooo06/0oooo1000000?0?ooo`800000o`3oooni0?ooo`030000003oool0oooo00@0oooo000C0?oo
o`040?oOW0180000001d0;ooo`80oooo00<0_gAd0;ooo`3oool0=@3oool4000006/0oooo0P00000?
0?ooo`@00000o`3ooonf0?ooo`<000001P3oool00180oooo00@0omnL04P0B01dW;l0gooo0`3oool0
0`2oM7@0_ooo0?ooo`0e0?ooo`030000003oool0oooo07d0oooo1000003o0?oookP0oooo00<00000
0?ooo`3oool0103oool00140oooo00D0oooO09a8M02oool0_gAd0;ooo`020?ooo`030;md0018W=l0
oooo03H0oooo00<000000?ooo`3oool0OP3oool200000?P0oooo0P00002n0?ooo`030000003oool0
oooo00@0oooo000A0?ooo`050?noM01d_ol0oooo0?oOW01800000P0000000`1d_ol0oooo0?ooo`0f
0?ooo`030000003oool0oooo0?l0ooooN03oool400000;d0oooo00<000000?ooo`3oool0103oool0
0140oooo00<0gibL0;ooo`3oool0?@3oool00`000000oooo0?ooo`3o0?ooogP0oooo1000002m0?oo
o`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooN@3oool200000;h0
oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo
00<000000?ooo`3oool0103oool001L0oooo00@0okmd0000000007@0_ooo=P3oool00`000000oooo
0?ooo`3o0?ooool0oooo>P3oool00`000000oooo0?ooo`040?ooo`00403oool0103ooml0W9bo0?oo
g`2LB00300000003001d_`3oool0oooo03L0oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo
00<000000?ooo`3oool0103oool00100oooo00@0oono07@0000004P0W=oo0P3oool00`2oW9`0gooo
0?ooo`0h0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo
000D0?ooo`050=oOg`2oM000000000000000M;l0>03oool00`000000oooo0?ooo`3o0?ooool0oooo
>P3oool00`000000oooo0?ooo`040?ooo`004`3oool00`3ooml0W4P007Boo`020?ooo`030=nLB000
07@0_ooo03H0oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo00<000000?ooo`3oool0103o
ool001<0oooo00<0oooO09adW03Oool00P3oool00`3OW7@0W=oo0?ooo`0f0?ooo`030000003oool0
oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo
0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo001A0?ooo`@00000o`3ooooo0?ooocL0
oooo0`0000060?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00`000000oooo
0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`2e0?ooo`800000o`3ooon20?ooo`030000003o
ool0oooo00@0oooo001A0?ooo`030000003oool0oooo0;@0oooo1000003o0?ooo`/0oooo0P00001d
0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0;@0oooo1000003o0?oo
o`X0oooo1000001c0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0;D0
oooo0P00003o0?ooo`/0oooo1000001c0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000
003oool0oooo0?l0oooo@`3oool2000007h0oooo0P00001d0?ooo`030000003oool0oooo00@0oooo
001A0?ooo`030000003oool0oooo0?l0oooo@P3oool400000?<0oooo00<000000?ooo`3oool0103o
ool00540oooo00<000000?ooo`3oool0o`3ooom20?ooo`@00000l`3oool00`000000oooo0?ooo`04
0?ooo`00D@3oool00`000000oooo0?ooo`3o0?oood<0oooo0P00003d0?ooo`030000003oool0oooo
00@0oooo001A0?ooo`030000003oool0oooo03D0oooo0P00003o0?ooool0oooo0`3oool00`000000
oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`0d0?ooo`@00000o`3ooooo0?ooo`80oooo
00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0=03oool400000?l0ooooo`3o
ool20?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo03D0oooo0P00003o
0?ooool0oooo0`3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?oo
ool0oooo>P3oool00`000000oooo0?ooo`040?ooo`00D@3oool400000?l0ooooo`3ooolg0?ooo`<0
00001P3oool00540oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo00<000000?ooo`3oool0
103oool00540oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo00<000000?ooo`3oool0103o
ool00540oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo00<000000?ooo`3oool0103oool0
0540oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo00<000000?ooo`3oool0103oool00540
oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo00<000000?ooo`3oool0103oool00540oooo
00<000000?ooo`3oool0k03oool200000?l0ooooB`3oool00`000000oooo0?ooo`040?ooo`00D@3o
ool00`000000oooo0?ooo`3[0?ooo`@00000o`3ooom:0?ooo`030000003oool0oooo00@0oooo001A
0?ooo`030000003oool0oooo0>/0oooo1000003o0?ooodX0oooo00<000000?ooo`3oool0103oool0
03<0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`060?oOW0180000
000000000000B9`0gooo303oool00`000000oooo0?ooo`3/0?ooo`800000o`3ooom;0?ooo`030000
003oool0oooo00@0oooo000b0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0
B00007Boo`020?ooo`060?noM0000000M;oo0?ooo`3ogi`0B7Bo303oool00`000000oooo0?ooo`3o
0?ooo``0oooo0P00003o0?ooob`0oooo00<000000?ooo`3oool0103oool00340oooo00<0oooO09a8
0018W=l00P3oool00`3o_g@0001809cOo`0;0?ooo`030?noM018W=l0oooo00X0oooo00<000000?oo
o`3oool0o`3oool;0?ooo`@00000o`3oool[0?ooo`030000003oool0oooo00@0oooo000a0?ooo`03
0?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo2P3oool00`3ookl0M01d0;ooo`0:0?oo
o`030000003oool0oooo0?l0oooo2`3oool400000?l0oooo:`3oool00`000000oooo0?ooo`040?oo
o`00<@3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00X0oooo00<0oooO09a8001d
_ol02P3oool00`000000oooo0?ooo`3o0?ooo``0oooo0P00003/0?ooo`800000?@3oool00`000000
oooo0?ooo`040?ooo`00<P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00X0oooo
00<0oono07@00018W=l02P3oool500000?l0oooom`3oool4000003P0oooo1@0000060?ooo`00<P3o
ool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00X0oooo00<0okmd0000001d_ol02P3o
ool00`000000oooo0?ooo`3o0?ooooT0oooo1000000l0?ooo`030000003oool0oooo00@0oooo000b
0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01P3oool01P3ogml0gooo0?noM000
0000001d0;ooo`X0oooo00<000000?ooo`3oool0o`3ooooj0?ooo`800000?@3oool00`000000oooo
0?ooo`040?ooo`00<P3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00H0oooo
00D0oono07@000000000001809cOo`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`03
0000003oool0oooo00@0oooo000c0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0
1`3oool00`3OW9`0_ooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000
003oool0oooo00@0oooo000d0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO203oool00`3ogi`0
M9cO0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0
oooo000e0?ooo`040=nLB00000000000001d_`X0oooo00D0_g@0000000000000000004RLg`090?oo
o`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo001A0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000
003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0
oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo
0?l0oooo903oool200000?l0oooo503oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000
oooo0?ooo`3o0?ooob<0oooo1000003o0?oooa<0oooo00<000000?ooo`3oool0103oool00540oooo
00<000000?ooo`3oool0o`3ooolS0?ooo`@00000o`3ooolC0?ooo`030000003oool0oooo00@0oooo
001A0?ooo`030000003oool0oooo0?l0oooo903oool200000?80oooo0P00000O0?ooo`030000003o
ool0oooo00@0oooo001A0?ooo`@00000d`3oool200000?l0oooo@@3oool4000001`0oooo0`000006
0?ooo`00D@3oool00`000000oooo0?ooo`3C0?ooo`@00000o`3ooom00?ooo`@000007P3oool00`00
0000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3C0?ooo`@00000o`3ooom10?ooo`80
00007`3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3D0?ooo`800000
o`3ooomS0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3o
oolj0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooolj
0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?oo
o`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`03
0000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000
003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003o
ool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0
oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo
00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0
oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo
001A0?ooo`@00000o`3ooomJ0?ooo`800000fP3oool3000000H0oooo001A0?ooo`030000003oool0
oooo01H0oooo0P00003o0?oood80oooo1000003K0?ooo`030000003oool0oooo00@0oooo001A0?oo
o`030000003oool0oooo01D0oooo1000003o0?oood40oooo1000003K0?ooo`030000003oool0oooo
00@0oooo001A0?ooo`030000003oool0oooo01D0oooo1000003o0?oood80oooo0P00003L0?ooo`03
0000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo01H0oooo0P0000250?ooo`800000
o`3ooonJ0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo09`0oooo1000
003o0?oooiT0oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0W03oool4
00000?l0oooo@@3oool2000005H0oooo00<000000?ooo`3oool0103oool00540oooo00<000000?oo
o`3oool0W@3oool200000?l0oooo@@3oool4000005D0oooo00<000000?ooo`3oool0103oool00540
oooo00<000000?ooo`3oool0o`3ooooP0?ooo`@00000E@3oool00`000000oooo0?ooo`040?ooo`00
D@3oool00`000000oooo0?ooo`3o0?ooon40oooo0P00001F0?ooo`030000003oool0oooo00@0oooo
001A0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo001A
0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo001A0?oo
o`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo001A0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000
003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo001A0?ooo`@00000o`3o
oooo0?ooocL0oooo0`0000060?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool0
0`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooi80oooo0P00002U0?oo
o`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooT@3oool400000:@0
oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0o`3ooonA0?ooo`@00000
Y03oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooi80oooo0P00
002U0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo04d0oooo0P00000G
0?ooo`800000o`3ooooA0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo
04`0oooo1000000E0?ooo`@00000o`3oooo@0?ooo`030000003oool0oooo00@0oooo001A0?ooo`03
0000003oool0oooo04`0oooo1000000E0?ooo`@00000o`3oooo@0?ooo`030000003oool0oooo00@0
oooo001A0?ooo`030000003oool0oooo04d0oooo0P00000G0?ooo`800000o`3ooooA0?ooo`030000
003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooZP3oool2000008d0oooo00<0
00000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0o`3ooonY0?ooo`@00000S03oool0
0`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooojT0oooo1000002<0?oo
o`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooZP3oool2000008d0
oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo
00<000000?ooo`3oool0103oool00540oooo1000003o0?ooool0oooo=`3oool3000000H0oooo001A
0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo001A0?oo
o`030000003oool0oooo0?l0oooob@3oool2000006h0oooo00<000000?ooo`3oool0103oool00540
oooo00<000000?ooo`3oool0o`3oooo80?ooo`@00000K@3oool00`000000oooo0?ooo`040?ooo`00
D@3oool00`000000oooo0?ooo`3o0?ooolP0oooo1000001]0?ooo`030000003oool0oooo00@0oooo
001A0?ooo`030000003oool0oooo0?l0oooob@3oool2000006h0oooo00<000000?ooo`3oool0103o
ool00540oooo00<000000?ooo`3oool0;`3oool200000?l0ooooo`3oool90?ooo`030000003oool0
oooo00@0oooo001A0?ooo`030000003oool0oooo02h0oooo1000003o0?ooool0oooo203oool00`00
0000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`0^0?ooo`@00000DP3oool200000?l0
oooo/`3oool00`000000oooo0?ooo`040?ooo`00?P3oool00`3ookl0M000000000020000000304RL
g`3oool0oooo00/0oooo00<000000?ooo`3oool0;`3oool200000580oooo1000003o0?oook80oooo
00<000000?ooo`3oool0103oool00400oooo00<0okmd0000001d_ol03P3oool00`000000oooo0?oo
o`230?ooo`@00000o`3ooonb0?ooo`030000003oool0oooo00@0oooo00100?ooo`030?oog`2LB000
07Bo00h0oooo00<000000?ooo`3oool0Q03oool200000>`0oooo0P0000340?ooo`030000003oool0
oooo00@0oooo00110?ooo`030=nLB000B9`0gooo00d0oooo00<000000?ooo`3oool0o`3ooomb0?oo
o`@00000``3oool00`000000oooo0?ooo`040?ooo`00@@3oool00`3ogi`0B01809cOo`0=0?ooo`03
0000003oool0oooo0?l0ooooLP3oool400000<<0oooo00<000000?ooo`3oool0103oool00440oooo
00<0oono07@0001d_ol03@3oool500000?l0ooooL@3oool200000<00oooo1@0000060?ooo`00@P3o
ool00`2oM00007Bo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003o
ool0oooo00@0oooo00120?ooo`030=nLB000B9`0gooo00`0oooo00<000000?ooo`3oool0o`3ooooo
0?ooo`40oooo0P00000g0?ooo`030000003oool0oooo00@0oooo00120?ooo`030?oOW01804P0W=oo
00`0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`@00000=P3oool00`000000oooo0?ooo`040?oo
o`00@P3oool00`3ookl0M00007Boo`0<0?ooo`030000003oool0oooo0?l0ooooo`3oool4000003H0
oooo00<000000?ooo`3oool0103oool004<0oooo00<0_g@0001d_`3oool02`3oool00`000000oooo
0?ooo`3o0?ooool0oooo0@3oool2000003L0oooo00<000000?ooo`3oool0103oool00440oooo00D0
oono07@000000000001d0;ooo`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000
003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003o
ool0oooo00@0oooo001A0?ooo`030000003oool0oooo0;/0oooo0P00003o0?ooog`0oooo00<00000
0?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0^P3oool400000?l0ooooE03oool20000
02D0oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0^P3oool400000?l0
ooooD`3oool4000002@0oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0
^`3oool2000007h0oooo0P00003C0?ooo`@00000903oool00`000000oooo0?ooo`040?ooo`00D@3o
ool00`000000oooo0?ooo`3o0?oooc/0oooo1000003C0?ooo`8000009@3oool00`000000oooo0?oo
o`040?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooc/0oooo1000003j0?ooo`030000003oool0
oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0oooo?03oool200000?/0oooo00<000000?oo
o`3oool0103oool00540oooo1000003o0?ooool0oooo=`3oool3000000H0oooo001A0?ooo`030000
003oool0oooo0?l0ooooo`3ooolj0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003o
ool0oooo01d0oooo0P00003o0?ooool0oooo6`3oool00`000000oooo0?ooo`040?ooo`00D@3oool0
0`000000oooo0?ooo`0L0?ooo`@00000o`3ooooo0?oooaX0oooo00<000000?ooo`3oool0103oool0
0540oooo00<000000?ooo`3oool0703oool400000?l0ooooo`3ooolJ0?ooo`030000003oool0oooo
00@0oooo001A0?ooo`030000003oool0oooo01d0oooo0P00003C0?ooo`800000iP3oool2000005`0
oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0l@3oool400000>@0oooo
1000001K0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?40oooo1000
000?0?ooo`800000d`3oool4000005/0oooo00<000000?ooo`3oool0103oool00540oooo00<00000
0?ooo`3oool0lP3oool2000000l0oooo1000003C0?ooo`800000G03oool00`000000oooo0?ooo`04
0?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo1000003o0?oooc80oooo00<000000?oo
o`3oool0103oool00540oooo00<000000?ooo`3oool0o`3oool50?ooo`800000o`3ooolc0?ooo`03
0000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`030000
003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo05<0oooo0P00003o0?ooon@0oooo00<0
00000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0DP3oool400000?l0ooooh`3oool0
0`000000oooo0?ooo`040?ooo`00D@3oool400000540oooo1000003o0?ooodh0oooo0P00002A0?oo
o`<000001P3oool00540oooo00<000000?ooo`3oool0D`3oool200000=@0oooo0P00001g0?ooo`@0
0000TP3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`3>0?ooo`800000
F03oool4000007H0oooo1000002B0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003o
ool0oooo0<d0oooo1000001G0?ooo`@00000M`3oool2000009<0oooo00<000000?ooo`3oool0103o
ool00540oooo00<000000?ooo`3oool0c@3oool4000005P0oooo0P00003o0?ooo`h0oooo00<00000
0?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0RP3oool200000480oooo0P00003o0?oo
ofT0oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0R@3oool400000?l0
oooo[03oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`290?ooo`@00000
g`3oool200000<X0oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0RP3o
ool200000=@0oooo0P0000090?ooo`@00000b@3oool00`000000oooo0?ooo`040?ooo`00D@3oool0
0`000000oooo0?ooo`2G0?ooo`800000aP3oool4000000P0oooo100000390?ooo`030000003oool0
oooo00@0oooo001A0?ooo`030000003oool0oooo09H0oooo100000350?ooo`@000002@3oool20000
0<X0oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0UP3oool4000002L0
oooo0P00002M0?ooo`800000eP3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo
0?ooo`2G0?ooo`8000009`3oool400000740oooo0P00003o0?ooo`80oooo00<000000?ooo`3oool0
103oool00540oooo00<000000?ooo`3oool0`03oool400000700oooo1000003o0?ooo`40oooo00<0
00000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0`@3oool200000740oooo1000001O
0?ooo`800000W`3oool00`000000oooo0?ooo`040?ooo`00D@3oool4000005l0oooo0P00003C0?oo
o`800000G`3oool4000009`0oooo0`0000060?ooo`00D@3oool00`000000oooo0?ooo`1O0?ooo`@0
0000U@3oool2000009`0oooo1000002N0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000
003oool0oooo05l0oooo1000002D0?ooo`@000000`3oool2000009L0oooo0P00002O0?ooo`030000
003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo0600oooo0P00002E0?ooo`@000000P3o
ool400000<d0oooo0P00001X0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0
oooo02T0oooo0P00003=0?ooo`8000000`3oool4000002h0oooo0P00002L0?ooo`@00000I`3oool0
0`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`0X0?ooo`@00000V`3oool20000
03D0oooo0P00000^0?ooo`@00000V`3oool4000006L0oooo00<000000?ooo`3oool0103oool00540
oooo00<000000?ooo`3oool0:03oool4000009X0oooo1000001T0?ooo`@00000W03oool2000003D0
oooo0P00000a0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo02T0oooo
0P00001V0?ooo`800000<`3oool4000006D0oooo0P00000e0?ooo`800000W03oool4000000<0oooo
0P00000[0?ooo`030000003oool0oooo00@0oooo001A0?ooo`030000003oool0oooo02<0oooo0P00
000e0?ooo`800000=03oool4000003<0oooo0P00002L0?ooo`@00000=03oool2000003D0oooo0P00
000^0?ooo`@000000P3oool4000002X0oooo00<000000?ooo`3oool0103oool00540oooo00<00000
0?ooo`3oool08P3oool4000003<0oooo1000000c0?ooo`@00000d@3oool4000003<0oooo1000000c
0?ooo`@00000;P3oool2000000<0oooo1000000Z0?ooo`030000003oool0oooo00@0oooo001A0?oo
o`030000003oool0oooo0280oooo1000000c0?ooo`@00000=03oool200000=<0oooo0P00000d0?oo
o`@00000<`3oool4000003@0oooo0P00000[0?ooo`030000003oool0oooo00@0oooo001A0?ooo`03
0000003oool0oooo02<0oooo0P00000e0?ooo`800000o`3ooom20?ooo`800000=@3oool200000680
oooo00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo
00<000000?ooo`3oool0103oool00540oooo00<000000?ooo`3oool0o`3ooooo0?ooocX0oooo00<0
00000?ooo`3oool0103oool00540oooo1000000:0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool0M`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool0@03oool3000000H0oooo001A0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`00D@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00540ooooo`00003o000003h00000
1P3oool00001\
\>"],
  ImageRangeCache->{{{0, 658.625}, {406.688, 0}} -> {-15.6479, -1.37024, \
0.245771, 0.0102946}}]
}, Closed]],

Cell["\<\
Finally, consider a double-well potential with modest driving force.  The \
phase trajectory appears to be rather complicated, with peculiar kinks and \
loops, and tends to fill an area of phase space.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(duffingPlot[\(-0.25\), 1, 0, 0.5, 2, 1, 0, 0, 10\^2, 
        MaxSteps \[Rule] 10\^4];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.501398 0.44813 0.499597 0.469841 [
[.05327 -0.0125 -9.34375 -15.6875 ]
[.05327 -0.0125 9.34375 0 ]
[.27733 -0.0125 -13.8438 -15.6875 ]
[.27733 -0.0125 13.8438 0 ]
[.5014 -0.0125 -5 -15.6875 ]
[.5014 -0.0125 5 0 ]
[.72546 -0.0125 -9.5 -15.6875 ]
[.72546 -0.0125 9.5 0 ]
[.94953 -0.0125 -5 -15.6875 ]
[.94953 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.9688 -31.375 ]
[.5 -0.0125 21.9688 -15.6875 ]
[-0.0125 .02976 -18.6875 -7.84375 ]
[-0.0125 .02976 0 7.84375 ]
[-0.0125 .26468 -27.6875 -7.84375 ]
[-0.0125 .26468 0 7.84375 ]
[-0.0125 .4996 -10 -7.84375 ]
[-0.0125 .4996 0 7.84375 ]
[-0.0125 .73452 -19 -7.84375 ]
[-0.0125 .73452 0 7.84375 ]
[-0.0125 .96944 -10 -7.84375 ]
[-0.0125 .96944 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -43.375 -20.4688 ]
[-0.01875 .5 -27.6875 20.4688 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -43.9375 0 ]
[.5 1.0125 43.9375 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05327 0 m
.05327 .00625 L
s
gsave
.05327 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.27733 0 m
.27733 .00625 L
s
gsave
.27733 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5014 0 m
.5014 .00625 L
s
gsave
.5014 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.72546 0 m
.72546 .00625 L
s
gsave
.72546 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.94953 0 m
.94953 .00625 L
s
gsave
.94953 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.09808 0 m
.09808 .00375 L
s
.14289 0 m
.14289 .00375 L
s
.18771 0 m
.18771 .00375 L
s
.23252 0 m
.23252 .00375 L
s
.32215 0 m
.32215 .00375 L
s
.36696 0 m
.36696 .00375 L
s
.41177 0 m
.41177 .00375 L
s
.45658 0 m
.45658 .00375 L
s
.54621 0 m
.54621 .00375 L
s
.59102 0 m
.59102 .00375 L
s
.63584 0 m
.63584 .00375 L
s
.68065 0 m
.68065 .00375 L
s
.77028 0 m
.77028 .00375 L
s
.81509 0 m
.81509 .00375 L
s
.8599 0 m
.8599 .00375 L
s
.90471 0 m
.90471 .00375 L
s
.00845 0 m
.00845 .00375 L
s
.99434 0 m
.99434 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.9688 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
102.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02976 m
.00625 .02976 L
s
gsave
-0.0125 .02976 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .26468 m
.00625 .26468 L
s
gsave
-0.0125 .26468 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .4996 m
.00625 .4996 L
s
gsave
-0.0125 .4996 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .73452 m
.00625 .73452 L
s
gsave
-0.0125 .73452 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .96944 m
.00625 .96944 L
s
gsave
-0.0125 .96944 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07674 m
.00375 .07674 L
s
0 .12372 m
.00375 .12372 L
s
0 .17071 m
.00375 .17071 L
s
0 .21769 m
.00375 .21769 L
s
0 .31166 m
.00375 .31166 L
s
0 .35865 m
.00375 .35865 L
s
0 .40563 m
.00375 .40563 L
s
0 .45261 m
.00375 .45261 L
s
0 .54658 m
.00375 .54658 L
s
0 .59357 m
.00375 .59357 L
s
0 .64055 m
.00375 .64055 L
s
0 .68753 m
.00375 .68753 L
s
0 .7815 m
.00375 .7815 L
s
0 .82849 m
.00375 .82849 L
s
0 .87547 m
.00375 .87547 L
s
0 .92245 m
.00375 .92245 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -117 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
81.4688 11.8438 translate
90 rotate
-81.4688 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(velocity) show
99.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.05327 .99375 m
.05327 1 L
s
.27733 .99375 m
.27733 1 L
s
.5014 .99375 m
.5014 1 L
s
.72546 .99375 m
.72546 1 L
s
.94953 .99375 m
.94953 1 L
s
.125 Mabswid
.09808 .99625 m
.09808 1 L
s
.14289 .99625 m
.14289 1 L
s
.18771 .99625 m
.18771 1 L
s
.23252 .99625 m
.23252 1 L
s
.32215 .99625 m
.32215 1 L
s
.36696 .99625 m
.36696 1 L
s
.41177 .99625 m
.41177 1 L
s
.45658 .99625 m
.45658 1 L
s
.54621 .99625 m
.54621 1 L
s
.59102 .99625 m
.59102 1 L
s
.63584 .99625 m
.63584 1 L
s
.68065 .99625 m
.68065 1 L
s
.77028 .99625 m
.77028 1 L
s
.81509 .99625 m
.81509 1 L
s
.8599 .99625 m
.8599 1 L
s
.90471 .99625 m
.90471 1 L
s
.00845 .99625 m
.00845 1 L
s
.99434 .99625 m
.99434 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02976 m
1 .02976 L
s
.99375 .26468 m
1 .26468 L
s
.99375 .4996 m
1 .4996 L
s
.99375 .73452 m
1 .73452 L
s
.99375 .96944 m
1 .96944 L
s
.125 Mabswid
.99625 .07674 m
1 .07674 L
s
.99625 .12372 m
1 .12372 L
s
.99625 .17071 m
1 .17071 L
s
.99625 .21769 m
1 .21769 L
s
.99625 .31166 m
1 .31166 L
s
.99625 .35865 m
1 .35865 L
s
.99625 .40563 m
1 .40563 L
s
.99625 .45261 m
1 .45261 L
s
.99625 .54658 m
1 .54658 L
s
.99625 .59357 m
1 .59357 L
s
.99625 .64055 m
1 .64055 L
s
.99625 .68753 m
1 .68753 L
s
.99625 .7815 m
1 .7815 L
s
.99625 .82849 m
1 .82849 L
s
.99625 .87547 m
1 .87547 L
s
.99625 .92245 m
1 .92245 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .4996 m
1 .4996 L
s
.5014 0 m
.5014 1 L
s
gsave
.5 1.0125 -104.938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Duffing) show
102.938 15.813 moveto
(Equation) show
146.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.94953 .4996 m
.94867 .48491 L
.94634 .47059 L
.94163 .45193 L
.93489 .43143 L
.91628 .38703 L
.88443 .32836 L
.83305 .2568 L
.79735 .21767 L
.75917 .18271 L
.68155 .12798 L
.63571 .1037 L
.58343 .08193 L
.52719 .06482 L
.47329 .05425 L
.44179 .05075 L
.41308 .04936 L
.3799 .05005 L
.34877 .05313 L
.29301 .0655 L
.24359 .08546 L
.19266 .11788 L
.16876 .13858 L
.14418 .16469 L
.10593 .21866 L
.07737 .27576 L
.05286 .34821 L
.03855 .4194 L
.03309 .48339 L
.03431 .53798 L
.04185 .58983 L
.05574 .63319 L
.07473 .66376 L
.08551 .67371 L
.09789 .68065 L
.12053 .68378 L
.1414 .67794 L
.15365 .67121 L
.16473 .66326 L
.18389 .64579 L
.20222 .62576 L
.21881 .60699 L
.23052 .59577 L
.24225 .58912 L
.25253 .58906 L
.26244 .59441 L
.27524 .60716 L
.2887 .62425 L
.32779 .67607 L
.35396 .70651 L
Mistroke
.38637 .73811 L
.42098 .76489 L
.45523 .78498 L
.47744 .79486 L
.49845 .80203 L
.52201 .80764 L
.54722 .81084 L
.56932 .81125 L
.58987 .80959 L
.61222 .80548 L
.63571 .79845 L
.65699 .78951 L
.67601 .77927 L
.71612 .74974 L
.74733 .7176 L
.77545 .67937 L
.811 .61115 L
.82402 .57618 L
.83216 .54891 L
.8371 .52901 L
.83985 .51718 L
.84089 .51359 L
.84183 .51201 L
.84348 .5145 L
.84568 .52207 L
.84925 .53374 L
.85357 .54497 L
.8597 .55662 L
.86736 .56571 L
.87206 .56863 L
.87647 .56952 L
.88491 .56555 L
.892 .5539 L
.89523 .5438 L
.89784 .53024 L
.8998 .49892 L
.89904 .47807 L
.89696 .45657 L
.89299 .43126 L
.88664 .40246 L
.87271 .35737 L
.85502 .31555 L
.8305 .27198 L
.79884 .23025 L
.78098 .2117 L
.76032 .19372 L
.71995 .16722 L
.67792 .14937 L
.6376 .13985 L
.59929 .13676 L
Mistroke
.56336 .13865 L
.52443 .14566 L
.48372 .15838 L
.44306 .17663 L
.40674 .1978 L
.34587 .24418 L
.29146 .29708 L
.24591 .34522 L
.22866 .36107 L
.21215 .3724 L
.19892 .37749 L
.18475 .37842 L
.1762 .37692 L
.16828 .37444 L
.14974 .36622 L
.13266 .35821 L
.12328 .35454 L
.11308 .35163 L
.09371 .35054 L
.0761 .35674 L
.06072 .3707 L
.0462 .39661 L
.03615 .4313 L
.03055 .47808 L
.0307 .525 L
.0368 .58153 L
.05086 .64566 L
.07463 .71357 L
.10505 .77359 L
.13884 .82246 L
.17835 .86522 L
.21875 .8981 L
.26669 .92698 L
.32059 .94973 L
.36934 .96352 L
.41601 .97181 L
.46792 .97619 L
.52388 .97567 L
.55669 .97288 L
.5873 .96856 L
.64349 .95591 L
.70184 .93517 L
.73333 .92002 L
.76119 .90376 L
.80526 .87127 L
.84887 .8282 L
.88817 .77549 L
.91827 .72062 L
.93238 .68762 L
.94509 .65108 L
Mistroke
.95458 .61648 L
.96118 .58499 L
.96818 .52836 L
.96838 .47533 L
.96592 .45169 L
.96161 .4295 L
.9502 .39837 L
.94151 .38503 L
.93241 .37604 L
.92375 .37073 L
.91397 .36754 L
.90528 .36658 L
.89586 .36706 L
.87902 .37042 L
.86444 .37425 L
.84889 .37717 L
.84027 .3775 L
.8322 .37666 L
.82358 .37438 L
.8141 .37017 L
.80494 .36456 L
.79585 .3577 L
.77739 .34096 L
.68395 .24703 L
.65026 .2186 L
.61002 .1898 L
.57224 .16773 L
.52817 .14776 L
.48246 .13337 L
.43861 .12556 L
.3917 .12394 L
.36548 .12627 L
.34187 .13051 L
.30045 .14343 L
.25767 .16536 L
.22021 .19361 L
.18894 .2258 L
.15793 .26867 L
.13395 .31334 L
.11374 .36515 L
.10528 .39445 L
.09934 .42077 L
.0924 .47048 L
.09121 .49582 L
.09168 .517 L
.09594 .54897 L
.09987 .56265 L
.10417 .57235 L
.11332 .58359 L
.12387 .58694 L
Mistroke
.13287 .58392 L
.14209 .5759 L
.15078 .56382 L
.15832 .54961 L
.16375 .53765 L
.16761 .52967 L
.17082 .52609 L
.17421 .52843 L
.17778 .53644 L
.18289 .55106 L
.19707 .58985 L
.22317 .64544 L
.24331 .67858 L
.26568 .70859 L
.29292 .73777 L
.32565 .76447 L
.35901 .78404 L
.39234 .79704 L
.42328 .80388 L
.45728 .80598 L
.4945 .80203 L
.51531 .79698 L
.53438 .79052 L
.57131 .77283 L
.60795 .74801 L
.63859 .72104 L
.66426 .6936 L
.70327 .64315 L
.73046 .60499 L
.74144 .59206 L
.75226 .58389 L
.76094 .58227 L
.77042 .58592 L
.78001 .59406 L
.78975 .60487 L
.8191 .63922 L
.83649 .65595 L
.85389 .66843 L
.87349 .67663 L
.89502 .67728 L
.91781 .66582 L
.93713 .64152 L
.95157 .60691 L
.9619 .55741 L
.96544 .50096 L
.96256 .44356 L
.95119 .37327 L
.94086 .3336 L
.92879 .29773 L
.9008 .23627 L
Mistroke
.86335 .17933 L
.84012 .15282 L
.81722 .13139 L
.79115 .11156 L
.76111 .09359 L
.7079 .0719 L
.67786 .0643 L
.64942 .05969 L
.5948 .05694 L
.54507 .06055 L
.48858 .07103 L
.43668 .08641 L
.39378 .10337 L
.34872 .12565 L
.26642 .1801 L
.20262 .23795 L
.15453 .29386 L
.08558 .40098 L
.06552 .44198 L
.05977 .45659 L
.05536 .47144 L
.05274 .48707 L
.05219 .50343 L
.05371 .52194 L
.05718 .54192 L
.06359 .56708 L
.07431 .59898 L
.0904 .6369 L
.10981 .67433 L
.15765 .74542 L
.18851 .78118 L
.22679 .81808 L
.26609 .84934 L
.30566 .87544 L
.34913 .89902 L
.39123 .91754 L
.44709 .93638 L
.47734 .94405 L
.50976 .95037 L
.56514 .95653 L
.59678 .9573 L
.62625 .95605 L
.68091 .94808 L
.72945 .93364 L
.78293 .90737 L
.82982 .87219 L
.87491 .82268 L
.89504 .79332 L
.9149 .7579 L
.9434 .68892 L
Mistroke
.96185 .61972 L
.96895 .57754 L
.97291 .53809 L
.97331 .46855 L
.96983 .43375 L
.96447 .40475 L
.95652 .37711 L
.94602 .35284 L
.92597 .32559 L
.91336 .31628 L
.90111 .31134 L
.88796 .30973 L
.87596 .31113 L
.86232 .31564 L
.84979 .32225 L
.82896 .33784 L
.81153 .35455 L
.79361 .37384 L
.77895 .38922 L
.76604 .39987 L
.75925 .40333 L
.75317 .40472 L
.74692 .40427 L
.73996 .40156 L
.7324 .39628 L
.72493 .38921 L
.68583 .34059 L
.63314 .27976 L
.60542 .25416 L
.57287 .22957 L
.55471 .21826 L
.5339 .20729 L
.49558 .1924 L
.45952 .18443 L
.42012 .18234 L
.38307 .18687 L
.34998 .19663 L
.33076 .205 L
.31095 .21595 L
.27746 .2405 L
.24208 .27668 L
.21495 .31416 L
.19397 .35171 L
.17661 .3919 L
.16507 .42695 L
.15819 .45475 L
.15407 .47826 L
.1525 .4935 L
.1523 .50111 L
.15266 .50311 L
Mistroke
.15289 .49878 L
.15271 .49452 L
.15215 .48861 L
.15001 .47626 L
.14656 .4643 L
.14206 .45449 L
.13632 .44769 L
.13101 .44607 L
.12529 .44979 L
.11999 .46117 L
.11637 .48219 L
.11588 .51008 L
.11866 .54132 L
.12677 .5842 L
.13304 .60733 L
.14168 .63336 L
.16156 .67939 L
.18532 .7204 L
.21925 .7636 L
.25507 .79632 L
.2765 .81118 L
.30094 .82459 L
.32487 .83452 L
.3476 .84135 L
.39317 .84818 L
.43635 .84702 L
.47465 .84017 L
.51483 .82725 L
.55665 .80743 L
.59757 .78148 L
.66091 .7277 L
.70845 .67729 L
.729 .65463 L
.74803 .63553 L
.7629 .62394 L
.7781 .61719 L
.79151 .61656 L
.80426 .62031 L
.81271 .62459 L
.82106 .62973 L
.83774 .64119 L
.8478 .64801 L
.85905 .65493 L
.8699 .66051 L
.88044 .66458 L
.90079 .66765 L
.91919 .6634 L
.93837 .64889 L
.95629 .61991 L
.96808 .58301 L
Mistroke
.97475 .53938 L
.97619 .48304 L
.96993 .41593 L
.95404 .34265 L
.93012 .27489 L
.90166 .21856 L
.86393 .16449 L
.82645 .125 L
.78071 .08954 L
.72907 .06142 L
.67793 .04272 L
.62873 .03136 L
.58279 .02555 L
.53194 .02381 L
.47847 .02684 L
.42055 .03571 L
.38847 .04326 L
.35941 .05189 L
.30767 .07208 L
.25588 .09984 L
.2128 .13046 L
.17586 .16403 L
.13967 .206 L
.10647 .25616 L
.07831 .31327 L
.06573 .34638 L
.05626 .37699 L
.04428 .43124 L
.04048 .45968 L
.03872 .48379 L
.03933 .52429 L
.04493 .55921 L
.05385 .58333 L
.06424 .59836 L
.07528 .60718 L
.0879 .61222 L
.10017 .61428 L
.11147 .61513 L
.12485 .61636 L
.13965 .61964 L
.15418 .6259 L
.16846 .63517 L
.25338 .71879 L
.30597 .76831 L
.34051 .79616 L
.37558 .82056 L
.41515 .84358 L
.45327 .86147 L
.49595 .87671 L
.54312 .88775 L
Mistroke
.59155 .89261 L
.61899 .89229 L
.64416 .88989 L
.68977 .87988 L
.7362 .86089 L
.7739 .83733 L
.81111 .80468 L
.84239 .76731 L
.86714 .72843 L
.89094 .67851 L
.91004 .62132 L
.92139 .56757 L
.9263 .52071 L
.92612 .47658 L
.92062 .43783 L
.9115 .41116 L
.90081 .39557 L
.88754 .38779 L
.87978 .38735 L
.87259 .38919 L
.85873 .39818 L
.85159 .40546 L
.84559 .4129 L
.82684 .44242 L
.82296 .44857 L
.81927 .45338 L
.81635 .45583 L
.81326 .45656 L
.80752 .45221 L
.80391 .44648 L
.80017 .4392 L
.78014 .39601 L
.74692 .33649 L
.70347 .28088 L
.67417 .25359 L
.65744 .24097 L
.63893 .2292 L
.603 .21229 L
.56839 .2027 L
.53578 .19921 L
.50075 .20124 L
.4682 .20849 L
.43946 .21933 L
.40739 .23665 L
.37515 .26018 L
.32513 .31081 L
.28233 .36979 L
.25506 .41045 L
.24451 .4217 L
.23908 .42489 L
Mistroke
.23422 .4258 L
.22919 .42472 L
.22353 .4213 L
.21725 .41545 L
.21094 .40817 L
.18426 .3745 L
.16794 .35711 L
.15115 .34357 L
.13022 .33379 L
.11884 .33219 L
.10679 .33377 L
.08795 .34451 L
.06948 .36924 L
.05495 .40844 L
.04678 .45657 L
.04517 .51981 L
.04808 .5584 L
.0532 .59443 L
.06896 .66117 L
.08141 .69772 L
.09502 .72993 L
.12522 .78442 L
.16348 .83331 L
.20256 .86874 L
.24819 .8974 L
.2939 .91596 L
.33696 .92623 L
.38844 .931 L
.4445 .92835 L
.4967 .91933 L
.54363 .90613 L
.59141 .88775 L
.64007 .8636 L
.71922 .81118 L
.79619 .74125 L
.84967 .67949 L
.91757 .58997 L
.92893 .57493 L
.93902 .56009 L
.94292 .55311 L
.9465 .54522 L
.95138 .52887 L
.95387 .50878 L
.95363 .48552 L
.94983 .45457 L
.94582 .43478 L
.94086 .41533 L
.92909 .37911 L
.91136 .33693 L
.86527 .25799 L
Mistroke
.8368 .22138 L
.80084 .18337 L
.76157 .14962 L
.71502 .11748 L
.66827 .09189 L
.62293 .07226 L
.57778 .05704 L
.52872 .04489 L
.46899 .03597 L
.41404 .0336 L
.38359 .03491 L
.35075 .03865 L
.29218 .05233 L
.23944 .07424 L
.18713 .1082 L
.14644 .14648 L
.10706 .19838 L
.08655 .23416 L
.06956 .27083 L
.04478 .34476 L
.03517 .38759 L
.02902 .42732 L
.0253 .47 L
.02469 .51332 L
.02684 .54848 L
.03173 .58294 L
.03854 .61154 L
.04643 .63413 L
.06485 .66667 L
.08764 .68643 L
.11102 .69258 L
.12435 .69134 L
.13651 .6877 L
.15796 .67619 L
.17896 .65963 L
.21046 .62871 L
.22446 .6154 L
.23778 .60576 L
.25129 .60172 L
.26359 .6045 L
.27575 .61278 L
.29046 .62768 L
.33309 .67923 L
.38583 .73521 L
.41402 .75916 L
.44746 .78236 L
.48146 .80054 L
.51443 .81324 L
.55066 .82181 L
.59121 .82474 L
Mistroke
.63346 .82001 L
.67192 .80817 L
.70631 .7906 L
.73676 .76849 L
.76184 .74457 L
.78631 .71489 L
.80911 .67957 L
.82876 .64021 L
.84172 .60676 L
.85206 .57174 L
.85877 .53916 L
.86179 .51376 L
.86215 .49232 L
.8605 .4807 L
.85806 .47652 L
.85568 .47794 L
.85352 .48431 L
.85228 .49497 L
.85244 .50705 L
.85387 .51826 L
.85675 .52849 L
.86094 .53486 L
.86331 .53558 L
.86588 .53402 L
.86988 .52419 L
.87194 .50554 L
.87122 .48046 L
.86933 .46308 L
.86587 .44216 L
.86112 .42077 L
.8554 .40002 L
.84079 .35906 L
.8199 .3157 L
.79136 .27188 L
.75954 .236 L
.71981 .20425 L
.69575 .19045 L
.67297 .18054 L
.63144 .1694 L
.59218 .16617 L
.54914 .17012 L
.52772 .17489 L
.50451 .18216 L
.46716 .19852 L
.42942 .22111 L
.36955 .27046 L
.28617 .36325 L
.27773 .37205 L
.26916 .37985 L
.25472 .38898 L
Mistroke
.24136 .39133 L
.22897 .38791 L
.21441 .37853 L
.19666 .36313 L
.17711 .34555 L
.16531 .33594 L
.15348 .32757 L
.14203 .32096 L
.12911 .31556 L
.10587 .3123 L
.08247 .31962 L
.06229 .33807 L
.05164 .35472 L
.043 .37386 L
.03506 .39904 L
.02876 .43005 L
.02381 .49112 L
.02456 .52962 L
.02775 .56717 L
.04049 .63934 L
.05978 .70399 L
.09075 .77324 L
.12779 .83044 L
.17483 .88101 L
.2009 .90192 L
.23111 .92142 L
.2875 .94724 L
.34283 .96233 L
.37519 .96744 L
.40951 .97029 L
.47101 .96959 L
.50515 .96623 L
.53658 .96134 L
.57063 .95407 L
.60627 .94417 L
.66024 .92429 L
.71627 .89624 L
.77021 .86004 L
.81553 .82012 L
.85283 .77806 L
.8821 .7366 L
.90988 .68658 L
.93014 .63889 L
.94547 .58943 L
.95076 .566 L
.95481 .54177 L
.95782 .50407 L
.95651 .47519 L
.95429 .4616 L
.95098 .44943 L
Mistroke
.9475 .44065 L
.94309 .43253 L
.93775 .42521 L
.93148 .41865 L
.91898 .40856 L
.86153 .35751 L
.81498 .30515 L
.75637 .24422 L
.69363 .19086 L
.61353 .13976 L
.56293 .11618 L
.51219 .09874 L
.46502 .08798 L
.4125 .08236 L
.38349 .08231 L
.35624 .08443 L
.306 .0945 L
.25389 .11508 L
.22595 .13143 L
.20145 .14957 L
.16346 .18664 L
.12723 .23629 L
.0966 .29641 L
.07546 .35747 L
.06687 .39284 L
.06029 .43102 L
.05668 .46605 L
.0555 .49691 L
.05851 .5494 L
.06815 .59409 L
.07519 .61197 L
.08399 .62713 L
.10212 .64387 L
.11335 .64766 L
.12531 .64752 L
.13541 .64449 L
.14611 .63866 L
.17837 .6066 L
.20071 .57626 L
.20557 .57046 L
.21035 .56597 L
.21531 .56324 L
.21978 .56293 L
.22775 .56768 L
.23267 .57336 L
.23769 .58056 L
.26209 .62158 L
.30124 .67994 L
.32591 .70909 L
.35237 .73468 L
Mistroke
.37859 .75501 L
.40913 .77316 L
.44478 .78763 L
.46331 .7925 L
.4839 .79587 L
.52068 .79669 L
.55469 .79149 L
.57514 .78553 L
.59402 .77804 L
.62779 .75958 L
.66119 .73417 L
.69322 .70194 L
.7638 .59556 L
.7739 .57751 L
.78278 .56419 L
.78726 .55968 L
.79114 .5576 L
.79865 .55908 L
.80635 .56664 L
.8146 .57795 L
.82633 .59476 L
.83901 .61083 L
.85288 .6245 L
.86723 .6338 L
.88318 .63774 L
.90043 .63299 L
.91416 .62013 L
.92708 .59588 L
.93681 .55928 L
.94126 .51573 L
.94049 .46844 L
.93515 .4216 L
.92312 .36558 L
.90587 .31307 L
.88158 .2606 L
.84903 .21012 L
.81304 .16993 L
.77632 .14022 L
.73239 .11551 L
.6816 .09807 L
.65527 .09287 L
.62684 .08979 L
.57542 .09024 L
.54725 .09349 L
.52153 .09823 L
.4937 .1052 L
.46484 .11443 L
.41808 .13378 L
.36974 .15973 L
.29087 .21625 L
Mistroke
.23055 .27235 L
.0974 .39727 L
.08524 .40346 L
.07914 .40694 L
.0729 .41122 L
.06236 .42162 L
.05401 .43561 L
.04732 .45624 L
.04372 .48191 L
.04331 .51025 L
.04648 .54612 L
.05124 .57403 L
.05909 .60669 L
.07036 .64233 L
.08382 .67627 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00g03oool00`3ooml0W4P0000000020000000307Bo
o`3oool0oooo0<`0oooo003N0?ooo`030?noM00007@0_ooo0<l0oooo003N0?ooo`030?oo_`1d0000
M;oo0<l0oooo003N0?ooo`030?oog`2LB000B9cO0<l0oooo003O0?ooo`030=nLB000000000000080
000000<0M;oo0?ooo`3oool00P3oool01@3o_g@000000000000004P0W=oo0080oooo00<0oono07@0
000000000P0000003@18W=l0oooo0?ooo`3oool0_g@00000000004P0W=oo0?ooo`3o_g@000000000
B02Lgol00P3oool0102oM00000000000B02Lgol20?ooo`050?noM000000000000000B02Lgol00`3o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000000007Bo09H0oooo003O0?ooo`070?noM00004P0
W=oo0?ooo`3ooml0W4P0001d_`020?ooo`0?0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`3oool0
oooO09a8001d_ol0oooo0?oOW0180000M;oo0080oooo01L0gia80018W03Ooml0W7BL0=ooo`3o_g@0
001809cOg`2LM9`0gooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0
B000001d_`020?ooo`030?noM00007@0_ooo0080oooo00@0gia80018W03O_g@0M;ooU@3oool00=l0
oooo00<0oono07@0001d_ol00P3oool01`3ooml0W4P004RLg`3oool0gia80018W03Oool00P3oool0
2P3ogi`0B00004RLg`3oool0_gAd0;ooo`3oool0oono07@0001d_ol20?ooo`030?noM00004P0W=oo
0080oooo00<0oono07@0001d_ol00`3oool00`3o_g@0001809cOo`020?ooo`030=nLB000B9`0gooo
0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol0UP3o
ool00=l0oooo00<0oooO09a80018W=l00`3oool01P3ogi`0B01809cOo`3o_g@0001d0;ooo`<0oooo
00<0gia80000M02oool00`3oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo
00<0_g@0001d_`3oool00P3oool00`3ookl0M00004RLg`020?ooo`030?noM00007@0_ooo00<0oooo
00/0gia80000M02oool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`2F0?ooo`00h03oool0
0`3OW4P0001d0;ooo`020?ooo`060?oog`2LB000B9cO0?oo_`1d0000M;oo0`3oool00`3ogi`0B018
09cOo`020?ooo`030?noM00004P0W=oo00@0oooo00<0_g@00018W03Oool00P3oool00`3OW4P004RL
0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3ookl0M00007Boo`030?ooo`070?oOW01804P0W=oo
0?ooo`3OW4P004Q804Qd_`020?ooo`030;md0000M;l0oooo09D0oooo003P0?ooo`040?noM0000000
04RL0=ooo`80oooo00H0gia8001d_`3oool0gia80000M02oool20?ooo`0:0?oo_`1d0000M;oo0?oo
o`3ogi`0B01809cOo`3oool0giad09cOo`80oooo00<0gia80000B02Lgol00P3oool00`3ogi`0B018
09cOo`030?ooo`030=nLB00004P0W=oo0080oooo00<0gia80000M02oool00P3oool0303ookl0M000
07Boo`3oool0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;oooiD0oooo003P0?ooo`080?oo_`1d
0000M9bL04P0M02oool0oooO09a80000M;l20?ooo`0>0;md000007@0_ooo0?ooo`3o_g@0001d0;oo
o`3oool0omnL04P0B02Lgol0oooO09a8001d_ol20?ooo`030?oOW0180000B9cO0080oooo00<0oooO
09a80018W=l00`3oool00`3ogi`0B00004RLg`030?ooo`0@0;md000007@0_ooo0?ooo`3o_g@0001d
0;ooo`3oool0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOoiD0oooo003O0?ooo`090?oOW018
0000000004RLg`3ookl0M0000000000007@0_ooo00<0oooo00D0okmd000000000000000007Boo`03
0?ooo`070;md00000000000000000018W=l0oooo0?noM002000000040018W03Oool0oono07@000<0
000000H0M;oo0?noM000000000000018W03Oool30?ooo`0?0?noM000000000000000001d_ol0oooo
0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo09D0oooo003o0?ooo`40oooo00<0okmd
0000M02oool0[@3oool00?l0oooo0P3oool00`3OW7@0W=oo0?ooo`2/0?ooo`00n`3oool0103ookl0
M0000018W03Oool70?ooo`040?oo_`1d000004RL0=ooojH0oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo001P0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0@P3o
ool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00H0omnL04P000000000
00000018W03Ooolm0?ooo`040;md00000000000007Bood@0oooo00@0_g@0000000000000M;oo0`3o
ool00`3ogi`0B00007Boo`020?ooo`060?oOW0180000000000000000B9`0gooo@@3oool00`3ookl0
M000000000020000000304RLg`3oool0oooo01@0oooo001R0?ooo`030?noM0000000M;oo04@0oooo
00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo0080oooo00H0okmd0000
001d_ol0oooo0?oOW018M;ll0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO@P3oool01P3OW4P0
07Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00P3oool01P3o_g@0000007Boo`3o
ool0omnL04Qd_d<0oooo00<0okmd0000001d_ol05`3oool00680oooo00<0oooO09a80000M;l0@`3o
ool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00/0oooo00<0okmd04RLg`3oool0>@3o
ool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo0400oooo00<0oooO09a80018W=l00P3o
ool00`3o_g@0001809cOo`0;0?ooo`030?noM018W=l0oooo0440oooo00<0oooO09a80000M;l05`3o
ool006<0oooo00<0gia80018W03Oool0@P3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB000
04RL0=ooo`X0oooo00<0oono07@0M02oool0>@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2L
B00004RL0=ooocl0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool:0?ooo`03
0?oo_`1d07@0_ooo0480oooo00<0gia80018W03Oool05P3oool005<0oooo00<0oooO09a800000000
1`0000000`18W=l0oooo0?ooo`030?ooo`030?oOW01804P0W=oo03D0oooo00<0oooO09a800000000
1`0000001P18W=l0oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol02P3oool00`3o
oml0W4P007Boo`0i0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol0?`3oool00`3o
oml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00X0oooo00<0oooO09a8001d_ol0@P3oool00`3o
gi`0B01809cOo`0F0?ooo`00H`3oool00`3ookl0M00007Boo`130?ooo`030;md0000B9`0gooo0080
oooo00<0omnL04P00018W=l02P3oool00`3ookl0M00004RLg`0j0?ooo`030;md0000B9`0gooo0080
oooo00<0omnL04P00018W=l0@03oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00X0
oooo00<0oono07@00018W=l0@P3oool00`3ookl0M00007Boo`0F0?ooo`00I03oool00`2oM00007Bo
0?ooo`120?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l02P3oool00`3o_g@00000
07Boo`0j0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0@03oool00`3OW4P00018
09cOo`020?ooo`030?oog`2LB00007Bo00X0oooo00<0okmd0000001d_ol0@`3oool00`2oM00007Bo
0?ooo`0E0?ooo`00I03oool00`3OW4P004RL0=ooo`120?ooo`030?oOW0180000B9cO00<0oooo00<0
_g@00018W03Oool01P3oool01P3ogml0gooo0?noM0000000001d0;ooocX0oooo00<0omnL04P00018
W=l00`3oool00`2oM00004RL0=ooo`0o0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03O
ool01P3oool01P3ogml0gooo0?noM0000000001d0;oood<0oooo00<0gia80018W03Oool05@3oool0
06@0oooo00<0omnL04P0B02Lgol0@P3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0
gooo00H0oooo00D0oono07@000000000001809cOo`0k0?ooo`040?oog`2LB00004RL0=ooo`80oooo
00<0gia80018W03Oool0?`3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00H0
oooo00D0oono07@000000000001809cOo`140?ooo`030?oOW01804P0W=oo01D0oooo001T0?ooo`03
0?oo_`1d0000M;oo04<0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`070?ooo`03
0=nLW02oool0oooo03d0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`100?ooo`03
0?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01`3oool00`3OW9`0_ooo0?ooo`150?ooo`03
0?oo_`1d0000M;oo01D0oooo001U0?ooo`030;md0000M;l0oooo04<0oooo00H0gia80000M02oool0
oooO09a80018W=l80?ooo`030?oOW01dW=l0oooo03h0oooo00H0gia80000M02oool0oooO09a80018
W=m20?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO203oool00`3ogi`0M9cO0?ooo`160?ooo`03
0;md0000M;l0oooo01@0oooo001S0?ooo`050?oo_`1d000000000000M02oool0A03oool0103OW4P0
000000000000M;l:0?ooo`050;md00000000000000000018W=l0?03oool0103OW4P0000000000000
M;m40?ooo`040=nLB00000000000001d_`X0oooo00D0_g@0000000000000000004RLg`110?ooo`05
0?oo_`1d000000000000M02oool0503oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool004/0ooooo`00001R000000@0oooo001;0?ooo`040000003oool0oooo0000
00l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`000000103oool004/0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0C03oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?oo
o`020?ooo`00>`3oool00`3ookl0M000000000020000000304RLg`3oool0oooo00P0oooo00<00000
0?ooo`3oool0[@3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0080oooo000m0?oo
o`030?noM0000000M;oo00/0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`2]0?oo
o`030000003oool0oooo0080oooo000m0?ooo`030?oog`2LB00007Bo00/0oooo00<000000?ooo`3o
ool0[@3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0080oooo000n0?ooo`030=nL
B000B9`0gooo00X0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0000000A000009`0oooo
00<000000?ooo`3oool00P3oool002h0oooo00<0oooO09a8000000001`0000000`18W=l0oooo0?oo
o`030?ooo`030?oOW01804P0W=oo00X0oooo00<000000?ooo`3oool0X`3oool<00000180oooo3@00
002?0?ooo`030000003oool0oooo0080oooo000n0?ooo`030?oo_`1d0000M;oo00X0oooo0`00002N
0?ooo`D000002P3oool00`000000oooo0?ooo`0N0?ooo`P00000Q03oool4000000@0oooo000o0?oo
o`030;md0000M;l0oooo00T0oooo00<000000?ooo`3oool0V@3oool5000000l0oooo00<000000?oo
o`3oool09P3oool700000800oooo00<000000?ooo`3oool00P3oool003l0oooo00<0gia80018W03O
ool02@3oool00`000000oooo0?ooo`220?oooaL00000503oool00`000000oooo0?ooo`0]0?ooo`@0
0000O03oool00`000000oooo0?ooo`020?ooo`00?`3oool00`3ogi`0B01809cOo`090?ooo`030000
003oool0oooo07`0oooo1P00000=0?ooo`D000001@3oool=000000L0oooo00<000000?ooo`3oool0
<@3oool4000007P0oooo00<000000?ooo`3oool00P3oool003l0oooo00<0oono07@0001d_ol02@3o
ool00`000000oooo0?ooo`1f0?ooo`H000003@3oool6000001L0oooo2000000g0?ooo`@00000M03o
ool00`000000oooo0?ooo`020?ooo`00@03oool00`2oM00007Bo0?ooo`080?ooo`030000003oool0
oooo0740oooo1@00000?0?ooo`@00000903oool7000003D0oooo1000001`0?ooo`030000003oool0
oooo0080oooo000n0?ooo`050?oo_`1d000000000000M02oool0203oool00`000000oooo0?ooo`1/
0?ooo`D00000403oool4000002P0oooo00<000000?ooo`3oool0103oool6000003<0oooo0P00001^
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo06L0oooo1@00000A0?oo
o`@00000203oool:000001X0oooo00<000000?ooo`3oool02P3oool400000340oooo0`00001[0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo06<0oooo1000000C0?ooo`<0
000000<0oooo0000000000002@00000:0?ooo`/000003`3oool00`000000oooo0?ooo`0>0?ooo`@0
0000<03oool2000006T0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
H@3oool2000001<0oooo2000000P0?ooo`P000001`3oool00`000000oooo0?ooo`0B0?ooo`@00000
;P3oool3000006H0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0G`3o
ool200000100oooo1`00000^0?ooo`D000000P3oool00`000000oooo0?ooo`0F0?oooa8000007`3o
ool3000006<0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0G03oool3
000000d0oooo1@0000020?ooo`800000=P3oool4000000`0oooo2`0000040?ooo`<000002`3oool<
000001H0oooo0P00001Q0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
05X0oooo0P00000;0?ooo`D00000103oool3000003X0oooo00<000000?ooo`000000100000020?oo
o`D000004P3oool3000001@0oooo1@00000C0?ooo`800000G`3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`1G0?ooo`<000002@3oool4000000H0oooo0`00000m0?ooo`04
0000003oool0oooo0?ooo`L00000603oool4000001D0oooo1@00000@0?ooo`800000G@3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1E0?ooo`8000002P3oool2000000P0
oooo0P00000o0?ooo`D000001`3oool3000001T0oooo0`00000G0?ooo`H00000303oool2000005/0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0D`3oool2000000T0oooo
0`0000080?ooo`800000?@3oool4000000030?ooo`000000oooo00`0oooo1000000H0?ooo`<00000
6P3oool4000000X0oooo0P00001I0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo0540oooo0P0000090?ooo`8000002@3oool2000003/0oooo100000050?ooo`030000003o
ool0oooo00l0oooo0`00000H0?ooo`800000703oool2000000X0oooo0P00001G0?ooo`030000003o
ool0oooo0080oooo001;0?ooo`800000D03oool2000000T0oooo0P0000090?ooo`800000>@3oool4
000000T0oooo00<000000?ooo`3oool04P3oool3000001L0oooo0P00000L0?ooo`8000002P3oool2
000005<0oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo
00H0oooo0`0000090?ooo`800000=`3oool4000000d0oooo00<000000?ooo`3oool05@3oool40000
01D0oooo0P00000L0?ooo`<000002@3oool2000005<0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool0C03oool2000000L0oooo0P00000:0?ooo`8000007@3ooolC000000D0
oooo1000000A0?ooo`030000003oool0oooo01T0oooo0`00000D0?ooo`<00000703oool2000000T0
oooo0P00001A0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool01@3oool2000000/0oooo00<000000?ooo`3oool05@3oool8000001<0oooo
2@00000A0?ooo`030000003oool0oooo01`0oooo0P00000E0?ooo`800000703oool3000000P0oooo
0P00001?0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo04T0oooo0P00
00060?ooo`8000002`3oool200000180oooo1P00000K0?ooo`8000001`3oool7000000X0oooo00<0
00000?ooo`3oool07P3oool3000001@0oooo0P00000M0?ooo`800000203oool2000004d0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`04
0?ooo`8000002`3oool2000000h0oooo1P00000N0?ooo`<00000403oool4000000H0oooo00<00000
0?ooo`3oool04`3ooolK000000T0oooo0P00000M0?ooo`800000203oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo04H0oooo0P0000060?oo
o`030000003oool0oooo00T0oooo0P00000<0?ooo`@000008P3oool2000001L0oooo100000020?oo
o`030000003oool0oooo00T0oooo2P00000@0?ooo`<00000203oool:000000030?ooo`0000000000
01d0oooo0P0000070?ooo`800000BP3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo00@0oooo0P00000:0?ooo`8000002`3oool3000002<0
oooo0`00000M0?ooo`@00000103oool6000001d0oooo0`00000?0?ooo`L000006`3oool2000000L0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`130?ooo`8000001P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
0P00000T0?ooo`8000008P3oool00`000000oooo00000003000002H0oooo0P00000B0?ooo`@00000
6`3oool2000000H0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00@0oooo0P00000:0?ooo`8000002@3o
ool3000002@0oooo0P00000T0?ooo`<000000`3oool3000002D0oooo0P00000B0?ooo`030000003o
ool00000008000006P3oool00`000000oooo0?ooo`040?ooo`800000AP3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`100?ooo`8000001@3oool2000000/0oooo00<00000
0?ooo`3oool01P3oool3000002D0oooo0P00000S0?ooo`@00000203oool3000002@0oooo0P00000A
0?ooo`8000000P3oool2000001T0oooo0P0000060?ooo`030000003oool0oooo04<0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool2000002H0oooo0P00000Q0?oo
o`@000000`3oool00`000000oooo0?ooo`090?ooo`<000008`3oool200000140oooo0P0000020?oo
o`8000006@3oool2000000D0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00<0oooo0P00000;0?ooo`80
00001@3oool3000002H0oooo0P00000O0?ooo`@000001`3oool00`000000oooo0?ooo`0<0?ooo`<0
00008P3oool200000140oooo0P0000020?ooo`<00000603oool00`000000oooo0?ooo`030?ooo`80
0000@P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo0080oooo0P00000<0?ooo`030000003oool0oooo00<0oooo0P00000W0?ooo`800000
7P3oool3000000/0oooo00<000000?ooo`3oool03`3oool300000240oooo0P00000A0?ooo`800000
0`3oool2000001L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo03/0oooo0P0000040?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00P3oool2000002L0oooo0P00000N0?ooo`8000003P3o
ool00`000000oooo0?ooo`0B0?ooo`<00000803oool200000140oooo00<000000?ooo`3oool00P3o
ool2000001H0oooo0P0000050?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00X0oooo0P0000030?ooo`8000009`3oool2000001h0oooo0P00000@0?ooo`030000003oool0
oooo01D0oooo0P00000P0?ooo`800000403oool2000000@0oooo0P00000F0?ooo`030000003oool0
oooo00<0oooo0P00000n0?ooo`030000003oool0oooo0080oooo001;0?ooo`800000>P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0U0?ooo`8000007P3oool200000180oooo00<000000?ooo`3oool05`3oool20000
0200oooo0P00000@0?ooo`030000003oool0oooo00<0oooo0P00000E0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0>@3oool3000000@0oooo001;0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo0?oo
o`8000009`3oool010000000oooo0?ooo`3ooolN000001<0oooo00<000000?ooo`3oool06@3oool2
00000200oooo0P00000?0?ooo`030000003oool0oooo00@0oooo0P00000D0?ooo`8000001@3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool00P3oool2000000/0oooo0P0000020?ooo`8000009`3oool60000
01P0oooo0P0000040?ooo`D000003P3oool00`000000oooo0?ooo`0K0?ooo`<000007`3oool00`00
0000oooo0?ooo`0=0?ooo`8000001P3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?oo
o`0000009`3oool4000001X0oooo0P00000;0?ooo`H00000203oool00`000000oooo0?ooo`0N0?oo
o`8000007P3oool2000000l0oooo00<000000?ooo`3oool01@3oool2000001<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`05
0000003oool0oooo0?ooo`000000903oool5000001/0oooo0P00000C0?ooo`@00000103oool00`00
0000oooo0?ooo`0P0?ooo`8000007P3oool00`000000oooo0?ooo`0=0?ooo`8000001`3oool20000
0180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo03<0oooo0P0000040?ooo`030000003oool0oooo00X0
oooo00D000000?ooo`3oool0oooo0000000R0?ooo`<000000P3oool00`000000oooo0?ooo`0I0?oo
o`8000006@3oool3000000030?ooo`000000oooo01/0oooo3@00000J0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool01P3oool200000140oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?oo
o`0000007`3oool4000000<0oooo0P00000J0?ooo`8000007P3oool300000140oooo2P00000:0?oo
o`80000000<0oooo0000000000001`00000B0?ooo`8000003`3oool2000000P0oooo0P00000@0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`02000001h0oooo0P0000060?ooo`030000003oool0oooo01P0
oooo0P00000Q0?ooo`030000003oool0000000<000001P3oool7000001H0oooo0P0000080?ooo`@0
0000403oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool00P3oool004/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00X0oooo00@000000?ooo`3oool000007P3oool2000000H0oooo0P00000I0?ooo`80
00008`3oool00`000000oooo0?ooo`030?ooo`H000007`3oool00`000000oooo0?ooo`090?ooo`D0
0000303oool2000000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2@3oool200000080oooo00<000000?ooo`3oool06`3oool2000000L0oooo00<000000?ooo`3oool0
5`3oool2000002D0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`<00000803oool2000000h0
oooo1000000:0?ooo`030000003oool0oooo00d0oooo0P0000080?ooo`8000003`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo
00D000000?ooo`3oool0oooo0000000L0?ooo`8000001`3oool2000001P0oooo0P00000W0?ooo`04
0000003oool00000000000P0oooo0P00000P0?ooo`030000003oool0oooo00l0oooo0P0000090?oo
o`8000003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`05
0000003oool0oooo0?ooo`0000006`3oool2000000L0oooo0P00000H0?ooo`800000:03oool30000
00`0oooo0P00000O0?ooo`8000004@3oool2000000T0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?oo
o`0000006P3oool2000000P0oooo00<000000?ooo`3oool05P3oool2000002L0oooo0`0000000`3o
ool000000?ooo`0>0?ooo`8000007`3oool200000140oooo0P0000080?ooo`030000003oool0oooo
00d0oooo0P0000080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?oo
o`0000006@3oool2000000P0oooo0P00000H0?ooo`030000003oool0oooo02@0oooo0`0000040?oo
o`030000003oool0oooo00l0oooo0P00000O0?ooo`030000003oool0oooo0100oooo0P0000070?oo
o`8000003`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`05
0000003oool0oooo0?ooo`000000603oool2000000T0oooo00<000000?ooo`3oool05P3oool20000
02D0oooo0P0000070?ooo`030000003oool0oooo0140oooo0P00000N0?ooo`8000004P3oool20000
00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`8000003P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo00D000000?ooo`3oool0oooo0000000H0?ooo`030000003oool0oooo00L0oooo0P00000H0?oo
o`030000003oool0oooo02<0oooo0P0000090?ooo`030000003oool0oooo01<0oooo0P0000050?oo
o`L000004P3oool00`000000oooo0?ooo`0A0?ooo`8000001P3oool2000000h0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0[0?ooo`05
0000003oool0oooo0?ooo`0000002P3oool01@000000oooo0?ooo`3oool0000001L0oooo0P000009
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool08@3oool3000000/0oooo00<00000
0?ooo`3oool04P3oool8000000L0oooo1`00000<0?ooo`8000004`3oool2000000H0oooo00<00000
0?ooo`3oool0303oool2000000P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool00P3oool004/0oooo0P00000[0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020000
01L0oooo00<000000?ooo`3oool01`3oool2000001P0oooo0P00000R0?ooo`8000003P3oool00`00
0000oooo0?ooo`0;0?ooo`L000001@3oool2000000l0oooo1P0000080?ooo`030000003oool0oooo
0180oooo0P0000050?ooo`8000003P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`<00000103oool004/0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0
oooo00@000000?ooo`3oool00000603oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0803oool200000100oooo00<000000?ooo`3oool01@3oool60000
00h0oooo0P00000C0?ooo`D00000103oool2000001@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0
oooo00@000000?ooo`3oool000005`3oool2000000P0oooo0P00000H0?ooo`8000008@3oool20000
0180oooo00<000000?ooo`3oool00`3oool2000001H0oooo00<000000?ooo`3oool05@3oool50000
00030?ooo`000000oooo01<0oooo0P0000050?ooo`030000003oool0oooo00`0oooo0P0000070?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02P0oooo00D000000?ooo`3o
ool0oooo000000090?ooo`040000003oool0oooo000001L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01l0oooo0P00000D0?ooo`030000003oool0
oooo00<000006@3oool2000001X0oooo1000000D0?ooo`030000003oool0oooo00<0oooo0P00000>
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3o
ool0000002`0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000005P3o
ool2000000T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`X000005@3o
ool3000001h0oooo00<000000?ooo`3oool06P3oool3000001<0oooo0P0000050?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`050000003o
ool0oooo0?ooo`000000:`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool010000000oooo0?oo
o`00000F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05P3oool2000001@0oooo
1P0000060?ooo`040000003oool0oooo0?ooo`T000002P3oool300000240oooo0P00000L0?ooo`80
0000503oool2000000@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02H0oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0000001H0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo1@00000:0?ooo`8000003@3oool4000000@0
oooo0P0000020?ooo`030000003oool0oooo0240oooo0P00000L0?ooo`800000503oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`000000:P3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`0U0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`00
0000oooo0000000E0?ooo`8000002P3oool00`000000oooo0?ooo`0E0?ooo`8000003P3oool40000
00h0oooo00<000000?ooo`3oool04@3oool4000000@0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0K0?ooo`8000004`3oool2000000<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000000Y
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000001@0oooo00<00000
0?ooo`3oool0203oool2000001L0oooo00<000000?ooo`3oool02P3oool400000100oooo0P00000D
0?ooo`8000000P3oool5000002H0oooo0P00000L0?ooo`<000004`3oool01@000000oooo0?ooo`3o
ool0000000d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`0T0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo0?oo
o`00000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`070?ooo`@000004P3oool2000001@0oooo0P0000080?ooo`<000009P3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
8`3oool01@000000oooo0?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000503oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01D0oooo0P0000080?ooo`8000005@3oool00`00
0000oooo0?ooo`0B0?ooo`8000002P3oool00`000000oooo0?ooo`0200000080oooo2`00000H0?oo
o`8000006`3oool400000180oooo0P0000020?ooo`800000303oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000000W0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo0280oooo00D000000?ooo`3oool0oooo00000008
0?ooo`040000003oool0oooo000001@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00H0oooo0P00000F0?ooo`030000003oool0oooo0140oooo0P00
000:0?ooo`X000002P3oool800000180oooo00<000000?ooo`3oool06P3oool010000000oooo0000
0000000B0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000000V0?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo0280oooo00D000000?ooo`3oool0oooo000000070?oo
o`050000003oool0oooo0?ooo`0000004`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01@0oooo0P0000070?ooo`8000005P3oool200000180oooo0P0000060?ooo`H000000P3oool0
0`000000oooo0?ooo`050?ooo`<000003`3oool300000100oooo0P00000K0?ooo`040000003oool0
oooo00000180oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool08@3oool01@000000oooo0?oo
o`3oool0000000L0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`8000005`3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo100000080?ooo`030000003oool0oooo00P0
oooo0P00000@0?ooo`<000003`3oool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo0000
0180oooo0P0000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000009@3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo0?ooo`000000203oool0
10000000oooo0?ooo`00000C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`040?ooo`800000603oool00`000000oooo0?ooo`0@0?ooo`8000000P3o
ool3000000`0oooo00<000000?ooo`3oool02P3oool200000140oooo0`00000=0?ooo`8000006P3o
ool00`000000oooo0?ooo`0200000180oooo00@000000?ooo`3oool00000303oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000000T0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0200oooo00@000000?ooo`3oool0
0000203oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0C0?ooo`8000001@3oool2000001P0oooo0P00000B0?ooo`030000003oool0oooo
008000003`3oool00`000000oooo0?ooo`0<0?ooo`8000004P3oool3000000`0oooo00<000000?oo
o`3oool0603oool01@000000oooo0?ooo`3oool000000180oooo00@000000?ooo`3oool000002`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0080oooo001;0?ooo`800000803oool0
1@000000oooo0?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0403oool500000140oooo00<000000?ooo`3oool0
3P3oool2000001<0oooo0P00000;0?ooo`8000006@3oool01@000000oooo0?ooo`3oool000000180
oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00X0oooo00D000000?ooo`3oool0oooo0000000Q0?ooo`<00000103oool004/0oooo00<000000?oo
o`3oool07P3oool01@000000oooo0?ooo`3oool0000000P0oooo00@000000?ooo`3oool000004P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00l0oooo1000000D0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool04P3oool2000000/0oooo00<000000?ooo`3oool05`3o
ool200000080oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000;0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool000000280
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool07P3oool010000000oooo
0?ooo`0000080?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool00`3oool2000001P0oooo0P00000A0?oo
o`<000005P3oool00`000000oooo0?ooo`0A0?ooo`800000503oool2000000X0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0200000100oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3o
ool000000280oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool07@3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000
003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0@0?ooo`800000603oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo01<0oooo0P0000090?ooo`030000003oool0oooo01P0oooo00D000000?ooo`3oool0
oooo0000000@0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000000Q0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo01`0oooo00D000000?ooo`3oool0oooo00000008
0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0?0?ooo`8000006P3oool00`000000oooo0?ooo`0D0?ooo`8000005@3oool2000000P0oooo00<0
00000?ooo`3oool0603oool01@000000oooo0?ooo`3oool000000100oooo00D000000?ooo`3oool0
oooo0000000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool010000000
oooo0?ooo`00000Q0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01`0
oooo00D000000?ooo`3oool0oooo000000070?ooo`040000003oool0oooo00000180oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo0P00000H
0?ooo`800000403oool2000001`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0D
0?ooo`8000001`3oool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo0?ooo`8000003`3o
ool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0:0?ooo`040000003oool0oooo00000200oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool06`3oool01@000000oooo0?ooo`3oool0000000L0oooo00D000000?ooo`3o
ool0oooo0000000A0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03P3oool30000
01d0oooo00<000000?ooo`3oool05`3oool2000001H0oooo0P0000060?ooo`8000006@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo0000000:
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00
000P0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01/0oooo00D00000
0?ooo`3oool0oooo000000070?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000001h0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
5`3oool2000000<0oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000/0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo0000
01l0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool06P3oool01@000000
oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool0oooo0P00000H0?ooo`8000003`3o
ool4000001l0oooo00<000000?ooo`3oool06P3oool2000001H0oooo0P0000060?ooo`030000003o
ool0oooo01P0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`050000003oool0oooo0?ooo`00
00002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3o
ool000007`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0J0?ooo`05
0000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000140oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo0?ooo`0000006@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool000000240oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0603o
ool01@000000oooo0?ooo`3oool0000000h0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00000N0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01T0oooo00D000000?ooo`3o
ool0oooo000000070?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0C0?ooo`8000000`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`0000008P3oool00`000000oooo0?ooo`0M0?ooo`8000005P3oool2
000000D0oooo00<000000?ooo`3oool0603oool01@000000oooo0?ooo`3oool0000000h0oooo00D0
00000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2@3oool010000000oooo0?ooo`00000N0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo01T0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?oo
o`000000403oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00d0oooo0P0000000`3o
ool000000?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3oool000003P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`090?ooo`040000003oool0oooo000001d0oooo00<000000?ooo`3oool00P3o
ool002l0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`060?oOW018
0000000000000000B9`0gooo2P3oool00`000000oooo0?ooo`0H0?ooo`050000003oool0oooo0?oo
o`0000001P3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000002@0oooo00<000000?ooo`3oool0803o
ool2000001H0oooo0P0000040?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3oool00000
3P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000001d0oooo00<000000?ooo`3o
ool00P3oool002h0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo
0080oooo00H0okmd0000001d_ol0oooo0?oOW018M;l:0?ooo`030000003oool0oooo01P0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`000000403oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`00000000009@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0H0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool0
10000000oooo0?ooo`00000L0?ooo`030000003oool0oooo0080oooo000]0?ooo`030?oog`2LB000
B9cO0080oooo00<0okmd0000B02Lgol02`3oool00`3o_g@0B9cO0?ooo`080?ooo`030000003oool0
oooo01L0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`000000
403oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00`0oooo0P0000000`3oool00000
0?ooo`0V0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3oool000003P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`040000003oool0oooo000001`0oooo00<000000?ooo`3oool00P3oool002d0
oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool:0?ooo`030?oo_`1d07@0_ooo
00P0oooo00<000000?ooo`3oool05`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo0P00000>
0?ooo`040000003oool0oooo000002P0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool010000000oooo0?oo
o`00000=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool000006`3oool00`000000
oooo0?ooo`020?ooo`00803oool00`3ooml0W4P0000000070000000604RLg`3oool0oooo0?oog`2L
B00007Bo0`3oool00`3OW4P0001809cOo`0:0?ooo`030?oog`2LB000M;oo00P0oooo00<000000?oo
o`3oool05P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo0000
000?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03@3oool010000000oooo0?oo
o`00000Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3oool000003@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`080?ooo`040000003oool0oooo000001/0oooo00<000000?ooo`3oool00P3oool002h0
oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?ooo`030?oo_`1d0000B9cO00P0
oooo0`00000F0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0=0?oo
o`040000003oool00000000002X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool00`000000oooo0000000>
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool000005`3oool4000000@0oooo000^
0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l02P3oool00`3o_g@0000007Boo`08
0?ooo`030000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003o
ool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`000000;03oool00`000000oooo0?ooo`0W0?ooo`8000005P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01P0oooo00<000000?ooo`0000003P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`080?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool00P3oool002h0oooo
00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`060?ooo`060?oOg`3Oool0okmd00000000
07@0_ooo203oool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000001@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool0
0`000000oooo0000000=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000
000I0?ooo`030000003oool0oooo0080oooo000^0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0
gia80018W03Oool01P3oool01@3ookl0M0000000000004P0W=oo00T0oooo00<000000?ooo`3oool0
5@3oool010000000oooo0?ooo`0000060?ooo`050000003oool0oooo0?ooo`0000003`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000;P3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool01000
0000oooo0?ooo`00000I0?ooo`030000003oool0oooo0080oooo000_0?ooo`030?oOW0180000M;oo
0080oooo00<0gia8001d_`3oool01`3oool00`3OW9`0_ooo0?ooo`0:0?ooo`030000003oool0oooo
01@0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`000000;`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`040000003oool0oooo000000d0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`000000
2P3oool01@000000oooo0?ooo`3oool0000001P0oooo00<000000?ooo`3oool00P3oool00300oooo
00H0gia80000M02oool0oooO09a80018W=l80?ooo`030?oOW01dW=l0oooo00X0oooo00<000000?oo
o`3oool0503oool01@000000oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0oooo0000
000?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000
000`0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01L0oooo00<000000?ooo`0000003@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`080?ooo`040000003oool0oooo000001P0oooo00<000000?ooo`3oool00P3oool00340oooo00@0
gia800000000000007Bo2P3oool01@2oM0000000000000000000B9cO00L0oooo00<000000?ooo`3o
ool0503oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`000000<@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0000000d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000002P3oool0
1@000000oooo0?ooo`3oool0000001L0oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool04`3oool01@000000oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0oooo
0000000?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01@0oooo0P00000?0?ooo`040000003oool0oooo00000340
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool05`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo00@000000?ooo`3oool000005`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0>0?oo
o`040000003oool0oooo00000380oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool2000000d0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002P3o
ool010000000oooo0?ooo`00000G0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo01<0oooo00@000000?ooo`3oool000001@3oool01@000000oooo0?ooo`3oool0000000l0
oooo00D000000?ooo`3oool0oooo0000000C0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000003<0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool05`3oool2000000d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`06
0?ooo`040000003oool0oooo000000/0oooo00@000000?ooo`3oool000005P3oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`00
00004P3oool2000000H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0>0?ooo`04
0000003oool0oooo000003@0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool2000000`0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002P3oool0
10000000oooo0?ooo`00000F0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo0180oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000
3`3oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000003D0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0000001H0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3o
ool000000140oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00h0oooo00@000000?ooo`3oool00000=P3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000002P3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000103oool01@00
0000oooo0?ooo`3oool0000000l0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03P3oool010000000oooo0?oo
o`00000g0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000002P3oool010000000
oooo0?ooo`00000E0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0140
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0303oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000003P0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool05P3oool2000000`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`050?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0000000E0?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool0
0000403oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool03P3oool01@000000oooo0?ooo`3oool0000003P0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05P3oool20000
00/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo
000000X0oooo00@000000?ooo`3oool00000503oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`0A0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0
oooo0000000i0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo0P00000;0?ooo`030000003oool0oooo00@0
oooo300000090?ooo`040000003oool0oooo000001@0oooo00<000000?ooo`3oool00P3oool004/0
oooo0P00000A0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo0?ooo`D000001P3oool010000000oooo0?ooo`00000?0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`050000003o
ool0oooo0?ooo`000000>P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0000000X0oooo
00<000000?ooo`3oool00P3oool3000000L0oooo00<000000?ooo`3oool00P0000090?ooo`040000
003oool0oooo00000140oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`0@0?ooo`050000
003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`3oool5000000D0oooo1`0000000`3o
ool000000?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0?0?ooo`040000003oool0oooo000003/0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0000000:0?ooo`040000003oool00000000000<0oooo00<000000?ooo`3oool01@3o
ool010000000oooo0000003oool2000000L0oooo00@000000?ooo`3oool000004`3oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool00`00000>0?ooo`<000003`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00000l0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01D0oooo0P00000:0?ooo`8000001P3oool00`000000oooo0?ooo`040?oo
o`040000003oool0oooo00000080oooo0P0000050?ooo`040000003oool0oooo000001<0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0000000800000303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool03P3oool010000000oooo0?ooo`00000m0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`0000001`3oool2000000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000oooo000000040?ooo`800000103oool010000000oooo0?ooo`00000B0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0
oooo000000030?ooo`8000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000<0
oooo0P0000090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0>0?ooo`040000003oool0oooo000003h0oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0503oool00`00
0000oooo000000050?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool03`3oool0
10000000oooo0?ooo`0000030?ooo`8000000`3oool00`000000oooo0?ooo`0<0?ooo`8000001P3o
ool2000000H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`000000?`3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`040000003o
ool0oooo00000080oooo0P0000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo000000060?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0?0?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`80
0000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000003l0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`02000000L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`040?ooo`8000001P3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0>0?oo
o`050000003oool0oooo0?ooo`0000000P3oool2000000<0oooo00<000000?ooo`3oool01@3oool:
000000T0oooo0P0000000`3oool000000?ooo`0;0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03`3oool010000000oooo0?ooo`0000100?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool00P0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo000000060?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0>0?ooo`040000003o
ool0oooo00000080oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000070?ooo`800000
00<0oooo000000000000203oool2000000`0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool000000440oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool200000080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo
0P0000070?ooo`030000003oool000000080oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0>0?ooo`080000003oool0oooo0000003oool0
00000?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool20000
00@0oooo0P0000050?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool000000480oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool2
000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo0P0000070?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo
0?ooo`8000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo0P0000090?ooo`030000003o
ool0oooo00D0oooo0P0000020?ooo`030000003oool0oooo0080oooo0P0000080?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0403oool00`000000oooo000000130?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00h0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool2000000L0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo00d0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000@0oooo00@000000?oo
o`3oool000002`3oool00`000000oooo0?ooo`070?ooo`8000001`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool00`000000oooo00000014
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`800000203o
ool200000080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo008000000P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`800000203o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04@3o
ool2000004D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00@0oooo0P0000080?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000<0oooo
00L000000?ooo`3oool0oooo0000003oool000000080oooo1@0000040?ooo`8000002@3oool01000
0000oooo0?ooo`0000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0A0?ooo`800000AP3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool01`3oool2000000T0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`040?ooo`800000203oool01@000000oooo0?ooo`3oool0000000l0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo00000002000000D0oooo1P00
00080?ooo`030000003oool0oooo0080oooo0P0000070?ooo`040000003oool0oooo000000h0oooo
00<000000?ooo`3oool04@3oool00`000000oooo000000160?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
0P0000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool0303oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo0?ooo`<0
00002`3oool5000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0000000d0oooo00<000000?ooo`3oool04P3oool2000004L0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo0P0000080?ooo`04
0000003oool0oooo000000l0oooo00<000000?ooo`3oool00P3oool004/0oooo0P00000=0?ooo`04
0000003oool00000000000<0oooo00@000000?ooo`3oool0oooo0P00000;0?ooo`030000003oool0
000000<0oooo0`0000000`3oool000000?ooo`080?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0B0?ooo`800000B03oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3o
ool0000000/0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`80000000<0oooo0000003oool0
303oool3000000@0oooo001;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P00
00030?ooo`030000003oool0oooo00800000303oool2000000L0oooo0P00000:0?ooo`030000003o
ool0oooo00@0oooo0P00000;0?ooo`030000003oool0oooo0180oooo0P0000190?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0:0?ooo`<00000303o
ool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0
103oool2000000L0oooo0P0000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool02`3oool01@000000oooo0000003oool000000080oooo
00<000000?ooo`0000000`00000;0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0
0P0000090?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`0B0?ooo`800000BP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool02`3oool2000000d0oooo00<000000?ooo`3oool01@3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool20000
0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`0;0?ooo`040000003oool00000000000<0oooo0P0000020?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`800000203oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool2000001D0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`02000000/0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo000000040?ooo`X000000P3oool00`000000oooo0?ooo`060?ooo`80000000<0oooo
0000003oool03@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0;0?oo
o`80000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`02000000/0oooo00<000000?oo
o`0000001@3oool00`000000oooo0?ooo`060?ooo`8000001`3oool00`000000oooo000000050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?oo
o`H000001P3oool010000000oooo0?ooo`3oool4000000L0oooo0P0000000`3oool000000?ooo`0=
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00X0oooo00D000000?oo
o`000000oooo000000020?ooo`8000000P3oool2000000X0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`090?ooo`8000001P3oool2000000H0oooo1000000F0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool2000000T0oooo00<000000?ooo`3oool01@3o
ool4000000T0oooo00<000000?ooo`3oool0103oool2000000H0oooo0P0000020?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02P3oool0
1@000000oooo0000003oool000000080oooo00<000000?ooo`3oool00P00000;0?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0303oool6000000030?ooo`000000oooo00D0oooo
0`00000F0?ooo`800000C@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`D00000103oool010000000oooo
0?ooo`3oool4000000<0oooo0P0000090?ooo`030000003oool0oooo00<0oooo0`0000050?ooo`05
0000003oool000000?ooo`0000003@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`0:0?ooo`80000000@0oooo0000003oool0oooo0P0000020?ooo`8000002P3oool01P00
0000oooo0?ooo`3oool000000?ooo`8000005@3oool8000000<0oooo00<000000?ooo`3oool04P3o
ool2000004h0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool03P3oool8000000L0oooo00<000000?ooo`000000203o
ool00`000000oooo0?ooo`030?ooo`80000000<0oooo0000003oool00`3oool01@000000oooo0000
003oool0000000d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02P3o
ool2000000040?ooo`000000oooo0?ooo`8000000P3oool2000000T0oooo00L000000?ooo`3oool0
oooo0000003oool0000001L0oooo00@000000?ooo`3oool00000203oool200000140oooo0P00001?
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0203oool00`000000oooo00000008
0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool0000000d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
2@3oool01P000000oooo0000003oool000000?ooo`8000000P3oool00`000000oooo000000090?oo
o`040000003oool0oooo0?ooo`8000005`3oool01@000000oooo0?ooo`3oool0000000X0oooo0P00
000=0?ooo`80000000<0oooo0000003oool0CP3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo0100oooo00D000000?ooo`3oool0oooo0000000F0?ooo`030000003oool0oooo00P0oooo
00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool000000080
oooo00H000000?ooo`3oool0oooo0000003oool2000000d0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool02@3oool200000080oooo00@000000?ooo`00000000000P3oool2
000000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02@3oool2000000T0oooo0P0000020?ooo`030000003oool0
oooo04h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0
oooo000001L0oooo00<000000?ooo`3oool01`3oool4000000030?ooo`000000oooo00H0oooo00<0
00000?ooo`3oool00P3oool2000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo0000
00`0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02@3oool20000000:
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000T0oooo00@000000?ooo`3oool0
oooo0P00000G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool2000000@0
oooo0`0000030?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0C03oool00`000000
oooo0?ooo`0?0?ooo`8000006@3oool00`000000oooo0?ooo`040?ooo`8000000P3oool00`000000
oooo00000002000000H0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00P000000?ooo`3o
ool000000?ooo`000000oooo000000`0oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool02@3oool20000000:0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00P0oooo00@000000?ooo`3oool0oooo0P00000H0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02`3oool4000000H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`02
0?ooo`800000103oool010000000oooo0?ooo`3oool2000000H0oooo00L000000?ooo`3oool0oooo
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool2000000`0oooo00<000000?ooo`3o
ool00P3oool004/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`02000000070?oo
o`000000oooo0?ooo`000000oooo000000070?ooo`070000003oool0oooo0?ooo`000000oooo0000
000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`1@0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool02`3oool2000000030?ooo`00
0000oooo01P0oooo00<000000?ooo`3oool00P0000060?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`800000303oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`080?ooo`8000000P3oool2000000040?ooo`000000oooo00000080oooo00<000000?ooo`3o
ool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0500oooo00<000000?oo
o`3oool0C`3oool2000000X0oooo00D000000?ooo`3oool0oooo0000000J0?ooo`8000002@3oool0
0`000000oooo0?ooo`020?ooo`<00000103oool01P000000oooo0?ooo`000000oooo000000@0oooo
0P0000020?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool0203oool2000000080?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`030000003oool0oooo00@0oooo00@000000?ooo`00000000000`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1A
0?ooo`030000003oool0oooo0540oooo0P0000070?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000000`3oool010000000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`0000000P3o
ool2000000/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0203oool2
000000030?ooo`00000000000080oooo00D000000?ooo`000000oooo000000060?ooo`<00000103o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo05<0oooo1`0000060?ooo`030000003o
ool0oooo01H0oooo0P00000:0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0`3oool01P000000oooo0?ooo`000000oooo000000@0oooo0P0000020?ooo`8000002`3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool2000000T0oooo00<000000?ooo`3oool00P000000103oool0
00000?ooo`0000020?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`060000003o
ool0oooo0000003oool00000103oool200000080oooo0P0000090?ooo`<00000103oool004/0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02000000040?ooo`000000oooo00000080
oooo00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`1Q0?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`030000003oool0oooo00<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<0
00000?ooo`000000103oool200000080oooo00<000000?ooo`0000002P3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`080?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo0?ooo`8000002P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`080?ooo`040000003oool0000000000080oooo00<000000?ooo`0000000P3oool01P00
0000oooo0?ooo`000000oooo000000L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool200000080oooo00<0
00000?ooo`000000103oool010000000oooo0?ooo`3oool2000000X0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool01`3oool2000000070?ooo`00000000000?ooo`000000
oooo000000030?ooo`<000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool03`3oool2000000P0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`1S0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool01@000000
oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P00000:0?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo00L0oooo0P0000001`3oool000000000003oool00000
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3o
ool3000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool00P00000:0?ooo`030000003o
ool0oooo0080oooo000<0?ooo`030?oo_`1dM;l0oooo03`0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`02000000040?ooo`000000oooo00000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3o
ool200000080oooo0P00001J0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`030?ooo`@000001@3oool00`000000oooo0?ooo`02000000X0oooo00<0
00000?ooo`3oool00P3oool000`0oooo00@0omnL04P0000004P0W=oo>`3oool00`000000oooo0?oo
o`070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0E0?ooo`80
0000G03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00`3oool2000000030?ooo`000000000000@0oooo0P0000020?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool000h0oooo00<0_g@00000000000000`0000000`0007@0_ooo
0?ooo`0d0?ooo`030000003oool0oooo00L0oooo00H000000?ooo`3oool000000?ooo`0000020?oo
o`040000003oool00000000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`0000000000103oool200000080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`004P3oool00`3ogi`0B00007Boo`0f
0?ooo`030000003oool0oooo00L0oooo00P000000?ooo`3oool000000?ooo`000000oooo00000080
oooo0P0000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`1c0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo0P0000020?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00P3oool00140oooo00<0gia80000M02oool0=`3oool00`000000
oooo0?ooo`070?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0M03oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool00P0000090?ooo`03
0000003oool0oooo0080oooo000<0?ooo`060?oOW01804P0W=oo0?noM0000000B9cO>@3oool00`00
0000oooo0?ooo`070?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`00000:0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0000000000040?ooo`80000000<0oooo0000000000002@3oool00`000000oooo0?oo
o`020?ooo`00303oool0103ogi`0B00000000000M;lk0?ooo`030000003oool0oooo00L0oooo00L0
00000?ooo`3oool000000?ooo`000000oooo008000000P3oool00`000000oooo0000000:0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?oo
o`80000000<0oooo0000000000002@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`070?ooo`070000003oool000000000003oool000000?ooo`0200000080oooo00<00000
0?ooo`0000002P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool0I`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool00000103oool2000000030?ooo`000000000000T0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool01P3oool2000000040?ooo`000000000000000080oooo0P00
00020?ooo`8000002P3oool00`000000oooo0?ooo`0:0?ooo`<00000203oool00`000000oooo0?oo
o`1d0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo008000000`3oool2000000030?ooo`000000000000T0oooo00<0
00000?ooo`3oool00P3oool000l0oooo00H0gia800000000000000000000B02Lgolf0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`000000203oool000000?ooo`000000oooo0000
003oool000002P3oool00`000000oooo0?ooo`080?ooo`8000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0080oooo0P0000000`3oool00000000000030?ooo`030000003oool0
0000008000002@3oool00`000000oooo0?ooo`020?ooo`003@3oool02@3ookl0M00004RLg`3ogi`0
W;oo0?ooo`3OW4P004RL0=ooo`0e0?ooo`8000001`3oool01`000000oooo0?ooo`000000oooo0000
003oool00P0000020?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0M@3oool00`00
0000oooo0?ooo`1Y0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool200000080oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000001`3oool3000000@0oooo000=0?ooo`090;md
M02oool0oooo0?noW02Lgol0oooo0?oo_`1d07@0_ooo03D0oooo00<000000?ooo`3oool01P3oool0
1`000000oooo0?ooo`000000oooo0000003oool00P0000020?ooo`8000002`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`1e0?ooo`030000003oool0oooo06X0oooo0`00000A0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`8000000P3oool02@000000oooo
0?ooo`3oool000000?ooo`000000oooo000000090?ooo`030000003oool0oooo0080oooo000<0?oo
o`090?oOW02L_ol0oooo0?oog`2LM9`0gooo0?ooo`3ogi`0B7Bo03H0oooo00<000000?ooo`3oool0
1P3oool01`000000oooo0?ooo`000000oooo0000003oool00P0000020?ooo`8000002`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`1e0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo0P0000000`3oool00000000000020?oo
o`050000003oool000000?ooo`0000002@3oool00`000000oooo0?ooo`020?ooo`00303oool02@3o
_i`0W=oo0?ooo`2oM000M;oo0?ooo`3OW4P0001d0;ooo`0f0?ooo`030000003oool0oooo00H0oooo
00L000000?ooo`3oool000000?ooo`000000oooo008000000P3oool2000000/0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000N03oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`80000000<0oooo0000000000000P3oool01@000000oooo0000003o
ool0000000T0oooo00<000000?ooo`3oool00P3oool000`0oooo00@0oono07@000000000M;oo>`3o
ool00`000000oooo0?ooo`060?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`050000003oool0oooo0?ooo`000000N03oool00`000000oooo0?ooo`1o0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`80000000<0oooo
0000000000000P3oool01@000000oooo0000003oool0000000T0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool01P3oool020000000oooo000000000000oooo0000003oool0
00000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool0000007P0oooo00<000000?ooo`3oool0O`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0000000200000080oooo00D000000?ooo`000000oooo000000090?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo00H0oooo00P000000?ooo`00000000000?ooo`00
0000oooo00000080oooo0P00000;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`00001h0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00/000000?ooo`00
000000000?ooo`000000oooo0000003oool000000?ooo`02000000P0oooo00<000000?ooo`3oool0
0P3oool00100oooo00H0okmd00000000000000000000M02ooole0?ooo`030000003oool0oooo00H0
oooo00P000000?ooo`00000000000?ooo`000000oooo00000080oooo0P00000;0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0000001i0?ooo`030000003o
ool0oooo07l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`000000oooo0P0000001@3oool000000?ooo`000000oooo0080
0000203oool00`000000oooo0?ooo`020?ooo`00203oool01P2oW9`0gooo0?ooo`3oool0omnL04P0
00<0000000@004RL0=ooo`3ookl0M7Bo=P3oool00`000000oooo0?ooo`060?ooo`050000003oool0
00000000003oool00`0000020?ooo`8000002`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00T0oooo0P00001i0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00@000000?ooo`000000oooo
0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`020?ooo`001`3o
ool00`3ooml0W4P00000000300000003001d_`3oool0oooo0080oooo00<0okmd0000M02oool0=P3o
ool00`000000oooo0?ooo`050?ooo`80000000@0oooo000000000000oooo0`0000020?ooo`800000
2`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo0P00001i0?ooo`030000
003oool0oooo07X0oooo0P0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`040000003oool000000?ooo`8000000P3oool200000003
0?ooo`000000000000P0oooo00<000000?ooo`3oool00P3oool000L0oooo00<0oono07@00018W=l0
@@3oool00`000000oooo0?ooo`050?ooo`80000000@0oooo000000000000oooo0`000000103oool0
00000?ooo`00000;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool20000
07T0oooo00<000000?ooo`3oool0N@3oool00`000000oooo000000030?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`040000003oool00000
0?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool01@3oool2000000040?ooo`00000000000?ooo`<0000000<0oooo
000000000000303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo0P00001i
0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool010000000oooo0000003o
ool200000080oooo0P0000000`3oool00000000000080?ooo`030000003oool0oooo0080oooo000?
0?ooo`060?oOW018000000000000000004P0W=oo:03oool0102oM00000000000001d_ol:0?ooo`03
0000003oool0oooo00D0oooo0P000000103oool000000000003oool3000000030?ooo`0000000000
00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`800000N@3oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00@000000?ooo`000000oooo0P000002
0?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`020?ooo`003P3oool00`2o
M000000007Boo`020?ooo`030?oog`2LM9`0gooo02H0oooo00H0gia8001d_`3oool0omnL04P00018
W=l90?ooo`030000003oool0oooo00D0oooo0P000000103oool000000000003oool3000000030?oo
o`000000000000`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`800000
N@3oool00`000000oooo0?ooo`1i0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00@000000?ooo`00
0000oooo0P0000020?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`020?oo
o`003@3oool00`3OW4P0B9cO0?ooo`040?ooo`030=nLW02oool0oooo02@0oooo00<0oooO09a80018
W=l00P3oool00`3o_g@0001809cOo`080?ooo`030000003oool0oooo00D0oooo0P000000103oool0
00000000003oool3000000030?ooo`000000000000`0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`090?ooo`800000N@3oool00`000000oooo0?ooo`1i0?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo00P000000?ooo`000000oooo0000003oool000000?ooo`80000000<0oooo00000000
0000203oool00`000000oooo0?ooo`020?ooo`00303oool00`3ogi`0M9cO0?ooo`040?ooo`030?oo
g`2LM9`0gooo02D0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool70?ooo`03
0000003oool0oooo00D0oooo0P000000103oool000000000003oool3000000030?ooo`0000000000
00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool0N@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080000000<0oooo0000003oool00P0000000`3oool00000000000080?ooo`030000003oool0
oooo0080oooo000<0?ooo`030?noW02Lgol0oooo00<0oooo00<0oooO09a8001d_ol09P3oool00`3o
oml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00L0oooo00<000000?ooo`3oool01@3oool20000
00040?ooo`00000000000?ooo`<0000000<0oooo000000000000303oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00T0oooo0P00001i0?ooo`030000003oool0oooo07T0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`02000000030?ooo`000000oooo0080000000<0
oooo000000000000203oool00`000000oooo0?ooo`020?ooo`00303oool00`3ogi`0B7Bo0?ooo`02
0?ooo`030=nLB0000000B9cO02P0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`07
0?ooool00000HP0000040?ooo`003@3oool01P3o_g@0000000000000000004RL0=ooobT0oooo00<0
gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`070?ooo`030000003oool0oooo00D0oooo0P00
0000103oool000000000003oool3000000030?ooo`000000000000`0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
N@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`080000003oool0oooo0?ooo`000000oooo0000003o
ool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool00P3oool003`0oooo00<0omnL
04P00018W=l00`3oool00`2oM00004RL0=ooo`060?ooo`030000003oool0oooo00D0oooo0P000000
103oool000000000003oool3000000030?ooo`000000000000`0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`240?ooo`030000003oool0oooo07T0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0P3oool020000000oooo0?ooo`3oool000000?ooo`000000oooo0P0000000`3oool0000000000008
0?ooo`030000003oool0oooo0080oooo000l0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia8
0018W03Oool01P3oool00`000000oooo0?ooo`050?ooo`80000000@0oooo000000000000oooo0`00
00000`3oool000000000000<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0Q03o
ool00`000000oooo0?ooo`1i0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00P000000?ooo`3oool0
oooo0000003oool000000?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`02
0?ooo`003`3oool01P3ogi`0B000000000000000001809cOobP0oooo00<0omnL04P0001d_ol00P3o
ool00`3OW4P007Bo0?ooo`060?ooo`030000003oool0oooo00H0oooo00D000000?ooo`0000000000
0?ooo`03000000040?ooo`000000oooo000000/0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`240?ooo`030000003oool0oooo07D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo00P000000?ooo`3oool0oooo0000003oool000000?ooo`80000000<0oooo00000000
0000203oool00`000000oooo0?ooo`020?ooo`003@3oool0103ooml0W4P00018W03Oool20?ooo`03
0?noM000B9`0gooo02P0oooo00H0gia80000M02oool0oooO09a80018W=l70?ooo`030000003oool0
oooo00H0oooo00D000000?ooo`00000000000?ooo`0300000080oooo0P00000;0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`1e0?ooo`8000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`080000003oool0oooo0?ooo`000000oooo0000003oool2
000000030?ooo`000000000000P0oooo00<000000?ooo`3oool00P3oool000d0oooo00<0_gA809cO
o`3oool00`3oool00`3ooml0W4Qd0;ooo`0Y0?ooo`040=nLB00000000000001d_`P0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo000000000000oooo00<000000P3oool2000000/0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo07@0oooo00<0
00000?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`080000003oool0oooo0?ooo`00
0000oooo0000003oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool00P3oool0
00`0oooo00<0omnL09boo`3oool0103oool00`3ogi`0B7Bo0?ooo`0e0?ooo`030000003oool0oooo
00H0oooo00D000000?ooo`00000000000?ooo`0300000080oooo0P00000;0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`050000
003oool000000000003oool00P0000080?ooo`030000003oool0oooo0080oooo000<0?ooo`030?no
W02Lgol0oooo00<0oooo00<0omnL04Q8W03Oool0=P3oool00`000000oooo0?ooo`060?ooo`050000
003oool000000000003oool00`0000020?ooo`8000002`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo08@0oooo00<000000?ooo`3oool0L`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`800000
00<0oooo000000000000203oool00`000000oooo0?ooo`020?ooo`00303oool0103ookl0M0000000
001d_olk0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`00000000000?ooo`0300000080
oooo0P00000<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`1a0?ooo`030000003oool0oooo07<0oooo00@000000?ooo`3oool000000`3oool01@00
0000oooo0000003oool0000000X0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`0000000P3oool2000000030?ooo`000000000000P0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01P3oool020000000oooo00000000
0000oooo0000003oool000000P3oool2000000`0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool000000780oooo00<000000?ooo`3oool0L`3oool01@000000
oooo0?ooo`3oool000000080oooo0P0000020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool01@000000oooo0?ooo`3oool0000000<0oooo00P000000?ooo`000000oooo0000
003oool000000?ooo`800000203oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`060?ooo`080000003oool000000000003oool000000?ooo`0000020?ooo`800000303oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`000000LP3oool0
0`000000oooo0?ooo`1c0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0000
000;0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000030?ooo`080000
003oool000000?ooo`000000oooo0000003oool2000000P0oooo00<000000?ooo`3oool00P3oool0
00`0oooo00<0oono09bLg`3oool00`3oool0103o_g@000000000M02ooole0?ooo`030000003oool0
oooo00H0oooo00@000000?ooo`00000000000P3oool2000000<0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo
0000001a0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`03000000/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`0<0000
003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0P0000080?ooo`030000
003oool0oooo0080oooo000<0?ooo`040?oo_`2LW=l0oono07@000@0000000<004RL0=ooo`3oool0
=03oool00`000000oooo0?ooo`060?ooo`040000003oool0000000000080oooo0P0000030?ooo`80
00002`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3o
ool0oooo0000001a0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`00000<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000020?ooo`060000003oool000000?ooo`000000oooo0P0000080?ooo`03
0000003oool0oooo0080oooo000<0?ooo`090?oOW018000000000000B02Lgol0oooo0?oog`2LB7@0
_ooo03H0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000020?ooo`<000000P3o
ool2000000/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1b0?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01P000000oooo0000003oool00000
0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`00203oool0103ooml0W4P00000M02ooolo
0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000000P3oool300000080oooo0P00
000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?oo
o`040?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`00000000000P3oool2000000P0
oooo00<000000?ooo`3oool00P3oool004/0oooo0P0000070?ooo`040000003oool0oooo00000080
oooo0`0000020?ooo`800000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool0103oool00`000000oooo0000000<0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool00000
00000080oooo0P0000060?ooo`<00000103oool000`0oooo00D0omno0;oOo`3oool0oooo0;md0003
000000030000M02oool0oooo03@0oooo00<000000?ooo`3oool01P3oool2000000040?ooo`000000
00000?ooo`<000000P3oool2000000`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?oo
o`1b0?ooo`030000003oool0oooo00@0oooo0P00000<0?ooo`030000003oool0oooo00P0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo0P0000020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool000`0oooo00<0_g@0000000000000
0P0000001@0007@0_ooo0?ooo`2oW9`0gooo03D0oooo00<000000?ooo`3oool01P3oool200000003
0?ooo`00000000000080oooo0P0000030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0K@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`080?ooo`070000003oool0oooo0?ooo`000000oooo00000003
0?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo000:0?ooo`050;md0000000000000018W03Oool00`3oool00`3ooml0W4P007Boo`02
0?ooo`030;md0000B9`0gooo0340oooo00<000000?ooo`3oool01P3oool2000000030?ooo`000000
00000080oooo0P0000030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0K@3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`080?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000
003oool0oooo008000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo
000<0?ooo`030?noW02Lgol0oooo00P0oooo00<0omnL04Qd_`3oool0<@3oool00`000000oooo0?oo
o`060?ooo`80000000<0oooo0000000000000P3oool2000000<0oooo0P00000<0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo06`0oooo00<000000?ooo`3oool0H`3oool2000000`0oooo00<000000?ooo`3oool01P3o
ool2000000X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`800000103o
ool00`000000oooo0?ooo`02000000030?ooo`000000000000T0oooo00<000000?ooo`3oool00P3o
ool000`0oooo00<0oono07Ad_`3oool01`3oool00`3o_g@004RL0=ooo`0b0?ooo`030000003oool0
oooo00L0oooo00@000000?ooo`00000000000P3oool2000000<0oooo0P00000<0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo06`0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`02000000X0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo000000080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00P3oool2000000<0oooo00@000000?ooo`3oool0oooo0P0000000`3oool00000
000000090?ooo`030000003oool0oooo0080oooo000<0?ooo`040?oOW0180000001d0;ooo`D0oooo
00<0gia8001d_`3oool0<`3oool00`000000oooo0?ooo`070?ooo`040000003oool0000000000080
oooo0P0000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool200000680
oooo00<000000?ooo`3oool0H03oool2000000D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P000000
0`3oool000000?ooo`090?ooo`030000003oool0oooo0080oooo000=0?ooo`030?oOW01800000000
00D0000000<0B9cO0?ooo`3oool0<`3oool00`000000oooo0?ooo`070?ooo`050000003oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01@3oool200000080oooo0P00001P0?ooo`030000003oool0oooo05l0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000303oool010000000oooo0?ooo`3o
ool2000000@0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000X0oooo00<000000?oo
o`3oool00P3oool00180oooo00<0okmd0000B02Lgol0=P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo008000000P3oool2000000<0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0G@3oool00`000000
oooo0?ooo`1O0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo1000000>0?ooo`050000003oool0oooo0?oo
o`0000001@3oool020000000oooo0?ooo`000000oooo0000003oool000002P3oool00`000000oooo
0?ooo`020?ooo`004@3oool00`2oM00007Bo0?ooo`0g0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00P0000020?ooo`8000000`3oool2000000d0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0GP3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo
0?ooo`3oool200000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00
303oool01P3ogi`0B00007Boo`3o_g@0000007BoocT0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?oo
o`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0
oooo05h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`02000000@0oooo00@00000
0?ooo`3oool0oooo0P0000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool000`0oooo00@0omnL04P00000000007Bo>`3oool00`000000oooo0?ooo`080?ooo`040000003o
ool00000000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000A0?ooo`050000003oool0oooo0?oo
o`0000002`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo05d0oooo00<000000?oo
o`3oool02`3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`02000000D0oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000000
000:0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00P0oooo00@00000
0?ooo`00000000000`3oool2000000<0oooo0P00000>0?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000004`3oool00`000000oooo0000000=0?ooo`030000003oool0oooo05T0oooo
00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000P0
oooo00<000000?ooo`3oool05@3oool01@000000oooo0000003oool0000000D0oooo00@000000?oo
o`3oool0oooo0P0000000`3oool000000000000:0?ooo`030000003oool0oooo0080oooo001;0?oo
o`030000003oool0oooo00P0oooo00D000000?ooo`000000oooo000000020?ooo`8000000`3oool2
000000l0oooo0P0000030?ooo`<00000503oool2000000l0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`1E0?ooo`D000000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
000000T0oooo00<000000?ooo`3oool05@3oool01@000000oooo0000003oool0000000@0oooo00P0
00000?ooo`3oool0oooo0000003oool000000?ooo`8000002P3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`080?ooo`050000003oool000000?ooo`0000000`3oool20000
0080oooo0P00000A0?ooo`@000005`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`030?ooo`<00000403oool20000
00P0oooo00<000000?ooo`3oool05P3oool200000080oooo00<000000?ooo`3oool00P3oool02@00
0000oooo0?ooo`3oool000000?ooo`000000oooo0000000;0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P0000030?ooo`030000003o
ool000000080oooo0P00000C0?ooo`030000003oool0oooo01@0oooo0P00000?0?ooo`D00000EP3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000
3`3oool2000000P0oooo00<000000?ooo`3oool05@3oool200000080oooo00<000000?ooo`3oool0
0`3oool01P000000oooo0?ooo`3oool000000?ooo`<000002`3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000000000000`3oool300000080
oooo0P00000D0?ooo`030000003oool0oooo0180oooo00<000000?ooo`0000003@3oool200000003
0?ooo`000000oooo0080oooo0P00001D0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool01@3oool01@000000oooo0?ooo`3oool0000000h0oooo0P0000080?ooo`030000003oool0oooo
01D0oooo00D000000?ooo`3oool0oooo000000050?ooo`060000003oool0oooo0?ooo`000000oooo
0`00000;0?ooo`030000003oool0oooo0080oooo001;0?ooo`8000002P3oool01@000000oooo0000
003oool000000080oooo0P0000000`3oool000000?ooo`02000001@0oooo00<000000?ooo`3oool0
4@3oool01@000000oooo0?ooo`3oool0000000X0oooo0P0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo0000
00H0oooo00<000000?ooo`3oool05@3oool2000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`80000000<0oooo0000000000002@3oool3000000@0oooo001;0?ooo`03
0000003oool0oooo00T0oooo00D000000?ooo`000000oooo000000020?ooo`8000000P3oool20000
00030?ooo`000000oooo0180oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0500oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0
000000D0oooo00<000000?ooo`3oool05@3oool200000080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`<0000000<0oooo0000003oool02P3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo008000000P3oool20000
00<0oooo0`00000C0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool20000
0500oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0503oool00`000000oooo000000020?ooo`030000003oool0oooo
00<0oooo00H000000?ooo`3oool0oooo0000003oool3000000`0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool02@3oool01P000000oooo0?ooo`000000oooo00000080oooo
0P0000030?ooo`800000503oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`@000001@3oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`3oool0000001H0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`06
0000003oool0oooo0?ooo`000000oooo0`00000<0?ooo`030000003oool0oooo0080oooo001;0?oo
o`030000003oool0oooo00T0oooo0P000000103oool000000?ooo`0000020?ooo`8000000`3oool3
000001<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0103oool300000080oooo00<000000?ooo`0000000P000003
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo000001D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000P00000<0?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00T0oooo0P000000103oool000000?oo
o`0000020?ooo`800000103oool400000140oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`070?ooo`050000003oool0oooo0?ooo`0000001@3oool2000000D0oooo00<000000?ooo`3o
ool00P3oool200000080oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`0000005@3oool01P000000oooo0?ooo`000000oooo
000000H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000`0oooo00<0
00000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02@3oool2000000040?ooo`000000
oooo00000080oooo00<000000?ooo`0000000`3oool010000000oooo0000003oool3000000h0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000@0oooo
0P0000080?ooo`030000003oool0oooo00<0oooo0`00001=0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`070000003oool0oooo0?ooo`00
0000oooo000000060?ooo`060000003oool0oooo0?ooo`000000oooo0P0000000`3oool000000?oo
o`0;0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00X0oooo00H00000
0?ooo`3oool000000?ooo`0000020?ooo`800000103oool2000000@0oooo2@0000060?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool2000000@0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`050?ooo`800000C03oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000X0
oooo0P00000C0?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000000P00000=0?ooo`030000003oool0oooo0080oooo001;0?oo
o`030000003oool0oooo00X0oooo0P000000103oool000000?ooo`0000020?ooo`800000103oool0
0`000000oooo0000000<0?ooo`D0000000<0oooo0000003oool02@3oool00`000000oooo0?ooo`0;
0?ooo`8000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo0P00001;
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`T000000P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo00000140oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000060?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0000000=0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo00X0oooo0P000000103oool000000?ooo`0000020?ooo`030000003oool0000000@0oooo
0P00000A0?ooo`@000001`3oool00`000000oooo0?ooo`0<0?ooo`8000000P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00D0oooo0P00001;0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`<00000203oool3000000X0oooo
00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo0080oooo0P0000070?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0000000=0?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo00X0oooo0P0000002@3oool000000?ooo`3oool00000
0?ooo`000000oooo000000040?ooo`030000003oool000000180oooo00@000000?ooo`0000000000
103oool00`000000oooo0?ooo`0<0?ooo`050000003oool000000?ooo`0000003`3oool00`000000
oooo0?ooo`050?ooo`800000BP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00`3oool2000000d0oooo0`0000070?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`00000000000P3oool0
1@000000oooo0000003oool0000000D0oooo0P00000B0?ooo`040000003oool0oooo0?ooo`800000
00<0oooo0000003oool03@3oool01@000000oooo0?ooo`3oool000000140oooo00<000000?ooo`3o
ool01@3oool2000004T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool010000000oooo0000003oool20000
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`0000003P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0:0?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`8000001P3oool200000140oooo00<0
00000?ooo`3oool00`3oool2000000d0oooo00@000000?ooo`3oool0oooo0P00000A0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool2000000l0oooo00@000000?ooo`3oool0
00000P3oool2000000<0oooo00<000000?ooo`3oool01@3oool2000000T0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo00000080oooo0P0000000`3o
ool000000?ooo`0=0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00/0
oooo00@000000?ooo`00000000000P3oool01@000000oooo0000003oool0000000H0oooo00<00000
0?ooo`3oool0403oool01@000000oooo0?ooo`3oool000000080oooo0P00000:0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00L0oooo
00D000000?ooo`3oool0oooo0000000@0?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0000000:0?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`800000203oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool02`3oool010000000oooo0000000000020?ooo`050000003o
ool000000?ooo`0000001`3oool200000100oooo00@000000?ooo`3oool000001@3oool00`000000
oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool2000000`0oooo0`0000030?ooo`030000003oool0
oooo00D000002@3oool00`000000oooo000000020?ooo`8000000P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00/0oooo00@000000?oo
o`3oool000000`3oool2000000030?ooo`000000oooo00H0oooo00<000000?ooo`0000003`3oool0
0`000000oooo000000070?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo0P0000160?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000A0?ooo`030000
003oool0oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool0000000h0oooo1P0000040?oo
o`030000003oool0oooo00H0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00003`3oool00`000000oooo0?ooo`020?ooo`00B`3oool2000000`0oooo00<000000?ooo`3oool0
0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000l0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000H0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0000
0180oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
00000080oooo0P0000020?ooo`030000003oool0oooo00/0oooo0`0000040?ooo`00B`3oool00`00
0000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000000`3oool2000000030?ooo`000000
oooo00H0oooo00@000000?ooo`3oool00000303oool3000000X0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`070?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool01`3oool2000000@0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0
oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
008000000P3oool2000000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool00P0000080?oo
o`8000000`3oool00`000000oooo0?ooo`080?ooo`030000003oool000000080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`0000004`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0P00000:0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000020?oo
o`030000003oool000000080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo008000000`3oool010000000
oooo0?ooo`0000070?ooo`030000003oool0oooo0080oooo200000050?ooo`030000003oool0oooo
00T0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`0000004`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo0P0000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo
0?ooo`8000000P3oool2000000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`070?ooo`040000003oool00000000000`0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`060?ooo`800000@P3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`000000503oool00`000000oooo0?ooo`080?ooo`040000003o
ool0oooo000000H0oooo0P0000050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0000000200000080oooo00@000000?ooo`3oool00000403oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00800000
0`3oool00`000000oooo000000080?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
1@3oool200000080oooo0P00000=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
203oool2000001@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00D0oooo0P0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool3000000@0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0=0?ooo`060000003oool0oooo0000003oool000000P3oool20000
00030?ooo`000000oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0203oool2000001D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo0`00000:0?ooo`030000003oool0
oooo00D0oooo0`0000040?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`0=0?ooo`080000003oool0oooo0?ooo`000000oooo
0000003oool2000000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0203oool2000001D0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`050?ooo`8000001`3oool3000000P0oooo00<000000?oo
o`3oool01P3oool2000000D0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`0>0?ooo`090000003oool0oooo0000003oool000000?oo
o`000000oooo008000002@3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`060?ooo`800000?`3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool20000
00H0oooo00<000000?ooo`3oool0103oool3000000H0oooo00@000000?ooo`3oool000004@3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`000000oooo0P0000080?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`0000000P3oool2000000P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00L0oooo0P00000n0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool02@3oool2000000<0oooo00<000000?ooo`3oool00`3oool5000000030?ooo`00
0000oooo0080oooo0`0000000`3oool000000?ooo`050?ooo`050000003oool0oooo0?ooo`000000
4@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0>0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0>0?ooo`8000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`070?ooo`800000?@3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00/0oooo0`00000;0?ooo`D000000P3oool3000000H0oooo
00D000000?ooo`3oool0oooo0000000A0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo00h0oooo00D000000?ooo`3oool0oooo000000030?ooo`80000000<0oooo00000000
0000203oool00`000000oooo0?ooo`0=0?ooo`050000003oool000000?ooo`0000003@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool30000
00X0oooo00<000000?ooo`3oool00P3oool2000000030?ooo`000000oooo00H0oooo00@000000?oo
o`3oool000004P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0?0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P0000080?ooo`030000003oool0
oooo00X0oooo0P0000020?ooo`8000003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool01P3oool2000003`0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0<0?ooo`040000003oool0oooo0?ooo`800000203oool00`000000oooo0?oo
o`02000000<0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`00000B0?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo
000000030?ooo`@0000000<0oooo0000000000001`3oool00`000000oooo0?ooo`060?ooo`<00000
0`3oool00`000000oooo0000000@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`070?ooo`800000>`3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00P0oooo0P00000F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`030?ooo`/00000103oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`0?0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo000000030?ooo`D0
00000P3oool00`000000oooo0?ooo`020?ooo`@00000103oool200000080oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool01`3oool2000003X0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`080?ooo`80
00005`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3o
ool0oooo0000000B0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0100
oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000070?ooo`L000001P3oool2
000000D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool01`3oool2000003T0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`080?ooo`8000005`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00H0oooo00@000000?ooo`3oool000004`3oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?oo
o`3oool2000000T0oooo00<000000?ooo`3oool0103oool2000000L0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
1`3oool2000003P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`080?ooo`030000
003oool0000001H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000004`3oool00`000000oooo0?ooo`020?ooo`00B`3oool200000140oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo100000050?ooo`03
0000003oool0oooo0080oooo0P00000:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo0P00000g0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000G0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool00000
0140oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool01P3oool:000000`0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0000000f0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool01`3oool01000
0000oooo0?ooo`00000F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0?ooo`3oool0000001<0oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool04@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000=@3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000
5P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0
oooo0000000D0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0140oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`070?ooo`030000003oool0000003@0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000001H0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000503oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`000000<`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo00L0oooo00D000000?ooo`3oool0oooo0000000F0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000001D0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`000000<P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00L0oooo
00D000000?ooo`3oool0oooo0000000F0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool0000001D0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`000000<@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00P0oooo00@000000?oo
o`3oool000005P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00D00000
0?ooo`3oool0oooo0000000F0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo01<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000`0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00000F0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000001H0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool04`3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`000000;`3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo00P0oooo00@000000?ooo`3oool000005`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0000000^0?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`00000G0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000001L0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`000000;@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00P0oooo00@0
00000?ooo`3oool000005`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo
000_0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol00P3oool01P3ogi`0B000
00000000000004RL0=ooo`X0oooo00<000000?ooo`3oool05@3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0000002`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`08
0?ooo`040000003oool00000000001L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`070?ooo`050000003oool0oooo0?ooo`000000603oool00`000000oooo0?ooo`020?ooo`00;P3o
ool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00P3oool01P3o_g@0
000007Boo`3oool0omnL04Qd_`X0oooo00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00L0oooo0`00000[0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0000000H0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00P3o
ool002d0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`0;0?ooo`030?noM018W=l0
oooo00P0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`800000:P3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000603o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo000]0?ooo`030?oog`2LB000
B9cO0080oooo00@0oooO09a80000B9`0gooo2P3oool00`3ookl0M01d0;ooo`080?ooo`030000003o
ool0oooo01H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`800000:@3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000603oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo0080oooo000]0?ooo`030?oog`2LB00007Bo00<0oooo00<0
gia80000B02Lgol02P3oool00`3ooml0W4P007Boo`080?ooo`030000003oool0oooo01H0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0F0?ooo`8000001P3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00P0oooo0P00000X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0000000H0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
0P3oool002h0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?ooo`030?oo_`1d
0000B9cO00P0oooo0`00000G0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool2000002L0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`080?ooo`030000003oool0000001P0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool05@3oool4000000@0oooo000^0?ooo`030=nLB00004P0W=oo0080oooo00<0
oooO09a80000M;l02P3oool00`3o_g@0000007Boo`080?ooo`030000003oool0oooo01L0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`080?ooo`8000009P3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo00L0oooo0P0000000`3oool000000?ooo`0H0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool00P3oool002h0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=oo
o`060?ooo`060?oOg`3Oool0okmd0000000007@0_ooo203oool00`000000oooo0?ooo`0H0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01<0oooo0P0000090?ooo`8000009@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00L0oooo00@000000?ooo`00000000006@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo0080oooo000^0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool01P3oool0
1@3ookl0M0000000000004P0W=oo00T0oooo00<000000?ooo`3oool0603oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00L0oooo0P00000T0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0000000J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
0P3oool002l0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`070?ooo`030=nLW02o
ool0oooo00X0oooo00<000000?ooo`3oool06@3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo
0P00000S0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0000000J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool00300oooo00H0
gia80000M02oool0oooO09a80018W=l80?ooo`030?oOW01dW=l0oooo00X0oooo00<000000?ooo`3o
ool06@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0D0?ooo`8000002@3oool200000240oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0000001X0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`020?ooo`00<@3oool0103OW4P0000000000000M;l:0?ooo`050;md000000000000
00000018W=l01`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo0000000C0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`040?ooo`8000005P3oool00`000000oooo0?ooo`070?ooo`800000803o
ool00`000000oooo0?ooo`0Q0?ooo`8000002@3oool00`000000oooo0000000J0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool06P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00L0oooo0P00000O0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0203oool3000001T0oooo0P00000=0?ooo`030000003oool0oooo00L0oooo0P00
000F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000004`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01T0oooo0P0000060?ooo`030000003o
ool0oooo01@0oooo0P0000080?ooo`8000007P3oool00`000000oooo0?ooo`0N0?ooo`8000002@3o
ool3000001X0oooo00<000000?ooo`3oool02`3oool2000000T0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo01/0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`060?ooo`8000007@3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000006P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000001@0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3o
ool2000000P0oooo0P00000K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0203o
ool3000001T0oooo0P00000=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo01`0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool05P3oool2000000L0oooo0P00000J0?ooo`030000003oool0oooo01X0oooo0P00
000:0?ooo`8000006P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo00@0oooo0P00000H0?ooo`030000003oool0oooo00D0oooo0P00000I
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0H
0?ooo`8000003P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0M0?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`050?ooo`8000005`3oool2
000000L0oooo0P00000G0?ooo`030000003oool0oooo01L0oooo0P00000:0?ooo`8000006P3oool0
0`000000oooo0?ooo`0<0?ooo`8000002P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0F0?ooo`8000001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01D0oooo0P00000:0?ooo`<000006P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000001D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0J0?oo
o`8000001`3oool2000001P0oooo0P0000060?ooo`800000503oool00`000000oooo0?ooo`0C0?oo
o`8000002P3oool3000001X0oooo0P00000>0?ooo`030000003oool0oooo00P0oooo0P00000I0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0?0?ooo`800000703oool00`000000oooo0?ooo`060?ooo`80
0000603oool2000000D0oooo0`00000B0?ooo`030000003oool0oooo0140oooo0P00000:0?ooo`80
000000<0oooo0000003oool06@3oool00`000000oooo0?ooo`0<0?ooo`8000002P3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool00P3oool004/0oooo
0P00000P0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000F0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`070?ooo`80
0000603oool3000000@0oooo0`00000@0?ooo`030000003oool0oooo00l0oooo0P0000080?ooo`@0
00000P3oool00`000000oooo0?ooo`0G0?ooo`8000003P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool07P3oool3000000@0oooo001;0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000001H0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00P0
oooo0P00000I0?ooo`8000000`3oool4000000h0oooo00<000000?ooo`3oool03@3oool2000000L0
oooo0`0000040?ooo`800000603oool2000000l0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00005P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool02@3oool3000001P0oooo0`0000020?ooo`@00000303oool00`000000oooo0?ooo`0;0?ooo`80
00001@3oool4000000H0oooo00<000000?ooo`3oool05P3oool2000000l0oooo0P00000;0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
6P3oool2000000`0oooo0`00000H0?ooo`T000002@3oool00`000000oooo0?ooo`080?ooo`<00000
0`3oool4000000P0oooo0P00000G0?ooo`800000403oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
0000000G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0<0?ooo`<000006@3oool8000000H0oooo00<000000?ooo`3oool0103oool:000000/0oooo
00<000000?ooo`3oool05@3oool200000100oooo0P00000<0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000G0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0>0?ooo`<00000
6P3ooolE000000l0oooo0P00000E0?ooo`<00000403oool2000000d0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0403oool2000001`0oooo0P00000A0?ooo`@00000603o
ool3000000030?ooo`00000000000080oooo1000000D0?ooo`800000503oool300000140oooo0P00
000=0?ooo`800000703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01D0oooo0P00000B0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool04P3oool4000001@0oooo2@00000F0?ooo`030000003oool0oooo0100oooo1000000B
0?ooo`8000003P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`030?oo
o`050000003oool0oooo0?ooo`0000006@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo01/0oooo0P00000F0?oooa@000001@3oool2000000030?ooo`000000000000<00000403oool2
000000l0oooo1000000D0?ooo`8000003`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0@0?ooo`8000007@3oool00`000000oooo0?ooo`0^0?ooo`<000000`3oool70000
00L0oooo0P00000=0?ooo`@000005@3oool300000100oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0K0?ooo`800000;`3oool010000000
oooo0000000000080?oooaH000005P3oool300000180oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool04@3oool2000001d0oooo00<000000?ooo`3oool0;03oool010000000
oooo0?ooo`3oool4000000L0oooo0P00000S0?ooo`@000004`3oool2000001`0oooo0P0000060?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0?ooo`3oool0000001X0oooo00<000000?ooo`3oool04P3oool20000
01`0oooo0P00000/0?ooo`030000003oool0oooo00D0oooo100000000`3oool000000000000R0?oo
o`<000005P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0C0?ooo`80
0000703oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00P0oooo1@00000L0?ooo`D0
00005`3oool2000001d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01@0oooo0P00000K0?ooo`800000
:@3oool00`000000oooo0?ooo`060?ooo`8000001@3oool9000000/0oooo2000000K0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01D0oooo0P00000K0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0103oool200000100oooo2`00000Q0?ooo`8000007P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0080oooo001;0?ooo`800000:P3oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000006`3oool2000001L0oooo0P00
000J0?ooo`8000009P3oool010000000oooo0?ooo`3oool3000003d0oooo00<000000?ooo`3oool0
703oool2000000L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo02T0oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000L0?ooo`030000003oool0oooo01H0oooo
0`00000I0?ooo`030000003oool0oooo02<0oooo1000000n0?ooo`8000007P3oool00`000000oooo
0?ooo`050?ooo`8000003@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`000000703oool00`000000oooo0?ooo`0H0?ooo`<00000
5`3oool200000200oooo100000100?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000L0?ooo`030000003oool0oooo01X0oooo
0P00000G0?ooo`8000006P3oool4000000<0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000
703oool00`000000oooo0?ooo`0K0?ooo`<000005P3oool00`000000oooo0?ooo`0C0?ooo`@00000
1`3oool00`000000oooo0?ooo`0k0?ooo`8000007P3oool2000000L0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`040?ooo`040000003o
ool0oooo0?ooo`8000006`3oool2000001h0oooo1@00000B0?ooo`8000003`3oool4000000/0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0P0?ooo`P00000303oool2000000P0oooo1@00000?0?ooo`030000003oool0oooo03P0oooo0P00
000N0?ooo`800000203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo02L0oooo5P00000D0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0080oooo001;0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0=P3oool2000001P0oooo00<000000?oo
o`3oool0=@3oool2000001l0oooo00<000000?ooo`3oool01P3oool2000000h0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01X0oooo0P00000h0?ooo`8000005P3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo01d0oooo0P0000080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0=`3oool2000001@0oooo00<000000?ooo`3oool0
<P3oool2000001l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool2000001`0oooo0P00000i0?ooo`8000004P3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo01d0oooo0P0000090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0>03oool3000000l0oooo00<000000?ooo`3oool0;`3oool2
000001h0oooo0P0000090?ooo`8000003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06`3oool20000
03/0oooo0`00000<0?ooo`030000003oool0oooo02d0oooo0P00000M0?ooo`<000002P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0L0?ooo`800000?03oool3000000T0
oooo00<000000?ooo`3oool0:`3oool2000001`0oooo0`00000;0?ooo`800000403oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
0P00000N0?ooo`030000003oool0oooo03`0oooo0`0000060?ooo`030000003oool0oooo02T0oooo
0P00000L0?ooo`8000003@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo00D0oooo0P0000060?ooo`030000003oool0oooo01`0oooo0P00
000o0?ooo`<000000`3oool00`000000oooo0?ooo`0W0?ooo`8000006`3oool3000000d0oooo0P00
000A0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`020?ooo`00B`3oool2000003T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`04
0?ooo`8000007P3oool00`000000oooo0?ooo`0o0?ooo`@000009`3oool2000001X0oooo0`00000?
0?ooo`030000003oool0oooo00l0oooo0P0000080?ooo`800000>P3oool3000000@0oooo001;0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`8000007@3oool200000480oooo1@00000Q0?ooo`8000006@3oool300000140oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0703oool200000400oooo00<000000?ooo`3o
ool00P3oool4000001/0oooo0P00000G0?ooo`@000004P3oool200000140oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo03/0oooo0P0000070?ooo`030000003oool0oooo00H0oooo0P00000N0?ooo`800000
?P3oool00`000000oooo0?ooo`060?ooo`@000005@3oool2000001D0oooo1000000E0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool01P3oool200000400oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool07@3oool2000003`0oooo00<000000?ooo`3oool02P3o
ool7000000/0oooo0`00000C0?ooo`@000005`3oool200000140oooo0P0000080?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0?P3oool0
0`000000oooo0?ooo`050?ooo`800000203oool2000001l0oooo0P00000j0?ooo`030000003oool0
oooo0140oooo200000000`3oool000000000000@0?ooo`H000006P3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00H0oooo0P0000130?ooo`030000003oool0oooo0080oooo001;0?oo
o`030000003oool0oooo03l0oooo0P0000070?ooo`030000003oool0oooo00L0oooo0P00000O0?oo
o`800000>03oool00`000000oooo0?ooo`0G0?oooaD000007P3oool200000180oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`80
00007`3oool2000003H0oooo00<000000?ooo`3oool05@3oool200000380oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`050?ooo`800000AP3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`120?ooo`8000001P3oool00`000000oooo0?ooo`090?ooo`800000
7`3oool2000003@0oooo00<000000?ooo`3oool04`3oool200000380oooo0P00000B0?ooo`800000
1`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0103oool2000000/0oooo0P00000O0?ooo`800000<P3o
ool00`000000oooo0?ooo`0@0?ooo`<00000<P3oool2000001<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo04D0oooo0P0000060?ooo`8000002`3oool2000001l0oooo0P00000`0?ooo`030000003oool0
oooo00h0oooo0P00000c0?ooo`800000503oool00`000000oooo0?ooo`050?ooo`800000BP3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool02P3oool3000001h0oooo0P00000^0?ooo`030000003oool0oooo
00/0oooo0`00000c0?ooo`800000503oool2000000H0oooo0P00001<0?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool01@3oool2000000d0
oooo0P00000N0?ooo`800000;03oool00`000000oooo0?ooo`070?ooo`@00000=03oool2000001@0
oooo0P0000060?ooo`800000CP3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`190?ooo`8000001`3oool2000000d0oooo0P00000N0?ooo`800000:P3oool00`000000oooo
0?ooo`030?ooo`@00000=P3oool2000001@0oooo0P0000060?ooo`800000D03oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00H0oooo0P00
000=0?ooo`<000007@3oool2000002P0oooo00<000000?ooo`0000000`00000h0?ooo`800000503o
ool2000000H0oooo0P00001B0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo04`0oooo0P0000080?ooo`030000003oool0oooo00d0oooo1000000K0?ooo`<000008@3oool6
000003X0oooo0P00000D0?ooo`8000001P3oool2000005@0oooo00<000000?ooo`3oool00P3oool0
04/0oooo0P00001?0?ooo`8000001`3oool200000140oooo1000000J0?ooo`<00000603oool60000
00@0oooo00<000000?ooo`3oool0=`3oool2000001@0oooo0P0000060?ooo`800000E03oool30000
00@0oooo001;0?ooo`030000003oool0oooo0500oooo0P0000070?ooo`8000004`3oool4000001T0
oooo1000000>0?ooo`H000002P3oool00`000000oooo0?ooo`0d0?ooo`<00000503oool2000000H0
oooo0P00001H0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0580oooo
0P0000070?ooo`8000005@3oool;00000180oooo3P00000@0?ooo`030000003oool0oooo0340oooo
0`00000E0?ooo`8000001P3oool2000005X0oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool0E03oool2000000L0oooo0P00000N0?oooa<000000P3oool3000001P0oooo00<0
00000?ooo`3oool0;`3oool2000001H0oooo0P0000060?ooo`800000G03oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`1F0?ooo`8000001`3oool2000003@0oooo1000000D
0?ooo`030000003oool0oooo02`0oooo0`00000F0?ooo`8000001@3oool3000005h0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0F03oool3000000H0oooo0`00000e0?oo
o`<000004@3oool00`000000oooo0?ooo`0Y0?ooo`<000005`3oool2000000<0oooo1000001Q0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo05/0oooo0P0000070?ooo`80
0000=P3oool4000000d0oooo00<000000?ooo`3oool09`3oool2000001L0oooo0`0000020?ooo`<0
0000I@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1M0?ooo`800000
1`3oool3000003L0oooo100000090?ooo`030000003oool0oooo02@0oooo0`00000F0?ooo`<00000
0P3oool3000006P0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0G`3o
ool2000000P0oooo0P00000i0?ooo`@000001@3oool00`000000oooo0?ooo`0Q0?ooo`<000005P3o
ool3000000030?ooo`000000000000800000J`3oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`1Q0?ooo`<000001`3oool2000003/0oooo1P00000O0?ooo`@000005P3oool7
000006l0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0I03oool40000
00D0oooo0`00000m0?ooo`P00000503oool4000001H0oooo1P00001d0?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo06P0oooo100000040?ooo`@00000>@3oool00`000000
oooo0?ooo`050?ooo`X000001P3oool4000001@0oooo1`00001i0?ooo`030000003oool0oooo0080
oooo000k0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0203oool00`000000oooo
0?ooo`1/0?ooo`@00000103oool3000003H0oooo00<000000?ooo`3oool03`3oool;000000/0oooo
20000000103oool0000000000000001l0?ooo`030000003oool0oooo0080oooo000m0?ooo`030?no
M0000000M;oo00/0oooo00<000000?ooo`3oool0L03oool4000000<0oooo0`00000c0?ooo`030000
003oool0oooo00d0oooo100000090?ooo`/000001@3oool4000007l0oooo00<000000?ooo`3oool0
0P3oool003d0oooo00<0oooO09a80000M;l02`3oool00`000000oooo0?ooo`1d0?ooo`@000000P3o
ool4000002l0oooo00<000000?ooo`3oool0203oool5000001T0oooo100000230?ooo`030000003o
ool0oooo0080oooo000n0?ooo`030=nLB000B9`0gooo00X0oooo00<000000?ooo`3oool0N03oool:
000002/0oooo00<000000?ooo`3oool00P3oool6000001X0oooo100000270?ooo`030000003oool0
oooo0080oooo000n0?ooo`030?oOW01804P0W=oo00X0oooo00<000000?ooo`3oool0OP3oool90000
02<0oooo2000000L0?ooo`@00000R`3oool00`000000oooo0?ooo`020?ooo`00?P3oool00`3ookl0
M00007Boo`0:0?ooo`<00000Q`3ooolS000000<0oooo00<000000?ooo`3oool05`3oool7000008`0
oooo100000040?ooo`00?`3oool00`2oM00007Bo0?ooo`090?ooo`030000003oool0oooo08d0oooo
2`00000E0?ooo`030000003oool0oooo00`0oooo2`00002F0?ooo`030000003oool0oooo0080oooo
000o0?ooo`030=nLB000B9`0gooo00T0oooo00<000000?ooo`3oool0V03ooolT00000:40oooo00<0
00000?ooo`3oool00P3oool003l0oooo00<0omnL04P0B02Lgol02@3oool00`000000oooo0?ooo`2]
0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool00P3oool003l0oooo00<0oono07@0
001d_ol02@3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0:d0oooo00<000000?oo
o`3oool00P3oool00400oooo00<0_g@0001d_`3oool0203oool00`000000oooo0?ooo`2]0?ooo`03
0000003oool0oooo0:d0oooo00<000000?ooo`3oool00P3oool003h0oooo00D0oono07@000000000
001d0;ooo`080?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0[@3oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0:d0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`1<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool004/0oooo00@00000
0?ooo`3oool000003`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo000000040?ooo`00B`3oool010000000oooo0?ooo`00
000?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0000000@0oooo001;0?ooool00000HP0000040?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00cP3oool02@3ookl0M00000000018W=l0oooo0?oo_`1d0000000004RLg`0D0?ooo`030?noM000
000000000080000000<004RL0=ooo`3oool04P3oool01@2oM0000000000000000000B9cO0:H0oooo
003>0?ooo`0:0?oo_`1d04P0W=oo0;md0000M;l0oono07@0B02Lgol0_g@0001d_a80oooo00<0okmd
00000018W=l00`3oool00`3ogi`0B01809cOo`0C0?ooo`030?oog`2LB000B9cO0:L0oooo003A0?oo
o`030?oo_`1d0000M;oo0080oooo00<0oono07@0001d_ol04@3oool00`3o_g@0001d0;ooo`040?oo
o`030=nLB000M;l0oooo01<0oooo00<0gia80018W03Oool0YP3oool00=80oooo00<0gia80018W03O
ool00P3oool00`3OW4P004RL0=ooo`0A0?ooo`080;md000007@0_ooo0?ooo`3ooml0W4P000000018
W=lD0?ooo`030?oOW01807@0_ooo0:H0oooo002k0?ooo`030;md00000000000000D0000000<004RL
0=ooo`3oool00`3oool0303ogi`0B00000000000B9`0gooo0;md0000000007Bo0?ooo`3o_g@00018
09cOo`80oooo00<0okmd0000B02Lgol00`3oool0202oM00000000000B02Lgol0oooo0=nLB000B9`0
gooo0P3oool00`2oM0000000001d_`020?ooo`060?oo_`1d000000000000000007@0_ooo1@3oool0
0`3o_g@00000000000070000000907Boo`3oool0omnL04P000000000001d0;oo_`1d0000M;oo0080
oooo00/0omnL04P00000000004RL0=ooo`2oM0000000001d_`3oool0omnL04P000020000000907Bo
o`3OW4P000000018W03Oool0okmd0000000004P0W=oo0080oooo00@0_g@00000000004P0W=oo0P3o
ool01@3o_g@000000000000004P0W=oo00<0oooo00<0gia80018W03Oool00P3oool00`2oM0000000
001d_`1f0?ooo`00_03oool0103ookl0M0000018W03Oool30?ooo`030;md0000000007Bo00<0oooo
00`0omnL04P0B02Lgol0omnL04Qd_`2oM00007Bo0?noW02Lgol0oono07@00018W=l20?ooo`030?oo
_`1d0000B9cO00<0oooo00P0gia80018W03Ooml0W7BL0=ooo`3o_g@0001d0;ooo`80oooo00P0gia8
0018W03O_g@0M;oo0?ooo`3o_g@0001d0;ooo`T0oooo00@0oooO09a80000B9`0gooo0`3oool02`3o
oml0W4P00018W03Oool0_g@00018W03Oool0oono07@0M01dM000B9cO0080oooo02@0omnL04P0B02L
gol0omnL04Qd_`2oM00007Bo0?noW02Lgol0_g@00018W03Oool0oooo0;md001dM7@0001d0;oOW02L
_ol0okmd0000B02Lgml0W7BL0=ooo`3oool0gia80018W03Ooml0W7BL0=ooo`3ogi`0B01809cOo`3o
ool0omnL04P00000M;l20?ooo`030?noM00007@0_ooo0080oooo00@0gia80018W03O_g@0M;ooM@3o
ool00;d0oooo00<0gia80000B02Lgol0103oool03@3ookl0M0000018W03Oool0oooo0?oog`2LB000
B9cO0?ooo`3o_g@0M7Ad0018W03Oool00P3oool00`2oM00004RL0=ooo`020?ooo`030;md0000B9`0
gooo0080oooo00<0okmd0000B02Lgol00P3oool00`3ookl0M00004RLg`020?ooo`030?oOW01804P0
W=oo00<0oooo00<0_g@007Boo`3oool02@3oool00`3o_g@0001809cOo`050?ooo`040=nLM02Lgol0
_g@0001d_`80oooo0100oono07@00000B9`0gooo0?ooo`3ooml0W4P004RLg`3oool0okmd07AdM000
B9`0gooo0?ooo`2oM00007Bo0`3oool01`2oM000000007Boo`3oool0oono07@0001d_ol00`3oool0
0`3o_g@0001809cOo`020?ooo`030=nLB000B9`0gooo0080oooo00L0omnL04P00018W=l0oooo0?oo
_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol0MP3oool00;d0oooo00<0omnL04P0001d_ol01@3o
ool00`3ogi`0B000001d_`020?ooo`070;md0000B9`0gooo0?ooo`2oM000001809cOo`020?ooo`03
0=nLB00007@0_ooo0080oooo00<0gia80000M02oool00P3oool00`3ookl0M00004RLg`020?ooo`08
0?oog`2LB000001d0;ooo`3oool0oooO09a80018W=l20?ooo`030?oo_`1d000000000080000000<0
M;oo0?ooo`3oool01@3oool00`3ookl0M00004RLg`070?ooo`030=nLB000B9`0gooo0080oooo00<0
okmd0000M02oool00P3oool02`2oM00004RL0=ooo`3oool0_g@00000B02Lgol0oooo0?noM00007@0
_ooo0080oooo00<0oono07@00018W=l00P3oool00`2oM00007Bo0?ooo`020?ooo`030?oo_`1d0000
B9cO0080oooo00<0okmd0000M02oool00`3oool02`3OW4P0001d0;ooo`3ooml0W4P00000M02oool0
oooo0?oog`2LB000B9cO07H0oooo002m0?ooo`030?oo_`1d000007Bo00H0oooo00/0_g@00000B02L
gol0oooo0?noM00007@0_ooo0?ooo`3ookl0M00007Boo`020?ooo`030?oOW0180000M;oo0080oooo
00<0omnL04P0001d_ol00`3oool00`2oM00004RL0=ooo`020?ooo`030=nLB000B4P0B7Bo0080oooo
00/0_g@0001d_`3oool0oooo0;md0000B9`0gooo0?ooo`3ogi`0B00004RLg`060?ooo`030?oog`2L
B00007Bo0080oooo00<0oono09bLg`3oool00P3oool00`3ogi`0B00007Boo`020?ooo`030?oo_`1d
0000M;oo0080oooo00/0okmd0000M02oool0oooo0?oo_`1d0000M;oo0?ooo`3ookl0M00007Boo`03
0?ooo`070;md0000B9`0gooo0?ooo`3OW4P004RL0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3o
okl0M00007Boo`030?ooo`070?oOW01804P0W=oo0?ooo`3OW4P004Q804Qd_`020?ooo`030;md0000
M;l0oooo07D0oooo002n0?ooo`030;md0000B9`0gooo00D0oooo00L0okmd00000018W=l0omoO0=oo
_`1d0000M;oo0080oooo00L0_g@0001d_`3oool0oooo0?oog`2LB000B9cO0080oooo00<0oooO09a8
0018W=l00`3oool00`3OW4P0001809cOo`020?ooo`0;0?noM00007@0_kmd04RLg`3oool0okmd0000
M02oool0oooo0;md0000M;l00`3oool00`3OW4P0001d0;ooo`060?ooo`060=nLB00007@0_ooo0?oo
o`3ogi`0B7Bo103oool0302oM000001d0;ooo`3oool0oooO09a80018W=l0oooo0?oOg`3Ookl0M000
07Boo`80oooo00L0_g@0001d_`3oool0oooo0?noM00007@0_ooo0080oooo00L0gia80000M02oool0
oooo0?oOW01804P0W=oo00<0oooo00<0gia80000B02Lgol00P3oool00`3OW4P0001d0;ooo`020?oo
o`0<0?oo_`1d0000M;oo0?ooo`3o_g@0001d0;noM018W=l0oooo0?noM00007@0_oooM@3oool00;h0
oooo00<0okmd0000B02Lgol01@3oool01`3ogi`0B000001d_`3ogi`0B7Bo0;md0000M;l00P3oool0
0`3o_g@004RL0=ooo`020?ooo`030;md0000B9`0gooo0080oooo00<0_g@00018W03Oool00P3oool0
0`3ogi`0B00004RLg`020?ooo`0<0?oog`2LB000M;oo0=nLB000M;l0omnL04P0B02Lgol0oooo0?oO
W0180000B9cO0P3oool00`3OW4P0001d0;ooo`060?ooo`030?noM000000000000080000000<0001d
0;ooo`3oool00P3oool0303ooml0W4P00018W03Oool0oono09a8B000B9`0gooo0?oOW018M;l0_g@0
001d_`80oooo00<0okmd0018W03Oool00P3oool02`3OW4P0001d0;ooo`3oool0_g@00000B02Lgol0
oooo0?oog`2LB000B9cO00<0oooo00<0omnL04P00018W=l00`3oool0402oM000001d0;ooo`3oool0
okmd0000M02oool0oooo0?oog`2LB000M;oo0=nLB000M;l0omnL04P0B02Lgome0?ooo`00_P3oool0
0`3ogi`0B00007Boo`050?ooo`070?oOW018000007Bo0?ooo`3o_g@00000001d_`020?ooo`050?oO
W01804P0W=oo0?oo_`1d00000`0000000`1d_kl0M000000000020000000?07Boo`3o_g@000000000
0000B9`0gooo0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo0080oooo00<0oono07@0
00000000100000000`18W=l0oooo0?ooo`030?ooo`030?oo_`1d0000M;oo0080oooo00<0_gA809cO
o`3oool0103oool02P3OW4P000000000M02o_g@0001d0;ooo`3oool0okmd00000000M;l20?ooo`03
0?oOW01804P0W=oo00<0oooo00P0omnL04P000000000B9bL07@00018W=l0oono07@000<0000000H0
M;oo0?noM000000000000018W03Oool30?ooo`0?0?noM000000000000000001d_ol0oooo0?oo_`1d
0000000004RLg`3oool0okmd0000000004P0W=oo07D0oooo002n0?ooo`030?oog`2LB00007Bo00D0
oooo00<0okmd00000018W=l02`3oool00`3o_g@0001809cOo`020?ooo`030?noM00004P0W=oo01l0
oooo00H0_g@0001d_`3oool0oooo0?oOW01dW=lO0?ooo`030?noM00007@0_ooo08d0oooo002o0?oo
o`030;md0000B9`0gooo00<0oooo00@0oooO09a8000007@0_ooo2`3oool00`3ooml0W4P0001d_`02
0?ooo`030?oog`2LB00007Bo01l0oooo00<0gia80000M02oool0103oool00`3OW9`0_ooo0?ooo`0L
0?ooo`030=nLM02Lgol0oooo08`0oooo002o0?ooo`030=nLB00004P0W=oo0080oooo00@0oono07@0
00000000M;oo3@3oool00`3o_g@0001d0;ooo`020?ooo`030?noM00007@0_ooo0080oooo00@0oono
07@00000B9`0gooo603oool00`3o_g@0001809cOo`030?ooo`030?oo_`1d04P0W=oo0280oooo00@0
oono07@00000B9`0goooQP3oool00;h0oooo00<0_g@0000000000000100000000`00B9`0gooo0?oo
o`0>0?ooo`0:0=nLB000B9`0gooO09a80018W=l0gia80018W03Ooml0W4P004RLgaX0oooo00<0_g@0
0000000000001P0000000`1d_ol0oooo0?ooo`2Z0?ooo`00e`3oool02@3OW4P000000000B02Lgol0
oooo0=nLB0000000001809cOo`3@0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-1.59757, -1.37483, 0.0095197, \
0.0090798}}]
}, Closed]],

Cell["\<\
In this case the Poincar\[EAcute] map consists of three disconnected closed \
curves between which the phase point hops in the sequence indicated.  Even \
though the phase trajectory is ultimately space filling, there is underlying \
order.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[sol];\)\), "\[IndentingNewLine]", 
    \(\(sol[
          t_] = \(duffingSol[\(-0.25\), 1, 0, 0.5, 2, 1, 0, 10\^3, 
            MaxSteps \[Rule] 10\^5]\)[t];\)\), "\[IndentingNewLine]", 
    \(\(pts = poincare[sol[t], 2, 100, 10\^3];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[pts, Frame \[Rule] True, 
        FrameLabel \[Rule] {\*"\"\<\!\(x\_k\)\>\"", \*"\"\<\!\(x\_k\%\[Prime]\
\)\>\""}, 
        Epilog \[Rule] {Text["\<1\>", {\(-0.8\), 0.25}], 
            Text["\<2\>", {0.85, 0.1}], 
            Text["\<3\>", {\(-0.25\), \(-0.8\)}]}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.507165 0.455336 0.428034 0.416851 [
[.05183 -0.0125 -9.34375 -15.6875 ]
[.05183 -0.0125 9.34375 0 ]
[.2795 -0.0125 -13.8438 -15.6875 ]
[.2795 -0.0125 13.8438 0 ]
[.50716 -0.0125 -5 -15.6875 ]
[.50716 -0.0125 5 0 ]
[.73483 -0.0125 -9.5 -15.6875 ]
[.73483 -0.0125 9.5 0 ]
[.9625 -0.0125 -5 -15.6875 ]
[.9625 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -7.125 -31.375 ]
[.5 -0.0125 7.125 -15.6875 ]
[-0.0125 .01118 -18.6875 -7.84375 ]
[-0.0125 .01118 0 7.84375 ]
[-0.0125 .09455 -27.6875 -7.84375 ]
[-0.0125 .09455 0 7.84375 ]
[-0.0125 .17792 -27.9375 -7.84375 ]
[-0.0125 .17792 0 7.84375 ]
[-0.0125 .26129 -27.6875 -7.84375 ]
[-0.0125 .26129 0 7.84375 ]
[-0.0125 .34466 -27.6875 -7.84375 ]
[-0.0125 .34466 0 7.84375 ]
[-0.0125 .42803 -10 -7.84375 ]
[-0.0125 .42803 0 7.84375 ]
[-0.0125 .5114 -19 -7.84375 ]
[-0.0125 .5114 0 7.84375 ]
[-0.0125 .59477 -19 -7.84375 ]
[-0.0125 .59477 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -43.625 -7.125 ]
[-0.01875 .30902 -27.9375 7.125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05183 0 m
.05183 .00625 L
s
gsave
.05183 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2795 0 m
.2795 .00625 L
s
gsave
.2795 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.50716 0 m
.50716 .00625 L
s
gsave
.50716 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.73483 0 m
.73483 .00625 L
s
gsave
.73483 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.9625 0 m
.9625 .00625 L
s
gsave
.9625 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.09736 0 m
.09736 .00375 L
s
.1429 0 m
.1429 .00375 L
s
.18843 0 m
.18843 .00375 L
s
.23396 0 m
.23396 .00375 L
s
.32503 0 m
.32503 .00375 L
s
.37056 0 m
.37056 .00375 L
s
.4161 0 m
.4161 .00375 L
s
.46163 0 m
.46163 .00375 L
s
.5527 0 m
.5527 .00375 L
s
.59823 0 m
.59823 .00375 L
s
.64377 0 m
.64377 .00375 L
s
.6893 0 m
.6893 .00375 L
s
.78037 0 m
.78037 .00375 L
s
.8259 0 m
.8259 .00375 L
s
.87143 0 m
.87143 .00375 L
s
.91697 0 m
.91697 .00375 L
s
.00629 0 m
.00629 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -68.125 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 17.688 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
73.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01118 m
.00625 .01118 L
s
gsave
-0.0125 .01118 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .09455 m
.00625 .09455 L
s
gsave
-0.0125 .09455 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .17792 m
.00625 .17792 L
s
gsave
-0.0125 .17792 -88.9375 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .26129 m
.00625 .26129 L
s
gsave
-0.0125 .26129 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .34466 m
.00625 .34466 L
s
gsave
-0.0125 .34466 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .42803 m
.00625 .42803 L
s
gsave
-0.0125 .42803 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .5114 m
.00625 .5114 L
s
gsave
-0.0125 .5114 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .59477 m
.00625 .59477 L
s
gsave
-0.0125 .59477 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03203 m
.00375 .03203 L
s
0 .05287 m
.00375 .05287 L
s
0 .07371 m
.00375 .07371 L
s
0 .1154 m
.00375 .1154 L
s
0 .13624 m
.00375 .13624 L
s
0 .15708 m
.00375 .15708 L
s
0 .19877 m
.00375 .19877 L
s
0 .21961 m
.00375 .21961 L
s
0 .24045 m
.00375 .24045 L
s
0 .28214 m
.00375 .28214 L
s
0 .30298 m
.00375 .30298 L
s
0 .32382 m
.00375 .32382 L
s
0 .36551 m
.00375 .36551 L
s
0 .38635 m
.00375 .38635 L
s
0 .40719 m
.00375 .40719 L
s
0 .44888 m
.00375 .44888 L
s
0 .46972 m
.00375 .46972 L
s
0 .49056 m
.00375 .49056 L
s
0 .53225 m
.00375 .53225 L
s
0 .55309 m
.00375 .55309 L
s
0 .57393 m
.00375 .57393 L
s
0 .61562 m
.00375 .61562 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -103.906 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.125 11.8438 translate
90 rotate
-68.125 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 18.625 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
68.563 11.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\242) show
73.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.05183 .61178 m
.05183 .61803 L
s
.2795 .61178 m
.2795 .61803 L
s
.50716 .61178 m
.50716 .61803 L
s
.73483 .61178 m
.73483 .61803 L
s
.9625 .61178 m
.9625 .61803 L
s
.125 Mabswid
.09736 .61428 m
.09736 .61803 L
s
.1429 .61428 m
.1429 .61803 L
s
.18843 .61428 m
.18843 .61803 L
s
.23396 .61428 m
.23396 .61803 L
s
.32503 .61428 m
.32503 .61803 L
s
.37056 .61428 m
.37056 .61803 L
s
.4161 .61428 m
.4161 .61803 L
s
.46163 .61428 m
.46163 .61803 L
s
.5527 .61428 m
.5527 .61803 L
s
.59823 .61428 m
.59823 .61803 L
s
.64377 .61428 m
.64377 .61803 L
s
.6893 .61428 m
.6893 .61803 L
s
.78037 .61428 m
.78037 .61803 L
s
.8259 .61428 m
.8259 .61803 L
s
.87143 .61428 m
.87143 .61803 L
s
.91697 .61428 m
.91697 .61803 L
s
.00629 .61428 m
.00629 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01118 m
1 .01118 L
s
.99375 .09455 m
1 .09455 L
s
.99375 .17792 m
1 .17792 L
s
.99375 .26129 m
1 .26129 L
s
.99375 .34466 m
1 .34466 L
s
.99375 .42803 m
1 .42803 L
s
.99375 .5114 m
1 .5114 L
s
.99375 .59477 m
1 .59477 L
s
.125 Mabswid
.99625 .03203 m
1 .03203 L
s
.99625 .05287 m
1 .05287 L
s
.99625 .07371 m
1 .07371 L
s
.99625 .1154 m
1 .1154 L
s
.99625 .13624 m
1 .13624 L
s
.99625 .15708 m
1 .15708 L
s
.99625 .19877 m
1 .19877 L
s
.99625 .21961 m
1 .21961 L
s
.99625 .24045 m
1 .24045 L
s
.99625 .28214 m
1 .28214 L
s
.99625 .30298 m
1 .30298 L
s
.99625 .32382 m
1 .32382 L
s
.99625 .36551 m
1 .36551 L
s
.99625 .38635 m
1 .38635 L
s
.99625 .40719 m
1 .40719 L
s
.99625 .44888 m
1 .44888 L
s
.99625 .46972 m
1 .46972 L
s
.99625 .49056 m
1 .49056 L
s
.99625 .53225 m
1 .53225 L
s
.99625 .55309 m
1 .55309 L
s
.99625 .57393 m
1 .57393 L
s
.99625 .61562 m
1 .61562 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .42803 m
1 .42803 L
s
.50716 0 m
.50716 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.08287 .58478 Mdot
.96147 .29804 Mdot
.34476 .13725 Mdot
.15092 .47721 Mdot
.78216 .52511 Mdot
.4627 .03073 Mdot
.16006 .60171 Mdot
.93403 .29184 Mdot
.40336 .16981 Mdot
.08188 .46509 Mdot
.86775 .53539 Mdot
.36828 .01486 Mdot
.25512 .55432 Mdot
.89272 .38117 Mdot
.49111 .1625 Mdot
.02882 .45548 Mdot
.95119 .48656 Mdot
.31651 .04231 Mdot
.27235 .51892 Mdot
.84619 .4483 Mdot
.49907 .11316 Mdot
.04896 .54405 Mdot
.97411 .35151 Mdot
.33613 .11198 Mdot
.17997 .48942 Mdot
.78481 .51325 Mdot
.47769 .04501 Mdot
.13236 .60318 Mdot
.94294 .28303 Mdot
.37584 .15931 Mdot
.10896 .4712 Mdot
.83043 .53613 Mdot
.40318 .01577 Mdot
.22418 .57223 Mdot
.90954 .35517 Mdot
.47143 .17071 Mdot
.03762 .45006 Mdot
.932 .5098 Mdot
.32228 .02917 Mdot
.28213 .52827 Mdot
.86375 .42146 Mdot
.50421 .13719 Mdot
.02996 .50089 Mdot
.97538 .40841 Mdot
.32433 .08358 Mdot
.21865 .49965 Mdot
.79556 .49689 Mdot
.49079 .06395 Mdot
.10157 .59691 Mdot
.95376 .28306 Mdot
.35058 .14627 Mdot
.13903 .47308 Mdot
.78799 .52979 Mdot
.45054 .02473 Mdot
.17632 .59692 Mdot
.92898 .30418 Mdot
.4228 .17413 Mdot
.06629 .45907 Mdot
.88841 .53204 Mdot
.3507 .01647 Mdot
.2694 .54569 Mdot
.88407 .39109 Mdot
.49883 .15844 Mdot
.02565 .45914 Mdot
.95854 .47448 Mdot
.31482 .0486 Mdot
.26674 .5148 Mdot
.83666 .45905 Mdot
.49764 .10301 Mdot
.05832 .55842 Mdot
.97117 .33258 Mdot
.33918 .12088 Mdot
.16933 .4855 Mdot
.78327 .51756 Mdot
.47283 .03987 Mdot
.14187 .60326 Mdot
.93984 .2855 Mdot
.38513 .1631 Mdot
.0993 .46988 Mdot
.84443 .53639 Mdot
.38978 .01501 Mdot
.23623 .56516 Mdot
.9032 .36669 Mdot
.47982 .16737 Mdot
.03378 .4522 Mdot
.94052 .50051 Mdot
.31966 .03467 Mdot
.27818 .52429 Mdot
.85692 .43342 Mdot
.5017 .1267 Mdot
.03752 .52146 Mdot
.97619 .3811 Mdot
.33032 .09751 Mdot
.19896 .49486 Mdot
.78837 .50556 Mdot
.48541 .05409 Mdot
.11637 .60158 Mdot
.94829 .28021 Mdot
.36072 .15266 Mdot
.1258 .47201 Mdot
.80504 .53372 Mdot
.42956 .01933 Mdot
.19888 .58631 Mdot
.92098 .32824 Mdot
.44904 .17522 Mdot
.04927 .45142 Mdot
.91178 .52416 Mdot
.33284 .02068 Mdot
.28172 .5366 Mdot
.87455 .4023 Mdot
.50502 .15229 Mdot
.02381 .46855 Mdot
.96674 .45505 Mdot
.31526 .0588 Mdot
.25456 .50928 Mdot
.82164 .47372 Mdot
.49576 .0885 Mdot
.07291 .57571 Mdot
.96558 .30984 Mdot
.34259 .13148 Mdot
.15742 .48021 Mdot
.78194 .52244 Mdot
.46686 .034 Mdot
.15313 .60268 Mdot
.93621 .28879 Mdot
.39608 .16738 Mdot
.08852 .46721 Mdot
.85899 .53603 Mdot
.37619 .01472 Mdot
.24828 .55824 Mdot
.89659 .37633 Mdot
.4872 .16421 Mdot
.03051 .45433 Mdot
.94763 .49152 Mdot
.31758 .03968 Mdot
.27435 .52076 Mdot
.85006 .44342 Mdot
.4998 .11765 Mdot
.04504 .53703 Mdot
.97507 .36076 Mdot
.33448 .10755 Mdot
.18554 .49121 Mdot
.78572 .511 Mdot
.48009 .04768 Mdot
.12753 .60292 Mdot
.94453 .28194 Mdot
.37115 .15733 Mdot
.11402 .47159 Mdot
.82285 .53569 Mdot
.41072 .0165 Mdot
.21719 .57625 Mdot
.91296 .34801 Mdot
.46596 .1724 Mdot
.04026 .44952 Mdot
.92673 .51454 Mdot
.32439 .02633 Mdot
.28343 .53057 Mdot
.86715 .41504 Mdot
.50523 .14257 Mdot
.02691 .48942 Mdot
.97358 .4242 Mdot
.32096 .07533 Mdot
.23061 .50259 Mdot
.80239 .49068 Mdot
.49273 .07073 Mdot
.09295 .59213 Mdot
.95726 .28865 Mdot
.34732 .14232 Mdot
.14479 .47466 Mdot
.78386 .52759 Mdot
.45749 .0276 Mdot
.16766 .59994 Mdot
.93168 .29662 Mdot
.41207 .17215 Mdot
.07453 .4624 Mdot
.87743 .53418 Mdot
.35983 .01537 Mdot
.26219 .55018 Mdot
.88859 .38598 Mdot
.495 .16066 Mdot
.02717 .45687 Mdot
.95473 .48117 Mdot
.31552 .04511 Mdot
.27008 .517 Mdot
.84194 .45324 Mdot
.49843 .10855 Mdot
.0531 .55082 Mdot
.97291 .34255 Mdot
.33758 .1162 Mdot
.17487 .4876 Mdot
.78396 .51531 Mdot
.47547 .04256 Mdot
.13682 .60332 Mdot
.94147 .28405 Mdot
.38011 .16111 Mdot
.10444 .47065 Mdot
.83702 .53636 Mdot
.39677 .01531 Mdot
.23002 .56884 Mdot
.90654 .36084 Mdot
.47563 .16917 Mdot
.03566 .45088 Mdot
.93618 .50553 Mdot
.32085 .03171 Mdot
.28052 .52636 Mdot
.86064 .42706 Mdot
.50311 .13234 Mdot
.03321 .51071 Mdot
.97614 .3952 Mdot
.32719 .09035 Mdot
.209 .4973 Mdot
.79136 .50131 Mdot
.48859 .05898 Mdot
.10859 .59967 Mdot
.95107 .28062 Mdot
.35459 .14933 Mdot
.13335 .47233 Mdot
.79443 .5317 Mdot
.44198 .02214 Mdot
.18593 .59275 Mdot
.9258 .31407 Mdot
.4346 .1753 Mdot
.05814 .45539 Mdot
.89935 .52905 Mdot
.34197 .01803 Mdot
.27591 .54139 Mdot
.87965 .39595 Mdot
.50219 .15607 Mdot
.02441 .46205 Mdot
.96215 .46718 Mdot
.31444 .05236 Mdot
.26277 .51256 Mdot
.8309 .46485 Mdot
.49697 .09737 Mdot
.06378 .56558 Mdot
.96918 .32307 Mdot
.3405 .12525 Mdot
.16443 .48335 Mdot
.78245 .51957 Mdot
.47062 .03746 Mdot
.14629 .60321 Mdot
.93839 .28647 Mdot
.38923 .16482 Mdot
.09513 .46892 Mdot
.85005 .53638 Mdot
.38442 .01478 Mdot
.24107 .56242 Mdot
.9006 .37062 Mdot
.48287 .16615 Mdot
.03241 .45291 Mdot
.94341 .49707 Mdot
.31873 .0366 Mdot
.27683 .52289 Mdot
.85432 .43735 Mdot
.50098 .12318 Mdot
.04032 .52773 Mdot
.97593 .37283 Mdot
.332 .1016 Mdot
.19344 .49339 Mdot
.78701 .50783 Mdot
.48344 .05144 Mdot
.1208 .60233 Mdot
.94676 .2805 Mdot
.36457 .15453 Mdot
.1213 .47183 Mdot
.81166 .53467 Mdot
.42226 .01801 Mdot
.20618 .58245 Mdot
.91797 .33612 Mdot
.45623 .17448 Mdot
.04527 .44999 Mdot
.91789 .5209 Mdot
.3289 .02254 Mdot
.28345 .53421 Mdot
.87183 .40643 Mdot
.50572 .14938 Mdot
.02423 .47453 Mdot
.96942 .4456 Mdot
.31669 .06388 Mdot
.24739 .50704 Mdot
.81496 .47975 Mdot
.49483 .0823 Mdot
.07963 .58202 Mdot
.96282 .30163 Mdot
.34405 .13546 Mdot
.15295 .47815 Mdot
.782 .52428 Mdot
gsave
.1429 .53225 -66 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.8942 .46972 -66 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.39333 .09455 -66 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00n`3oool01`2oM4P0W=oo0?oo
o`3ogi`0B0000000001d_ol0[P3oool00?/0oooo00P0okmd04RLg`3oool0gia8001d_`3oool0_ibL
0=ooojd0oooo003c0?ooo`0=0=nLB000000007Bo0?ooo`3ooml0W4P00000001d_ol0oono07A8B018
M9`0W4P007Boo`2`0?ooo`00m@3oool02`3o_g@0M;oo0?oOW01804P0W=oo0;mdM02ooml0W4Qd0;no
M00007@0_ooo0;00oooo003f0?ooo`040;mdM02LW4P004RL0=ooo`80oooo00@0gia807Boo`3ookl0
M7Bo/03oool00?H0oooo00<0oono07@00000M;l00`3oool0103ogi`0B7Bo0?oog`2LB00200000003
07Boo`3oool0oooo0:/0oooo003f0?ooo`030?oo_`1d0000M;oo00<0oooo00<0oooO09a8M02oool0
/@3oool00?H0oooo00@0okmd00000000B9`0gooo0`3oool00`3OW4P0M;oo0?ooo`2`0?ooo`00mP3o
ool02@2oM00004RL0=oOW018B9`0gooo0?ooo`3OW4P00000001d_`2a0?ooo`00m03oool02@3o_g@0
00000000001d_ol0oooo0?oOW018000004RL0=ooo`2c0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I03oool00`3o
okl0M000000000020000000304RLg`3oool0oooo0440oooo00@0_g@0000000000000M;oo0`3oool0
0`3ogi`0B00007Boo`020?ooo`060?oOW0180000000000000000B9`0gooo?03oool0102oM0000000
0000001d_om30?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol00P3oool01P3o
gi`0B00000000000000004RL0=oood00oooo00<0oono07@0000000000P0000000`18W=l0oooo0?oo
o`0D0?ooo`00IP3oool00`3o_g@0000007Boo`130?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO
0P3oool00`3ogi`0B00007Boo`020?ooo`060?noM0000000M;oo0?ooo`3ogi`0B7Bo>`3oool01P3O
W4P007Bo0?ooo`3ogi`0B00004RLgd40oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`03
0?oOW0180000M;oo0080oooo00H0okmd0000001d_ol0oooo0?oOW018M;m20?ooo`030?noM0000000
M;oo01L0oooo001V0?ooo`030?oog`2LB00007Bo0480oooo00<0oooO09a80018W=l00P3oool00`3o
_g@0001809cOo`0;0?ooo`030?noM018W=l0oooo03P0oooo00<0oooO09a80018W=l00P3oool00`3o
_g@0001809cOo`0o0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol02`3oool00`3o
_g@0B9cO0?ooo`100?ooo`030?oog`2LB00007Bo01L0oooo001W0?ooo`030=nLB000B9`0gooo0440
oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool:0?ooo`030?oo_`1d07@0_ooo
03P0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oooln0?ooo`030?oog`2LB000
B9cO0080oooo00@0oooO09a80000B9`0gooo2P3oool00`3ookl0M01d0;ooo`110?ooo`030=nLB000
B9`0gooo01H0oooo001G0?ooo`030?oog`2LB000000000L0000000<0B9cO0?ooo`3oool00`3oool0
0`3ogi`0B01809cOo`0d0?ooo`030?oog`2LB000000000L0000000H0B9cO0?ooo`3oool0oooO09a8
0000M;l30?ooo`030=nLB00004P0W=oo00X0oooo00<0oooO09a8001d_ol0>03oool00`3ooml0W4P0
001d_`030?ooo`030=nLB00004P0W=oo03h0oooo00<0oooO09a80000M;l00`3oool00`3OW4P00018
09cOo`0:0?ooo`030?oog`2LB000M;oo0440oooo00<0omnL04P0B02Lgol05P3oool006L0oooo00<0
oono07@0001d_ol0@P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00X0oooo00<0
oono07@00018W=l0>@3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO03l0oooo00<0
_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?ooo`030?oo_`1d0000B9cO0440oooo00<0
oono07@0001d_ol05P3oool006P0oooo00<0_g@0001d_`3oool0@@3oool00`3OW4P0001809cOo`02
0?ooo`030?oog`2LB00007Bo00X0oooo00<0okmd0000001d_ol0>@3oool00`3OW4P0001809cOo`02
0?ooo`030?oog`2LB00007Bo03l0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0:
0?ooo`030?noM0000000M;oo0480oooo00<0_g@0001d_`3oool05@3oool006P0oooo00<0gia80018
W03Oool0@@3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00H0oooo00H0omoO0=oo
o`3o_g@000000000M02oooli0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool0?P3o
ool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00H0oooo00H0omoO0=ooo`3o_g@00000
0000M02ooom20?ooo`030=nLB000B9`0gooo01D0oooo001X0?ooo`030?oOW01804P0W=oo0440oooo
00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`060?ooo`050?oo_`1d000000000000
B02Lgol0>P3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo03h0oooo00@0oooO
09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`060?ooo`050?oo_`1d000000000000B02Lgol0
@`3oool00`3ogi`0B01809cOo`0E0?ooo`00J03oool00`3ookl0M00007Boo`120?ooo`030?oOW018
0000M;oo0080oooo00<0gia8001d_`3oool01`3oool00`3OW9`0_ooo0?ooo`0l0?ooo`030?oOW018
0000M;oo0080oooo00<0gia8001d_`3oool0?`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000
M;l0oooo00L0oooo00<0gibL0;ooo`3oool0A03oool00`3ookl0M00007Boo`0E0?ooo`00J@3oool0
0`2oM00007Bo0?ooo`120?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO203oool00`3ogi`0M9cO
0?ooo`0m0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO@@3oool01P3OW4P0001d0;ooo`3ooml0
W4P004RLg`P0oooo00<0omnL07BLg`3oool0A@3oool00`2oM00007Bo0?ooo`0D0?ooo`00I`3oool0
1@3ookl0M0000000000007@0_ooo04<0oooo00@0gia800000000000007Bo2P3oool01@2oM0000000
000000000000B9cO03/0oooo00@0gia800000000000007Bo@`3oool0103OW4P0000000000000M;l:
0?ooo`050;md00000000000000000018W=l0@03oool01@3ookl0M0000000000007@0_ooo01@0oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo00100?ooo`030?oo_`1d000000000080
000000<0B9cO0?ooo`3oool0o`3ooomY0?ooo`00@P3oool00`3o_g@0000007Boo`0;0?ooool00000
E`00000:0?ooo`00@P3oool00`3ooml0W4P0001d_`0;0?ooo`030000003oool0000000l0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool004<0oooo00<0gia80018W03Oool02P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`00<`3oool00`3ooml0W4P0000000070000000304RLg`3oool0oooo00<0oooo00<0omnL04P0
B02Lgol02P3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo0:D0oooo00<000000?oo
o`3oool0203oool004<0oooo00<0oono07@0001d_ol02P3oool300000:X0oooo00<000000?ooo`3o
ool0X`3oool3000000X0oooo00140?ooo`030;md0000M;l0oooo00T0oooo00<000000?ooo`3oool0
M03oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo0P0000020?oo
o`030000003oool000000080oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`2U0?oo
o`030000003oool0oooo00P0oooo00140?ooo`030=nLB000B9`0gooo00T0oooo00<000000?ooo`3o
ool0L@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00P0000020?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo0000
003oool0000001X0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`080?ooo`00A03o
ool00`3ogi`0B01809cOo`090?ooo`030000003oool0oooo06d0oooo0P0000020?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo0:D0oooo00<000000?ooo`3oool0203oool004@0oooo00<0oono07@0001d_ol02@3oool0
0`000000oooo0?ooo`1]0?ooo`800000903oool010000000oooo0?ooo`00000C0?ooo`030000003o
ool0oooo0:D0oooo00<000000?ooo`3oool0203oool004D0oooo00<0_g@0001d_`3oool0203oool0
0`000000oooo0?ooo`1[0?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool00000403o
ool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00P0oooo00130?ooo`050?oo_`1d0000
00000000M02oool0203oool00`000000oooo0?ooo`1Z0?ooo`800000;@3oool2000000l0oooo00<0
00000?ooo`3oool0Y@3oool00`000000oooo0?ooo`080?ooo`00D03oool3000006X0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0000000=0?ooo`030000003oool0oooo0:@0oooo0P00000:
0?ooo`00D03oool00`000000oooo0?ooo`1Y0?ooo`800000<@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0203oool00500oooo00<000000?ooo`3o
ool0J@3oool200000380oooo0P00000;0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3o
ool0203oool00500oooo00<000000?ooo`3oool0J03oool2000003<0oooo0`00000:0?ooo`030000
003oool0oooo0:D0oooo00<000000?ooo`3oool0203oool00500oooo00<000000?ooo`3oool0J03o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0Y@3o
ool00`000000oooo0?ooo`080?ooo`00D03oool00`000000oooo0?ooo`1X0?ooo`030000003oool0
oooo03@0oooo0P0000090?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0203oool0
0500oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0e0?ooo`800000203oool00`00
0000oooo0?ooo`2U0?ooo`030000003oool0oooo00P0oooo001@0?ooo`<00000J03oool00`000000
oooo0?ooo`0f0?ooo`8000001`3oool00`000000oooo0?ooo`2T0?ooo`8000002P3oool00500oooo
00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`080?ooo`00D03oool00`000000oooo0?oo
o`1X0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`2U0?ooo`030000003oool0oooo00P0oooo001@0?ooo`030000003oool0oooo06P0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:D0oooo00<00000
0?ooo`3oool0203oool00500oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`080?oo
o`00D03oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00P0oooo001@0?ooo`030000
003oool0oooo0:D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2U0?ooo`030000
003oool0oooo00P0oooo001@0?ooo`<00000JP3oool00`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0Y03oool2000000X0oooo001@0?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo00P0oooo000e0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol00`3oool0
1P3ookl0M00000000000000004RL0=ooo`P0oooo00<000000?ooo`3oool0O`3oool00`3ookl0M000
000000020000000307Boo`3oool0oooo02<0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo
0?ooo`080?ooo`00=03oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d
_ol00P3oool00`3ookl0M00004RLg`020?ooo`030=nLB00007@0_ooo00L0oooo00<000000?ooo`3o
ool0J`3oool00`000000oooo0?ooo`0A0?ooo`030?noM000000007Bo0080oooo00<0_gA809cOo`3o
ool07P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3o
ool0203oool003<0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`060?ooo`030?no
M000B9`0gooo00<0oooo00<0_g@004RLg`3oool01P3oool00`000000oooo0?ooo`1[0?ooo`030000
003oool0oooo01H0oooo00<0omnL04Q8W03Oool07P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0:D0oooo00<000000?ooo`3oool0203oool003<0oooo00<0oooO09a80018W=l00P3o
ool0103ooml0W4P00018W03Oool50?ooo`030?noM000B9`0gooo00<0oooo00<0_g@0001d_`3oool0
1P3oool00`000000oooo0?ooo`240?ooo`030?oo_`1d0000M;oo01l0oooo00D000000?ooo`3oool0
oooo0000002W0?ooo`030000003oool0oooo00P0oooo000V0?ooo`030?oog`2LB000000000L00000
00H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`030=nLB00004P0W=oo00D0oooo00<0oooO09a8
001d_ol00P3oool00`3ookl0M00004RLg`070?ooo`030000003oool0oooo06`0oooo00<000000?oo
o`3oool05@3oool00`3ogi`0B00007Boo`0O0?ooo`050000003oool0oooo0?ooo`000000Y`3oool0
0`000000oooo0?ooo`080?ooo`00=03oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO
00L0oooo00H0_g@00000B02Lgml0W4P00000M02oool70?ooo`<00000K03oool00`000000oooo0?oo
o`0D0?ooo`040?oOW0180000001809cOob<0oooo00<000000?ooo`3oool0X`3oool3000000X0oooo
000d0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0203oool01@3ooml0W4P00000
0000B9`0gooo00L0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0A0?ooo`050?oO
W018000000000000001d_ol0803oool01@000000oooo0?ooo`3oool000000:L0oooo00<000000?oo
o`3oool0203oool003@0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`070?ooo`06
0;md000004P0W=oo0?oOW018B9`0gooo1P3oool00`000000oooo0?ooo`1]0?ooo`800000503oool0
0`3ookl0M000001d_`0P0?ooo`050000003oool0oooo0?ooo`000000Y`3oool00`000000oooo0?oo
o`080?ooo`00=03oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00H0oooo00<0
omnL04P0001d_ol00P3oool00`3o_g@0B9cO0?ooo`050?ooo`030000003oool0oooo06h0oooo00<0
00000?ooo`3oool0503oool00`3OW4P007Bo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`000000
Y`3oool00`000000oooo0?ooo`080?ooo`00=@3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000
M;l0oooo00H0oooo00<0omnL04P0B02Lgol00P3oool00`3o_g@004RL0=ooo`050?ooo`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool04`3oool00`3ogi`0B01809cOo`0N0?ooo`050000003o
ool0oooo0?ooo`000000Y`3oool00`000000oooo0?ooo`080?ooo`00=P3oool01P3OW4P0001d0;oo
o`3ooml0W4P004RLg`L0oooo00<0oooO09a80018W=l00P3oool00`2oM00007Bo0?ooo`050?ooo`03
0000003oool0oooo06l0oooo00<000000?ooo`3oool0403oool01P2oM000M;oo0?ooo`3OW4P00018
09cOoah0oooo00D000000?ooo`3oool0oooo0000002W0?ooo`030000003oool0oooo00P0oooo000g
0?ooo`040=nLB00000000000001d_`T0oooo00D0oooO09a8000000000000001d_`070?ooo`030000
003oool0oooo06l0oooo00<000000?ooo`3oool04@3oool0102oM000000000000018W=lO0?ooo`80
00000P3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00P0oooo001@0?ooo`<00000
K`3oool2000003H0oooo00@000000?ooo`3oool00000YP3oool2000000X0oooo001@0?ooo`030000
003oool0oooo0700oooo00<000000?ooo`3oool0=03oool010000000oooo0?ooo`00002W0?ooo`03
0000003oool0oooo00P0oooo001@0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0
=03oool010000000oooo0?ooo`00002W0?ooo`030000003oool0oooo00P0oooo001@0?ooo`030000
003oool0oooo0700oooo0P00000e0?ooo`040000003oool0oooo00000:L0oooo00<000000?ooo`3o
ool0203oool00500oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0c0?ooo`800000
00<0oooo0000003oool0YP3oool00`000000oooo0?ooo`080?ooo`00D03oool00`000000oooo0?oo
o`2X0?ooo`030000003oool000000:L0oooo00<000000?ooo`3oool0203oool00500oooo00<00000
0?ooo`3oool0L@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool000000:L0oooo00<00000
0?ooo`3oool0203oool00500oooo0`00001a0?ooo`800000=@3oool00`000000oooo0000002V0?oo
o`8000002P3oool00500oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool000000:L0oooo00<000000?ooo`3oool0203oool00500oooo00<000000?ooo`3oool0
LP3oool2000003@0oooo0`00002W0?ooo`030000003oool0oooo00P0oooo001@0?ooo`030000003o
ool0oooo07<0oooo00<000000?ooo`3oool0<`3oool200000:L0oooo00<000000?ooo`3oool0203o
ool00500oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo0:D0oooo00<000000?ooo`3oool0203oool00500oooo00<000000?ooo`3oool0M03oool20000
03<0oooo0P00002W0?ooo`030000003oool0oooo00P0oooo001@0?ooo`030000003oool0oooo07D0
oooo00<000000?ooo`3oool00P00000_0?ooo`800000Y`3oool00`000000oooo0?ooo`080?ooo`00
D03oool00`000000oooo0?ooo`1h0?ooo`80000000<0oooo0000003oool0:`3oool300000:L0oooo
00<000000?ooo`3oool0203oool00500oooo0`00001k0?ooo`030000003oool0000002T0oooo0P00
00000`3oool000000?ooo`2U0?ooo`8000002P3oool00500oooo00<000000?ooo`3oool0O@3oool2
000000030?ooo`000000oooo0280oooo0P0000001@3oool000000?ooo`3oool000000:L0oooo00<0
00000?ooo`3oool0203oool003@0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Bo
o`030?ooo`050?oog`2LB000000000000000M;l02P3oool00`000000oooo0?ooo`1n0?ooo`040000
003oool00000000001l0oooo00<000000?ooo`0000000P0000040?ooo`030000003oool0oooo0:D0
oooo00<000000?ooo`3oool0203oool003<0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?oo
o`030?oOW0180000M;oo00<0oooo00L0gia8001d_`3oool0oono07@00000B9`0gooo00P0oooo00<0
00000?ooo`3oool0P@3oool010000000oooo0?ooo`00000J0?ooo`<0000000<0oooo0000003oool0
1@3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00P0oooo000b0?ooo`030?oog`2L
B000B9cO0080oooo00<0okmd0000B02Lgol01P3oool00`3ooml0W4P007Boo`020?ooo`030?oOW018
0000B9cO00P0oooo00<000000?ooo`3oool0Q03oool00`000000oooo000000020?ooo`030000003o
ool0oooo0140oooo00@000000?ooo`00000000002@3oool00`000000oooo0?ooo`2U0?ooo`030000
003oool0oooo00P0oooo000b0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo
1@3oool00`3ookl0M00007Boo`030?ooo`030;md000007@0_ooo00L0oooo00<000000?ooo`3oool0
QP3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3o
ool000000?ooo`00000<0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0203oool0
02D0oooo00<0oooO09a8000000001`0000001P18W=l0oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0
gia80000B02Lgol01@3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00L0oooo00<0
00000?ooo`3oool0S@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0
203oool003<0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`060?ooo`030;md0000
07@0_ooo0080oooo00<0gia80000B02Lgol01`3oool300000940oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0:<0oooo0`00000:0?ooo`00<`3oool0
0`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00H0oooo00P0okmd00000018W=l0oooo0?oo
g`2LB00004RL0=ooo`L0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`2U0?ooo`03
0000003oool0oooo00P0oooo000c0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool0
1@3oool00`3ooml0W4P000000002000000030000M02oool0oooo00L0oooo00<000000?ooo`3oool0
ZP3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00P0oooo000c0?ooo`040?oog`2L
B00004RL0=ooo`80oooo00<0gia80018W03Oool01P3oool00`3ookl0M000001d_`0;0?ooo`030000
003oool0oooo0:X0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`080?ooo`00=03o
ool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00L0oooo00<0omnL04P00018W=l02P3o
ool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0203o
ool003D0oooo00H0gia80000M02oool0oooO09a80018W=l90?ooo`040?oog`2LB000001d0;ooo`P0
oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00P0
oooo000f0?ooo`040=nLB00000000000001d_``0oooo00@0oono07@000000000B9cO1P3oool00`00
0000oooo0?ooo`2Z0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0203oool00500
oooo0`00002Z0?ooo`030000003oool0oooo0:@0oooo0P00000:0?ooo`00D03oool00`000000oooo
0?ooo`2Z0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0203oool00500oooo00<0
00000?ooo`3oool0ZP3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00P0oooo001@
0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`08
0?ooo`00D03oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo0:D0oooo00<000000?oo
o`3oool0203oool00500oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`2U0?ooo`03
0000003oool0oooo00P0oooo001@0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0
Y@3oool00`000000oooo0?ooo`080?ooo`00D03oool300000:X0oooo00<000000?ooo`3oool0Y03o
ool2000000X0oooo001@0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0Y@3oool0
0`000000oooo0?ooo`080?ooo`00D03oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo
0:D0oooo00<000000?ooo`3oool0203oool00500oooo00<000000?ooo`3oool0ZP3oool00`000000
oooo0?ooo`2U0?ooo`030000003oool0oooo00P0oooo001@0?ooo`030000003oool0oooo0:X0oooo
00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`080?ooo`00D03oool00`000000oooo0?oo
o`2Z0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0203oool00500oooo00<00000
0?ooo`3oool0ZP3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00P0oooo001@0?oo
o`<00000ZP3oool00`000000oooo0?ooo`2T0?ooo`8000002P3oool00500oooo00<000000?ooo`3o
ool0ZP3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00P0oooo000e0?ooo`040;md
00000000000007Boo`<0oooo00<0omnL04P0001d_ol01@3oool00`3ooml0W4P004RLg`090?ooo`03
0000003oool0oooo0:X0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`080?ooo`00
=03oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol01P3oool00`3O
W4P004RL0=ooo`080?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0Y@3oool00`00
0000oooo0?ooo`080?ooo`00<`3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00X0
oooo00<0omnL04P0B02Lgol0203oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo0:D0
oooo00<000000?ooo`3oool0203oool003<0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P0
0018W03Oool50?ooo`030?noM0000000000000@0000000<004RL0=ooo`3oool01@3oool00`000000
oooo0?ooo`2Z0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0203oool002H0oooo
00<0oooO09a8000000001`0000001P18W=l0oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0gia80000
B02Lgol01@3oool00`3ooml0W4Q809cOo`020?ooo`030;md0000M;l0oooo00L0oooo00<000000?oo
o`3oool0ZP3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00P0oooo000d0?ooo`03
0;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01P3oool01`3ookl0M01d0;ooo`3oool0okmd
0018W03Oool01`3oool300000:X0oooo00<000000?ooo`3oool0X`3oool3000000X0oooo000d0?oo
o`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l01`3oool01P3ogi`0B4RL0=ooo`3ogi`0
B01809cOo`L0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`2U0?ooo`030000003o
ool0oooo00P0oooo000d0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01`3oool0
1@3o_g@007Bo0?oog`2LB000B9cO00L0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?oo
o`2U0?ooo`030000003oool0oooo00P0oooo000d0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0
gia80018W03Oool0203oool0103OW4P0B9cO0;md0000M;l70?ooo`030000003oool0oooo0:X0oooo
00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`080?ooo`00=@3oool00`3ogi`0B00007Bo
o`020?ooo`030=nLB000M;l0oooo00T0oooo00@0gia807AdM00007@0_ooo1P3oool00`000000oooo
0?ooo`2Z0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0203oool003H0oooo00H0
gia80000M02oool0oooO09a80018W=l;0?ooo`030;md000004P0W=oo00H0oooo00<000000?ooo`3o
ool0ZP3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00P0oooo000g0?ooo`040=nL
B00000000000001d_``0oooo00<0oooO09a80018W=l01P3oool00`000000oooo0?ooo`2Z0?ooo`03
0000003oool0oooo0980oooo0`00000@0?ooo`030000003oool0oooo00P0oooo001@0?ooo`<00000
ZP3oool00`000000oooo0?ooo`2A0?ooo`D000003P3oool2000000X0oooo001@0?ooo`030000003o
ool0oooo0:X0oooo00<000000?ooo`3oool0S`3oool400000080oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`080?ooo`00603oool00`3OW4P0001d0;ooo`0e0?ooo`030000003oool0
oooo0:X0oooo00<000000?ooo`3oool0S`3oool3000000@0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`080?ooo`004@3oool00`3ookl0M7Bo0?ooo`040?ooo`030?oo_`1dB9`0gooo
03D0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`2>0?ooo`8000001P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo000A0?ooo`030?oOW01807@0_ooo00<0
oooo00<0okmd0000M02oool0=P3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`080?ooo`004@3oool01`3ogi`0B000
0000000004P0W=oo0?oOW018M;l0>03oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00P0oooo000C0?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool0=@3oool00`000000
oooo0?ooo`2Z0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo000B0?ooo`090?oo_`1d07@0_ooo0?ooo`3o
oml0W4P00000000007@0_ooo03D0oooo0`00002Z0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`8000002P3oool00140oooo00<0oono07@0
M02oool0103oool00`3ogi`0B7Bo0?ooo`0e0?ooo`030000003oool0oooo0:X0oooo00<000000?oo
o`3oool0S03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0203oool00140oooo00<0okmd0000001d_ol00`3oool00`3ookl0M4RL0=ooo`0f0?ooo`03
0000003oool0oooo0:X0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo001@0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0
V@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo000K0?ooo`040?noM000
0000001d0;oooc40oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`2;0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0203oool00100oooo00P0gia80000001d_ol0oooo
0?oog`2LW;l0oooO09a800<0000000<007Bo0?ooo`3oool0<P3oool00`000000oooo0?ooo`2Z0?oo
o`030000003oool0oooo08/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`080?oo
o`003@3oool0103OW4P0000000000000M;l30?ooo`040?oo_`1d0000001809cOo`80oooo00<0_ibL
0=ooo`3oool0<`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo0:D0oooo00<00000
0?ooo`3oool0203oool000`0oooo00@0oono07@00000B9`0gooo203oool01@3Ogml0_g@000000000
000007Bo03<0oooo0`00002Z0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool01`3o
ool2000000X0oooo000G0?ooo`030?oog`2LB000M;oo0080oooo00<0gia80000M02oool0<@3oool0
0`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`005`3oool00`3ooml0W7BL0=ooo`020?ooo`030=nLM02Lgol0oooo
0340oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0203oool003D0oooo00@0_g@0000000000000M;oo0`3oool00`3o
gi`0B00007Boo`020?ooo`030=nLB0000000000000<0000000<0B9cO0?ooo`3oool01P3oool00`00
0000oooo0?ooo`2Z0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo000d0?ooo`060=nLB000M;l0oooo0?oO
W0180000B9cO0P3oool00`3ogi`0B00007Boo`030?ooo`030?noM000M;l0oooo0080oooo00<0_gAd
0;ooo`3oool01P3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo08T0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo000c0?oo
o`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0203oool00`3o_g@007Bo0?ooo`0:0?oo
o`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00P0oooo000c0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000
B9`0gooo203oool00`3o_g@007Bo0?ooo`090?ooo`030000003oool0oooo0:X0oooo00<000000?oo
o`3oool0Y@3oool00`000000oooo0?ooo`080?ooo`009P3oool00`3ooml0W4P00000000700000006
04RLg`3oool0oooo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`090?ooo`030?noM018W=l0
oooo00P0oooo0`00002Z0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool01@3oool3
000000X0oooo000d0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l02P3oool00`3O
W4P0B9cO0?ooo`070?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0Q`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool003@0
oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0;0?ooo`030;md001d_ol0oooo00H0
oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0203oool003@0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL
0=ooo`0:0?ooo`030?oOW01807@0_ooo00H0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo
0?ooo`2L0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool003@0oooo00@0
oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`0:0?ooo`030?oog`2LB000M;oo00H0oooo
00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`00=@3oool00`3ogi`0B00007Bo
o`020?ooo`030=nLB000M;l0oooo00X0oooo00<0oono07@00018W=l01P3oool00`000000oooo0?oo
o`2Z0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`080?ooo`00=P3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`L0oooo00L0okmd0018W03Oool0
oooo0=nLB00004P0W=oo00H0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`250?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?oo
o`00=`3oool0103OW4P0000000000000M;l90?ooo`050?oOW018000000000000001d_ol01`3oool0
0`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo001@0?ooo`<00000ZP3oool00`00
0000oooo0?ooo`230?ooo`030000003oool0oooo01h0oooo0P00000:0?ooo`00D03oool00`000000
oooo0?ooo`2Z0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`080?ooo`00D03oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo
001@0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00500oooo00<00000
0?ooo`3oool0ZP3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0203oool00500oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`200?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?oo
o`00D03oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`00
00006`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo001@0?ooo`<00000
ZP3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02<0oooo0P00000:0?ooo`00D03o
ool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`080?ooo`00D03oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0
oooo07d0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`00D03oool00`00
0000oooo0?ooo`2Z0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo001@0?ooo`030000003oool0oooo0:X0
oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0203oool00500oooo00<000000?ooo`3oool0ZP3oool00`000000oooo
0?ooo`1j0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0203oool00500oooo00<0
00000?ooo`3oool0ZP3oool00`000000oooo0?ooo`1i0?ooo`800000:P3oool00`000000oooo0?oo
o`080?ooo`00D03oool300000:X0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo00D0oooo0P00000:0?ooo`00D03oool00`000000oooo0?ooo`2Z0?oo
o`030000003oool0oooo09`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?oo
o`00@P3oool0102oM00000000000001d_ol:0?ooo`030000003oool0oooo0:X0oooo00<000000?oo
o`3oool0M`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00P0oooo00110?ooo`06
0=nLB000M;l0oooo0?oOW0180000B9cO2@3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0
oooo07L0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`080?ooo`00@03oool00`3o
oml0W4P004RLg`020?ooo`030?noM00004P0W=oo00P0oooo00<000000?ooo`3oool0ZP3oool00`00
0000oooo0?ooo`1f0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0203oool00400
oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool70?ooo`030000003oool0oooo
0:X0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00400oooo00<0oooO09a80000M;l00`3oool00`3OW4P0
001809cOo`070?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0M@3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00440oooo
00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`070?ooool00000E`00000:0?ooo`00@@3o
ool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00L0oooo00<000000?ooo`3oool0ZP3o
ool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00P0oooo00110?ooo`030?oOW0180000
B9cO00<0oooo00<0_g@00018W03Oool01P3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0
oooo07@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`080?ooo`00@@3oool0103o
oml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00H0oooo00<000000?ooo`3oool0ZP3oool0
0`000000oooo0?ooo`1c0?ooo`800000<03oool00`000000oooo0?ooo`080?ooo`00@P3oool00`3o
gi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00H0oooo00<000000?ooo`3oool0ZP3oool00`00
0000oooo0?ooo`1c0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0203oool004<0
oooo00H0gia80000M02oool0oooO09a80018W=l70?ooo`030000003oool0oooo0:X0oooo00<00000
0?ooo`3oool0L@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00P0oooo00140?oo
o`040=nLB00000000000001d_`P0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`1a
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`00D03oool3000000T0oooo0P0000000`3oool000000?ooo`2L0?ooo`030000003oool0oooo
0700oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`070?ooo`8000002P3oool00500
oooo00<000000?ooo`3oool0203oool3000000030?ooo`000000000009`0oooo00<000000?ooo`3o
ool0K`3oool2000003@0oooo00<000000?ooo`3oool0203oool00500oooo00<000000?ooo`3oool0
1P3oool3000000@0oooo00@000000?ooo`3oool00000V@3oool00`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo00/0oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`0C0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00500oooo00<000000?ooo`3oool0
1@3oool3000000P0oooo00@000000?ooo`3oool00000UP3oool00`000000oooo0?ooo`1]0?ooo`03
0000003oool0oooo00h0oooo00<0okmd001d_`3oool00P3oool00`2oM7@0_ooo0?ooo`0C0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00500oooo00<000000?ooo`3oool0
1@3oool2000000`0oooo00@000000?ooo`3oool00000T`3oool00`000000oooo0?ooo`1]0?ooo`03
0000003oool0oooo00l0oooo00<0okmd001d_`3oool08`3oool00`000000oooo0?ooo`080?ooo`00
D03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`000000
T@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0180oooo00<0okmd001d_`3oool0
8P3oool00`000000oooo0?ooo`080?ooo`00D03oool00`000000oooo0?ooo`0H0?ooo`040000003o
ool0oooo000008h0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0C0?ooo`030?no
M018W=l0oooo01@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`00D03o
ool3000000D0oooo00<000000?ooo`3oool04`3oool020000000oooo000000000000oooo0000003o
ool00000Q`3oool00`000000oooo0?ooo`220?ooo`030=nLB018W=l0oooo01<0oooo00<000000?oo
o`3oool02@3oool2000000X0oooo001@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool05@3oool2000000030?ooo`000000oooo008000000P3oool200000080oooo00<000000?ooo`00
0000O@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo01P0oooo00<0_g@007Boo`3o
ool07`3oool00`000000oooo0?ooo`080?ooo`00D03oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool00P0000020?ooo`070000003oool000000?ooo`00
0000oooo0000001i0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0603oool00`3o
gi`0B01d0;ooo`0@0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool00500
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool000000080
0000M`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo01/0oooo00<0oooO09a8001d
_ol0403oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo001@0?ooo`030000
003oool0oooo0340oooo0P00001g0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0
6`3oool00`3ookl0M00004RLg`0?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
203oool00500oooo00<000000?ooo`3oool0=@3oool2000007<0oooo00<000000?ooo`3oool0O`3o
ool01`3o_g@004RL0=ooo`3oool0gia80000B02Lgol03`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00P0oooo001@0?ooo`030000003oool0oooo03D0oooo0P0000000`3oool00000
0?ooo`1`0?ooo`030000003oool0oooo0800oooo00D0omnL04P000000000000007Boo`0?0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool00500oooo0`0000060?ooo`030000
003oool0oooo02l0oooo00D000000?ooo`000000oooo0000001]0?ooo`030000003oool0oooo0640
oooo00<000000?ooo`3oool0;`3oool2000000l0oooo0P00000:0?ooo`00D03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0340oooo00L000000?ooo`000000oooo0000003oool00000
06T0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0203oool003D0oooo00@0_g@0000000000000M;oo0`3oool00`3o
gi`0B00007Boo`020?ooo`030=nLB0000000000000<0000000<0B9cO0?ooo`3oool01P3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`1O0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`080?ooo`00=03oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL
04P0001d_ol00`3oool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02oool0oooo00H0oooo00<00000
0?ooo`3oool0A03oool010000000oooo0?ooo`00001R0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool0;P3oool2000001<0oooo00<000000?ooo`3oool0203oool003<0oooo00<0oooO
09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?noM000M;l0oooo00X0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0m0?ooo`050000003oool0oooo0?ooo`000000GP3o
ool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`080?ooo`00<`3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB000
04RL0=ooo`P0oooo00<0okmd001d_`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`1L0?ooo`800000<@3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000c0?ooo`030?oog`2LB000
07Bo00<0oooo00<0gia80000B02Lgol02@3oool00`3o_g@0B9cO0?ooo`080?ooo`030000003oool0
oooo0540oooo00<000000?ooo`000000EP3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`00=03oool00`2o
M00004RL0=ooo`020?ooo`030?oOW0180000B9cO00X0oooo00<0gia804RLg`3oool01`3oool30000
00P0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0000001F0?ooo`030000003oool0oooo
05/0oooo0P00000`0?ooo`030000003oool0oooo01<0oooo0`00000:0?ooo`00=03oool00`3OW4P0
001809cOo`020?ooo`030?oog`2LB00007Bo00/0oooo00<0_g@007Boo`3oool01P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo04/0oooo0P00001B0?ooo`030000003oool0oooo05/0
oooo00<000000?ooo`3oool0;P3oool2000001L0oooo00<000000?ooo`3oool0203oool003@0oooo
00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`0:0?ooo`030?oOW01807@0_ooo00H0oooo
00<000000?ooo`3oool0:P3oool00`3ookl0M000000000020000000304RLg`3oool0oooo02@0oooo
0P0000000`3oool000000?ooo`1?0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0oooo000d0?ooo`040?oog`2L
B00004RL0=ooo`80oooo00<0gia80018W03Oool02P3oool00`3ooml0W4P007Boo`060?ooo`030000
003oool0oooo02`0oooo00<0okmd0000001d_ol0:P3oool2000004l0oooo00<000000?ooo`3oool0
FP3oool2000002`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`080?ooo`00=@3o
ool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00X0oooo00<0oono07@00018W=l01P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0200oooo00<0oooO09a80000M;l0:P3o
ool3000004h0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0000001`0oooo00<000000?ooo`3oool0203oool003H0oooo00H0gia80000M02oool0oooO09a8
0018W=l70?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cOo`060?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool08@3oool00`3OW4P004RL0=ooo`0[0?ooo`800000C@3oool00`00
0000oooo0?ooo`1J0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`080?ooo`00=`3oool0103OW4P0000000000000M;l90?ooo`050?oOW01800000000
0000001d_ol01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0200oooo00<0omnL
04P0B02Lgol0:`3oool3000004`0oooo00<000000?ooo`3oool0FP3oool3000002D0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`080?ooo`00D03oool3000000X0oooo00<000000?oo
o`3oool0803oool00`3ookl0M00007Boo`0]0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool0F`3oool2000000030?ooo`000000oooo01h0oooo00D000000?ooo`3oool0oooo0000000Q
0?ooo`8000002P3oool00500oooo00<000000?ooo`3oool0;P3oool00`2oM00007Bo0?ooo`0/0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool0GP3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo001@0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool07`3oool00`3OW4P004RL0=ooo`0/0?ooo`030000003o
ool0oooo04X0oooo00<000000?ooo`3oool0HP3oool00`000000oooo000000030?ooo`0:0000003o
ool0oooo0000003oool000000?ooo`000000oooo00000080oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo001@0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool07`3oool00`3ogi`0B01809cOo`0Z0?ooo`030000003oool0
000004`0oooo00<000000?ooo`3oool0J`3oool01`000000oooo0000003oool000000?ooo`000000
0P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00P0oooo001@0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool07P3oool00`3ookl0M00007Boo`0Z0?ooo`030000003o
ool0oooo04`0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`080?ooo`00D03oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01l0oooo00<0_g@0001d_`3oool09P3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0203oool0
0500oooo00<000000?ooo`3oool0;@3oool01@3ookl0M0000000000007@0_ooo02@0oooo00<00000
0?ooo`000000D@3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00P0oooo001@0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1A0?oo
o`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0203oool00500oooo0`00000?0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`2T0?ooo`80
00002P3oool00500oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0n0?ooo`040000
003oool0oooo000005D0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`080?ooo`00
D03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00P0oooo001@0?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`2U0?ooo`030000003o
ool0oooo00P0oooo001@0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0000001J0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0203oool0
0500oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
05`0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`080?ooo`00D03oool00`000000
oooo0?ooo`190?ooo`030000003oool0000005h0oooo00<000000?ooo`3oool0Y@3oool00`000000
oooo0?ooo`080?ooo`00D03oool3000001D0oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0000001P0?ooo`030000003oool0oooo0:@0oooo0P00000:0?ooo`00D03oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?oo
o`2U0?ooo`030000003oool0oooo00P0oooo000e0?ooo`040;md00000000000007Boo`<0oooo00<0
omnL04P0001d_ol01@3oool00`3ooml0W4P004RLg`090?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0:D0oooo00<0
00000?ooo`3oool0203oool003@0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oO
W0180000M;oo00H0oooo00<0gia80018W03Oool0203oool00`000000oooo0?ooo`0H0?ooo`800000
:@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0
203oool003<0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`0:0?ooo`030?oOW018
04P0W=oo00P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo06L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`080?ooo`00<`3oool0
0`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`D0oooo00<0okmd0000000000001000
00000`00B9`0gooo0?ooo`050?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0I`3o
ool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00P0oooo000c0?ooo`030?oog`2LB000
07Bo00<0oooo00<0gia80000B02Lgol01@3oool00`3ooml0W4Q809cOo`020?ooo`030;md0000M;l0
oooo00L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo06/0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`080?ooo`00=03oool00`2o
M00004RL0=ooo`020?ooo`030?oOW0180000B9cO00H0oooo00L0oono07@0M02oool0oooo0?noM000
B9`0gooo00L0oooo0`00000L0?ooo`040000003oool0oooo000001T0oooo00@000000?ooo`3oool0
0000K@3oool00`000000oooo0?ooo`2S0?ooo`<000002P3oool003@0oooo00<0gia80000B02Lgol0
0P3oool00`3ooml0W4P0001d_`070?ooo`060?oOW018B9`0gooo0?oOW01804P0W=oo1`3oool00`00
0000oooo0?ooo`0O0?ooo`040000003oool0oooo000001<0oooo00@000000?ooo`3oool00000L03o
ool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00P0oooo000d0?ooo`030?oOW0180000
B9cO00<0oooo00<0_g@00018W03Oool01`3oool01@3o_g@007Bo0?oog`2LB000B9cO00L0oooo00<0
00000?ooo`3oool08P3oool020000000oooo0000003oool000000?ooo`000000oooo0P0000000`3o
ool00000000000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool0L@3oool00`00
0000oooo0?ooo`2U0?ooo`030000003oool0oooo00P0oooo000d0?ooo`040?oog`2LB00004RL0=oo
o`80oooo00<0gia80018W03Oool0203oool0103OW4P0B9cO0;md0000M;l70?ooo`030000003oool0
oooo02@0oooo00H000000?ooo`000000oooo0000003oool2000000030?ooo`00000000000080oooo
00<000000?ooo`000000MP3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00P0oooo
000e0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool02@3oool0103OW4P0M7Ad0000
M02oool60?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo
0?ooo`080?ooo`00=P3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`/0oooo00<0_g@00000B02L
gol01P3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3o
ool0203oool003L0oooo00@0gia800000000000007Bo303oool00`3ooml0W4P004RLg`060?ooo`03
0000003oool0000000l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00500oooo0`00000?0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`800000
2P3oool00500ooooo`00001G000000X0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-1.63462, -1.38796, \
0.00966222, 0.0105543}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        ListPlot[Take[pts, {\[ScriptL], Length[pts], 3}], Frame \[Rule] True, 
          FrameLabel \[Rule] {\*"\"\<\!\(x\_k\)\>\"", \*"\"\<\!\(x\_k\%\
\[Prime]\)\>\""}], {\[ScriptL], 1, 3}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
1.79682 1.67023 0.0147151 1.39977 [
[.12659 -0.0125 -9.34375 -15.6875 ]
[.12659 -0.0125 9.34375 0 ]
[.29361 -0.0125 -13.8438 -15.6875 ]
[.29361 -0.0125 13.8438 0 ]
[.46063 -0.0125 -13.8438 -15.6875 ]
[.46063 -0.0125 13.8438 0 ]
[.62765 -0.0125 -13.9688 -15.6875 ]
[.62765 -0.0125 13.9688 0 ]
[.79468 -0.0125 -13.9688 -15.6875 ]
[.79468 -0.0125 13.9688 0 ]
[.9617 -0.0125 -13.8438 -15.6875 ]
[.9617 -0.0125 13.8438 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -7.125 -31.375 ]
[.5 -0.0125 7.125 -15.6875 ]
[-0.0125 .01472 -10 -7.84375 ]
[-0.0125 .01472 0 7.84375 ]
[-0.0125 .15469 -19 -7.84375 ]
[-0.0125 .15469 0 7.84375 ]
[-0.0125 .29467 -19 -7.84375 ]
[-0.0125 .29467 0 7.84375 ]
[-0.0125 .43465 -19 -7.84375 ]
[-0.0125 .43465 0 7.84375 ]
[-0.0125 .57463 -19 -7.84375 ]
[-0.0125 .57463 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.6875 -7.125 ]
[-0.01875 .30902 -19 7.125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12659 0 m
.12659 .00625 L
s
gsave
.12659 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.29361 0 m
.29361 .00625 L
s
gsave
.29361 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
1.000 setlinewidth
grestore
.46063 0 m
.46063 .00625 L
s
gsave
.46063 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.62765 0 m
.62765 .00625 L
s
gsave
.62765 -0.0125 -74.9688 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
1.000 setlinewidth
grestore
.79468 0 m
.79468 .00625 L
s
gsave
.79468 -0.0125 -74.9688 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.9617 0 m
.9617 .00625 L
s
gsave
.9617 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.15999 0 m
.15999 .00375 L
s
.19339 0 m
.19339 .00375 L
s
.2268 0 m
.2268 .00375 L
s
.2602 0 m
.2602 .00375 L
s
.32701 0 m
.32701 .00375 L
s
.36042 0 m
.36042 .00375 L
s
.39382 0 m
.39382 .00375 L
s
.42723 0 m
.42723 .00375 L
s
.49404 0 m
.49404 .00375 L
s
.52744 0 m
.52744 .00375 L
s
.56085 0 m
.56085 .00375 L
s
.59425 0 m
.59425 .00375 L
s
.66106 0 m
.66106 .00375 L
s
.69446 0 m
.69446 .00375 L
s
.72787 0 m
.72787 .00375 L
s
.76127 0 m
.76127 .00375 L
s
.82808 0 m
.82808 .00375 L
s
.86149 0 m
.86149 .00375 L
s
.89489 0 m
.89489 .00375 L
s
.9283 0 m
.9283 .00375 L
s
.09318 0 m
.09318 .00375 L
s
.05978 0 m
.05978 .00375 L
s
.02637 0 m
.02637 .00375 L
s
.9951 0 m
.9951 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -68.125 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 17.688 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
73.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .15469 m
.00625 .15469 L
s
gsave
-0.0125 .15469 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .29467 m
.00625 .29467 L
s
gsave
-0.0125 .29467 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .43465 m
.00625 .43465 L
s
gsave
-0.0125 .43465 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
0 .57463 m
.00625 .57463 L
s
gsave
-0.0125 .57463 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04271 m
.00375 .04271 L
s
0 .07071 m
.00375 .07071 L
s
0 .0987 m
.00375 .0987 L
s
0 .1267 m
.00375 .1267 L
s
0 .18269 m
.00375 .18269 L
s
0 .21068 m
.00375 .21068 L
s
0 .23868 m
.00375 .23868 L
s
0 .26667 m
.00375 .26667 L
s
0 .32267 m
.00375 .32267 L
s
0 .35066 m
.00375 .35066 L
s
0 .37866 m
.00375 .37866 L
s
0 .40665 m
.00375 .40665 L
s
0 .46264 m
.00375 .46264 L
s
0 .49064 m
.00375 .49064 L
s
0 .51863 m
.00375 .51863 L
s
0 .54663 m
.00375 .54663 L
s
0 .60262 m
.00375 .60262 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -94.9688 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.125 11.8438 translate
90 rotate
-68.125 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 18.625 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
68.563 11.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\242) show
73.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.12659 .61178 m
.12659 .61803 L
s
.29361 .61178 m
.29361 .61803 L
s
.46063 .61178 m
.46063 .61803 L
s
.62765 .61178 m
.62765 .61803 L
s
.79468 .61178 m
.79468 .61803 L
s
.9617 .61178 m
.9617 .61803 L
s
.125 Mabswid
.15999 .61428 m
.15999 .61803 L
s
.19339 .61428 m
.19339 .61803 L
s
.2268 .61428 m
.2268 .61803 L
s
.2602 .61428 m
.2602 .61803 L
s
.32701 .61428 m
.32701 .61803 L
s
.36042 .61428 m
.36042 .61803 L
s
.39382 .61428 m
.39382 .61803 L
s
.42723 .61428 m
.42723 .61803 L
s
.49404 .61428 m
.49404 .61803 L
s
.52744 .61428 m
.52744 .61803 L
s
.56085 .61428 m
.56085 .61803 L
s
.59425 .61428 m
.59425 .61803 L
s
.66106 .61428 m
.66106 .61803 L
s
.69446 .61428 m
.69446 .61803 L
s
.72787 .61428 m
.72787 .61803 L
s
.76127 .61428 m
.76127 .61803 L
s
.82808 .61428 m
.82808 .61803 L
s
.86149 .61428 m
.86149 .61803 L
s
.89489 .61428 m
.89489 .61803 L
s
.9283 .61428 m
.9283 .61803 L
s
.09318 .61428 m
.09318 .61803 L
s
.05978 .61428 m
.05978 .61803 L
s
.02637 .61428 m
.02637 .61803 L
s
.9951 .61428 m
.9951 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15469 m
1 .15469 L
s
.99375 .29467 m
1 .29467 L
s
.99375 .43465 m
1 .43465 L
s
.99375 .57463 m
1 .57463 L
s
.125 Mabswid
.99625 .04271 m
1 .04271 L
s
.99625 .07071 m
1 .07071 L
s
.99625 .0987 m
1 .0987 L
s
.99625 .1267 m
1 .1267 L
s
.99625 .18269 m
1 .18269 L
s
.99625 .21068 m
1 .21068 L
s
.99625 .23868 m
1 .23868 L
s
.99625 .26667 m
1 .26667 L
s
.99625 .32267 m
1 .32267 L
s
.99625 .35066 m
1 .35066 L
s
.99625 .37866 m
1 .37866 L
s
.99625 .40665 m
1 .40665 L
s
.99625 .46264 m
1 .46264 L
s
.99625 .49064 m
1 .49064 L
s
.99625 .51863 m
1 .51863 L
s
.99625 .54663 m
1 .54663 L
s
.99625 .60262 m
1 .60262 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.12659 0 m
.12659 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.24047 .54107 Mdot
.49008 .17985 Mdot
.52358 .59793 Mdot
.23683 .13915 Mdot
.87228 .43879 Mdot
.04217 .10687 Mdot
.93548 .3199 Mdot
.11606 .40429 Mdot
.59661 .22086 Mdot
.422 .60285 Mdot
.33616 .15966 Mdot
.75879 .49892 Mdot
.07447 .08868 Mdot
.97137 .35131 Mdot
.04638 .25937 Mdot
.7385 .25519 Mdot
.30905 .5818 Mdot
.44645 .16597 Mdot
.58323 .58185 Mdot
.17965 .11894 Mdot
.92466 .4098 Mdot
.03054 .11918 Mdot
.91492 .30608 Mdot
.1504 .45253 Mdot
.55761 .20767 Mdot
.45688 .60312 Mdot
.30072 .15522 Mdot
.803 .47518 Mdot
.06038 .09587 Mdot
.95686 .33794 Mdot
.07411 .32845 Mdot
.66628 .23913 Mdot
.36332 .59748 Mdot
.39793 .16238 Mdot
.666 .5462 Mdot
.11722 .09325 Mdot
.96987 .37926 Mdot
.02381 .15075 Mdot
.87025 .28755 Mdot
.20393 .51062 Mdot
.51392 .18993 Mdot
.49816 .60119 Mdot
.26119 .14628 Mdot
.84719 .45196 Mdot
.04839 .10302 Mdot
.94281 .3261 Mdot
.10168 .38071 Mdot
.61707 .22685 Mdot
.40428 .60198 Mdot
.35472 .16098 Mdot
.73317 .51244 Mdot
.08415 .08686 Mdot
.97611 .35904 Mdot
.03519 .22086 Mdot
.78238 .26508 Mdot
.27743 .56574 Mdot
.46758 .1713 Mdot
.55145 .59196 Mdot
.20985 .13011 Mdot
.89821 .42487 Mdot
.03614 .11155 Mdot
.92717 .31347 Mdot
.13124 .42702 Mdot
.57793 .21474 Mdot
.43835 .60332 Mdot
.31956 .15783 Mdot
.78022 .48753 Mdot
.06727 .09143 Mdot
.96546 .3449 Mdot
.0583 .29234 Mdot
.70311 .24732 Mdot
.33479 .59108 Mdot
.42562 .16346 Mdot
.61849 .56783 Mdot
.14973 .10657 Mdot
.94853 .39536 Mdot
.02602 .12895 Mdot
.90034 .29855 Mdot
.17042 .47659 Mdot
.53961 .20046 Mdot
.47309 .60295 Mdot
.28543 .15201 Mdot
.82075 .46599 Mdot
.05534 .09824 Mdot
.95191 .33324 Mdot
.08437 .3495 Mdot
.64604 .23418 Mdot
.37957 .6 Mdot
.38143 .16178 Mdot
.69277 .53323 Mdot
.10252 .08846 Mdot
.97619 .37126 Mdot
.02535 .17084 Mdot
.84394 .28 Mdot
.22855 .53181 Mdot
.4975 .183 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00l@3oool01`2oM4P0W=oo0?oo
o`3ogi`0B0000000001d_ol0^03oool00?40oooo00P0okmd04RLg`3oool0gia8001d_`3oool0_ibL
0=oookL0oooo003X0?ooo`0>0=nLB000000007Bo0?ooo`3ooml0W4P00000001d_ol0oooo0?oo_`1d
B4P0B7BL09a8001d_onj0?ooo`00jP3oool0303o_g@0M;oo0?oOW01804P0W=oo0;mdM02oool0oooO
09a8M02o_g@0001d0;oookX0oooo003[0?ooo`040;mdM02LW4P004RL0=ooo`<0oooo00@0gia807Bo
o`3ookl0M7Bo^P3oool00>/0oooo00<0oono07@00000M;l0103oool0103ogi`0B7Bo0?oog`2LB002
0000000307Boo`3oool0oooo0;D0oooo003[0?ooo`030?oo_`1d0000M;oo00@0oooo00<0oooO09a8
M02oool0^`3oool00>/0oooo00@0okmd00000000B9`0gooo103oool00`3OW4P0M;oo0?ooo`2j0?oo
o`00j`3oool01@2oM00004RL0=oOW018B9`0gooo0080oooo00<0gia800000000M;l0^`3oool00>T0
oooo00T0okmd000000000000M;oo0?ooo`3ogi`0B0000018W03Oool0_P3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0740oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`0]0?ooo`040;md000000000000
07Boo`<0oooo00<0omnL04P0001d_ol00P3oool0103OW4P000000000M02ooolZ0?ooo`040;md0000
0000000007Boo`<0oooo00<0omnL04P0001d_ol00`3oool01P3ookl0M00000000000000004RL0=oo
obL0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`030?ooo`030?oo_`1dB9`0
gooo02X0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`030?ooo`050?oog`2L
B000000000000000M;l0:03oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080
oooo00H0omnL04P00000000000000018W03Oool@0?ooo`00L`3oool00`3o_g@0000007Boo`0_0?oo
o`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`040?ooo`030?oo_`1d
000007Bo02P0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo0080
oooo00<0oono07@00018W=l00P3oool00`3OW4P0001d0;ooo`0U0?ooo`060=nLB000M;l0oooo0?oO
W0180000B9cO0P3oool00`3ogi`0B00007Boo`040?ooo`030=nLB018W=l0oooo02P0oooo00H0gia8
001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00<0oooo00L0gia8001d_`3oool0
oono07@00000B9`0gooo02D0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW018
0000M;oo0080oooo00H0okmd0000001d_ol0oooo0?oOW018M;l@0?ooo`00L`3oool00`3ooml0W4P0
001d_`0^0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol02P3oool00`2oM000001d
0;ooo`0U0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol01P3oool00`3o_g@004RL
0=ooo`030?ooo`030;md0018W=l0oooo02<0oooo00<0oooO09a80018W=l00P3oool00`3o_g@00018
09cOo`080?ooo`030?oo_`1d07@0_ooo02L0oooo00<0oooO09a80018W=l00P3oool00`3o_g@00018
09cOo`060?ooo`030?oog`2LB000M;oo0080oooo00<0omnL04P00018W=l0903oool00`3ooml0W4P0
04RLg`020?ooo`030?noM00004P0W=oo00/0oooo00<0okmd04RLg`3oool03P3oool007@0oooo00<0
gia80018W03Oool0;@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`T0oooo
00@0oooO09a8000007@0_ooo903oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=oo
o`D0oooo00<0okmd0018W03Oool00`3oool00`2oM00007Bo0?ooo`0S0?ooo`030?oog`2LB000B9cO
0080oooo00@0oooO09a80000B9`0gooo203oool00`3o_g@007Bo0?ooo`0V0?ooo`030?oog`2LB000
B9cO0080oooo00@0oooO09a80000B9`0gooo1@3oool00`3ookl0M00007Boo`030?ooo`030;md0000
07@0_ooo02<0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool:0?ooo`030?oo
_`1d07@0_ooo00h0oooo001T0?ooo`030?oog`2LB000000000L0000000<0B9cO0?ooo`3oool00`3o
ool00`3ogi`0B01809cOo`0P0?ooo`030?oog`2LB000000000L0000000H0B9cO0?ooo`3oool0oooO
09a80000M;l30?ooo`030=nLB00004P0W=oo00L0oooo00<0omnL04P0000000000P0000000`00M;l0
oooo0?ooo`0E0?ooo`030?oog`2LB000000000L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l3
0?ooo`030=nLB00004P0W=oo00D0oooo00<0oooO09a8001d_ol00P3oool00`3ookl0M00004RLg`0G
0?ooo`030?oog`2LB000000000L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`030=nL
B00004P0W=oo00P0oooo00<0oooO09a8B02Lgol06@3oool00`3ooml0W4P0000000070000000604RL
g`3oool0oooo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`050?ooo`030?oog`2LB00007Bo
00<0oooo00<0gia80000B02Lgol05P3oool00`3ooml0W4P0000000070000000604RLg`3oool0oooo
0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`0:0?ooo`030?oog`2LB000M;oo00h0oooo001d
0?ooo`030?oo_`1d0000M;oo02h0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`06
0?ooo`080?oo_`1d000004RL0=ooo`3oool0_g@00000B02LgolT0?ooo`030;md0000B9`0gooo0080
oooo00<0omnL04P00018W=l01`3oool01P2oM000001809cOg`2LB000001d0;ooobD0oooo00<0_g@0
0018W03Oool00P3oool00`3ogi`0B00004RLg`090?ooo`030?oOW018M;l0oooo02H0oooo00<0_g@0
0018W03Oool00P3oool00`3ogi`0B00004RLg`060?ooo`030;md000007@0_ooo0080oooo00<0gia8
0000B02Lgol0903oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00X0oooo00<0oono
07@00018W=l03P3oool007D0oooo00<0_g@0001d_`3oool0;@3oool00`3OW4P0001809cOo`020?oo
o`030?oog`2LB00007Bo00H0oooo00<0omnL04P0001d_ol00P3oool00`3ogi`0B00004RLg`0T0?oo
o`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0203oool01@3ooml0W4P000000000B9`0
gooo02D0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0:0?ooo`030;md001d_ol0
oooo02D0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`060?ooo`080?noM0000000
B9cO0?ooo`3ooml0W4P00018W03OoolT0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000
M;l02P3oool00`3o_g@0000007Boo`0>0?ooo`00M@3oool00`3OW4P004RL0=ooo`0]0?ooo`030?oO
W0180000B9cO00<0oooo00<0_g@00018W03Oool01@3oool00`3ogi`0B00007Boo`020?ooo`030?oo
g`2LB00007Bo02@0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`070?ooo`060;md
000004P0W=oo0?oOW018B9`0gooo903oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo
00T0oooo00<0omnL04Q8W03Oool09@3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo
00D0oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`0T0?ooo`030?oOW0180000B9cO
00<0oooo00<0_g@00018W03Oool01P3oool01P3ogml0gooo0?noM0000000001d0;ooo`h0oooo001e
0?ooo`030?oOW01804P0W=oo02d0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=oo
o`050?ooo`030?oo_`1d000007Bo00<0oooo00<0gia80018W03Oool08`3oool0103ooml0W4P00018
W03Oool20?ooo`030=nLB000B9`0gooo00H0oooo00<0omnL04P0001d_ol00P3oool00`3o_g@0B9cO
0?ooo`0S0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool02P3oool00`3OW4P0
B9cO0?ooo`0T0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool01P3oool00`3o
okl0M000001d_`0X0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool01P3oool0
1@3ookl0M0000000000004P0W=oo00l0oooo001e0?ooo`030?oo_`1d0000M;oo02h0oooo00<0omnL
04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`060?ooo`030;md000007@0_ooo0080oooo00<0gia8
001d_`3oool0903oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00H0oooo00<0omnL
04P0B02Lgol00P3oool00`3o_g@004RL0=ooo`0T0?ooo`030?oOW0180000M;oo0080oooo00<0gia8
001d_`3oool01@3oool00`3ooml0gmoo0?ooo`020?ooo`030?oo_`1d07@0_ooo02D0oooo00<0omnL
04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`070?ooo`030?oOW0180000B9cO02P0oooo00<0omnL
04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`070?ooo`030=nLW02oool0oooo0100oooo001f0?oo
o`030;md0000M;l0oooo02h0oooo00H0gia80000M02oool0oooO09a80018W=l70?ooo`070?oo_`1d
000004RL0=ooo`3ooml0W4P007Boo`0V0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO1`3oool0
0`3ooml0W4P004RLg`020?ooo`030;md0000M;l0oooo02D0oooo00H0gia80000M02oool0oooO09a8
0018W=l70?ooo`030;mdM02oool0oooo0080oooo00<0okmd001d_`3oool09@3oool01P3OW4P0001d
0;ooo`3ooml0W4P004RLg`T0oooo00@0oooO09a8000007@0_ooo9`3oool01P3OW4P0001d0;ooo`3o
oml0W4P004RLg`P0oooo00<0omnL07BLg`3oool0403oool007@0oooo00D0oono07@000000000001d
0;ooo`0_0?ooo`040=nLB00000000000001d_`X0oooo00@0_g@0000000000000B9cO:03oool0103O
W4P0000000000000M;l90?ooo`050?oog`2LB000000000000000M;l0:03oool0103OW4P000000000
0000M;l80?ooo`030?oo_`1d0000000000<0000000<0001809cOo`3oool09@3oool0103OW4P00000
00000000M;l<0?ooo`040?oo_`1d0000000004RLgbH0oooo00@0gia800000000000007Bo2P3oool0
1@2oM0000000000000000000B9cO00d0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo000e0?ooo`040;md00000000000007Boo`X0ooooo`00001M00000140oooo
000d0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO2@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0000000A0?ooo`00
<`3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00P0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0?0?ooo`00<`3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2L
B00004RL0=ooo`L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooobd0oooo
00<000000?ooo`3oool03`3oool003<0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cO
o`070?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000003o
ool0oooo00l0oooo000d0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01`3oool3
000002T0oooo00<000000?ooo`3oool0o`3oool[0?ooo`<000004@3oool003@0oooo00<0gia80000
B02Lgol00P3oool00`3ooml0W4P0001d_`070?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0o`3oool]0?ooo`030000003oool0oooo00l0oooo000d0?ooo`030?oOW0180000B9cO00<0
oooo00<0_g@00018W03Oool01P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0
oooo;@3oool00`000000oooo0?ooo`0?0?ooo`00=03oool0103ooml0W4P00018W03Oool20?ooo`03
0=nLB000B9`0gooo00H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooobd0
oooo00<000000?ooo`3oool03`3oool003D0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo
0?ooo`060?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000
003oool0oooo00l0oooo000f0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO1`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0?0?ooo`00
=`3oool0103OW4P0000000000000M;l80?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0o`3oool]0?ooo`030000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0o`3oool]0?ooo`030000003oool0oooo00l0oooo00130?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000003oool0oooo00l0oooo0013
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000003oool0
oooo00l0oooo00130?ooo`800000:P3oool00`000000oooo0?ooo`3o0?ooob`0oooo0P00000A0?oo
o`00@`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000
oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo
;@3oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0?0?oo
o`00@`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000
oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo
;@3oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0?0?ooo`00@`3oool20000
02X0oooo00<000000?ooo`3oool0o`3oool/0?ooo`8000004@3oool004<0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool03`3oool004<0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool0
3`3oool004<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<0
00000?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o
0?ooobd0oooo00<000000?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0?0?oo
o`00@`3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool03`3oool004<0
oooo00<000000?ooo`3oool04`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo0000003o0?ooobl0oooo00<000000?ooo`3oool03`3oool0
04<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0000000A0?ooo`050000003oool0oooo
0?ooo`000000o`3oool_0?ooo`030000003oool0oooo00l0oooo00130?ooo`800000403oool00`00
0000oooo0000000G0?ooo`030000003oool0oooo0?l0oooo;03oool200000140oooo00130?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?ooobd0
oooo00<000000?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0?0?ooo`00@`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0000001/0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`3o0?ooobH0oooo00<000000?ooo`3oool03`3oool004<0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0o`3ooolV0?ooo`030000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<000000?oo
o`3oool03`3oool004<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3o
oolL0?ooo`030000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0o`3oool]0?ooo`030000003oool0oooo00l0oooo00130?ooo`800000:P3oool00`00
0000oooo0?ooo`3o0?ooob`0oooo0P00000A0?ooo`00@`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?oooa40
oooo00<000000?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`030000
003oool0oooo00l0oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3o
ool]0?ooo`030000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?ooo`P0oooo00<000000?ooo`3oool03`3oool0
02L0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`030?oo_`1d0000
00000080000000<0B9cO0?ooo`3oool0203oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0o`3oool80?ooo`030000003oool0oooo00l0oooo000V0?oo
o`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`040?ooo`030?noM000
0000M;oo00/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<0
00000?ooo`3oool03`3oool002D0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`08
0?ooo`030?oog`2LB00007Bo00/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo0?h0oooo00<000000?ooo`3oool03`3oool002D0oooo00<0oooO09a8
0018W=l00P3oool0103ooml0W4P00018W03Oool80?ooo`030=nLB000B9`0gooo00X0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0oP3oool00`000000oooo0?ooo`0?0?ooo`009@3oool00`3ooml0W4P0001d_`030?oo
o`030=nLB00004P0W=oo00P0oooo00<0omnL04P0B02Lgol02P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`3f0?oo
o`030000003oool0oooo00l0oooo000V0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018
W=l0203oool00`3ookl0M00007Boo`0:0?ooo`<00000:@3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0kP3oool300000140oooo000V0?ooo`030=nL
B00004P0W=oo0080oooo00<0oooO09a80000M;l02@3oool00`2oM00007Bo0?ooo`090?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0i03oool00`000000oooo0?ooo`0?0?ooo`009P3o
ool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00P0oooo00<0gia80018W03Oool02@3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00l0oooo000V0?ooo`040?oog`2LB000
04RL0=ooo`80oooo00<0gia80018W03Oool0203oool00`3ogi`0B01809cOo`090?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0;h0oooo00<000000?ooo`3oool03`3oool002L0oooo00<0omnL04P0001d_ol00P3oool0
0`3OW4P007Bo0?ooo`080?ooo`030?oo_`1d0000M;oo00T0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0_P3oool0
0`000000oooo0?ooo`0?0?ooo`00:03oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`X0oooo00<0
_g@0001d_`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo00l0oooo000Y
0?ooo`040=nLB00000000000001d_`T0oooo00D0oono07@000000000001d0;ooo`080?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1b0?ooo`030000
003oool0oooo0;L0oooo00<000000?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool03`3oool004<0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0:l0oooo00<00000
0?ooo`3oool03`3oool004<0oooo0P00000Z0?ooo`030000003oool0oooo07X0oooo00@000000?oo
o`3oool00000[@3oool200000140oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0O@3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo00l0oooo00130?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000003oool0oooo00l0
oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0PP3oool00`000000oooo
0?ooo`2W0?ooo`030000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0PP3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo00l0oooo0013
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000003oool0
oooo00l0oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0R`3oool00`00
0000oooo0?ooo`2N0?ooo`030000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo00l0
oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000
003oool0oooo00l0oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0TP3o
ool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00l0oooo00130?ooo`800000:P3oool0
0`000000oooo0?ooo`2B0?ooo`030000003oool0oooo09H0oooo0P00000A0?ooo`00@`3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0T03oool00`00
0000oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo09T0
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0?0?ooo`00@`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0W`3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00l0oooo00130?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`2V0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool03`3oool004<0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo08<0
oooo00<000000?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`2`0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool03`3oool004<0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool03`3oool004<0oooo0P00000Z0?ooo`030000003oool0oooo0;L0oooo00<00000
0?ooo`3oool0L@3oool200000140oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0]`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo00l0oooo00130?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000003oool0oooo00l0
oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0a03oool00`000000oooo
0?ooo`1U0?ooo`030000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0a03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00l0oooo0013
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0d03oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00l0oooo00130?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3o0?ooobd0
oooo00<000000?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0?0?ooo`00@`3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`0?0?ooo`00@`3oool2000002X0oooo00<000000?ooo`3oool0h03oool0
0`000000oooo0?ooo`180?ooo`8000004@3oool004<0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool03`3oool004<0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool03`3oool004<0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool0
3`3oool002L0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`030=nL
B0000000000000<0000000<0B9cO0?ooo`3oool01`3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo0?D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0?0?ooo`009P3o
ool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0
07Bo0?ooo`020?ooo`030;mdM02oool0oooo00L0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`3e0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool03`3oool002D0oooo
00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?noM000M;l0oooo00/0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool0
3`3oool001P0oooo00<0gia80000M02oool02P3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2L
B00004RL0=ooo`P0oooo00<0okmd001d_`3oool02P3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo0?h0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0?0?ooo`004@3o
ool00`3ookl0M7Bo0?ooo`040?ooo`030?oo_`1dB9`0gooo00X0oooo00<0oooO09a80000M;l00`3o
ool00`3OW4P0001809cOo`090?ooo`030?noM018W=l0oooo00T0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?h0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`0?0?ooo`004@3oool00`3ogi`0B01d0;ooo`030?ooo`030?noM00007@0
_ooo00`0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?ooo`030=nLB018W=l0
oooo00P0oooo0`00000@0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3oool[
0?ooo`<000004@3oool00140oooo00L0omnL04P000000000001809cOo`3ogi`0B7Bo00h0oooo00<0
gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0;0?ooo`030;md001d_ol0oooo00L0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool03`3o
ool001<0oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`0;0?ooo`030?oOW0180000
B9cO00<0oooo00<0_g@00018W03Oool02P3oool00`3ogi`0B01d0;ooo`070?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool03`3oool00180oooo00T0oono07@0M02oool0oooo0?oog`2LB00000000000M02oool0
2`3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00X0oooo00<0oooO09a8001d
_ol01`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo00l0oooo000A0?ooo`030?oo_`1d07@0_ooo00@0oooo
00<0omnL04Qd_`3oool0303oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00X0oooo
00<0oono07@00018W=l01`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo
3`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00l0oooo000A0?ooo`030?noM000
0000M;oo00<0oooo00<0oono07A8W03Oool03P3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`L0
oooo00L0okmd0018W03Oool0oooo0=nLB00004P0W=oo00L0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0?
0?ooo`00:@3oool0103OW4P0000000000000M;l90?ooo`050?oOW018000000000000001d_ol0203o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo0?oo
o`0?0?ooo`006`3oool0103o_g@000000000M02ooolT0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0o`3ooolC0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03`3o
ool00100oooo00P0gia80000001d_ol0oooo0?oog`2LW;l0oooO09a800<0000000<007Bo0?ooo`3o
ool09@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo4`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00l0oooo000=0?ooo`040=nLB00000000000001d_`<0
oooo00@0oono07@0000004P0W=oo0P3oool00`2oW9`0gooo0?ooo`0V0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0o`3ooolF0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool03`3oool000`0oooo00@0oono07@00000B9`0gooo203oool01@3Ogml0_g@0000000000000
07Bo02H0oooo0P00000Z0?ooo`030000003oool0oooo0?l0oooo5P3oool00`000000oooo0?ooo`0C
0?ooo`8000004@3oool001L0oooo00<0oooO09a8001d_ol00P3oool00`3OW4P0001d0;ooo`0T0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool03`3oool001L0oooo00<0oooO09adW03Oool00P3oool00`3OW7@0
W=oo0?ooo`0T0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`3o0?oooaP0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0?0?ooo`00
@`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
o`3oool]0?ooo`030000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0o`3ooolK0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3o
ool004<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?oooa/0oooo00<00000
0?ooo`0000003`3oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo0?l0oooo7@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00l0oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3oool]0?ooo`03
0000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
o`3ooolP0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool004<0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo803o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00130?ooo`8000006P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo8P3oool00`000000oooo0?ooo`07
0?ooo`8000004@3oool004<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?oo
ob80oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
o`3ooolT0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03`3oool004<0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool03`3o
ool004<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<00000
0?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?oo
obd0oooo00<000000?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`00
@`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00l0oooo00130?ooo`800000:P3oool00`000000oooo0?oo
o`3o0?ooob`0oooo0P00000A0?ooo`00@`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0?l0oooo8P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00l0oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3oool]0?ooo`03
0000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
o`3oool]0?ooo`030000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0o`3oool]0?ooo`030000003oool0oooo00l0oooo00130?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?oo
oaX0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0?0?ooo`00
@`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
o`3oool]0?ooo`030000003oool0oooo00l0oooo00130?ooo`8000009@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0?l0oooo;03oool200000140oooo00130?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?oo
oa80oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0?0?ooo`00
@`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo
0?ooo`0?0?ooo`009`3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo
00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`080?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0o`3oool]0?ooo`030000003oool0oooo00l0oooo000V0?ooo`060=nLB000
M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`020?ooo`030?noM000000007Bo0080
oooo00<0_gA809cOo`3oool0203oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0
oooo2@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00l0oooo000U0?ooo`030?oo
g`2LB000B9cO0080oooo00<0okmd0000B02Lgol02`3oool00`3ogi`0B4RL0=ooo`080?ooo`030000
003oool0oooo02T0oooo0P00003o0?ooo`X0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0?0?ooo`009@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`X0oooo
00<0oono07@0001d_ol0203oool00`000000oooo0?ooo`0Y0?ooo`800000o`3oool^0?ooo`030000
003oool0oooo00l0oooo000U0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol02P3o
ool00`3ogi`0B00007Boo`080?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3o
ool]0?ooo`030000003oool0oooo00l0oooo000V0?ooo`030;md0000B9`0gooo0080oooo00<0omnL
04P00018W=l02@3oool0103ogi`0B0000000B02Lgol80?ooo`<00000:@3oool00`000000oooo0?oo
o`3o0?ooob/0oooo0`00000A0?ooo`009P3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB000
07Bo00L0oooo00D0omnL04P000000000000007Boo`090?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0o`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00l0oooo000V
0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool0203oool00`3ookl0M000001d_`09
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo00l0oooo000V0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia8
0018W03Oool02P3oool00`3OW4P007Bo0?ooo`070?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0o`3oool]0?ooo`030000003oool0oooo00l0oooo000W0?ooo`030?oOW0180000M;oo
0080oooo00<0gia8001d_`3oool02P3oool00`3ogi`0B01809cOo`070?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000003oool0oooo00l0oooo000X0?ooo`06
0=nLB00007@0_ooo0?oog`2LB000B9cO203oool01P2oM000M;oo0?ooo`3OW4P0001809cOo`L0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool0
3`3oool002T0oooo00@0gia800000000000007Bo2P3oool0102oM000000000000018W=l80?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3_0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0>l0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0?0?ooo`00@`3oool20000
02X0oooo00<000000?ooo`3oool0o`3oool/0?ooo`8000004@3oool004<0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`3]0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool03`3oool004<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3]0?ooo`030000
003oool0oooo03`0oooo00<000000?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool03`3oool004<0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0=T0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0o`3oool]0?ooo`030000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0o`3oool]0?ooo`030000003oool0oooo00l0oooo00130?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0g`3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo00l0oooo00130?ooo`800000:P3oool00`000000oooo0?ooo`3O0?ooo`030000003oool0
oooo04T0oooo0P00000A0?ooo`00@`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
0?l0oooo;@3oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0DP3oool00`000000oooo
0?ooo`0?0?ooo`00@`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0=L0oooo00<0
00000?ooo`3oool0DP3oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0?0?oo
o`00@`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0o`3ooolC0?ooo`030000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`3?0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool03`3oool004<0oooo0P00000Z
0?ooo`030000003oool0oooo0?l0oooo;03oool200000140oooo00130?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000003oool0oooo00l0oooo00130?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000003oool0oooo00l0
oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000
003oool0oooo00l0oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool03`3oool004<0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo09l0oooo00<00000
0?ooo`3oool0J03oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo0<40oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0?0?oo
o`00@`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000
oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0oooo00l0oooo00130?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo0780oooo00<000000?ooo`3oool03`3oool004<0oooo0P00000Z0?ooo`030000003oool0
oooo0;L0oooo00<000000?ooo`3oool0L@3oool200000140oooo00130?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000003oool0oooo00l0oooo00130?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000003oool0oooo00l0
oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000
003oool0oooo00l0oooo000W0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol0
1@3oool00`3ooml0W4P004RLg`0:0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
o`3oool]0?ooo`030000003oool0oooo00l0oooo000V0?ooo`060=nLB000M;l0oooo0?oOW0180000
B9cO0P3oool00`3ogi`0B00007Boo`060?ooo`030=nLB000B9`0gooo00T0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool03`3oool002D0oooo
00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`0:0?ooo`030?oOW01804P0W=oo00T0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0?T0oooo
00<000000?ooo`3oool03`3oool002D0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018
W03Oool50?ooo`030?noM0000000000000@0000000<004RL0=ooo`3oool01P3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`220?ooo`030000003oool0oooo00l0oooo000U0?ooo`030?oog`2LB00007Bo00<0oooo00<0
gia80000B02Lgol01@3oool00`3ooml0W4Q809cOo`020?ooo`030;md0000M;l0oooo00P0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0880oooo00<0
00000?ooo`3oool03`3oool002H0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`06
0?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@004RL0=ooo`080?ooo`<00000:@3oool00`000000oooo
0?ooo`3o0?ooob/0oooo0`00000A0?ooo`009P3oool00`3OW4P0001809cOo`020?ooo`030?oog`2L
B00007Bo00L0oooo00H0omnL04Q8W03Oool0omnL04P0B02Lgol80?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000003oool0oooo00l0oooo000V0?ooo`030?oO
W0180000B9cO00<0oooo00<0_g@00018W03Oool01`3oool01@3o_g@007Bo0?oog`2LB000B9cO00P0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3o
ool03`3oool002H0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`080?ooo`04
0=nLB018W=l0_g@0001d_`P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0?0?oo
o`009`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00T0oooo00@0gia807AdM000
07@0_ooo1`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0G@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00l0oooo000X0?ooo`06
0=nLB00007@0_ooo0?oog`2LB000B9cO2`3oool00`2oM000001809cOo`070?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000003oool0oooo00l0oooo000Y0?oo
o`040=nLB00000000000001d_``0oooo00<0oooO09a80018W=l01`3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`2I
0?ooo`030000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo09T0oooo00<000000?oo
o`3oool03`3oool004<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0?0?ooo`00
@`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0
3`3oool004<0oooo0P00000Z0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0Z`3o
ool200000140oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0G03oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0[03oool0
0`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
0?l0oooo;@3oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool000000140oooo00130?ooool00000G@00
000A0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-1.19228, -0.11633, \
0.00258793, 0.00308797}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
-1.32336 2.23243 0.354358 0.957789 [
[.0161 -0.0125 -9.625 -15.6875 ]
[.0161 -0.0125 9.625 0 ]
[.23934 -0.0125 -9.625 -15.6875 ]
[.23934 -0.0125 9.625 0 ]
[.46259 -0.0125 -9.5 -15.6875 ]
[.46259 -0.0125 9.5 0 ]
[.68583 -0.0125 -9.5 -15.6875 ]
[.68583 -0.0125 9.5 0 ]
[.90907 -0.0125 -5 -15.6875 ]
[.90907 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -7.125 -31.375 ]
[.5 -0.0125 7.125 -15.6875 ]
[-0.0125 .06702 -27.6875 -7.84375 ]
[-0.0125 .06702 0 7.84375 ]
[-0.0125 .1628 -27.6875 -7.84375 ]
[-0.0125 .1628 0 7.84375 ]
[-0.0125 .25858 -27.6875 -7.84375 ]
[-0.0125 .25858 0 7.84375 ]
[-0.0125 .35436 -10 -7.84375 ]
[-0.0125 .35436 0 7.84375 ]
[-0.0125 .45014 -19 -7.84375 ]
[-0.0125 .45014 0 7.84375 ]
[-0.0125 .54592 -19 -7.84375 ]
[-0.0125 .54592 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -43.375 -7.125 ]
[-0.01875 .30902 -27.6875 7.125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0161 0 m
.0161 .00625 L
s
gsave
.0161 -0.0125 -70.625 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.23934 0 m
.23934 .00625 L
s
gsave
.23934 -0.0125 -70.625 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
1.000 setlinewidth
grestore
.46259 0 m
.46259 .00625 L
s
gsave
.46259 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.68583 0 m
.68583 .00625 L
s
gsave
.68583 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
1.000 setlinewidth
grestore
.90907 0 m
.90907 .00625 L
s
gsave
.90907 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.06075 0 m
.06075 .00375 L
s
.1054 0 m
.1054 .00375 L
s
.15005 0 m
.15005 .00375 L
s
.1947 0 m
.1947 .00375 L
s
.28399 0 m
.28399 .00375 L
s
.32864 0 m
.32864 .00375 L
s
.37329 0 m
.37329 .00375 L
s
.41794 0 m
.41794 .00375 L
s
.50724 0 m
.50724 .00375 L
s
.55188 0 m
.55188 .00375 L
s
.59653 0 m
.59653 .00375 L
s
.64118 0 m
.64118 .00375 L
s
.73048 0 m
.73048 .00375 L
s
.77513 0 m
.77513 .00375 L
s
.81978 0 m
.81978 .00375 L
s
.86442 0 m
.86442 .00375 L
s
.95372 0 m
.95372 .00375 L
s
.99837 0 m
.99837 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -68.125 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 17.688 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
73.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .06702 m
.00625 .06702 L
s
gsave
-0.0125 .06702 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
0 .1628 m
.00625 .1628 L
s
gsave
-0.0125 .1628 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .25858 m
.00625 .25858 L
s
gsave
-0.0125 .25858 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .35436 m
.00625 .35436 L
s
gsave
-0.0125 .35436 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .45014 m
.00625 .45014 L
s
gsave
-0.0125 .45014 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .54592 m
.00625 .54592 L
s
gsave
-0.0125 .54592 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08618 m
.00375 .08618 L
s
0 .10533 m
.00375 .10533 L
s
0 .12449 m
.00375 .12449 L
s
0 .14364 m
.00375 .14364 L
s
0 .18196 m
.00375 .18196 L
s
0 .20111 m
.00375 .20111 L
s
0 .22027 m
.00375 .22027 L
s
0 .23942 m
.00375 .23942 L
s
0 .27774 m
.00375 .27774 L
s
0 .29689 m
.00375 .29689 L
s
0 .31605 m
.00375 .31605 L
s
0 .3352 m
.00375 .3352 L
s
0 .37351 m
.00375 .37351 L
s
0 .39267 m
.00375 .39267 L
s
0 .41183 m
.00375 .41183 L
s
0 .43098 m
.00375 .43098 L
s
0 .46929 m
.00375 .46929 L
s
0 .48845 m
.00375 .48845 L
s
0 .5076 m
.00375 .5076 L
s
0 .52676 m
.00375 .52676 L
s
0 .04787 m
.00375 .04787 L
s
0 .02871 m
.00375 .02871 L
s
0 .00955 m
.00375 .00955 L
s
0 .56507 m
.00375 .56507 L
s
0 .58423 m
.00375 .58423 L
s
0 .60338 m
.00375 .60338 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -103.656 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.125 11.8438 translate
90 rotate
-68.125 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 18.625 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
68.563 11.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\242) show
73.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.0161 .61178 m
.0161 .61803 L
s
.23934 .61178 m
.23934 .61803 L
s
.46259 .61178 m
.46259 .61803 L
s
.68583 .61178 m
.68583 .61803 L
s
.90907 .61178 m
.90907 .61803 L
s
.125 Mabswid
.06075 .61428 m
.06075 .61803 L
s
.1054 .61428 m
.1054 .61803 L
s
.15005 .61428 m
.15005 .61803 L
s
.1947 .61428 m
.1947 .61803 L
s
.28399 .61428 m
.28399 .61803 L
s
.32864 .61428 m
.32864 .61803 L
s
.37329 .61428 m
.37329 .61803 L
s
.41794 .61428 m
.41794 .61803 L
s
.50724 .61428 m
.50724 .61803 L
s
.55188 .61428 m
.55188 .61803 L
s
.59653 .61428 m
.59653 .61803 L
s
.64118 .61428 m
.64118 .61803 L
s
.73048 .61428 m
.73048 .61803 L
s
.77513 .61428 m
.77513 .61803 L
s
.81978 .61428 m
.81978 .61803 L
s
.86442 .61428 m
.86442 .61803 L
s
.95372 .61428 m
.95372 .61803 L
s
.99837 .61428 m
.99837 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06702 m
1 .06702 L
s
.99375 .1628 m
1 .1628 L
s
.99375 .25858 m
1 .25858 L
s
.99375 .35436 m
1 .35436 L
s
.99375 .45014 m
1 .45014 L
s
.99375 .54592 m
1 .54592 L
s
.125 Mabswid
.99625 .08618 m
1 .08618 L
s
.99625 .10533 m
1 .10533 L
s
.99625 .12449 m
1 .12449 L
s
.99625 .14364 m
1 .14364 L
s
.99625 .18196 m
1 .18196 L
s
.99625 .20111 m
1 .20111 L
s
.99625 .22027 m
1 .22027 L
s
.99625 .23942 m
1 .23942 L
s
.99625 .27774 m
1 .27774 L
s
.99625 .29689 m
1 .29689 L
s
.99625 .31605 m
1 .31605 L
s
.99625 .3352 m
1 .3352 L
s
.99625 .37351 m
1 .37351 L
s
.99625 .39267 m
1 .39267 L
s
.99625 .41183 m
1 .41183 L
s
.99625 .43098 m
1 .43098 L
s
.99625 .46929 m
1 .46929 L
s
.99625 .48845 m
1 .48845 L
s
.99625 .5076 m
1 .5076 L
s
.99625 .52676 m
1 .52676 L
s
.99625 .04787 m
1 .04787 L
s
.99625 .02871 m
1 .02871 L
s
.99625 .00955 m
1 .00955 L
s
.99625 .56507 m
1 .56507 L
s
.99625 .58423 m
1 .58423 L
s
.99625 .60338 m
1 .60338 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .35436 m
1 .35436 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.90402 .05568 Mdot
.02489 .57741 Mdot
.76948 .04143 Mdot
.4445 .60103 Mdot
.56696 .24669 Mdot
.85362 .48884 Mdot
.33881 .40092 Mdot
.96599 .17853 Mdot
.03788 .55016 Mdot
.81315 .0212 Mdot
.26155 .60273 Mdot
.6494 .18694 Mdot
.75953 .54224 Mdot
.42491 .33924 Mdot
.97224 .30927 Mdot
.09058 .51256 Mdot
.86623 .02125 Mdot
.05348 .58815 Mdot
.74475 .06979 Mdot
.54583 .59332 Mdot
.52452 .26948 Mdot
.88967 .46107 Mdot
.29207 .42561 Mdot
.95158 .13503 Mdot
.03036 .56005 Mdot
.79797 .02685 Mdot
.33018 .60332 Mdot
.61832 .2134 Mdot
.8013 .52088 Mdot
.39144 .36672 Mdot
.97619 .24653 Mdot
.05533 .53249 Mdot
.83939 .01472 Mdot
.1371 .5972 Mdot
.70549 .12507 Mdot
.66042 .57523 Mdot
.47785 .29522 Mdot
.92984 .41644 Mdot
.21844 .45932 Mdot
.92418 .08278 Mdot
.02381 .57128 Mdot
.78017 .03443 Mdot
.4016 .60251 Mdot
.5859 .23555 Mdot
.83615 .50023 Mdot
.35778 .3897 Mdot
.97067 .19979 Mdot
.04234 .54499 Mdot
.82095 .01869 Mdot
.22438 .60173 Mdot
.66621 .17049 Mdot
.73369 .55312 Mdot
.44161 .3245 Mdot
.96341 .34555 Mdot
.1241 .4983 Mdot
.8834 .0341 Mdot
.03323 .58312 Mdot
.75796 .05241 Mdot
.49198 .59825 Mdot
.5467 .25772 Mdot
.871 .47645 Mdot
.318 .41226 Mdot
.9601 .15793 Mdot
.03374 .5549 Mdot
.80598 .02353 Mdot
.29386 .60325 Mdot
.63469 .19997 Mdot
.78003 .53242 Mdot
.40967 .35212 Mdot
.97596 .27892 Mdot
.07003 .52273 Mdot
.85302 .01566 Mdot
.08504 .59254 Mdot
.72912 .09251 Mdot
.59945 .58647 Mdot
.50286 .28064 Mdot
.90735 .44431 Mdot
.26386 .43896 Mdot
.94182 .11319 Mdot
.02631 .56469 Mdot
.79088 .0291 Mdot
.35777 .60331 Mdot
.6056 .22244 Mdot
.81547 .51298 Mdot
.37867 .37576 Mdot
.97492 .22752 Mdot
.04866 .53771 Mdot
.83189 .01537 Mdot
.16955 .59937 Mdot
.69073 .14316 Mdot
.69034 .56773 Mdot
.46454 .30472 Mdot
.94299 .39473 Mdot
.1857 .47318 Mdot
.91066 .06392 Mdot
.02411 .5755 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00n`3oool01`2oM4P0W=oo0?oo
o`3ogi`0B0000000001d_ol0[P3oool00?/0oooo00P0okmd04RLg`3oool0gia8001d_`3oool0_ibL
0=ooojd0oooo003b0?ooo`0>0=nLB000000007Bo0?ooo`3ooml0W4P00000001d_ol0oooo0?oo_`1d
B4P0B7BL09a8001d_on`0?ooo`00m03oool0303o_g@0M;oo0?oOW01804P0W=oo0;mdM02oool0oooO
09a8M02o_g@0001d0;oook00oooo003e0?ooo`040;mdM02LW4P004RL0=ooo`<0oooo00@0gia807Bo
o`3ookl0M7Bo/03oool00?D0oooo00<0oono07@00000M;l0103oool0103ogi`0B7Bo0?oog`2LB002
0000000307Boo`3oool0oooo0:/0oooo003e0?ooo`030?oo_`1d0000M;oo00@0oooo00<0oooO09a8
M02oool0/@3oool00?D0oooo00@0okmd00000000B9`0gooo103oool00`3OW4P0M;oo0?ooo`2`0?oo
o`00m@3oool01@2oM00004RL0=oOW018B9`0gooo0080oooo00<0gia800000000M;l0/@3oool00?<0
oooo00T0okmd000000000000M;oo0?ooo`3ogi`0B0000018W03Oool0]03oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
04T0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`030?ooo`050?oog`2LB000
000000000000M;l0?03oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo00<0oooo
00<0oono07A8W03Oool0?@3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo00<0
oooo00H0oono07@00000000000000018W03Ooolk0?ooo`040;md00000000000007Boo`<0oooo00<0
omnL04P0001d_ol00P3oool0103OW4P000000000M02ooom20?ooo`030?oo_`1d0000000000800000
00<0B9cO0?ooo`3oool0903oool004P0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`03
0?oOW0180000M;oo00<0oooo00L0gia8001d_`3oool0oono07@00000B9`0gooo03T0oooo00H0gia8
001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00@0oooo00<0gia804RLg`3oool0
>`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00P3oool00`3o
okl0M00004RLg`020?ooo`030=nLB00007@0_ooo03T0oooo00H0gia8001d_`3oool0omnL04P00018
W=l20?ooo`030?oOW0180000M;oo00@0oooo00<0oono07@00000M;l0@`3oool00`3o_g@0000007Bo
o`0W0?ooo`00A`3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00H0oooo00<0oooO
09a8001d_ol00P3oool00`3ogi`0B00004RLg`0h0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd
0000B02Lgol0203oool00`3ookl0M01d0;ooo`0j0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd
0000B02Lgol01P3oool00`3o_g@004RL0=ooo`030?ooo`030;md0018W=l0oooo03L0oooo00<0oooO
09a80018W=l00P3oool00`3o_g@0001809cOo`0:0?ooo`030;md000007@0_ooo0440oooo00<0oooO
09a80000M;l09`3oool004L0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool5
0?ooo`030?oo_`1d0000M;oo00<0oooo00<0_g@00000M02oool0=`3oool00`3ooml0W4P004RLg`02
0?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<0okmd001d_`3oool0>@3oool00`3ooml0W4P004RL
g`020?ooo`040?oog`2LB00004RL0=ooo`D0oooo00<0okmd0018W03Oool00`3oool00`2oM00007Bo
0?ooo`0g0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo2@3oool0103ooml0
W4P00000M02ooom10?ooo`030=nLB000B9`0gooo02H0oooo00170?ooo`030?oog`2LB00007Bo00<0
oooo00<0gia80000B02Lgol01@3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo03L0
oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`080?ooo`030?oog`2LB4P0W=oo03T0
oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`050?ooo`030?oog`2LB000M;oo0080
oooo00<0oono07@00018W=l0>03oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00L0
oooo00<0omnL04P0000000000P0000000`00M;l0oooo0?ooo`0o0?ooo`030?oOW01804P0W=oo02H0
oooo00180?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01P3oool00`2oM000001d
0;ooo`020?ooo`030=nLB00004P0W=oo03P0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B000
04RLg`090?ooo`030?oOW018M;l0oooo03T0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B000
04RLg`070?ooo`060;md000004P0W=oO09a8000007@0_ooo>@3oool00`2oM00004RL0=ooo`020?oo
o`030?oOW0180000B9cO00H0oooo00P0oono07@00000B9`0gooo0?ooo`2oM000001809cOod00oooo
00<0oono07@0001d_ol09P3oool004P0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d
_`060?ooo`080?noM0000000B9cO0?ooo`3ooml0W4P00018W03Ooolh0?ooo`030=nLB00004P0W=oo
0080oooo00<0oooO09a80000M;l02P3oool00`2oM000M;oo0?ooo`0h0?ooo`030=nLB00004P0W=oo
0080oooo00<0oooO09a80000M;l0203oool01@3ooml0W4P000000000B9`0gooo03T0oooo00<0gia8
0000B02Lgol00P3oool00`3ooml0W4P0001d_`060?ooo`030?oOW0180000M;oo0080oooo00<0omnL
04P00018W=l0@@3oool00`2oM00007Bo0?ooo`0U0?ooo`00B03oool00`3ogi`0B00004RLg`030?oo
o`030;md0000B9`0gooo00D0oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`0h0?oo
o`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool02@3oool00`3ogi`0B4RL0=ooo`0h0?oo
o`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01`3oool01P2oM000001809cOo`3ogi`0
B4RL0=ooocP0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`050?ooo`030?oOW018
0000M;oo0080oooo00<0oooO09a80000M;l0@@3oool00`3OW4P004RL0=ooo`0U0?ooo`00B03oool0
103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00H0oooo00<0oono07@00000M;l0?03o
ool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00X0oooo00<0gia804RLg`3oool0
=`3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00H0oooo00<0omnL04P0001d
_ol00P3oool00`3o_g@0B9cO0?ooo`0g0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018
W03Oool01@3oool00`3ookl0M000001d_`030?ooo`030=nLB000B9`0gooo0400oooo00<0omnL04P0
B02Lgol09@3oool004T0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`070?ooo`03
0?oOW0180000B9cO03`0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`050?ooo`03
0?oog`3Ogol0oooo0080oooo00<0oono07@0M02oool0>03oool00`3ogi`0B00007Boo`020?ooo`03
0=nLB000M;l0oooo00H0oooo00<0omnL04P0B02Lgol00P3oool00`3o_g@004RL0=ooo`0h0?ooo`03
0?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01P3oool00`2oM000001d0;ooo`020?ooo`03
0=nLB000M;l0oooo0400oooo00<0oono07@0001d_ol09@3oool004X0oooo00H0gia80000M02oool0
oooO09a80018W=l90?ooo`040?oog`2LB000001d0;oooc/0oooo00H0gia80000M02oool0oooO09a8
0018W=l70?ooo`030;mdM02oool0oooo0080oooo00<0okmd001d_`3oool0>03oool01P3OW4P0001d
0;ooo`3ooml0W4P004RLg`L0oooo00<0oooO09a80018W=l00P3oool00`2oM00007Bo0?ooo`0i0?oo
o`060=nLB00007@0_ooo0?oog`2LB000B9cO1`3oool01`3ookl0M0000018W03Oool0oooO09a8001d
_ol0@P3oool00`2oM00007Bo0?ooo`0T0?ooo`00B`3oool0103OW4P0000000000000M;l<0?ooo`04
0?oo_`1d0000000004RLgcX0oooo00@0gia800000000000007Bo203oool00`3ookl0M00000000003
000000030000B02Lgol0oooo03P0oooo00@0gia800000000000007Bo2@3oool01@3ooml0W4P00000
0000000007Bo03`0oooo00@0gia800000000000007Bo2P3oool0102oM000000000000018W=m10?oo
o`050?oo_`1d000000000000M02oool0903oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool004d0ooooo`00001M000000L0oooo001=0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`00C@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`050?ooo`00C@3oool200000?l0ooooF@3oool2000000L0oooo001=0?ooo`030000003o
ool0oooo0?l0ooooF@3oool00`000000oooo0?ooo`050?ooo`00C@3oool00`000000oooo0?ooo`3o
0?oooah0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo00D0oooo001=0?ooo`030000003oool0oooo0?l0oooo6P3oool01@000000oooo0?ooo`3o
ool000000080oooo00D000000?ooo`3oool0oooo0000000c0?ooo`030000003oool0oooo00D0oooo
001=0?ooo`030000003oool0oooo0?l0oooo5`3oool010000000oooo0?ooo`00000?0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool01@3oool004d0oooo00<000000?ooo`3oool0o`3o
oolE0?ooo`030000003oool000000180oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`050?ooo`00C@3oool00`000000oooo0?ooo`3o0?oooa80oooo00@000000?ooo`3oool00000@`3o
ool00`000000oooo0?ooo`050?ooo`00C@3oool200000?l0oooo4@3oool00`000000oooo00000015
0?ooo`8000001`3oool004d0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool01@3oool004d0oooo00<000000?ooo`3oool0o`3oool<0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`050?ooo`00
C@3oool00`000000oooo0?ooo`3o0?ooo``0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo00D0oooo001=0?ooo`030000003oool0oooo0?l0oooo203o
ool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo001=0?ooo`030000003oool0
oooo0?l0oooo203oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo001=0?oo
o`030000003oool0oooo0?l0ooooF@3oool00`000000oooo0?ooo`050?ooo`00C@3oool200000?l0
ooooF@3oool2000000L0oooo000a0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d
_ol00P3oool00`3ookl0M000000000020000000307Boo`3oool0oooo00P0oooo00<000000?ooo`3o
ool0o`3oool40?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool01@3oool00300oooo
00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo0080oooo00<0okmd0000
0000M;l00P3oool00`2oM4P0W=oo0?ooo`080?ooo`030000003oool0oooo0?l0oooo103oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01@3oool002l0
oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`0;0?ooo`030?oOW018B9`0gooo00P0
oooo00<000000?ooo`3oool0o`3ooolg0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool01@3oool002l0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool:0?ooo`03
0?oo_`1d0000M;oo00P0oooo00<000000?ooo`3oool0o`3ooomI0?ooo`030000003oool0oooo00D0
oooo000R0?ooo`030?oog`2LB000000000L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?oo
o`030=nLB00004P0W=oo00X0oooo00<0omnL04P0001d_ol0203oool00`000000oooo0?ooo`3o0?oo
ocT0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`050?ooo`00<03oool00`2oM000
04RL0=ooo`020?ooo`030?oOW0180000B9cO00T0oooo00@0omnL04P0000004P0W=oo203oool30000
0?l0oooo>@3oool00`000000oooo0?ooo`0K0?ooo`<000001`3oool00300oooo00<0gia80000B02L
gol00P3oool00`3ooml0W4P0001d_`070?ooo`050?oOW018000000000000001d_ol02@3oool00`00
0000oooo0?ooo`3o0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool01@3oool00300
oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`080?ooo`030?oo_`1d000007Bo00T0
oooo00<000000?ooo`3oool0o`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00D0
oooo000`0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool02P3oool00`3OW4P0
07Bo0?ooo`070?ooo`030000003oool0oooo0?l0ooooF@3oool00`000000oooo0?ooo`050?ooo`00
<@3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00X0oooo00<0omnL04P0B02Lgol0
1`3oool00`000000oooo0?ooo`3o0?oooeT0oooo00<000000?ooo`3oool01@3oool00380oooo00H0
gia80000M02oool0oooO09a80018W=l80?ooo`060;md001d_ol0oooo0=nLB00004P0W=oo1`3oool0
0`000000oooo0?ooo`3o0?oooeT0oooo00<000000?ooo`3oool01@3oool003<0oooo00@0gia80000
0000000007Bo2P3oool0102oM000000000000018W=l80?ooo`030000003oool0oooo0?l0oooo?P3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo001=0?ooo`800000o`3ooolo
0?ooo`030000003oool0oooo01L0oooo0P0000070?ooo`00C@3oool00`000000oooo0?ooo`3o0?oo
oeT0oooo00<000000?ooo`3oool01@3oool004d0oooo00<000000?ooo`3oool0n@3oool00`000000
oooo0?ooo`1L0?ooo`030000003oool0oooo00D0oooo001=0?ooo`030000003oool0oooo0?T0oooo
00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`050?ooo`00C@3oool00`000000oooo0?oo
o`3o0?oooeT0oooo00<000000?ooo`3oool01@3oool004d0oooo00<000000?ooo`3oool0o`3ooomI
0?ooo`030000003oool0oooo00D0oooo001=0?ooo`030000003oool0oooo0?l0ooooF@3oool00`00
0000oooo0?ooo`050?ooo`00C@3oool200000?l0ooooF@3oool2000000L0oooo001=0?ooo`030000
003oool0oooo0?l0ooooF@3oool00`000000oooo0?ooo`050?ooo`00C@3oool00`000000oooo0?oo
o`3o0?oood@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`00C@3oool0
0`000000oooo0?ooo`3o0?oood@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`05
0?ooo`00C@3oool00`000000oooo0?ooo`3o0?oooeT0oooo00<000000?ooo`3oool01@3oool004d0
oooo00<000000?ooo`3oool0o`3ooomI0?ooo`030000003oool0oooo00D0oooo001=0?ooo`800000
lP3oool00`000000oooo0?ooo`1S0?ooo`8000001`3oool004d0oooo00<000000?ooo`3oool0l@3o
ool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo001=0?ooo`030000003oool0
oooo0?l0ooooF@3oool00`000000oooo0?ooo`050?ooo`00C@3oool00`000000oooo0?ooo`3o0?oo
oeT0oooo00<000000?ooo`3oool01@3oool004d0oooo00<000000?ooo`3oool0o`3ooom80?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool004d0oooo00<000000?ooo`3oool0
o`3ooom80?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool004d0oooo00<0
00000?ooo`3oool0o`3ooomI0?ooo`030000003oool0oooo00D0oooo001=0?ooo`800000k@3oool0
0`000000oooo0?ooo`1X0?ooo`8000001`3oool004d0oooo00<000000?ooo`3oool0k03oool00`00
0000oooo0?ooo`1Y0?ooo`030000003oool0oooo00D0oooo000a0?ooo`040;md00000000000007Bo
o`<0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P00000000000030000000304RLg`3oool0oooo
00L0oooo00<000000?ooo`3oool0o`3ooomI0?ooo`030000003oool0oooo00D0oooo000`0?ooo`06
0=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`030?ooo`030?noM000M;l0
oooo0080oooo00<0_gAd0;ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oooeT0oooo00<00000
0?ooo`3oool01@3oool002l0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?oo
o`030?noM000M;l0oooo00/0oooo00<000000?ooo`3oool0o`3ooomI0?ooo`030000003oool0oooo
00D0oooo000_0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo203oool00`3o
_g@007Bo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooBP3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00D0oooo000R0?ooo`030?oog`2LB000000000L0000000H0B9cO0?ooo`3o
ool0oooO09a80000M;l30?ooo`030=nLB00004P0W=oo00T0oooo00<0okmd04RLg`3oool02@3oool0
0`000000oooo0?ooo`3o0?ooodX0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`05
0?ooo`00<03oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00X0oooo00<0gia804RL
g`3oool0203oool300000?l0ooooE`3oool3000000L0oooo000`0?ooo`030=nLB00004P0W=oo0080
oooo00<0oooO09a80000M;l02`3oool00`2oM000M;oo0?ooo`070?ooo`030000003oool0oooo0?l0
ooooF@3oool00`000000oooo0?ooo`050?ooo`00<03oool00`3ogi`0B00004RLg`030?ooo`030;md
0000B9`0gooo00X0oooo00<0omnL04P0M02oool01`3oool00`000000oooo0?ooo`3S0?ooo`030000
003oool0oooo0780oooo00<000000?ooo`3oool01@3oool00300oooo00@0oooO09a80000B9`0gooo
0P3oool00`3OW4P004RL0=ooo`0:0?ooo`030?oog`2LB000M;oo00L0oooo00<000000?ooo`3oool0
h`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo00D0oooo000a0?ooo`030?oOW018
0000M;oo0080oooo00<0gia8001d_`3oool02P3oool00`3ookl0M00004RLg`070?ooo`030000003o
ool0oooo0?l0ooooF@3oool00`000000oooo0?ooo`050?ooo`00<P3oool01P3OW4P0001d0;ooo`3o
oml0W4P004RLg`L0oooo00L0okmd0018W03Oool0oooo0=nLB00004P0W=oo00L0oooo00<000000?oo
o`3oool0o`3ooom=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool003<0
oooo00@0gia800000000000007Bo2@3oool01@3ogi`0B000000000000000M;oo00P0oooo0P00003o
0?ooodh0oooo00<000000?ooo`3oool0203oool2000000L0oooo001=0?ooo`030000003oool0oooo
0?l0ooooF@3oool00`000000oooo0?ooo`050?ooo`00C@3oool00`000000oooo0?ooo`3N0?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool01@3oool004d0oooo00<000000?ooo`3oool0
gP3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo00D0oooo001=0?ooo`030000003o
ool0oooo0?l0ooooF@3oool00`000000oooo0?ooo`050?ooo`00C@3oool00`000000oooo0?ooo`3o
0?oooeT0oooo00<000000?ooo`3oool01@3oool004d0oooo00<000000?ooo`3oool0f@3oool00`00
0000oooo0?ooo`1a0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool004d0
oooo0P00003J0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool01`3oool2000000L0
oooo001=0?ooo`030000003oool0oooo0?l0ooooF@3oool00`000000oooo0?ooo`050?ooo`00C@3o
ool00`000000oooo0?ooo`3o0?oooeT0oooo00<000000?ooo`3oool01@3oool004d0oooo00<00000
0?ooo`3oool0o`3ooomI0?ooo`030000003oool0oooo00D0oooo001=0?ooo`030000003oool0oooo
0=<0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`050?ooo`00C@3oool00`000000
oooo0?ooo`3C0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool01@3oool004d0oooo
0P00003o0?oooeT0oooo0P0000070?ooo`00C@3oool00`000000oooo0?ooo`3>0?ooo`030000003o
ool0oooo08L0oooo00<000000?ooo`3oool01@3oool004d0oooo00<000000?ooo`3oool0cP3oool0
0`000000oooo0?ooo`270?ooo`030000003oool0oooo00D0oooo001=0?ooo`030000003oool0oooo
0?l0ooooD03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo001=0?ooo`03
0000003oool0oooo0?l0ooooD03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo001=0?ooo`030000003oool0oooo0?l0ooooF@3oool00`000000oooo0?ooo`050?ooo`00C@3o
ool00`000000oooo0?ooo`380?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool01@3o
ool004d0oooo0P0000390?ooo`030000003oool0oooo08`0oooo0P0000070?ooo`00C@3oool00`00
0000oooo0?ooo`3o0?oooeT0oooo00<000000?ooo`3oool01@3oool00340oooo00@0_g@000000000
0000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`030?oo_`1d000000000080000000<0B9cO0?oo
o`3oool0203oool00`000000oooo0?ooo`3o0?oooe00oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`00<03oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL
04P0001d_ol0103oool00`3o_g@0000007Boo`0;0?ooo`030000003oool0oooo0<40oooo00<00000
0?ooo`3oool0R`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo000_0?oo
o`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0203oool00`3ooml0W4P0001d_`0;0?oo
o`030000003oool0oooo0<40oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`050?oo
o`00;`3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<0gia80018
W03Oool02P3oool00`000000oooo0?ooo`3o0?oooeT0oooo00<000000?ooo`3oool01@3oool00280
oooo00<0oooO09a8000000001`0000001P18W=l0oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0gia8
0000B02Lgol0203oool00`3ogi`0B01809cOo`0:0?ooo`030000003oool0oooo0;X0oooo00<00000
0?ooo`3oool0V`3oool00`000000oooo0?ooo`050?ooo`00<03oool00`2oM00004RL0=ooo`020?oo
o`030?oOW0180000B9cO00P0oooo00<0oono07@0001d_ol02P3oool300000;X0oooo00<000000?oo
o`3oool0V@3oool3000000L0oooo000`0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000
M;l02@3oool00`2oM00007Bo0?ooo`090?ooo`030000003oool0oooo0?l0ooooF@3oool00`000000
oooo0?ooo`050?ooo`00<03oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00P0oooo
00<0gia80018W03Oool02@3oool00`000000oooo0?ooo`3o0?oooeT0oooo00<000000?ooo`3oool0
1@3oool00300oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`080?ooo`030?oO
W01804P0W=oo00T0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`2S0?ooo`030000
003oool0oooo00D0oooo000a0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0203o
ool00`3ookl0M00007Boo`090?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool0X`3o
ool00`000000oooo0?ooo`050?ooo`00<P3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`X0oooo
00<0_g@0001d_`3oool0203oool00`000000oooo0?ooo`3o0?oooeT0oooo00<000000?ooo`3oool0
1@3oool003<0oooo00@0gia800000000000007Bo2@3oool01@3ookl0M0000000000007@0_ooo00P0
oooo0P00003o0?oooeT0oooo0P0000070?ooo`00C@3oool00`000000oooo0?ooo`2[0?ooo`030000
003oool0oooo0:40oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`00C@3o
ool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`00C@3oool00`000000oooo0?ooo`3o0?oooeT0oooo00<00000
0?ooo`3oool01@3oool001D0oooo00<0gia80000M02oool0=@3oool00`000000oooo0?ooo`3o0?oo
oeT0oooo00<000000?ooo`3oool01@3oool000h0oooo00<0oono07Ad_`3oool0103oool00`3ookl0
M4RL0=ooo`0e0?ooo`030000003oool0oooo0?l0ooooF@3oool00`000000oooo0?ooo`050?ooo`00
3P3oool00`3ogi`0B01d0;ooo`030?ooo`030?noM00007@0_ooo03H0oooo00<000000?ooo`3oool0
XP3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo00D0oooo000>0?ooo`070?oOW018
000000000000B02Lgol0omnL04Qd_`0h0?ooo`800000X`3oool00`000000oooo0?ooo`2b0?ooo`80
00001`3oool00100oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`0e0?ooo`030000
003oool0oooo0?l0ooooF@3oool00`000000oooo0?ooo`050?ooo`003`3oool02@3ookl0M01d0;oo
o`3oool0oooO09a800000000001d0;ooo`0e0?ooo`030000003oool0oooo0?l0ooooF@3oool00`00
0000oooo0?ooo`050?ooo`003P3oool00`3ookl0M01d0;ooo`040?ooo`030?oOW018M;l0oooo03D0
oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo00D0
oooo000>0?ooo`030?noM0000000M;oo00<0oooo00<0oono07A8W03Oool0=P3oool00`000000oooo
0?ooo`2N0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`050?ooo`00C@3oool00`000000oooo0?ooo`3o0?ooodl0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`050?ooo`006@3oool0103o_g@000000000M02oool`0?ooo`030000003o
ool0oooo0?l0ooooF@3oool00`000000oooo0?ooo`050?ooo`003@3oool00`3OW4P0000007Boo`02
0?ooo`040?oog`2LW;l0oooO09a800<0000000<007Bo0?ooo`3oool0<@3oool200000?l0ooooF@3o
ool2000000L0oooo000:0?ooo`040=nLB00000000000001d_`@0oooo00@0oono07@0000004P0W=oo
0P3oool00`2oW9`0gooo0?ooo`0b0?ooo`030000003oool0oooo0?l0ooooF@3oool00`000000oooo
0?ooo`050?ooo`002@3oool0103ookl0M0000018W03Oool90?ooo`050=oOg`2oM000000000000000
M;l0<P3oool00`000000oooo0?ooo`3o0?oooeT0oooo00<000000?ooo`3oool01@3oool001D0oooo
00<0oooO09a8001d_ol00P3oool00`3OW4P0001d0;ooo`0`0?ooo`030000003oool0oooo09H0oooo
00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`050?ooo`005@3oool00`3ooml0W7BL0=oo
o`020?ooo`030=nLM02Lgol0oooo0300oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?oo
o`2o0?ooo`030000003oool0oooo00D0oooo001=0?ooo`030000003oool0oooo0?l0ooooF@3oool0
0`000000oooo0?ooo`050?ooo`00C@3oool200000?l0ooooF@3oool2000000L0oooo001=0?ooo`03
0000003oool0oooo0?l0ooooF@3oool00`000000oooo0?ooo`050?ooo`00?`3oool0102oM0000000
0000001d_ol:0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0a@3oool00`000000
oooo0?ooo`050?ooo`00?P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`T0oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00D0oooo000m0?ooo`03
0?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0203oool00`000000oooo0?ooo`3o0?oood`0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`00?@3oool00`3ooml0W4P0
04RLg`020?ooo`040?oog`2LB00004RL0=ooo`L0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool003d0oooo00<0oooO09a80000M;l0
0`3oool00`3OW4P0001809cOo`070?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0
b`3oool00`000000oooo0?ooo`050?ooo`00?P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW018
0000B9cO00L0ooooo`00001M000000L0oooo000n0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO
09a80000M;l01`3oool00`000000oooo0?ooo`3o0?oooeT0oooo00<000000?ooo`3oool01@3oool0
03h0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`060?ooo`030000003oool0oooo
0?l0ooooF@3oool00`000000oooo0?ooo`050?ooo`00?P3oool0103ooml0W4P00018W03Oool20?oo
o`030=nLB000B9`0gooo00H0oooo00<000000?ooo`3oool0o`3ooomI0?ooo`030000003oool0oooo
00D0oooo000o0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01P3oool00`000000
oooo0?ooo`240?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00400oooo
00H0gia80000M02oool0oooO09a80018W=l70?ooo`030000003oool0oooo08@0oooo00<000000?oo
o`3oool0d@3oool00`000000oooo0?ooo`050?ooo`00@@3oool0103OW4P0000000000000M;l80?oo
o`030000003oool0oooo0?l0ooooF@3oool00`000000oooo0?ooo`050?ooo`00C@3oool200000840
oooo00<000000?ooo`3oool0e03oool2000000L0oooo001=0?ooo`030000003oool0oooo0800oooo
00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`050?ooo`00C@3oool00`000000oooo0?oo
o`3o0?oooeT0oooo00<000000?ooo`3oool01@3oool004d0oooo00<000000?ooo`3oool0o`3ooomI
0?ooo`030000003oool0oooo00D0oooo001=0?ooo`030000003oool0oooo0?l0ooooF@3oool00`00
0000oooo0?ooo`050?ooo`00C@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0=d0
oooo00<000000?ooo`3oool01@3oool004d0oooo0P00001i0?ooo`030000003oool0oooo0=`0oooo
0P0000070?ooo`00C@3oool00`000000oooo0?ooo`3o0?ooodD0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`050?ooo`00C@3oool00`000000oooo0?ooo`3o0?ooodD0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`00C@3oool00`000000oooo0?ooo`1b0?oo
o`030000003oool0oooo0><0oooo00<000000?ooo`3oool01@3oool004d0oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`3S0?ooo`030000003oool0oooo00D0oooo001=0?ooo`030000
003oool0oooo0?l0ooooF@3oool00`000000oooo0?ooo`050?ooo`00C@3oool00`000000oooo0?oo
o`3o0?oooeT0oooo00<000000?ooo`3oool01@3oool004d0oooo0P00001/0?ooo`030000003oool0
oooo0>T0oooo0P0000070?ooo`00C@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo
0=40oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00C@3oool00`000000
oooo0?ooo`3o0?oood00oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00
C@3oool00`000000oooo0?ooo`3o0?oooeT0oooo00<000000?ooo`3oool01@3oool004d0oooo00<0
00000?ooo`3oool0o`3ooomI0?ooo`030000003oool0oooo00D0oooo001=0?ooo`030000003oool0
oooo0680oooo00<000000?ooo`3oool0l`3oool00`000000oooo0?ooo`050?ooo`00C@3oool00`00
0000oooo0?ooo`1R0?ooo`030000003oool0oooo0?<0oooo00<000000?ooo`3oool01@3oool004d0
oooo0P00003o0?oooeT0oooo0P0000070?ooo`00<@3oool0102oM00000000000001d_ol30?ooo`03
0?oOW0180000M;oo0080oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`080?ooo`03
0000003oool0oooo0?l0ooooF@3oool00`000000oooo0?ooo`050?ooo`00<03oool01P3OW4P007Bo
0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol0103oool00`3o_g@0000007Boo`0;0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0o@3oool00`000000oooo0?ooo`050?oo
o`00;`3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00P0oooo00<0oooO09a80000
M;l02`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0?d0oooo00<000000?ooo`3o
ool01@3oool002l0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool80?ooo`03
0=nLB000B9`0gooo00X0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool01@3oool002l0oooo00<0oooO09a80000M;l00`3oool00`3OW4P00018
09cOo`080?ooo`030?oOW01804P0W=oo00X0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool01@3oool00300oooo00<0_g@00018W03Oool00P3o
ool00`3ogi`0B00004RLg`080?ooo`030?oo_`1d0000M;oo00X0oooo0`00003o0?oooeL0oooo0`00
00070?ooo`00<03oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00T0oooo00<0_g@0
001d_`3oool02@3oool00`000000oooo0?ooo`3o0?oooeT0oooo00<000000?ooo`3oool01@3oool0
0300oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`080?ooo`030=nLB000B9`0gooo
00T0oooo00<000000?ooo`3oool0o`3ooomI0?ooo`030000003oool0oooo00D0oooo000`0?ooo`04
0?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0203oool00`3ogi`0B01809cOo`090?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool0o`3oool>0?ooo`030000003oool0oooo
00D0oooo000a0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0203oool00`3ookl0
M00007Boo`090?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0iP3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo00D0oooo000b0?ooo`060=nLB00007@0_ooo0?oog`2L
B000B9cO2P3oool00`2oM00007Bo0?ooo`080?ooo`030000003oool0oooo0?l0oooo<P3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo00D0oooo000c0?ooo`040=nLB00000000000001d
_`T0oooo00D0oono07@000000000001d0;ooo`080?ooo`030000003oool0oooo0?l0ooooF@3oool0
0`000000oooo0?ooo`050?ooo`00C@3oool200000?l0ooooF@3oool2000000L0oooo001=0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo00D0
oooo001=0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0j`3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo00D0oooo001=0?ooo`030000003oool0oooo0?l0oooo;03o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00D0oooo001=0?ooo`030000003oool0
oooo0?l0ooooF@3oool00`000000oooo0?ooo`050?ooo`00C@3oool00`000000oooo0?ooo`3o0?oo
oeT0oooo00<000000?ooo`3oool01@3oool004d0oooo00<000000?ooo`3oool0o`3ooomI0?ooo`03
0000003oool0oooo00D0oooo001=0?ooo`800000o`3ooolW0?ooo`030000003oool0oooo02l0oooo
0P0000070?ooo`00C@3oool00`000000oooo0?ooo`3o0?ooobH0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`050?ooo`00C@3oool00`000000oooo0?ooo`3o0?oooeT0oooo00<00000
0?ooo`3oool01@3oool004d0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3d0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool01@3oool004d0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool01@3oool004d0oooo00<000000?ooo`3oool0o`3ooomI0?ooo`030000003oool0oooo00D0oooo
001=0?ooo`800000o`3ooomI0?ooo`8000001`3oool004d0oooo00<000000?ooo`3oool0o`3ooomI
0?ooo`030000003oool0oooo00D0oooo001=0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0n03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00D0oooo001=0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0n03oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo00D0oooo001=0?ooo`030000003oool0oooo0?l0ooooF@3oool00`000000oooo
0?ooo`050?ooo`00C@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?X0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`050?ooo`00C@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0?X0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`05
0?ooo`00C@3oool200000?l0ooooF@3oool2000000L0oooo001=0?ooo`030000003oool0oooo0?l0
ooooF@3oool00`000000oooo0?ooo`050?ooo`00<@3oool0102oM00000000000001d_ol30?ooo`03
0?oOW0180000M;oo0080oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`070?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0n03oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo00D0oooo000`0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3o
gi`0B00007Boo`030?ooo`030?noM000M;l0oooo0080oooo00<0_gAd0;ooo`3oool01`3oool00`00
0000oooo0?ooo`0=0?ooo`040000003oool0oooo00000?X0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`050?ooo`00;`3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo
00P0oooo00<0okmd001d_`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0?l0ooooB@3oool00`000000oooo0?ooo`050?ooo`00;`3oool00`3ooml0W4P004RLg`020?ooo`04
0?oog`2LB00004RL0=ooo`P0oooo00<0okmd001d_`3oool02P3oool00`000000oooo0?ooo`3o0?oo
o`D0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`050?ooo`00;`3oool00`3ooml0
W4P0001d_`030?ooo`030=nLB00004P0W=oo00T0oooo00<0okmd04RLg`3oool02@3oool3000000/0
oooo00<000000?ooo`3oool0mP3oool00`000000oooo0?ooo`1?0?ooo`<000001`3oool00300oooo
00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?ooo`030=nLB018W=l0oooo00P0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oood/0oooo00<000000?ooo`3oool0
1@3oool00300oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0;0?ooo`030;md001d
_ol0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<0
00000?ooo`3oool01@3oool00300oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`0:
0?ooo`030?oOW01807@0_ooo00L0oooo00<000000?ooo`3oool0203oool200000?40oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`00<03oool0103ooml0W4P00018W03Oool2
0?ooo`030=nLB000B9`0gooo00X0oooo00<0oooO09a8001d_ol01`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0?00oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`05
0?ooo`00<@3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00X0oooo00<0oono07@0
0018W=l01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooC`3oool00`00
0000oooo0?ooo`050?ooo`00<P3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`L0oooo00L0okmd
0018W03Oool0oooo0=nLB00004P0W=oo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`3o0?ooodl0oooo00<000000?ooo`3oool01@3oool003<0oooo00@0gia800000000000007Bo
2@3oool01@3ogi`0B000000000000000M;oo00P0oooo0P0000060?ooo`030000003oool0oooo0?l0
ooooD03oool2000000L0oooo001=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
i03oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00D0oooo001=0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0i03oool00`000000oooo0?ooo`1Y0?ooo`030000003o
ool0oooo00D0oooo001=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooomA
0?ooo`030000003oool0oooo00D0oooo001=0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0f@3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00D0oooo001=0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo00D0oooo001=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
o`3ooom>0?ooo`030000003oool0oooo00D0oooo001=0?ooo`8000002@3oool00`000000oooo0?oo
o`310?ooo`030000003oool0oooo08P0oooo0P0000070?ooo`00C@3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`05
0?ooo`00C@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooA`3oool00`00
0000oooo0?ooo`050?ooo`00C@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo09d0
oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`050?ooo`00C@3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`2K0?ooo`030000003oool0oooo00D0oooo001=0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0[P3oool00`000000oooo0?ooo`050?ooo`00C@3oool2000003P0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0:d0oooo0P000007
0?ooo`00C@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo00D0oooo001=0?ooo`03
0000003oool0oooo0?l0ooooF@3oool00`000000oooo0?ooo`050?ooo`00C@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`050?ooo`00C@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool01@3oool004d0ooooo`00001M000000L0oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0.492522, -0.524623, \
0.00193621, 0.00451294}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.97619 2.25016 1.5297 1.52793 [
[.07613 -0.0125 -13.8438 -15.6875 ]
[.07613 -0.0125 13.8438 0 ]
[.30114 -0.0125 -13.8438 -15.6875 ]
[.30114 -0.0125 13.8438 0 ]
[.52616 -0.0125 -13.8438 -15.6875 ]
[.52616 -0.0125 13.8438 0 ]
[.75117 -0.0125 -13.8438 -15.6875 ]
[.75117 -0.0125 13.8438 0 ]
[.97619 -0.0125 -5 -15.6875 ]
[.97619 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -7.125 -31.375 ]
[.5 -0.0125 7.125 -15.6875 ]
[-0.0125 .00177 -18.6875 -7.84375 ]
[-0.0125 .00177 0 7.84375 ]
[-0.0125 .15456 -27.6875 -7.84375 ]
[-0.0125 .15456 0 7.84375 ]
[-0.0125 .30735 -27.6875 -7.84375 ]
[-0.0125 .30735 0 7.84375 ]
[-0.0125 .46015 -27.9375 -7.84375 ]
[-0.0125 .46015 0 7.84375 ]
[-0.0125 .61294 -27.9375 -7.84375 ]
[-0.0125 .61294 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -43.625 -7.125 ]
[-0.01875 .30902 -27.9375 7.125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07613 0 m
.07613 .00625 L
s
gsave
.07613 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.30114 0 m
.30114 .00625 L
s
gsave
.30114 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
.52616 0 m
.52616 .00625 L
s
gsave
.52616 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.75117 0 m
.75117 .00625 L
s
gsave
.75117 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
.12113 0 m
.12113 .00375 L
s
.16613 0 m
.16613 .00375 L
s
.21114 0 m
.21114 .00375 L
s
.25614 0 m
.25614 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.39115 0 m
.39115 .00375 L
s
.43615 0 m
.43615 .00375 L
s
.48115 0 m
.48115 .00375 L
s
.57116 0 m
.57116 .00375 L
s
.61616 0 m
.61616 .00375 L
s
.66117 0 m
.66117 .00375 L
s
.70617 0 m
.70617 .00375 L
s
.79618 0 m
.79618 .00375 L
s
.84118 0 m
.84118 .00375 L
s
.88618 0 m
.88618 .00375 L
s
.93119 0 m
.93119 .00375 L
s
.03112 0 m
.03112 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -68.125 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 17.688 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
73.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .00177 m
.00625 .00177 L
s
gsave
-0.0125 .00177 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .15456 m
.00625 .15456 L
s
gsave
-0.0125 .15456 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
1.000 setlinewidth
grestore
0 .30735 m
.00625 .30735 L
s
gsave
-0.0125 .30735 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .46015 m
.00625 .46015 L
s
gsave
-0.0125 .46015 -88.9375 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
1.000 setlinewidth
grestore
0 .61294 m
.00625 .61294 L
s
gsave
-0.0125 .61294 -88.9375 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03233 m
.00375 .03233 L
s
0 .06288 m
.00375 .06288 L
s
0 .09344 m
.00375 .09344 L
s
0 .124 m
.00375 .124 L
s
0 .18512 m
.00375 .18512 L
s
0 .21568 m
.00375 .21568 L
s
0 .24624 m
.00375 .24624 L
s
0 .27679 m
.00375 .27679 L
s
0 .33791 m
.00375 .33791 L
s
0 .36847 m
.00375 .36847 L
s
0 .39903 m
.00375 .39903 L
s
0 .42959 m
.00375 .42959 L
s
0 .4907 m
.00375 .4907 L
s
0 .52126 m
.00375 .52126 L
s
0 .55182 m
.00375 .55182 L
s
0 .58238 m
.00375 .58238 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -103.906 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.125 11.8438 translate
90 rotate
-68.125 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 18.625 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
68.563 11.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\242) show
73.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.07613 .61178 m
.07613 .61803 L
s
.30114 .61178 m
.30114 .61803 L
s
.52616 .61178 m
.52616 .61803 L
s
.75117 .61178 m
.75117 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.12113 .61428 m
.12113 .61803 L
s
.16613 .61428 m
.16613 .61803 L
s
.21114 .61428 m
.21114 .61803 L
s
.25614 .61428 m
.25614 .61803 L
s
.34615 .61428 m
.34615 .61803 L
s
.39115 .61428 m
.39115 .61803 L
s
.43615 .61428 m
.43615 .61803 L
s
.48115 .61428 m
.48115 .61803 L
s
.57116 .61428 m
.57116 .61803 L
s
.61616 .61428 m
.61616 .61803 L
s
.66117 .61428 m
.66117 .61803 L
s
.70617 .61428 m
.70617 .61803 L
s
.79618 .61428 m
.79618 .61803 L
s
.84118 .61428 m
.84118 .61803 L
s
.88618 .61428 m
.88618 .61803 L
s
.93119 .61428 m
.93119 .61803 L
s
.03112 .61428 m
.03112 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00177 m
1 .00177 L
s
.99375 .15456 m
1 .15456 L
s
.99375 .30735 m
1 .30735 L
s
.99375 .46015 m
1 .46015 L
s
.99375 .61294 m
1 .61294 L
s
.125 Mabswid
.99625 .03233 m
1 .03233 L
s
.99625 .06288 m
1 .06288 L
s
.99625 .09344 m
1 .09344 L
s
.99625 .124 m
1 .124 L
s
.99625 .18512 m
1 .18512 L
s
.99625 .21568 m
1 .21568 L
s
.99625 .24624 m
1 .24624 L
s
.99625 .27679 m
1 .27679 L
s
.99625 .33791 m
1 .33791 L
s
.99625 .36847 m
1 .36847 L
s
.99625 .39903 m
1 .39903 L
s
.99625 .42959 m
1 .42959 L
s
.99625 .4907 m
1 .4907 L
s
.99625 .52126 m
1 .52126 L
s
.99625 .55182 m
1 .55182 L
s
.99625 .58238 m
1 .58238 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.17363 .46384 Mdot
.75647 .0734 Mdot
.4632 .58322 Mdot
.28987 .01525 Mdot
.89687 .55641 Mdot
.034 .11586 Mdot
.93619 .37556 Mdot
.13099 .37125 Mdot
.83052 .12576 Mdot
.32721 .54471 Mdot
.46232 .01859 Mdot
.79958 .58651 Mdot
.06254 .0677 Mdot
.96157 .46362 Mdot
.07267 .26713 Mdot
.89526 .19517 Mdot
.20238 .4969 Mdot
.69638 .05142 Mdot
.55931 .59902 Mdot
.20298 .02114 Mdot
.93502 .54151 Mdot
.02565 .1389 Mdot
.92911 .33835 Mdot
.14607 .40384 Mdot
.80651 .10692 Mdot
.37311 .55859 Mdot
.39612 .01579 Mdot
.84105 .57424 Mdot
.04958 .08785 Mdot
.9492 .42518 Mdot
.10225 .31818 Mdot
.86867 .15904 Mdot
.2525 .52033 Mdot
.59267 .03164 Mdot
.68897 .60302 Mdot
.11473 .0366 Mdot
.96559 .51898 Mdot
.02787 .1763 Mdot
.91981 .28515 Mdot
.1629 .44271 Mdot
.777 .08539 Mdot
.42722 .57429 Mdot
.32896 .01472 Mdot
.87754 .56268 Mdot
.0393 .10621 Mdot
.93982 .39203 Mdot
.12282 .355 Mdot
.84242 .13555 Mdot
.30404 .53747 Mdot
.49956 .02124 Mdot
.77258 .59271 Mdot
.07298 .05727 Mdot
.96662 .48336 Mdot
.05602 .23691 Mdot
.90484 .22003 Mdot
.1863 .48245 Mdot
.73069 .06195 Mdot
.50624 .59179 Mdot
.2481 .01713 Mdot
.91608 .54968 Mdot
.02913 .12612 Mdot
.933 .35866 Mdot
.13814 .38669 Mdot
.81955 .11676 Mdot
.34834 .55129 Mdot
.43065 .01688 Mdot
.82038 .58086 Mdot
.05549 .077 Mdot
.95617 .44585 Mdot
.08679 .29195 Mdot
.88438 .17698 Mdot
.22222 .50813 Mdot
.65409 .04193 Mdot
.61758 .60332 Mdot
.15985 .02686 Mdot
.95159 .53286 Mdot
.02381 .15271 Mdot
.92582 .31766 Mdot
.15259 .41986 Mdot
.7956 .0981 Mdot
.39338 .56491 Mdot
.36963 .01495 Mdot
.85612 .5698 Mdot
.045 .09491 Mdot
.94561 .4123 Mdot
.11056 .33319 Mdot
.85895 .14932 Mdot
.27151 .52719 Mdot
.55663 .0268 Mdot
.72451 .60031 Mdot
.09527 .04338 Mdot
.96907 .50831 Mdot
.03491 .19493 Mdot
.91526 .26242 Mdot
.17013 .4573 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00n`3oool01`2oM4P0W=oo0?oo
o`3ogi`0B0000000001d_ol0[P3oool00?/0oooo00P0okmd04RLg`3oool0gia8001d_`3oool0_ibL
0=ooojd0oooo003b0?ooo`0>0=nLB000000007Bo0?ooo`3ooml0W4P00000001d_ol0oooo0?oo_`1d
B4P0B7BL09a8001d_on`0?ooo`00m03oool0303o_g@0M;oo0?oOW01804P0W=oo0;mdM02oool0oooO
09a8M02o_g@0001d0;oook00oooo003e0?ooo`040;mdM02LW4P004RL0=ooo`<0oooo00@0gia807Bo
o`3ookl0M7Bo/03oool00?D0oooo00<0oono07@00000M;l0103oool0103ogi`0B7Bo0?oog`2LB002
0000000307Boo`3oool0oooo0:/0oooo003e0?ooo`030?oo_`1d0000M;oo00@0oooo00<0oooO09a8
M02oool0/@3oool00?D0oooo00@0okmd00000000B9`0gooo103oool00`3OW4P0M;oo0?ooo`2`0?oo
o`00m@3oool01@2oM00004RL0=oOW018B9`0gooo0080oooo00<0gia800000000M;l0/@3oool00?<0
oooo00T0okmd000000000000M;oo0?ooo`3ogi`0B0000018W03Oool0]03oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
06`0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`050?ooo`030?oog`2LB000
B9cO03P0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`030?oo_`1d
000000000080000000<0M;oo0?ooo`3oool0=`3oool0102oM00000000000001d_ol30?ooo`030?oO
W0180000M;oo0080oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`0e0?ooo`040;md
00000000000007Boo`<0oooo00<0omnL04P0001d_ol00P3oool00`3ookl0M0000000000200000003
04RLg`3oool0oooo03L0oooo00@0_g@0000000000000M;oo5P3oool006/0oooo00H0gia8001d_`3o
ool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00H0oooo00<0gia80018W03Oool0=P3oool0
1P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00P3oool00`3o_g@00000
001d_`020?ooo`030;mdB02Lgol0oooo03H0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?oo
o`030?oOW0180000M;oo00<0oooo00<0okmd001d_`3oool00P3oool00`2oM7@0_ooo0?ooo`0d0?oo
o`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`040?ooo`030?noM000
0000M;oo03T0oooo00H0gia8001d_`3oool0omnL04P00018W=lE0?ooo`00JP3oool00`3ooml0W4P0
04RLg`020?ooo`030?noM00004P0W=oo00X0oooo00<0omnL04P0B02Lgol0=@3oool00`3ooml0W4P0
04RLg`020?ooo`030?noM00004P0W=oo00/0oooo00<0omnL04Q8W03Oool0=@3oool00`3ooml0W4P0
04RLg`020?ooo`030?noM00004P0W=oo00P0oooo00<0okmd001d_`3oool0=`3oool00`3ooml0W4P0
04RLg`020?ooo`030?noM00004P0W=oo00P0oooo00<0oooO09a80000M;l0>03oool00`3ooml0W4P0
04RLg`020?ooo`030?noM00004P0W=oo01@0oooo001Z0?ooo`030?oog`2LB000B9cO0080oooo00@0
oooO09a80000B9`0gooo1@3oool00`3o_g@0000000000004000000030018W03Oool0oooo0380oooo
00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool:0?ooo`030?oo_`1d0000M;oo03D0
oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool80?ooo`030?noM000M;l0oooo
03H0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool80?ooo`030=nLB000B9`0
gooo03L0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03OoolC0?ooo`00G@3oool0
0`3ooml0W4P0000000070000000604RLg`3oool0oooo0?oog`2LB00007Bo0`3oool00`3OW4P00018
09cOo`050?ooo`030?oog`2LB4P0W=oo0080oooo00<0_g@0001d_`3oool09`3oool00`3ooml0W4P0
000000070000000604RLg`3oool0oooo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`0:0?oo
o`030?oOW0180000M;oo02P0oooo00<0oooO09a8000000001`0000001P18W=l0oooo0?ooo`3ooml0
W4P0001d_`<0oooo00<0gia80000B02Lgol02@3oool00`3o_g@0B9cO0?ooo`0X0?ooo`030?oog`2L
B000000000L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`030=nLB00004P0W=oo00P0
oooo00<0omnL04P0B02Lgol0=`3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo01<0
oooo001[0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01P3oool01`3ookl0M01d
0;ooo`3oool0okmd0018W03Oool0=@3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO
00T0oooo00@0omnL04P0000004P0W=oo=P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000
B9cO00X0oooo00<0gia804RLg`3oool0=@3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000
B9cO00P0oooo00<0oono07@0001d_ol0>03oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000
B9cO01<0oooo001[0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l01`3oool01P3o
gi`0B4RL0=ooo`3ogi`0B01809cOocD0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d
_`070?ooo`050?oOW018000000000000001d_ol0=`3oool00`3OW4P0001809cOo`020?ooo`030?oo
g`2LB00007Bo00/0oooo00<0_g@007Boo`3oool0=03oool00`3OW4P0001809cOo`020?ooo`030?oo
g`2LB00007Bo00T0oooo00<0_g@0001d_`3oool0=`3oool00`3OW4P0001809cOo`020?ooo`030?oo
g`2LB00007Bo01<0oooo001[0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01`3o
ool01@3o_g@007Bo0?oog`2LB000B9cO03D0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL
0=ooo`080?ooo`030?oo_`1d000007Bo03L0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL
0=ooo`0:0?ooo`030?oOW01807@0_ooo03@0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL
0=ooo`080?ooo`030=nLB000B9`0gooo03L0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL
0=ooo`0B0?ooo`00J`3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00P0oooo
00@0gia804RLg`2oM00007Bo=@3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo
00X0oooo00<0gia8001d_`3oool0=@3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0
gooo00X0oooo00<0oooO09a8001d_ol0=03oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000
B9`0gooo00P0oooo00<0omnL04P0B02Lgol0=`3oool0103ooml0W4P00018W03Oool20?ooo`030=nL
B000B9`0gooo0180oooo001/0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool02@3o
ool0103OW4P0M7Ad0000M02ooole0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0
2P3oool00`3ogi`0B01809cOo`0f0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0
2P3oool00`3ookl0M00004RLg`0e0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0
203oool00`3ookl0M00007Boo`0h0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0
4P3oool006d0oooo00H0gia80000M02oool0oooO09a80018W=l;0?ooo`030;md000004P0W=oo03H0
oooo00H0gia80000M02oool0oooO09a80018W=l80?ooo`060;md001d_ol0oooo0=nLB00004P0W=oo
=`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`L0oooo00L0okmd0018W03Oool0oooo0=nLB000
04P0W=oo03H0oooo00H0gia80000M02oool0oooO09a80018W=l:0?ooo`030;md0000M;l0oooo03P0
oooo00H0gia80000M02oool0oooO09a80018W=lC0?ooo`00KP3oool0103OW4P0000000000000M;l<
0?ooo`030?oog`2LB000B9cO03L0oooo00@0gia800000000000007Bo2P3oool0102oM00000000000
0018W=li0?ooo`040=nLB00000000000001d_`T0oooo00D0omnL04P000000000000007Boo`0h0?oo
o`040=nLB00000000000001d_`T0oooo00D0oono07@000000000001d0;ooo`0i0?ooo`040=nLB000
00000000001d_a@0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo00150?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0o`3ooomT0?ooo`00A`3o
ool00`3o_g@0000007Boo`3o0?ooofL0oooo00170?ooo`030?oog`2LB00007Bo0?l0ooooI`3oool0
04P0oooo00<0gia80018W03Oool0o`3ooomV0?ooo`00>03oool00`3ooml0W4P00000000700000003
04RLg`3oool0oooo00<0oooo00<0omnL04P0B02Lgol0o`3ooomV0?ooo`00B03oool00`3ookl0M000
07Boo`0:0?ooool00000C@00000?0?ooo`00B@3oool00`2oM00007Bo0?ooo`090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`00B@3oool0
0`3OW4P004RL0=ooo`090?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00190?ooo`030?oOW01804P0W=oo
00T0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo00d0oooo00190?ooo`03
0?oo_`1d0000M;oo00T0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo00d0
oooo001:0?ooo`030;md0000M;l0oooo00P0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0^P3oool00`000000oooo
0?ooo`0=0?ooo`00B03oool01@3ookl0M0000000000007@0_ooo00P0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0:<0oooo00<000000?ooo`3oool03@3oool005D0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool03@3oool0
05D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool03@3oool005D0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`210?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0Q03oool00`000000
oooo0?ooo`0=0?ooo`00E@3oool200000<80oooo00<000000?ooo`3oool0P`3oool2000000l0oooo
001E0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003o
ool0oooo00d0oooo001E0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0o`3ooolT
0?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0]P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00d0oooo001E0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`1`0?ooo`03
0000003oool0oooo00d0oooo001E0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo
0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`3S0?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool03@3oool005D0oooo00<000000?ooo`3oool0h`3oool00`000000oooo0?ooo`1R
0?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0o`3ooola0?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00d0
oooo001E0?ooo`800000k`3oool00`000000oooo0?ooo`1F0?ooo`8000003`3oool005D0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooocD0oooo00<000000?ooo`3oool03@3o
ool005D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooocD0oooo00<00000
0?ooo`3oool03@3oool005D0oooo00<000000?ooo`3oool0m`3oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo00d0oooo001E0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0i@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`030000003oool0oooo00d0oooo
001E0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool0
0`000000oooo0?ooo`3n0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03@3oool0
05D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3^0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool03@3oool005D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3oool03@3oool005D0oooo0P00000<0?ooo`030000
003oool0oooo0?l0oooo>P3oool2000000l0oooo001E0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0mP3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00d0oooo001E
0?ooo`030000003oool0oooo0?l0oooo1@3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo00d0oooo001E0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0=0?oo
o`00E@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?/0oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0?/0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`00E@3o
ool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool03@3oool005D0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooo`80oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0?l0oooo0P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00d0oooo001E0?ooo`03
0000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool2000000L0oooo
00<000000?ooo`3oool0o`3oool70?ooo`030000003oool0oooo03D0oooo0P00000?0?ooo`00E@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo1`3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000003oool0oooo0?l0ooooB@3oool0
0`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?oo
o`3oool03@3oool005D0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool03@3oool003X0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0
B00007Boo`020?ooo`040=nLB0000000001d0;ooo`/0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`3o0?ooo``0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0=0?oo
o`00>@3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol0103oool0
0`3ookl0M000001d_`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooom1
0?ooo`030000003oool0oooo00d0oooo000h0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000
B02Lgol02P3oool00`2oM000001d0;ooo`080?ooo`030000003oool0oooo0?l0ooooB@3oool00`00
0000oooo0?ooo`0=0?ooo`00>03oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=oo
o`T0oooo00@0oooO09a8000007@0_ooo1`3oool00`000000oooo0?ooo`3o0?oooaX0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0=0?ooo`00:`3oool00`3ooml0W4P0000000070000
000604RLg`3oool0oooo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`070?ooo`030?oOW018
000000000080000000<007Bo0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0?l0oooo4`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00d0oooo000i
0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01P3oool0203ookl0M0000018W03O
ool0oooo0;md000004P0W=oo1P3oool3000000@0oooo00<000000?ooo`3oool0o`3ooom00?ooo`<0
00003`3oool003T0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`060?ooo`030?oO
W0180000M;oo0080oooo00<0omnL04P00018W=l01P3oool00`000000oooo0?ooo`3o0?oooad0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0=0?ooo`00>@3oool00`3ogi`0B00004RL
g`030?ooo`030;md0000B9`0gooo00D0oooo00<0omnL04P0001d_ol00P3oool00`3ooml0W4P0001d
_`060?ooo`030000003oool0oooo0?l0oooo7@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo00d0oooo000i0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool01@3o
ool00`3ookl0M000001d_`030?ooo`030=nLB000B9`0gooo00D0oooo00<000000?ooo`3oool0o`3o
oom90?ooo`030000003oool0oooo00d0oooo000j0?ooo`030?oOW0180000M;oo0080oooo00<0gia8
001d_`3oool01P3oool00`2oM000001d0;ooo`020?ooo`030=nLB000M;l0oooo00D0oooo00<00000
0?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo00d0oooo000k0?ooo`060=nLB00007@0_ooo
0?oog`2LB000B9cO1`3oool01`3ookl0M0000018W03Oool0oooO09a8001d_ol01P3oool00`000000
oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool03@3oool003`0oooo00@0gia8000000000000
07Bo2P3oool0102oM000000000000018W=l70?ooo`030000003oool0oooo0?l0ooooB@3oool00`00
0000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0
oooo6@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool03@3oool005D0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003o
ool0oooo00d0oooo001E0?ooo`800000o`3ooom90?ooo`8000003`3oool005D0oooo00<000000?oo
o`3oool0o`3ooom90?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000003oool0oooo0?l0
ooooB@3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00d0oooo
001E0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool03@3oool005D0oooo00<000000?ooo`3oool0o`3ooom9
0?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000003oool0oooo0?l0ooooB@3oool00`00
0000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3o
ool03@3oool005D0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo00d0oooo
001E0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool2
00000?l0ooooB@3oool2000000l0oooo001E0?ooo`030000003oool0oooo0?l0oooo:@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000003oool0oooo0?l0
oooo:@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000
003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?oo
o`3o0?ooodT0oooo00<000000?ooo`3oool03@3oool005D0oooo00<000000?ooo`3oool0o`3ooom9
0?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000003oool0oooo0?l0ooooB@3oool00`00
0000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0
oooo=`3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0?l0oooo=`3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?oo
o`3o0?ooodT0oooo00<000000?ooo`3oool03@3oool005D0oooo0P00003o0?ooodT0oooo0P00000?
0?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool03@3oool005D0
oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000
003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?oo
o`3o0?ooodT0oooo00<000000?ooo`3oool03@3oool005D0oooo00<000000?ooo`3oool0o`3ooom9
0?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000003oool0oooo0?l0oooo;03oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0o`3ooolE0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool03@3oool005D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?oooc80oooo
00<000000?ooo`3oool03@3oool005D0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003o
ool0oooo00d0oooo001E0?ooo`800000o`3ooom90?ooo`8000003`3oool005D0oooo00<000000?oo
o`3oool0o`3ooom90?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000003oool0oooo0?l0
ooooB@3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooobh0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0=0?ooo`007@3oool00`3OW4P0001d0;oo
o`0e0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00d0oooo000F0?ooo`030?oo_`1dM;l0oooo00@0oooo00<0oono07A8W03Oool0=@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0=
0?ooo`005P3oool00`3ogi`0B01d0;ooo`030?ooo`030?noM00007@0_ooo01/0oooo00@0_g@00000
00000000M;oo0`3oool00`3ogi`0B00007Boo`030?ooo`060?oo_`1d0000000000000000B9`0gooo
203oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo
0?ooo`0=0?ooo`005P3oool01`3ogi`0B0000000000004P0W=oo0?oOW018M;l0703oool01P3OW4P0
07Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00P3oool00`3ookl0M00004RLg`02
0?ooo`030=nLB00007@0_ooo00L0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0
oooo00d0oooo000H0?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool0603oool00`3o
oml0W4P004RLg`020?ooo`030?noM00004P0W=oo00H0oooo00<0okmd0018W03Oool00`3oool00`2o
M000B9cO0?ooo`060?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0=0?oo
o`005`3oool02@3ookl0M01d0;ooo`3oool0oooO09a800000000001d0;ooo`0H0?ooo`030?oog`2L
B000B9cO0080oooo00@0oooO09a80000B9`0gooo1@3oool00`3o_g@004RL0=ooo`030?ooo`030;md
0000M;l0oooo00H0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo00d0oooo
000F0?ooo`030?oo_`1d07@0_ooo00@0oooo00<0omnL04Qd_`3oool02`3oool00`3ooml0W4P00000
00070000000604RLg`3oool0oooo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`050?ooo`03
0?oog`2LB000M;oo0080oooo00<0oono07@00018W=l01`3oool00`000000oooo0?ooo`3o0?ooodT0
oooo00<000000?ooo`3oool03@3oool001H0oooo00<0okmd0000001d_ol00`3oool00`3ookl0M4RL
0=ooo`0J0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01`3oool01P2oM0000018
09cOg`2LB000001d0;ooo`L0oooo0`00003o0?ooodL0oooo0`00000?0?ooo`00>@3oool00`3OW4P0
001809cOo`020?ooo`030?oog`2LB00007Bo00P0oooo00D0oooO09a80000000004RL0=ooo`070?oo
o`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0=0?ooo`008@3oool0103o_g@0
00000000M02ooolD0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01`3oool01P2o
M000001809cOo`3ogi`0B4RL0=ooo`H0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003o
ool0oooo00d0oooo000E0?ooo`030=nLB0000000M;oo0080oooo00@0oooO09bL_`3ooml0W4P00`00
00000`00M;l0oooo0?ooo`0E0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0
1P3oool00`3ogi`0B00007Boo`020?ooo`030?noM018W=l0oooo00D0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0=0?ooo`004P3oool0103OW4P0000000000000M;l40?ooo`040?oo_`1d0000001809cOo`80
oooo00<0_ibL0=ooo`3oool05`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00H0
oooo00<0omnL04P0B02Lgol00P3oool00`3o_g@004RL0=ooo`050?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool03@3oool00140oooo00@0oono07@00000B9`0gooo2@3oool01@3Ogml0_g@000000000000007Bo
01P0oooo00H0gia80000M02oool0oooO09a80018W=l70?ooo`030?oog`2LB000B9cO0080oooo00<0
_g@0001d_`3oool01@3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool03@3o
ool001d0oooo00<0oooO09a8001d_ol00P3oool00`3OW4P0001d0;ooo`0G0?ooo`040=nLB0000000
0000001d_`T0oooo00D0oooO09a8000000000000001d_`070?ooo`030000003oool0oooo0?l0oooo
B@3oool00`000000oooo0?ooo`0=0?ooo`007@3oool00`3ooml0W7BL0=ooo`020?ooo`030=nLM02L
gol0oooo0300oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo00d0oooo001E
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooolU0?ooo`030000003oool0
oooo00d0oooo001E0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooolU0?oo
o`030000003oool0oooo00d0oooo001E0?ooo`800000o`3ooolb0?ooo`030000003oool0oooo01@0
oooo0P00000?0?ooo`00E@3oool00`000000oooo0?ooo`3o0?oooc40oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<0
00000?ooo`3oool03@3oool005D0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0
oooo00d0oooo001E0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0=0?oo
o`00E@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0?l0oooo8@3oool00`000000
oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0?l0oooo
2P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000003o
ool0oooo0?l0oooo<P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00d0oooo001E
0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`00
0000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool03@3oool005D0oooo0P00003o0?ooodT0
oooo0P00000?0?ooo`00E@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0?l0oooo
7P3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo0?l0oooo203oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00d0oooo001E
0?ooo`030000003oool0oooo0?l0oooo<`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00d0oooo001E0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0=0?oo
o`00E@3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool03@3oool005D0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool0
3@3oool005D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?ooo`P0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`3o
0?ooocD0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`00
0000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool03@3oool005D0oooo0P00003o0?ooodT0
oooo0P00000?0?ooo`00E@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0oooo
6@3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo0?l0oooo6@3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`3o
0?ooodT0oooo00<000000?ooo`3oool03@3oool005D0oooo00<000000?ooo`3oool0o`3ooolf0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool03@3oool005D0oooo00<000000?ooo`3o
ool0o`3ooolf0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03@3oool005D0oooo
00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`030000003oool0oooo00d0oooo001E
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool005D0oooo00<000000?ooo`3oool0o`3ooolh0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool005D0oooo0P00003o0?ooodT0
oooo0P00000?0?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool0
3@3oool005D0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo00d0oooo001E
0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo0?l0oooo503oool00`000000oooo0?ooo`0=0?oo
o`00>@3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo00<0oooo00<0oono07A8
W03Oool0303oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0?l0oooo1@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo000h0?ooo`060=nLB000M;l0oooo0?oO
W0180000B9cO0P3oool00`3ogi`0B00007Boo`040?ooo`030=nLB018W=l0oooo00/0oooo00<00000
0?ooo`3oool0o`3ooolj0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool0
03L0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?oo_`1d07@0_ooo
00/0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo00d0oooo000g0?ooo`03
0?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo203oool00`3o_g@007Bo0?ooo`0:0?oo
o`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0=0?ooo`00:P3oool00`3ooml0
W4P0000000070000000604RLg`3oool0oooo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`08
0?ooo`030?oog`2LB4P0W=oo00X0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3o
0?oooa40oooo00<000000?ooo`3oool03@3oool003P0oooo00<0_g@00018W03Oool00P3oool00`3o
gi`0B00004RLg`090?ooo`030?oOW018M;l0oooo00T0oooo0`00000e0?ooo`030000003oool0oooo
0?l0oooo3`3oool3000000l0oooo000h0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000
M;l02P3oool00`2oM000M;oo0?ooo`080?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool003P0oooo
00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`090?ooo`030?oOW018B9`0gooo00P0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0=0?ooo`00>03oool0103ooml0W4P00018W03Oool20?ooo`030=nL
B000B9`0gooo00X0oooo00<0gia804RLg`3oool01`3oool00`000000oooo0?ooo`3o0?ooodT0oooo
00<000000?ooo`3oool03@3oool003T0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?oo
o`050?ooo`030?oog`3Ogol0oooo0080oooo00<0oono07@0M02oool01`3oool00`000000oooo0?oo
o`3o0?ooodT0oooo00<000000?ooo`3oool03@3oool003X0oooo00H0gia80000M02oool0oooO09a8
0018W=l70?ooo`030;mdM02oool0oooo0080oooo00<0okmd001d_`3oool01P3oool00`000000oooo
0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool03@3oool003/0oooo00@0gia800000000000007Bo
203oool00`3ookl0M00000000003000000030000B02Lgol0oooo00D0oooo00<000000?ooo`3oool0
o`3ooom90?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0o`3oool<0?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool0o`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00d0oooo001E0?ooo`030000003oool0oooo0?l0oooo?@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00d0oooo001E0?ooo`800000o`3ooom90?ooo`8000003`3oool005D0oooo
00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0o`3oool70?ooo`030000003oool0oooo00d0oooo001E
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0o`3oool70?ooo`030000003oool0
oooo00d0oooo001E0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0=0?oo
o`00E@3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool03@3oool005D0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool03@3oool005D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`3d0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool005D0oooo00<00000
0?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo00d0oooo001E0?ooo`030000003oool0oooo
0?l0oooo?@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo001E0?ooo`80
0000D@3oool00`000000oooo0?ooo`3Y0?ooo`030000003oool0oooo00P0oooo0P00000?0?ooo`00
E@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0?D0oooo00<000000?ooo`3oool0
3@3oool005D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`3_0?ooo`030000003o
ool0oooo00d0oooo001E0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0k`3oool0
0`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooocP0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo
0?ooo`1Q0?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3oool03@3oool005D0oooo00<0
00000?ooo`3oool0H@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool03@3oool005D0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`36
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool005D0oooo00<000000?oo
o`3oool0J@3oool00`000000oooo0?ooo`3L0?ooo`030000003oool0oooo00d0oooo001E0?ooo`80
0000L@3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo0P00000?0?ooo`00
E@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooobH0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0=
0?ooo`00E@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0:@0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`1o0?ooo`03
0000003oool0oooo09d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0=0?ooo`00
E@3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`3o0?oooaT0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`2:
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0=
0?ooo`00E@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool00`000000oooo0?ooo`3o0?ooo`d0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0=0?ooo`00E@3oool2000009L0oooo
00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0h0?ooo`8000003`3oool005D0oooo00<0
00000?ooo`3oool0UP3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool03@3oool005D0oooo00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool03@3oool005D0oooo00<000000?ooo`3oool0Y03oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03@3oool005D0
oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool03@3oool003T0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0
B00007Boo`030?ooo`050?oog`2LB000000000000000M;l02P3oool00`000000oooo0?ooo`2f0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0=0?oo
o`00>03oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00`3oool0
1`3OW4P007Bo0?ooo`3ookl0M0000018W03Oool0203oool00`000000oooo0?ooo`2f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo05T0oooo00<000000?ooo`3oool03@3oool003L0oooo00<0oooO09a80018W=l00P3o
ool00`3o_g@0001809cOo`060?ooo`030?oog`2LB000M;oo0080oooo00<0omnL04P00018W=l0203o
ool00`000000oooo0?ooo`390?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`0=0?ooo`00=`3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB000
04RL0=ooo`D0oooo00<0oono07@0001d_ol00`3oool00`2oM000001d0;ooo`070?ooo`030000003o
ool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0=0?ooo`00:P3oool00`3ooml0W4P000000007
0000000604RLg`3oool0oooo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`050?ooo`030?oo
g`2LB00007Bo00<0oooo00<0gia80000B02Lgol01`3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`00>03o
ool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00H0oooo00<0_g@00000M02oool00P3o
ool00`3OW4P0001809cOo`070?ooo`<00000203oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`<000003`3o
ool003P0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`060?ooo`080?noM0000000
B9cO0?ooo`3ooml0W4P00018W03Oool70?ooool00000C@00000?0?ooo`00>03oool00`3ogi`0B000
04RLg`030?ooo`030;md0000B9`0gooo00D0oooo00<0oooO09a8000000000P0000000`0007@0_ooo
0?ooo`3o0?ooof<0oooo000h0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0
1P3oool00`3ookl0M000001d_`3o0?ooofL0oooo000i0?ooo`030?oOW0180000M;oo0080oooo00<0
gia8001d_`3oool01`3oool00`3ogi`0B00004RLg`3o0?ooofH0oooo000j0?ooo`060=nLB00007@0
_ooo0?oog`2LB000B9cO2@3oool0103ooml0W4P00000M02ooooo0?ooof@0oooo000k0?ooo`040=nL
B00000000000001d_``0oooo00@0oono07@000000000B9cOo`3ooomR0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.548894, -1.10239, \
0.00201372, 0.00296558}}]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Damping", "Subsection"],

Cell[TextData[{
  "When ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] > 0\)]],
  ", damping removes energy from the system such that without a driving force \
oscillations gradually decay away and the phase diagram becomes an inward \
spiral."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(duffingPlot[1, 0, 0.1, 0, 0, 1, 0, 0, 30];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.425433 0.550758 0.574542 0.638513 [
[.01236 -0.0125 -16.8438 -15.6875 ]
[.01236 -0.0125 16.8438 0 ]
[.15005 -0.0125 -13.8438 -15.6875 ]
[.15005 -0.0125 13.8438 0 ]
[.28774 -0.0125 -16.8438 -15.6875 ]
[.28774 -0.0125 16.8438 0 ]
[.42543 -0.0125 -5 -15.6875 ]
[.42543 -0.0125 5 0 ]
[.56312 -0.0125 -12.5 -15.6875 ]
[.56312 -0.0125 12.5 0 ]
[.70081 -0.0125 -9.5 -15.6875 ]
[.70081 -0.0125 9.5 0 ]
[.8385 -0.0125 -12.5 -15.6875 ]
[.8385 -0.0125 12.5 0 ]
[.97619 -0.0125 -5 -15.6875 ]
[.97619 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.9688 -31.375 ]
[.5 -0.0125 21.9688 -15.6875 ]
[-0.0125 .06373 -27.6875 -7.84375 ]
[-0.0125 .06373 0 7.84375 ]
[-0.0125 .19143 -27.9375 -7.84375 ]
[-0.0125 .19143 0 7.84375 ]
[-0.0125 .31914 -27.6875 -7.84375 ]
[-0.0125 .31914 0 7.84375 ]
[-0.0125 .44684 -27.6875 -7.84375 ]
[-0.0125 .44684 0 7.84375 ]
[-0.0125 .57454 -10 -7.84375 ]
[-0.0125 .57454 0 7.84375 ]
[-0.0125 .70224 -19 -7.84375 ]
[-0.0125 .70224 0 7.84375 ]
[-0.0125 .82995 -19 -7.84375 ]
[-0.0125 .82995 0 7.84375 ]
[-0.0125 .95765 -19.25 -7.84375 ]
[-0.0125 .95765 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -43.625 -20.4688 ]
[-0.01875 .5 -27.9375 20.4688 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -43.9375 0 ]
[.5 1.0125 43.9375 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01236 0 m
.01236 .00625 L
s
gsave
.01236 -0.0125 -77.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.15005 0 m
.15005 .00625 L
s
gsave
.15005 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.28774 0 m
.28774 .00625 L
s
gsave
.28774 -0.0125 -77.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.42543 0 m
.42543 .00625 L
s
gsave
.42543 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.56312 0 m
.56312 .00625 L
s
gsave
.56312 -0.0125 -73.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.70081 0 m
.70081 .00625 L
s
gsave
.70081 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.8385 0 m
.8385 .00625 L
s
gsave
.8385 -0.0125 -73.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.0399 0 m
.0399 .00375 L
s
.06744 0 m
.06744 .00375 L
s
.09498 0 m
.09498 .00375 L
s
.12252 0 m
.12252 .00375 L
s
.17759 0 m
.17759 .00375 L
s
.20513 0 m
.20513 .00375 L
s
.23267 0 m
.23267 .00375 L
s
.26021 0 m
.26021 .00375 L
s
.31528 0 m
.31528 .00375 L
s
.34282 0 m
.34282 .00375 L
s
.37036 0 m
.37036 .00375 L
s
.3979 0 m
.3979 .00375 L
s
.45297 0 m
.45297 .00375 L
s
.48051 0 m
.48051 .00375 L
s
.50805 0 m
.50805 .00375 L
s
.53558 0 m
.53558 .00375 L
s
.59066 0 m
.59066 .00375 L
s
.6182 0 m
.6182 .00375 L
s
.64574 0 m
.64574 .00375 L
s
.67327 0 m
.67327 .00375 L
s
.72835 0 m
.72835 .00375 L
s
.75589 0 m
.75589 .00375 L
s
.78343 0 m
.78343 .00375 L
s
.81096 0 m
.81096 .00375 L
s
.86604 0 m
.86604 .00375 L
s
.89358 0 m
.89358 .00375 L
s
.92111 0 m
.92111 .00375 L
s
.94865 0 m
.94865 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.9688 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
102.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .06373 m
.00625 .06373 L
s
gsave
-0.0125 .06373 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .19143 m
.00625 .19143 L
s
gsave
-0.0125 .19143 -88.9375 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .31914 m
.00625 .31914 L
s
gsave
-0.0125 .31914 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .44684 m
.00625 .44684 L
s
gsave
-0.0125 .44684 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .57454 m
.00625 .57454 L
s
gsave
-0.0125 .57454 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .70224 m
.00625 .70224 L
s
gsave
-0.0125 .70224 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .82995 m
.00625 .82995 L
s
gsave
-0.0125 .82995 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .95765 m
.00625 .95765 L
s
gsave
-0.0125 .95765 -80.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .09566 m
.00375 .09566 L
s
0 .12758 m
.00375 .12758 L
s
0 .15951 m
.00375 .15951 L
s
0 .22336 m
.00375 .22336 L
s
0 .25529 m
.00375 .25529 L
s
0 .28721 m
.00375 .28721 L
s
0 .35106 m
.00375 .35106 L
s
0 .38299 m
.00375 .38299 L
s
0 .41491 m
.00375 .41491 L
s
0 .47877 m
.00375 .47877 L
s
0 .51069 m
.00375 .51069 L
s
0 .54262 m
.00375 .54262 L
s
0 .60647 m
.00375 .60647 L
s
0 .63839 m
.00375 .63839 L
s
0 .67032 m
.00375 .67032 L
s
0 .73417 m
.00375 .73417 L
s
0 .7661 m
.00375 .7661 L
s
0 .79802 m
.00375 .79802 L
s
0 .86187 m
.00375 .86187 L
s
0 .8938 m
.00375 .8938 L
s
0 .92572 m
.00375 .92572 L
s
0 .03181 m
.00375 .03181 L
s
0 .98958 m
.00375 .98958 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -117.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
81.4688 11.8438 translate
90 rotate
-81.4688 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(velocity) show
99.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01236 .99375 m
.01236 1 L
s
.15005 .99375 m
.15005 1 L
s
.28774 .99375 m
.28774 1 L
s
.42543 .99375 m
.42543 1 L
s
.56312 .99375 m
.56312 1 L
s
.70081 .99375 m
.70081 1 L
s
.8385 .99375 m
.8385 1 L
s
.97619 .99375 m
.97619 1 L
s
.125 Mabswid
.0399 .99625 m
.0399 1 L
s
.06744 .99625 m
.06744 1 L
s
.09498 .99625 m
.09498 1 L
s
.12252 .99625 m
.12252 1 L
s
.17759 .99625 m
.17759 1 L
s
.20513 .99625 m
.20513 1 L
s
.23267 .99625 m
.23267 1 L
s
.26021 .99625 m
.26021 1 L
s
.31528 .99625 m
.31528 1 L
s
.34282 .99625 m
.34282 1 L
s
.37036 .99625 m
.37036 1 L
s
.3979 .99625 m
.3979 1 L
s
.45297 .99625 m
.45297 1 L
s
.48051 .99625 m
.48051 1 L
s
.50805 .99625 m
.50805 1 L
s
.53558 .99625 m
.53558 1 L
s
.59066 .99625 m
.59066 1 L
s
.6182 .99625 m
.6182 1 L
s
.64574 .99625 m
.64574 1 L
s
.67327 .99625 m
.67327 1 L
s
.72835 .99625 m
.72835 1 L
s
.75589 .99625 m
.75589 1 L
s
.78343 .99625 m
.78343 1 L
s
.81096 .99625 m
.81096 1 L
s
.86604 .99625 m
.86604 1 L
s
.89358 .99625 m
.89358 1 L
s
.92111 .99625 m
.92111 1 L
s
.94865 .99625 m
.94865 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .06373 m
1 .06373 L
s
.99375 .19143 m
1 .19143 L
s
.99375 .31914 m
1 .31914 L
s
.99375 .44684 m
1 .44684 L
s
.99375 .57454 m
1 .57454 L
s
.99375 .70224 m
1 .70224 L
s
.99375 .82995 m
1 .82995 L
s
.99375 .95765 m
1 .95765 L
s
.125 Mabswid
.99625 .09566 m
1 .09566 L
s
.99625 .12758 m
1 .12758 L
s
.99625 .15951 m
1 .15951 L
s
.99625 .22336 m
1 .22336 L
s
.99625 .25529 m
1 .25529 L
s
.99625 .28721 m
1 .28721 L
s
.99625 .35106 m
1 .35106 L
s
.99625 .38299 m
1 .38299 L
s
.99625 .41491 m
1 .41491 L
s
.99625 .47877 m
1 .47877 L
s
.99625 .51069 m
1 .51069 L
s
.99625 .54262 m
1 .54262 L
s
.99625 .60647 m
1 .60647 L
s
.99625 .63839 m
1 .63839 L
s
.99625 .67032 m
1 .67032 L
s
.99625 .73417 m
1 .73417 L
s
.99625 .7661 m
1 .7661 L
s
.99625 .79802 m
1 .79802 L
s
.99625 .86187 m
1 .86187 L
s
.99625 .8938 m
1 .8938 L
s
.99625 .92572 m
1 .92572 L
s
.99625 .03181 m
1 .03181 L
s
.99625 .98958 m
1 .98958 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .57454 m
1 .57454 L
s
.42543 0 m
.42543 1 L
s
gsave
.5 1.0125 -104.938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Duffing) show
102.938 15.813 moveto
(Equation) show
146.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.97619 .57454 m
.97581 .55099 L
.97482 .52974 L
.97291 .50545 L
.97036 .48276 L
.96406 .44314 L
.95473 .40134 L
.94154 .35701 L
.92438 .31221 L
.88591 .23831 L
.8369 .17199 L
.78366 .1201 L
.75047 .09517 L
.71865 .07553 L
.68049 .05672 L
.64304 .04275 L
.6232 .03699 L
.60433 .03252 L
.58726 .02929 L
.56871 .02663 L
.55901 .02559 L
.54834 .02471 L
.53719 .0241 L
.52678 .02381 L
.50812 .02395 L
.49767 .02439 L
.48815 .02503 L
.46968 .02689 L
.45265 .02934 L
.43407 .03283 L
.41448 .03743 L
.38203 .04718 L
.347 .06082 L
.27363 .10088 L
.23527 .12896 L
.20228 .15787 L
.1477 .21809 L
.10002 .28947 L
.08134 .32526 L
.06604 .36002 L
.05414 .39224 L
.04366 .42682 L
.03475 .46481 L
.02887 .49993 L
.02657 .51942 L
.02505 .53759 L
.02444 .54797 L
.02406 .55743 L
.02383 .56831 L
.02381 .57859 L
Mistroke
.0242 .59549 L
.02502 .61067 L
.02649 .62801 L
.0284 .64413 L
.03302 .67237 L
.03975 .70201 L
.04921 .73363 L
.06141 .76546 L
.08854 .81797 L
.12488 .86754 L
.16333 .90522 L
.18646 .92279 L
.21284 .93913 L
.23653 .95089 L
.26343 .96128 L
.27558 .96501 L
.28877 .96843 L
.30026 .97088 L
.31288 .97303 L
.32644 .97471 L
.34074 .9758 L
.35401 .97619 L
.36634 .97602 L
.37888 .97534 L
.39067 .97421 L
.40123 .97281 L
.41261 .97089 L
.43793 .96503 L
.46086 .9578 L
.50842 .9366 L
.53377 .92152 L
.55589 .90592 L
.59615 .87059 L
.62909 .83304 L
.66145 .78468 L
.6755 .75811 L
.68878 .72781 L
.69775 .7028 L
.70562 .67546 L
.70915 .66029 L
.71189 .64635 L
.71416 .63227 L
.71585 .61899 L
.71708 .60607 L
.71794 .59212 L
.7183 .57952 L
.71827 .56796 L
.71787 .55556 L
.71697 .54205 L
.71633 .53531 L
Mistroke
.71552 .52811 L
.71372 .51524 L
.70897 .49084 L
.70299 .46846 L
.68807 .42892 L
.67752 .408 L
.66478 .38718 L
.63832 .35392 L
.62013 .33642 L
.60181 .32205 L
.58315 .31017 L
.56504 .30092 L
.54809 .29407 L
.52953 .28839 L
.5188 .28592 L
.50856 .28411 L
.49932 .2829 L
.48925 .28204 L
.47941 .28166 L
.47381 .28165 L
.46856 .28176 L
.46304 .28202 L
.45799 .28237 L
.45246 .2829 L
.44665 .2836 L
.43697 .28511 L
.42802 .28689 L
.40796 .29225 L
.38968 .29883 L
.37288 .3064 L
.34286 .32387 L
.31307 .34712 L
.28437 .3768 L
.26022 .40984 L
.2418 .44334 L
.22651 .48205 L
.22028 .50431 L
.21608 .52478 L
.21451 .53512 L
.2138 .54078 L
.21323 .5461 L
.21241 .55642 L
.21198 .56572 L
.21186 .57111 L
.21185 .57676 L
.2121 .58681 L
.2124 .59236 L
.21277 .59751 L
.21329 .60311 L
.21397 .60907 L
Mistroke
.21538 .61892 L
.21732 .62943 L
.22187 .64799 L
.22754 .66529 L
.23381 .68052 L
.249 .70832 L
.26902 .73417 L
.29086 .75426 L
.31287 .76871 L
.32695 .77554 L
.34041 .78058 L
.34815 .78286 L
.35551 .78463 L
.36407 .78623 L
.36779 .78677 L
.37188 .78726 L
.37896 .78785 L
.38645 .78813 L
.39339 .78807 L
.39987 .78774 L
.40749 .78702 L
.41442 .78605 L
.42237 .78457 L
.42984 .7828 L
.4431 .77877 L
.45528 .77402 L
.4818 .75987 L
.50549 .74205 L
.52808 .71902 L
.54501 .69606 L
.55954 .66982 L
.56909 .64623 L
.57329 .63256 L
.57641 .61972 L
.57784 .61232 L
.57908 .60449 L
.57992 .59781 L
.58059 .59048 L
.58086 .58639 L
.58104 .58265 L
.58116 .57835 L
.58119 .57429 L
.58106 .56713 L
.58088 .5631 L
.58064 .55939 L
.57998 .55219 L
.57912 .5455 L
.57694 .53327 L
.57375 .52052 L
.56936 .50734 L
Mistroke
.55935 .48571 L
.5533 .47578 L
.54596 .46568 L
.53133 .45 L
.51607 .43811 L
.50619 .43223 L
.49671 .42773 L
.48601 .42384 L
.48052 .4223 L
.4744 .42092 L
.46902 .41999 L
.46406 .41937 L
.45861 .41895 L
.45586 .41883 L
.45285 .41877 L
.44777 .41886 L
.44234 .4192 L
.43724 .41975 L
.43262 .42044 L
.42778 .42136 L
.42269 .42255 L
.41368 .42522 L
.40419 .42885 L
.39407 .4337 L
.3769 .44449 L
.36222 .4568 L
.34734 .47316 L
.33382 .49319 L
.32865 .50296 L
.32388 .51365 L
.32039 .52309 L
.31728 .53342 L
.31496 .54342 L
.31415 .54781 L
.31339 .55262 L
.31285 .55686 L
.3124 .56139 L
.31207 .56616 L
.3119 .57058 L
.31185 .5758 L
.3119 .57873 L
.312 .58142 L
.31231 .58633 L
.3128 .59147 L
.3134 .596 L
.31408 .6002 L
.31608 .60953 L
.31887 .61905 L
.32203 .62748 L
.32649 .63695 L
Mistroke
.33115 .64497 L
.34117 .65824 L
.34744 .66465 L
.35359 .6699 L
.36599 .67803 L
.37289 .68136 L
.38038 .68416 L
.38358 .68512 L
.38704 .686 L
.39004 .68663 L
.39334 .6872 L
.39721 .68769 L
.40089 .68799 L
.40449 .68813 L
.40781 .68811 L
.41145 .68795 L
.41526 .68761 L
.41851 .68719 L
.42204 .68659 L
.42986 .68473 L
.43699 .68237 L
.44948 .67662 L
.46193 .66856 L
.47525 .65669 L
.48604 .64358 L
.49405 .6306 L
.49756 .62346 L
.50079 .61559 L
.50337 .60783 L
.50526 .60066 L
.506 .5972 L
.50669 .59342 L
.50723 .58988 L
.50763 .58655 L
.50783 .58452 L
.508 .58233 L
.5082 .57853 L
.50825 .57638 L
.50827 .57412 L
.50824 .5722 L
.50818 .57011 L
.50796 .56638 L
.50779 .56431 L
.50759 .56243 L
.50657 .55546 L
.50583 .55178 L
.5049 .54794 L
.50287 .54128 L
.5002 .53445 L
.4967 .52738 L
Mistroke
.49324 .52173 L
.4891 .51611 L
.48063 .50731 L
.47587 .50353 L
.47053 .50006 L
.46572 .49753 L
.46036 .49531 L
.457 .4942 L
.45387 .49337 L
.45085 .49273 L
.4493 .49246 L
.44764 .49222 L
.44474 .49191 L
.44203 .49175 L
.44037 .49171 L
.4388 .49171 L
.43585 .49183 L
.43327 .49204 L
.43043 .4924 L
.42748 .49292 L
.42472 .49352 L
.41987 .49491 L
.41474 .49681 L
.40921 .4994 L
.40361 .50264 L
.39429 .50966 L
.38604 .51802 L
.37959 .5266 L
.37352 .53738 L
.37126 .54257 L
.36925 .54817 L
.36783 .55303 L
.3666 .55842 L
.36617 .56079 L
.36579 .56333 L
.3655 .56571 L
.36529 .56792 L
.36512 .57065 L
.36506 .57209 L
.36503 .57362 L
.36505 .57643 L
.36515 .57895 L
.36532 .58139 L
.36559 .584 L
.36592 .58644 L
.3663 .58865 L
.36741 .59366 L
.36871 .59806 L
.37041 .6026 L
.37258 .60728 L
Mistroke
.37722 .61483 L
.38245 .621 L
.38946 .6269 L
.39329 .62928 L
.39769 .63143 L
.40155 .63286 L
.40361 .63347 L
.40581 .63399 L
.40775 .63436 L
.40988 .63466 L
.41183 .63484 L
.41365 .63493 L
.41575 .63495 L
.4168 .63492 L
.41797 .63485 L
.42002 .63467 L
.42193 .63442 L
.42417 .63402 L
.4262 .63356 L
.4307 .63221 L
.43448 .63069 L
.43846 .62869 L
.4453 .62419 L
.45128 .61889 L
.45685 .61239 L
.46125 .60559 L
.46445 .59903 L
.466 .59499 L
.46719 .59116 L
.46817 .58713 L
.4686 .58485 L
.46893 .58269 L
.46915 .58086 L
.46933 .57887 L
.46943 .57707 L
.46948 .57542 L
.46948 .57364 L
.46942 .57171 L
.46928 .5697 L
.4691 .56784 L
.46883 .56586 L
.46846 .56374 L
.46758 .55996 L
.46647 .55644 L
.46524 .55332 L
.46175 .54684 L
.45942 .54363 L
.4571 .54099 L
.45237 .53686 L
.4498 .53516 L
Mistroke
.44686 .53359 L
.44426 .5325 L
.44281 .532 L
.44141 .53159 L
.4401 .53127 L
.43867 .53098 L
.43736 .53078 L
.43615 .53064 L
.43473 .53053 L
.43319 .53049 L
.43174 .53051 L
.43041 .53059 L
.42894 .53074 L
.42811 .53086 L
.42734 .53098 L
.42569 .53131 L
.42415 .53169 L
.42102 .5327 L
.41825 .53386 L
.41238 .53728 L
.40791 .54091 L
.40357 .54558 L
.39978 .55109 L
.39825 .5539 L
.39699 .55666 L
.39598 .55925 L
.39507 .56211 L
.3944 .56476 L
.39393 .56718 L
.3937 .56866 L
.39354 .57005 L
.39341 .57151 L
.39336 .57233 L
.39333 .57309 L
.39331 .57434 L
.39332 .57571 L
.39339 .57713 L
.39349 .57844 L
.39365 .57987 L
.39387 .58138 L
.3944 .58401 L
.39517 .58674 L
.39623 .5896 L
.39731 .59193 L
.39865 .59428 L
.40148 .59807 L
.40471 .60119 L
.40647 .6025 L
.40848 .60373 L
.41027 .60462 L
Mistroke
.41224 .6054 L
.41414 .60596 L
.41499 .60615 L
.41589 .60633 L
.4167 .60645 L
.41761 .60656 L
.41843 .60662 L
.4192 .60666 L
.42011 .60667 L
.42094 .60664 L
.4219 .60658 L
.4228 .60649 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00g03oool00`3ooml0W4P0000000020000000307Bo
o`3oool0oooo0<`0oooo003N0?ooo`030?noM00007@0_ooo0<l0oooo003N0?ooo`030?oo_`1d0000
M;oo0<l0oooo003N0?ooo`030?oog`2LB000B9cO0<l0oooo003O0?ooo`030=nLB000000000000080
000000<0M;oo0?ooo`3oool00P3oool01@3o_g@000000000000004P0W=oo0080oooo00<0oono07@0
000000000P0000003@18W=l0oooo0?ooo`3oool0_g@00000000004P0W=oo0?ooo`3o_g@000000000
B02Lgol00P3oool0102oM00000000000B02Lgol20?ooo`050?noM000000000000000B02Lgol00`3o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000000007Bo09H0oooo003O0?ooo`070?noM00004P0
W=oo0?ooo`3ooml0W4P0001d_`020?ooo`0?0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`3oool0
oooO09a8001d_ol0oooo0?oOW0180000M;oo0080oooo01L0gia80018W03Ooml0W7BL0=ooo`3o_g@0
001809cOg`2LM9`0gooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0
B000001d_`020?ooo`030?noM00007@0_ooo0080oooo00@0gia80018W03O_g@0M;ooU@3oool00=l0
oooo00<0oono07@0001d_ol00P3oool01`3ooml0W4P004RLg`3oool0gia80018W03Oool00P3oool0
2P3ogi`0B00004RLg`3oool0_gAd0;ooo`3oool0oono07@0001d_ol20?ooo`030?noM00004P0W=oo
0080oooo00<0oono07@0001d_ol00`3oool00`3o_g@0001809cOo`020?ooo`030=nLB000B9`0gooo
0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol0UP3o
ool00=l0oooo00<0oooO09a80018W=l00`3oool01P3ogi`0B01809cOo`3o_g@0001d0;ooo`<0oooo
00<0gia80000M02oool00`3oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo
00<0_g@0001d_`3oool00P3oool00`3ookl0M00004RLg`020?ooo`030?noM00007@0_ooo00<0oooo
00/0gia80000M02oool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`2F0?ooo`00h03oool0
0`3OW4P0001d0;ooo`020?ooo`060?oog`2LB000B9cO0?oo_`1d0000M;oo0`3oool00`3ogi`0B018
09cOo`020?ooo`030?noM00004P0W=oo00@0oooo00<0_g@00018W03Oool00P3oool00`3OW4P004RL
0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3ookl0M00007Boo`030?ooo`070?oOW01804P0W=oo
0?ooo`3OW4P004Q804Qd_`020?ooo`030;md0000M;l0oooo09D0oooo003P0?ooo`040?noM0000000
04RL0=ooo`80oooo00H0gia8001d_`3oool0gia80000M02oool20?ooo`0:0?oo_`1d0000M;oo0?oo
o`3ogi`0B01809cOo`3oool0giad09cOo`80oooo00<0gia80000B02Lgol00P3oool00`3ogi`0B018
09cOo`030?ooo`030=nLB00004P0W=oo0080oooo00<0gia80000M02oool00P3oool0303ookl0M000
07Boo`3oool0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;oooiD0oooo003P0?ooo`080?oo_`1d
0000M9bL04P0M02oool0oooO09a80000M;l20?ooo`0>0;md000007@0_ooo0?ooo`3o_g@0001d0;oo
o`3oool0omnL04P0B02Lgol0oooO09a8001d_ol20?ooo`030?oOW0180000B9cO0080oooo00<0oooO
09a80018W=l00`3oool00`3ogi`0B00004RLg`030?ooo`0@0;md000007@0_ooo0?ooo`3o_g@0001d
0;ooo`3oool0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOoiD0oooo003O0?ooo`090?oOW018
0000000004RLg`3ookl0M0000000000007@0_ooo00<0oooo00D0okmd000000000000000007Boo`03
0?ooo`070;md00000000000000000018W=l0oooo0?noM002000000040018W03Oool0oono07@000<0
000000H0M;oo0?noM000000000000018W03Oool30?ooo`0?0?noM000000000000000001d_ol0oooo
0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo09D0oooo003o0?ooo`40oooo00<0okmd
0000M02oool0[@3oool00?l0oooo0P3oool00`3OW7@0W=oo0?ooo`2/0?ooo`00n`3oool0103ookl0
M0000018W03Oool70?ooo`040?oo_`1d000004RL0=ooojH0oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo00180?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol0
0`3oool00`3ookl0M4RL0=ooo`050?ooo`060?oOW0180000000000000000B9`0gooo6P3oool0102o
M00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00H0omnL04P00000000000000018
W03OoolJ0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P0
0000000000030000000504RLg`3oool0oooo0?oOW01800000P0000000`00B9`0gooo0?ooo`0I0?oo
o`040;md00000000000007Boob40oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Bo
o`020?ooo`030=nLB0000000000000<0000000D0B9cO0?ooo`3oool0omnL04P00002000000030018
W03Oool0oooo01T0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`06
0?oOW0180000000000000000B9`0gooo6P3oool0102oM00000000000001d_ol30?ooo`030?oOW018
0000M;oo00<0oooo00<0oono07A8W03Oool01@3oool01P3ogi`0B00000000000000004RL0=oooal0
oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`0:0?ooo`00A`3oool01P3OW4P007Bo
0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol0103oool00`3OW4P0B9cO0?ooo`040?oo
o`060?noM0000000M;oo0?ooo`3ogi`0B7Bo6@3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80
oooo00<0omnL04P0001d_ol00P3oool01P3o_g@0000007Boo`3oool0omnL04Qd_aT0oooo00H0gia8
001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00<0oooo00<0okmd001d_`3oool0
0P3oool02@2oM7@0_ooo0?ooo`3o_g@0000007Boo`3oool0omnL04Qd_`0I0?ooo`060=nLB000M;l0
oooo0?oOW0180000B9cO7`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0
001d_ol00`3oool00`3o_g@007Bo0?ooo`020?ooo`090;mdM02oool0oooo0?noM0000000M;oo0?oo
o`3ogi`0B7Bo01T0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo
0080oooo00H0okmd0000001d_ol0oooo0?oOW018M;lI0?ooo`060=nLB000M;l0oooo0?oOW0180000
B9cO0P3oool00`3ogi`0B00007Boo`040?ooo`030=nLB018W=l0oooo00@0oooo00H0okmd0000001d
_ol0oooo0?oOW018M;lQ0?ooo`030?noM0000000M;oo00d0oooo00160?ooo`030?oog`2LB000B9cO
0080oooo00<0okmd0000B02Lgol0203oool00`3ookl0M01d0;ooo`090?ooo`030?noM018W=l0oooo
01H0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`0;0?ooo`030?noM018W=l0oooo
01H0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?noM000M;l0oooo
00T0oooo00<0okmd04RLg`3oool05P3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo
01d0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?noM000M;l0oooo
00T0oooo00<0okmd04RLg`3oool05P3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo
00/0oooo00<0okmd04RLg`3oool05P3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo
00P0oooo00<0oono07@0M02oool02@3oool00`3o_g@0B9cO0?ooo`0O0?ooo`030?oog`2LB00007Bo
00d0oooo00160?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo203oool00`3o
_g@007Bo0?ooo`080?ooo`030?oo_`1d07@0_ooo01H0oooo00<0oooO09a80018W=l00P3oool0103o
oml0W4P00018W03Oool:0?ooo`030?oo_`1d07@0_ooo01H0oooo00<0oooO09a80018W=l00P3oool0
103ooml0W4P00018W03Oool80?ooo`030?noM000M;l0oooo00P0oooo00<0oono07@0M02oool05P3o
ool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=oooa`0oooo00<0oooO09a80018W=l0
0P3oool0103ooml0W4P00018W03Oool80?ooo`030?noM000M;l0oooo00P0oooo00<0oono07@0M02o
ool05P3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`X0oooo00<0oono07@0
M02oool05P3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<0okmd
001d_`3oool0203oool00`3ookl0M01d0;ooo`0P0?ooo`030=nLB000B9`0gooo00`0oooo000i0?oo
o`030?oog`2LB000000000L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`030=nLB000
04P0W=oo00P0oooo00<0oooO09a8B02Lgol0203oool00`3ooml0W4P007Boo`090?ooo`030?oog`2L
B000000000L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`030=nLB00004P0W=oo00X0
oooo00<0oooO09a8001d_ol02@3oool00`3ooml0W4P0000000070000000604RLg`3oool0oooo0?oo
g`2LB00007Bo0`3oool00`3OW4P0001809cOo`090?ooo`030?noM018W=l0oooo00L0oooo00<0oooO
09a8001d_ol05P3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo01`0oooo00<0oooO
09a80000M;l00`3oool00`3OW4P0001809cOo`090?ooo`030?noM018W=l0oooo00L0oooo00<0oooO
09a8001d_ol05P3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00X0oooo00<0oooO
09a8001d_ol05P3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00P0oooo00<0oooO
09a8B02Lgol0203oool00`3ooml0W4P007Boo`0P0?ooo`030?oOW01804P0W=oo00`0oooo00170?oo
o`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l02@3oool00`3ogi`0B7Bo0?ooo`070?oo
o`030?oo_`1d0000B9cO01L0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?oo
o`030?oo_`1d0000B9cO01L0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?oo
o`030=nLB018W=l0oooo00H0oooo00<0oono07@00018W=l05`3oool00`2oM00004RL0=ooo`020?oo
o`030?oOW0180000B9cO01d0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?oo
o`030=nLB018W=l0oooo00H0oooo00<0oono07@00018W=l05`3oool00`2oM00004RL0=ooo`020?oo
o`030?oOW0180000B9cO00X0oooo00<0oono07@00018W=l05`3oool00`2oM00004RL0=ooo`020?oo
o`030?oOW0180000B9cO00T0oooo00<0omnL04Qd_`3oool01`3oool00`3ookl0M00004RLg`0P0?oo
o`030?oo_`1d0000M;oo00`0oooo00170?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000
M;l02P3oool00`2oM000M;oo0?ooo`060?ooo`030?noM0000000M;oo01L0oooo00<0gia80000B02L
gol00P3oool00`3ooml0W4P0001d_`0:0?ooo`030?noM0000000M;oo01L0oooo00<0gia80000B02L
gol00P3oool00`3ooml0W4P0001d_`0;0?ooo`030;md001d_ol0oooo00D0oooo00<0okmd0000001d
_ol05`3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo01d0oooo00<0gia80000B02L
gol00P3oool00`3ooml0W4P0001d_`0;0?ooo`030;md001d_ol0oooo00D0oooo00<0okmd0000001d
_ol05`3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00X0oooo00<0okmd0000001d
_ol05`3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00X0oooo00<0_g@007Boo`3o
ool01P3oool00`3o_g@0000007Boo`0Q0?ooo`030;md0000M;l0oooo00/0oooo00170?ooo`030?oO
W0180000B9cO00<0oooo00<0_g@00018W03Oool02@3oool00`3ogi`0B4RL0=ooo`030?ooo`060?oO
g`3Oool0okmd0000000007@0_ooo5`3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo
00H0oooo00H0omoO0=ooo`3o_g@000000000M02ooolG0?ooo`030?oOW0180000B9cO00<0oooo00<0
_g@00018W03Oool02P3oool00`3ogi`0B01d0;ooo`020?ooo`060?oOg`3Oool0okmd0000000007@0
_ooo5`3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo01`0oooo00<0omnL04P00018
W=l00`3oool00`2oM00004RL0=ooo`0:0?ooo`030?oOW01807@0_ooo0080oooo00H0omoO0=ooo`3o
_g@000000000M02ooolG0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01P3oool0
1P3ogml0gooo0?noM0000000001d0;oooaL0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL
0=ooo`090?ooo`030?oOW018B9`0gooo00<0oooo00H0omoO0=ooo`3o_g@000000000M02ooolQ0?oo
o`030=nLB000B9`0gooo00/0oooo00170?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018
W03Oool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`050?oo_`1d000000000000B02Lgol0603oool0
103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00H0oooo00D0oono07@0000000000018
09cOo`0H0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool02P3oool00`3ooml0
W4P007Boo`020?ooo`050?oo_`1d000000000000B02Lgol0603oool0103ooml0W4P00018W03Oool2
0?ooo`030=nLB000B9`0gooo01`0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=oo
o`0:0?ooo`030?oog`2LB000M;oo0080oooo00D0oono07@000000000001809cOo`0H0?ooo`040?oo
g`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool01P3oool01@3ookl0M0000000000004P0W=oo
01P0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`0:0?ooo`030=nLB018W=l0
oooo0080oooo00D0oono07@000000000001809cOo`0R0?ooo`030?oOW01804P0W=oo00/0oooo0018
0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01@3oool00`3ooml0gmoo0?ooo`02
0?ooo`030?oo_`1d07@0_ooo00<0oooo00<0gibL0;ooo`3oool06P3oool00`3ogi`0B00007Boo`02
0?ooo`030=nLB000M;l0oooo00L0oooo00<0gibL0;ooo`3oool06P3oool00`3ogi`0B00007Boo`02
0?ooo`030=nLB000M;l0oooo00X0oooo00<0oono07@00018W=l00`3oool00`3OW9`0_ooo0?ooo`0J
0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool07@3oool00`3ogi`0B00007Boo`02
0?ooo`030=nLB000M;l0oooo00X0oooo00<0oono07@00018W=l00`3oool00`3OW9`0_ooo0?ooo`0J
0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01`3oool00`3OW9`0_ooo0?ooo`0J
0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01@3oool00`3ooml0gmoo0?ooo`02
0?ooo`030?oo_`1d07@0_ooo00<0oooo00<0gibL0;ooo`3oool08`3oool00`3ookl0M00007Boo`0;
0?ooo`00B@3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`L0oooo00<0_gAd0;ooo`3oool00P3o
ool00`3o_g@007Bo0?ooo`020?ooo`030?oOW01dW=l0oooo01/0oooo00H0gia80000M02oool0oooO
09a80018W=l80?ooo`030?oOW01dW=l0oooo01/0oooo00H0gia80000M02oool0oooO09a80018W=l7
0?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cOo`030?ooo`030?oOW01dW=l0oooo01/0oooo
00H0gia80000M02oool0oooO09a80018W=lO0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO1`3o
ool01`3o_g@004RL0=ooo`3oool0gia80000B02Lgol00`3oool00`3ogi`0M9cO0?ooo`0K0?ooo`06
0=nLB00007@0_ooo0?oog`2LB000B9cO203oool00`3ogi`0M9cO0?ooo`0K0?ooo`060=nLB00007@0
_ooo0?oog`2LB000B9cO1`3oool00`2oM7@0_ooo0?ooo`020?ooo`030?noM000M;l0oooo0080oooo
00<0omnL07BLg`3oool0903oool00`2oM00007Bo0?ooo`0:0?ooo`00BP3oool0103OW4P000000000
0000M;l80?ooo`030?oo_`1d0000000000<0000000<0001809cOo`3oool00P3oool01@2oM0000000
000000000000B9cO01T0oooo00@0gia800000000000007Bo2P3oool01@2oM0000000000000000000
B9cO01T0oooo00@0gia800000000000007Bo2@3oool01@3ogi`0B000000000000000M;oo00D0oooo
00D0_g@0000000000000000004RLg`0I0?ooo`040=nLB00000000000001d_b40oooo00@0gia80000
0000000007Bo2@3oool01@3ogi`0B000000000000000M;oo00D0oooo00D0_g@00000000000000000
04RLg`0I0?ooo`040=nLB00000000000001d_`X0oooo00D0_g@0000000000000000004RLg`0I0?oo
o`040=nLB00000000000001d_`P0oooo00<0oono07@0000000000`0000000`0004P0W=oo0?ooo`02
0?ooo`050;md00000000000000000018W=l07`3oool01@3ookl0M0000000000007@0_ooo00X0oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo001;0?ooool00000
HP0000040?ooo`00B`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo001;0?ooo`050000003o
ool0oooo0?ooo`000000<03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0<L0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`370?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3o
ool0a`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`2C0?ooo`030000
003oool0oooo0<L0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0T`3o
ool00`000000oooo0?ooo`0I0?ooo`d00000X@3oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`2C0?ooo`030000003oool0oooo00X0oooo3`00000=0?ooo`d00000U03oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
00D0oooo1@00000Y0?ooo`H00000SP3oool00`000000oooo0?ooo`020?ooo`00B`3oool2000009@0
oooo00<000000?ooo`3oool00P3oool3000003@0oooo1@0000270?ooo`<00000103oool004/0oooo
00<000000?ooo`3oool0T`3oool5000003`0oooo0`0000260?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo08h0oooo1P0000130?ooo`<00000P`3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`2;0?ooo`<000001@3oool00`000000oooo0?ooo`14
0?ooo`@00000O`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`280?oo
o`<00000203oool00`000000oooo0?ooo`180?ooo`<00000O03oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`250?ooo`<000002`3oool00`000000oooo0?ooo`1;0?ooo`80
0000NP3oool00`000000oooo0?ooo`020?ooo`00;`3oool0102oM00000000000001d_ol30?ooo`03
0?oOW0180000M;oo00<0oooo00H0oono07@00000000000000018W03Oool90?ooo`030000003oool0
oooo0880oooo0`00000>0?ooo`030000003oool0oooo04d0oooo0`00001g0?ooo`030000003oool0
oooo0080oooo000^0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Bo
o`020?ooo`030?oo_`1d0000B9cO0080oooo00<0gia80000M02oool0203oool00`000000oooo0?oo
o`1o0?ooo`<000004@3oool00`000000oooo0?ooo`1@0?ooo`<00000M03oool00`000000oooo0?oo
o`020?ooo`00;@3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00H0oooo00<0okmd
0018W03Oool00`3oool00`2oM000B9cO0?ooo`070?ooo`030000003oool0oooo07`0oooo0`00000D
0?ooo`030000003oool0oooo05<0oooo0P00001b0?ooo`030000003oool0oooo0080oooo000]0?oo
o`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo1@3oool00`3o_g@004RL0=ooo`03
0?ooo`030;md0000M;l0oooo00L0oooo00<000000?ooo`3oool0N@3oool3000001L0oooo00<00000
0?ooo`3oool0E@3oool200000700oooo00<000000?ooo`3oool00P3oool00200oooo00<0oooO09a8
000000001`0000001P18W=l0oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol01@3o
ool00`3ooml0W4P007Boo`020?ooo`030?oo_`1d0000B9cO00P0oooo00<000000?ooo`3oool0M`3o
ool2000001X0oooo00<000000?ooo`3oool0E`3oool2000006h0oooo00<000000?ooo`3oool00P3o
ool002h0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`070?ooo`060;md000004P0
W=oO09a8000007@0_ooo203oool3000007D0oooo0P00000L0?ooo`030000003oool0oooo05T0oooo
0P00001Z0?ooo`<00000103oool002h0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d
_`080?ooo`050?oog`2LB00000000018W03Oool0203oool00`000000oooo0?ooo`1c0?ooo`800000
7P3oool00`000000oooo0?ooo`1K0?ooo`800000JP3oool00`000000oooo0?ooo`020?ooo`00;P3o
ool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00L0oooo00H0_g@00000B02Lgol0omnL
04Q8W03Oool70?ooo`030000003oool0oooo0740oooo0P00000P0?ooo`030000003oool0oooo05d0
oooo0P00001X0?ooo`030000003oool0oooo0080oooo000^0?ooo`040?oog`2LB00004RL0=ooo`80
oooo00<0gia80018W03Oool01P3oool00`3ogi`0B00007Boo`020?ooo`030?noM018W=l0oooo00H0
oooo00<000000?ooo`3oool0K`3oool200000280oooo00<000000?ooo`3oool0G`3oool2000006H0
oooo00<000000?ooo`3oool00P3oool002l0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo
0?ooo`060?ooo`030?oOW01804P0W=oo0080oooo00<0okmd0018W03Oool01P3oool00`000000oooo
0?ooo`1]0?ooo`800000903oool00`000000oooo0?ooo`1Q0?ooo`800000I03oool00`000000oooo
0?ooo`020?ooo`00<03oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`L0oooo00<0oooO09a80018
W=l00P3oool00`2oM00007Bo0?ooo`060?ooo`030000003oool0oooo06/0oooo0P00000V0?ooo`03
0000003oool0oooo06<0oooo0P00001R0?ooo`030000003oool0oooo0080oooo000a0?ooo`040=nL
B00000000000001d_`T0oooo00D0oooO09a8000000000000001d_`080?ooo`030000003oool0oooo
06X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1U0?ooo`800000H03oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1X0?ooo`800000:@3oool00`000000
oooo0?ooo`1W0?ooo`800000GP3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`1V0?ooo`800000:`3oool00`000000oooo0?ooo`1Y0?ooo`800000G03oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1T0?ooo`800000;@3oool00`000000oooo0?oo
o`1[0?ooo`800000FP3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1R
0?ooo`800000;`3oool00`000000oooo0?ooo`1]0?ooo`800000F03oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`1P0?ooo`800000<@3oool00`000000oooo0?ooo`1_0?oo
o`030000003oool0oooo05D0oooo00<000000?ooo`3oool00P3oool004/0oooo0P00001O0?ooo`80
0000<`3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0580oooo0`0000040?ooo`00
B`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
L@3oool2000005@0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0G03o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0D@3o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1J0?ooo`800000=`3oool0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
07D0oooo0P00001@0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0EP3oool2000003/0oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`1i0?ooo`800000C03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0580oooo0P00000o0?oo
o`030000003oool0oooo07`0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0O@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0080oooo001;0?ooo`800000
D@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
A03oool3000000@0oooo001;0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo0800oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`00
0000oooo0?ooo`1<0?ooo`800000A@3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`240?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool0B03oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`160?oo
o`800000B`3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool00P3oool004/0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo08L0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0080oooo001;0?ooo`800000A03o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0>@3o
ool3000000@0oooo001;0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`2:0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0S03oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`1A0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`020?ooo`00;`3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo00<0oooo00D0
oooO09a8000000000000001d_`0:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
0P3oool002h0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00<0
oooo00L0gia8001d_`3oool0oono07@00000B9`0gooo00P0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`020?ooo`00;@3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo
00H0oooo00<0oooO09a8001d_ol00P3oool00`3ogi`0B00004RLg`080?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool00P3oool002d0oooo00<0oooO09a80018W=l00P3oool0103ooml0
W4P00018W03Oool50?ooo`030?oo_`1d0000M;oo00<0oooo00<0_g@00000M02oool01`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo0080oooo000P0?ooo`030?oog`2LB000000000L0
000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`030=nLB00004P0W=oo00D0oooo00<0oooO
09a80000M;l00`3oool00`3OW4P0001809cOo`070?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool00P3oool002h0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`060?oo
o`030;md000007@0_ooo0080oooo00<0gia80000B02Lgol01`3oool3000003X0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0300oooo0`0000040?oo
o`00;P3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00H0oooo00P0okmd00000018
W=l0oooo0?oog`2LB00004RL0=ooo`L0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`020?ooo`00;P3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00D0oooo00<0oooO
09a8000000000P0000000`0007@0_ooo0?ooo`070?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool00P3oool002h0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`06
0?ooo`030?oo_`1d000007Bo00/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`02
0?ooo`00;`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00L0oooo00<0omnL04P0
0018W=l02P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo05X0oooo00<000000?oo
o`3oool0U@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0080oooo000`0?ooo`06
0=nLB00007@0_ooo0?oog`2LB000B9cO2@3oool0103ooml0W4P00000M02oool80?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`2F0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool00P3oool00340oooo00@0gia800000000000007Bo303o
ool0103ookl0M00000000018W=l60?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1L0?ooo`030000003o
ool0oooo09L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0V03oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`1O0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`020?ooo`00B`3oool200000340oooo00<000000?ooo`3oool0H03oool00`000000oooo
0?ooo`2J0?ooo`030000003oool0oooo02P0oooo0`0000040?ooo`00B`3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool0H@3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1R0?oo
o`030000003oool0oooo09d0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3o
ool0W@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`2N0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`2P0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0:00
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0X@3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool00P3oool004/0oooo0P00000Y0?ooo`030000003oool0oooo06P0oooo00<00000
0?ooo`3oool0XP3oool00`000000oooo0?ooo`0P0?ooo`<00000103oool004/0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0:80oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo06T0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
JP3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1[0?ooo`030000003o
ool0oooo0:@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`020?ooo`00B`3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0Y03oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`1]0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo
00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?oo
o`060?oooa<00000S@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`06
000001<0oooo1`0000270?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool00P3oool0
04/0oooo0P00000R0?ooo`030000003oool0oooo06l0oooo0`00000P0?ooo`<00000Q03oool00`00
0000oooo0?ooo`0K0?ooo`<00000103oool004/0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`1/0?ooo`D000009@3oool400000840oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06X0oooo
0`0000040?ooo`030000003oool0oooo02L0oooo0P00001o0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`1V0?ooo`@000001`3oool00`000000oooo0?ooo`0Y0?ooo`800000OP3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0I@3oool2000000/0oooo00<000000?ooo`3oool0:`3oool2000007`0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo06<0oooo0P00000=0?ooo`030000003oool0oooo02d0oooo0P00001k0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3oool002l0oooo00@0_g@000000000
0000M;oo0`3oool00`3ogi`0B00007Boo`050?ooo`030?oog`2LB000B9cO00X0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`1R0?ooo`8000003`3oool00`000000oooo0?ooo`0_0?oo
o`800000N@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo000^0?ooo`06
0=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`060?ooo`030=nLB000B9`0
gooo00T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1P0?ooo`8000004@3oool0
0`000000oooo0?ooo`0a0?ooo`800000N03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo0080oooo000]0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol02P3oool00`3o
gi`0B01809cOo`090?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0G`3oool20000
01<0oooo00<000000?ooo`3oool0<`3oool2000007H0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`020?ooo`00;@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=oo
o`D0oooo00<0okmd000000000000100000000`00B9`0gooo0?ooo`060?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0G@3oool2000001D0oooo00<000000?ooo`3oool0=@3oool20000
07D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`00803oool00`3ooml0
W4P0000000070000000604RLg`3oool0oooo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`05
0?ooo`030?oog`2LB4P0W=oo0080oooo00<0_g@0001d_`3oool0203oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0g
0?ooo`800000L`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo000^0?oo
o`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01P3oool01`3ookl0M01d0;ooo`3oool0
okmd0018W03Oool0203oool3000001/0oooo00<000000?ooo`3oool0F`3oool2000001P0oooo00<0
00000?ooo`3oool0>@3oool200000780oooo00<000000?ooo`3oool05@3oool3000000@0oooo000^
0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l01`3oool01P3ogi`0B4RL0=ooo`3o
gi`0B01809cOo`P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`800000
6P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`020?ooo`00;P3oool00`3ogi`0B00004RLg`030?ooo`030;md0000
B9`0gooo00L0oooo00D0okmd001d_`3ooml0W4P004RLg`080?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo
000^0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0203oool0103OW4P0B9cO
0;md0000M;l80?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0E`3oool2000001d0
oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool00P3oool002l0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo
0?ooo`090?ooo`040=nLB01dM7@0001d0;ooo`L0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0?P3oool2000006h0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00<03oool01P3OW4P0001d
0;ooo`3ooml0W4P004RLg`/0oooo00<0_g@00000B02Lgol01`3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo06`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?oo
o`00<@3oool0103OW4P0000000000000M;l<0?ooo`030?oog`2LB000B9cO00L0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`1E0?ooo`8000008@3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo06/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`130?ooo`030000
003oool0oooo06X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0580oooo0P00000U0?ooo`030000003o
ool0oooo04@0oooo0P00001Z0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool00P3oool004/0oooo0P00000G0?ooo`030000003oool0oooo
0540oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
06L0oooo00<000000?ooo`3oool04@3oool3000000@0oooo001;0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0D03oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool0IP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0I@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo04`0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0
I@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0080oooo001;0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0H`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0C03oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0H`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo001;0?ooo`8000004P3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0D03oool00`000000oooo
0?ooo`1R0?ooo`030000003oool0oooo00d0oooo0`0000040?ooo`00B`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`1A0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0640oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`1B0?oo
o`030000003oool0oooo0640oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?oo
o`00B`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo0640oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo0600oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0600
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`020?ooo`00B`3oool2000000h0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?oo
o`0:0?ooo`<00000103oool004/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool00`3oool8000004`0oooo00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo001;0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0i0?oo
o`H00000203oool6000004H0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0080oooo000<0?ooo`030?oo_`1dM;l0oooo03`0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo03H0oooo1@00000C0?ooo`<0
0000A03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00P3oool000`0oooo00@0omnL04P0000004P0W=oo>`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool0=@3oool2000000@0oooo00<000000?ooo`3o
ool0503oool300000440oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0080oooo000>0?ooo`030;md00000000000000<0000000<0001d0;ooo`3oool0
=03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
<P3oool3000000H0oooo00<000000?ooo`3oool05`3oool200000400oooo00<000000?ooo`3oool0
G@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo000B0?ooo`030?oOW018
0000M;oo01X0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`030=nL
B0000000000000<0000000<0B9cO0?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool0<@3oool2000000T0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`020?ooo`004@3oool00`3OW4P0001d0;ooo`0J0?ooo`060=nLB000
M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`030?ooo`030?noM000M;l0oooo0080
oooo00<0_gAd0;ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool0;`3oool2000000/0oooo00<000000?ooo`3oool06P3oool2000003h0
oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080
oooo000<0?ooo`060?oOW01804P0W=oo0?noM0000000B9cO6`3oool00`3ooml0W4P004RLg`020?oo
o`030?noM00004P0W=oo00P0oooo00<0okmd001d_`3oool02`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo01`0oooo0P00000l0?ooo`030000003oool0oooo05d0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`020?ooo`00303oool0103ogi`0B00000000000M;lM0?oo
o`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo203oool00`3o_g@007Bo0?ooo`0:
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0]
0?ooo`8000003P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0G@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo000P0?oo
o`030?oog`2LB000000000L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`030=nLB000
04P0W=oo00T0oooo00<0okmd04RLg`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo01l0oooo0P00000j0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`020?ooo`00;P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000
B9cO00X0oooo00<0gia804RLg`3oool0203oool3000000X0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0203oool3
000000@0oooo000?0?ooo`060=nLB000000000000000000004P0W=oo6@3oool00`3OW4P0001809cO
o`020?ooo`030?oog`2LB00007Bo00/0oooo00<0_g@007Boo`3oool01`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`1L0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool000d0oooo00T0oono
07@00018W=l0omnL09boo`3oool0gia80018W03Oool0603oool00`3ogi`0B00004RLg`030?ooo`03
0;md0000B9`0gooo00X0oooo00<0omnL04P0M02oool01`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool0:P3oool2000001<0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`020?ooo`003@3oool02@2oM7@0_ooo0?ooo`3o_i`0W=oo0?oo
o`3ookl0M01d0;ooo`0H0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool02P3o
ool00`3ooml0W4P007Boo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`020?ooo`00303oool02@3ogi`0W;oo0?ooo`3ooml0W7BL0=ooo`3oool0
omnL04Qd_`0J0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool02P3oool00`3ookl0
M00004RLg`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`020?ooo`00303oool02@3o_i`0W=oo0?ooo`2oM000M;oo0?ooo`3OW4P0001d0;ooo`0K
0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO1`3oool01`3o_g@004RL0=ooo`3oool0gia80000
B02Lgol01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool00P3oool000`0oooo00@0oono07@000000000M;oo8@3oool0103OW4P0000000000000M;l9
0?ooo`050?oOW018000000000000001d_ol0203oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1K0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0FP3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00403oool01P3o_g@0
0000000000000000001d0;ooocD0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0080oooo00080?ooo`060;nLW03Oool0oooo0?ooo`3ogi`0B0000`00
00001000B9`0gooo0?oo_`1dM;lf0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`020?ooo`001`3oool00`3ooml0W4P00000000300000003001d_`3o
ool0oooo0080oooo00<0okmd0000M02oool0=P3oool2000000T0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01P3o
ool3000000@0oooo00070?ooo`030?oo_`1d0000B9cO0440oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0FP3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`003`3oool01P3ogi`0
B000000000000000001809cOocH0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo000>0?ooo`030;md00000000M;oo0080oooo00<0oooO09ad
W03Oool0=@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00P3oool000d0oooo00<0gia804RLg`3oool0103oool00`3OW9`0_ooo0?ooo`0d0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo01d0oooo3000000U0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool0F@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo000<0?ooo`030?oO
W01dW=l0oooo00@0oooo00<0oooO09adW03Oool0=@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0000000X0oooo0P00000S0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo000<0?ooo`030?noW02L
gol0oooo00<0oooo00<0oooO09a8001d_ol0=P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0K0?ooo`8000000P3o
ool00`000000oooo0?ooo`0:0?ooo`8000008P3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo05X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00303oool0
0`3ogi`0B7Bo0?ooo`020?ooo`030=nLB0000000B9cO03L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06@3oool2
000000@0oooo00<000000?ooo`3oool0303oool200000200oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
00d0oooo00H0okmd00000000000000000018W03Ooolh0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01L0oooo0P00
00060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`0F0?ooo`800000203oool00`000000oooo0?ooo`0?
0?ooo`8000007P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo05T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0080oooo000?0?ooo`060?oOW018000000000000000004P0W=oo=P3oool2
000000L0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo00D0oooo0`0000040?ooo`003@3oool0103ooml0W4P00018W03Oool20?ooo`030?noM000B9`0
gooo03D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`003@3oool00`2o
M4P0W=oo0?ooo`030?ooo`030?oog`2LB7@0_ooo03D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`020?ooo`00303oool00`3ogi`0W;oo0?ooo`040?ooo`030?oOW018M;l0oooo03D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo05T0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00303oool00`3o_i`0W=oo
0?ooo`030?ooo`030?oOW018B9`0gooo03H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`00303oool0103ookl0M0000000001d_olk0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0>0?ooo`040000003oool00000000001D0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00d0oooo1000
00000`3oool0000000000002000001<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`00303oool00`3ookl0W9cO0?ooo`030?ooo`040?noM0000000001d0;ooocD0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000H0oooo
0P00000A0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000`0oooo00@0
oono09bLg`3ookl0M000100000000`00B9`0gooo0?ooo`0d0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool02`3oool2000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000`0oooo00T0
omnL04P000000000001809cOo`3oool0oooO09a8M02oool0=P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?oo
o`8000003`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00080?ooo`04
0?oog`2LB000001d0;ooocl0oooo0P0000070?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0103oool3000000@0oooo001;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo000<0?ooo`050?oO
_`2ogol0oooo0?ooo`2oM0000`0000000`0007@0_ooo0?ooo`0d0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo000<0?ooo`030;md0000000000000080000000D0001d0;ooo`3oool0_ibL0=ooo`0e0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo000:0?ooo`050;md0000000000000018W03Oool00`3oool00`3ooml0
W4P007Boo`020?ooo`030;md0000B9`0gooo0340oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000`0oooo
00<0oknL09cOo`3oool0203oool00`3ogi`0B7Bo0?ooo`0a0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
000<0?ooo`030?oo_`1dM;l0oooo00L0oooo00<0okmd0018W03Oool0903oool0102oM00000000000
001d_ol:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo000<0?ooo`040?oOW0180000001d0;ooo`D0oooo
00<0gia8001d_`3oool0903oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`T0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool000d0oooo00<0omnL04P0000000001@0000000`18W=l0oooo0?ooo`0S0?ooo`03
0?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0203oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0400oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00
4P3oool00`3o_g@0001809cOo`0V0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0
gooo1`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo0P00000:0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo000A0?ooo`030;md0000M;l0oooo02L0oooo00<0oooO09a80000M;l0
0`3oool00`3OW4P0001809cOo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo000<0?ooo`060?oOW018
0000M;oo0?noM0000000M;oo:P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00L0
ooooo`00001R000000@0oooo000<0?ooo`040?oOW01800000000001d_b`0oooo00<0gia80000B02L
gol00P3oool00`3ooml0W4P0001d_`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool0H03oool00`000000oooo0?ooo`020?ooo`00?03oool00`3ogi`0B00004RLg`030?ooo`030;md
0000B9`0gooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1P0?ooo`030000
003oool0oooo0080oooo000l0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0
0P3oool003d0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`020?ooo`00?P3oool0
1P3OW4P0001d0;ooo`3ooml0W4P004RLg`L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo0080oooo000o0?ooo`040=nLB00000000000001d_`P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0600oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1Q0?oo
o`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool02P3oool2000000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1Q0?ooo`03
0000003oool0oooo0080oooo001;0?ooo`8000001`3oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`L00000
2`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`1O0?ooo`<00000103oool004/0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0H@3o
ool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`1Q0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`800000403oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?oo
o`020?ooo`00B`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P3oool200000180oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000004`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0HP3oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0F0?ooo`<00000203oool01000
0000oooo00000000000D0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
01T0oooo2P00000E0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`1R0?ooo`030000003oool0oooo0080oooo001;0?ooo`800000203oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`1P0?ooo`<00000103oool004/0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool0H`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo0080oooo001;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
06@0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`1T0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`020?ooo`00B`3oool2000000X0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0X0?ooo`800000603oool00`000000oooo0?oo
o`080?ooo`8000008@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo06<0oooo0`00
00040?ooo`00B`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool0:P3oool2000001H0oooo00<000000?ooo`3oool01P3oool2000002<0oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0080oooo001;0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0[0?oo
o`800000503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool2000002D0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`800000
4@3oool00`000000oooo0?ooo`03000002H0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`1V0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`0_0?ooo`D000002`3oool4000002T0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0080oooo000_
0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P000000000
00030000000304RLg`3oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo03<0oooo2`0000000`3oool000000?ooo`0Y0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`020?ooo`00;P3oool0
1P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00`3oool00`3o_g@007Bo
0?ooo`020?ooo`030;mdM02oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool00P3oool002d0oooo00<0
oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?noM000M;l0oooo00/0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool00P3oool002d0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03O
ool80?ooo`030?noM000M;l0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool00P3oool002d0oooo00<0oooO
09a80000M;l00`3oool00`3OW4P0001809cOo`090?ooo`030?noM018W=l0oooo00T0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo06P0oooo00<00000
0?ooo`3oool00P3oool002h0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?oo
o`030=nLB018W=l0oooo00P0oooo0`00000;0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0IP3oool3000000@0oooo000^0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000
M;l02`3oool00`2oM000M;oo0?ooo`070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo0080oooo000^0?ooo`030?oO
W0180000B9cO00<0oooo00<0_g@00018W03Oool02P3oool00`3ogi`0B01d0;ooo`070?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1Y0?ooo`030000
003oool0oooo0080oooo000^0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0
2P3oool00`3ooml0W4P007Boo`070?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0080oooo000_0?ooo`030?oOW018
0000M;oo0080oooo00<0gia8001d_`3oool02P3oool00`3ookl0M00004RLg`070?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1Y0?ooo`030000003o
ool0oooo0080oooo000`0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO1`3oool01`3o_g@004RL
0=ooo`3oool0gia80000B02Lgol01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`020?ooo`00<@3oool0103OW4P0
000000000000M;l90?ooo`050?oOW018000000000000001d_ol0203oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0JP3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
J`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo04X0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo03T0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`020?ooo`00B`3oool2
000000l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`1Z0?ooo`<00000103oool0
04/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
06`0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool00P3oool004/0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo06d0oooo
00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`1=0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool05P3oool2000003h0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool0KP3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04l0oooo0P00000]0?ooo`030000
003oool0oooo0180oooo0P0000110?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0
0P3oool004/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1A0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`1A0?ooo`800000:P3oool00`000000oooo0?ooo`0?0?ooo`800000@`3oool0
0`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0080oooo001;0?ooo`800000503oool00`00
0000oooo0?ooo`1C0?ooo`800000:03oool00`000000oooo0?ooo`0=0?ooo`800000A@3oool00`00
0000oooo0?ooo`1^0?ooo`<00000103oool004/0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool02`3oool2000004H0
oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo05D0oooo0P00000U0?ooo`030000003oool0oooo00T0oooo
0P0000180?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool00P3oool004/0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`1G0?ooo`8000008`3oool00`000000oooo0?oo
o`070?ooo`800000B@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0080oooo001;
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0F03oool300000200oooo00<00000
0?ooo`3oool01@3oool2000004/0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05/0oooo1000000L0?oo
o`040000003oool0oooo0?ooo`@00000C03oool00`000000oooo0?ooo`1c0?ooo`030000003oool0
oooo0080oooo001;0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0GP3oool20000
01X0oooo1000001@0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3oool004/0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1P0?ooo`D00000403oool600000580
oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo06@0oooo400000050?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`1e0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?oo
o`00B`3oool2000001X0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1<0?ooo`03
0000003oool0oooo07H0oooo0`0000040?ooo`00B`3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0MP3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool00P3oool002l0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0
B00007Boo`050?ooo`030?oog`2LB000B9cO00X0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0O03oool00`000000
oooo0?ooo`020?ooo`00;P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0
001d_ol01P3oool00`3OW4P004RL0=ooo`090?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo07`0oooo00<000000?oo
o`3oool00P3oool002d0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`0:0?ooo`03
0?oOW01804P0W=oo00T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1c0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`020?ooo`00
;@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`D0oooo00<0okmd00000000
0000100000000`00B9`0gooo0?ooo`060?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3o
ool00P3oool002d0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`050?ooo`030?oo
g`2LB4P0W=oo0080oooo00<0_g@0001d_`3oool0203oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo0780oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`1o0?ooo`030000
003oool0oooo0080oooo000^0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01P3o
ool01`3ookl0M01d0;ooo`3oool0okmd0018W03Oool0203oool3000001l0oooo00<000000?ooo`3o
ool0L@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo07d0oooo0`0000040?ooo`00
;P3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00L0oooo00H0omnL04Q8W03Oool0
omnL04P0B02Lgol80?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0L03oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool00P3oool002h0
oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`070?ooo`050?noM000M;l0oooO09a8
0018W=l0203oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo06l0oooo00<000000?oo
o`3oool0@`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0080oooo000^0?ooo`04
0?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0203oool0103OW4P0B9cO0;md0000M;l8
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool00P3oool002l0oooo00<0omnL04P0
001d_ol00P3oool00`3OW4P007Bo0?ooo`090?ooo`040=nLB01dM7@0001d0;ooo`L0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0P`3oool00`000000oooo0?ooo`020?ooo`00<03oool01P3OW4P0001d0;ooo`3ooml0
W4P004RLg`/0oooo00<0_g@00000B02Lgol01`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`230?ooo`030000003o
ool0oooo0080oooo000a0?ooo`040=nLB00000000000001d_``0oooo00<0oooO09a80018W=l01`3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0
oooo08D0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`1[0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo06X0
oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0080
oooo001;0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0J@3oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool00P3oool004/0oooo0P00
000X0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`260?ooo`<00000103oool004/0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1X
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`02
0?ooo`00B`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo08/0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo06@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo0080oooo001;0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0H`3oool0
0`000000oooo0?ooo`0e0?ooo`800000T03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0940
oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0<03oool200000640oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool00P3oool004/0oooo0P00000d
0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`2B
0?ooo`<00000103oool004/0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1L0?oo
o`030000003oool0oooo02h0oooo0P00002G0?ooo`030000003oool0oooo0080oooo001;0?ooo`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo09L0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
V03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo05T0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2I0?ooo`030000003o
ool0oooo0080oooo001;0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool00P3oool0
04/0oooo00<000000?ooo`3oool0>@3oool2000005P0oooo00<000000?ooo`3oool0:03oool20000
09d0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0W@3oool00`000000
oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo0080oooo
001;0?ooo`030000003oool0oooo03d0oooo0P00001D0?ooo`030000003oool0oooo02@0oooo0P00
002Q0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0:40oooo00<00000
0?ooo`3oool00P3oool004/0oooo0P0000110?ooo`800000D@3oool00`000000oooo0?ooo`0Q0?oo
o`800000XP3oool3000000@0oooo001;0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`0O0?ooo`800000YP3oool00`000000oooo0?ooo`020?ooo`00
B`3oool00`000000oooo0?ooo`130?ooo`800000CP3oool00`000000oooo0?ooo`0M0?ooo`800000
Z03oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool06`3oool200000:X0oooo00<000000?ooo`3oool00P3o
ool004/0oooo00<000000?ooo`3oool0AP3oool2000004/0oooo00<000000?ooo`3oool06@3oool2
00000:`0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo01L0oooo0P00002^0?ooo`030000003oool0oooo
0080oooo001;0?ooo`030000003oool0oooo04T0oooo0P0000180?ooo`030000003oool0oooo01D0
oooo0P00002`0?ooo`030000003oool0oooo0080oooo000_0?ooo`040;md00000000000007Boo`<0
oooo00<0omnL04P0001d_ol00`3oool01@3ooml0W4P000000000000007Bo00X0oooo00<000000?oo
o`3oool0B`3oool2000004H0oooo00<000000?ooo`3oool04`3oool200000;80oooo00<000000?oo
o`3oool00P3oool002h0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000
M;oo00<0oooo00L0gia8001d_`3oool0oono07@00000B9`0gooo00P0oooo00<000000?ooo`3oool0
C@3oool2000004@0oooo00<000000?ooo`3oool04@3oool200000;@0oooo00<000000?ooo`3oool0
0P3oool002d0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`060?ooo`030?oog`2L
B000M;oo0080oooo00<0omnL04P00018W=l0203oool00`000000oooo0?ooo`1?0?ooo`<00000@@3o
ool00`000000oooo0?ooo`0?0?ooo`800000]P3oool00`000000oooo0?ooo`020?ooo`00;@3oool0
0`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`D0oooo00<0oono07@0001d_ol00`3o
ool00`2oM000001d0;ooo`070?ooo`030000003oool0oooo0580oooo0P00000o0?ooo`030000003o
ool0oooo00d0oooo0P00002h0?ooo`030000003oool0oooo0080oooo000]0?ooo`030?oog`2LB000
07Bo00<0oooo00<0gia80000B02Lgol01@3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0
W=oo00L0oooo00<000000?ooo`3oool0E03oool3000003`0oooo00<000000?ooo`3oool02`3oool2
00000;X0oooo00<000000?ooo`3oool00P3oool002h0oooo00<0_g@00018W03Oool00P3oool00`3o
gi`0B00004RLg`060?ooo`030;md000007@0_ooo0080oooo00<0gia80000B02Lgol01`3oool30000
05L0oooo0P00000j0?ooo`030000003oool0oooo00P0oooo0`00002j0?ooo`<00000103oool002h0
oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`060?ooo`080?noM0000000B9cO0?oo
o`3ooml0W4P00018W03Oool70?ooo`030000003oool0oooo05T0oooo0`00000g0?ooo`030000003o
ool0oooo00@0oooo1000002o0?ooo`030000003oool0oooo0080oooo000^0?ooo`030?oOW0180000
B9cO00<0oooo00<0_g@00018W03Oool01@3oool00`3ooml0W4P000000002000000030000M02oool0
oooo00L0oooo00<000000?ooo`3oool0G03oool500000380oooo00<000000?ooo`00000010000033
0?ooo`030000003oool0oooo0080oooo000^0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia8
0018W03Oool01P3oool00`3ookl0M000001d_`0;0?ooo`030000003oool0oooo0640oooo1000000/
0?ooo`@00000b03oool00`000000oooo0?ooo`020?ooo`00;`3oool00`3ogi`0B00007Boo`020?oo
o`030=nLB000M;l0oooo00L0oooo00<0omnL04P00018W=l02P3oool00`000000oooo0?ooo`1U0?oo
o`@00000903oool400000080oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`020?oo
o`00<03oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`T0oooo00@0oooO09a8000007@0_ooo203o
ool00`000000oooo0?ooo`1Y0?ooo`D000006`3oool4000000H0oooo00<000000?ooo`3oool0a`3o
ool00`000000oooo0?ooo`020?ooo`00<@3oool0103OW4P0000000000000M;l<0?ooo`040?oo_`1d
0000000004RLg`H0oooo00<000000?ooo`3oool0KP3ooolK000000X0oooo00<000000?ooo`3oool0
a`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000oooo0?ooo`2C0?ooo`030000003o
ool0oooo0<L0oooo00<000000?ooo`3oool00P3oool004/0oooo00<000000?ooo`3oool0T`3oool0
0`000000oooo0?ooo`370?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0oooo
09<0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`020?ooo`00B`3oool00`000000
oooo0?ooo`2C0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool00P3oool004/0oooo
0P00002D0?ooo`030000003oool0oooo0<D0oooo0`0000040?ooo`00B`3oool01@000000oooo0?oo
o`3oool000000300oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00B`3o
ool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo001;0?ooo`050000003oool0oooo0?ooo`000000
2@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool004/0ooooo`00001R000000@0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003>0?ooo`090?oo_`1d00000000
04RLg`3oool0oono07@000000000B9cO01@0oooo00<0okmd0000000000000P0000000`00B9`0gooo
0?ooo`0B0?ooo`050;md00000000000000000018W=l0YP3oool00<h0oooo00X0oono07@0B02Lgol0
_g@0001d_`3ookl0M01809cOo`2oM00007Bo4P3oool00`3o_g@0000004RLg`030?ooo`030?oOW018
04P0W=oo01<0oooo00<0oooO09a80018W=l0Y`3oool00=40oooo00<0oono07@0001d_ol00P3oool0
0`3ookl0M00007Boo`0A0?ooo`030?noM00007@0_ooo00@0oooo00<0gia8001d_`3oool04`3oool0
0`3OW4P004RL0=ooo`2V0?ooo`00dP3oool00`3OW4P004RL0=ooo`020?ooo`030=nLB000B9`0gooo
0140oooo00P0_g@00000M02oool0oooo0?oog`2LB000000004RLga@0oooo00<0omnL04P0M02oool0
YP3oool00;/0oooo00<0_g@00000000000001@0000000`00B9`0gooo0?ooo`030?ooo`0<0?oOW018
000000000018W03Oool0_g@000000000M;l0oooo0?noM00004P0W=oo0P3oool00`3o_g@0001809cO
o`030?ooo`080;md00000000001809cOo`3oool0gia80018W03Oool20?ooo`030;md0000000007Bo
0080oooo00H0oono07@00000000000000000M02oool50?ooo`030?noM0000000000000L0000000T0
M;oo0?ooo`3ogi`0B0000000000007@0_ono07@0001d_ol00P3oool02`3ogi`0B00000000000B9`0
gooo0;md0000000007Bo0?ooo`3ogi`0B0000080000000T0M;oo0=nLB000000004RL0=ooo`3o_g@0
00000000B02Lgol00P3oool0102oM00000000000B02Lgol20?ooo`050?noM000000000000000B02L
gol00`3oool00`3OW4P004RL0=ooo`020?ooo`030;md0000000007Bo07H0oooo002l0?ooo`040?oo
_`1d000004RL0=ooo`<0oooo00<0_g@000000000M;l00`3oool0303ogi`0B01809cOo`3ogi`0B7Bo
0;md0000M;l0oknL09cOo`3ookl0M00004RLg`80oooo00<0oono07@00018W=l00`3oool0203OW4P0
04RL0=oog`2LM9`0gooo0?noM00007@0_ooo0P3oool0203OW4P004RL0=noM01d_ol0oooo0?noM000
07@0_ooo2@3oool0103ooml0W4P00018W03Oool30?ooo`0;0?oog`2LB00004RL0=ooo`2oM00004RL
0=ooo`3ookl0M01d07Ad0018W=l00P3oool0903ogi`0B01809cOo`3ogi`0B7Bo0;md0000M;l0oknL
09cOo`2oM00004RL0=ooo`3oool0_g@007AdM00007@0_mnL09boo`3o_g@0001809cOg`2LM9`0gooo
0?ooo`3OW4P004RL0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`80oooo00<0
okmd0000M02oool00P3oool0103OW4P004RL0=noM01d_ome0?ooo`00_@3oool00`3OW4P0001809cO
o`040?ooo`0=0?oo_`1d000004RL0=ooo`3oool0oooO09a80018W=l0oooo0?noM01dM7@004RL0=oo
o`020?ooo`030;md0000B9`0gooo0080oooo00<0_g@00018W03Oool00P3oool00`3o_g@0001809cO
o`020?ooo`030?oo_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol00`3oool00`2oM000M;oo0?oo
o`090?ooo`030?noM00004P0W=oo00D0oooo00@0giad09cOo`2oM00007Bo0P3oool0403ookl0M000
0018W03Oool0oooo0?oog`2LB000B9cO0?ooo`3o_g@0M7Ad0018W03Oool0oooo0;md0000M;l30?oo
o`070;md00000000M;oo0?ooo`3ookl0M00007Boo`030?ooo`030?noM00004P0W=oo0080oooo00<0
gia80018W03Oool00P3oool01`3ogi`0B00004RLg`3oool0oono07@00018W=l00P3oool00`3ogi`0
B01809cOo`1f0?ooo`00_@3oool00`3ogi`0B00007Boo`050?ooo`030?oOW018000007Bo0080oooo
00L0_g@00018W03Oool0oooo0;md000004P0W=oo0080oooo00<0gia80000M02oool00P3oool00`3O
W4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO0080oooo00P0oooO09a8000007@0_ooo0?ooo`3o
oml0W4P004RLg`80oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`050?ooo`030?oo
_`1d0000B9cO00L0oooo00<0gia80018W03Oool00P3oool00`3o_g@0001d0;ooo`020?ooo`0;0;md
0000B9`0gooo0?ooo`2oM000001809cOo`3oool0okmd0000M02oool00P3oool00`3ookl0M00004RL
g`020?ooo`030;md0000M;l0oooo0080oooo00<0oono07@00018W=l00P3oool00`3o_g@0001d0;oo
o`030?ooo`0;0=nLB00007@0_ooo0?oog`2LB000001d0;ooo`3oool0oooO09a80018W=l0MP3oool0
0;d0oooo00<0oono07@00000M;l01P3oool02`2oM000001809cOo`3oool0okmd0000M02oool0oooo
0?oo_`1d0000M;oo0080oooo00<0omnL04P0001d_ol00P3oool00`3ogi`0B00007Boo`030?ooo`03
0;md0000B9`0gooo0080oooo00<0gia80018B018M;l00P3oool02`2oM00007Bo0?ooo`3oool0_g@0
0018W03Oool0oooo0?oOW0180000B9cO00H0oooo00<0oooO09a80000M;l00P3oool00`3ookl0W9cO
0?ooo`020?ooo`030?oOW0180000M;oo0080oooo00<0oono07@0001d_ol00P3oool02`3o_g@0001d
0;ooo`3oool0oono07@0001d_ol0oooo0?oo_`1d0000M;oo00<0oooo00L0_g@00018W03Oool0oooo
0=nLB000B9`0gooo00<0oooo00L0_g@00018W03Oool0oooo0?oo_`1d0000M;oo00<0oooo00L0omnL
04P0B02Lgol0oooo0=nLB000B4P0B7Bo0080oooo00<0_g@0001d_`3oool0M@3oool00;h0oooo00<0
_g@00018W03Oool01@3oool01`3o_g@0000004RLg`3ogml0gono07@0001d_ol00P3oool01`2oM000
07Bo0?ooo`3oool0oooO09a80018W=l00P3oool00`3ooml0W4P004RLg`030?ooo`030=nLB00004P0
W=oo0080oooo00/0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;ooo`3oool0_g@0001d_`030?oo
o`030=nLB00007@0_ooo00H0oooo00H0gia80000M02oool0oooo0?oOW018M;l40?ooo`0<0;md0000
07@0_ooo0?ooo`3ooml0W4P004RLg`3oool0omoO0=oo_`1d0000M;oo0P3oool01`2oM00007Bo0?oo
o`3oool0okmd0000M02oool00P3oool01`3OW4P0001d0;ooo`3oool0omnL04P0B02Lgol00`3oool0
0`3OW4P0001809cOo`020?ooo`030=nLB00007@0_ooo0080oooo00`0oono07@0001d_ol0oooo0?no
M00007@0_kmd04RLg`3oool0okmd0000M02ooome0?ooo`00_P3oool00`3o_g@0001809cOo`050?oo
o`070?oOW018000007Bo0?oOW018M;l0_g@0001d_`020?ooo`030?noM000B9`0gooo0080oooo00<0
_g@00018W03Oool00P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO0080oooo00`0
oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOo`3oool0omnL04P00018W=l20?ooo`030=nLB000
07@0_ooo00H0oooo00<0okmd0000000000000P0000000`0007@0_ooo0?ooo`020?ooo`0<0?oog`2L
B00004RL0=ooo`3ookl0W4Q80018W03Oool0omnL04Qd_`2oM00007Bo0P3oool00`3o_g@004RL0=oo
o`020?ooo`0;0=nLB00007@0_ooo0?ooo`2oM000001809cOo`3oool0oooO09a80018W=l00`3oool0
0`3ogi`0B00004RLg`030?ooo`0@0;md000007@0_ooo0?ooo`3o_g@0001d0;ooo`3oool0oooO09a8
001d_ol0gia8001d_`3ogi`0B01809cOogD0oooo002n0?ooo`030?oOW0180000M;oo00D0oooo00L0
omnL04P00000M;l0oooo0?noM000000007Bo0080oooo00D0omnL04P0B02Lgol0oono07@000030000
000307Bo_`1d000000000080000000l0M;oo0?noM000000000000018W03Oool0oono07@000000000
B9cO0?ooo`3o_g@000000000B02Lgol00P3oool00`3ookl0M000000000040000000304RLg`3oool0
oooo00<0oooo00<0oono07@0001d_ol00P3oool00`2oM4P0W=oo0?ooo`040?ooo`0:0=nLB0000000
001d0;noM00007@0_ooo0?ooo`3o_g@00000001d_`80oooo00<0omnL04P0B02Lgol00`3oool0203o
gi`0B00000000018W9`0M00004RLg`3ookl0M0000`0000001P1d_ol0okmd00000000000004RL0=oo
o`<0oooo00l0okmd000000000000000007Boo`3oool0oono07@000000000B9cO0?ooo`3o_g@00000
0000B02Lgol0M@3oool00;h0oooo00<0oooO09a80000M;l01@3oool00`3o_g@0000004RLg`0;0?oo
o`030?noM00004P0W=oo0080oooo00<0okmd0000B02Lgol07`3oool01P2oM00007Bo0?ooo`3oool0
omnL07BLgal0oooo00<0okmd0000M02oool0S@3oool00;l0oooo00<0_g@00018W03Oool00`3oool0
103ooml0W4P00000M02oool;0?ooo`030?oog`2LB00007Bo0080oooo00<0oooO09a80000M;l07`3o
ool00`3OW4P0001d0;ooo`040?ooo`030=nLW02oool0oooo01`0oooo00<0giad09cOo`3oool0S03o
ool00;l0oooo00<0gia80000B02Lgol00P3oool0103ookl0M0000000001d_ol=0?ooo`030?noM000
07@0_ooo0080oooo00<0okmd0000M02oool00P3oool0103ookl0M0000018W03OoolH0?ooo`030?no
M00004P0W=oo00<0oooo00<0oono07@0B02Lgol08P3oool0103ookl0M0000018W03Ooon60?ooo`00
_P3oool00`2oM000000000000004000000030018W03Oool0oooo00h0oooo00X0gia80018W03Ooml0
W4P004RLg`3OW4P004RL0=oog`2LB000B9cO6P3oool00`2oM0000000000000060000000307Boo`3o
ool0oooo0:X0oooo003G0?ooo`090=nLB0000000001809cOo`3oool0gia80000000004P0W=oo0=00
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-1.16292, -1.12902, 0.0077458, \
0.00668125}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Driven, damped, anharmonic oscillator", "Subsection"],

Cell["\<\
A complete catalog of the complex motions that become possible when both \
driving and damping forces are applied to an anharmonic oscillator is beyond \
the scope of this notebook, but it is fun to  present a few interesting \
cases.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Modest driving and damping forces", "Subsubsection"],

Cell[TextData[{
  "We begin at the origin, for simplicity, and allow the driving force to \
seek a periodic motion.  The initial transients are suppressed by the damping \
forces and the system eventually settles upon a periodic orbit through phase \
space.  The shape of the limiting orbit depends upon ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ", but for a wide range of initial conditions is independent of those \
initial conditions; hence, the limiting orbit is called an ",
  StyleBox["attractor ",
    FontSlant->"Italic"],
  "and the domain of initial conditions which lead to that attractor is \
called the ",
  StyleBox["basin of attraction",
    FontSlant->"Italic"],
  ".  The basin of attraction is clearly limited for negative ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ", but for positive ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " is the entire phase plane."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(duffingPlot[1, 1, 0.05, 0.1, 0.5, 0, 0, 0, 100, 
        MaxSteps \[Rule] 3000, PlotPoints \[Rule] 100, 
        AspectRatio \[Rule] Automatic];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .79762 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.613232 2.63412 0.430435 2.63412 [
[.08641 -0.0125 -13.8438 -15.6875 ]
[.08641 -0.0125 13.8438 0 ]
[.21811 -0.0125 -16.8438 -15.6875 ]
[.21811 -0.0125 16.8438 0 ]
[.34982 -0.0125 -13.8438 -15.6875 ]
[.34982 -0.0125 13.8438 0 ]
[.48153 -0.0125 -16.8438 -15.6875 ]
[.48153 -0.0125 16.8438 0 ]
[.61323 -0.0125 -5 -15.6875 ]
[.61323 -0.0125 5 0 ]
[.74494 -0.0125 -12.5 -15.6875 ]
[.74494 -0.0125 12.5 0 ]
[.87664 -0.0125 -9.5 -15.6875 ]
[.87664 -0.0125 9.5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.9688 -31.375 ]
[.5 -0.0125 21.9688 -15.6875 ]
[-0.0125 .03532 -33.6875 -7.84375 ]
[-0.0125 .03532 0 7.84375 ]
[-0.0125 .16702 -27.6875 -7.84375 ]
[-0.0125 .16702 0 7.84375 ]
[-0.0125 .29873 -33.6875 -7.84375 ]
[-0.0125 .29873 0 7.84375 ]
[-0.0125 .43044 -10 -7.84375 ]
[-0.0125 .43044 0 7.84375 ]
[-0.0125 .56214 -25 -7.84375 ]
[-0.0125 .56214 0 7.84375 ]
[-0.0125 .69385 -19 -7.84375 ]
[-0.0125 .69385 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .39881 -49.375 -20.4688 ]
[-0.01875 .39881 -33.6875 20.4688 ]
[ 0 .79762 .125 0 ]
[ 1 0 .125 0 ]
[.5 .81012 -43.9375 0 ]
[.5 .81012 43.9375 15.6875 ]
[ 0 0 0 0 ]
[ 1 .79762 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08641 0 m
.08641 .00625 L
s
gsave
.08641 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.21811 0 m
.21811 .00625 L
s
gsave
.21811 -0.0125 -77.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
.34982 0 m
.34982 .00625 L
s
gsave
.34982 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.48153 0 m
.48153 .00625 L
s
gsave
.48153 -0.0125 -77.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
.61323 0 m
.61323 .00625 L
s
gsave
.61323 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.74494 0 m
.74494 .00625 L
s
gsave
.74494 -0.0125 -73.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
.87664 0 m
.87664 .00625 L
s
gsave
.87664 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.125 Mabswid
.11275 0 m
.11275 .00375 L
s
.13909 0 m
.13909 .00375 L
s
.16543 0 m
.16543 .00375 L
s
.19177 0 m
.19177 .00375 L
s
.24445 0 m
.24445 .00375 L
s
.2708 0 m
.2708 .00375 L
s
.29714 0 m
.29714 .00375 L
s
.32348 0 m
.32348 .00375 L
s
.37616 0 m
.37616 .00375 L
s
.4025 0 m
.4025 .00375 L
s
.42884 0 m
.42884 .00375 L
s
.45518 0 m
.45518 .00375 L
s
.50787 0 m
.50787 .00375 L
s
.53421 0 m
.53421 .00375 L
s
.56055 0 m
.56055 .00375 L
s
.58689 0 m
.58689 .00375 L
s
.63957 0 m
.63957 .00375 L
s
.66591 0 m
.66591 .00375 L
s
.69226 0 m
.69226 .00375 L
s
.7186 0 m
.7186 .00375 L
s
.77128 0 m
.77128 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.82396 0 m
.82396 .00375 L
s
.8503 0 m
.8503 .00375 L
s
.06007 0 m
.06007 .00375 L
s
.03372 0 m
.03372 .00375 L
s
.00738 0 m
.00738 .00375 L
s
.90299 0 m
.90299 .00375 L
s
.92933 0 m
.92933 .00375 L
s
.95567 0 m
.95567 .00375 L
s
.98201 0 m
.98201 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.9688 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
102.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .03532 m
.00625 .03532 L
s
gsave
-0.0125 .03532 -94.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
0 .16702 m
.00625 .16702 L
s
gsave
-0.0125 .16702 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .29873 m
.00625 .29873 L
s
gsave
-0.0125 .29873 -94.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
0 .43044 m
.00625 .43044 L
s
gsave
-0.0125 .43044 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .56214 m
.00625 .56214 L
s
gsave
-0.0125 .56214 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
0 .69385 m
.00625 .69385 L
s
gsave
-0.0125 .69385 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .06166 m
.00375 .06166 L
s
0 .088 m
.00375 .088 L
s
0 .11434 m
.00375 .11434 L
s
0 .14068 m
.00375 .14068 L
s
0 .19336 m
.00375 .19336 L
s
0 .21971 m
.00375 .21971 L
s
0 .24605 m
.00375 .24605 L
s
0 .27239 m
.00375 .27239 L
s
0 .32507 m
.00375 .32507 L
s
0 .35141 m
.00375 .35141 L
s
0 .37775 m
.00375 .37775 L
s
0 .40409 m
.00375 .40409 L
s
0 .45678 m
.00375 .45678 L
s
0 .48312 m
.00375 .48312 L
s
0 .50946 m
.00375 .50946 L
s
0 .5358 m
.00375 .5358 L
s
0 .58848 m
.00375 .58848 L
s
0 .61482 m
.00375 .61482 L
s
0 .64117 m
.00375 .64117 L
s
0 .66751 m
.00375 .66751 L
s
0 .00898 m
.00375 .00898 L
s
0 .72019 m
.00375 .72019 L
s
0 .74653 m
.00375 .74653 L
s
0 .77287 m
.00375 .77287 L
s
.25 Mabswid
0 0 m
0 .79762 L
s
gsave
-0.01875 .39881 -123 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
81.4688 11.8438 translate
90 rotate
-81.4688 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(velocity) show
99.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08641 .79137 m
.08641 .79762 L
s
.21811 .79137 m
.21811 .79762 L
s
.34982 .79137 m
.34982 .79762 L
s
.48153 .79137 m
.48153 .79762 L
s
.61323 .79137 m
.61323 .79762 L
s
.74494 .79137 m
.74494 .79762 L
s
.87664 .79137 m
.87664 .79762 L
s
.125 Mabswid
.11275 .79387 m
.11275 .79762 L
s
.13909 .79387 m
.13909 .79762 L
s
.16543 .79387 m
.16543 .79762 L
s
.19177 .79387 m
.19177 .79762 L
s
.24445 .79387 m
.24445 .79762 L
s
.2708 .79387 m
.2708 .79762 L
s
.29714 .79387 m
.29714 .79762 L
s
.32348 .79387 m
.32348 .79762 L
s
.37616 .79387 m
.37616 .79762 L
s
.4025 .79387 m
.4025 .79762 L
s
.42884 .79387 m
.42884 .79762 L
s
.45518 .79387 m
.45518 .79762 L
s
.50787 .79387 m
.50787 .79762 L
s
.53421 .79387 m
.53421 .79762 L
s
.56055 .79387 m
.56055 .79762 L
s
.58689 .79387 m
.58689 .79762 L
s
.63957 .79387 m
.63957 .79762 L
s
.66591 .79387 m
.66591 .79762 L
s
.69226 .79387 m
.69226 .79762 L
s
.7186 .79387 m
.7186 .79762 L
s
.77128 .79387 m
.77128 .79762 L
s
.79762 .79387 m
.79762 .79762 L
s
.82396 .79387 m
.82396 .79762 L
s
.8503 .79387 m
.8503 .79762 L
s
.06007 .79387 m
.06007 .79762 L
s
.03372 .79387 m
.03372 .79762 L
s
.00738 .79387 m
.00738 .79762 L
s
.90299 .79387 m
.90299 .79762 L
s
.92933 .79387 m
.92933 .79762 L
s
.95567 .79387 m
.95567 .79762 L
s
.98201 .79387 m
.98201 .79762 L
s
.25 Mabswid
0 .79762 m
1 .79762 L
s
.99375 .03532 m
1 .03532 L
s
.99375 .16702 m
1 .16702 L
s
.99375 .29873 m
1 .29873 L
s
.99375 .43044 m
1 .43044 L
s
.99375 .56214 m
1 .56214 L
s
.99375 .69385 m
1 .69385 L
s
.125 Mabswid
.99625 .06166 m
1 .06166 L
s
.99625 .088 m
1 .088 L
s
.99625 .11434 m
1 .11434 L
s
.99625 .14068 m
1 .14068 L
s
.99625 .19336 m
1 .19336 L
s
.99625 .21971 m
1 .21971 L
s
.99625 .24605 m
1 .24605 L
s
.99625 .27239 m
1 .27239 L
s
.99625 .32507 m
1 .32507 L
s
.99625 .35141 m
1 .35141 L
s
.99625 .37775 m
1 .37775 L
s
.99625 .40409 m
1 .40409 L
s
.99625 .45678 m
1 .45678 L
s
.99625 .48312 m
1 .48312 L
s
.99625 .50946 m
1 .50946 L
s
.99625 .5358 m
1 .5358 L
s
.99625 .58848 m
1 .58848 L
s
.99625 .61482 m
1 .61482 L
s
.99625 .64117 m
1 .64117 L
s
.99625 .66751 m
1 .66751 L
s
.99625 .00898 m
1 .00898 L
s
.99625 .72019 m
1 .72019 L
s
.99625 .74653 m
1 .74653 L
s
.99625 .77287 m
1 .77287 L
s
.25 Mabswid
1 0 m
1 .79762 L
s
0 .43044 m
1 .43044 L
s
.61323 0 m
.61323 .79762 L
s
gsave
.5 .81012 -104.938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Duffing) show
102.938 15.813 moveto
(Equation) show
146.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .79762 L
0 .79762 L
closepath
clip
newpath
.5 Mabswid
.61323 .43044 m
.61335 .4383 L
.61366 .44544 L
.61426 .45363 L
.61506 .46132 L
.61706 .47486 L
.62002 .48929 L
.62423 .50481 L
.62975 .52075 L
.64224 .54775 L
.65838 .57304 L
.67619 .59394 L
.69831 .61334 L
.72456 .62965 L
.73898 .63613 L
.75274 .64086 L
.76064 .64298 L
.76814 .64461 L
.77232 .64535 L
.77686 .64603 L
.78096 .64653 L
.7848 .6469 L
.79194 .64733 L
.79573 .64743 L
.79979 .64743 L
.80405 .64732 L
.80808 .64711 L
.81169 .64683 L
.81561 .64643 L
.82271 .64544 L
.83021 .64404 L
.84354 .6406 L
.85612 .63616 L
.86934 .63016 L
.89211 .61617 L
.90447 .60626 L
.9167 .59445 L
.93626 .57003 L
.94495 .55605 L
.95229 .54197 L
.96357 .51352 L
.9684 .49649 L
.97186 .48017 L
.97328 .47143 L
.97452 .46166 L
.97502 .45668 L
.97546 .45129 L
.97599 .44145 L
.97619 .43222 L
.97612 .42358 L
Mistroke
.97575 .414 L
.97541 .40862 L
.97502 .40373 L
.9741 .39468 L
.97281 .38484 L
.96966 .3669 L
.96556 .34918 L
.96015 .33045 L
.94767 .29702 L
.9283 .25803 L
.90643 .2236 L
.87854 .18821 L
.84342 .15234 L
.80682 .12207 L
.76981 .09698 L
.72892 .07439 L
.6893 .05681 L
.64413 .04126 L
.62024 .0348 L
.59373 .02897 L
.57024 .02495 L
.54823 .02213 L
.53598 .02095 L
.52484 .02012 L
.51196 .01944 L
.4998 .01908 L
.48729 .01899 L
.47356 .01923 L
.46665 .01948 L
.45924 .01985 L
.44588 .02077 L
.43262 .02201 L
.42009 .0235 L
.39673 .02708 L
.36956 .03262 L
.34477 .03902 L
.29039 .05794 L
.2477 .07811 L
.20458 .10423 L
.136 .16197 L
.1028 .20076 L
.07366 .24509 L
.05385 .28515 L
.03778 .33069 L
.03209 .35348 L
.02968 .36556 L
.02758 .37838 L
.02612 .38961 L
.02549 .39556 L
.02492 .40196 L
Mistroke
.0242 .41319 L
.02385 .42369 L
.02381 .43451 L
.02414 .44627 L
.02481 .45732 L
.02574 .46753 L
.02695 .47758 L
.0283 .48663 L
.03218 .50668 L
.03821 .52975 L
.04515 .55044 L
.06547 .59487 L
.08845 .63097 L
.11741 .66544 L
.14897 .69438 L
.18071 .71722 L
.22034 .7392 L
.26028 .75556 L
.27877 .76146 L
.29874 .76677 L
.31624 .77056 L
.33529 .77382 L
.346 .77527 L
.35585 .77637 L
.3659 .77727 L
.37526 .7779 L
.38558 .77838 L
.39688 .77863 L
.40789 .77862 L
.41405 .7785 L
.41965 .77832 L
.43022 .7778 L
.44009 .77711 L
.4509 .77613 L
.46246 .7748 L
.48588 .77128 L
.50703 .76711 L
.54692 .7567 L
.58346 .74409 L
.65858 .70791 L
.69661 .68334 L
.72857 .65856 L
.78292 .60431 L
.80411 .57682 L
.82036 .55162 L
.83233 .52941 L
.84271 .50577 L
.85036 .48303 L
.85341 .47116 L
.85556 .4605 L
Mistroke
.85645 .45502 L
.85719 .44933 L
.85767 .4446 L
.85805 .4395 L
.85819 .43671 L
.85827 .43418 L
.85831 .43132 L
.8583 .42864 L
.85817 .42401 L
.85803 .42145 L
.85786 .41911 L
.85741 .41467 L
.85686 .41064 L
.8555 .40349 L
.85359 .39638 L
.85104 .3894 L
.84855 .3841 L
.84548 .3789 L
.84219 .37447 L
.83839 .37042 L
.83462 .36729 L
.83102 .36499 L
.82925 .36407 L
.82729 .36321 L
.82554 .36256 L
.82368 .362 L
.82155 .36152 L
.81959 .36121 L
.81747 .36102 L
.81515 .36099 L
.81314 .3611 L
.811 .36137 L
.80898 .36175 L
.80716 .36222 L
.80277 .36379 L
.80034 .36495 L
.79814 .36618 L
.79397 .36903 L
.79026 .37221 L
.78352 .3799 L
.78036 .38463 L
.77733 .39018 L
.77459 .39642 L
.77242 .40271 L
.77087 .40862 L
.77015 .41207 L
.7696 .41529 L
.76917 .41845 L
.76883 .42181 L
.76859 .42522 L
Mistroke
.76851 .42717 L
.76847 .42899 L
.76848 .43231 L
.76858 .43535 L
.76867 .43703 L
.7688 .43886 L
.76913 .44218 L
.7695 .44513 L
.77002 .44838 L
.77137 .45491 L
.77299 .46086 L
.77483 .46633 L
.78051 .47897 L
.78714 .48952 L
.79581 .49965 L
.80105 .50439 L
.80628 .50832 L
.81115 .51135 L
.81661 .51411 L
.82172 .51612 L
.82652 .51753 L
.82924 .51814 L
.83179 .51858 L
.83461 .51893 L
.83619 .51906 L
.83764 .51913 L
.84055 .51917 L
.8422 .51912 L
.84372 .51903 L
.84651 .51875 L
.84946 .51828 L
.85198 .51775 L
.85427 .51715 L
.85938 .5154 L
.86378 .51341 L
.8683 .51085 L
.87733 .50387 L
.88205 .49899 L
.88614 .49385 L
.8935 .48146 L
.8969 .47346 L
.89951 .46547 L
.90134 .45803 L
.90219 .45362 L
.90284 .44937 L
.90339 .44479 L
.90375 .44049 L
.9039 .43808 L
.90401 .43542 L
.90409 .43048 L
Mistroke
.90402 .42556 L
.9038 .42084 L
.90348 .41654 L
.903 .41181 L
.90232 .40657 L
.90142 .40095 L
.89932 .39069 L
.89399 .37179 L
.88574 .35047 L
.87345 .3262 L
.85882 .30318 L
.82365 .26115 L
.77507 .21961 L
.74317 .19877 L
.71112 .18163 L
.68097 .1684 L
.64686 .15641 L
.6134 .14741 L
.5819 .14126 L
.56353 .13868 L
.54631 .13691 L
.53638 .13617 L
.52733 .13568 L
.52231 .13548 L
.51687 .13532 L
.50699 .1352 L
.49743 .13528 L
.492 .13541 L
.48692 .13559 L
.48158 .13584 L
.4767 .13612 L
.46575 .13693 L
.45647 .13783 L
.44639 .13902 L
.42816 .14175 L
.40944 .14537 L
.38951 .15016 L
.35439 .16112 L
.32173 .17456 L
.29333 .18921 L
.23571 .23007 L
.21104 .2541 L
.18777 .28264 L
.16987 .31098 L
.1565 .33892 L
.14755 .36463 L
.1438 .37931 L
.14117 .39292 L
.14013 .39994 L
.13925 .40749 L
Mistroke
.13865 .41461 L
.13829 .42111 L
.1381 .42868 L
.13811 .43296 L
.13819 .43692 L
.13851 .44414 L
.13879 .44817 L
.13911 .45181 L
.14 .45968 L
.14107 .46687 L
.14434 .48289 L
.14818 .4967 L
.1532 .51093 L
.16494 .53603 L
.17832 .55746 L
.19671 .58019 L
.21678 .59955 L
.2579 .62822 L
.28371 .64101 L
.3089 .6506 L
.33529 .65806 L
.35047 .6613 L
.36458 .66367 L
.37709 .66528 L
.3843 .66601 L
.39087 .66656 L
.39785 .66701 L
.40532 .66734 L
.41225 .66753 L
.4188 .66759 L
.42597 .66754 L
.43386 .66733 L
.43782 .66717 L
.44208 .66696 L
.44977 .66646 L
.46461 .66509 L
.47809 .66341 L
.49359 .66094 L
.5103 .65767 L
.54002 .65025 L
.5954 .63084 L
.64064 .60922 L
.72171 .55474 L
.7709 .50824 L
.80185 .47252 L
.80682 .46687 L
.81144 .4621 L
.81521 .45884 L
.81846 .45674 L
.82012 .45599 L
Mistroke
.82104 .45567 L
.82188 .45544 L
.82259 .4553 L
.82336 .4552 L
.82416 .45515 L
.82491 .45515 L
.82531 .45517 L
.82576 .4552 L
.82622 .45526 L
.82665 .45532 L
.82743 .45547 L
.82827 .45568 L
.83022 .45632 L
.83204 .45709 L
.83938 .46104 L
.84839 .46595 L
.85248 .46782 L
.85709 .46953 L
.85982 .47032 L
.86236 .4709 L
.86359 .47112 L
.86494 .47132 L
.86622 .47147 L
.86741 .47156 L
.86873 .47162 L
.86995 .47162 L
.87129 .47158 L
.87196 .47153 L
.87269 .47147 L
.87393 .47131 L
.87525 .47109 L
.8776 .47054 L
.88001 .46974 L
.88224 .46877 L
.88623 .46634 L
.88838 .4646 L
.89052 .46245 L
.89399 .45783 L
.89566 .45483 L
.89704 .45172 L
.89834 .448 L
.89895 .44576 L
.89944 .44363 L
.89981 .44161 L
.90015 .43935 L
.9003 .43807 L
.90042 .43688 L
.9006 .43446 L
.90068 .43232 L
.90071 .4299 L
Mistroke
.90065 .42731 L
.90051 .42482 L
.9004 .42338 L
.90025 .42179 L
.8999 .41883 L
.89897 .4131 L
.8974 .40608 L
.89546 .3993 L
.89109 .38729 L
.88458 .37331 L
.86563 .34337 L
.8394 .31327 L
.80859 .28618 L
.76764 .25844 L
.71726 .23312 L
.66705 .21515 L
.63723 .20738 L
.60932 .2019 L
.59645 .19993 L
.58272 .19822 L
.57552 .19748 L
.56756 .19678 L
.56023 .19626 L
.55351 .19587 L
.5467 .19558 L
.54023 .19539 L
.5334 .19529 L
.52595 .19528 L
.51947 .19537 L
.51257 .19557 L
.50606 .19584 L
.50018 .19617 L
.4863 .19724 L
.47118 .19889 L
.45551 .20114 L
.44107 .20374 L
.41565 .20955 L
.38927 .21743 L
.35967 .22877 L
.3333 .2415 L
.31135 .25438 L
.28904 .27012 L
.25353 .30312 L
.23767 .32287 L
.22528 .34221 L
.21597 .36077 L
.20938 .37806 L
.20667 .3872 L
.2043 .39721 L
.20334 .40227 L
Mistroke
.20249 .40766 L
.20186 .41267 L
.20141 .41734 L
.20108 .4224 L
.20097 .42507 L
.2009 .42794 L
.20088 .43093 L
.20091 .43376 L
.20111 .43905 L
.20146 .44395 L
.20191 .44847 L
.20256 .45339 L
.20342 .45859 L
.20574 .46914 L
.20858 .47886 L
.21737 .50014 L
.22747 .51745 L
.23863 .53227 L
.25271 .54713 L
.26978 .56144 L
.28766 .57341 L
.3052 .5829 L
.32411 .59117 L
.34237 .59757 L
.36448 .60355 L
.37617 .60602 L
.38922 .60827 L
.39992 .60974 L
.4115 .61098 L
.41792 .61151 L
.42381 .61191 L
.42974 .61222 L
.43538 .61243 L
.44115 .61258 L
.4444 .61262 L
.44739 .61265 L
.4529 .61263 L
.45871 .61254 L
.46393 .6124 L
.46879 .61222 L
.47411 .61196 L
.47981 .61162 L
.49245 .61062 L
.50434 .6094 L
.52637 .60643 L
.56507 .59914 L
.60502 .58907 L
.67887 .56464 L
.74365 .53898 L
.83034 .5052 L
Mistroke
.86669 .49199 L
.88041 .48614 L
.89376 .47895 L
.89937 .47513 L
.90483 .47066 L
.90906 .46642 L
.91309 .46141 L
.91518 .45823 L
.91689 .45515 L
.91831 .45213 L
.91966 .44865 L
.9206 .44562 L
.92142 .44223 L
.92178 .4403 L
.92205 .43851 L
.92227 .43667 L
.92243 .43489 L
.92254 .43291 L
.92257 .43178 L
.92258 .43073 L
.92256 .42877 L
.92248 .42667 L
.92234 .42475 L
.92216 .42294 L
.92191 .42092 L
.92158 .41872 L
.92058 .41371 L
.91931 .40883 L
.91604 .39931 L
.91187 .38997 L
.90703 .38105 L
.89244 .36005 L
.87246 .33822 L
.84885 .31778 L
.81541 .29478 L
.77808 .27464 L
.73758 .25764 L
.71458 .24985 L
.68901 .24259 L
.66456 .23693 L
.64181 .23273 L
.63066 .23104 L
.6185 .22946 L
.60689 .22821 L
.59624 .22729 L
.58396 .22649 L
.57718 .22617 L
.57075 .22594 L
.56481 .2258 L
.55931 .22573 L
Mistroke
.55327 .22572 L
.54686 .22579 L
.54045 .22593 L
.53685 .22604 L
.53355 .22617 L
.52109 .22684 L
.5145 .22732 L
.50731 .22794 L
.49289 .2295 L
.46618 .23355 L
.43835 .2395 L
.41297 .24661 L
.39081 .25431 L
.34846 .27369 L
.31422 .29534 L
.28293 .32258 L
.26991 .33742 L
.25785 .3544 L
.24884 .37062 L
.24229 .38629 L
.24006 .39314 L
.2381 .40045 L
.23644 .40846 L
.23586 .41207 L
.23536 .41587 L
.23513 .41801 L
.23491 .42036 L
.23465 .42447 L
.23456 .42678 L
.23451 .42925 L
.23451 .43157 L
.23455 .43368 L
.23472 .43776 L
.23488 .44006 L
.23507 .44217 L
.23551 .44603 L
.2361 .4501 L
.23755 .45748 L
.23932 .46429 L
.24482 .47938 L
.25147 .49241 L
.26047 .50591 L
.2709 .51823 L
.28369 .5304 L
.31051 .5495 L
.33925 .56399 L
.3579 .57113 L
.37588 .57671 L
.39634 .58176 L
.41867 .58593 L
Mistroke
.42819 .58733 L
.43849 .58862 L
.44746 .58955 L
.45729 .59039 L
.46328 .59082 L
.46885 .59115 L
.47407 .59141 L
.47985 .59164 L
.48502 .5918 L
.48988 .59192 L
.49501 .59199 L
.4979 .59202 L
.50056 .59203 L
.50579 .59202 L
.51073 .59197 L
.51517 .5919 L
.51998 .59179 L
.52522 .59163 L
.53076 .59143 L
.54069 .59095 L
.55834 .58981 L
.57762 .58814 L
.61984 .58309 L
.65798 .57709 L
.72992 .56246 L
.78863 .54714 L
.84087 .52955 L
.86649 .51843 L
.88742 .50709 L
.90628 .49381 L
.91419 .48676 L
.92062 .47995 L
.93035 .4663 L
.93419 .45867 L
.93589 .45439 L
.93723 .45026 L
.93831 .44611 L
.93877 .4439 L
.93919 .44152 L
.93947 .43951 L
.93972 .43727 L
.93989 .43522 L
.93999 .43328 L
.94005 .43097 L
.94002 .42852 L
.93994 .42641 L
.93978 .42409 L
.93952 .42156 L
.93915 .41884 L
.93824 .41389 L
Mistroke
.9371 .40921 L
.93555 .40408 L
.93186 .39465 L
.92192 .3767 L
.90661 .35704 L
.88431 .33568 L
.8551 .31429 L
.82259 .29572 L
.7846 .27875 L
.74467 .26504 L
.70616 .25509 L
.68347 .25056 L
.66196 .24712 L
.63799 .24423 L
.62435 .24302 L
.61175 .24217 L
.60639 .24189 L
.60065 .24165 L
.59433 .24144 L
.58844 .24131 L
.58527 .24127 L
.58182 .24123 L
.57555 .24123 L
.56944 .24128 L
.5638 .24139 L
.55866 .24154 L
.55314 .24175 L
.54316 .24226 L
.53134 .24309 L
.52057 .24407 L
.49856 .24674 L
.47581 .25048 L
.45312 .2553 L
.43312 .26052 L
.39076 .27507 L
.3553 .29184 L
.32588 .31022 L
.29879 .33272 L
.28643 .34588 L
.27651 .3586 L
.2688 .37065 L
.26301 .38183 L
.25798 .39437 L
.25585 .4013 L
.25425 .40789 L
.25364 .41096 L
.25309 .41426 L
.25269 .41712 L
.25234 .42024 L
.25207 .42369 L
Mistroke
.25196 .42557 L
.2519 .42732 L
.25185 .43045 L
.2519 .43378 L
.25198 .4356 L
.25207 .43729 L
.25221 .43913 L
.25239 .44108 L
.25278 .44433 L
.25333 .4479 L
.25466 .45442 L
.25628 .46045 L
.26051 .47204 L
.26555 .4823 L
.27273 .49369 L
.28083 .50402 L
.30125 .52366 L
.32794 .54183 L
.35712 .55622 L
.38635 .56693 L
.40363 .57195 L
.42251 .57654 L
.45762 .58298 L
.47775 .58563 L
.49681 .58753 L
.50764 .58837 L
.51795 .58902 L
.52366 .58932 L
.52987 .58959 L
.53556 .5898 L
.54077 .58995 L
.5454 .59006 L
.55027 .59015 L
.55516 .59021 L
.56051 .59024 L
.56515 .59024 L
.57011 .59022 L
.57479 .59017 L
.57903 .5901 L
.58445 .58999 L
.58944 .58985 L
.6007 .58945 L
.6106 .58899 L
.62104 .58839 L
.64174 .58686 L
.66089 .58505 L
.70348 .57961 L
.74218 .57284 L
.77705 .56498 L
.83637 .54637 L
Mistroke
.86336 .53467 L
.88874 .52065 L
.90914 .50594 L
.92435 .49142 L
.93142 .48282 L
.93769 .4734 L
.94205 .4651 L
.94574 .45575 L
.94731 .45037 L
.94842 .44541 L
.94889 .44264 L
.9493 .43961 L
.94945 .43822 L
.94958 .43674 L
.94974 .43408 L
.94981 .43163 L
.94981 .42899 L
.94973 .42649 L
.94958 .42419 L
.94933 .4215 L
.94896 .41855 L
.94801 .41316 L
.94671 .40778 L
.94491 .40195 L
.94061 .39136 L
.93513 .38107 L
.92896 .37166 L
.91097 .35067 L
.88616 .32954 L
.85972 .31225 L
.82695 .29544 L
.79227 .28155 L
.7579 .2708 L
.73806 .26575 L
.71635 .26108 L
.69713 .25764 L
.67601 .25458 L
.66409 .25318 L
.65307 .25208 L
.6418 .25116 L
.63127 .25047 L
.61965 .24991 L
.61349 .2497 L
.61006 .24961 L
.6069 .24954 L
.60357 .24948 L
.59996 .24944 L
.59678 .24942 L
.59341 .24942 L
.58758 .24945 L
Mistroke
.58426 .24949 L
.58116 .24955 L
.57541 .24969 L
.56928 .2499 L
.55829 .25043 L
.54528 .2513 L
.53355 .25232 L
.51064 .25499 L
.48945 .25828 L
.45128 .26641 L
.41246 .27805 L
.37719 .29231 L
.34286 .3108 L
.31265 .33287 L
.29028 .35547 L
.28145 .36718 L
.27357 .3802 L
.2678 .3927 L
.26563 .39871 L
.26393 .40436 L
.26261 .40985 L
.26167 .41489 L
.26127 .41755 L
.26093 .42047 L
.26067 .42339 L
.26049 .42647 L
.26041 .42953 L
.26043 .43231 L
.26055 .43551 L
.26075 .43852 L
.26103 .4413 L
.26136 .44385 L
.26235 .44958 L
.26373 .45539 L
.2653 .46064 L
.26991 .47223 L
.27549 .48267 L
.28191 .49224 L
.30003 .51239 L
.31245 .52291 L
.32524 .53204 L
.3501 .54639 L
.38033 .55972 L
.41695 .57173 L
.45399 .58054 L
.49129 .58679 L
.51303 .58941 L
.53356 .59127 L
.54482 .59205 L
.55551 .59264 L
Mistroke
.56514 .59305 L
.57054 .59323 L
.5756 .59337 L
.58104 .59348 L
.58392 .59352 L
.58702 .59356 L
.59026 .59358 L
.59335 .5936 L
.59611 .5936 L
.59913 .59359 L
.60459 .59355 L
.60763 .59351 L
.6104 .59347 L
.61577 .59336 L
.62084 .59322 L
.63081 .59287 L
.64009 .59243 L
.66109 .59106 L
.68134 .58924 L
.70275 .58674 L
.74051 .58081 L
.77348 .57382 L
.8085 .56413 L
.8385 .55346 L
.86834 .5399 L
.89594 .52345 L
.91626 .5074 L
.92534 .49842 L
.93366 .48859 L
.93989 .47965 L
.9455 .4696 L
.94948 .46024 L
.9522 .45137 L
.95283 .44865 L
.95341 .44577 L
.95383 .44327 L
.9542 .44057 L
.95437 .43905 L
.9545 .43767 L
.95468 .43494 L
.95475 .43342 L
.95479 .43175 L
.9548 .43018 L
.95479 .42872 L
.95468 .42589 L
.9545 .42322 L
.95426 .42082 L
.95393 .41823 L
.9529 .41239 L
.95161 .40703 L
Mistroke
.94852 .39762 L
.94395 .38737 L
.93787 .37679 L
.93101 .36708 L
.91123 .34575 L
.88744 .32688 L
.86219 .31131 L
.83096 .29615 L
.79716 .28334 L
.75665 .27171 L
.7352 .2669 L
.71147 .26255 L
.68854 .25924 L
.6672 .2569 L
.65635 .25598 L
.64608 .25527 L
.64037 .25494 L
.63419 .25464 L
.62904 .25443 L
.62337 .25424 L
.61801 .25411 L
.61299 .25403 L
.6077 .25398 L
.60202 .25397 L
.59674 .254 L
.59173 .25407 L
.58724 .25417 L
.58236 .25431 L
.57664 .25451 L
.57126 .25475 L
.55905 .25545 L
.5472 .25634 L
.53449 .25755 L
.51181 .26034 L
.49137 .2636 L
.45082 .27237 L
.41533 .28298 L
.37954 .29717 L
.34564 .31506 L
.31808 .3345 L
.30567 .3455 L
.29421 .35766 L
.28566 .36863 L
.27788 .38101 L
.27233 .39248 L
.26846 .40334 L
.26688 .40936 L
.26576 .41496 L
.26528 .41818 L
.26493 .42111 L
Mistroke
.26478 .42273 L
.26465 .42448 L
.26456 .42613 L
.2645 .42765 L
.26446 .43041 L
.2645 .43299 L
.26462 .43581 L
.26485 .43883 L
.265 .44035 L
.26519 .44199 L
.26562 .44497 L
.26669 .45052 L
.26796 .45559 L
.26971 .46113 L
.27428 .47217 L
.27975 .48216 L
.28592 .49127 L
.30368 .51103 L
.32747 .52995 L
.35153 .54441 L
.38133 .55827 L
.41649 .57071 L
.45098 .57988 L
.47096 .5841 L
.49318 .58796 L
.51447 .59093 L
.53469 .59314 L
.55372 .59469 L
.56447 .59536 L
.57432 .59584 L
.57954 .59604 L
.58511 .59622 L
.58831 .5963 L
.59122 .59637 L
.59417 .59643 L
.59688 .59647 L
.6022 .59652 L
.60499 .59654 L
.60793 .59654 L
.61289 .59653 L
.61833 .59647 L
.6212 .59643 L
.62431 .59637 L
.62997 .59624 L
.63547 .59606 L
.64055 .59587 L
.65204 .59532 L
.66418 .59454 L
.68426 .59284 L
.7061 .59037 L
Mistroke
.74657 .5839 L
.7819 .57599 L
.82005 .5645 L
.85311 .55128 L
.88087 .53688 L
.90635 .51959 L
.92606 .50162 L
.93998 .48415 L
.94602 .47401 L
.95101 .46304 L
.95413 .45351 L
.95542 .44804 L
.95631 .44291 L
.95668 .44005 L
.95683 .43854 L
.95696 .43693 L
.95706 .43553 L
.95713 .43398 L
.9572 .43125 L
.95719 .4286 L
.95708 .42575 L
.95689 .42305 L
.95665 .42058 L
.95628 .41769 L
.95584 .415 L
.95455 .4089 L
.95289 .40298 L
.95067 .39668 L
.9453 .38504 L
.93896 .37448 L
.91987 .35153 L
.89783 .33266 L
.86959 .31445 L
.83992 .2997 L
.80437 .28604 L
.76786 .27539 L
.73246 .26767 L
.71244 .26428 L
.69071 .26135 L
.66991 .25921 L
.66066 .25847 L
.65087 .25782 L
.64525 .2575 L
.63909 .25721 L
.63341 .25699 L
.62823 .25683 L
.6221 .25669 L
.61873 .25664 L
.61553 .2566 L
.60985 .25657 L
Mistroke
.60665 .25657 L
.60368 .25659 L
.59839 .25665 L
.59342 .25674 L
.58798 .25688 L
.58212 .25707 L
.57022 .25763 L
.55936 .25831 L
.53863 .2601 L
.51679 .2627 L
.47851 .26915 L
.45591 .27422 L
.43532 .27975 L
.39901 .29202 L
.36641 .30648 L
.33616 .32406 L
.31417 .34072 L
.2945 .36048 L
.28593 .37169 L
.2792 .38258 L
.27434 .39253 L
.27034 .40349 L
.26881 .40919 L
.26754 .4155 L
.26706 .41868 L
.26686 .42034 L
.26668 .4221 L
.26655 .42365 L
.26644 .42534 L
.26632 .42831 L
.2663 .43132 L
.26637 .43406 L
.26644 .43557 L
.26655 .43721 L
.26683 .44019 L
.26717 .44297 L
.26764 .44591 L
.26871 .45116 L
.27022 .45682 L
.27199 .46216 L
.2762 .47205 L
.28197 .48247 L
.28972 .49352 L
.30727 .51238 L
.32749 .52855 L
.3563 .546 L
.38746 .56031 L
.41831 .57129 L
.45422 .5811 L
.49167 .58863 L
Mistroke
.51365 .59196 L
.53453 .59445 L
.54598 .59555 L
.55689 .59642 L
.56684 .59709 L
.57746 .59764 L
.58295 .59787 L
.58902 .59808 L
.59454 .59823 L
.59973 .59833 L
.6027 .59838 L
.60583 .59841 L
.61142 .59844 L
.61453 .59844 L
.61743 .59842 L
.62061 .5984 L
.62401 .59835 L
.62928 .59826 L
.63508 .59811 L
.64112 .59791 L
.64677 .59767 L
.65685 .59716 L
.66763 .59645 L
.69201 .59427 L
.71395 .59157 L
.75548 .5844 L
.79285 .57526 L
.827 .56413 L
.86005 .55001 L
.8876 .53466 L
.9091 .51921 L
.92443 .5052 L
.93793 .48917 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 229.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001F2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00h03oool00`3ooml0W4P0000000020000000307Bo
o`3oool0oooo0<P0oooo003R0?ooo`030?noM00007@0_ooo0</0oooo003R0?ooo`030?oo_`1d0000
M;oo0</0oooo003R0?ooo`030?oog`2LB000B9cO0</0oooo003S0?ooo`030=nLB000000000000080
000000<0M;oo0?ooo`3oool00P3oool01@3o_g@000000000000004P0W=oo0080oooo00<0oono07@0
000000000P0000003@18W=l0oooo0?ooo`3oool0_g@00000000004P0W=oo0?ooo`3o_g@000000000
B02Lgol00P3oool0102oM00000000000B02Lgol20?ooo`050?noM000000000000000B02Lgol00`3o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000000007Bo0980oooo003S0?ooo`070?noM00004P0
W=oo0?ooo`3ooml0W4P0001d_`020?ooo`0?0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`3oool0
oooO09a8001d_ol0oooo0?oOW0180000M;oo0080oooo01L0gia80018W03Ooml0W7BL0=ooo`3o_g@0
001809cOg`2LM9`0gooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0
B000001d_`020?ooo`030?noM00007@0_ooo0080oooo00@0gia80018W03O_g@0M;ooT@3oool00><0
oooo00<0oono07@0001d_ol00P3oool01`3ooml0W4P004RLg`3oool0gia80018W03Oool00P3oool0
2P3ogi`0B00004RLg`3oool0_gAd0;ooo`3oool0oono07@0001d_ol20?ooo`030?noM00004P0W=oo
0080oooo00<0oono07@0001d_ol00`3oool00`3o_g@0001809cOo`020?ooo`030=nLB000B9`0gooo
0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol0TP3o
ool00><0oooo00<0oooO09a80018W=l00`3oool01P3ogi`0B01809cOo`3o_g@0001d0;ooo`<0oooo
00<0gia80000M02oool00`3oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo
00<0_g@0001d_`3oool00P3oool00`3ookl0M00004RLg`020?ooo`030?noM00007@0_ooo00<0oooo
00/0gia80000M02oool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`2B0?ooo`00i03oool0
0`3OW4P0001d0;ooo`020?ooo`060?oog`2LB000B9cO0?oo_`1d0000M;oo0`3oool00`3ogi`0B018
09cOo`020?ooo`030?noM00004P0W=oo00@0oooo00<0_g@00018W03Oool00P3oool00`3OW4P004RL
0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3ookl0M00007Boo`030?ooo`070?oOW01804P0W=oo
0?ooo`3OW4P004Q804Qd_`020?ooo`030;md0000M;l0oooo0940oooo003T0?ooo`040?noM0000000
04RL0=ooo`80oooo00H0gia8001d_`3oool0gia80000M02oool20?ooo`0:0?oo_`1d0000M;oo0?oo
o`3ogi`0B01809cOo`3oool0giad09cOo`80oooo00<0gia80000B02Lgol00P3oool00`3ogi`0B018
09cOo`030?ooo`030=nLB00004P0W=oo0080oooo00<0gia80000M02oool00P3oool0303ookl0M000
07Boo`3oool0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;oooi40oooo003T0?ooo`080?oo_`1d
0000M9bL04P0M02oool0oooO09a80000M;l20?ooo`0>0;md000007@0_ooo0?ooo`3o_g@0001d0;oo
o`3oool0omnL04P0B02Lgol0oooO09a8001d_ol20?ooo`030?oOW0180000B9cO0080oooo00<0oooO
09a80018W=l00`3oool00`3ogi`0B00004RLg`030?ooo`0@0;md000007@0_ooo0?ooo`3o_g@0001d
0;ooo`3oool0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOoi40oooo003S0?ooo`090?oOW018
0000000004RLg`3ookl0M0000000000007@0_ooo00<0oooo00D0okmd000000000000000007Boo`03
0?ooo`070;md00000000000000000018W=l0oooo0?noM002000000040018W03Oool0oono07@000<0
000000H0M;oo0?noM000000000000018W03Oool30?ooo`0?0?noM000000000000000001d_ol0oooo
0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo0940oooo003o0?ooo`D0oooo00<0okmd
0000M02oool0Z@3oool00?l0oooo1P3oool00`3OW7@0W=oo0?ooo`2X0?ooo`00o`3oool0103ookl0
M0000018W03Oool70?ooo`040?oo_`1d000004RL0=oooj80oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo001c0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P0
0000000000030000000304RLg`3oool0oooo0180oooo00@0_g@0000000000000M;oo0`3oool00`3o
gi`0B00007Boo`020?ooo`030?oo_`1d000000000080000000H0B9cO0?ooo`3oool0oooo0?oOW018
0002000000030018W03Oool0oooo01@0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B000
07Boo`020?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0503oool0102oM0000000
0000001d_ol30?ooo`030?oOW0180000M;oo00@0oooo00@0_g@0000000000000M;oo0`3oool01P3o
gi`0B00000000000000004RL0=oooaD0oooo00@0_g@0000000000000M;oo7@3oool0102oM0000000
0000001d_ol30?ooo`030?oOW0180000M;oo00@0oooo00@0_g@0000000000000M;oo0`3oool01P3o
gi`0B00000000000000004RL0=oooaD0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B000
07Boo`020?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0:@3oool00780oooo00H0
gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00<0oooo00<0okmd001d_`3o
ool00P3oool00`2oM7@0_ooo0?ooo`0A0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool0
0`3ogi`0B00007Boo`040?ooo`030?noM0000000M;oo00@0oooo00H0okmd0000001d_ol0oooo0?oO
W018M;lD0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`040?oo
o`030?noM0000000M;oo01H0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW018
0000M;oo00<0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`060?noM0000000M;oo0?oo
o`3ogi`0B7Bo503oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLga/0oooo00H0gia8001d_`3oool0
omnL04P00018W=l20?ooo`030?oOW0180000M;oo00<0oooo00H0gia8001d_`3oool0omnL04P00018
W=l20?ooo`060?noM0000000M;oo0?ooo`3ogi`0B7Bo503oool01P3OW4P007Bo0?ooo`3ogi`0B000
04RLg`80oooo00<0omnL04P0001d_ol0103oool00`3o_g@0000007Boo`0/0?ooo`00L@3oool00`3o
oml0W4P004RLg`020?ooo`030?noM00004P0W=oo00P0oooo00<0okmd001d_`3oool0503oool00`3o
oml0W4P004RLg`020?ooo`030?noM00004P0W=oo00P0oooo00<0oooO09a80000M;l02@3oool00`3o
_g@0B9cO0?ooo`0A0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0203oool00`3o
oml0W4P0001d_`0E0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol01P3oool00`3o
oml0W4P004RLg`020?ooo`030?noM00004P0W=oo00H0oooo00<0okmd04RLg`3oool04@3oool00`3o
oml0W4P004RLg`020?ooo`030?noM00004P0W=oo01T0oooo00<0oooO09a80018W=l00P3oool00`3o
_g@0001809cOo`060?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol01P3oool00`3o
_g@0B9cO0?ooo`0A0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0203oool00`3o
oml0W4P0001d_`0/0?ooo`00L@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=oo
o`P0oooo00<0okmd001d_`3oool04`3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL
0=ooo`P0oooo00<0gia80018W03Oool0203oool00`3ookl0M01d0;ooo`0A0?ooo`030?oog`2LB000
B9cO0080oooo00@0oooO09a80000B9`0gooo203oool00`3OW4P004RL0=ooo`0D0?ooo`030?oog`2L
B000B9cO0080oooo00@0oooO09a80000B9`0gooo1@3oool00`3ooml0W4P004RLg`020?ooo`040?oo
g`2LB00004RL0=ooo`D0oooo00<0oono07@0M02oool04@3oool00`3ooml0W4P004RLg`020?ooo`04
0?oog`2LB00004RL0=oooaP0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool5
0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo1@3oool00`3ookl0M01d0;oo
o`0A0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo203oool00`3OW4P004RL
0=ooo`0[0?ooo`00I03oool00`3ooml0W4P0000000070000000604RLg`3oool0oooo0?oog`2LB000
07Bo0`3oool00`3OW4P0001809cOo`090?ooo`030?noM018W=l0oooo00D0oooo00<0oooO09a80000
00001`0000001P18W=l0oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol0203oool0
0`3ogi`0B01809cOo`080?ooo`030?oog`2LB000M;oo00@0oooo00<0oooO09a8000000001`000000
1P18W=l0oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol0203oool00`3ogi`0B018
09cOo`070?ooo`030?oog`2LB000000000L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?oo
o`030=nLB00004P0W=oo00D0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`050?oo
o`030?oog`2LB000M;oo0140oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`0H0?oo
o`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol01@3oool00`3ooml0W4P0001d_`030?oo
o`030=nLB00004P0W=oo00D0oooo00<0oooO09a8001d_ol04@3oool00`3ooml0W4P0001d_`030?oo
o`030=nLB00004P0W=oo00P0oooo00<0omnL04P0B02Lgol0:`3oool00780oooo00<0_g@00018W03O
ool00P3oool00`3ogi`0B00004RLg`0:0?ooo`030=nLB018W=l0oooo0180oooo00<0_g@00018W03O
ool00P3oool00`3ogi`0B00004RLg`080?ooo`030?oo_`1d0000M;oo00P0oooo00<0oono07@00018
W=l04P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00P0oooo00<0oono07@0001d
_ol05@3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00H0oooo00<0_g@00018W03O
ool00P3oool00`3ogi`0B00004RLg`050?ooo`030?oo_`1d0000B9cO0180oooo00<0_g@00018W03O
ool00P3oool00`3ogi`0B00004RLg`0I0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018
W=l01P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00D0oooo00<0oono07@00018
W=l04P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00P0oooo00<0oono07@0001d
_ol0:`3oool00780oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0;0?ooo`030;md
001d_ol0oooo0140oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`090?ooo`030;md
0000M;l0oooo00L0oooo00<0okmd0000001d_ol04P3oool00`3OW4P0001809cOo`020?ooo`030?oo
g`2LB00007Bo00T0oooo00<0_g@0001d_`3oool0503oool00`3OW4P0001809cOo`020?ooo`030?oo
g`2LB00007Bo00H0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`050?ooo`030?no
M0000000M;oo0180oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0I0?ooo`030=nL
B00004P0W=oo0080oooo00<0oooO09a80000M;l01P3oool00`3OW4P0001809cOo`020?ooo`030?oo
g`2LB00007Bo00D0oooo00<0okmd0000001d_ol04P3oool00`3OW4P0001809cOo`020?ooo`030?oo
g`2LB00007Bo00T0oooo00<0_g@0001d_`3oool0:P3oool00780oooo00<0omnL04P00018W=l00`3o
ool00`2oM00004RL0=ooo`0:0?ooo`030?oOW01807@0_ooo0140oooo00<0omnL04P00018W=l00`3o
ool00`2oM00004RL0=ooo`080?ooo`030=nLB000B9`0gooo00@0oooo00H0omoO0=ooo`3o_g@00000
0000M02ooolB0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool0203oool00`3OW4P0
04RL0=ooo`0D0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01@3oool00`3ogi`0
B00004RLg`030?ooo`0:0;md0000B9`0gooo0?ooo`3ogml0gooo0?noM0000000001d0;oooa80oooo
00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`0H0?ooo`030?oOW0180000B9cO00<0oooo
00<0_g@00018W03Oool01@3oool00`3ogi`0B00004RLg`030?ooo`0:0;md0000B9`0gooo0?ooo`3o
gml0gooo0?noM0000000001d0;oooa80oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=oo
o`080?ooo`030=nLB000B9`0gooo02X0oooo001b0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0
gia80018W03Oool02P3oool00`3ooml0W4P007Boo`0A0?ooo`040?oog`2LB00004RL0=ooo`80oooo
00<0gia80018W03Oool0203oool00`3ogi`0B01809cOo`040?ooo`050?oo_`1d000000000000B02L
gol04`3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00P0oooo00<0omnL04P0
B02Lgol0503oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00D0oooo00@0oooO
09a80000B9`0gooo0P3oool02@3OW4P004RL0=ooo`3oool0oono07@000000000001809cOo`0C0?oo
o`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0603oool0103ooml0W4P00018W03O
ool20?ooo`030=nLB000B9`0gooo00D0oooo00@0oooO09a80000B9`0gooo0P3oool02@3OW4P004RL
0=ooo`3oool0oono07@000000000001809cOo`0C0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0
gia80018W03Oool0203oool00`3ogi`0B01809cOo`0Z0?ooo`00L`3oool00`3ogi`0B00007Boo`02
0?ooo`030=nLB000M;l0oooo00X0oooo00<0oono07@00018W=l04P3oool00`3ogi`0B00007Boo`02
0?ooo`030=nLB000M;l0oooo00P0oooo00<0oono07@0001d_ol01@3oool00`3OW9`0_ooo0?ooo`0E
0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0203oool00`3ookl0M00007Boo`0E
0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01P3oool00`3ogi`0B00007Boo`02
0?ooo`030=nLB000M;l0oooo0080oooo00<0gibL0;ooo`3oool05@3oool00`3ogi`0B00007Boo`02
0?ooo`030=nLB000M;l0oooo01T0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`06
0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool00P3oool00`3OW9`0_ooo0?ooo`0E
0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool0203oool00`3ookl0M00007Boo`0Z
0?ooo`00M03oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`L0oooo00L0okmd0018W03Oool0oooo
0=nLB00004P0W=oo01<0oooo00H0gia80000M02oool0oooO09a80018W=l:0?ooo`030;md0000M;l0
oooo00@0oooo00<0omnL07BLg`3oool05P3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`X0oooo
00<0_g@0001d_`3oool05@3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`P0oooo00H0gia80000
M02oool0oooO09a80018W=l30?ooo`030?oOW01dW=l0oooo01H0oooo00H0gia80000M02oool0oooO
09a80018W=lK0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO203oool01P3OW4P0001d0;ooo`3o
oml0W4P004RLg`<0oooo00<0omnL07BLg`3oool05P3oool01P3OW4P0001d0;ooo`3ooml0W4P004RL
g`X0oooo00<0_g@0001d_`3oool0:@3oool007D0oooo00@0gia800000000000007Bo2@3oool01@3o
gi`0B000000000000000M;oo01D0oooo00@0gia800000000000007Bo2@3oool01@3ookl0M0000000
000007@0_ooo00D0oooo00D0_g@0000000000000000004RLg`0D0?ooo`040=nLB00000000000001d
_`T0oooo00D0oono07@000000000001d0;ooo`0F0?ooo`040=nLB00000000000001d_`X0oooo00@0
gia800000000000007Bo1@3oool01@2oM0000000000000000000B9cO01@0oooo00@0gia800000000
000007Bo7@3oool0103OW4P0000000000000M;l:0?ooo`040=nLB00000000000001d_`D0oooo00D0
_g@0000000000000000004RLg`0D0?ooo`040=nLB00000000000001d_`T0oooo00D0oono07@00000
0000001d0;ooo`0Y0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00F@3ooooo000004h000002P3oool005T0oooo00@000000?ooo`3oool000001`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo001I0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`00F@3oool200000<X0oooo
00<000000?ooo`3oool0O03oool2000000X0oooo001I0?ooo`030000003oool0oooo0<T0oooo00<0
00000?ooo`3oool0O@3oool00`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo0?ooo`39
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0203oool005T0oooo00<000000?oo
o`3oool0b@3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00P0oooo000e0?ooo`04
0;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol00P3oool00`3ookl0M000000000020000
000604RLg`3oool0oooo0?ooo`3ogi`0B0000P0000000`00B9`0gooo0?ooo`080?ooo`030000003o
ool0oooo0900oooo8@00000H0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0203o
ool003@0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00@0oooo
00<0okmd0000001d_ol0103oool01P3o_g@0000007Boo`3oool0omnL04Qd_`T0oooo00<000000?oo
o`3oool0QP3oool:00000240oooo2`00000=0?ooo`030000003oool0oooo07d0oooo00<000000?oo
o`3oool0203oool003<0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`03
0?oog`2LB00007Bo00T0oooo00<0okmd04RLg`3oool01`3oool00`000000oooo0?ooo`1o0?ooo`L0
0000=P3oool4000000T0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`080?ooo`00
<`3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<0gia80018W03O
ool0203oool00`3ookl0M01d0;ooo`070?ooo`030000003oool0oooo07/0oooo100000110?ooo`D0
0000103oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00P0oooo000V0?ooo`030?oo
g`2LB000000000L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`030=nLB00004P0W=oo
00P0oooo00<0omnL04P0B02Lgol0203oool00`3ooml0W4P007Boo`070?ooo`030000003oool0oooo
07L0oooo1000001:0?ooo`D00000O`3oool00`000000oooo0?ooo`080?ooo`00=03oool00`2oM000
04RL0=ooo`020?ooo`030?oOW0180000B9cO00P0oooo00<0oono07@0001d_ol0203oool00`3ookl0
M00004RLg`070?ooo`<00000L`3oool400000580oooo1000001j0?ooo`<000002P3oool003@0oooo
00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`090?ooo`030;md0000M;l0oooo00L0oooo
00<0okmd0000001d_ol01`3oool00`000000oooo0?ooo`1_0?ooo`@00000EP3oool010000000oooo
0?ooo`3oool4000007P0oooo00<000000?ooo`3oool0203oool003@0oooo00<0omnL04P00018W=l0
0`3oool00`2oM00004RL0=ooo`080?ooo`030=nLB000B9`0gooo00@0oooo00H0omoO0=ooo`3o_g@0
00000000M02oool70?ooo`030000003oool0oooo06`0oooo0`00001J0?ooo`030000003oool0oooo
00D0oooo1000001d0?ooo`030000003oool0oooo00P0oooo000d0?ooo`040?oog`2LB00004RL0=oo
o`80oooo00<0gia80018W03Oool0203oool00`3ogi`0B01809cOo`040?ooo`050?oo_`1d00000000
0000B02Lgol0203oool00`000000oooo0?ooo`1Y0?ooo`<00000G@3oool00`000000oooo0?ooo`09
0?ooo`<00000L@3oool00`000000oooo0?ooo`080?ooo`00=@3oool00`3ogi`0B00007Boo`020?oo
o`030=nLB000M;l0oooo00P0oooo00<0oono07@0001d_ol01@3oool00`3OW9`0_ooo0?ooo`090?oo
o`030000003oool0oooo06H0oooo0`00001P0?ooo`030000003oool0oooo00`0oooo0`00001^0?oo
o`030000003oool0oooo00P0oooo000f0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO2P3oool0
0`2oM00007Bo0?ooo`040?ooo`030?oOW01dW=l0oooo00T0oooo00<000000?ooo`3oool0H`3oool3
000006<0oooo00<000000?ooo`3oool03`3oool3000006/0oooo00<000000?ooo`3oool0203oool0
03L0oooo00@0gia800000000000007Bo2@3oool01@3ookl0M0000000000007@0_ooo00D0oooo00D0
_g@0000000000000000004RLg`060?ooo`030000003oool0oooo0600oooo0`00001V0?ooo`030000
003oool0oooo0180oooo0`00001X0?ooo`030000003oool0oooo00P0oooo001I0?ooo`030000003o
ool0oooo05d0oooo0`00001Y0?ooo`030000003oool0oooo01D0oooo0`00001U0?ooo`030000003o
ool0oooo00P0oooo001I0?ooo`030000003oool0oooo05/0oooo0P00001/0?ooo`030000003oool0
oooo01P0oooo0P00001S0?ooo`030000003oool0oooo00P0oooo001I0?ooo`800000FP3oool20000
06h0oooo00<000000?ooo`3oool06P3oool200000600oooo0P00000:0?ooo`00F@3oool00`000000
oooo0?ooo`1G0?ooo`800000L03oool00`000000oooo0?ooo`0L0?ooo`800000G`3oool00`000000
oooo0?ooo`080?ooo`00F@3oool00`000000oooo0?ooo`1E0?ooo`800000LP3oool00`000000oooo
0?ooo`0N0?ooo`800000G@3oool00`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo0?oo
o`1C0?ooo`800000M03oool00`000000oooo0?ooo`0P0?ooo`800000F`3oool00`000000oooo0?oo
o`080?ooo`00F@3oool00`000000oooo0?ooo`1A0?ooo`800000MP3oool00`000000oooo0?ooo`0R
0?ooo`800000F@3oool00`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo0?ooo`1?0?oo
o`800000N03oool00`000000oooo0?ooo`0T0?ooo`800000E`3oool00`000000oooo0?ooo`080?oo
o`00F@3oool00`000000oooo0?ooo`1=0?ooo`800000NP3oool00`000000oooo0?ooo`0V0?ooo`80
0000E@3oool00`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo07X0oooo00<000000?ooo`3oool0:03oool2000005<0oooo00<000000?ooo`3oool0
203oool005T0oooo0P00001;0?ooo`800000O@3oool00`000000oooo0?ooo`0Z0?ooo`800000D03o
ool2000000X0oooo001I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0O@3oool0
0`000000oooo0?ooo`0/0?ooo`800000C`3oool00`000000oooo0?ooo`080?ooo`00F@3oool00`00
0000oooo0?ooo`170?ooo`800000P03oool00`000000oooo0?ooo`0^0?ooo`800000C@3oool00`00
0000oooo0?ooo`080?ooo`00F@3oool00`000000oooo0?ooo`150?ooo`800000PP3oool00`000000
oooo0?ooo`0`0?ooo`800000B`3oool00`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`180?ooo`030000003oool0oooo00P0oooo001I0?ooo`030000003oool0oooo0480oooo0P00
00250?ooo`030000003oool0oooo03<0oooo0P0000180?ooo`030000003oool0oooo00P0oooo001I
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0203oool005T0oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo0?ooo`0n0?ooo`80
0000R@3oool00`000000oooo0?ooo`0g0?ooo`800000A03oool00`000000oooo0?ooo`080?ooo`00
F@3oool2000003h0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo0400oooo0P00000:0?ooo`00F@3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo08X0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo00P0oooo001I0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0R`3oool0
0`000000oooo0?ooo`0k0?ooo`800000@03oool00`000000oooo0?ooo`080?ooo`00F@3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0m0?ooo`030000003oool0oooo00P0oooo001I0?ooo`030000003oool0oooo03P0
oooo0P00002?0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`080?ooo`00F@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00P0oooo
001I0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`100?ooo`800000>`3oool00`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo0680oooo5`00000H0?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo05P0oooo2`00000G0?ooo`X000003P3oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0203oool005T0oooo0P00000c0?ooo`80
0000E@3oool6000002`0oooo1P0000080?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool0=@3oool2000000X0oooo001I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
D03oool5000003P0oooo1P0000020?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo04d0oooo100000130?ooo`@00000A`3oool2000003D0oooo00<000000?ooo`3oool0203o
ool005T0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1;0?ooo`<00000B@3oool0
0`000000oooo00000003000004D0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`08
0?ooo`00?P3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo0080oooo00<0oono
07@0000000000P0000000`18W=l0oooo0?ooo`070?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0B@3oool3000004`0oooo00<000000?ooo`3oool00`3oool400000480oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`080?ooo`00?@3oool01P3OW4P007Bo0?ooo`3ogi`0
B00004RLg`80oooo00<0omnL04P0001d_ol0103oool00`3o_g@0000007Boo`0:0?ooo`030000003o
ool0oooo02`0oooo0P00001:0?ooo`800000C`3oool00`000000oooo0?ooo`070?ooo`<00000@03o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00P0oooo000l0?ooo`030?oog`2LB000
B9cO0080oooo00<0okmd0000B02Lgol0203oool00`3ooml0W4P0001d_`0:0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool0A`3oool300000540oooo00<000000?ooo`3oool02P3oool3
000003h0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`080?ooo`00?03oool00`3o
oml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<0gia80018W03Oool02@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo04D0oooo0`00001D0?ooo`030000003oool0
oooo00d0oooo0P00000m0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0203oool0
02l0oooo00<0oooO09a8000000001`0000001P18W=l0oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0
gia80000B02Lgol0203oool00`3ogi`0B01809cOo`090?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0@`3oool3000005L0oooo00<000000?ooo`3oool03`3oool3000003/0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`080?ooo`00?@3oool00`2oM00004RL0=ooo`02
0?ooo`030?oOW0180000B9cO00P0oooo00<0oono07@0001d_ol02@3oool3000002P0oooo00<00000
0?ooo`3oool0@P3oool2000005X0oooo00<000000?ooo`3oool04P3oool3000003T0oooo00<00000
0?ooo`3oool0:P3oool3000000X0oooo000m0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a8
0000M;l02@3oool00`2oM00007Bo0?ooo`080?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool0@03oool3000005`0oooo00<000000?ooo`3oool05@3oool2000003P0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`080?ooo`00?@3oool00`3ogi`0B00004RLg`030?ooo`03
0;md0000B9`0gooo00P0oooo00<0gia80018W03Oool0203oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo03h0oooo0P00001O0?ooo`030000003oool0oooo01L0oooo0`00000f0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0203oool003d0oooo00@0oooO09a80000B9`0
gooo0P3oool00`3OW4P004RL0=ooo`080?ooo`030?oOW01804P0W=oo00P0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0m0?ooo`800000H@3oool00`000000oooo0?ooo`0J0?ooo`80
0000=@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00P0oooo000n0?ooo`030?oO
W0180000M;oo0080oooo00<0gia8001d_`3oool0203oool00`3ookl0M00007Boo`080?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool0?03oool2000006<0oooo00<000000?ooo`3oool0
703oool2000003@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`080?ooo`00?`3o
ool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`X0oooo00<0_g@0001d_`3oool01`3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo03/0oooo0P00001U0?ooo`030000003oool0oooo01h0
oooo0P00000c0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool00400oooo
00@0gia800000000000007Bo2@3oool01@3ookl0M0000000000007@0_ooo00L0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0j0?ooo`800000I`3oool00`000000oooo0?ooo`0P0?oo
o`800000<P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo001I0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0>@3oool2000006T0oooo00<000000?ooo`3o
ool08P3oool200000340oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`00
F@3oool2000002<0oooo00<000000?ooo`3oool0=`3oool2000006/0oooo00<000000?ooo`3oool0
903oool200000300oooo00<000000?ooo`3oool08`3oool2000000X0oooo001I0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`140?oooaT000003P3o
ool00`000000oooo0?ooo`0V0?ooo`800000;`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo00P0oooo001I0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0j0?ooo`/000006@3oool6000000P0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool0
05T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0f0?ooo`800000>03oool50000
02X0oooo2@00000[0?ooo`800000;@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00P0oooo001I0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`0d0?ooo`@00000=`3oool6000002P0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00P0oooo001I0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0a0?ooo`@00000>`3oool00`000000oooo
0?ooo`030?ooo`@000009@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0203oool005T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0d0?ooo`800000;`3oool5000003l0oooo00<000000?ooo`3oool01`3oool3000002<0oooo0P00
000/0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0203oool005T0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02/0oooo10000014
0?ooo`030000003oool0oooo00X0oooo0`00000R0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0:03oool4000004P0oooo00<000000?oo
o`3oool03@3oool300000200oooo0P00000Z0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0203oool005T0oooo0P00000L0?ooo`030000003oool0oooo0380oooo0P00000Y0?ooo`80
0000C03oool00`000000oooo0?ooo`0@0?ooo`<000007`3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo01`0oooo0P00000:0?ooo`00F@3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool09P3oool3000004h0oooo00<000000?ooo`3oool0
4`3oool3000001d0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00P0oooo001I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`0U0?ooo`800000<P3ooolG000000P0oooo00<000000?ooo`3oool05P3o
ool2000001`0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00P0oooo001I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0;`3oool2
000002H0oooo0P00000Y0?ooo`/000005`3oool;000001P0oooo0`00000J0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`080?ooo`00F@3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0903oool20000
02L0oooo1000000Z0?ooo`030000003oool0oooo00P000004`3oool3000001P0oooo0P00000X0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203oool005T0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02<0oooo0P00000T0?ooo`D0
0000;P3oool00`000000oooo0?ooo`080?ooo`@000004P3oool3000001L0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo001I0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0R0?ooo`800000
8P3oool4000003<0oooo00<000000?ooo`3oool0303oool400000140oooo0P00000F0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`080?ooo`00F@3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool08@3o
ool2000001l0oooo1@00000R0?oooa<000000P3oool00`000000oooo0?ooo`0@0?ooo`@000003`3o
ool2000001D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00P0oooo001I0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0P0?ooo`8000007@3oool4000001X0oooo3@00000C0?ooo`h000002`3oool4
000000d0oooo0P00000D0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`080?ooo`00F@3oool2000001L0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo01T0oooo1000000G0?ooo`L000008P3oool00`00
0000oooo0?ooo`090?ooo`P000001`3oool4000000/0oooo0P00000C0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool05P3oool2000000X0oooo001I0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0O0?ooo`8000006P3oool2000001D0
oooo1P00000E0?oooa`00000303oool5000000H0oooo100000090?ooo`8000004P3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0203oool005T0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01h0oooo
0P00000J0?ooo`8000004`3oool400000140oooo2P00000<0?ooo`T000001`3oool:000000L0oooo
100000060?ooo`8000002@3oool200000140oooo0P00000T0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0203oool005T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05`3oool300000140oooo1000
000>0?ooo`L000001P3oool`000000D0oooo100000040?ooo`<00000203oool200000140oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0oooo001I
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0M
0?ooo`800000603oool200000140oooo0`00000<0?ooo`H000001`3ooolB000000`0oooo00<00000
0?ooo`3oool0103ooolH00000080oooo100000030?ooo`<000001`3oool200000100oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00P0oooo001I0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo01H0oooo0P00000@0?ooo`<000002`3oool4000000H0oooo2@00000L0?oo
o`030000003oool0oooo01<0oooo4`0000020?ooo`8000001`3oool2000000l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo001I0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01@0oooo0`00000>0?ooo`@000002P3oool4000000@0oooo2000000S0?ooo`03
0000003oool0oooo01X0oooo4`0000060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo001I0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0L0?ooo`800000
5@3oool2000000h0oooo0`0000090?ooo`D00000103oool6000002T0oooo00<000000?ooo`3oool0
8@3oool;000000040?ooo`0000000000000000@0oooo0P00000>0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0C0?ooo`800000303oool4000000P0oooo100000050?ooo`D00000;P3oool00`000000oooo
0?ooo`0V0?ooo`T0000000<0oooo000000000000103oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`00F@3o
ool200000180oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo0180oooo0P00000<0?ooo`800000203oool4000000D0oooo1@00000b0?ooo`030000003o
ool0oooo02X0oooo2P0000030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0A0?ooo`8000002P3oool005T0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04@3oool2
000000`0oooo0P0000060?ooo`@000001@3oool5000003H0oooo00<000000?ooo`3oool0;P3oool8
00000080oooo0P00000<0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0@0?ooo`800000303oool20000
00H0oooo0P0000050?ooo`H00000>@3oool00`000000oooo0?ooo`0b0?ooo`L0000000<0oooo0000
003oool02`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0203oool003D0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`040?oo
o`040;md00000000000007Boo`<0oooo00H0omnL04P00000000000000018W03Oool90?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool02P3oool2000000H0oooo0P0000030?ooo`L00000
?03oool00`000000oooo0?ooo`0f0?ooo`L000002`3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0203oool003@0oooo00H0gia8001d_`3oool0omnL
04P00018W=l20?ooo`030?oOW0180000M;oo00<0oooo00H0gia8001d_`3oool0omnL04P00018W=l2
0?ooo`060?noM0000000M;oo0?ooo`3ogi`0B7Bo2@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0?0?ooo`800000
2`3oool2000000D0oooo0`0000030?ooo`80000000@0oooo0000000000000000?`3oool00`000000
oooo0?ooo`0i0?ooo`H000002P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0203oool003<0oooo00<0oooO09a80018W=l00P3oool00`3o_g@00018
09cOo`060?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol01P3oool00`3o_g@0B9cO
0?ooo`070?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0I0?ooo`800000403oool2000000/0oooo0P0000050?ooo`800000103oool500000480oooo
00<000000?ooo`3oool0?03oool5000000T0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00P0oooo000c0?ooo`030?oog`2LB000B9cO0080oooo00@0
oooO09a80000B9`0gooo1@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`D0
oooo00<0oono07@0M02oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`8000002`3oool2000000D0
oooo0P0000030?ooo`D00000A@3oool00`000000oooo0?ooo`0n0?ooo`H000001`3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool002H0oooo
00<0oooO09a8000000001`0000001P18W=l0oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0gia80000
B02Lgol01@3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00D0oooo00<0oooO09a8
001d_ol01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo0P0000050?oo
o`8000000`3oool4000004P0oooo00<000000?ooo`3oool0@03oool6000000D0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo000d0?ooo`03
0;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01P3oool00`2oM00004RL0=ooo`020?ooo`03
0?oOW0180000B9cO00D0oooo00<0oono07@00018W=l01`3oool3000000h0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0203oool2000000D0oooo0P0000030?ooo`@00000BP3oool00`000000oooo0?ooo`110?ooo`L0
0000103oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00`0oooo0`00000:0?ooo`00
=03oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00H0oooo00<0gia80000B02Lgol0
0P3oool00`3ooml0W4P0001d_`050?ooo`030?noM0000000M;oo00L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`@00000
C03oool00`000000oooo0?ooo`130?ooo`030000003oool0000000@000000`3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool003@0oooo00<0
omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`050?ooo`030?oOW0180000B9cO00<0oooo00X0
_g@00018W03Oool0oooo0?oOg`3Oool0okmd0000000007@0_ooo1`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00L0oooo0P0000040?ooo`8000000`3oool4000004h0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`0500000080oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo000d0?ooo`040?oog`2LB00004RL
0=ooo`80oooo00<0gia80018W03Oool01@3oool0103ooml0W4P00018W03Oool20?ooo`090=nLB000
B9`0gooo0?ooo`3ookl0M0000000000004P0W=oo00P0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`060?ooo`800000103oool2000000<0oooo1000001@0?ooo`030000003oool0oooo
04D0oooo0P0000020?ooo`D0000000<0oooo0000003oool0703oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00P0oooo000e0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3o
ool01P3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo0080oooo00<0gibL0;ooo`3o
ool02@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0=0?ooo`800000203oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo0?ooo`@00000DP3oool00`000000oooo0?ooo`170?ooo`040000003oool0oooo
0?ooo`D000007@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo000f0?oo
o`060=nLB00007@0_ooo0?oog`2LB000B9cO203oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`<0
oooo00<0omnL07BLg`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04000005@0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`020?ooo`D00000703oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00P0oooo000g0?ooo`040=nLB00000000000001d_`X0oooo00@0gia800000000
000007Bo1@3oool01@2oM0000000000000000000B9cO00H0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0
000005H0oooo00<000000?ooo`3oool0B@3oool2000000<0oooo1@00000K0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0203oool00180oooo00<0oono07Ad_`3oool0A03oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`04000005L0oooo00<000000?ooo`3oool0BP3oool2000000<0oooo1P00000J0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00180oooo00@0omnL04P00000
04P0W=oo@`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo0P0000040?oo
o`030000003oool0oooo00<00000F@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool00000
00@0oooo0`0000000`3oool000000?ooo`0H0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0203oool001@0oooo00<0_g@00000000000000`0000000`0007@0_ooo0?ooo`0l0?ooo`80
0000303oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00000P00001K0?ooo`030000003oool0oooo04/0oooo00@000000?ooo`00000000000`3oool30000
00030?ooo`000000000001L0oooo00<000000?ooo`3oool02P3oool2000000X0oooo000H0?ooo`03
0?oOW0180000M;oo03h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo0P000000103oool0000000000000001L0?ooo`030000003oool0oooo
04`0oooo00@000000?ooo`3oool000000`3oool01P000000oooo000000000000oooo000001L0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`005`3oool00`3OW4P0001d0;oo
o`0o0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000800000GP3oool00`000000oooo0?ooo`1=0?ooo`040000003o
ool0oooo000000<0oooo0P0000000`3oool000000?ooo`02000001D0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`080?ooo`004P3oool01P3ogi`0B01809cOo`3o_g@0000004RLgd40
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000000P00001O0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool00P0000001`3oool000000?ooo`000000oooo0000003oool00P00000D0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0203oool00180oooo00@0omnL04P00000000007Bo@`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
10000000oooo00000000001Q0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool00P3o
ool020000000oooo0000003oool000000?ooo`000000oooo0P00000C0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0203oool005T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000H`3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool000000080
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0
oooo001I0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`030000003oool0000006@0oooo00<000000?ooo`3oool0D03oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool01@000000oooo000000000000oooo008000004@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo000E0?ooo`060=nLB00000000000
0000000004P0W=oo?P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo00@0
00000?ooo`3oool0oooo0P0000000`3oool000000?ooo`1T0?ooo`030000003oool0oooo0540oooo
00@000000?ooo`3oool0oooo0P0000030?ooo`050000003oool0oooo0000003oool00P00000@0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool001<0oooo00T0oono07@00018
W=l0omnL09boo`3oool0gia80018W03Oool0?@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`020?ooo`8000000`3oool01@000000oooo
0?ooo`000000oooo008000003`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0
oooo000C0?ooo`090;mdM02oool0oooo0?noW02Lgol0oooo0?oo_`1d07@0_ooo03d0oooo0P000009
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`800000IP3o
ool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`000000oooo008000003P3oool00`000000oooo0?ooo`080?ooo`800000
2P3oool00180oooo00T0omnL09boo`3oool0oooO09adW03Oool0oooo0?oOW018M;l0?P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000P3oool2
000006L0oooo00<000000?ooo`3oool0D`3oool010000000oooo0?ooo`3oool2000000@0oooo00D0
00000?ooo`3oool000000?ooo`02000000h0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`004P3oool02@3o_i`0W=oo0?ooo`2oM000M;oo0?ooo`3OW4P0001d0;ooo`0n0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`000002
0?ooo`800000J03oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0?ooo`000000oooo008000003@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo000B0?ooo`040?oo_`1d0000000007Bood<0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0?ooo`000000
oooo0P00001Y0?ooo`030000003oool0oooo03d0oooo1`00000@0?ooo`040000003oool0oooo0?oo
o`8000001@3oool01@000000oooo0?ooo`000000oooo00800000303oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo001I0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool00`3oool01P000000oooo0?ooo`3oool000000?ooo`800000JP3oool00`000000oooo0?oo
o`0k0?ooo`8000001`3oool2000000l0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`030000
003oool000000080oooo0P00000<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
203oool005T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`070000003o
ool0oooo0?ooo`000000oooo0000001[0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo008000001@3oool010000000
oooo0?ooo`0000020?ooo`8000002`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo000F0?ooo`060?noM000000000000000000007@0_ooo?@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool0oooo0000003oool2000006/0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo
00@000000?ooo`3oool0oooo0P0000050?ooo`040000003oool0oooo00000080oooo0P00000:0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool000h0oooo00H0_ibL0=ooo`3o
ool0oooo0?oOW0180003000000040018W03Oool0oono07Ad_ch0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0?ooo`000000oooo0P00001/0?ooo`03
0000003oool0oooo03L0oooo0P00000?0?ooo`8000003@3oool01P000000oooo0?ooo`000000oooo
000000D0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000T0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`080?ooo`003@3oool00`3ooml0W4P00000000300000003001d
_`3oool0oooo0080oooo00<0okmd0000M02oool0?P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0`00001]0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`000000oooo008000002@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo000=0?ooo`030?oo_`1d0000B9cO
04T0oooo0P0000070?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool0oooo0000003o
ool2000006d0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00/0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`080000003oool0oooo0000
003oool000000?ooo`0000090?ooo`030000003oool0oooo00D0oooo0P00000:0?ooo`00F@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool000000?oo
o`02000006h0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0000003oool00P0000090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0203oool001D0oooo00H0omnL04P00000000000000000B02Lgoln0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00`3oool01P000000oooo0?ooo`000000oooo000006l0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`800000
00<0oooo0000003oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo
000D0?ooo`030;md00000000M;oo0080oooo00<0oooO09adW03Oool0?@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool000000?ooo`02000006l0oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00X0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0000
003oool00P0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool001<0
oooo00<0gia804RLg`3oool0103oool00`3OW9`0_ooo0?ooo`0l0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00`3oool01P000000oooo0?ooo`000000oooo00000700oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00X0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0?ooo`000000
oooo0P0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00180oooo
00<0omnL07BLg`3oool0103oool00`3ooml0W7BL0=ooo`0m0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00`3oool010000000oooo0000003oool200000700oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0000003oool00P000007
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00180oooo00<0oknL09cO
o`3oool00`3oool00`3ooml0W4P007Boo`0n0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00`3oool01P000000oooo0?ooo`000000oooo00000740oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`000000103o
ool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0000003oool00P0000060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00180oooo00<0omnL04Qd_`3oool00P3o
ool00`3OW4P0000004RLg`0o0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0300000740oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`000000103oool00`000000oooo0?oo
o`030?ooo`050000003oool0oooo0000003oool00P0000070?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0203oool001<0oooo00H0okmd00000000000000000018W03Ooom00?ooo`80
00001P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<00000L@3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo000000040?ooo`030000003oool0oooo00@0oooo00H000000?ooo`3oool000000?ooo`000007
0?ooo`030000003oool0oooo00@0oooo0P00000:0?ooo`00F@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo0000001b0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
000000@0oooo00<000000?ooo`3oool00`3oool01P000000oooo0?ooo`000000oooo000000L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo0000001b0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0000000@0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`000000oooo0080
00001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo000E0?ooo`060?oO
W018000000000000000004P0W=oo?P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`00001b0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0000000D0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`3oool3000000H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`004`3oool0103ooml0W4P00018W03Oool20?ooo`030?noM000B9`0
gooo02l0oooo00@0_g@0000000000000M;oo2P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`00001b0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000D0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`3oool3000000H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`080?ooo`004`3oool00`2oM4P0W=oo0?ooo`030?ooo`030?oog`2L
B7@0_ooo02h0oooo00H0gia8001d_`3oool0omnL04P00018W=l90?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0300000780oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00/0oooo0P0000050?ooo`03
0000003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`0000060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0203oool00180oooo00<0omnL09boo`3oool0103oool00`3o
gi`0B7Bo0?ooo`0]0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0203oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`00001b0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0;0?oo
o`8000001@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0000003oool00P000005
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00180oooo00<0oknL09cO
o`3oool00`3oool00`3ogi`0B4RL0=ooo`0^0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a8
0000B9`0gooo1`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`00001b0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0;0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`050000003oool0
oooo0000003oool00P0000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203o
ool00180oooo00@0oono07@000000000M;oo<`3oool00`3ooml0W4P0001d_`030?ooo`030=nLB000
04P0W=oo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<00000LP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool02`3oool2000000D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?oo
o`000000oooo008000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo
001:0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01`3ooooo000004h000002P3o
ool004X0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`070?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0300000780oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00/0oooo0P000005
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool000000?ooo`02000000D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`004P3oool00`3ookl0W9cO0?ooo`03
0?ooo`040?noM0000000001d0;ooobh0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0300000780oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00/0oooo0P0000050?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool00000
0?ooo`02000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`004P3o
ool0103ookl0W9cO0?oo_`1d0004000000030018W03Oool0oooo02d0oooo00@0oooO09a80000B9`0
gooo0P3oool00`3OW4P004RL0=ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0300000780oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00/0oooo0P0000050?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool000000?ooo`02000000D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`080?ooo`004P3oool02@3ogi`0B0000000000004P0W=oo0?ooo`3ooml0W4Qd0;oo
o`0`0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`00001b0?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0;0?ooo`8000001@3o
ool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool000001P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo000>0?ooo`040?oog`2LB000001d0;ooocX0
oooo00H0gia80000M02oool0oooO09a80018W=l70?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0300000780oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`0000001@3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<000001P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00P0oooo001=0?ooo`040=nLB00000000000001d_`P0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<00000LP3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool00000
0?ooo`02000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`004P3o
ool01@3ogkl0_moo0?ooo`3oool0_g@000<0000000<0001d0;ooo`3oool0?03oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`00001b0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0;0?oo
o`8000001@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0000003oool00P000006
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00180oooo00<0_g@00000
000000000P0000001@0007@0_ooo0?ooo`2oW9`0gooo03d0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00800000LP3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo00d0oooo100000080?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0000003oool00P00
00060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00100oooo00D0_g@0
00000000000004RL0=ooo`030?ooo`030?oog`2LB000M;oo0080oooo00<0_g@00018W03Oool0>@3o
ool2000000H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0300000740oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0<0?ooo`8000000`3oool2000000H0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool0oooo0P0000000`3oool000000?ooo`050?ooo`030000003oool0oooo00@0oooo
0P00000:0?ooo`004P3oool00`3o_i`0W=oo0?ooo`080?ooo`030?oOW018M;l0oooo03T0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool0
0000L@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool01@3oool2000000@0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00@0oooo00D000000?ooo`3oool000000?ooo`02000000H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`004P3oool00`3ookl0M7Bo0?ooo`070?oo
o`030?noM000B9`0gooo03X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?oo
o`060000003oool0oooo0000003oool00000L@3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0203oool200000080oooo00<000000?ooo`3oool0203o
ool200000080oooo00@000000?ooo`3oool000001P3oool01P000000oooo0?ooo`3oool000000?oo
o`8000001P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo000B0?ooo`04
0?oOW0180000001d0;ooo`D0oooo00<0gia8001d_`3oool0>`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`00001`0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`8000002P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000H0oooo00@000000?ooo`3oool0oooo0`00
00070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool001<0oooo00<0omnL
04P0000000001@0000000`18W=l0oooo0?ooo`0k0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00`3oool01P000000oooo0?ooo`000000oooo00000700oooo0P00000c0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool4000000@0oooo0`0000040?ooo`040000
003oool00000000000H0oooo00H000000?ooo`3oool0oooo0000003oool2000000L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`00603oool00`3o_g@0001809cOo`0n0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030000
06l0oooo0P00000d0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool01000
0000oooo0?ooo`3oool4000000L0oooo0P0000070?ooo`060000003oool0oooo0?ooo`000000oooo
0P0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool001L0oooo00<0
_g@0001d_`3oool0?`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool0oooo0`00001^0?ooo`800000=03oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0303oool2000000L0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0203oool00180oooo00H0omnL04P0001d_ol0okmd0000001d_om10?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03000006h0oooo0P00000e0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?oo
o`<000001`3oool01P000000oooo0?ooo`3oool000000?ooo`8000002@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00P0oooo000B0?ooo`040?oOW01800000000001d_d<0oooo0P00
00070?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0`00001]0?ooo`800000
=@3oool01@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool02@3oool200000003
0?ooo`000000oooo00H0oooo00H000000?ooo`3oool0oooo0000003oool2000000X0oooo00<00000
0?ooo`3oool01@3oool2000000X0oooo001I0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0103oool01P000000oooo0?ooo`000000oooo000006d0oooo00<000000?ooo`000000=@3o
ool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo00L0oooo0P0000020?ooo`030000
003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000002P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo001I0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool3000006`0oooo00<000000?ooo`00
0000=@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo00H0oooo0P0000030?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool010000000oooo00000000000:0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool005T0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`040?ooo`060000003oool0oooo0000003oool00000K03oool0
0`000000oooo0000000f0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool3
000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0
0000000000/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`00F@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00H000000?ooo`3oool000000?oo
o`00001[0?ooo`030000003oool0000003D0oooo00<000000?ooo`0000004P3oool010000000oooo
0?ooo`3oool2000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`03
0000003oool00000008000002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0
oooo001I0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool01P000000oooo
0?ooo`000000oooo000006X0oooo00<000000?ooo`000000=03oool01@000000oooo0?ooo`3oool0
00000140oooo00@000000?ooo`0000000000203oool00`000000oooo0?ooo`030?ooo`800000103o
ool00`000000oooo0?ooo`02000000/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`00F@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00L00000
0?ooo`3oool0oooo0000003oool0000006T0oooo00@000000?ooo`3oool00000<P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo0`00000:0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02000000`0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0`00001X0?ooo`040000003oool0oooo0000
0380oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`<000002P3oool20000
00<0oooo0P0000050?ooo`030000003oool0oooo00<00000303oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo001I0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0103oool010000000oooo0?ooo`3oool3000006L0oooo00@000000?ooo`3oool00000<@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo0`0000020?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<00000303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo001I0?oo
o`8000002@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`<00000IP3oool0
10000000oooo0?ooo`00000`0?ooo`030000003oool0oooo00P0oooo0P0000040?ooo`800000103o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0?ooo`8000001@3oool200000080oooo
0`00000=0?ooo`030000003oool0oooo00P0oooo0P00000:0?ooo`00F@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo0`00001U0?ooo`050000
003oool0oooo0?ooo`000000;P3oool00`000000oooo0?ooo`0;0?ooo`@000001P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo008000001P3oool00`000000oooo0?ooo`04000000h0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo0`00001T0?ooo`05
0000003oool0oooo0?ooo`000000;@3oool00`000000oooo0?ooo`0:0?ooo`L00000103oool00`00
0000oooo0?ooo`040?ooo`<0000000<0oooo0000000000001`3oool01P000000oooo0?ooo`000000
oooo00000100oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`00F@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo0`00
001S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`090?ooo`8000001`3oool;00000080oooo0P0000070?ooo`8000000P3oool00`000000oooo0000
000A0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool005T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`060000003oool0oooo0?ooo`000000oooo
0P00001Q0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`070?ooo`<00000303oool00`000000oooo0?ooo`050?ooo`800000203oool00`000000oooo
0?ooo`02000000030?ooo`000000oooo0100oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`080?ooo`00F@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00H0
00000?ooo`3oool0oooo0000003oool200000600oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo00D0oooo0`00000?0?ooo`030000003oool0oooo00<0
oooo0P0000080?ooo`8000000P3oool010000000oooo00000000000B0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0203oool005T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`050?ooo`8000000P3oool010000000oooo00000000001O0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`040?ooo`8000004@3oool00`00
0000oooo0?ooo`020?ooo`8000002@3oool00`000000oooo0?ooo`0500000180oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`1M0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`<0
00004`3oool00`000000oooo00000002000000T0oooo0P0000000`3oool0000000000003000001@0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00H0oooo0P0000020?ooo`040000003oool00000000005`0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`8000000P3oool3000001D0
oooo0`00000:0?ooo`80000000<0oooo0000000000000P0000000`3oool000000?ooo`0C0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool005T0oooo0P00000<0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0=0?ooo`800000
203oool00`000000oooo0?ooo`02000000030?ooo`000000000005X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo008000005@3oool4000000X0oooo
0P0000001@3oool000000000003oool000000080oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0;0?ooo`8000002P3oool005T0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`060?ooo`8000000P3oool5000005P0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0N0?ooo`@000005@3oool200000080oooo00<000000?ooo`3oool01P3oool300000080oooo
00D000000?ooo`00000000000?ooo`02000001D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`080?ooo`00F@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo
00@000000?ooo`3oool0oooo1@00001F0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool07@3oool2000001D0oooo0`0000040?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`@0
000000<0oooo0000000000005`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0
oooo001I0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00h0oooo0P0000080?ooo`8000000`3oool5000005@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0I0?ooo`<00000503oool3000000H0oooo
00@000000?ooo`3oool0oooo0`0000040?ooo`@0000000<0oooo0000000000006@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo000e0?ooo`040;md00000000000007Boo`<0
oooo00<0omnL04P0001d_ol0103oool0102oM00000000000001d_ol30?ooo`060?oOW01800000000
00000000B9`0gooo2@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo0P00
00030?ooo`D00000DP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01L0oooo0P00
00000`3oool000000?ooo`0A0?ooo`<000002@3oool4000000D0oooo100000000`3oool000000000
000J0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool003@0oooo00H0gia8
001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00<0oooo00H0gia8001d_`3oool0
omnL04P00018W=l20?ooo`060?noM0000000M;oo0?ooo`3ogi`0B7Bo2@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0603oool200000100oooo0P00
00090?ooo`8000000`3oool500000500oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0D0?ooo`8000000P3oool00`000000oooo0?ooo`0=0?ooo`@000002P3oool3000000H0oooo1`00
000L0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool003<0oooo00<0oooO
09a80018W=l00P3oool00`3o_g@0001809cOo`060?ooo`030?oog`2LB000B9cO0080oooo00<0okmd
0000B02Lgol01P3oool00`3o_g@0B9cO0?ooo`070?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00l0oooo0P000009
0?ooo`8000000`3oool2000000030?ooo`000000000004h0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0A0?ooo`<000000`3oool00`000000oooo0?ooo`0:0?ooo`@00000303oool3
000000D0oooo1`00000N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool0
03<0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool50?ooo`030?oog`2LB000
B9cO0080oooo00@0oooO09a80000B9`0gooo1@3oool00`3ookl0M01d0;ooo`070?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0J0?ooo`8000004@3o
ool3000000P0oooo0`0000020?ooo`80000000@0oooo0000000000000000B`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00h0oooo0P0000040?ooo`8000002@3oool4000000d0oooo
0`0000020?ooo`030000003oool0oooo00P00000803oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00P0oooo000c0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol01@3o
ool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00D0oooo00<0oooO09a8001d_ol01`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0A0?ooo`8000002@3oool3000000030?ooo`000000000000@00000B@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo0`0000050?ooo`030000003o
ool0oooo00D0oooo1000000>0?ooo`<00000103oool900000280oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`080?ooo`00=03oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000
B9cO00H0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`050?ooo`030?oo_`1d0000
B9cO00L0oooo0`00000>0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0703oool2
000001<0oooo0P00000:0?ooo`<0000000<0oooo0000000000000`0000170?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool01`3oool2000000H0oooo0P0000030?ooo`D000003`3oool3
000000@0oooo2P00000S0?ooo`030000003oool0oooo00l0oooo0`00000:0?ooo`00=03oool00`3O
W4P0001809cOo`020?ooo`030?oog`2LB00007Bo00H0oooo00<0gia80000B02Lgol00P3oool00`3o
oml0W4P0001d_`050?ooo`030?noM0000000M;oo00L0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool04P3oool20000
00/0oooo0`0000000`3oool0000000000003000004@0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`040?ooo`<000001`3oool600000100oooo100000040?ooo`<0000000<0oooo0000
000000001000000V0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0203oool003@0
oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`050?ooo`030?oOW0180000B9cO00<0
oooo00X0_g@00018W03Oool0oooo0?oOg`3Oool0okmd0000000007@0_ooo1`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool07@3oool2000001@0oooo
0P00000<0?ooo`<0000000<0oooo0000000000000P0000120?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00`0000070?ooo`@000003`3oool6000000H0oooo0P0000000`3oool00000
00000004000002P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`00=03o
ool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00D0oooo00@0oooO09a80000B9`0
gooo0P3oool02@3OW4P004RL0=ooo`3oool0oono07@000000000001809cOo`080?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo01<0oooo0`00000<0?ooo`P00000?`3oool00`000000oooo0?ooo`0;0?ooo`<000001@3o
ool6000000`0oooo1P0000090?ooo`X00000:@3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00P0oooo000e0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01P3oool0
0`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo0080oooo00<0gibL0;ooo`3oool02@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0E0?ooo`<000003@3oool8000003/0oooo00<000000?ooo`3oool0203oool3
00000080oooo1P0000030?ooo`8000001`3oool6000000/0oooo2P0000030?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`080?ooo`00=P3oool01P3O
W4P0001d0;ooo`3ooml0W4P004RLg`P0oooo00H0gia80000M02oool0oooO09a80018W=l30?ooo`03
0?oOW01dW=l0oooo00T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo01l0oooo0P00000H0?ooo`D000003@3oool7000003L0oooo00<000000?ooo`3o
ool01@3oool3000000030?ooo`000000000000@000001P3oool00`000000oooo0?ooo`07000000/0
oooo3@0000050?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`080?ooo`00=`3oool0103OW4P0000000000000M;l:0?ooo`040=nLB00000000000001d
_`D0oooo00D0_g@0000000000000000004RLg`060?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01X0oooo1@00000<
0?ooo`P00000<P3oool00`000000oooo0?ooo`020?ooo`L000001P3oool9000000`0oooo1P000002
0?ooo`L00000203oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0203oool005T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo0200oooo0P00000O0?ooo`@00000303oool<000002H0oooo2P0000070?oo
o`H000000P3oool00`000000oooo0?ooo`090?ooo`H000000P3oool9000000/0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0oooo001I0?ooo`80
00004`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0240oooo1000000O0?ooo`X0
0000303oool;00000180oooo2`0000030?ooo`h000001P3oool2000000D0oooo1`0000000`3oool0
00000000000800000140oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0F0?ooo`80
00002P3oool005T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0/0?ooo`800000
9@3oool3000002H0oooo300000050?ooobP00000303oool=000000030?ooo`000000000000P00000
5`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
203oool005T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo02D0oooo0`00000_0?ooocT000000P3oool?000001d0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00P0oooo001I0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0W0?ooo`<00000@03oool_
000002<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo00P0oooo001I0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0Y0?ooo`@00000@@3oool600000080oooo5P0000020?ooo`800000203oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`080?ooo`00F@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02l0
oooo0P00000]0?ooo`<00000>03oool6000001<0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00P0oooo001I0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0]0?ooo`@00000;@3oool7000001T0oooo
00<000000?ooo`3oool01`3oool2000000d0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0203oool005T0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0300oooo2000
000O0?ooo`H00000803oool00`000000oooo0?ooo`050?ooo`800000403oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`080?ooo`00F@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0340oooo0P00000h
0?oooal000009P3oool00`000000oooo0?ooo`030?ooo`8000004`3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`08
0?ooo`00F@3oool2000001P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`1j0?oo
o`040000003oool0oooo0?ooo`8000005P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool07`3oool2000000X0oooo001I0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0<P3oool2000007X0oooo00@000000?ooo`00000000006@3oool2
000001D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo00P0oooo001I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`1g0?ooo`8000007@3oool200000180oooo00<000000?ooo`3oool0903oool20000
02@0oooo00<000000?ooo`3oool0203oool005T0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo07@0oooo0`00000P0?ooo`8000003`3oool00`000000
oooo0?ooo`0S0?ooo`8000009P3oool00`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo03@0oooo0P00001b0?ooo`8000000P3oool00`000000oooo
0?ooo`0P0?ooo`800000303oool00`000000oooo0?ooo`0R0?ooo`800000:03oool00`000000oooo
0?ooo`080?ooo`00F@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0K03oool3000000@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0240oooo0P00000Z0?ooo`030000003oool0oooo00P0oooo001I
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0=P3oool2000006T0oooo0`000007
0?ooo`030000003oool0oooo02<0oooo0P0000070?ooo`030000003oool0oooo0200oooo0P00000/
0?ooo`030000003oool0oooo00P0oooo001I0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0=`3oool2000006D0oooo0P00000:0?ooo`030000003oool0oooo02D0oooo0`0000030?oo
o`030000003oool0oooo01l0oooo0P00000^0?ooo`030000003oool0oooo00P0oooo001I0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0>03oool200000600oooo0`00000<0?ooo`03
0000003oool0oooo02P0oooo0`00000P0?ooo`800000<03oool00`000000oooo0?ooo`080?ooo`00
F@3oool2000001h0oooo00<000000?ooo`3oool0>P3oool3000005X0oooo0`00000?0?ooo`030000
003oool0oooo02T0oooo1000000K0?ooo`<00000<@3oool2000000X0oooo001I0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0?03oool3000005D0oooo0P00000B0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool00P3oool500000100oooo1P00000e0?ooo`030000003o
ool0oooo00P0oooo001I0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0?P3oool3
000004l0oooo0`00000D0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool@
000003/0oooo00<000000?ooo`3oool0203oool005T0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`100?ooo`<00000B03oool4000001L0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo00P0oooo001I0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0@P3oool200000440oooo1@00000K0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo04<0oooo0`00000i0?ooo`D00000803oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0203oool005T0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`160?ooo`@00000<03oool5000002D0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00P0oooo001I
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0B@3oool900000280oooo1@00000Z
0?ooo`030000003oool0oooo0240oooo0P00001J0?ooo`030000003oool0oooo00P0oooo001I0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0D@3oool;000000d0oooo2P00000_0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`080?oo
o`00F@3oool2000002H0oooo00<000000?ooo`3oool0F`3oool=000003T0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`1J0?ooo`8000002P3oool005T0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo01d0oooo0P00001N0?ooo`030000
003oool0oooo00P0oooo001I0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0W`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0203o
ool003h0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`030?oo_`1d
000000000080000000<0B9cO0?ooo`3oool01`3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo09h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1O0?ooo`030000003o
ool0oooo00P0oooo000m0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B000
07Boo`040?ooo`030?noM0000000M;oo00X0oooo00<000000?ooo`3oool0:@3oool2000009h0oooo
00<000000?ooo`3oool06@3oool200000680oooo00<000000?ooo`3oool0203oool003`0oooo00<0
oooO09a80018W=l00P3oool00`3o_g@0001809cOo`080?ooo`030?oog`2LB00007Bo00X0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0HP3oool00`000000oooo0?ooo`080?ooo`00?03oool00`3ooml0W4P004RLg`02
0?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<0gia80018W03Oool02@3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool05P3oool2000006D0oooo00<0
00000?ooo`3oool0203oool003`0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`08
0?ooo`030?oOW01804P0W=oo00T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2I
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`08
0?ooo`00?@3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00P0oooo00<0oono07@0
001d_ol02@3oool3000002h0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0C0?oo
o`800000IP3oool3000000X0oooo000m0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000
M;l02@3oool00`2oM00007Bo0?ooo`080?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool0U`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3o
ool0203oool003d0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`080?ooo`030=nL
B000B9`0gooo00P0oooo00<000000?ooo`3oool0<03oool2000009L0oooo00<000000?ooo`3oool0
403oool2000006/0oooo00<000000?ooo`3oool0203oool003d0oooo00@0oooO09a80000B9`0gooo
0P3oool00`3OW4P004RL0=ooo`080?ooo`030?oOW01804P0W=oo00P0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
J`3oool00`000000oooo0?ooo`080?ooo`00?P3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000
M;l0oooo00P0oooo00<0oono07@0001d_ol0203oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo09<0oooo00<000000?ooo`3oool03@3oool2000006h0oooo00<000000?ooo`3oool0203o
ool003l0oooo00H0gia80000M02oool0oooO09a80018W=l:0?ooo`030;md0000M;l0oooo00L0oooo
00<000000?ooo`3oool0=03oool2000009<0oooo00<000000?ooo`3oool02`3oool200000700oooo
00<000000?ooo`3oool0203oool00400oooo00@0gia800000000000007Bo2@3oool01@3ookl0M000
0000000007@0_ooo00L0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo00T0oooo0P00001b0?ooo`030000003oool0oooo00P0oooo001I0?ooo`030000
003oool0oooo03L0oooo0P00002@0?ooo`030000003oool0oooo00L0oooo0P00001d0?ooo`030000
003oool0oooo00P0oooo001I0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`050?ooo`800000MP3oool00`000000oooo0?ooo`080?ooo`00F@3oool2
000003/0oooo0P00002=0?ooo`030000003oool0oooo00<0oooo0P00001g0?ooo`8000002P3oool0
05T0oooo00<000000?ooo`3oool0?03oool2000008/0oooo00@000000?ooo`3oool0oooo0P00001j
0?ooo`030000003oool0oooo00P0oooo001I0?ooo`030000003oool0oooo03h0oooo0P0000290?oo
o`040000003oool00000000007`0oooo00<000000?ooo`3oool0203oool005T0oooo00<000000?oo
o`3oool0@03oool2000008L0oooo0P00001n0?ooo`030000003oool0oooo00P0oooo001I0?ooo`03
0000003oool0oooo0480oooo0P0000230?ooo`<00000O`3oool00`000000oooo0?ooo`080?ooo`00
F@3oool00`000000oooo0?ooo`140?ooo`800000O`3oool200000080oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo0?ooo`160?ooo`800000N`3o
ool2000000@0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`080?ooo`00F@3oool0
0`000000oooo0?ooo`180?ooo`800000M`3oool2000000H0oooo00<000000?ooo`3oool0O@3oool0
0`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo0?ooo`1:0?ooo`800000LP3oool30000
00P0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`080?ooo`00F@3oool2000004d0
oooo0`00001/0?ooo`<000002`3oool00`000000oooo0?ooo`1l0?ooo`8000002P3oool005T0oooo
00<000000?ooo`3oool0C`3oool2000006L0oooo0`00000>0?ooo`030000003oool0oooo07d0oooo
00<000000?ooo`3oool0203oool005T0oooo00<000000?ooo`3oool0D@3oool200000680oooo0`00
000A0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0203oool005T0oooo00<00000
0?ooo`3oool0D`3oool3000005`0oooo0`00000D0?ooo`030000003oool0oooo07d0oooo00<00000
0?ooo`3oool0203oool005T0oooo00<000000?ooo`3oool0EP3oool3000005D0oooo1000000G0?oo
o`030000003oool0oooo07d0oooo00<000000?ooo`3oool0203oool005T0oooo00<000000?ooo`3o
ool0F@3oool3000004l0oooo0`00000K0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3o
ool0203oool005T0oooo00<000000?ooo`3oool0G03oool3000004P0oooo1000000N0?ooo`030000
003oool0oooo07d0oooo00<000000?ooo`3oool0203oool005T0oooo00<000000?ooo`3oool0G`3o
ool4000003l0oooo1@00000R0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0203o
ool005T0oooo00<000000?ooo`3oool0H`3oool600000380oooo1`00000W0?ooo`030000003oool0
oooo07d0oooo00<000000?ooo`3oool0203oool005T0oooo0P00001Z0?ooo`T00000903oool50000
02h0oooo00<000000?ooo`3oool0O03oool2000000X0oooo001I0?ooo`030000003oool0oooo0780
oooo3@0000070?oooa000000<`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00P0
oooo001I0?ooo`030000003oool0oooo07l0oooo1`0000130?ooo`030000003oool0oooo07d0oooo
00<000000?ooo`3oool0203oool005T0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?oo
o`1m0?ooo`030000003oool0oooo00P0oooo001I0?ooo`030000003oool0oooo0<T0oooo00<00000
0?ooo`3oool0O@3oool00`000000oooo0?ooo`080?ooo`00F@3oool00`000000oooo0?ooo`390?oo
o`030000003oool0oooo07d0oooo00<000000?ooo`3oool0203oool005T0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo001I0?ooo`040000
003oool0oooo000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`00
F@3ooooo000004h000002P3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00=80oooo00T0oono07@000000000B9cO0?oo
o`3ookl0M00000000018W=l0503oool00`3o_g@0000000000002000000030018W03Oool0oooo0180
oooo00D0_g@0000000000000000004RLg`2R0?ooo`00dP3oool02P3ookl0M01809cOo`2oM00007Bo
0?oo_`1d04P0W=oo0;md0000M;lB0?ooo`030?noM0000000B9cO00<0oooo00<0omnL04P0B02Lgol0
4`3oool00`3ooml0W4P004RLg`2S0?ooo`00e@3oool00`3ookl0M00007Boo`020?ooo`030?oo_`1d
0000M;oo0140oooo00<0okmd0000M02oool0103oool00`3OW4P007Bo0?ooo`0C0?ooo`030=nLB000
B9`0gooo0:80oooo003F0?ooo`030=nLB000B9`0gooo0080oooo00<0gia80018W03Oool04@3oool0
202oM000001d0;ooo`3oool0oooO09a800000000B9cO503oool00`3ogi`0B01d0;ooo`2R0?ooo`00
_`3oool00`2oM000000000000005000000030018W03Oool0oooo00<0oooo00`0omnL04P000000000
04RL0=ooo`2oM0000000001d_`3oool0okmd0000B02Lgol20?ooo`030?noM00004P0W=oo00<0oooo
00P0_g@00000000004P0W=oo0?ooo`3OW4P004RL0=ooo`80oooo00<0_g@000000000M;l00P3oool0
1P3ookl0M000000000000000001d0;ooo`D0oooo00<0okmd0000000000001`0000002@1d_ol0oooo
0?oOW018000000000000M02ookl0M00007Boo`020?ooo`0;0?oOW018000000000018W03Oool0_g@0
00000000M;l0oooo0?oOW01800000P0000002@1d_ol0gia800000000B9`0gooo0?noM00000000018
09cOo`020?ooo`040;md00000000001809cOo`80oooo00D0okmd000000000000001809cOo`030?oo
o`030=nLB000B9`0gooo0080oooo00<0_g@000000000M;l0LP3oool00<00oooo00@0oono07@00000
B9`0gooo0`3oool00`2oM0000000001d_`030?ooo`0<0?oOW01804P0W=oo0?oOW018M;l0_g@0001d
_`3o_i`0W=oo0?oo_`1d0000B9cO0P3oool00`3ookl0M00004RLg`030?ooo`080=nLB000B9`0gooO
09adW03Oool0okmd0000M02oool20?ooo`080=nLB000B9`0gkmd07Boo`3oool0okmd0000M02oool9
0?ooo`040?oog`2LB00004RL0=ooo`<0oooo00/0oooO09a80000B9`0gooo0;md0000B9`0gooo0?oo
_`1d07@0M7@004RLg`020?ooo`0T0?oOW01804P0W=oo0?oOW018M;l0_g@0001d_`3o_i`0W=oo0;md
0000B9`0gooo0?ooo`2oM000M7Ad0000M02ogi`0W;oo0?noM00004P0W=oO09adW03Oool0oooo0=nL
B000B9`0gooO09adW03Oool0omnL04P0B02Lgol0oooo0?oOW018000007Bo0P3oool00`3o_g@0001d
0;ooo`020?ooo`040=nLB000B9`0gkmd07Boog40oooo00310?ooo`030=nLB00004P0W=oo00@0oooo
00d0oono07@00000B9`0gooo0?ooo`3ooml0W4P004RLg`3oool0okmd07AdM000B9`0gooo0080oooo
00<0_g@00018W03Oool00P3oool00`2oM00004RL0=ooo`020?ooo`030?noM00004P0W=oo0080oooo
00<0oono07@00018W=l00P3oool00`3ogi`0B01809cOo`030?ooo`030;md001d_ol0oooo00T0oooo
00<0okmd0000B02Lgol01@3oool0103OW7@0W=oo0;md0000M;l20?ooo`0@0?oo_`1d000004RL0=oo
o`3oool0oooO09a80018W=l0oooo0?noM01dM7@004RL0=ooo`3oool0_g@0001d_`<0oooo00L0_g@0
0000001d_ol0oooo0?oo_`1d0000M;oo00<0oooo00<0okmd0000B02Lgol00P3oool00`3OW4P004RL
0=ooo`020?ooo`070?oOW0180000B9cO0?ooo`3ookl0M00004RLg`020?ooo`030?oOW01804P0W=oo
0780oooo00310?ooo`030?oOW0180000M;oo00D0oooo00<0omnL04P00000M;l00P3oool01`2oM000
04RL0=ooo`3oool0_g@00000B02Lgol00P3oool00`3OW4P0001d0;ooo`020?ooo`030=nLB00007@0
_ooo0080oooo00<0oono07@00018W=l00P3oool0203ooml0W4P00000M02oool0oooo0?oog`2LB000
B9cO0P3oool00`3ookl0M000000000020000000307Boo`3oool0oooo00D0oooo00<0oono07@00018
W=l01`3oool00`3OW4P004RL0=ooo`020?ooo`030?noM00007@0_ooo0080oooo00/0_g@00018W03O
ool0oooo0;md000004P0W=oo0?ooo`3o_g@0001d0;ooo`020?ooo`030?oo_`1d0000B9cO0080oooo
00<0_g@0001d_`3oool00P3oool00`3ookl0M00004RLg`020?ooo`030?noM00007@0_ooo00<0oooo
00/0gia80000M02oool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`1b0?ooo`00`@3oool0
0`3ookl0M000001d_`060?ooo`0;0;md000004P0W=oo0?ooo`3o_g@0001d0;ooo`3oool0oono07@0
001d_ol00P3oool00`3ogi`0B00007Boo`020?ooo`030?oOW0180000M;oo00<0oooo00<0_g@00018
W03Oool00P3oool00`3OW4P004Q804Qd_`020?ooo`0;0;md0000M;l0oooo0?ooo`2oM00004RL0=oo
o`3oool0omnL04P00018W=l01P3oool00`3ooml0W4P0001d_`020?ooo`030?oo_`2LW=l0oooo0080
oooo00<0omnL04P0001d_ol00P3oool00`3ookl0M00007Boo`020?ooo`0;0?noM00007@0_ooo0?oo
o`3ookl0M00007Boo`3oool0oono07@0001d_ol00`3oool01`2oM00004RL0=ooo`3oool0gia80018
W03Oool00`3oool01`2oM00004RL0=ooo`3oool0oono07@0001d_ol00`3oool01`3ogi`0B01809cO
o`3oool0gia80018B018M;l00P3oool00`2oM00007Bo0?ooo`1a0?ooo`00`P3oool00`2oM00004RL
0=ooo`050?ooo`070?noM0000000B9cO0?oOg`3Ookl0M00007Boo`020?ooo`070;md0000M;l0oooo
0?ooo`3ooml0W4P004RLg`020?ooo`030?oog`2LB000B9cO00<0oooo00<0gia80000B02Lgol00P3o
ool02`3o_g@0001d0;noM018W=l0oooo0?noM00007@0_ooo0?ooo`2oM00007Bo00<0oooo00<0gia8
0000M02oool01P3oool01P3OW4P0001d0;ooo`3oool0omnL04Qd_`@0oooo00`0_g@00000M02oool0
oooo0?oog`2LB000B9cO0?ooo`3ogml0gono07@0001d_ol20?ooo`070;md0000M;l0oooo0?ooo`3o
_g@0001d0;ooo`020?ooo`070=nLB00007@0_ooo0?ooo`3ogi`0B01809cOo`030?ooo`030=nLB000
04P0W=oo0080oooo00<0gia80000M02oool00P3oool0303ookl0M00007Boo`3oool0okmd0000M02o
_g@0B9cO0?ooo`3o_g@0001d0;ooog40oooo00320?ooo`030?noM00004P0W=oo00D0oooo00L0omnL
04P00000M;l0omnL04Qd_`2oM00007Bo0080oooo00<0okmd0018W03Oool00P3oool00`2oM00004RL
0=ooo`020?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l00P3oool0303ooml0W4P0
07Boo`3OW4P007Bo0?oOW01804P0W=oo0?ooo`3ogi`0B00004RLg`80oooo00<0gia80000M02oool0
1P3oool00`3o_g@0000000000002000000030000M02oool0oooo0080oooo00`0oooO09a80000B9`0
gooo0?oo_`2LB4P004RL0=ooo`3ogi`0B7Bo0;md0000M;l20?ooo`030?noM000B9`0gooo0080oooo
00/0gia80000M02oool0oooo0;md000004P0W=oo0?ooo`3ooml0W4P004RLg`030?ooo`030?oOW018
0000B9cO00<0oooo0100_g@00000M02oool0oooo0?noM00007@0_ooo0?ooo`3ooml0W4P007Boo`3O
W4P007Bo0?oOW01804P0W=ooL@3oool00<80oooo00<0omnL04P0001d_ol01@3oool01`3ogi`0B000
001d_`3oool0okmd00000000M;l00P3oool01@3ogi`0B01809cOo`3ookl0M00000<0000000<0M;no
07@0000000000P0000003`1d_ol0okmd00000000000004RL0=ooo`3ookl0M00000000018W=l0oooo
0?noM0000000001809cOo`020?ooo`030?oo_`1d0000000000@0000000<0B9cO0?ooo`3oool00`3o
ool00`3ookl0M00007Boo`020?ooo`030;mdB02Lgol0oooo00@0oooo00X0gia80000000007@0_kmd
0000M02oool0oooo0?noM000000007Bo0P3oool00`3ogi`0B01809cOo`030?ooo`080?oOW0180000
000004RLW01d0000B9cO0?oo_`1d00030000000607Boo`3o_g@0000000000000B9`0gooo0`3oool0
3`3o_g@00000000000000000M;oo0?ooo`3ookl0M00000000018W=l0oooo0?noM0000000001809cO
o`1a0?ooo`00`P3oool00`3ooml0W4P0001d_`050?ooo`030?noM0000000B9cO00/0oooo00<0okmd
0000B02Lgol00P3oool00`3o_g@0001809cOo`0O0?ooo`060;md0000M;l0oooo0?ooo`3ogi`0M9cO
7`3oool00`3o_g@0001d0;ooo`290?ooo`00``3oool00`2oM00004RL0=ooo`030?ooo`040?oog`2L
B000001d0;ooo`/0oooo00<0oooO09a80000M;l00P3oool00`3ooml0W4P0001d_`0O0?ooo`030=nL
B00007@0_ooo00@0oooo00<0gibL0;ooo`3oool0703oool00`3OW7@0W=oo0?ooo`280?ooo`00``3o
ool00`3OW4P0001809cOo`020?ooo`040?oo_`1d0000000007Boo`d0oooo00<0okmd0000M02oool0
0P3oool00`3o_g@0001d0;ooo`020?ooo`040?oo_`1d000004RL0=oooaP0oooo00<0okmd0000B02L
gol00`3oool00`3ookl0M01809cOo`0R0?ooo`040?oo_`1d000004RL0=oooh80oooo00320?ooo`03
0;md00000000000000@0000000<004RL0=ooo`3oool03P3oool02P3OW4P004RL0=oog`2LB000B9cO
0=nLB000B9`0gooO09a80018W=lJ0?ooo`030;md00000000000000H0000000<0M;oo0?ooo`3oool0
YP3oool00=/0oooo00T0gia80000000004P0W=oo0?ooo`3OW4P000000000B02Lgol0c03oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {343.5, 0}} -> {-0.33542, -0.22201, \
0.00171651, 0.00171651}}]
}, Closed]],

Cell[TextData[{
  "Below we generate a table of plots that show the limiting orbits for an \
array of initial conditions, with the early transient behavior suppressed.  \
Plotting this array together shows that the limiting orbit for specified ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Alpha], \[Gamma], f}\)]],
  "is independent of initial conditions."
}], "Text"],

Cell[BoxData[
    \(\(stuff = 
        Table[duffingPlot[1, 1, 0.05, 0.1, 0.5, x0, v0, 150, 300, 
            MaxSteps \[Rule] 3000, PlotPoints \[Rule] 100, 
            DisplayFunction \[Rule] Identity], {x0, 0, 1, 0.2}, {v0, 0, 1, 
            0.2}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[stuff, DisplayFunction \[Rule] $DisplayFunction, 
        AspectRatio \[Rule] Automatic];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49377 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.499356 3.61331 0.247376 3.61331 [
[.13803 -0.0125 -13.8438 -15.6875 ]
[.13803 -0.0125 13.8438 0 ]
[.31869 -0.0125 -16.8438 -15.6875 ]
[.31869 -0.0125 16.8438 0 ]
[.49936 -0.0125 -5 -15.6875 ]
[.49936 -0.0125 5 0 ]
[.68002 -0.0125 -12.5 -15.6875 ]
[.68002 -0.0125 12.5 0 ]
[.86069 -0.0125 -9.5 -15.6875 ]
[.86069 -0.0125 9.5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.9688 -31.375 ]
[.5 -0.0125 21.9688 -15.6875 ]
[-0.0125 .03058 -33.9375 -7.84375 ]
[-0.0125 .03058 0 7.84375 ]
[-0.0125 .10284 -33.6875 -7.84375 ]
[-0.0125 .10284 0 7.84375 ]
[-0.0125 .17511 -33.6875 -7.84375 ]
[-0.0125 .17511 0 7.84375 ]
[-0.0125 .24738 -10 -7.84375 ]
[-0.0125 .24738 0 7.84375 ]
[-0.0125 .31964 -25 -7.84375 ]
[-0.0125 .31964 0 7.84375 ]
[-0.0125 .39191 -25 -7.84375 ]
[-0.0125 .39191 0 7.84375 ]
[-0.0125 .46417 -25.25 -7.84375 ]
[-0.0125 .46417 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .24689 -49.625 -20.4688 ]
[-0.01875 .24689 -33.9375 20.4688 ]
[ 0 .49377 .125 0 ]
[ 1 0 .125 0 ]
[.5 .50627 -43.9375 0 ]
[.5 .50627 43.9375 15.6875 ]
[ 0 0 0 0 ]
[ 1 .49377 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13803 0 m
.13803 .00625 L
s
gsave
.13803 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.31869 0 m
.31869 .00625 L
s
gsave
.31869 -0.0125 -77.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
.49936 0 m
.49936 .00625 L
s
gsave
.49936 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.68002 0 m
.68002 .00625 L
s
gsave
.68002 -0.0125 -73.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
.86069 0 m
.86069 .00625 L
s
gsave
.86069 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.125 Mabswid
.17416 0 m
.17416 .00375 L
s
.21029 0 m
.21029 .00375 L
s
.24642 0 m
.24642 .00375 L
s
.28256 0 m
.28256 .00375 L
s
.35482 0 m
.35482 .00375 L
s
.39096 0 m
.39096 .00375 L
s
.42709 0 m
.42709 .00375 L
s
.46322 0 m
.46322 .00375 L
s
.53549 0 m
.53549 .00375 L
s
.57162 0 m
.57162 .00375 L
s
.60776 0 m
.60776 .00375 L
s
.64389 0 m
.64389 .00375 L
s
.71615 0 m
.71615 .00375 L
s
.75229 0 m
.75229 .00375 L
s
.78842 0 m
.78842 .00375 L
s
.82455 0 m
.82455 .00375 L
s
.10189 0 m
.10189 .00375 L
s
.06576 0 m
.06576 .00375 L
s
.02963 0 m
.02963 .00375 L
s
.89682 0 m
.89682 .00375 L
s
.93295 0 m
.93295 .00375 L
s
.96909 0 m
.96909 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.9688 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
102.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .03058 m
.00625 .03058 L
s
gsave
-0.0125 .03058 -94.9375 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
1.000 setlinewidth
grestore
0 .10284 m
.00625 .10284 L
s
gsave
-0.0125 .10284 -94.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
1.000 setlinewidth
grestore
0 .17511 m
.00625 .17511 L
s
gsave
-0.0125 .17511 -94.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
1.000 setlinewidth
grestore
0 .24738 m
.00625 .24738 L
s
gsave
-0.0125 .24738 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .31964 m
.00625 .31964 L
s
gsave
-0.0125 .31964 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
1.000 setlinewidth
grestore
0 .39191 m
.00625 .39191 L
s
gsave
-0.0125 .39191 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
1.000 setlinewidth
grestore
0 .46417 m
.00625 .46417 L
s
gsave
-0.0125 .46417 -86.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04864 m
.00375 .04864 L
s
0 .06671 m
.00375 .06671 L
s
0 .08478 m
.00375 .08478 L
s
0 .12091 m
.00375 .12091 L
s
0 .13898 m
.00375 .13898 L
s
0 .15704 m
.00375 .15704 L
s
0 .19318 m
.00375 .19318 L
s
0 .21124 m
.00375 .21124 L
s
0 .22931 m
.00375 .22931 L
s
0 .26544 m
.00375 .26544 L
s
0 .28351 m
.00375 .28351 L
s
0 .30158 m
.00375 .30158 L
s
0 .33771 m
.00375 .33771 L
s
0 .35578 m
.00375 .35578 L
s
0 .37384 m
.00375 .37384 L
s
0 .40997 m
.00375 .40997 L
s
0 .42804 m
.00375 .42804 L
s
0 .44611 m
.00375 .44611 L
s
0 .01251 m
.00375 .01251 L
s
0 .48224 m
.00375 .48224 L
s
.25 Mabswid
0 0 m
0 .49377 L
s
gsave
-0.01875 .24689 -123.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
81.4688 11.8438 translate
90 rotate
-81.4688 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(velocity) show
99.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.13803 .48752 m
.13803 .49377 L
s
.31869 .48752 m
.31869 .49377 L
s
.49936 .48752 m
.49936 .49377 L
s
.68002 .48752 m
.68002 .49377 L
s
.86069 .48752 m
.86069 .49377 L
s
.125 Mabswid
.17416 .49002 m
.17416 .49377 L
s
.21029 .49002 m
.21029 .49377 L
s
.24642 .49002 m
.24642 .49377 L
s
.28256 .49002 m
.28256 .49377 L
s
.35482 .49002 m
.35482 .49377 L
s
.39096 .49002 m
.39096 .49377 L
s
.42709 .49002 m
.42709 .49377 L
s
.46322 .49002 m
.46322 .49377 L
s
.53549 .49002 m
.53549 .49377 L
s
.57162 .49002 m
.57162 .49377 L
s
.60776 .49002 m
.60776 .49377 L
s
.64389 .49002 m
.64389 .49377 L
s
.71615 .49002 m
.71615 .49377 L
s
.75229 .49002 m
.75229 .49377 L
s
.78842 .49002 m
.78842 .49377 L
s
.82455 .49002 m
.82455 .49377 L
s
.10189 .49002 m
.10189 .49377 L
s
.06576 .49002 m
.06576 .49377 L
s
.02963 .49002 m
.02963 .49377 L
s
.89682 .49002 m
.89682 .49377 L
s
.93295 .49002 m
.93295 .49377 L
s
.96909 .49002 m
.96909 .49377 L
s
.25 Mabswid
0 .49377 m
1 .49377 L
s
.99375 .03058 m
1 .03058 L
s
.99375 .10284 m
1 .10284 L
s
.99375 .17511 m
1 .17511 L
s
.99375 .24738 m
1 .24738 L
s
.99375 .31964 m
1 .31964 L
s
.99375 .39191 m
1 .39191 L
s
.99375 .46417 m
1 .46417 L
s
.125 Mabswid
.99625 .04864 m
1 .04864 L
s
.99625 .06671 m
1 .06671 L
s
.99625 .08478 m
1 .08478 L
s
.99625 .12091 m
1 .12091 L
s
.99625 .13898 m
1 .13898 L
s
.99625 .15704 m
1 .15704 L
s
.99625 .19318 m
1 .19318 L
s
.99625 .21124 m
1 .21124 L
s
.99625 .22931 m
1 .22931 L
s
.99625 .26544 m
1 .26544 L
s
.99625 .28351 m
1 .28351 L
s
.99625 .30158 m
1 .30158 L
s
.99625 .33771 m
1 .33771 L
s
.99625 .35578 m
1 .35578 L
s
.99625 .37384 m
1 .37384 L
s
.99625 .40997 m
1 .40997 L
s
.99625 .42804 m
1 .42804 L
s
.99625 .44611 m
1 .44611 L
s
.99625 .01251 m
1 .01251 L
s
.99625 .48224 m
1 .48224 L
s
.25 Mabswid
1 0 m
1 .49377 L
s
0 .24738 m
1 .24738 L
s
.49936 0 m
.49936 .49377 L
s
gsave
.5 .50627 -104.938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Duffing) show
102.938 15.813 moveto
(Equation) show
146.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49377 L
0 .49377 L
closepath
clip
newpath
.5 Mabswid
.9224 .35563 m
.9399 .33624 L
.95305 .31742 L
.96383 .29611 L
.96816 .28395 L
.97102 .27278 L
.97209 .26707 L
.97292 .26099 L
.97339 .2558 L
.97365 .25008 L
.97363 .24393 L
.97348 .24048 L
.97326 .23733 L
.97261 .23122 L
.9717 .22542 L
.97061 .22008 L
.96919 .2144 L
.96597 .20424 L
.96102 .19229 L
.9555 .18161 L
.93941 .15803 L
.92039 .13735 L
.8951 .11602 L
.86372 .09526 L
.80132 .06507 L
.76127 .05082 L
.72137 .0395 L
.68074 .03042 L
.65866 .02639 L
.63479 .0227 L
.61369 .01998 L
.59013 .01751 L
.56851 .01575 L
.55876 .01512 L
.54807 .01453 L
.53831 .01409 L
.52786 .01373 L
.51681 .01347 L
.50652 .01333 L
.49624 .01329 L
.48652 .01335 L
.47781 .01349 L
.46837 .01372 L
.45804 .01407 L
.4467 .01459 L
.42387 .01601 L
.40287 .01779 L
.38339 .01987 L
.34068 .0259 L
.29565 .03468 L
Mistroke
.255 .04504 L
.21928 .05641 L
.1581 .08231 L
.12807 .09913 L
.10377 .11568 L
.08095 .13477 L
.06085 .15614 L
.0471 .17522 L
.03577 .19683 L
.03116 .20926 L
.02809 .22069 L
.02686 .22704 L
.02634 .2304 L
.02589 .23396 L
.02559 .23707 L
.02535 .2405 L
.02516 .24655 L
.02527 .25262 L
.02563 .25816 L
.02633 .26424 L
.02679 .26729 L
.02738 .27062 L
.03018 .28222 L
.03377 .2929 L
.03896 .30479 L
.04478 .31558 L
.06156 .33922 L
.08036 .35907 L
.10411 .37883 L
.15394 .40962 L
.18662 .42491 L
.21967 .43765 L
.25712 .44947 L
.30025 .46027 L
.34283 .46844 L
.36368 .47163 L
.38353 .47421 L
.40291 .47633 L
.42085 .47793 L
.44089 .47932 L
.45146 .4799 L
.46263 .48039 L
.4728 .48072 L
.48368 .48097 L
.49396 .48109 L
.50332 .48112 L
.51431 .48104 L
.52051 .48094 L
.52623 .48082 L
.53673 .48051 L
Mistroke
.54783 .48006 L
.57019 .47878 L
.5913 .4771 L
.63042 .47274 L
.67153 .46629 L
.71482 .45717 L
.75082 .44751 L
.78715 .43548 L
.84622 .40955 L
.87758 .39124 L
.90297 .3729 L
.92671 .35128 L
.94677 .32704 L
.95359 .31649 L
.95982 .305 L
.96429 .29493 L
.96817 .28386 L
.97004 .27708 L
.97142 .27077 L
.97243 .26473 L
.97283 .26168 L
.97318 .25831 L
.97356 .25249 L
.97365 .24922 L
.97366 .24622 L
.97348 .2407 L
.97303 .23489 L
.9723 .22915 L
.97121 .22295 L
.96843 .21176 L
.96472 .20095 L
.96044 .1911 L
.94771 .1692 L
.92981 .14696 L
.91088 .12875 L
.89041 .11264 L
.83472 .07985 L
.80141 .06519 L
.76213 .05118 L
.72527 .04059 L
.68408 .03118 L
.64164 .0238 L
.60215 .0188 L
.58279 .01696 L
.56172 .0154 L
.55199 .01483 L
.54172 .01434 L
.53214 .01397 L
.52328 .01371 L
.51232 .01349 L
Mistroke
.50655 .01343 L
.50042 .01339 L
.49013 .01342 L
.4788 .01357 L
.46874 .01381 L
.45794 .01417 L
.44775 .01463 L
.43845 .01513 L
.4164 .01668 L
.39252 .01893 L
.34974 .02452 L
.31114 .03142 L
.27149 .04059 L
.20511 .06165 L
.1687 .07714 L
.13816 .09311 L
.10881 .11199 L
.08119 .13453 L
.06136 .1555 L
.04659 .17601 L
.04015 .18743 L
.03509 .19842 L
.03054 .21123 L
.02897 .21689 L
.02758 .22302 L
.02657 .22874 L
.02588 .23398 L
.02543 .23901 L
.02518 .24431 L
.02517 .25013 L
.02541 .25554 L
.02596 .26148 L
.02639 .2648 L
.02686 .26781 L
.0294 .27947 L
.03132 .28601 L
.03342 .29201 L
.04403 .31433 L
.05644 .33284 L
.07349 .3524 L
.11819 .38876 L
.14812 .4066 L
.17967 .42197 L
.24604 .4463 L
.28652 .4572 L
.32584 .46553 L
.37054 .47265 L
.39608 .4757 L
.41948 .47789 L
.44007 .47935 L
Mistroke
.4518 .47999 L
.46276 .48046 L
.47437 .48084 L
.48496 .48106 L
.49082 .48114 L
.49719 .48118 L
.50877 .48116 L
.51864 .48104 L
.52953 .4808 L
.54088 .48042 L
.55151 .47995 L
.57042 .47883 L
.59067 .47722 L
.61279 .47497 L
.63668 .47194 L
.68367 .46403 L
.72546 .45456 L
.76247 .44395 L
.79923 .43091 L
.83599 .41474 L
.86543 .39882 L
.89321 .38041 L
.91508 .36255 L
.93537 .34172 L
.95024 .32186 L
.96092 .30267 L
.96581 .2909 L
.9693 .27989 L
.97071 .27411 L
.97195 .26771 L
.97245 .26449 L
.97289 .261 L
.97321 .25771 L
.97343 .25469 L
.97364 .24915 L
.97361 .244 L
.97332 .23834 L
.97272 .2323 L
.9723 .22926 L
.97177 .22597 L
.97056 .22 L
.96752 .20889 L
.96382 .19875 L
.95874 .18771 L
.94536 .16591 L
.92935 .1465 L
.91133 .12917 L
.88711 .11034 L
.85677 .09138 L
.82691 .07619 L
Mistroke
.79219 .06166 L
.75521 .04907 L
.71974 .03924 L
.6853 .03148 L
.64619 .02454 L
.60416 .01907 L
.58082 .01685 L
.56955 .01598 L
.55885 .01528 L
.54895 .01473 L
.53816 .01424 L
.52833 .0139 L
.51923 .01367 L
.50941 .01351 L
.49857 .01344 L
.48725 .0135 L
.47662 .01366 L
.46577 .01394 L
.45963 .01416 L
.45393 .01439 L
.43014 .0157 L
.4097 .01729 L
.38806 .01946 L
.33949 .02621 L
.29686 .0345 L
.2583 .04418 L
.21962 .05635 L
.15698 .08291 L
.12649 .10012 L
.10116 .11766 L
.0772 .13833 L
.05623 .16196 L
.04846 .17303 L
.04138 .18505 L
.03627 .1956 L
.03183 .20713 L
.02965 .21428 L
.02802 .22088 L
.0268 .22721 L
.02631 .23044 L
.02587 .2339 L
.02535 .23992 L
.02514 .24554 L
.02514 .24897 L
.02522 .25222 L
.02562 .2583 L
.02622 .26366 L
.02715 .26956 L
.02844 .2757 L
.02992 .28144 L
Mistroke
.03326 .29162 L
.03781 .30246 L
.05183 .32657 L
.06899 .34773 L
.08898 .36684 L
.114 .38596 L
.16783 .41659 L
.20571 .43266 L
.24435 .44583 L
.28086 .45587 L
.32286 .46501 L
.36545 .472 L
.4063 .47677 L
.42918 .47867 L
.45019 .47995 L
.46185 .48047 L
.46801 .48069 L
.47457 .48088 L
.48028 .48101 L
.48659 .48112 L
.49773 .48122 L
.50812 .4812 L
.51906 .48107 L
.52839 .48087 L
.5386 .48054 L
.5496 .48007 L
.56133 .47944 L
.58237 .47796 L
.6035 .47601 L
.62327 .47375 L
.65968 .46843 L
.69806 .46106 L
.73863 .45106 L
.77611 .43944 L
.81375 .42495 L
.84606 .40964 L
.87293 .39422 L
.91732 .36048 L
.93615 .34078 L
.95217 .31879 L
.95839 .30779 L
.96329 .29729 L
.96687 .28783 L
.96993 .27738 L
.97128 .27134 L
.97226 .26569 L
.97301 .25971 L
.97331 .25636 L
.9735 .2533 L
.97364 .24784 L
Mistroke
.97352 .2419 L
.97314 .23629 L
.97255 .23112 L
.97161 .22518 L
.97047 .21963 L
.96691 .20706 L
.96218 .19494 L
.95571 .18208 L
.94127 .16047 L
.92423 .14123 L
.90174 .12124 L
.87362 .10141 L
.83979 .08242 L
.8043 .06643 L
.77007 .05384 L
.72997 .0419 L
.68955 .03238 L
.65027 .02521 L
.60756 .01947 L
.58317 .01708 L
.57231 .01621 L
.56071 .01542 L
.54975 .0148 L
.53981 .01434 L
.52981 .01397 L
.52039 .01372 L
.50933 .01353 L
.49918 .01347 L
.48804 .01351 L
.47629 .01369 L
.46673 .01394 L
.45651 .0143 L
.43813 .01522 L
.4164 .01675 L
.39676 .01855 L
.355 .02377 L
.31198 .0313 L
.27655 .03933 L
.23922 .04985 L
.20151 .06305 L
.16407 .07937 L
.10603 .114 L
.08137 .13435 L
.06223 .15443 L
.04562 .17755 L
.03842 .19088 L
.03322 .20315 L
.03123 .20891 L
.02943 .21502 L
.02813 .22032 L
Mistroke
.02699 .22602 L
.02647 .22923 L
.02607 .23216 L
.02548 .23791 L
.02528 .24113 L
.02515 .24463 L
.02512 .24794 L
.02517 .25099 L
.02545 .25638 L
.02593 .26143 L
.02669 .26696 L
.0278 .2729 L
.03096 .28494 L
.0349 .29587 L
.0456 .31703 L
.06119 .33886 L
.07969 .35852 L
.09953 .37545 L
.12635 .39406 L
.15935 .41248 L
.19365 .42795 L
.22836 .44075 L
.26596 .45205 L
.30205 .4608 L
.34373 .46872 L
.36757 .47231 L
.38999 .4751 L
.41368 .47746 L
.43532 .47911 L
.44777 .47985 L
.45952 .48039 L
.47195 .48083 L
.47895 .481 L
.4854 .48112 L
.49638 .48124 L
.50663 .48123 L
.51787 .48111 L
.52417 .48099 L
.5299 .48084 L
.54144 .48045 L
.55396 .47987 L
.5766 .47843 L
.59718 .47666 L
.61914 .47427 L
.65818 .46869 L
.70313 .45995 L
.74252 .44997 L
.81686 .4236 L
.84996 .40757 L
.88231 .3881 L
Mistroke
.90879 .36806 L
.92991 .34784 L
.9455 .32877 L
.95862 .30732 L
.96386 .2959 L
.96833 .28321 L
.97007 .27676 L
.97156 .26982 L
.97214 .26645 L
.9726 .26325 L
.97323 .25724 L
.97356 .25161 L
.97362 .24562 L
.97344 .24051 L
.97299 .23487 L
.97222 .22884 L
.97105 .22236 L
.96963 .21626 L
.96806 .21069 L
.9595 .18926 L
.95302 .1775 L
.94612 .167 L
.9115 .12936 L
.8866 .11002 L
.8555 .09072 L
.8228 .07435 L
.78939 .06066 L
.71791 .03883 L
.67711 .02992 L
.63156 .02246 L
.60827 .01956 L
.58256 .01704 L
.57071 .01611 L
.55804 .01527 L
.54613 .01463 L
.53515 .01417 L
.52353 .01381 L
.51741 .01367 L
.51095 .01357 L
.50006 .01348 L
.49389 .01349 L
.48812 .01352 L
.47735 .01368 L
.46755 .01393 L
.45624 .01432 L
.44556 .01482 L
.42457 .01612 L
.40501 .01775 L
.38194 .02019 L
.36104 .0229 L
Mistroke
.31934 .02985 L
.27608 .03945 L
.20825 .06048 L
.17712 .07326 L
.14576 .08883 L
.11557 .10725 L
.09063 .12612 L
.0712 .14439 L
.05416 .16471 L
.04681 .1756 L
.03994 .18779 L
.03475 .19918 L
.03097 .2097 L
.02925 .21567 L
.02771 .22221 L
.02702 .22581 L
.02647 .22914 L
.02601 .23254 L
.02566 .23574 L
.02542 .23873 L
.02523 .24196 L
.02511 .2476 L
.02516 .2508 L
.0253 .25418 L
.02579 .26022 L
.02652 .26591 L
.02762 .27207 L
.03042 .2832 L
.03412 .29395 L
.0384 .30376 L
.0511 .32557 L
.06898 .34775 L
.08783 .36589 L
.10825 .38196 L
.16387 .41472 L
.19695 .42929 L
.23603 .44327 L
.27272 .45384 L
.3138 .46327 L
.35604 .47067 L
.39545 .47571 L
.41475 .47757 L
.4358 .47915 L
.44551 .47973 L
.45579 .48025 L
.46537 .48063 L
.47426 .4809 L
.48512 .48113 L
.49085 .4812 L
.49695 .48125 L
Mistroke
.50717 .48124 L
.51846 .48111 L
.52846 .48089 L
.53923 .48054 L
.54938 .48011 L
.55867 .47962 L
.57955 .47821 L
.60223 .47616 L
.64721 .47044 L
.68572 .46365 L
.7254 .4546 L
.79196 .43372 L
.82831 .41842 L
.85892 .4026 L
.88838 .38389 L
.91623 .36147 L
.93626 .34064 L
.95127 .3202 L
.95784 .30883 L
.96304 .29786 L
.96776 .28506 L
.97087 .27324 L
.97197 .26746 L
.97243 .26442 L
.97284 .26121 L
.97337 .25529 L
.9736 .24985 L
.97359 .2446 L
.97338 .23972 L
.97293 .23436 L
.97218 .22864 L
.97108 .22254 L
.96955 .21594 L
.96583 .20403 L
.96108 .19257 L
.95571 .18211 L
.94363 .1636 L
.92689 .14396 L
.88273 .10738 L
.85477 .09032 L
.82204 .07402 L
.75621 .04943 L
.71604 .03838 L
.67691 .02989 L
.63237 .02258 L
.60688 .01942 L
.58346 .01712 L
.56304 .01559 L
.55125 .0149 L
.54046 .01439 L
Mistroke
.52905 .01397 L
.52276 .01379 L
.51678 .01367 L
.50617 .01352 L
.49461 .01349 L
.48478 .01357 L
.47393 .01376 L
.4626 .01409 L
.45197 .01451 L
.43307 .01555 L
.41278 .01706 L
.39072 .0192 L
.36682 .02211 L
.31971 .02978 L
.27775 .03903 L
.24047 .04946 L
.20363 .06223 L
.16663 .07813 L
.13693 .09381 L
.10874 .11202 L
.08652 .12967 L
.06574 .15033 L
.0504 .17005 L
.03924 .18918 L
.03409 .20083 L
.03034 .21176 L
.02866 .21798 L
.02738 .22386 L
.02679 .22713 L
.02625 .23066 L
.02585 .23385 L
.02556 .23683 L
.02521 .24238 L
.02511 .24846 L
.02531 .25439 L
.02554 .25771 L
.02584 .26073 L
.02655 .26612 L
.0276 .27197 L
.03022 .28256 L
.03363 .29268 L
.03838 .30374 L
.05113 .32562 L
.06657 .34512 L
.08411 .36262 L
.13436 .39894 L
.16452 .41504 L
.2008 .43082 L
.23435 .44273 L
.27235 .45375 L
Mistroke
.30718 .46191 L
.3454 .46901 L
.36704 .47226 L
.39117 .47525 L
.41363 .47748 L
.43432 .47906 L
.44689 .47981 L
.45886 .48038 L
.47152 .48083 L
.47869 .48101 L
.48534 .48114 L
.49162 .48121 L
.49752 .48125 L
.50855 .48123 L
.51474 .48117 L
.52043 .48108 L
.52667 .48094 L
.53324 .48075 L
.54444 .48034 L
.55462 .47985 L
.57738 .47838 L
.59833 .47655 L
.61797 .47442 L
.66119 .46819 L
.70655 .45918 L
.745 .44926 L
.77923 .43836 L
.81727 .42342 L
.84921 .40796 L
.90446 .37166 L
.92753 .35037 L
.94699 .32665 L
.95425 .31529 L
.96006 .30441 L
.96446 .29438 L
.96818 .28368 L
.96974 .27808 L
.97115 .27191 L
.97215 .26628 L
.97286 .261 L
.97317 .25781 L
.9734 .25478 L
.97361 .2491 L
.97354 .24298 L
.97337 .23952 L
.97312 .23632 L
.97258 .23145 L
.97178 .2262 L
.96975 .21674 L
.96637 .20557 L
Mistroke
.96237 .19542 L
.9514 .17491 L
.93601 .15404 L
.91626 .13362 L
.89501 .1161 L
.86885 .09849 L
.83691 .08102 L
.80434 .06647 L
.77199 .05452 L
.70287 .0353 L
.66439 .0276 L
.64263 .02406 L
.62166 .02117 L
.60201 .0189 L
.58036 .01687 L
.56053 .01544 L
.54204 .01446 L
.5305 .01402 L
.52399 .01383 L
.51799 .01369 L
.50696 .01353 L
.49531 .01349 L
.48485 .01357 L
.47509 .01374 L
.4644 .01403 L
.45296 .01447 L
.44079 .01508 L
.4276 .01591 L
.40376 .01787 L
.38078 .02033 L
.35977 .02309 L
.32059 .02961 L
.27985 .03851 L
.21116 .05939 L
.175 .07422 L
.14037 .09183 L
.11147 .11008 L
.08847 .12797 L
.06917 .14654 L
.05203 .16769 L
.04434 .17969 L
.03837 .19095 L
.03342 .20256 L
.02983 .21353 L
.02755 .22299 L
.02659 .22832 L
.02593 .2332 L
.02542 .23854 L
.02514 .24435 L
.02513 .24985 L
Mistroke
.02534 .25494 L
.02583 .26069 L
.02654 .26609 L
.02738 .27092 L
.02851 .27613 L
.03186 .28777 L
.03593 .29836 L
.04703 .31938 L
.06302 .34107 L
.08187 .36058 L
.10202 .37738 L
.12914 .39581 L
.16247 .41405 L
.19704 .42934 L
.23202 .44198 L
.2697 .45307 L
.30587 .46164 L
.3476 .46937 L
.37147 .47286 L
.39394 .47556 L
.41577 .47766 L
.43925 .47938 L
.45272 .48011 L
.46546 .48064 L
.47691 .48097 L
.48337 .48111 L
.48932 .48119 L
.50029 .48126 L
.51053 .48122 L
.52176 .48105 L
.52806 .4809 L
.53379 .48074 L
.54532 .4803 L
.55783 .47967 L
.58048 .47814 L
.60095 .47629 L
.6228 .47383 L
.66167 .46811 L
.70639 .45922 L
.74559 .44909 L
.81944 .42246 L
.85227 .40631 L
.88436 .38669 L
.91046 .36661 L
.93126 .34636 L
.94656 .32726 L
.95939 .30577 L
.96446 .29437 L
.96876 .28168 L
.97042 .27524 L
Mistroke
.97182 .2683 L
.97235 .26494 L
.97277 .26174 L
.97333 .25572 L
.97359 .2501 L
.97358 .24412 L
.97329 .23847 L
.97281 .23337 L
.97197 .22735 L
.97072 .22087 L
.96758 .20919 L
.96362 .19836 L
.95829 .1869 L
.9459 .16672 L
.92664 .14372 L
.90504 .12393 L
.87864 .10467 L
.84582 .08554 L
.81149 .06943 L
.77651 .05606 L
.70381 .03551 L
.66253 .02728 L
.64073 .02378 L
.61655 .02054 L
.59402 .01809 L
.56974 .01605 L
.55622 .01518 L
.5439 .01454 L
.53795 .01429 L
.5315 .01405 L
.51978 .01373 L
.50897 .01355 L
.50282 .0135 L
.49708 .01349 L
.4855 .01356 L
.47901 .01366 L
.47308 .01379 L
.46253 .01409 L
.45106 .01456 L
.43027 .01573 L
.40977 .01732 L
.38782 .01952 L
.34872 .02474 L
.3036 .03305 L
.26389 .04264 L
.18872 .06822 L
.15505 .08389 L
.12192 .10302 L
.09481 .12265 L
.07296 .14255 L
Mistroke
.05665 .16136 L
.04267 .18262 L
.03699 .19392 L
.032 .20653 L
.03 .21292 L
.02822 .21983 L
.02691 .22638 L
.02602 .23239 L
.02544 .23833 L
.02515 .24384 L
.02513 .2499 L
.02524 .25328 L
.02543 .25635 L
.02598 .26198 L
.02686 .26805 L
.02797 .27376 L
.02923 .27901 L
.03273 .29026 L
.03684 .30042 L
.0492 .32277 L
.06443 .34271 L
.08207 .36077 L
.13206 .39758 L
.16611 .41582 L
.2009 .43086 L
.23445 .44277 L
.27282 .45388 L
.30755 .462 L
.34693 .46927 L
.39195 .47534 L
.41694 .47776 L
.42899 .4787 L
.4404 .47945 L
.45104 .48003 L
.46258 .48053 L
.4731 .48088 L
.4828 .4811 L
.49331 .48123 L
.50488 .48125 L
.5107 .48122 L
.51695 .48114 L
.52823 .4809 L
.53438 .48072 L
.54015 .48051 L
.55092 .48004 L
.57494 .47856 L
.59555 .47682 L
.61762 .47446 L
.6668 .46722 L
.71033 .4583 L
Mistroke
.74709 .44866 L
.78522 .43621 L
.82199 .42132 L
.85381 .40546 L
.88186 .38839 L
.90853 .36826 L
.9275 .3504 L
.9448 .32972 L
.95907 .30641 L
.96486 .29333 L
.96713 .28699 L
.96898 .28092 L
.9704 .27535 L
.97165 .26925 L
.97253 .26368 L
.97311 .25851 L
.97352 .25236 L
.97362 .24678 L
.97356 .24369 L
.97341 .24034 L
.97291 .23428 L
.97216 .22854 L
.97123 .22331 L
.96833 .21162 L
.96463 .20088 L
.96024 .19081 L
.94735 .16878 L
.92863 .14581 L
.90591 .12465 L
.87723 .10375 L
.84644 .08586 L
.81518 .07101 L
.74765 .04687 L
.70903 .03672 L
.66648 .02797 L
.62809 .022 L
.59154 .01786 L
.57027 .01609 L
.55081 .01488 L
.53999 .01437 L
.52824 .01395 L
.51712 .01368 L
.50685 .01353 L
.49569 .01349 L
.48508 .01357 L
.47557 .01373 L
.4652 .01401 L
.45398 .01443 L
.44206 .01501 L
.4207 .01642 L
Mistroke
.39919 .01832 L
.37911 .02053 L
.34221 .02578 L
.29927 .03398 L
.26139 .04333 L
.22224 .05544 L
.18318 .07058 L
.15025 .0864 L
.12307 .10228 L
.07857 .13697 L
.05916 .15815 L
.05061 .16973 L
.04285 .1823 L
.03721 .19344 L
.03221 .2059 L
.03044 .2114 L
.02881 .21735 L
.02756 .22291 L
.02661 .22816 L
.02583 .23401 L
.02536 .23932 L
.02512 .24505 L
.0251 .24828 L
.02516 .25126 L
.02542 .25623 L
.02594 .26168 L
.02674 .26737 L
.02773 .27267 L
.0309 .28482 L
.03485 .2958 L
.04067 .30831 L
.0474 .31998 L
.0642 .34245 L
.08369 .36225 L
.10918 .38264 L
.14067 .40259 L
.20824 .43367 L
.2512 .44793 L
.29321 .45885 L
.33181 .4667 L
.37553 .47339 L
.39802 .47599 L
.42235 .4782 L
.43422 .47906 L
.44549 .47974 L
.45653 .48029 L
.46666 .48068 L
.47688 .48097 L
.4879 .48118 L
.49811 .48126 L
Mistroke
.50782 .48124 L
.51907 .4811 L
.5295 .48087 L
.54094 .48048 L
.5531 .47993 L
.57767 .47836 L
.60063 .47633 L
.6429 .47109 L
.68174 .46444 L
.71633 .45687 L
.78914 .43477 L
.82159 .4215 L
.85357 .40559 L
.90294 .37288 L
.92721 .3507 L
.94574 .32842 L
.95847 .30758 L
.96399 .29554 L
.968 .28426 L
.96954 .27884 L
.97089 .27312 L
.97184 .26816 L
.97263 .26285 L
.97323 .25711 L
.97354 .25176 L
.97361 .24849 L
.9736 .2454 L
.97337 .23963 L
.97294 .23454 L
.97225 .22916 L
.97148 .22457 L
.97042 .21954 L
.96732 .20839 L
.96349 .19806 L
.95142 .17493 L
.93644 .15456 L
.91469 .1322 L
.88984 .11233 L
.83412 .07966 L
.79809 .06399 L
.76286 .05152 L
.72788 .04138 L
.68826 .03215 L
.64941 .02511 L
.61273 .02009 L
.59121 .01783 L
.57145 .01618 L
.56046 .01543 L
.54848 .01476 L
.53715 .01426 L
Mistroke
.52665 .0139 L
.51698 .01367 L
.50791 .01354 L
.49795 .01349 L
.48723 .01354 L
.47659 .01371 L
.46542 .014 L
.45589 .01435 L
.44549 .01483 L
.42143 .01636 L
.39976 .01826 L
.37499 .02104 L
.35195 .02424 L
.31183 .03133 L
.27005 .041 L
.19923 .06394 L
.16309 .07984 L
.13245 .09645 L
.10425 .1153 L
.08112 .13456 L
.05912 .1582 L
.05058 .16978 L
.04365 .18088 L
.03382 .2015 L
.03008 .21264 L
.02855 .21842 L
.0272 .22476 L
.02668 .22778 L
.0262 .23101 L
.02555 .23684 L
.0253 .24027 L
.02516 .24351 L
.02512 .24959 L
.02535 .25528 L
.02581 .26052 L
.02656 .26626 L
.02766 .27233 L
.03016 .28237 L
.03377 .29307 L
.04271 .3121 L
.05729 .33404 L
.07425 .35325 L
.09527 .37211 L
.12132 .39089 L
.1768 .42078 L
.21558 .43636 L
.25494 .44901 L
.292 .45857 L
.33445 .46717 L
.35509 .47054 L
Mistroke
.37753 .47364 L
.39716 .4759 L
.4187 .47791 L
.43141 .47887 L
.4432 .47961 L
.45429 .48019 L
.46654 .48068 L
.47752 .48099 L
.48783 .48118 L
.49872 .48126 L
.51046 .48122 L
.52083 .48107 L
.53048 .48084 L
.54105 .48048 L
.55231 .47997 L
.57525 .47854 L
.59594 .47679 L
.63539 .47217 L
.67175 .46633 L
.70982 .45842 L
.74988 .44783 L
.78676 .43565 L
.82359 .42059 L
.85508 .40476 L
.88108 .38891 L
.92353 .35446 L
.94128 .3344 L
.94944 .32302 L
.95606 .31211 L
.96131 .30174 L
.96595 .29041 L
.96923 .28 L
.97144 .27038 L
.97237 .2648 L
.97308 .25881 L
.97348 .25315 L
.97361 .248 L
.9735 .24195 L
.9733 .23854 L
.97303 .23539 L
.97232 .22961 L
.97127 .22351 L
.96998 .2177 L
.96828 .21147 L
.9644 .2003 L
.95843 .18718 L
.9517 .17538 L
.93674 .15491 L
.91678 .13411 L
.87117 .09992 L
Mistroke
.83766 .0814 L
.80266 .0658 L
.76897 .05351 L
.72961 .04184 L
.69183 .03289 L
.64971 .02515 L
.62587 .02171 L
.60382 .01909 L
.58117 .01694 L
.56004 .01541 L
.5405 .01439 L
.5306 .01402 L
.51965 .01373 L
.50871 .01355 L
.4969 .01349 L
.48575 .01356 L
.47553 .01373 L
.46588 .01398 L
.45691 .01431 L
.4366 .01533 L
.41692 .01672 L
.39603 .01864 L
.35009 .02453 L
.30896 .03192 L
.26564 .04217 L
.2223 .05542 L
.15684 .08296 L
.1245 .10136 L
.09786 .12021 L
.07556 .13992 L
.05564 .1627 L
.04812 .1735 L
.04126 .18522 L
.03591 .19637 L
.03192 .20674 L
.0287 .21781 L
.02741 .22366 L
.02636 .22986 L
.0257 .23526 L
.0253 .24031 L
.02511 .24585 L
.02518 .25178 L
.02548 .25705 L
.02607 .26278 L
.02688 .26818 L
.02784 .27315 L
.0302 .28252 L
.03351 .2924 L
.03811 .30318 L
.044 .31437 L
Mistroke
.05717 .33387 L
.07499 .354 L
.0986 .37476 L
.12239 .39158 L
.15091 .40818 L
.20952 .43414 L
.24898 .44727 L
.28753 .45753 L
.33185 .46671 L
.35513 .47054 L
.38053 .47401 L
.40312 .4765 L
.42393 .47832 L
.434 .47904 L
.445 .47971 L
.45534 .48023 L
.46508 .48063 L
.47632 .48096 L
.4823 .48109 L
.48876 .48119 L
.49516 .48124 L
.50191 .48126 L
.50767 .48124 L
.51398 .48118 L
.52531 .48097 L
.53165 .4808 L
.53741 .48061 L
.54866 .48015 L
.55917 .4796 L
.57951 .47822 L
.60175 .47621 L
.64601 .47063 L
.68323 .46415 L
.7219 .45549 L
.76486 .44319 L
.80305 .42939 L
.83773 .41387 L
.86636 .39824 L
.91519 .36241 L
.93615 .34075 L
.95181 .31932 L
.95754 .30938 L
.96265 .29874 L
.9663 .28943 L
.96939 .27938 L
.97077 .27369 L
.97178 .26849 L
.97258 .26325 L
.97313 .25828 L
.97351 .2525 L
Mistroke
.97362 .24714 L
.97346 .24127 L
.97328 .2383 L
.97299 .23503 L
.97229 .22939 L
.9714 .22415 L
.96854 .21232 L
.96464 .2009 L
.95928 .18885 L
.94645 .16751 L
.93143 .14884 L
.91 .12809 L
.88232 .10711 L
.85246 .08907 L
.82142 .07375 L
.75395 .04875 L
.71483 .0381 L
.67074 .02874 L
.648 .02488 L
.62279 .02131 L
.60027 .01872 L
.57604 .01652 L
.56359 .01563 L
.55184 .01494 L
.54036 .01439 L
.5298 .014 L
.51972 .01373 L
.50907 .01355 L
.49838 .01349 L
.48666 .01355 L
.47497 .01374 L
.46417 .01404 L
.45235 .0145 L
.43983 .01514 L
.4189 .01656 L
.39602 .01864 L
.35446 .02386 L
.31653 .0304 L
.27386 .04001 L
.23667 .05066 L
.19856 .0642 L
.16113 .08081 L
.13001 .09793 L
.10481 .11488 L
.08241 .13336 L
.06484 .15134 L
.0482 .17337 L
.0412 .18532 L
.03515 .19816 L
.03103 .20947 L
Mistroke
.02815 .22013 L
.02693 .22627 L
.02608 .23189 L
.02573 .235 L
.02543 .23839 L
.02523 .24159 L
.02513 .24455 L
.02513 .25002 L
.02539 .25577 L
.02582 .26068 L
.02653 .26604 L
.02756 .27181 L
.02896 .27797 L
.03228 .28899 L
.03665 .30002 L
.04173 .3103 L
.05361 .32914 L
.07179 .35074 L
.09223 .36963 L
.11825 .38888 L
.15029 .40785 L
.18281 .42343 L
.21504 .43616 L
.28409 .45671 L
.32542 .46554 L
.34789 .46942 L
.37223 .47296 L
.39594 .47577 L
.41766 .47782 L
.42821 .47864 L
.43966 .4794 L
.45035 .48 L
.46049 .48045 L
.47157 .48083 L
.48168 .48108 L
.49257 .48123 L
.49873 .48126 L
.50442 .48126 L
.51388 .48118 L
.52431 .481 L
.53519 .48069 L
.54538 .4803 L
.55673 .47974 L
.56864 .47901 L
.58983 .47735 L
.61243 .47506 L
.63685 .47196 L
.68142 .4645 L
.72709 .45416 L
.76792 .44219 L
Mistroke
.80272 .42952 L
.80576 .42829 L
Mfstroke
.92279 .35581 m
.94031 .33634 L
.95347 .31744 L
.95949 .30652 L
.96424 .29605 L
.96857 .28385 L
.97006 .27853 L
.97142 .27264 L
.97248 .26688 L
.97323 .26148 L
.97375 .25576 L
.97402 .24961 L
.97399 .2439 L
.97372 .23848 L
.97327 .23362 L
.97255 .22833 L
.9714 .22202 L
.97007 .21633 L
.96613 .20364 L
.96129 .19203 L
.9557 .18125 L
.94056 .15893 L
.91993 .13647 L
.89874 .11841 L
.87193 .09992 L
.83924 .08175 L
.80021 .06445 L
.76035 .0504 L
.72104 .03935 L
.68099 .03046 L
.63681 .02303 L
.61341 .02002 L
.59118 .0177 L
.56657 .01574 L
.55264 .01491 L
.53984 .01431 L
.5294 .01394 L
.51822 .01367 L
.50767 .01352 L
.49808 .01349 L
.4868 .01356 L
.48043 .01365 L
.47457 .01377 L
.4638 .01409 L
.45242 .01455 L
.44156 .0151 L
.42991 .01583 L
.40899 .01749 L
.38432 .02004 L
.36206 .02291 L
Mistroke
.32167 .0296 L
.28019 .03866 L
.21077 .05983 L
.17229 .07579 L
.1394 .09273 L
.11311 .10931 L
.08785 .12892 L
.06691 .14949 L
.05106 .16964 L
.03834 .19173 L
.03308 .20439 L
.03119 .21003 L
.02947 .21604 L
.02823 .22122 L
.02713 .22695 L
.02636 .23217 L
.02585 .23707 L
.02549 .24284 L
.02541 .24812 L
.02558 .25392 L
.02607 .26001 L
.02669 .26499 L
.02758 .2703 L
.02976 .2798 L
.03334 .29103 L
.03749 .3011 L
.04947 .32261 L
.06641 .34449 L
.0842 .3623 L
.10709 .38078 L
.13538 .39922 L
.16961 .41719 L
.24023 .44438 L
.28108 .45578 L
.32078 .46451 L
.36602 .47201 L
.3894 .47497 L
.41555 .47758 L
.4267 .47848 L
.4385 .47929 L
.44873 .47988 L
.45969 .4804 L
.46589 .48064 L
.47154 .48082 L
.48259 .48109 L
.48878 .48119 L
.4955 .48126 L
.50185 .48128 L
.5077 .48126 L
.51809 .48115 L
Mistroke
.5278 .48095 L
.53845 .48063 L
.54988 .48015 L
.57308 .47878 L
.59416 .47705 L
.6356 .47227 L
.65832 .46881 L
.6786 .46521 L
.75175 .44748 L
.78973 .43478 L
.82777 .41891 L
.8602 .40213 L
.8873 .38493 L
.91165 .36588 L
.9306 .34742 L
.94779 .32589 L
.95554 .31351 L
.96151 .30185 L
.96619 .2904 L
.96996 .27812 L
.97141 .27172 L
.97247 .26569 L
.97294 .26224 L
.97328 .25907 L
.97357 .25559 L
.97376 .25192 L
.97384 .24621 L
.97363 .2401 L
.97315 .23435 L
.97248 .22913 L
.9714 .22301 L
.96989 .21639 L
.96622 .20448 L
.96187 .19377 L
.95613 .18242 L
.94302 .16243 L
.92298 .13971 L
.90066 .12016 L
.87367 .10124 L
.84019 .08244 L
.76978 .05362 L
.72903 .04156 L
.68867 .03213 L
.65102 .02529 L
.60921 .01963 L
.587 .01741 L
.56245 .01554 L
.54999 .01483 L
.53663 .01424 L
.53014 .01401 L
Mistroke
.524 .01384 L
.51248 .01361 L
.50163 .01352 L
.49012 .01355 L
.48029 .01367 L
.46948 .01392 L
.45789 .01432 L
.44545 .01489 L
.42305 .01631 L
.40079 .01824 L
.37728 .02085 L
.33576 .02698 L
.28813 .03665 L
.247 .04762 L
.21025 .0599 L
.17331 .07517 L
.1417 .09127 L
.11511 .10776 L
.09038 .12655 L
.07104 .14478 L
.05336 .16609 L
.04531 .17836 L
.03905 .18992 L
.03417 .20105 L
.03001 .21348 L
.02836 .21997 L
.02713 .22608 L
.02617 .23255 L
.02578 .2362 L
.02551 .23954 L
.02528 .24528 L
.02531 .25061 L
.0256 .25647 L
.02589 .25974 L
.02623 .26271 L
.02714 .26871 L
.02846 .2752 L
.03174 .2869 L
.03578 .29759 L
.04118 .30893 L
.05368 .32896 L
.07301 .35177 L
.09471 .37146 L
.12108 .39056 L
.15393 .4096 L
.22339 .43899 L
.26365 .45136 L
.30365 .4611 L
.34101 .46825 L
.38261 .47424 L
Mistroke
.40471 .47664 L
.42918 .47871 L
.44159 .47952 L
.45493 .48022 L
.46141 .4805 L
.46755 .48072 L
.47906 .48104 L
.4899 .48122 L
.50141 .48129 L
.51123 .48125 L
.52206 .48108 L
.53366 .48078 L
.54017 .48056 L
.54612 .48031 L
.56859 .47907 L
.59055 .47735 L
.61032 .47538 L
.65393 .46948 L
.69315 .46223 L
.72881 .45383 L
.80283 .42961 L
.84007 .41284 L
.87101 .39555 L
.89601 .37845 L
.91931 .35876 L
.93631 .34076 L
.95134 .3203 L
.95865 .3075 L
.96416 .29545 L
.96827 .28379 L
.96993 .27779 L
.97139 .27129 L
.97239 .26545 L
.97307 .26008 L
.9735 .25494 L
.97372 .24952 L
.97368 .24357 L
.97338 .23803 L
.97276 .23196 L
.97228 .22856 L
.97176 .22548 L
.96937 .21486 L
.96566 .20326 L
.9606 .19129 L
.95477 .18025 L
.94178 .16099 L
.92425 .14112 L
.89931 .11924 L
.87146 .09998 L
.8404 .08266 L
Mistroke
.80941 .06847 L
.73929 .04441 L
.69743 .03405 L
.65627 .02619 L
.61689 .02057 L
.57992 .01684 L
.56035 .01543 L
.54908 .0148 L
.53877 .01434 L
.52786 .01396 L
.51615 .01368 L
.50528 .01354 L
.49499 .01352 L
.48482 .0136 L
.47386 .0138 L
.46352 .0141 L
.45406 .01447 L
.43216 .01566 L
.4212 .01643 L
.40926 .01742 L
.3868 .01969 L
.36309 .02268 L
.3213 .02955 L
.28081 .03836 L
.24427 .04838 L
.18136 .07148 L
.1515 .08584 L
.12175 .10324 L
.09616 .12168 L
.07271 .14292 L
.05482 .16394 L
.04205 .18393 L
.03715 .19376 L
.03276 .2046 L
.02952 .21494 L
.02732 .22458 L
.02634 .23057 L
.02596 .23359 L
.02563 .2369 L
.02527 .24276 L
.02519 .24824 L
.02525 .25156 L
.0254 .2547 L
.0259 .26058 L
.0263 .26387 L
.02675 .2669 L
.02805 .27374 L
.03083 .28432 L
.03497 .29586 L
.04048 .30776 L
Mistroke
.04672 .31874 L
.06129 .33889 L
.07773 .35657 L
.12485 .39307 L
.1528 .40909 L
.18566 .42459 L
.25173 .44804 L
.29582 .45942 L
.3394 .46801 L
.37982 .47392 L
.40303 .4765 L
.4246 .47838 L
.43573 .47917 L
.44631 .4798 L
.45594 .48028 L
.46621 .48068 L
.47736 .48101 L
.4877 .4812 L
.49883 .48129 L
.50517 .48128 L
.51112 .48124 L
.52103 .4811 L
.53146 .48084 L
.54035 .48054 L
.55007 .48012 L
.5717 .47884 L
.59172 .47723 L
.6152 .47479 L
.63712 .47198 L
.67732 .46535 L
.71907 .45626 L
.76212 .44414 L
.82867 .41832 L
.86199 .40091 L
.88978 .38296 L
.91473 .36291 L
.93463 .34264 L
.94393 .33101 L
.95268 .31803 L
.95937 .30594 L
.96441 .29466 L
.96846 .28295 L
.97012 .27675 L
.97154 .27018 L
.97248 .26445 L
.97311 .25909 L
.97354 .2532 L
.97365 .2499 L
.97368 .24689 L
.97353 .24132 L
Mistroke
.97316 .23618 L
.97251 .23054 L
.97154 .22456 L
.96924 .21458 L
.96575 .20366 L
.96057 .19136 L
.95471 .18026 L
.9377 .15598 L
.91849 .13562 L
.89425 .11548 L
.83993 .08248 L
.8046 .06654 L
.76986 .05378 L
.73539 .04337 L
.69617 .03381 L
.65764 .02644 L
.6211 .0211 L
.60023 .01872 L
.58025 .01687 L
.56916 .01602 L
.55704 .01524 L
.54587 .01465 L
.53573 .01422 L
.52525 .01388 L
.51539 .01366 L
.50496 .01354 L
.49371 .01352 L
.48382 .01361 L
.4734 .0138 L
.46451 .01406 L
.45479 .01442 L
.44244 .01502 L
.4308 .01573 L
.40912 .01742 L
.38597 .01976 L
.36115 .02293 L
.31747 .03026 L
.27859 .03887 L
.24239 .04892 L
.20561 .06152 L
.1459 .0888 L
.11447 .10805 L
.08852 .12798 L
.06874 .14706 L
.05118 .16898 L
.04409 .18021 L
.03766 .19256 L
.03279 .2044 L
.02936 .2154 L
.02712 .22541 L
Mistroke
.02623 .23112 L
.02563 .23646 L
.02525 .2421 L
.02514 .24724 L
.02528 .25318 L
.02568 .2588 L
.02633 .26437 L
.02735 .27051 L
.02874 .27691 L
.03036 .28288 L
.03398 .29348 L
.03892 .30477 L
.05416 .32982 L
.07282 .35174 L
.09342 .37056 L
.11907 .38938 L
.1739 .41944 L
.21226 .43513 L
.25133 .44795 L
.28816 .45767 L
.33051 .46647 L
.35092 .4699 L
.37318 .47309 L
.39266 .47542 L
.41409 .47753 L
.4267 .47854 L
.43843 .47934 L
.45062 .48002 L
.46169 .48051 L
.47262 .48088 L
.48291 .48112 L
.49378 .48125 L
.50553 .48127 L
.51585 .48118 L
.52546 .48099 L
.53599 .48069 L
.54725 .48024 L
.55904 .47963 L
.57016 .47893 L
.59089 .47728 L
.62776 .47323 L
.66694 .46723 L
.70703 .4591 L
.7431 .44984 L
.78371 .4368 L
.81834 .42299 L
.87998 .38968 L
.90685 .36972 L
.93056 .34716 L
.94764 .32575 L
Mistroke
.95952 .30557 L
.96458 .29415 L
.96679 .28809 L
.9688 .28164 L
.97028 .27598 L
.97159 .26973 L
.97251 .26403 L
.97312 .2587 L
.9735 .2534 L
.97365 .24763 L
.97354 .24218 L
.97322 .23714 L
.97275 .23262 L
.97204 .22763 L
.97108 .22243 L
.96998 .21756 L
.96676 .20662 L
.96294 .19668 L
.9513 .1747 L
.93633 .15439 L
.91636 .13369 L
.87076 .09964 L
.83734 .08122 L
.80234 .06566 L
.76868 .05341 L
.72925 .04174 L
.69172 .03287 L
.64978 .02517 L
.62606 .02174 L
.60408 .01912 L
.58149 .01697 L
.56036 .01544 L
.54093 .01442 L
.53003 .01402 L
.52014 .01375 L
.50925 .01357 L
.49746 .01351 L
.48632 .01357 L
.47609 .01373 L
.46648 .01398 L
.45752 .0143 L
.43721 .01531 L
.41753 .01669 L
.39658 .0186 L
.35093 .02442 L
.30994 .03175 L
.26674 .0419 L
.2234 .05507 L
.15795 .08243 L
.12552 .10075 L
Mistroke
.09872 .11956 L
.07578 .13972 L
.05808 .15956 L
.04352 .18116 L
.03749 .19288 L
.03235 .20557 L
.02903 .21657 L
.0276 .22281 L
.02657 .22857 L
.02589 .23363 L
.02539 .2392 L
.02514 .24502 L
.02516 .25046 L
.02541 .25576 L
.02586 .26078 L
.02644 .26527 L
.02726 .27017 L
.02981 .28107 L
.03306 .2911 L
.0381 .30311 L
.0438 .31399 L
.06033 .33782 L
.07896 .35783 L
.10251 .37773 L
.15214 .40881 L
.18472 .42424 L
.21761 .43707 L
.25521 .44908 L
.29843 .46003 L
.34114 .46832 L
.36203 .47156 L
.38187 .47418 L
.41933 .47797 L
.43944 .4794 L
.4507 .48002 L
.46119 .48049 L
.47208 .48086 L
.47784 .48101 L
.48399 .48113 L
.49538 .48126 L
.50571 .48126 L
.5158 .48117 L
.52671 .48095 L
.53699 .48064 L
.54645 .48026 L
.56822 .47905 L
.58796 .47753 L
.61057 .47529 L
.63176 .47268 L
.66873 .4669 L
Mistroke
.70772 .45893 L
.7487 .4482 L
.78968 .43459 L
.82528 .41984 L
.85521 .40471 L
.90554 .37079 L
.92688 .35107 L
.94523 .32915 L
.95763 .30923 L
.96234 .29949 L
.96605 .29019 L
.96949 .27909 L
.97068 .27416 L
.97172 .26893 L
.9726 .26322 L
.97317 .25794 L
.97353 .25226 L
.97362 .24902 L
.97362 .246 L
.97342 .24019 L
.97318 .23694 L
.9729 .23401 L
.97213 .22829 L
.97117 .22292 L
.96814 .21093 L
.9659 .20422 L
.96352 .19809 L
.95251 .17666 L
.93668 .15483 L
.91887 .13604 L
.89937 .1194 L
.84553 .08538 L
.81301 .07007 L
.77453 .05538 L
.73824 .04418 L
.69764 .03414 L
.65962 .02678 L
.63895 .02352 L
.61637 .02052 L
.59546 .01824 L
.57614 .01654 L
.55755 .01527 L
.54733 .01471 L
.5379 .0143 L
.52687 .01392 L
.52106 .01377 L
.51491 .01365 L
.50456 .01352 L
.49319 .01351 L
.48306 .0136 L
Mistroke
.4722 .01382 L
.46196 .01413 L
.45262 .0145 L
.43038 .01574 L
.41787 .01665 L
.40633 .01765 L
.36319 .02262 L
.32734 .02837 L
.28893 .03634 L
.21625 .05756 L
.18197 .07112 L
.14876 .08721 L
.0979 .12019 L
.07488 .14061 L
.05715 .16073 L
.04204 .18379 L
.03562 .19706 L
.0311 .2093 L
.02822 .2199 L
.027 .22595 L
.02613 .23163 L
.0255 .23762 L
.02518 .2431 L
.02511 .24613 L
.02512 .24944 L
.02538 .25545 L
.02588 .26107 L
.02656 .26616 L
.02761 .27202 L
.02886 .27752 L
.0317 .28726 L
.03566 .29771 L
.04814 .32113 L
.05619 .33259 L
.06634 .34486 L
.11099 .38392 L
.14019 .40231 L
.17109 .41816 L
.23643 .44341 L
.27655 .45484 L
.31552 .46363 L
.35995 .47126 L
.38292 .47431 L
.4086 .47703 L
.42927 .47872 L
.45203 .48009 L
.46357 .48058 L
.46991 .48079 L
.47591 .48096 L
.48758 .48118 L
Mistroke
.49818 .48127 L
.50821 .48125 L
.51881 .48112 L
.52786 .48092 L
.53781 .48061 L
.54848 .48017 L
.55991 .47956 L
.58048 .47815 L
.60394 .476 L
.62924 .47301 L
.67428 .46587 L
.71653 .45683 L
.75394 .44663 L
.79148 .43391 L
.82905 .41808 L
.85924 .40243 L
.88779 .38431 L
.91045 .36663 L
.93158 .34601 L
.94723 .32631 L
.95864 .30727 L
.96402 .29548 L
.96795 .28445 L
.96972 .27816 L
.97108 .27224 L
.97219 .26605 L
.97265 .26276 L
.97305 .25921 L
.97346 .25361 L
.97362 .24748 L
.97359 .24438 L
.97346 .24108 L
.97301 .23515 L
.97227 .22922 L
.9713 .22364 L
.96881 .21326 L
.96543 .20294 L
.96089 .19216 L
.95032 .17321 L
.93556 .15351 L
.91544 .13287 L
.89054 .11283 L
.86338 .09523 L
.80407 .06637 L
.76677 .05279 L
.72999 .04194 L
.68753 .032 L
.64042 .02374 L
.62001 .02097 L
.59825 .01852 L
Mistroke
.57927 .01679 L
.55884 .01534 L
.54724 .01471 L
.53667 .01424 L
.52603 .01389 L
.51596 .01366 L
.50422 .01352 L
.49338 .01351 L
.48771 .01354 L
.48148 .01362 L
.47497 .01375 L
.46888 .0139 L
.45883 .01424 L
.44789 .01472 L
.42803 .01589 L
.40881 .01742 L
.3911 .01916 L
.35159 .0243 L
.31064 .03158 L
.26744 .0417 L
.22973 .05291 L
.19171 .06698 L
.15352 .08468 L
.09889 .11941 L
.07484 .14064 L
.05645 .16164 L
.04213 .18362 L
.03592 .19636 L
.03141 .20829 L
.02846 .21881 L
.02719 .22482 L
.02627 .23048 L
.02559 .23643 L
.02523 .24189 L
.0251 .24789 L
.02515 .2509 L
.02529 .2542 L
.02576 .26002 L
.02645 .26551 L
.02729 .27043 L
.02842 .27574 L
.03181 .2876 L
.03596 .29842 L
.04604 .31779 L
.06015 .33763 L
.07911 .358 L
.09968 .37559 L
.12511 .39331 L
.1564 .41102 L
.18828 .42576 L
Mistroke
.22015 .43797 L
.28859 .45778 L
.33044 .46646 L
.35306 .47023 L
.3773 .47362 L
.39885 .47608 L
.4227 .47823 L
.43325 .479 L
.44456 .47969 L
.45449 .4802 L
.46503 .48063 L
.47617 .48096 L
.48646 .48116 L
.49754 .48126 L
.50385 .48126 L
.50976 .48123 L
.5204 .48108 L
.53013 .48085 L
.54134 .48047 L
.55199 .47999 L
.57147 .47882 L
.58947 .47739 L
.62978 .47294 L
.65237 .46964 L
.67284 .46613 L
.71773 .45653 L
.75544 .44616 L
.79303 .43332 L
.85163 .40666 L
.8806 .38923 L
.90451 .37162 L
.92635 .3516 L
.94564 .32856 L
.95284 .31765 L
.95936 .30584 L
.96401 .29549 L
.96802 .28421 L
.96953 .27889 L
.97086 .27327 L
.97186 .26806 L
.97259 .26319 L
.9731 .25861 L
.97345 .25371 L
.97362 .24827 L
.97355 .24333 L
.97322 .23752 L
.97267 .23217 L
.97179 .22631 L
.97056 .22012 L
.96777 .20978 L
Mistroke
.96368 .1985 L
.95849 .1873 L
.95163 .17527 L
.93599 .15403 L
.917 .1343 L
.89622 .11701 L
.83891 .08201 L
.80137 .06529 L
.76445 .05204 L
.72695 .04114 L
.68536 .03156 L
.6485 .02496 L
.60695 .01943 L
.58312 .01711 L
.56123 .01548 L
.54906 .01479 L
.53579 .01421 L
.52971 .014 L
.52324 .01382 L
.51163 .01359 L
.50102 .0135 L
.4896 .01353 L
.47882 .01367 L
.46896 .0139 L
.45802 .01427 L
.44609 .0148 L
.42217 .01631 L
.39981 .01826 L
.37585 .02094 L
.33322 .02731 L
.29306 .03537 L
.25754 .0444 L
.18342 .07048 L
.15028 .08639 L
.11766 .10583 L
.09135 .12551 L
.07016 .14548 L
.05443 .16432 L
.04103 .18565 L
.03568 .19691 L
.03102 .20951 L
.02919 .21589 L
.02758 .2228 L
.02698 .22599 L
.02643 .22935 L
.02569 .23537 L
.02527 .24095 L
.0251 .24692 L
.02521 .25256 L
.02554 .25768 L
Mistroke
.02619 .26369 L
.0267 .26708 L
.02724 .2702 L
.03004 .28196 L
.03377 .29307 L
.03809 .30313 L
.05089 .32527 L
.06647 .34501 L
.08445 .36292 L
.13499 .39932 L
.16933 .41735 L
.20446 .43224 L
.24158 .44503 L
.28431 .45676 L
.3267 .46578 L
.3671 .47227 L
.40454 .47665 L
.42607 .47849 L
.4463 .47979 L
.45732 .48032 L
.46777 .48072 L
.47717 .48098 L
.48739 .48117 L
.49852 .48126 L
.50413 .48126 L
.51033 .48122 L
.52127 .48106 L
.53153 .48081 L
.54202 .48044 L
.55319 .47993 L
.57325 .47869 L
.59693 .47669 L
.61824 .47439 L
.66377 .46775 L
.70531 .45946 L
.77412 .44012 L
.80972 .42665 L
.84011 .41268 L
.86826 .3971 L
.89525 .37887 L
.91566 .36199 L
.93462 .34255 L
.94439 .33029 L
.95223 .31865 L
.95909 .30638 L
.96417 .29509 L
.96813 .28384 L
.97088 .27318 L
.97199 .26728 L
.97276 .26185 L
Mistroke
.97332 .25589 L
.97349 .25288 L
.9736 .24959 L
.97356 .24349 L
.97325 .23786 L
.97298 .23492 L
.97261 .23169 L
.97159 .22516 L
.9704 .21945 L
.96883 .21333 L
.96519 .20233 L
.96036 .19107 L
.95478 .1805 L
.94176 .16115 L
.92253 .13957 L
.90094 .12064 L
.87359 .10143 L
.83986 .08249 L
.8035 .06614 L
.76719 .05293 L
.73099 .04221 L
.68918 .03234 L
.65013 .02522 L
.61263 .02008 L
.59159 .01786 L
.57224 .01624 L
.56149 .0155 L
.54975 .01483 L
.53859 .01432 L
.52834 .01395 L
.51822 .0137 L
.50756 .01354 L
.49685 .01349 L
.48513 .01357 L
.47497 .01374 L
.46412 .01404 L
.4539 .01443 L
.44462 .01488 L
.42198 .01633 L
.39761 .01848 L
.35408 .02392 L
.30958 .03179 L
.26443 .0425 L
.22788 .05352 L
.19019 .0676 L
.15599 .0834 L
.12658 .10005 L
.08046 .13517 L
.06036 .15666 L
.04561 .17753 L
Mistroke
.03888 .18988 L
.03392 .20124 L
.03164 .2076 L
.02955 .21451 L
.02794 .22109 L
.02679 .2271 L
.02597 .23277 L
.02545 .23814 L
.02515 .24382 L
.0251 .24703 L
.02513 .24999 L
.02533 .25492 L
.02579 .26035 L
.02653 .26601 L
.02746 .27131 L
.03046 .28338 L
.03427 .29434 L
.0396 .30623 L
.04649 .31853 L
.06292 .34095 L
.0821 .3608 L
.10725 .38126 L
.13851 .40136 L
.20515 .4325 L
.24766 .44688 L
.28941 .45797 L
.32767 .46595 L
.37118 .47282 L
.39356 .47552 L
.41784 .47784 L
.42968 .47875 L
.44096 .47948 L
.45201 .48008 L
.46218 .48052 L
.47335 .48089 L
.47922 .48103 L
.48541 .48114 L
.49584 .48125 L
.50728 .48124 L
.51749 .48113 L
.5284 .4809 L
.53869 .48057 L
.54804 .48018 L
.57042 .47889 L
.59455 .47692 L
.61711 .47452 L
.63771 .47184 L
.6737 .46597 L
.71209 .45789 L
.78455 .43646 L
Mistroke
.82065 .42192 L
.85213 .40638 L
.90268 .37309 L
.92551 .35246 L
.94295 .33222 L
.95772 .30904 L
.96391 .29574 L
.96823 .28351 L
.97096 .2728 L
.97208 .26669 L
.97286 .26098 L
.97338 .25493 L
.9736 .24942 L
.97361 .24637 L
.97354 .24306 L
.97318 .23703 L
.97263 .23191 L
.97178 .22626 L
.97061 .22038 L
.96926 .21488 L
.96621 .20512 L
.96204 .1947 L
.94902 .17125 L
.9407 .1598 L
.93029 .14759 L
.88482 .10881 L
.85498 .09045 L
.82356 .07472 L
.7574 .04981 L
.71679 .03858 L
.67753 .03002 L
.63282 .02265 L
.60977 .01975 L
.5841 .01719 L
.5621 .01554 L
.5496 .01482 L
.53797 .01429 L
.52676 .01391 L
.5166 .01367 L
.50487 .01352 L
.49382 .0135 L
.48372 .01359 L
.47306 .01379 L
.46397 .01405 L
.45402 .01443 L
.44332 .01494 L
.43188 .01563 L
.41136 .01718 L
.38781 .01952 L
.36253 .0227 L
Mistroke
.31764 .03018 L
.27562 .03956 L
.23861 .05004 L
.20461 .06185 L
.17052 .07628 L
.11649 .10661 L
.09026 .12643 L
.06711 .14878 L
.05118 .1689 L
.038 .19173 L
.03315 .20329 L
.03105 .20942 L
.02917 .21593 L
.02782 .22166 L
.02665 .22797 L
.02586 .23372 L
.02538 .2391 L
.02513 .24473 L
.02513 .25007 L
.02533 .25486 L
.02576 .26007 L
.02648 .26571 L
.02753 .2717 L
.03017 .28241 L
.03401 .29368 L
.03933 .30569 L
.05204 .32693 L
.07215 .35111 L
.09512 .37199 L
.11923 .38952 L
.14837 .40682 L
.20871 .43384 L
.24987 .44754 L
.29123 .4584 L
.33006 .46639 L
.3509 .4699 L
.37364 .47315 L
.39574 .47575 L
.41616 .4777 L
.43683 .47923 L
.45659 .48029 L
.4677 .48072 L
.47393 .4809 L
.47957 .48104 L
.49058 .48121 L
.50095 .48126 L
.50685 .48125 L
.51308 .48119 L
.52423 .481 L
.53043 .48084 L
Mistroke
.53621 .48066 L
.54934 .48012 L
.56094 .4795 L
.57352 .47867 L
.59624 .47676 L
.63821 .47177 L
.66152 .46813 L
.68581 .46363 L
.72804 .45392 L
.79815 .43133 L
.83367 .41586 L
.86332 .40005 L
.90979 .36718 L
.92874 .34908 L
.94583 .32829 L
.95314 .31716 L
.95983 .30488 L
.96464 .2939 L
.96863 .28214 L
.97123 .27146 L
.97229 .26536 L
.973 .25965 L
.97341 .2544 L
.9736 .24961 L
.97357 .24407 L
.97332 .23882 L
.97305 .23565 L
.97273 .23267 L
.97193 .22712 L
.97078 .22116 L
.96922 .21475 L
.96553 .20325 L
.96118 .1928 L
.9477 .1693 L
.92842 .14558 L
.90715 .12567 L
.8846 .10866 L
.85715 .09166 L
.82392 .07488 L
.7903 .06102 L
.75708 .04971 L
.68654 .0318 L
.6476 .02482 L
.62563 .02168 L
.60447 .01916 L
.5847 .01724 L
.56293 .01559 L
.55331 .01502 L
.54303 .0145 L
.53402 .01414 L
Mistroke
.52448 .01384 L
.51856 .01371 L
.51205 .01359 L
.50061 .01349 L
.49417 .0135 L
.48725 .01354 L
.48073 .01363 L
.47478 .01375 L
.46328 .01407 L
.45679 .01431 L
.45079 .01457 L
.42816 .01588 L
.40825 .01746 L
.38645 .01967 L
.34306 .02564 L
.30217 .03335 L
.26086 .04348 L
.19273 .06655 L
.15862 .08206 L
.12977 .09808 L
.10184 .11711 L
.07604 .13944 L
.05587 .16239 L
.04855 .17283 L
.04162 .18454 L
.0365 .195 L
.03205 .20637 L
.03006 .2127 L
.02853 .21851 L
.02734 .22404 L
.02635 .22994 L
.02566 .2357 L
.02527 .24093 L
.0251 .24619 L
.02516 .25114 L
.02547 .25693 L
.02601 .26224 L
.02686 .26806 L
.02806 .27419 L
.03079 .28446 L
.03412 .29396 L
.04446 .31516 L
.05178 .32656 L
.05954 .33688 L
.08054 .35936 L
.10283 .37799 L
.13009 .39639 L
.1852 .42446 L
.2205 .4381 L
.25585 .44927 L
Mistroke
.29623 .45954 L
.33541 .46734 L
.37761 .47365 L
.40036 .47623 L
.42489 .4784 L
.4461 .47977 L
.45811 .48035 L
.46919 .48076 L
.47892 .48102 L
.48962 .4812 L
.50079 .48126 L
.51124 .48121 L
.52141 .48106 L
.53105 .48082 L
.5397 .48053 L
.5491 .48013 L
.57009 .47891 L
.58941 .47739 L
.62961 .47295 L
.65184 .46972 L
.67195 .46629 L
.74466 .44936 L
.78053 .43789 L
.81723 .42343 L
.85202 .40644 L
.88148 .38864 L
.90628 .37015 L
.92913 .34867 L
.94599 .32807 L
.9581 .30831 L
.96337 .29704 L
.96733 .28637 L
.97058 .27455 L
.97189 .26788 L
.97277 .26176 L
.97309 .25868 L
.97335 .25539 L
.9736 .24948 L
.97361 .24585 L
.97352 .24244 L
.97335 .23938 L
.97309 .23607 L
.97278 .23313 L
.97236 .2299 L
.97125 .2234 L
.96991 .2174 L
.96839 .21182 L
.96427 .19996 L
.95941 .18912 L
.94479 .1652 L
Mistroke
.92786 .14499 L
.90592 .12466 L
.85909 .09276 L
.82788 .0767 L
.79591 .06315 L
.72216 .03991 L
.68211 .03091 L
.63658 .02318 L
.59644 .01833 L
.57365 .01634 L
.56281 .01558 L
.55279 .01499 L
.54348 .01452 L
.53321 .01411 L
.52288 .0138 L
.51193 .01359 L
.5023 .0135 L
.49195 .01351 L
.48219 .01361 L
.47327 .01378 L
.46174 .01412 L
.45092 .01456 L
.43076 .0157 L
.40919 .01737 L
.38608 .01971 L
.3451 .02531 L
.30848 .03202 L
.26969 .04109 L
.22929 .05305 L
.19018 .06761 L
.15618 .0833 L
.12697 .09981 L
.09891 .11938 L
.07871 .13684 L
.05997 .15714 L
.04408 .18013 L
.03737 .19308 L
.03239 .2054 L
.03055 .21104 L
.0289 .217 L
.02771 .22217 L
.02669 .22771 L
.02587 .2337 L
.02537 .23927 L
.02519 .24269 L
.02511 .24591 L
.02518 .25193 L
.0255 .25731 L
.02611 .26308 L
.02694 .26852 L
Mistroke
.0279 .27347 L
.03112 .28551 L
.03527 .29681 L
.04667 .31881 L
.05492 .33092 L
.0637 .34187 L
.1022 .37752 L
.1261 .39393 L
.15567 .41065 L
.18768 .42551 L
.22425 .43939 L
.29578 .45944 L
.33838 .46785 L
.37936 .47387 L
.40335 .47653 L
.42539 .47844 L
.43766 .47928 L
.45102 .48003 L
.46367 .48057 L
.47537 .48094 L
.48652 .48116 L
.49712 .48125 L
.50664 .48125 L
.51702 .48114 L
.52825 .4809 L
.53453 .48071 L
.54021 .48051 L
.55139 .48002 L
.56165 .47945 L
.58147 .47806 L
.60275 .47611 L
.64075 .4714 L
.6811 .46457 L
.72371 .45503 L
.76594 .44284 L
.80284 .42948 L
.80576 .42829 L
Mfstroke
.9233 .35569 m
.94079 .33613 L
.95391 .31716 L
.9599 .3062 L
.96462 .2957 L
.96891 .28346 L
.97038 .27812 L
.97173 .27222 L
.97277 .26645 L
.97349 .26103 L
.974 .25531 L
.97424 .24914 L
.97419 .24343 L
.9739 .238 L
.97343 .23314 L
.97269 .22784 L
.97152 .22153 L
.97017 .21583 L
.96617 .20315 L
.96128 .19154 L
.95565 .18076 L
.94041 .15847 L
.91969 .13607 L
.89843 .11806 L
.87157 .09965 L
.83882 .08157 L
.79977 .06437 L
.7599 .05041 L
.7206 .03945 L
.68057 .03063 L
.63644 .02329 L
.61306 .0203 L
.59086 .01802 L
.56629 .01609 L
.55238 .01526 L
.5396 .01468 L
.52917 .01432 L
.51802 .01406 L
.50749 .01392 L
.49791 .01388 L
.48665 .01396 L
.48029 .01406 L
.47444 .01419 L
.46369 .0145 L
.45233 .01496 L
.42986 .01625 L
.40897 .01791 L
.38625 .02024 L
.36213 .02332 L
.31787 .03074 L
Mistroke
.27834 .0395 L
.23704 .05117 L
.19594 .06589 L
.15992 .08205 L
.12927 .09903 L
.08154 .13485 L
.06317 .15402 L
.04706 .17605 L
.04059 .18748 L
.03493 .19991 L
.03079 .21179 L
.02934 .21707 L
.02806 .2227 L
.02711 .22789 L
.02632 .23363 L
.02584 .23885 L
.02559 .24376 L
.02556 .24952 L
.02577 .25479 L
.02626 .26058 L
.02707 .26665 L
.02797 .27162 L
.02915 .2769 L
.03186 .28637 L
.03604 .29752 L
.04074 .30752 L
.05391 .32883 L
.07204 .35044 L
.0908 .36798 L
.11471 .38612 L
.14402 .40416 L
.17925 .42166 L
.25141 .44792 L
.29292 .4588 L
.33313 .46702 L
.37883 .47396 L
.40239 .47662 L
.42871 .47891 L
.43993 .47966 L
.45178 .48033 L
.46193 .48078 L
.47306 .48116 L
.47935 .48132 L
.48509 .48143 L
.4917 .48152 L
.49796 .48157 L
.50909 .48156 L
.51537 .48149 L
.52116 .4814 L
.53155 .48115 L
Mistroke
.54126 .48083 L
.5519 .48036 L
.56331 .47973 L
.58646 .47804 L
.60746 .47602 L
.64865 .47066 L
.69128 .46297 L
.72996 .45387 L
.76345 .44411 L
.80071 .43079 L
.83784 .41428 L
.86928 .39693 L
.89537 .37923 L
.9186 .35973 L
.93645 .34091 L
.95236 .31905 L
.95929 .30666 L
.96464 .29475 L
.96868 .28308 L
.97028 .27715 L
.97171 .27058 L
.97265 .26498 L
.97338 .25894 L
.97378 .25323 L
.97392 .24799 L
.9739 .245 L
.9738 .24182 L
.9734 .23608 L
.97303 .23258 L
.97258 .22928 L
.9715 .22312 L
.97003 .21662 L
.96836 .21067 L
.96351 .19732 L
.95832 .18633 L
.95269 .17643 L
.93699 .15479 L
.91882 .13566 L
.89851 .11847 L
.8432 .08401 L
.80652 .06726 L
.76954 .05365 L
.73067 .04212 L
.68639 .03183 L
.64282 .0242 L
.62162 .0213 L
.60164 .01902 L
.58181 .01717 L
.56364 .01583 L
.54335 .01473 L
Mistroke
.53216 .0143 L
.52155 .014 L
.51124 .01382 L
.50031 .01374 L
.49097 .01376 L
.48068 .01389 L
.46966 .01414 L
.46347 .01434 L
.45781 .01455 L
.43645 .01562 L
.4251 .01639 L
.41443 .01722 L
.39461 .01909 L
.35087 .02473 L
.31408 .03121 L
.27565 .03989 L
.23521 .05146 L
.19523 .06587 L
.16074 .08133 L
.1321 .09698 L
.08395 .13229 L
.06314 .15367 L
.04745 .17496 L
.04176 .18474 L
.03661 .19529 L
.03293 .2045 L
.02976 .21453 L
.02836 .22015 L
.02731 .22532 L
.02651 .23028 L
.02589 .23551 L
.02546 .24126 L
.02531 .24662 L
.02541 .2525 L
.0256 .25579 L
.02584 .25878 L
.02649 .2643 L
.02732 .26945 L
.02848 .27509 L
.03002 .28114 L
.0341 .29336 L
.03892 .30441 L
.05108 .32522 L
.06605 .34427 L
.08722 .36516 L
.11042 .38336 L
.13934 .40171 L
.17451 .41966 L
.21248 .4352 L
.25007 .4476 L
Mistroke
.28733 .45752 L
.33008 .46647 L
.36987 .47276 L
.40786 .4771 L
.42914 .47886 L
.44864 .48007 L
.45946 .48058 L
.47125 .481 L
.4824 .48127 L
.49272 .48142 L
.50327 .48145 L
.51438 .48138 L
.52386 .48121 L
.5342 .48093 L
.54538 .48051 L
.55727 .47992 L
.57861 .47851 L
.60006 .47661 L
.62011 .4744 L
.65701 .46913 L
.69985 .46093 L
.73772 .45156 L
.77685 .43942 L
.81596 .42422 L
.84875 .40843 L
.87587 .39256 L
.92031 .35785 L
.93968 .33669 L
.94822 .32511 L
.95599 .31253 L
.96163 .30139 L
.96663 .28891 L
.96841 .28341 L
.97004 .27744 L
.97129 .27187 L
.97224 .2666 L
.97302 .26078 L
.97349 .25548 L
.97373 .24978 L
.97376 .24656 L
.9737 .24359 L
.97344 .23863 L
.97293 .23319 L
.97214 .22751 L
.97115 .22221 L
.96801 .2101 L
.96408 .19913 L
.9583 .18663 L
.95158 .17495 L
.93487 .15253 L
Mistroke
.91544 .13274 L
.89002 .11235 L
.85855 .09238 L
.79134 .0614 L
.74856 .04715 L
.70665 .03621 L
.66822 .02835 L
.6246 .02164 L
.60217 .01902 L
.57787 .01679 L
.56602 .01592 L
.55475 .01522 L
.54456 .01471 L
.53356 .01426 L
.52255 .01394 L
.51245 .01374 L
.50279 .01365 L
.49262 .01365 L
.48143 .01377 L
.47103 .01399 L
.45964 .01436 L
.44749 .01489 L
.42302 .01641 L
.4001 .0184 L
.35786 .02354 L
.3191 .03008 L
.2845 .03755 L
.21153 .05943 L
.17913 .07253 L
.14708 .08826 L
.09745 .12069 L
.07297 .14269 L
.05418 .16484 L
.04118 .18558 L
.03549 .19759 L
.03133 .20886 L
.02957 .2148 L
.02804 .22108 L
.02699 .22647 L
.02612 .23238 L
.02575 .23572 L
.0255 .23877 L
.0253 .24229 L
.0252 .24562 L
.02526 .25153 L
.02542 .25487 L
.02565 .25795 L
.02626 .26346 L
.02705 .26862 L
.02817 .27426 L
Mistroke
.02967 .28031 L
.03367 .29254 L
.03842 .30362 L
.04998 .32378 L
.06654 .34498 L
.08581 .36405 L
.1067 .38079 L
.13429 .39886 L
.16791 .41666 L
.2005 .43071 L
.23759 .4438 L
.27313 .454 L
.31406 .46339 L
.35271 .47025 L
.38979 .47519 L
.41248 .47747 L
.43367 .47912 L
.44572 .47986 L
.45707 .48041 L
.46893 .48086 L
.47525 .48104 L
.48206 .48119 L
.49278 .48134 L
.50451 .48137 L
.51043 .48134 L
.51676 .48126 L
.52815 .48102 L
.53952 .48066 L
.55023 .4802 L
.57023 .47902 L
.59004 .47746 L
.61087 .47537 L
.64766 .4705 L
.68623 .46368 L
.72713 .45428 L
.76712 .44258 L
.80278 .42962 L
.8624 .4007 L
.89092 .38216 L
.91398 .36361 L
.93523 .34194 L
.9445 .33025 L
.95294 .31762 L
.95924 .3062 L
.96487 .29349 L
.96879 .28179 L
.97018 .27653 L
.97142 .27079 L
.97205 .26731 L
.97253 .26409 L
Mistroke
.97291 .26107 L
.97324 .25774 L
.97359 .25195 L
.97367 .24581 L
.97357 .24234 L
.9734 .23916 L
.97312 .23567 L
.97271 .232 L
.97177 .22583 L
.97038 .21911 L
.96691 .20694 L
.96269 .19602 L
.94962 .17204 L
.93318 .15071 L
.91402 .13154 L
.86413 .09565 L
.83418 .07969 L
.798 .06396 L
.76472 .05214 L
.72684 .04115 L
.69212 .033 L
.65383 .02587 L
.63026 .02236 L
.60864 .01969 L
.58642 .01746 L
.56584 .01586 L
.55427 .01515 L
.54155 .01452 L
.52874 .01405 L
.52174 .01386 L
.51521 .01373 L
.509 .01364 L
.50312 .01359 L
.49212 .01359 L
.48596 .01365 L
.48028 .01373 L
.47404 .01385 L
.46743 .01403 L
.45637 .01442 L
.44626 .01488 L
.4236 .0163 L
.40274 .01806 L
.38308 .02015 L
.33992 .02626 L
.29437 .03517 L
.25239 .04596 L
.21504 .05807 L
.15214 .08548 L
.12147 .10338 L
.09657 .1213 L
Mistroke
.07317 .1424 L
.05323 .16605 L
.04587 .17719 L
.0399 .18793 L
.03534 .19781 L
.03141 .20843 L
.02975 .21395 L
.02821 .22006 L
.02707 .22571 L
.02625 .23089 L
.02558 .23699 L
.02535 .2402 L
.0252 .24358 L
.02515 .24927 L
.02525 .2525 L
.02541 .2555 L
.02588 .26082 L
.02665 .26658 L
.02764 .272 L
.02876 .27699 L
.03144 .28639 L
.03508 .29626 L
.04524 .31641 L
.06036 .33784 L
.08052 .35929 L
.10349 .37847 L
.15583 .41073 L
.18976 .42639 L
.22383 .43927 L
.26345 .45142 L
.30876 .46229 L
.35497 .47057 L
.37572 .47346 L
.39876 .47612 L
.42078 .47814 L
.44147 .47957 L
.45295 .48018 L
.46343 .48063 L
.46923 .48083 L
.47555 .48101 L
.48703 .48123 L
.49732 .48132 L
.50697 .48131 L
.51756 .4812 L
.52895 .48095 L
.54024 .48058 L
.5521 .48005 L
.5732 .47876 L
.5927 .47716 L
.61069 .47533 L
Mistroke
.65087 .46994 L
.69319 .46218 L
.73709 .45155 L
.77376 .4403 L
.81011 .42655 L
.84046 .41256 L
.87081 .39558 L
.91568 .36201 L
.93643 .34046 L
.95204 .31901 L
.96252 .2991 L
.96694 .28763 L
.97005 .27691 L
.97127 .2714 L
.9723 .26543 L
.97301 .25978 L
.97343 .25459 L
.97363 .24884 L
.97363 .24558 L
.97355 .24254 L
.97315 .23641 L
.97279 .23298 L
.97238 .22987 L
.97129 .22348 L
.96998 .2176 L
.96598 .20439 L
.96125 .19289 L
.95503 .18088 L
.94052 .15953 L
.92381 .14082 L
.90232 .12172 L
.87498 .10231 L
.84647 .08588 L
.81739 .07198 L
.75353 .04864 L
.7139 .0379 L
.66893 .02845 L
.64766 .02487 L
.62485 .02162 L
.6049 .01925 L
.5833 .01716 L
.56211 .01558 L
.54269 .01454 L
.53332 .01416 L
.5231 .01386 L
.51345 .01366 L
.50451 .01356 L
.49417 .01355 L
.48447 .01362 L
.47383 .01382 L
Mistroke
.46238 .01415 L
.45104 .01461 L
.43913 .01523 L
.41794 .01669 L
.39535 .01876 L
.37425 .02118 L
.33546 .02697 L
.29498 .03498 L
.25301 .04574 L
.21822 .05689 L
.18371 .07039 L
.12879 .09871 L
.10244 .11669 L
.08145 .13428 L
.06109 .15579 L
.04583 .1772 L
.04034 .18701 L
.03541 .19759 L
.03191 .20683 L
.02894 .21689 L
.02753 .22312 L
.02652 .22885 L
.02581 .23434 L
.02533 .24013 L
.02513 .24535 L
.02515 .25021 L
.02539 .25553 L
.0259 .26123 L
.02668 .26691 L
.02785 .27315 L
.02941 .27964 L
.03119 .2857 L
.04045 .30786 L
.04754 .32018 L
.05518 .33124 L
.07623 .35521 L
.09838 .37458 L
.1266 .39425 L
.1877 .42553 L
.22527 .43975 L
.26315 .45133 L
.29935 .46026 L
.33914 .46801 L
.36036 .47135 L
.384 .47446 L
.406 .47682 L
.42625 .47853 L
.43776 .47932 L
.45033 .48003 L
.46364 .48061 L
Mistroke
.46965 .48081 L
.47629 .481 L
.48239 .48113 L
.48812 .48122 L
.49417 .48128 L
.50069 .4813 L
.51248 .48124 L
.52328 .48106 L
.53465 .48075 L
.54538 .48033 L
.56539 .47926 L
.58681 .47765 L
.60985 .47539 L
.65067 .46994 L
.68731 .46337 L
.72599 .45448 L
.76648 .4427 L
.80573 .42833 L
.84005 .41274 L
.86923 .39652 L
.89747 .3772 L
.91985 .35808 L
.93697 .33979 L
.95322 .31704 L
.96017 .30418 L
.96542 .29189 L
.96914 .28035 L
.97052 .27483 L
.97158 .26966 L
.97248 .26404 L
.97286 .26106 L
.97317 .25787 L
.97342 .25452 L
.97356 .25135 L
.97361 .2454 L
.97341 .24009 L
.97293 .23437 L
.97223 .22898 L
.97139 .22406 L
.96865 .21268 L
.96461 .20081 L
.95954 .18935 L
.95383 .17886 L
.93742 .15572 L
.91934 .13649 L
.90002 .11993 L
.84748 .08641 L
.8162 .07146 L
.78026 .05739 L
.70966 .03688 L
Mistroke
.6676 .02819 L
.62692 .02187 L
.60311 .01904 L
.58115 .01696 L
.56893 .01602 L
.55558 .01517 L
.54287 .01452 L
.53117 .01407 L
.52109 .01379 L
.51045 .0136 L
.49976 .01352 L
.48805 .01356 L
.47791 .01371 L
.46707 .01398 L
.45685 .01434 L
.44757 .01475 L
.42495 .01613 L
.40057 .01821 L
.37778 .02072 L
.35699 .02351 L
.31616 .0305 L
.27288 .04029 L
.23007 .05282 L
.1926 .06663 L
.15973 .08152 L
.12726 .09964 L
.10189 .11709 L
.07848 .13707 L
.05926 .15804 L
.0454 .1779 L
.03996 .18773 L
.03501 .19851 L
.03124 .20884 L
.02858 .21833 L
.02736 .22397 L
.02644 .22932 L
.02573 .23498 L
.02545 .23818 L
.02526 .24114 L
.02511 .24606 L
.02517 .25149 L
.0255 .25716 L
.02604 .26247 L
.02692 .26839 L
.02816 .27459 L
.03116 .28562 L
.03552 .29738 L
.0416 .31006 L
.05656 .33309 L
.07756 .35651 L
Mistroke
.10185 .37726 L
.12746 .39478 L
.15627 .41096 L
.18988 .42644 L
.25706 .44963 L
.29761 .45986 L
.33718 .46766 L
.38205 .47422 L
.40775 .47697 L
.43146 .47889 L
.44291 .47962 L
.45371 .48018 L
.46355 .48059 L
.47395 .48092 L
.48533 .48116 L
.49579 .48127 L
.50705 .48126 L
.51344 .48121 L
.51939 .48112 L
.53 .48087 L
.54002 .48054 L
.549 .48015 L
.55874 .47964 L
.58049 .47816 L
.60044 .47636 L
.64185 .47126 L
.68622 .46357 L
.73065 .45324 L
.77013 .44148 L
.83818 .41366 L
.8681 .3972 L
.89705 .37751 L
.91853 .35932 L
.93778 .33879 L
.95231 .31853 L
.9623 .29955 L
.96645 .28899 L
.96993 .27729 L
.97125 .27136 L
.97186 .26808 L
.97235 .26498 L
.97307 .25894 L
.97347 .25343 L
.97362 .24826 L
.97353 .24277 L
.97326 .23809 L
.97276 .23292 L
.97198 .2274 L
.97085 .22146 L
.96807 .21076 L
Mistroke
.96399 .19926 L
.95826 .18684 L
.94278 .16249 L
.92393 .14096 L
.90267 .12202 L
.87673 .10344 L
.84473 .08498 L
.81346 .07028 L
.77755 .05643 L
.74303 .04554 L
.70299 .03534 L
.66501 .02773 L
.62837 .02206 L
.60754 .01951 L
.58513 .01729 L
.57213 .01624 L
.56031 .01544 L
.54826 .01476 L
.53714 .01427 L
.52656 .01392 L
.51536 .01366 L
.50412 .01353 L
.49773 .0135 L
.49178 .01352 L
.48098 .01364 L
.47115 .01385 L
.45982 .01421 L
.44911 .01466 L
.42927 .01581 L
.40834 .01746 L
.37121 .02154 L
.33214 .02751 L
.29042 .03599 L
.25161 .04611 L
.21301 .05872 L
.15097 .08602 L
.12087 .10371 L
.09614 .12158 L
.07292 .14258 L
.05294 .16638 L
.04549 .17775 L
.03883 .18999 L
.03412 .20073 L
.03015 .21238 L
.02842 .21897 L
.02716 .22501 L
.02619 .23109 L
.02555 .23687 L
.02531 .24013 L
.02516 .2436 L
Mistroke
.0251 .24687 L
.02512 .24983 L
.02524 .25332 L
.02549 .25709 L
.02582 .26065 L
.02622 .26392 L
.02708 .26934 L
.02827 .27512 L
.03111 .28549 L
.03565 .29771 L
.04086 .30868 L
.05568 .33193 L
.07395 .35295 L
.09416 .37122 L
.12003 .39005 L
.14862 .40696 L
.18277 .42342 L
.2175 .43705 L
.25141 .448 L
.28813 .45768 L
.32281 .46505 L
.36302 .47171 L
.38404 .47445 L
.40705 .47689 L
.42861 .47868 L
.43812 .47932 L
.44858 .47992 L
.45782 .48035 L
.46775 .48073 L
.47826 .48102 L
.48807 .48119 L
.49406 .48125 L
.50043 .48127 L
.51187 .48122 L
.51821 .48113 L
.52417 .48101 L
.5307 .48084 L
.53773 .48061 L
.54965 .48011 L
.56217 .47943 L
.58444 .47783 L
.60586 .47579 L
.6256 .47348 L
.66955 .46674 L
.71102 .45815 L
.75389 .44664 L
.78952 .43464 L
.82465 .42011 L
.85375 .4055 L
.88265 .38785 L
Mistroke
.92471 .35328 L
.94361 .33133 L
.9513 .32014 L
.95743 .30958 L
.9625 .29909 L
.96628 .28948 L
.96957 .27871 L
.97096 .27277 L
.97201 .26716 L
.97279 .26153 L
.97312 .25833 L
.97336 .25534 L
.9736 .24931 L
.97361 .24592 L
.97353 .24284 L
.9732 .23734 L
.97256 .23137 L
.97169 .22574 L
.97065 .22055 L
.96754 .20906 L
.96284 .19651 L
.95652 .1836 L
.94933 .17171 L
.9339 .15161 L
.91302 .13072 L
.88884 .11162 L
.85916 .0928 L
.8279 .07672 L
.79699 .06357 L
.73058 .0421 L
.69159 .03285 L
.64867 .025 L
.61095 .01989 L
.58918 .01765 L
.56867 .01599 L
.55726 .01525 L
.5448 .01459 L
.533 .01411 L
.52205 .01379 L
.51221 .0136 L
.50133 .0135 L
.48997 .01353 L
.47929 .01366 L
.46756 .01394 L
.46167 .01413 L
.45522 .01438 L
.43322 .01555 L
.42086 .01642 L
.4077 .01752 L
.38415 .01994 L
Mistroke
.33861 .02638 L
.29793 .03428 L
.25518 .04507 L
.21256 .05888 L
.14858 .08729 L
.11719 .10614 L
.09151 .12537 L
.07025 .14537 L
.05151 .16842 L
.04455 .17931 L
.03828 .19112 L
.0335 .20234 L
.03004 .21277 L
.02737 .22387 L
.02638 .22973 L
.02598 .23272 L
.02563 .23593 L
.02525 .24134 L
.0251 .24639 L
.0252 .25239 L
.02555 .25785 L
.02611 .26308 L
.02683 .2679 L
.02784 .27319 L
.02917 .27878 L
.03197 .28811 L
.03591 .29832 L
.04754 .32021 L
.06416 .3424 L
.08173 .36046 L
.10435 .37914 L
.13254 .39787 L
.16658 .41605 L
.23682 .44354 L
.27798 .4552 L
.31785 .46409 L
.36332 .47175 L
.38678 .47476 L
.41291 .47742 L
.43605 .47918 L
.44707 .47983 L
.45732 .48033 L
.46911 .48077 L
.47534 .48094 L
.48197 .48109 L
.48831 .48119 L
.49428 .48124 L
.50542 .48126 L
.51603 .48116 L
.5272 .48093 L
Mistroke
.53674 .48064 L
.54717 .48022 L
.57038 .47889 L
.59187 .47717 L
.61468 .47481 L
.63552 .47215 L
.6816 .46447 L
.72072 .45579 L
.76028 .44466 L
.82298 .42087 L
.85477 .40493 L
.88165 .38853 L
.90662 .36987 L
.9297 .34805 L
.94724 .32627 L
.95411 .31552 L
.95965 .30523 L
.9642 .29502 L
.96812 .28385 L
.96952 .27889 L
.97078 .27362 L
.97175 .26868 L
.97246 .26416 L
.97307 .25888 L
.97348 .25321 L
.97361 .24796 L
.97354 .24298 L
.97319 .23719 L
.97262 .23185 L
.97173 .22599 L
.97048 .21979 L
.96748 .20887 L
.96325 .19749 L
.953 .1775 L
.93822 .1567 L
.91775 .13501 L
.89656 .11727 L
.87059 .09957 L
.81599 .07136 L
.77871 .05683 L
.74188 .04521 L
.69914 .03447 L
.65171 .02548 L
.63134 .02245 L
.60916 .01968 L
.58979 .0177 L
.56849 .01597 L
.55551 .01514 L
.54342 .01452 L
.53184 .01407 L
Mistroke
.52537 .01387 L
.51949 .01373 L
.50835 .01355 L
.50208 .0135 L
.49631 .01349 L
.48569 .01356 L
.47449 .01376 L
.46359 .01406 L
.45176 .01453 L
.44061 .0151 L
.43034 .01573 L
.39059 .01921 L
.37026 .02165 L
.34812 .02484 L
.3044 .03288 L
.26782 .04159 L
.23027 .05273 L
.16831 .07733 L
.13756 .09344 L
.11184 .10981 L
.08517 .13086 L
.06491 .15126 L
.04788 .17387 L
.03606 .19601 L
.03136 .20843 L
.02819 .21998 L
.02697 .22605 L
.02598 .23274 L
.02562 .23611 L
.02534 .23973 L
.02517 .24316 L
.0251 .24628 L
.0252 .25231 L
.02556 .25798 L
.02611 .26305 L
.02694 .26853 L
.02813 .2745 L
.0297 .28077 L
.03333 .29192 L
.04242 .31157 L
.05607 .33245 L
.07509 .3541 L
.10005 .37588 L
.156 .41082 L
.1908 .42681 L
.22565 .43987 L
.26569 .452 L
.31236 .46299 L
.35467 .47048 L
.39545 .47572 L
Mistroke
.41829 .47788 L
.43936 .47939 L
.45104 .48003 L
.46382 .48058 L
.46967 .48078 L
.47591 .48095 L
.48716 .48117 L
.49825 .48126 L
.50454 .48126 L
.51042 .48122 L
.51662 .48115 L
.52227 .48104 L
.52879 .48089 L
.53496 .4807 L
.54588 .48028 L
.55595 .47978 L
.57867 .47828 L
.60118 .47627 L
.62577 .47345 L
.67446 .46583 L
.71541 .45709 L
.75747 .44553 L
.79455 .43273 L
.82667 .41918 L
.88376 .3871 L
.90893 .36792 L
.93158 .34599 L
.94125 .33444 L
.95036 .3216 L
.95718 .31005 L
.96313 .29761 L
.96737 .28626 L
.96917 .28019 L
.97077 .27365 L
.97193 .26763 L
.97272 .26211 L
.97327 .25656 L
.97355 .25128 L
.9736 .24547 L
.97351 .2422 L
.97334 .2392 L
.97284 .23367 L
.97205 .22785 L
.97109 .22264 L
.97 .21779 L
.96681 .20684 L
.96222 .1951 L
.95705 .18456 L
.94201 .16148 L
.9255 .14255 L
Mistroke
.90394 .12304 L
.85586 .09094 L
.82536 .07554 L
.79429 .06253 L
.75457 .04894 L
.71592 .03836 L
.67569 .02967 L
.63182 .02251 L
.60849 .0196 L
.58656 .0174 L
.56229 .01555 L
.54864 .01477 L
.53621 .01422 L
.52554 .01387 L
.51555 .01365 L
.50458 .01352 L
.49281 .0135 L
.48691 .01355 L
.48049 .01364 L
.46882 .0139 L
.45747 .01428 L
.44698 .01476 L
.42818 .01588 L
.40753 .01752 L
.36625 .02218 L
.34328 .02561 L
.32253 .02925 L
.27717 .03917 L
.23912 .04988 L
.20139 .06309 L
.13948 .09233 L
.10979 .11126 L
.08628 .12987 L
.06755 .1483 L
.05092 .16928 L
.04463 .17919 L
.0389 .18985 L
.03476 .19911 L
.03108 .20931 L
.02933 .21533 L
.02797 .22093 L
.02684 .22675 L
.02606 .23204 L
.02552 .23726 L
.02521 .24217 L
.0251 .24736 L
.02522 .25297 L
.02562 .25865 L
.02596 .26188 L
.02636 .26488 L
Mistroke
.02738 .27094 L
.02882 .2774 L
.03229 .28903 L
.03644 .29953 L
.04714 .31957 L
.06262 .3406 L
.08077 .35957 L
.10046 .3762 L
.12479 .39311 L
.15423 .40991 L
.21503 .43616 L
.25409 .44877 L
.29769 .45987 L
.3366 .46755 L
.38054 .47402 L
.40263 .47646 L
.42682 .47854 L
.43798 .4793 L
.44983 .47997 L
.46009 .48044 L
.47113 .48082 L
.48185 .48108 L
.49165 .48122 L
.5015 .48126 L
.51084 .48122 L
.52169 .48105 L
.53173 .4808 L
.54273 .48041 L
.55442 .47986 L
.57854 .47829 L
.60436 .47594 L
.62846 .4731 L
.65031 .46996 L
.69084 .46261 L
.73192 .45289 L
.80253 .4296 L
.83803 .41372 L
.86736 .39764 L
.89192 .38133 L
.91527 .36234 L
.9327 .34474 L
.94815 .32495 L
.95514 .31375 L
.96057 .30333 L
.96514 .2926 L
.96851 .28253 L
.97015 .27638 L
.97136 .27078 L
.9724 .26454 L
.97284 .26111 L
Mistroke
.97316 .25788 L
.97353 .25198 L
.97361 .24656 L
.97343 .24061 L
.97322 .23761 L
.97292 .23432 L
.97254 .23119 L
.97204 .22779 L
.97088 .22162 L
.96787 .21011 L
.96297 .19682 L
.95712 .1847 L
.94331 .16319 L
.92429 .14133 L
.9027 .12204 L
.87983 .10546 L
.85216 .08891 L
.81855 .07248 L
.75497 .04906 L
.71722 .03868 L
.68049 .03059 L
.63801 .02338 L
.61349 .02018 L
.59059 .01777 L
.57039 .0161 L
.548 .01474 L
.53669 .01424 L
.53045 .01402 L
.52452 .01385 L
.51301 .01361 L
.50248 .0135 L
.49201 .01351 L
.48254 .0136 L
.4716 .01382 L
.46132 .01414 L
.45179 .01452 L
.44305 .01496 L
.42338 .01622 L
.40359 .01789 L
.38208 .02018 L
.33944 .02624 L
.2959 .03473 L
.25646 .04471 L
.1884 .06835 L
.15434 .08425 L
.12581 .10053 L
.0983 .11985 L
.07319 .14231 L
.05501 .16353 L
.04202 .18379 L
Mistroke
.03299 .20371 L
.02973 .21387 L
.02836 .21923 L
.02714 .22506 L
.02657 .22842 L
.02613 .23152 L
.02549 .23763 L
.02517 .24319 L
.02511 .24907 L
.02519 .25212 L
.02536 .25538 L
.02589 .26128 L
.02636 .26487 L
.02689 .26828 L
.02816 .27464 L
.03126 .28597 L
.03509 .29637 L
.04706 .31945 L
.06154 .33932 L
.081 .35979 L
.12572 .39369 L
.15669 .41117 L
.19291 .42768 L
.2298 .44126 L
.26553 .45196 L
.302 .46081 L
.34315 .46865 L
.36634 .47217 L
.38805 .4749 L
.41036 .47719 L
.43145 .47887 L
.44955 .47996 L
.45975 .48042 L
.4691 .48076 L
.47931 .48103 L
.49046 .48121 L
.501 .48126 L
.51078 .48122 L
.5218 .48105 L
.53218 .48079 L
.54148 .48046 L
.55152 .48001 L
.574 .47863 L
.59455 .47692 L
.63534 .47217 L
.67794 .46517 L
.71675 .45677 L
.75067 .4476 L
.78835 .43507 L
.82635 .41933 L
Mistroke
.85877 .40268 L
.88606 .38551 L
.9102 .36683 L
.92916 .34863 L
.94646 .3274 L
.95433 .31515 L
.96047 .30354 L
.96539 .29193 L
.96888 .28126 L
.97035 .27554 L
.97164 .26932 L
.97221 .26589 L
.97265 .26273 L
.97299 .25973 L
.97327 .2565 L
.97358 .25051 L
.97359 .24491 L
.97347 .24149 L
.97327 .23824 L
.97266 .23217 L
.97224 .22908 L
.9717 .2258 L
.9705 .21991 L
.96674 .20665 L
.96208 .19478 L
.95589 .18244 L
.9416 .16095 L
.9218 .13886 L
.8951 .11617 L
.86806 .09802 L
.8354 .08029 L
.76804 .05321 L
.72748 .04128 L
.68804 .03211 L
.64298 .02412 L
.61968 .02092 L
.59364 .01806 L
.57067 .01612 L
.54948 .01481 L
.53832 .0143 L
.52611 .01389 L
.51994 .01373 L
.51334 .01361 L
.50712 .01353 L
.50147 .0135 L
.49027 .01352 L
.47997 .01364 L
.46867 .0139 L
.46298 .01408 L
.45674 .01431 L
Mistroke
.43504 .01542 L
.41488 .01689 L
.39214 .01904 L
.3713 .02151 L
.3251 .02876 L
.28581 .03706 L
.24588 .0478 L
.18244 .0709 L
.15008 .08648 L
.12254 .10261 L
.09625 .12149 L
.07518 .14029 L
.05692 .161 L
.04839 .17308 L
.04153 .18471 L
.03658 .19482 L
.03221 .20591 L
.02913 .21608 L
.02706 .22553 L
.02622 .23082 L
.02565 .23578 L
.02525 .24123 L
.0251 .24709 L
.02524 .25322 L
.02565 .25903 L
.02627 .26424 L
.02719 .26991 L
.02849 .27606 L
.02996 .28169 L
.03425 .29431 L
.03913 .30529 L
.04538 .31672 L
.05886 .33603 L
.07735 .35631 L
.10121 .37677 L
.13115 .39703 L
.19534 .42866 L
.2334 .44244 L
.2709 .45338 L
.3142 .46336 L
.33707 .46763 L
.36217 .47158 L
.38437 .47448 L
.40495 .47668 L
.42479 .47839 L
.4458 .47976 L
.45703 .48031 L
.46321 .48056 L
.46905 .48076 L
.4804 .48105 L
Mistroke
.49073 .48121 L
.4967 .48125 L
.50302 .48126 L
.51436 .48118 L
.52065 .48107 L
.52654 .48094 L
.533 .48076 L
.53992 .48052 L
.55779 .47968 L
.57672 .47843 L
.61044 .47529 L
.63085 .47279 L
.64981 .47004 L
.68453 .46389 L
.7455 .44911 L
.77773 .43887 L
.80576 .42829 L
Mfstroke
.92367 .35504 m
.94105 .33543 L
.95404 .31644 L
.95997 .30548 L
.96463 .29498 L
.96884 .28275 L
.97028 .27742 L
.9716 .27153 L
.9726 .26577 L
.9733 .26036 L
.97377 .25465 L
.97398 .2485 L
.9739 .2428 L
.97358 .2374 L
.97309 .23255 L
.97233 .22727 L
.97112 .22098 L
.96975 .2153 L
.9657 .20267 L
.96077 .19112 L
.95509 .1804 L
.9398 .15824 L
.91904 .13597 L
.89778 .11808 L
.87093 .0998 L
.83823 .08185 L
.79925 .06476 L
.75948 .0509 L
.72028 .04 L
.68036 .03122 L
.63635 .02389 L
.61304 .02091 L
.5909 .01862 L
.56638 .01668 L
.55251 .01584 L
.53976 .01525 L
.52936 .01488 L
.51823 .0146 L
.50772 .01445 L
.49817 .01441 L
.48693 .01447 L
.48059 .01456 L
.47475 .01467 L
.46403 .01497 L
.45269 .01541 L
.44186 .01595 L
.43026 .01666 L
.40941 .01828 L
.38483 .02077 L
.36263 .02358 L
Mistroke
.32235 .03014 L
.28097 .03905 L
.21163 .05992 L
.17315 .07569 L
.14022 .09247 L
.11387 .1089 L
.08852 .12837 L
.06746 .14883 L
.05148 .1689 L
.03862 .19094 L
.03327 .20358 L
.03134 .20921 L
.02958 .21522 L
.02831 .2204 L
.02717 .22613 L
.02636 .23136 L
.02582 .23626 L
.02542 .24204 L
.02531 .24733 L
.02544 .25313 L
.02589 .25924 L
.02648 .26423 L
.02733 .26955 L
.02946 .27909 L
.03297 .29035 L
.03706 .30047 L
.04894 .32208 L
.06579 .34409 L
.08352 .36202 L
.10637 .38063 L
.13464 .39923 L
.16889 .41735 L
.23962 .4448 L
.28057 .4563 L
.32037 .4651 L
.36574 .47267 L
.38919 .47565 L
.41541 .47827 L
.4266 .47917 L
.43844 .47998 L
.44869 .48057 L
.45969 .48108 L
.46591 .48132 L
.47157 .4815 L
.48265 .48177 L
.48886 .48186 L
.4956 .48192 L
.50197 .48194 L
.50784 .48192 L
.51825 .4818 L
Mistroke
.52799 .48159 L
.53867 .48125 L
.55013 .48076 L
.57339 .47935 L
.59452 .47759 L
.63605 .47272 L
.67913 .46556 L
.71833 .45695 L
.75236 .44762 L
.79036 .43479 L
.82839 .41879 L
.86078 .40189 L
.88783 .38459 L
.91211 .36545 L
.93097 .34692 L
.94806 .32533 L
.95575 .31293 L
.96167 .30126 L
.96629 .28981 L
.96999 .27752 L
.97142 .27112 L
.97244 .2651 L
.9729 .26165 L
.97323 .25848 L
.97349 .255 L
.97367 .25134 L
.97372 .24563 L
.97348 .23954 L
.97298 .2338 L
.97228 .22859 L
.97118 .22248 L
.96964 .21588 L
.96592 .204 L
.96153 .19332 L
.95575 .18202 L
.94258 .16211 L
.92248 .1395 L
.90013 .12005 L
.87313 .10124 L
.83966 .08257 L
.76934 .05393 L
.72867 .04194 L
.68838 .03257 L
.65081 .02576 L
.60909 .02013 L
.58693 .01791 L
.56243 .01605 L
.55 .01533 L
.53667 .01473 L
.53019 .01451 L
Mistroke
.52406 .01433 L
.51257 .0141 L
.50174 .014 L
.49025 .01402 L
.48045 .01414 L
.46966 .01437 L
.45809 .01476 L
.44567 .01532 L
.42331 .01671 L
.40109 .01861 L
.37761 .02118 L
.33615 .02724 L
.28856 .03681 L
.24746 .04769 L
.21071 .05988 L
.17376 .07506 L
.14212 .09108 L
.11549 .10749 L
.0907 .12621 L
.0713 .1444 L
.05354 .16568 L
.04545 .17793 L
.03914 .18949 L
.03422 .20061 L
.03002 .21304 L
.02834 .21953 L
.02709 .22565 L
.02611 .23213 L
.0257 .23577 L
.02543 .23912 L
.02518 .24486 L
.02518 .25021 L
.02546 .25607 L
.02574 .25935 L
.02607 .26233 L
.02696 .26834 L
.02826 .27483 L
.03151 .28656 L
.03551 .29728 L
.04089 .30866 L
.05335 .32874 L
.07264 .35163 L
.09432 .37141 L
.12068 .39058 L
.15355 .40971 L
.22308 .43923 L
.26339 .45165 L
.30345 .46143 L
.34087 .4686 L
.38254 .47461 L
Mistroke
.40467 .47701 L
.42918 .47908 L
.44162 .47989 L
.45497 .48058 L
.46146 .48086 L
.46761 .48108 L
.47914 .48139 L
.49 .48157 L
.50152 .48163 L
.51136 .48158 L
.5222 .48141 L
.53381 .4811 L
.54033 .48087 L
.5463 .48062 L
.5688 .47935 L
.59078 .47761 L
.61057 .47561 L
.65422 .46966 L
.69347 .46235 L
.72915 .45389 L
.80316 .42955 L
.84038 .41271 L
.87129 .39536 L
.89625 .37821 L
.9195 .35848 L
.93645 .34046 L
.95143 .31998 L
.95871 .30718 L
.96418 .29513 L
.96826 .28348 L
.9699 .27747 L
.97134 .27098 L
.97234 .26514 L
.973 .25978 L
.97342 .25464 L
.97362 .24923 L
.97356 .24328 L
.97325 .23775 L
.97262 .23169 L
.97214 .2283 L
.97161 .22522 L
.9692 .21461 L
.96547 .20304 L
.96038 .19109 L
.95453 .18007 L
.94152 .16086 L
.92397 .14105 L
.89902 .11923 L
.87118 .10003 L
.84013 .08277 L
Mistroke
.80916 .06862 L
.73912 .04464 L
.6973 .0343 L
.65619 .02645 L
.61686 .02084 L
.57993 .0171 L
.56039 .0157 L
.54912 .01506 L
.53883 .01459 L
.52793 .01421 L
.51623 .01393 L
.50538 .01379 L
.49509 .01376 L
.48493 .01384 L
.47398 .01403 L
.46365 .01432 L
.4542 .01468 L
.43232 .01585 L
.42137 .01662 L
.40944 .0176 L
.387 .01985 L
.3633 .02282 L
.32153 .02964 L
.28105 .0384 L
.24452 .04838 L
.18159 .07139 L
.15172 .08572 L
.12194 .10308 L
.09631 .12148 L
.07283 .14271 L
.05489 .16371 L
.04208 .18369 L
.03716 .19352 L
.03275 .20437 L
.02949 .21471 L
.02727 .22436 L
.02628 .23035 L
.0259 .23337 L
.02556 .23668 L
.02519 .24255 L
.02509 .24803 L
.02516 .25136 L
.0253 .2545 L
.02579 .26039 L
.02619 .26368 L
.02663 .26672 L
.02792 .27357 L
.03069 .28415 L
.03481 .29571 L
.0403 .30764 L
Mistroke
.04654 .31864 L
.06109 .33882 L
.07752 .35654 L
.12465 .39311 L
.1526 .40918 L
.18549 .42471 L
.25161 .44821 L
.29574 .45961 L
.33935 .46821 L
.37981 .47412 L
.40304 .47669 L
.42463 .47858 L
.43576 .47936 L
.44635 .47999 L
.456 .48046 L
.46627 .48086 L
.47743 .48118 L
.48778 .48137 L
.49891 .48145 L
.50526 .48145 L
.51121 .48141 L
.52113 .48126 L
.53156 .481 L
.54046 .48069 L
.55019 .48026 L
.57184 .47897 L
.59186 .47734 L
.61535 .4749 L
.63729 .47206 L
.6775 .4654 L
.71926 .45628 L
.7623 .44412 L
.82883 .41824 L
.86213 .40079 L
.8899 .38282 L
.91482 .36276 L
.93468 .34247 L
.94397 .33084 L
.9527 .31786 L
.95937 .30577 L
.9644 .29449 L
.96843 .28278 L
.97009 .27659 L
.97149 .27002 L
.97243 .26429 L
.97305 .25894 L
.97347 .25305 L
.97358 .24976 L
.9736 .24675 L
.97344 .24118 L
Mistroke
.97307 .23604 L
.97242 .23041 L
.97143 .22444 L
.96913 .21447 L
.96563 .20355 L
.96044 .19127 L
.95457 .18018 L
.93755 .15594 L
.91834 .13562 L
.8941 .1155 L
.83979 .08255 L
.80448 .06665 L
.76976 .0539 L
.73531 .0435 L
.69612 .03395 L
.65761 .02658 L
.6211 .02125 L
.60025 .01886 L
.58028 .01701 L
.5692 .01616 L
.55708 .01538 L
.54591 .01478 L
.53578 .01435 L
.52531 .01401 L
.51545 .01379 L
.50503 .01366 L
.49378 .01364 L
.4839 .01372 L
.47348 .01391 L
.4646 .01416 L
.45488 .01452 L
.44254 .01512 L
.4309 .01582 L
.40923 .0175 L
.38609 .01983 L
.36127 .02298 L
.3176 .03029 L
.27873 .03887 L
.24252 .0489 L
.20573 .06148 L
.146 .08872 L
.11455 .10794 L
.08858 .12786 L
.06878 .14694 L
.05119 .16886 L
.04409 .18008 L
.03765 .19244 L
.03277 .20428 L
.02932 .21528 L
.02708 .2253 L
Mistroke
.02618 .23101 L
.02558 .23635 L
.0252 .24199 L
.02508 .24714 L
.02521 .25308 L
.0256 .2587 L
.02625 .26428 L
.02726 .27043 L
.02865 .27683 L
.03027 .28281 L
.03388 .29341 L
.03882 .30472 L
.05405 .32979 L
.07271 .35174 L
.09331 .37058 L
.11897 .38942 L
.17382 .41951 L
.21219 .43522 L
.25128 .44805 L
.28813 .45777 L
.3305 .46657 L
.35092 .47001 L
.37319 .47319 L
.39267 .47553 L
.41412 .47763 L
.42673 .47864 L
.43847 .47944 L
.45066 .48012 L
.46174 .48061 L
.47266 .48097 L
.48296 .4812 L
.49384 .48134 L
.50559 .48135 L
.51591 .48125 L
.52552 .48107 L
.53606 .48076 L
.54732 .4803 L
.55912 .47969 L
.57024 .47899 L
.59098 .47733 L
.62785 .47326 L
.66703 .46725 L
.70713 .45911 L
.7432 .44982 L
.7838 .43676 L
.81842 .42293 L
.88004 .38961 L
.90689 .36963 L
.93059 .34707 L
.94764 .32566 L
Mistroke
.95951 .30548 L
.96456 .29407 L
.96677 .288 L
.96877 .28156 L
.97025 .27589 L
.97155 .26965 L
.97247 .26396 L
.97308 .25863 L
.97345 .25333 L
.9736 .24756 L
.97348 .24212 L
.97316 .23708 L
.97269 .23256 L
.97198 .22757 L
.97102 .22238 L
.96991 .21751 L
.96669 .20658 L
.96287 .19664 L
.95122 .17467 L
.93625 .15438 L
.91628 .1337 L
.87068 .09968 L
.83727 .08127 L
.80229 .06572 L
.76864 .05348 L
.72922 .04181 L
.69171 .03295 L
.64978 .02524 L
.62607 .02182 L
.60409 .0192 L
.58151 .01705 L
.56039 .01551 L
.54096 .01449 L
.53007 .01408 L
.52018 .01381 L
.50929 .01363 L
.4975 .01356 L
.48637 .01362 L
.47614 .01379 L
.46653 .01403 L
.45758 .01435 L
.43727 .01535 L
.41759 .01673 L
.39664 .01863 L
.351 .02444 L
.31001 .03175 L
.26681 .04189 L
.22346 .05504 L
.158 .08238 L
.12556 .10069 L
Mistroke
.09875 .1195 L
.0758 .13966 L
.05808 .15949 L
.04351 .18109 L
.03747 .19281 L
.03233 .20551 L
.029 .21651 L
.02757 .22275 L
.02654 .22852 L
.02586 .23358 L
.02536 .23915 L
.0251 .24497 L
.02512 .25041 L
.02536 .25571 L
.02581 .26073 L
.02639 .26523 L
.02721 .27013 L
.02976 .28104 L
.033 .29107 L
.03804 .30309 L
.04375 .31397 L
.06027 .33782 L
.0789 .35784 L
.10245 .37775 L
.1521 .40885 L
.18468 .42429 L
.21758 .43712 L
.25519 .44914 L
.29842 .46009 L
.34114 .46838 L
.36204 .47162 L
.38188 .47424 L
.41935 .47802 L
.43946 .47945 L
.45081 .48007 L
.46122 .48054 L
.47204 .4809 L
.4821 .48114 L
.49315 .48128 L
.50494 .48131 L
.51617 .4812 L
.52675 .48099 L
.53624 .4807 L
.54649 .48029 L
.56751 .47913 L
.58992 .47738 L
.61089 .47528 L
.62983 .47296 L
.67525 .46571 L
.71672 .4568 L
Mistroke
.75751 .44554 L
.79308 .4333 L
.82906 .41806 L
.8642 .39953 L
.89164 .38152 L
.91367 .36377 L
.93277 .34464 L
.9474 .32601 L
.95985 .30478 L
.96485 .29331 L
.96896 .2809 L
.97055 .27461 L
.97189 .26775 L
.97238 .2646 L
.97281 .26126 L
.97334 .25527 L
.97358 .24951 L
.97356 .24413 L
.97325 .23822 L
.97296 .23491 L
.97261 .23188 L
.9717 .22591 L
.97057 .2203 L
.96778 .20987 L
.96375 .19874 L
.95825 .18687 L
.94532 .16596 L
.93014 .14746 L
.91 .12812 L
.88395 .10825 L
.85289 .08934 L
.82002 .07317 L
.78613 .05952 L
.7466 .0466 L
.71185 .03743 L
.67189 .029 L
.62716 .02192 L
.60212 .01895 L
.57837 .01675 L
.56751 .01594 L
.55605 .01521 L
.54612 .01469 L
.5355 .01423 L
.524 .01387 L
.5133 .01365 L
.50675 .01357 L
.50057 .01353 L
.489 .01356 L
.47868 .0137 L
.46761 .01397 L
Mistroke
.45717 .01433 L
.44766 .01475 L
.42449 .01617 L
.40266 .01801 L
.35992 .02309 L
.33624 .0268 L
.31468 .03078 L
.24356 .04852 L
.21018 .05976 L
.17572 .07389 L
.14468 .08941 L
.11527 .10743 L
.09282 .12426 L
.0721 .14341 L
.05378 .16519 L
.04065 .18634 L
.03456 .19958 L
.03211 .20616 L
.03017 .21227 L
.0287 .21772 L
.02738 .22375 L
.02635 .22983 L
.02591 .23317 L
.02559 .23629 L
.0252 .24209 L
.0251 .24533 L
.02509 .24826 L
.02526 .25399 L
.02567 .25937 L
.02601 .26243 L
.02646 .26566 L
.02747 .27143 L
.02886 .27762 L
.03075 .28439 L
.03476 .29561 L
.04022 .30749 L
.05307 .32841 L
.07048 .34939 L
.09055 .36826 L
.13688 .40045 L
.16503 .41533 L
.19898 .43014 L
.23465 .44287 L
.27559 .45463 L
.3157 .4637 L
.35384 .47038 L
.39127 .4753 L
.41036 .47722 L
.43141 .4789 L
.44232 .47959 L
Mistroke
.4539 .4802 L
.45996 .48046 L
.46663 .48071 L
.47839 .48104 L
.48949 .48122 L
.49572 .48127 L
.50141 .48129 L
.51246 .48122 L
.52295 .48105 L
.53296 .48079 L
.5436 .4804 L
.56268 .47941 L
.58525 .47777 L
.60552 .47584 L
.65025 .46999 L
.69701 .46131 L
.73923 .4509 L
.77598 .43948 L
.80945 .42676 L
.84257 .41143 L
.8942 .37963 L
.92001 .35789 L
.94003 .33598 L
.95417 .3154 L
.96049 .30347 L
.96524 .2923 L
.96889 .28118 L
.97132 .27092 L
.97225 .26551 L
.97299 .2596 L
.97325 .25661 L
.97345 .25342 L
.9736 .24767 L
.97349 .24222 L
.9731 .23632 L
.97247 .23076 L
.97166 .22565 L
.96954 .21599 L
.96646 .20586 L
.96205 .19475 L
.95618 .183 L
.94263 .16231 L
.92175 .13883 L
.8984 .1187 L
.87321 .10122 L
.84305 .08413 L
.78114 .05771 L
.74312 .04558 L
.70541 .0359 L
.6622 .02724 L
Mistroke
.63904 .02356 L
.61389 .02024 L
.59129 .01785 L
.57055 .01613 L
.5605 .01546 L
.54957 .01484 L
.53929 .01436 L
.52966 .01401 L
.51844 .01372 L
.51249 .01362 L
.50609 .01354 L
.49939 .01351 L
.49303 .01352 L
.48732 .01356 L
.4811 .01364 L
.46985 .01389 L
.46357 .01408 L
.45788 .01428 L
.43642 .01535 L
.42472 .01613 L
.41242 .01711 L
.39053 .01923 L
.34203 .02582 L
.30146 .03351 L
.25881 .04405 L
.21927 .05647 L
.18432 .07008 L
.12647 .10011 L
.09906 .11925 L
.07723 .13825 L
.05742 .16034 L
.04895 .1722 L
.04139 .18495 L
.03628 .19547 L
.03179 .20712 L
.03017 .21228 L
.02869 .21781 L
.02753 .22301 L
.02666 .22781 L
.02583 .23388 L
.02552 .23709 L
.02528 .24047 L
.02509 .24617 L
.0251 .24941 L
.02519 .25244 L
.02556 .25807 L
.02612 .26321 L
.02703 .26913 L
.02817 .27473 L
.0309 .28484 L
Mistroke
.03472 .29551 L
.04398 .31436 L
.05887 .33606 L
.07584 .35485 L
.09776 .37411 L
.12464 .39303 L
.18144 .42285 L
.21735 .43701 L
.25317 .44852 L
.2947 .45921 L
.34127 .46836 L
.36318 .47174 L
.38675 .47477 L
.40736 .47693 L
.42972 .47877 L
.44231 .47958 L
.45386 .48018 L
.4655 .48065 L
.47659 .48098 L
.48281 .48111 L
.48944 .48121 L
.49571 .48126 L
.50139 .48127 L
.50809 .48125 L
.51533 .48117 L
.52217 .48106 L
.52846 .4809 L
.53884 .48057 L
.54995 .4801 L
.56993 .47893 L
.59353 .47702 L
.61486 .47479 L
.66037 .46833 L
.70209 .46019 L
.73858 .45108 L
.77684 .43918 L
.81174 .4258 L
.84635 .40947 L
.87544 .3926 L
.8992 .37583 L
.92049 .35743 L
.93692 .33982 L
.9518 .31932 L
.95797 .30853 L
.96353 .29665 L
.9676 .28551 L
.96906 .28059 L
.97043 .27515 L
.97143 .27036 L
.9723 .2652 L
Mistroke
.97298 .25973 L
.97339 .25461 L
.97354 .25151 L
.9736 .24821 L
.9735 .24227 L
.97329 .23863 L
.973 .23522 L
.97265 .23215 L
.97219 .22884 L
.97109 .22266 L
.96959 .21617 L
.96602 .20462 L
.96153 .19358 L
.95641 .18341 L
.94155 .16089 L
.92296 .14001 L
.89835 .11864 L
.87308 .10113 L
.8429 .08404 L
.81304 .07011 L
.77744 .0564 L
.70889 .0367 L
.66842 .02833 L
.64575 .02455 L
.62435 .02153 L
.5858 .01735 L
.56518 .01575 L
.55443 .01509 L
.54303 .01451 L
.53707 .01426 L
.53051 .01403 L
.51895 .01372 L
.51244 .01361 L
.50545 .01353 L
.49885 .0135 L
.49282 .01351 L
.48118 .01363 L
.4746 .01376 L
.46851 .01391 L
.45735 .01429 L
.44551 .01483 L
.42398 .01618 L
.40388 .01787 L
.35871 .02324 L
.3192 .02988 L
.27749 .03909 L
.23607 .05084 L
.19985 .06369 L
.14169 .09107 L
.11348 .10866 L
Mistroke
.09085 .12592 L
.07021 .14541 L
.05237 .16718 L
.04057 .18651 L
.03532 .19773 L
.03138 .20836 L
.02961 .21426 L
.02802 .22071 L
.02682 .22683 L
.026 .23253 L
.02544 .23817 L
.02516 .24329 L
.0251 .24921 L
.02532 .25478 L
.02584 .26087 L
.02622 .26393 L
.02672 .26728 L
.02915 .27873 L
.03099 .28514 L
.03335 .29197 L
.03858 .30417 L
.05241 .32747 L
.06931 .34813 L
.09218 .3696 L
.12113 .39078 L
.17938 .42193 L
.21727 .43697 L
.25549 .44918 L
.29579 .45945 L
.33491 .46726 L
.37705 .47359 L
.39978 .47618 L
.4243 .47836 L
.44548 .47975 L
.45748 .48033 L
.46856 .48075 L
.47827 .48101 L
.48896 .4812 L
.50014 .48127 L
.51058 .48122 L
.52075 .48108 L
.53039 .48084 L
.53904 .48056 L
.54844 .48016 L
.56943 .47896 L
.58878 .47745 L
.612 .47511 L
.6331 .47249 L
.67964 .46485 L
.71916 .45617 L
Mistroke
.75891 .44508 L
.8221 .42127 L
.85405 .40532 L
.88094 .389 L
.90632 .37011 L
.92964 .34811 L
.94732 .32615 L
.95421 .31535 L
.95973 .30506 L
.96423 .29493 L
.96758 .28557 L
.97045 .27509 L
.97164 .26928 L
.97251 .26375 L
.97311 .25842 L
.97349 .25274 L
.97361 .24737 L
.97351 .2425 L
.97315 .23677 L
.97282 .23354 L
.97245 .23057 L
.97157 .22512 L
.97038 .21938 L
.96709 .20772 L
.96294 .19677 L
.95247 .17664 L
.93738 .1557 L
.91664 .13399 L
.89508 .11617 L
.86884 .0985 L
.8139 .07047 L
.77966 .05717 L
.7462 .04645 L
.70829 .03655 L
.6649 .0277 L
.62569 .02169 L
.58836 .01757 L
.56746 .0159 L
.54833 .01476 L
.53771 .01428 L
.52617 .01389 L
.51525 .01365 L
.50517 .01352 L
.49401 .0135 L
.4834 .01359 L
.47389 .01377 L
.46353 .01406 L
.45231 .0145 L
.44039 .01511 L
.41905 .01655 L
Mistroke
.39754 .01848 L
.37748 .02073 L
.34062 .02604 L
.29774 .03432 L
.25993 .04373 L
.22086 .05592 L
.18191 .07113 L
.1491 .08701 L
.12203 .10294 L
.07778 .13773 L
.05852 .15895 L
.05005 .17055 L
.04238 .18313 L
.03682 .19429 L
.03191 .20676 L
.03018 .21226 L
.02859 .21822 L
.02738 .22378 L
.02647 .22904 L
.02573 .23488 L
.0253 .2402 L
.0251 .24593 L
.02511 .24916 L
.02519 .25213 L
.02548 .2571 L
.02604 .26256 L
.02688 .26824 L
.02791 .27354 L
.03117 .28568 L
.0352 .29665 L
.0411 .30915 L
.04792 .32081 L
.06489 .34324 L
.08452 .363 L
.11016 .38334 L
.14179 .40322 L
.20958 .43417 L
.25265 .44835 L
.29474 .45921 L
.3334 .46699 L
.37716 .4736 L
.39968 .47616 L
.42401 .47833 L
.4359 .47917 L
.44717 .47984 L
.45822 .48036 L
.46834 .48074 L
.47857 .48102 L
.48959 .4812 L
.4998 .48126 L
Mistroke
.50951 .48123 L
.52076 .48107 L
.53119 .48082 L
.54262 .48041 L
.55478 .47984 L
.57934 .47823 L
.60229 .47616 L
.64452 .47085 L
.68331 .46413 L
.71784 .4565 L
.79049 .43427 L
.82284 .42093 L
.85471 .40496 L
.90384 .37215 L
.92795 .34991 L
.94632 .32759 L
.9589 .30673 L
.96433 .29467 L
.96826 .28339 L
.96976 .27797 L
.97107 .27224 L
.97198 .26728 L
.97274 .26197 L
.97329 .25623 L
.97356 .25088 L
.97361 .24761 L
.97358 .24452 L
.97331 .23875 L
.97284 .23366 L
.97211 .22828 L
.9713 .2237 L
.97021 .21867 L
.96703 .20753 L
.96313 .1972 L
.95089 .17411 L
.93577 .15377 L
.91385 .13146 L
.88886 .11164 L
.8329 .07908 L
.79676 .06348 L
.76144 .05108 L
.72639 .041 L
.68671 .03184 L
.64781 .02486 L
.6111 .0199 L
.58956 .01768 L
.56979 .01606 L
.55879 .01533 L
.54681 .01468 L
.53547 .0142 L
Mistroke
.52497 .01386 L
.5153 .01364 L
.50623 .01353 L
.49627 .01349 L
.48555 .01356 L
.47491 .01374 L
.46374 .01406 L
.45421 .01442 L
.44382 .01492 L
.41977 .01649 L
.39811 .01842 L
.37337 .02125 L
.35035 .02449 L
.31028 .03165 L
.26856 .04139 L
.19791 .06446 L
.16188 .08043 L
.13136 .0971 L
.1033 .11601 L
.08031 .13531 L
.05848 .159 L
.05002 .1706 L
.04317 .18171 L
.03767 .19242 L
.03349 .20236 L
.02983 .21351 L
.02832 .2194 L
.02704 .22563 L
.02615 .23131 L
.0255 .23739 L
.02517 .24314 L
.0251 .24836 L
.0253 .25451 L
.02556 .25797 L
.02588 .26116 L
.02668 .26702 L
.02784 .2732 L
.03041 .28324 L
.0341 .29393 L
.04318 .31294 L
.05792 .33484 L
.07501 .35402 L
.09617 .37283 L
.12236 .39156 L
.17805 .42134 L
.21695 .43685 L
.2564 .44943 L
.29353 .45893 L
.33604 .46745 L
.35671 .47078 L
Mistroke
.37917 .47385 L
.39881 .47607 L
.42036 .47805 L
.43308 .47898 L
.44488 .47971 L
.45597 .48026 L
.46187 .48051 L
.46823 .48073 L
.47921 .48103 L
.48952 .4812 L
.50132 .48126 L
.51214 .4812 L
.52176 .48105 L
.53202 .48079 L
.5417 .48045 L
.55047 .48006 L
.5719 .47878 L
.59201 .47715 L
.63154 .47269 L
.67333 .46604 L
.71344 .45756 L
.74936 .44799 L
.7897 .43456 L
.82393 .42044 L
.88463 .3865 L
.91209 .36518 L
.93378 .34351 L
.95024 .32179 L
.96146 .30142 L
.96613 .28989 L
.96814 .28378 L
.96992 .2773 L
.9712 .2716 L
.97229 .26533 L
.973 .25963 L
.97342 .2543 L
.9736 .24896 L
.97354 .24317 L
.97323 .2377 L
.97272 .23266 L
.97209 .22813 L
.9712 .22314 L
.96876 .2131 L
.96518 .2023 L
.96023 .1908 L
.9485 .17047 L
.93088 .14824 L
.91064 .12864 L
.88438 .10851 L
.85203 .08884 L
Mistroke
.81743 .07199 L
.78181 .05792 L
.70861 .03662 L
.67046 .02869 L
.62713 .02188 L
.60485 .0192 L
.58068 .0169 L
.5689 .01599 L
.55768 .01527 L
.54767 .01472 L
.53658 .01424 L
.52635 .0139 L
.51673 .01367 L
.50657 .01353 L
.4956 .01349 L
.48596 .01356 L
.47581 .01372 L
.46715 .01395 L
.45768 .01427 L
.44646 .01478 L
.43628 .01535 L
.41354 .017 L
.39264 .01899 L
.37309 .02128 L
.33366 .02723 L
.29167 .03569 L
.24979 .04663 L
.21279 .05879 L
.15304 .08492 L
.12367 .10189 L
.09976 .11871 L
.078 .13752 L
.0587 .15873 L
.04436 .17965 L
.03473 .1992 L
.03043 .21143 L
.02759 .22277 L
.02652 .22873 L
.02605 .23216 L
.0257 .23529 L
.02541 .2386 L
.02521 .24214 L
.02511 .24543 L
.0251 .24854 L
.02529 .25418 L
.02577 .26017 L
.02641 .26528 L
.02737 .27089 L
.02869 .27689 L
.03044 .28333 L
Mistroke
.03448 .29488 L
.03934 .30571 L
.04561 .31709 L
.05968 .33705 L
.08088 .35967 L
.10412 .37896 L
.13221 .39767 L
.16664 .41607 L
.20234 .43143 L
.23834 .44402 L
.27662 .45486 L
.31321 .46316 L
.35536 .47058 L
.37941 .47388 L
.40198 .47639 L
.42399 .47833 L
.44758 .47985 L
.45984 .48043 L
.47139 .48083 L
.478 .481 L
.48407 .48112 L
.49074 .48121 L
.49777 .48126 L
.5087 .48123 L
.52038 .48108 L
.5314 .48081 L
.54141 .48046 L
.55315 .47993 L
.56585 .47919 L
.58881 .47744 L
.60935 .47541 L
.63123 .47274 L
.67002 .46664 L
.71455 .4573 L
.75341 .44678 L
.79142 .43392 L
.8298 .41771 L
.88984 .38283 L
.91528 .36233 L
.9353 .34175 L
.94985 .3224 L
.96177 .30073 L
.96638 .28921 L
.97014 .27643 L
.97152 .26995 L
.97213 .26638 L
.97261 .26299 L
.97298 .25983 L
.97328 .2564 L
.97358 .25039 L
Mistroke
.97359 .24479 L
.97348 .24161 L
.9733 .23862 L
.97272 .23261 L
.97226 .22924 L
.97176 .22615 L
.96937 .2153 L
.96779 .20987 L
.9658 .20397 L
.96103 .19249 L
.95463 .18023 L
.93976 .1586 L
.92141 .13848 L
.90127 .12091 L
.84496 .08509 L
.81162 .06949 L
.77162 .0544 L
.73198 .04247 L
.69233 .033 L
.65534 .02606 L
.61385 .02022 L
.58981 .0177 L
.56783 .01592 L
.55557 .01514 L
.54229 .01447 L
.53617 .01422 L
.52972 .014 L
.51815 .0137 L
.50745 .01354 L
.49599 .01349 L
.48518 .01357 L
.47534 .01373 L
.46379 .01405 L
.45728 .01429 L
.45128 .01455 L
.42862 .01584 L
.40724 .01755 L
.38782 .01952 L
.3448 .02536 L
.30794 .03213 L
.27057 .04086 L
.19714 .06477 L
.15997 .08138 L
.1288 .09867 L
.10179 .11716 L
.07675 .13874 L
.05738 .1604 L
.04344 .18125 L
.03415 .20066 L
.0303 .21186 L
Mistroke
.02766 .2224 L
.02662 .22813 L
.02588 .23358 L
.02542 .23848 L
.02515 .24381 L
.02512 .24961 L
.02521 .25253 L
.02538 .25576 L
.02591 .26146 L
.02665 .2668 L
.02764 .27222 L
.02897 .278 L
.03206 .28836 L
.03689 .30054 L
.04236 .31147 L
.05774 .33462 L
.0765 .35549 L
.11899 .38937 L
.14779 .40651 L
.17715 .42093 L
.20926 .43405 L
.24622 .44645 L
.27995 .45569 L
.31836 .46419 L
.34233 .46852 L
.36497 .47198 L
.38876 .47499 L
.41056 .47721 L
.43221 .47892 L
.45272 .48011 L
.46404 .48059 L
.47447 .48091 L
.48593 .48115 L
.4917 .48122 L
.49804 .48126 L
.50879 .48123 L
.51872 .48111 L
.52962 .48086 L
.54117 .48047 L
.55115 .48003 L
.5605 .47952 L
.58172 .47804 L
.60062 .47633 L
.61781 .47444 L
.65593 .46906 L
.69333 .46209 L
.73268 .45269 L
.80576 .42829 L
Mfstroke
.92333 .35406 m
.94055 .33455 L
.9534 .31567 L
.95926 .30478 L
.96386 .29435 L
.96802 .28221 L
.96944 .27693 L
.97073 .27109 L
.97171 .26537 L
.97239 .26001 L
.97285 .25434 L
.97305 .24824 L
.97296 .24259 L
.97262 .23723 L
.97212 .23242 L
.97136 .22718 L
.97015 .22095 L
.96878 .21532 L
.96474 .2028 L
.95982 .19134 L
.95417 .18071 L
.93896 .15872 L
.91832 .13661 L
.89718 .11883 L
.87048 .10064 L
.83797 .08274 L
.79919 .06568 L
.7596 .05179 L
.72057 .04083 L
.68081 .03197 L
.63693 .02452 L
.61368 .02147 L
.59159 .01911 L
.56712 .01708 L
.55328 .0162 L
.54054 .01556 L
.53016 .01516 L
.51904 .01484 L
.50854 .01465 L
.499 .01457 L
.48776 .01459 L
.48143 .01466 L
.47559 .01475 L
.46487 .01502 L
.45353 .01542 L
.4427 .01592 L
.4311 .01658 L
.41023 .01813 L
.38563 .02053 L
.36341 .02327 L
Mistroke
.32306 .0297 L
.28158 .03848 L
.21202 .0592 L
.17337 .07492 L
.14029 .09168 L
.1138 .10813 L
.08829 .12764 L
.0671 .14817 L
.05101 .16834 L
.03806 .19049 L
.03266 .20319 L
.03071 .20886 L
.02894 .21491 L
.02765 .22012 L
.0265 .22588 L
.02569 .23114 L
.02513 .23607 L
.02473 .24188 L
.02461 .2472 L
.02474 .25305 L
.02518 .25919 L
.02577 .26421 L
.02662 .26956 L
.02875 .27916 L
.03227 .29049 L
.03638 .30067 L
.04831 .32241 L
.06523 .34453 L
.08304 .36254 L
.106 .38122 L
.13439 .39987 L
.16878 .41802 L
.23977 .44544 L
.28084 .45689 L
.32075 .46562 L
.36621 .47308 L
.3897 .47601 L
.41596 .47857 L
.42716 .47944 L
.43901 .48022 L
.44928 .48078 L
.46028 .48127 L
.46651 .48149 L
.47217 .48166 L
.48326 .48189 L
.48947 .48197 L
.49621 .48202 L
.50258 .48201 L
.50845 .48198 L
.51887 .48183 L
Mistroke
.52861 .48159 L
.53929 .48123 L
.55074 .48071 L
.574 .47924 L
.59512 .47742 L
.6366 .47245 L
.67962 .46519 L
.71875 .45651 L
.7527 .44712 L
.7906 .43425 L
.82851 .41822 L
.86079 .40132 L
.88773 .38403 L
.91191 .36493 L
.93068 .34646 L
.94769 .32494 L
.95534 .31259 L
.96123 .30097 L
.96583 .28956 L
.96951 .27733 L
.97092 .27096 L
.97194 .26496 L
.97239 .26153 L
.97272 .25838 L
.97298 .25491 L
.97315 .25127 L
.9732 .24559 L
.97296 .23952 L
.97245 .2338 L
.97176 .22862 L
.97066 .22254 L
.96912 .21597 L
.96542 .20414 L
.96104 .19351 L
.95528 .18225 L
.94215 .16242 L
.92213 .13988 L
.89986 .12049 L
.87294 .10172 L
.83958 .08306 L
.76945 .0544 L
.72887 .04237 L
.68866 .03294 L
.65115 .02607 L
.60948 .02037 L
.58734 .01811 L
.56286 .0162 L
.55044 .01546 L
.53711 .01483 L
.53064 .01459 L
Mistroke
.52451 .01441 L
.51302 .01415 L
.50219 .01403 L
.49071 .01403 L
.4809 .01413 L
.47011 .01434 L
.45854 .0147 L
.44612 .01524 L
.42375 .01659 L
.40151 .01845 L
.37802 .02098 L
.33651 .02697 L
.28886 .03648 L
.24768 .04731 L
.21086 .05947 L
.17382 .07464 L
.1421 .09066 L
.11539 .10709 L
.09054 .12585 L
.07108 .14408 L
.05326 .16541 L
.04514 .1777 L
.03881 .18929 L
.03388 .20045 L
.02965 .21292 L
.02797 .21943 L
.02672 .22557 L
.02573 .23207 L
.02532 .23573 L
.02505 .23909 L
.02479 .24485 L
.0248 .25021 L
.02508 .25609 L
.02536 .25938 L
.02569 .26236 L
.02658 .26839 L
.02788 .27491 L
.03114 .28668 L
.03516 .29743 L
.04055 .30884 L
.05305 .32898 L
.0724 .35192 L
.09413 .37173 L
.12056 .39093 L
.15351 .41007 L
.22318 .43956 L
.26355 .45195 L
.30367 .46169 L
.34113 .46882 L
.38283 .47477 L
Mistroke
.40498 .47714 L
.4295 .47917 L
.44194 .47996 L
.4553 .48064 L
.46179 .48091 L
.46794 .48112 L
.47947 .48142 L
.49033 .48158 L
.50185 .48162 L
.51169 .48156 L
.52253 .48137 L
.53414 .48105 L
.54066 .48081 L
.54662 .48055 L
.56911 .47925 L
.59109 .47748 L
.61087 .47546 L
.65448 .46946 L
.69369 .46211 L
.72932 .45362 L
.80322 .42924 L
.84038 .4124 L
.87123 .39506 L
.89614 .37794 L
.91933 .35824 L
.93625 .34025 L
.9512 .31982 L
.95846 .30704 L
.96392 .29502 L
.96799 .2834 L
.96963 .27741 L
.97107 .27093 L
.97206 .26511 L
.97272 .25976 L
.97314 .25464 L
.97334 .24924 L
.97329 .2433 L
.97297 .23778 L
.97235 .23173 L
.97186 .22835 L
.97134 .22528 L
.96893 .2147 L
.96521 .20315 L
.96014 .19123 L
.95431 .18023 L
.94132 .16106 L
.92381 .14127 L
.89892 .11948 L
.87112 .1003 L
.84013 .08303 L
Mistroke
.8092 .06888 L
.73925 .04485 L
.69747 .03448 L
.65639 .0266 L
.61708 .02094 L
.58016 .01717 L
.56063 .01574 L
.54936 .0151 L
.53907 .01461 L
.52817 .01422 L
.51647 .01393 L
.50562 .01377 L
.49534 .01374 L
.48517 .0138 L
.47422 .01398 L
.46389 .01426 L
.45444 .01461 L
.44397 .0151 L
.43255 .01577 L
.40965 .01749 L
.3872 .01972 L
.3635 .02267 L
.32169 .02947 L
.28118 .0382 L
.24461 .04816 L
.1816 .07116 L
.15169 .0855 L
.12187 .10287 L
.09621 .1213 L
.07268 .14255 L
.05473 .16359 L
.04189 .18361 L
.03697 .19345 L
.03255 .20431 L
.02929 .21467 L
.02707 .22434 L
.02608 .23034 L
.02569 .23337 L
.02536 .23669 L
.02498 .24257 L
.02489 .24806 L
.02495 .25139 L
.0251 .25454 L
.02559 .26044 L
.02599 .26373 L
.02643 .26677 L
.02772 .27364 L
.0305 .28424 L
.03463 .29582 L
.04014 .30776 L
Mistroke
.04638 .31877 L
.06096 .33898 L
.07742 .35671 L
.12461 .39331 L
.1526 .40937 L
.18553 .4249 L
.25171 .44836 L
.29587 .45973 L
.3395 .4683 L
.37998 .47419 L
.40321 .47674 L
.4248 .47861 L
.43594 .47938 L
.44653 .48 L
.45618 .48047 L
.46645 .48086 L
.47761 .48117 L
.48795 .48135 L
.49909 .48143 L
.50543 .48142 L
.51139 .48137 L
.5213 .48121 L
.53173 .48094 L
.54063 .48063 L
.55035 .4802 L
.572 .47889 L
.59202 .47725 L
.6155 .47479 L
.63742 .47194 L
.67761 .46527 L
.71934 .45612 L
.76235 .44396 L
.82882 .41807 L
.86209 .40064 L
.88983 .38268 L
.91472 .36264 L
.93456 .34237 L
.94384 .33076 L
.95256 .3178 L
.95923 .30572 L
.96425 .29445 L
.96828 .28277 L
.96994 .27658 L
.97134 .27002 L
.97228 .2643 L
.9729 .25895 L
.97332 .25308 L
.97343 .24978 L
.97345 .24678 L
.9733 .24122 L
Mistroke
.97293 .23608 L
.97227 .23046 L
.97129 .22449 L
.96899 .21453 L
.9655 .20363 L
.96032 .19136 L
.95446 .18029 L
.93747 .15606 L
.91828 .13575 L
.89407 .11564 L
.83981 .08269 L
.80452 .06677 L
.76983 .05401 L
.7354 .0436 L
.69622 .03403 L
.65773 .02664 L
.62123 .02128 L
.60037 .01889 L
.58041 .01703 L
.56933 .01617 L
.55721 .01538 L
.54604 .01478 L
.53591 .01434 L
.52544 .01399 L
.51558 .01377 L
.50516 .01363 L
.49391 .01361 L
.48402 .01368 L
.4736 .01387 L
.46472 .01411 L
.455 .01447 L
.44265 .01506 L
.43102 .01576 L
.40933 .01742 L
.38619 .01975 L
.36136 .02289 L
.31767 .03018 L
.27878 .03875 L
.24255 .04878 L
.20574 .06136 L
.14597 .0886 L
.11449 .10784 L
.0885 .12778 L
.06869 .14687 L
.05109 .16881 L
.04398 .18005 L
.03754 .19242 L
.03266 .20426 L
.02921 .21528 L
.02697 .22531 L
Mistroke
.02607 .23102 L
.02547 .23637 L
.02509 .24202 L
.02497 .24717 L
.02511 .25311 L
.0255 .25874 L
.02615 .26433 L
.02717 .27048 L
.02856 .27688 L
.03017 .28287 L
.03379 .29348 L
.03874 .30479 L
.05399 .32987 L
.07266 .35184 L
.09328 .37068 L
.11896 .38952 L
.17384 .4196 L
.21223 .4353 L
.25135 .44812 L
.28821 .45783 L
.33059 .46662 L
.35101 .47004 L
.37328 .47322 L
.39276 .47554 L
.41421 .47764 L
.42683 .47864 L
.43856 .47943 L
.45076 .48011 L
.46183 .48059 L
.47276 .48095 L
.48305 .48118 L
.49393 .48131 L
.50568 .48132 L
.516 .48122 L
.52561 .48103 L
.53615 .48072 L
.54741 .48026 L
.5592 .47964 L
.57032 .47894 L
.59105 .47728 L
.62792 .47319 L
.66708 .46717 L
.70716 .45902 L
.74322 .44974 L
.7838 .43667 L
.81841 .42285 L
.88 .38953 L
.90683 .36958 L
.93052 .34702 L
.94757 .32563 L
Mistroke
.95943 .30547 L
.96447 .29406 L
.96669 .288 L
.96869 .28156 L
.97016 .2759 L
.97147 .26966 L
.97239 .26397 L
.973 .25865 L
.97337 .25335 L
.97352 .24759 L
.97341 .24215 L
.97309 .23711 L
.97262 .23259 L
.97191 .22761 L
.97095 .22242 L
.96985 .21755 L
.96663 .20663 L
.96281 .19669 L
.95117 .17474 L
.93621 .15445 L
.91626 .13377 L
.87069 .09975 L
.83729 .08134 L
.80232 .06579 L
.76868 .05353 L
.72928 .04186 L
.69177 .03298 L
.64985 .02526 L
.62614 .02183 L
.60416 .0192 L
.58159 .01704 L
.56046 .0155 L
.54103 .01448 L
.53014 .01407 L
.52025 .01379 L
.50936 .01361 L
.49757 .01354 L
.48644 .01359 L
.47621 .01376 L
.4666 .014 L
.45764 .01431 L
.44782 .01474 L
.43733 .01531 L
.416 .01681 L
.39669 .01858 L
.35511 .02377 L
.31218 .03125 L
.27683 .03923 L
.23952 .04972 L
.20187 .06286 L
Mistroke
.16441 .07913 L
.13263 .09627 L
.10628 .11372 L
.0825 .13318 L
.06424 .15192 L
.04788 .17374 L
.04071 .1861 L
.03516 .19795 L
.0309 .20965 L
.02905 .2161 L
.02764 .22215 L
.02668 .22732 L
.02588 .23288 L
.02555 .23605 L
.02531 .23907 L
.02505 .24472 L
.02507 .25087 L
.02522 .2543 L
.02544 .2574 L
.02608 .26345 L
.02697 .26912 L
.02834 .27575 L
.02992 .28181 L
.0346 .29537 L
.03965 .3065 L
.04516 .31648 L
.0606 .3383 L
.07859 .35761 L
.09869 .37492 L
.15375 .40975 L
.1903 .42669 L
.22708 .44043 L
.26235 .45117 L
.30228 .46094 L
.34152 .46845 L
.37851 .47382 L
.40129 .47637 L
.42265 .47827 L
.44627 .47983 L
.45954 .48045 L
.4654 .48067 L
.4716 .48087 L
.48315 .48114 L
.49378 .48127 L
.50523 .48128 L
.51173 .48123 L
.5178 .48115 L
.52878 .48091 L
.53878 .48058 L
.5503 .48009 L
Mistroke
.5612 .47949 L
.58209 .47802 L
.60156 .47624 L
.64529 .47073 L
.6867 .46344 L
.72961 .45348 L
.7655 .44295 L
.80112 .43012 L
.85817 .40297 L
.88619 .38535 L
.90864 .3681 L
.92935 .34835 L
.94753 .32576 L
.95419 .31527 L
.9602 .30398 L
.96478 .29338 L
.96821 .28336 L
.97066 .27393 L
.9717 .26861 L
.97246 .26374 L
.97306 .25842 L
.97345 .25261 L
.97356 .24712 L
.97344 .24203 L
.97303 .23604 L
.97271 .23302 L
.97228 .22972 L
.97129 .22389 L
.97011 .21847 L
.96656 .2063 L
.9614 .19342 L
.94835 .17036 L
.93254 .15016 L
.91389 .13157 L
.89004 .11254 L
.83795 .0816 L
.80583 .06715 L
.77339 .05506 L
.73227 .0426 L
.69252 .03309 L
.65143 .02547 L
.60685 .01946 L
.58324 .01714 L
.56111 .0155 L
.54831 .01478 L
.53666 .01426 L
.5302 .01403 L
.52319 .01383 L
.51657 .01369 L
.51047 .01359 L
Mistroke
.49925 .01351 L
.48861 .01355 L
.47906 .01367 L
.46866 .01391 L
.4574 .0143 L
.44544 .01484 L
.42403 .01617 L
.40448 .01781 L
.38624 .01969 L
.34529 .02527 L
.30215 .03334 L
.26411 .04256 L
.22476 .05455 L
.18552 .06954 L
.15227 .08529 L
.12482 .10111 L
.07984 .1357 L
.06014 .15687 L
.05144 .16845 L
.04354 .18099 L
.03776 .19213 L
.03263 .20458 L
.0308 .21008 L
.0291 .21602 L
.02779 .22157 L
.02679 .22682 L
.02633 .22978 L
.0259 .23299 L
.02537 .2386 L
.02518 .24179 L
.02507 .24516 L
.02511 .25119 L
.02542 .25677 L
.02593 .26197 L
.02675 .26766 L
.02792 .27375 L
.02953 .28029 L
.03168 .28736 L
.03665 .3001 L
.04279 .31232 L
.04959 .32343 L
.0648 .3432 L
.08555 .36397 L
.10986 .38318 L
.1393 .40186 L
.16919 .41732 L
.20496 .43247 L
.27441 .45433 L
.31668 .46389 L
.34066 .46827 L
Mistroke
.3637 .47182 L
.3855 .47463 L
.40941 .47712 L
.43133 .47888 L
.45168 .48008 L
.46282 .48056 L
.47342 .4809 L
.48295 .48111 L
.49334 .48124 L
.50461 .48127 L
.51091 .48122 L
.51661 .48115 L
.52771 .48092 L
.53814 .48059 L
.54798 .48018 L
.55834 .47965 L
.57681 .47842 L
.59656 .47672 L
.61803 .47441 L
.66215 .46802 L
.70776 .45888 L
.74882 .44813 L
.78417 .43657 L
.81781 .42315 L
.85062 .40717 L
.90105 .37435 L
.92383 .35412 L
.9415 .33407 L
.95658 .3111 L
.96301 .29783 L
.96757 .28552 L
.9693 .27962 L
.97066 .27403 L
.97167 .26895 L
.97251 .26355 L
.97315 .25766 L
.97349 .25223 L
.97358 .24639 L
.97351 .24307 L
.97336 .23997 L
.9729 .23447 L
.97224 .22928 L
.97145 .22462 L
.97039 .21956 L
.96726 .2083 L
.96342 .19796 L
.95247 .17669 L
.93595 .15403 L
.91395 .13159 L
.88912 .11185 L
Mistroke
.83191 .07864 L
.79872 .06427 L
.75947 .05048 L
.72375 .04034 L
.68373 .03126 L
.64455 .02437 L
.60797 .01956 L
.58784 .01753 L
.5655 .01577 L
.5542 .01508 L
.54201 .01447 L
.53048 .01403 L
.51993 .01374 L
.50948 .01357 L
.49979 .0135 L
.48915 .01353 L
.47782 .01369 L
.46703 .01395 L
.45688 .01431 L
.43796 .01525 L
.42727 .01594 L
.41559 .01682 L
.39217 .01904 L
.35092 .02439 L
.30421 .0329 L
.2625 .04301 L
.22446 .05466 L
.18586 .06941 L
.15453 .08412 L
.12439 .1014 L
.10029 .11827 L
.07726 .1382 L
.05975 .15737 L
.04645 .17611 L
.03554 .19717 L
.03105 .20933 L
.02799 .22074 L
.02678 .227 L
.02593 .23291 L
.02542 .23823 L
.02512 .244 L
.02507 .247 L
.02511 .25029 L
.02524 .25373 L
.02545 .25694 L
.02604 .26269 L
.02649 .2659 L
.02697 .26884 L
.02939 .27972 L
.03251 .28973 L
Mistroke
.03689 .3006 L
.04264 .31202 L
.05619 .33264 L
.0716 .35058 L
.09274 .37009 L
.11886 .38931 L
.17446 .41974 L
.20979 .43427 L
.24514 .44614 L
.28591 .45716 L
.33243 .46683 L
.3548 .47051 L
.3789 .47382 L
.40151 .47635 L
.4229 .47825 L
.443 .47961 L
.45434 .48019 L
.46474 .48062 L
.4761 .48096 L
.48254 .4811 L
.48852 .48119 L
.49947 .48126 L
.51114 .48121 L
.52234 .48104 L
.53263 .48077 L
.54392 .48036 L
.55581 .47978 L
.57575 .4785 L
.59749 .47663 L
.63709 .47192 L
.6732 .46605 L
.71417 .45738 L
.75665 .44577 L
.79193 .43371 L
.82681 .41909 L
.85558 .40446 L
.88423 .38676 L
.92589 .35204 L
.9436 .33132 L
.9516 .31963 L
.95795 .30855 L
.9629 .29812 L
.96659 .28854 L
.96978 .2778 L
.97113 .27187 L
.97213 .26625 L
.97287 .26067 L
.97318 .25749 L
.97339 .25451 L
.97359 .24851 L
Mistroke
.97358 .24514 L
.97348 .24206 L
.97312 .23659 L
.97244 .23063 L
.97154 .22501 L
.97047 .21982 L
.9669 .20717 L
.96252 .19583 L
.95614 .18294 L
.94885 .17102 L
.93346 .15112 L
.9126 .13037 L
.8885 .1114 L
.85883 .09263 L
.82771 .07664 L
.79683 .06352 L
.7304 .04206 L
.69174 .03289 L
.64906 .02506 L
.61155 .01996 L
.58986 .01771 L
.56935 .01603 L
.5468 .01468 L
.53543 .01419 L
.52891 .01397 L
.52298 .01381 L
.51228 .0136 L
.50086 .0135 L
.49028 .01352 L
.4803 .01364 L
.46863 .0139 L
.46275 .01409 L
.45631 .01433 L
.4343 .01547 L
.42196 .01632 L
.40877 .01741 L
.38514 .01981 L
.33994 .02615 L
.2994 .03394 L
.2568 .0446 L
.21413 .0583 L
.1501 .08646 L
.11858 .1052 L
.09266 .1244 L
.07077 .14481 L
.05404 .16484 L
.04052 .1866 L
.03505 .19838 L
.0305 .21115 L
.0277 .22216 L
Mistroke
.02656 .22841 L
.0258 .23418 L
.02536 .23924 L
.02511 .24481 L
.02513 .25062 L
.02539 .25607 L
.02589 .26135 L
.02657 .26635 L
.02735 .27084 L
.0284 .27572 L
.03145 .28659 L
.03516 .29659 L
.04692 .31924 L
.05545 .33164 L
.06448 .34278 L
.08354 .36213 L
.10837 .38208 L
.16042 .41305 L
.19311 .42777 L
.226 .43999 L
.26397 .45154 L
.30757 .46201 L
.35053 .46984 L
.37153 .47287 L
.39147 .47529 L
.41098 .47725 L
.429 .4787 L
.44913 .47994 L
.45974 .48042 L
.47092 .48082 L
.48112 .48107 L
.49203 .48122 L
.50232 .48126 L
.51167 .48121 L
.52268 .48103 L
.52888 .48088 L
.53459 .48071 L
.54507 .48031 L
.55615 .47977 L
.57854 .47829 L
.59964 .47642 L
.63868 .4717 L
.67963 .46484 L
.72261 .4553 L
.75831 .44526 L
.7942 .43285 L
.85228 .40629 L
.88302 .38759 L
.90773 .36893 L
.93065 .34701 L
Mistroke
.94055 .33533 L
.94976 .32252 L
.95667 .31098 L
.96195 .3003 L
.96633 .28931 L
.96947 .27907 L
.97085 .27325 L
.97202 .26705 L
.97246 .26405 L
.97286 .26081 L
.97321 .25726 L
.97343 .25393 L
.97356 .25088 L
.97361 .24755 L
.97346 .24147 L
.97303 .23557 L
.97238 .23009 L
.97139 .22415 L
.97002 .2179 L
.96677 .20676 L
.96212 .19489 L
.95566 .18206 L
.94062 .1597 L
.92269 .13974 L
.8798 .10545 L
.85084 .0882 L
.82165 .07387 L
.78859 .06039 L
.75091 .04784 L
.71651 .03851 L
.67778 .03007 L
.63486 .02294 L
.59345 .01804 L
.56912 .01601 L
.5568 .01521 L
.54328 .01451 L
.53167 .01406 L
.52516 .01386 L
.51924 .01372 L
.50771 .01354 L
.49681 .01349 L
.48654 .01355 L
.4755 .01373 L
.46509 .01401 L
.45558 .01436 L
.44449 .01488 L
.43242 .01559 L
.41056 .01725 L
.38797 .0195 L
.36417 .02246 L
Mistroke
.32227 .02929 L
.28156 .03808 L
.24493 .04808 L
.18191 .07112 L
.15179 .08557 L
.12187 .10304 L
.09614 .12156 L
.07264 .14286 L
.05468 .16397 L
.0419 .18401 L
.037 .19388 L
.03262 .20473 L
.02939 .21507 L
.0272 .2247 L
.02631 .23017 L
.02563 .23594 L
.02526 .24087 L
.0251 .24626 L
.02518 .25209 L
.02535 .25535 L
.02558 .25831 L
.02623 .26406 L
.0271 .26948 L
.02946 .2799 L
.03242 .28943 L
.03654 .29979 L
.04188 .31061 L
.05629 .33275 L
.07357 .35257 L
.09654 .37314 L
.12558 .39362 L
.18871 .42595 L
.22954 .44117 L
.27012 .45318 L
.31128 .46277 L
.34999 .46976 L
.37196 .47293 L
.396 .47578 L
.41895 .47793 L
.44019 .47944 L
.45147 .48005 L
.46216 .48052 L
.47177 .48084 L
.48221 .48109 L
.4936 .48123 L
.49934 .48126 L
.50567 .48125 L
.51685 .48114 L
.52732 .48092 L
.53779 .4806 L
Mistroke
.54773 .48019 L
.56632 .47916 L
.58623 .47766 L
.6078 .47557 L
.65248 .46962 L
.69857 .46096 L
.74017 .45063 L
.77594 .43949 L
.81049 .42632 L
.84416 .41061 L
.89609 .37822 L
.91978 .35812 L
.93824 .33822 L
.9542 .31536 L
.96111 .30216 L
.96611 .28995 L
.96937 .27946 L
.97081 .27346 L
.9719 .26781 L
.97275 .26186 L
.97328 .2564 L
.97357 .25039 L
.97361 .24738 L
.97357 .24407 L
.97329 .23848 L
.97281 .2334 L
.97199 .22755 L
.97097 .22204 L
.96852 .21228 L
.96498 .20179 L
.96009 .19051 L
.95348 .1783 L
.93627 .15437 L
.91591 .13332 L
.89323 .11479 L
.86631 .09697 L
.83327 .07926 L
.80125 .06524 L
.76451 .05206 L
.72576 .04084 L
.68895 .03229 L
.65057 .02529 L
.61347 .02017 L
.5924 .01794 L
.57259 .01626 L
.55071 .01488 L
.53839 .01431 L
.52716 .01392 L
.51537 .01364 L
.50446 .01351 L
Mistroke
.49877 .01349 L
.49249 .0135 L
.48593 .01356 L
.47979 .01364 L
.46853 .0139 L
.45823 .01425 L
.44695 .01475 L
.43512 .01542 L
.41555 .01683 L
.39483 .01876 L
.35804 .02333 L
.31543 .03061 L
.27814 .03893 L
.24038 .04948 L
.20277 .06255 L
.14251 .09062 L
.11356 .10861 L
.08983 .12679 L
.06774 .14808 L
.05798 .15963 L
.04894 .17223 L
.04228 .18331 L
.03617 .19576 L
.03176 .20723 L
.02862 .21811 L
.02727 .22435 L
.02667 .22777 L
.0262 .23095 L
.02557 .2366 L
.02534 .23959 L
.02518 .24278 L
.0251 .24623 L
.02512 .24997 L
.02525 .2535 L
.02545 .25676 L
.02572 .25969 L
.02609 .26292 L
.0271 .26943 L
.02838 .27562 L
.0299 .28148 L
.03351 .2924 L
.03851 .30402 L
.04525 .31651 L
.06068 .33829 L
.07867 .35759 L
.102 .37737 L
.13138 .39718 L
.16058 .41313 L
.19447 .42831 L
.22751 .44049 L
Mistroke
.26606 .4521 L
.30015 .46041 L
.33861 .46789 L
.36176 .47152 L
.38347 .47437 L
.40405 .4766 L
.42695 .47855 L
.43687 .47923 L
.44757 .47985 L
.45685 .4803 L
.46701 .48069 L
.47788 .481 L
.48932 .48119 L
.49993 .48126 L
.5098 .48122 L
.52148 .48106 L
.52807 .4809 L
.53413 .48072 L
.54526 .4803 L
.55702 .47972 L
.57731 .47838 L
.59946 .47644 L
.62287 .47382 L
.64768 .47037 L
.69138 .46249 L
.73363 .45243 L
.7708 .44124 L
.81205 .42567 L
.8462 .40955 L
.90026 .37501 L
.92416 .35383 L
.94257 .33272 L
.95599 .31223 L
.96195 .30032 L
.96642 .28908 L
.9684 .28292 L
.96998 .27707 L
.97117 .27173 L
.97218 .26606 L
.97259 .26312 L
.97297 .25988 L
.97342 .25416 L
.97356 .25095 L
.97361 .24749 L
.97357 .24422 L
.97346 .24123 L
.97308 .23595 L
.97242 .23032 L
.97156 .22503 L
.97058 .22024 L
Mistroke
.96737 .20854 L
.96331 .19763 L
.95348 .1783 L
.93931 .15804 L
.92063 .13774 L
.89985 .11979 L
.87118 .09993 L
.84157 .08335 L
.77211 .05456 L
.72951 .04182 L
.68685 .03186 L
.6485 .02496 L
.60492 .01921 L
.58266 .01706 L
.57088 .01614 L
.55844 .01531 L
.54746 .01471 L
.53543 .01419 L
.52447 .01384 L
.51425 .01362 L
.50398 .01351 L
.49284 .0135 L
.48232 .0136 L
.47262 .0138 L
.46388 .01405 L
.45428 .01441 L
.43493 .01543 L
.41401 .01696 L
.39172 .01909 L
.35205 .02422 L
.30805 .03211 L
.26884 .04132 L
.22798 .05349 L
.18745 .06875 L
.15209 .08542 L
.12215 .10287 L
.07597 .1395 L
.05848 .159 L
.04338 .18134 L
.03745 .19291 L
.03236 .20547 L
.03038 .21161 L
.02879 .21745 L
.02761 .22267 L
.02657 .22844 L
.02585 .23379 L
.0254 .23881 L
.02514 .24412 L
.02512 .24983 L
.02533 .25486 L
Mistroke
.02577 .26015 L
.02632 .26466 L
.02712 .26958 L
.02968 .2807 L
.03156 .28688 L
.03354 .29247 L
.04337 .31328 L
.04965 .32344 L
.05757 .3344 L
.07677 .35575 L
.12118 .3908 L
.15136 .40842 L
.18744 .42541 L
.26085 .45068 L
.30282 .46099 L
.34338 .46869 L
.38933 .47505 L
.41298 .47742 L
.4258 .47847 L
.43937 .47939 L
.45038 .48 L
.46246 .48053 L
.47347 .48089 L
.48374 .48111 L
.48998 .4812 L
.49589 .48125 L
.50695 .48124 L
.51314 .48119 L
.51886 .48111 L
.52513 .48098 L
.53177 .4808 L
.54204 .48044 L
.55307 .47993 L
.57293 .47871 L
.5964 .47674 L
.61766 .47445 L
.65849 .46864 L
.70066 .4605 L
.73883 .45101 L
.77181 .4409 L
.80838 .42721 L
.84471 .41033 L
.87533 .39267 L
.90062 .37473 L
.92295 .35504 L
.93996 .33609 L
.95492 .31412 L
.96133 .30169 L
.96618 .28976 L
.96973 .27808 L
Mistroke
.97109 .27215 L
.97225 .26559 L
.97296 .26 L
.97344 .25397 L
.97361 .24827 L
.97354 .24305 L
.9734 .24007 L
.97316 .2369 L
.97254 .23119 L
.97202 .2277 L
.97144 .22441 L
.97012 .21828 L
.96648 .2059 L
.9611 .19264 L
.94885 .17099 L
.93378 .15147 L
.91343 .13108 L
.88734 .11056 L
.85571 .09086 L
.82195 .07399 L
.78553 .05926 L
.75015 .04761 L
.71402 .0379 L
.67323 .0292 L
.65012 .02522 L
.62854 .02207 L
.60632 .01936 L
.58538 .0173 L
.5672 .01587 L
.54762 .01472 L
.53642 .01423 L
.52581 .01388 L
.51627 .01366 L
.50589 .01352 L
.49577 .01349 L
.48462 .01357 L
.47298 .01379 L
.46208 .01411 L
.45193 .01452 L
.44265 .01498 L
.42184 .01633 L
.39993 .01824 L
.38022 .0204 L
.33681 .02668 L
.29785 .03429 L
.26251 .04302 L
.18939 .06793 L
.15277 .08506 L
.12249 .10265 L
.09811 .12001 L
Mistroke
.07553 .13994 L
.05784 .15982 L
.0449 .17872 L
.03897 .18971 L
.0338 .20156 L
.03157 .20779 L
.0295 .21471 L
.02794 .2211 L
.0268 .22699 L
.02599 .23262 L
.02541 .23857 L
.02513 .24454 L
.0251 .24793 L
.02515 .25108 L
.02546 .25681 L
.02598 .26201 L
.02685 .26801 L
.02794 .27365 L
.03084 .28462 L
.03445 .29481 L
.03987 .30677 L
.04588 .31754 L
.0612 .3389 L
.08206 .36076 L
.10318 .37825 L
.12954 .39606 L
.18561 .42463 L
.22311 .439 L
.26092 .45069 L
.29707 .45973 L
.3368 .46758 L
.35802 .47098 L
.38165 .47415 L
.40365 .47656 L
.42388 .47832 L
.44796 .47987 L
.46128 .48048 L
.4674 .4807 L
.47391 .4809 L
.4856 .48114 L
.49641 .48125 L
.50804 .48124 L
.51466 .48117 L
.52087 .48107 L
.53029 .48084 L
.54034 .4805 L
.55839 .47964 L
.57974 .4782 L
.599 .47649 L
.64036 .47146 L
Mistroke
.6784 .46509 L
.74243 .44999 L
.77628 .43938 L
.80576 .42829 L
Mfstroke
.92204 .35363 m
.9392 .33438 L
.95205 .31573 L
.95792 .30497 L
.96254 .29467 L
.96674 .28266 L
.96817 .27743 L
.96949 .27165 L
.9705 .26599 L
.97121 .26068 L
.9717 .25507 L
.97194 .24903 L
.97188 .24343 L
.97159 .23811 L
.97113 .23334 L
.97041 .22814 L
.96925 .22196 L
.96792 .21637 L
.96399 .20392 L
.95919 .19252 L
.95366 .18194 L
.93869 .16 L
.91831 .1379 L
.8974 .12008 L
.87093 .10179 L
.83864 .08375 L
.80007 .06649 L
.76063 .05238 L
.72169 .0412 L
.68198 .03212 L
.6381 .02443 L
.61641 .02145 L
.59272 .01879 L
.57905 .01752 L
.56645 .01652 L
.55445 .01571 L
.54158 .01501 L
.5303 .01453 L
.52002 .0142 L
.50969 .01397 L
.49992 .01385 L
.48852 .01383 L
.47801 .01393 L
.46649 .01416 L
.46068 .01433 L
.4543 .01455 L
.44237 .01507 L
.4315 .01567 L
.40716 .01746 L
.3848 .01965 L
Mistroke
.36379 .02221 L
.32105 .02901 L
.28363 .0369 L
.24234 .04802 L
.20572 .0604 L
.1469 .08692 L
.11801 .10417 L
.09448 .12135 L
.07348 .14025 L
.05487 .16163 L
.04119 .18272 L
.03637 .19226 L
.03211 .2025 L
.03009 .20831 L
.02819 .21476 L
.02675 .22072 L
.02568 .22618 L
.02473 .23263 L
.02438 .23602 L
.0241 .23959 L
.02386 .24561 L
.02386 .24901 L
.02395 .25218 L
.02434 .25834 L
.025 .26415 L
.02582 .26935 L
.02696 .27497 L
.03045 .2875 L
.0348 .29892 L
.04593 .32001 L
.06199 .34182 L
.08091 .36142 L
.10119 .37834 L
.12838 .39681 L
.16188 .4151 L
.19661 .4304 L
.23184 .44305 L
.26945 .45401 L
.30563 .46248 L
.34734 .47008 L
.37121 .47348 L
.39374 .47612 L
.41444 .47805 L
.43673 .47965 L
.44951 .48033 L
.46162 .48083 L
.47251 .48115 L
.47866 .48129 L
.48434 .48137 L
.49583 .48146 L
Mistroke
.50659 .48141 L
.51839 .48124 L
.52501 .48108 L
.53107 .4809 L
.54317 .48042 L
.55635 .47974 L
.58023 .47806 L
.60264 .47594 L
.62661 .47308 L
.66917 .46639 L
.70919 .45803 L
.74448 .44876 L
.81801 .42222 L
.85076 .40615 L
.88286 .38662 L
.9088 .36682 L
.92958 .34681 L
.94492 .32796 L
.95788 .3067 L
.96302 .29546 L
.96744 .28292 L
.96915 .27656 L
.97063 .26969 L
.97117 .26653 L
.97166 .26319 L
.97229 .25722 L
.97262 .25167 L
.97268 .24574 L
.97248 .24015 L
.97206 .23507 L
.97131 .22911 L
.97016 .22266 L
.96875 .2166 L
.96718 .21103 L
.9588 .18999 L
.95247 .17841 L
.94568 .16802 L
.91162 .13072 L
.88716 .11155 L
.85645 .09228 L
.79093 .06209 L
.75179 .04884 L
.7127 .03823 L
.67601 .03028 L
.63502 .0234 L
.61127 .0203 L
.58888 .01793 L
.5653 .016 L
.55274 .01521 L
.53927 .01453 L
Mistroke
.52773 .01409 L
.52121 .0139 L
.51518 .01376 L
.50411 .0136 L
.49236 .01356 L
.48186 .01364 L
.47203 .01382 L
.46126 .01412 L
.44968 .01457 L
.43788 .01517 L
.42721 .01583 L
.40342 .01773 L
.38157 .02001 L
.36121 .0226 L
.31647 .03002 L
.27001 .04052 L
.23092 .05194 L
.19224 .06611 L
.15882 .08125 L
.13101 .09654 L
.08274 .13212 L
.06192 .15369 L
.04625 .17517 L
.04057 .18504 L
.03546 .19567 L
.03181 .20497 L
.02869 .21508 L
.02732 .22075 L
.02629 .22596 L
.02551 .23096 L
.02492 .23623 L
.02453 .24203 L
.02441 .24743 L
.02456 .25335 L
.02477 .25666 L
.02503 .25967 L
.02572 .26523 L
.02659 .27042 L
.02939 .28218 L
.03322 .29353 L
.03851 .30559 L
.05116 .32687 L
.06608 .3456 L
.08725 .3663 L
.11478 .38734 L
.1756 .42089 L
.21243 .4358 L
.24969 .44799 L
.28544 .45747 L
.3248 .46579 L
Mistroke
.34588 .46942 L
.36936 .47286 L
.39126 .4755 L
.4114 .47748 L
.43542 .47928 L
.44871 .48003 L
.46132 .48058 L
.47299 .48094 L
.48379 .48116 L
.48943 .48123 L
.49565 .48127 L
.50215 .48127 L
.50825 .48124 L
.51878 .48109 L
.53002 .48081 L
.5406 .48043 L
.5502 .47999 L
.57364 .47853 L
.59559 .47665 L
.63867 .47146 L
.66247 .46769 L
.684 .46368 L
.75541 .44574 L
.78879 .43443 L
.82306 .42031 L
.85594 .40371 L
.88391 .38638 L
.90637 .36941 L
.92695 .35023 L
.9452 .3283 L
.95813 .30714 L
.96361 .29514 L
.96764 .28372 L
.96934 .27758 L
.97079 .27108 L
.97141 .26768 L
.97198 .26394 L
.97238 .26075 L
.9727 .25737 L
.97305 .25128 L
.9731 .24566 L
.97287 .23962 L
.9726 .23618 L
.97226 .23297 L
.97143 .22718 L
.97043 .22191 L
.96734 .21009 L
.96363 .19972 L
.95855 .18853 L
.9466 .1686 L
Mistroke
.92855 .14644 L
.90455 .12416 L
.85004 .08827 L
.81575 .07171 L
.78139 .05817 L
.74174 .0455 L
.69553 .03395 L
.65337 .02595 L
.61279 .02024 L
.58998 .01782 L
.56899 .01608 L
.55732 .01531 L
.54459 .01462 L
.53254 .01412 L
.52137 .01378 L
.51086 .01357 L
.49979 .01347 L
.49033 .01348 L
.47999 .01359 L
.46883 .01383 L
.46258 .01402 L
.45692 .01423 L
.44578 .01472 L
.43553 .01528 L
.41581 .01667 L
.39459 .01862 L
.35663 .02333 L
.31645 .03016 L
.27389 .0397 L
.23172 .05191 L
.19478 .06534 L
.16154 .08019 L
.12873 .09828 L
.10305 .11573 L
.07936 .13569 L
.05984 .15671 L
.04574 .17661 L
.04018 .18647 L
.03512 .19727 L
.03124 .20762 L
.02849 .21712 L
.02721 .2228 L
.02624 .22819 L
.02548 .23388 L
.02516 .2371 L
.02495 .24007 L
.02475 .24503 L
.02477 .25049 L
.02505 .25619 L
.02555 .26153 L
Mistroke
.02594 .26452 L
.02644 .26779 L
.02758 .27372 L
.03051 .28481 L
.03521 .29762 L
.0408 .30936 L
.05587 .33278 L
.07359 .35309 L
.09858 .37518 L
.12631 .39446 L
.18705 .42555 L
.22174 .4388 L
.26251 .45136 L
.2992 .46038 L
.34017 .46829 L
.38004 .47405 L
.4172 .47784 L
.43733 .47929 L
.44885 .47994 L
.45969 .48043 L
.47109 .48081 L
.48156 .48106 L
.49307 .4812 L
.49886 .48122 L
.5052 .48121 L
.51592 .4811 L
.52567 .4809 L
.53691 .48056 L
.54751 .48012 L
.5663 .47906 L
.58658 .47751 L
.60841 .47537 L
.63217 .47245 L
.67911 .46475 L
.72093 .4555 L
.75826 .44503 L
.79461 .43243 L
.83133 .41668 L
.86084 .40117 L
.88902 .38308 L
.91331 .36373 L
.932 .34511 L
.94743 .32551 L
.95877 .30641 L
.9637 .29553 L
.9674 .28528 L
.97044 .27393 L
.97167 .26754 L
.97251 .2617 L
.97307 .25557 L
Mistroke
.97332 .24991 L
.97335 .24695 L
.97329 .24369 L
.97314 .24029 L
.97291 .2371 L
.97228 .23126 L
.97145 .22592 L
.97027 .22007 L
.96872 .21394 L
.96547 .20385 L
.96106 .19318 L
.95072 .17433 L
.93451 .1527 L
.91625 .13397 L
.89347 .11526 L
.86572 .09688 L
.80757 .06801 L
.77113 .05441 L
.73481 .04338 L
.69284 .03322 L
.64575 .02461 L
.62389 .02151 L
.60034 .01876 L
.57787 .01669 L
.55739 .01525 L
.54472 .01457 L
.53305 .01409 L
.52641 .01387 L
.52022 .01371 L
.51376 .01358 L
.50667 .01349 L
.50045 .01345 L
.49457 .01345 L
.48357 .01353 L
.47741 .01363 L
.47172 .01376 L
.45888 .01416 L
.4486 .01459 L
.43757 .01518 L
.41771 .01655 L
.39427 .0187 L
.37304 .02116 L
.32789 .0281 L
.28646 .03673 L
.24702 .04727 L
.21314 .05846 L
.179 .07219 L
.14515 .08892 L
.11691 .10608 L
.0939 .12313 L
Mistroke
.07341 .14179 L
.0577 .15967 L
.0438 .18021 L
.03774 .19181 L
.03307 .20295 L
.02968 .21333 L
.02734 .223 L
.02643 .22806 L
.02567 .23366 L
.02516 .23952 L
.02493 .24503 L
.02495 .25065 L
.02527 .25679 L
.02555 .25989 L
.02593 .2632 L
.02685 .26915 L
.02806 .27508 L
.02947 .28065 L
.0328 .29102 L
.03788 .30313 L
.04365 .31414 L
.06046 .3383 L
.07841 .35759 L
.10143 .37715 L
.152 .40892 L
.18794 .42576 L
.22515 .43982 L
.26436 .45174 L
.30174 .46083 L
.34286 .46865 L
.38275 .47431 L
.40507 .4767 L
.42578 .47846 L
.44867 .47989 L
.46024 .48042 L
.46632 .48064 L
.47294 .48084 L
.48397 .48108 L
.49441 .4812 L
.50458 .48121 L
.51398 .48113 L
.52411 .48095 L
.53528 .48063 L
.54691 .48016 L
.5578 .4796 L
.57754 .47829 L
.59549 .47674 L
.63542 .47206 L
.67563 .46549 L
.71704 .45656 L
Mistroke
.7865 .43559 L
.82502 .41978 L
.85804 .40292 L
.88447 .38643 L
.90995 .36685 L
.93099 .34643 L
.947 .32637 L
.95992 .30436 L
.96532 .29174 L
.96727 .2861 L
.96906 .28008 L
.97035 .27492 L
.97151 .26921 L
.97234 .264 L
.97291 .2591 L
.97333 .25334 L
.97348 .24806 L
.97337 .24226 L
.97296 .23615 L
.9724 .23118 L
.97157 .22587 L
.96949 .21633 L
.96605 .20508 L
.962 .19495 L
.95033 .17349 L
.93371 .15159 L
.9162 .13375 L
.89357 .11519 L
.86561 .09668 L
.83165 .07859 L
.76137 .05113 L
.72089 .03965 L
.68143 .03081 L
.63645 .02318 L
.61069 .01986 L
.58705 .01744 L
.56422 .01566 L
.54309 .01448 L
.53199 .01404 L
.52561 .01384 L
.5198 .0137 L
.51364 .01358 L
.50704 .0135 L
.50093 .01346 L
.49514 .01345 L
.48463 .01353 L
.47348 .01373 L
.46398 .01399 L
.4535 .01439 L
.4423 .01494 L
Mistroke
.43026 .01567 L
.40859 .01736 L
.38761 .01946 L
.36544 .02221 L
.32628 .02845 L
.28137 .03803 L
.24251 .04872 L
.20426 .06187 L
.166 .07831 L
.13354 .09567 L
.10652 .11348 L
.08301 .13267 L
.06479 .15124 L
.04842 .17286 L
.04111 .18527 L
.03554 .19697 L
.03127 .2084 L
.02951 .21429 L
.02793 .22068 L
.02717 .22436 L
.02658 .22774 L
.02611 .23092 L
.02569 .2344 L
.02519 .24046 L
.02505 .24377 L
.025 .24685 L
.02502 .24982 L
.02513 .25305 L
.02554 .25891 L
.02622 .2646 L
.02707 .26985 L
.02826 .2755 L
.02986 .2817 L
.03409 .29415 L
.03905 .30535 L
.04567 .31738 L
.06089 .33868 L
.07947 .35847 L
.0999 .37587 L
.15646 .41113 L
.19364 .42804 L
.23033 .44148 L
.26747 .45251 L
.30877 .46227 L
.34541 .46903 L
.3868 .47476 L
.41051 .47719 L
.43233 .47892 L
.44445 .47966 L
.45769 .48031 L
Mistroke
.46376 .48055 L
.47022 .48077 L
.48184 .48105 L
.49242 .48119 L
.50383 .48122 L
.5146 .48113 L
.52448 .48095 L
.53541 .48064 L
.54736 .48016 L
.5598 .47951 L
.57134 .47877 L
.59443 .47687 L
.61554 .47464 L
.66234 .46792 L
.70226 .46007 L
.74277 .44982 L
.80754 .42747 L
.84069 .41229 L
.86894 .39658 L
.89559 .37851 L
.92057 .35726 L
.94 .33592 L
.9542 .31522 L
.95998 .30439 L
.9645 .29406 L
.96779 .28469 L
.97052 .27449 L
.9716 .26914 L
.97251 .26327 L
.97286 .2603 L
.97315 .25712 L
.97348 .25139 L
.97353 .24566 L
.97334 .24025 L
.97296 .23539 L
.97232 .23012 L
.97138 .22448 L
.9703 .21932 L
.96704 .20776 L
.96325 .19767 L
.95835 .18718 L
.94487 .16542 L
.92553 .14267 L
.90235 .12184 L
.87314 .10122 L
.81019 .06893 L
.77231 .05466 L
.73502 .04332 L
.69183 .03291 L
.64407 .02428 L
Mistroke
.62354 .02141 L
.60124 .01881 L
.58177 .01697 L
.56042 .01541 L
.54737 .01469 L
.53526 .01416 L
.52366 .0138 L
.51779 .01366 L
.51131 .01355 L
.50016 .01346 L
.49388 .01347 L
.48812 .0135 L
.47751 .01365 L
.46634 .01393 L
.45539 .01433 L
.44354 .01489 L
.4221 .01627 L
.40136 .01806 L
.38238 .02009 L
.34002 .02609 L
.29655 .03452 L
.22853 .05324 L
.19293 .06641 L
.16199 .08031 L
.13186 .09674 L
.1027 .11639 L
.0805 .13506 L
.0607 .15616 L
.04524 .17805 L
.03493 .19857 L
.03124 .20864 L
.02964 .21398 L
.02821 .21964 L
.02718 .22461 L
.02628 .23007 L
.02567 .23506 L
.02529 .23971 L
.02506 .24558 L
.02505 .24854 L
.02513 .25181 L
.02547 .25758 L
.02605 .26299 L
.02649 .26608 L
.02703 .26933 L
.02822 .27512 L
.03191 .28809 L
.03624 .29921 L
.0412 .30942 L
.0557 .33203 L
.07268 .35172 L
Mistroke
.09109 .36874 L
.14201 .40338 L
.17234 .41878 L
.2074 .43338 L
.27672 .45489 L
.3182 .46416 L
.35848 .47104 L
.38166 .47414 L
.40392 .47657 L
.4163 .4777 L
.42985 .47874 L
.44228 .47954 L
.45372 .48014 L
.46482 .4806 L
.47654 .48094 L
.48833 .48116 L
.49502 .48122 L
.50125 .48124 L
.51257 .48117 L
.52287 .481 L
.52857 .48086 L
.53475 .48068 L
.54597 .48024 L
.56693 .47909 L
.58903 .47739 L
.60775 .47555 L
.62819 .4731 L
.67249 .46615 L
.71839 .45632 L
.75955 .44484 L
.79503 .4325 L
.82743 .41878 L
.85908 .40246 L
.90748 .36909 L
.93108 .34649 L
.94877 .32396 L
.96072 .30293 L
.96576 .29083 L
.96771 .28506 L
.96931 .27956 L
.97063 .27415 L
.97179 .26823 L
.9726 .26284 L
.97313 .25785 L
.97347 .25246 L
.97358 .24651 L
.97352 .24352 L
.97337 .24029 L
.9729 .23446 L
.97224 .22935 L
Mistroke
.97129 .22378 L
.96858 .21259 L
.96515 .20232 L
.96116 .19285 L
.94796 .16973 L
.93201 .14953 L
.90917 .12742 L
.88347 .10792 L
.82563 .07568 L
.79221 .06175 L
.7526 .04835 L
.71684 .03859 L
.67664 .02985 L
.63733 .02328 L
.60049 .01873 L
.57854 .01671 L
.55849 .0153 L
.54733 .01469 L
.53523 .01417 L
.52378 .01381 L
.51324 .01359 L
.50344 .01349 L
.4943 .01347 L
.48427 .01356 L
.47352 .01375 L
.46227 .01408 L
.45163 .01451 L
.43177 .01561 L
.4097 .0173 L
.38646 .01964 L
.34546 .02522 L
.30266 .03321 L
.25751 .04438 L
.22041 .05604 L
.18394 .07022 L
.12642 .10011 L
.09923 .11909 L
.07743 .13803 L
.05763 .16005 L
.04913 .17191 L
.0415 .18472 L
.03597 .19616 L
.03118 .20891 L
.02952 .21455 L
.02802 .22062 L
.02689 .22633 L
.02609 .23163 L
.02572 .23484 L
.02541 .23826 L
.02519 .24205 L
Mistroke
.02509 .24549 L
.02508 .24875 L
.02517 .25227 L
.02535 .25559 L
.02559 .25863 L
.02626 .26435 L
.02675 .26759 L
.02729 .2706 L
.0286 .27662 L
.03036 .28313 L
.03453 .29508 L
.03958 .30623 L
.05182 .32666 L
.0706 .34953 L
.09204 .3695 L
.11531 .38693 L
.14369 .40429 L
.20282 .43162 L
.24315 .44552 L
.28401 .45669 L
.32243 .46497 L
.3659 .4721 L
.38792 .47488 L
.41202 .47733 L
.43499 .4791 L
.44598 .47976 L
.45626 .48026 L
.46557 .48063 L
.47557 .48093 L
.48667 .48114 L
.49681 .48124 L
.50736 .48123 L
.51884 .48109 L
.52967 .48084 L
.53968 .48051 L
.55034 .48005 L
.56181 .47942 L
.58248 .47796 L
.60686 .47566 L
.62898 .47301 L
.67364 .46596 L
.7189 .45621 L
.75775 .44542 L
.79113 .434 L
.82471 .42006 L
.85799 .4031 L
.8856 .3858 L
.90809 .36861 L
.928 .34984 L
.94321 .33184 L
Mistroke
.95646 .31135 L
.96218 .29978 L
.96655 .28865 L
.96965 .27831 L
.97174 .26867 L
.97258 .26309 L
.97313 .25804 L
.9735 .25219 L
.9736 .24669 L
.97344 .24111 L
.97297 .235 L
.97262 .23193 L
.97215 .22864 L
.97109 .22271 L
.96821 .21128 L
.96464 .20095 L
.95936 .18906 L
.95228 .17634 L
.9359 .15394 L
.9167 .13405 L
.89542 .11643 L
.86627 .09695 L
.83619 .08068 L
.76611 .05258 L
.72537 .04073 L
.68016 .03052 L
.63793 .02337 L
.59856 .01853 L
.57642 .01655 L
.5647 .0157 L
.55226 .01495 L
.54134 .01442 L
.53554 .01418 L
.52932 .01397 L
.51837 .01369 L
.50813 .01353 L
.49718 .01348 L
.48705 .01353 L
.47593 .01371 L
.47031 .01384 L
.46411 .01403 L
.45379 .01442 L
.44267 .01496 L
.42262 .01626 L
.40304 .01792 L
.38258 .0201 L
.34654 .02506 L
.30491 .03275 L
.26846 .0414 L
.23104 .05246 L
Mistroke
.19297 .06644 L
.16042 .08114 L
.13294 .09614 L
.08695 .12926 L
.0676 .14822 L
.05066 .16964 L
.04395 .18032 L
.0385 .19064 L
.03403 .20092 L
.03075 .21034 L
.02779 .22175 L
.02662 .22805 L
.02582 .23399 L
.02534 .23951 L
.02512 .2446 L
.02512 .25018 L
.0254 .25607 L
.02597 .26202 L
.02641 .26535 L
.0269 .26839 L
.02943 .27981 L
.03132 .28617 L
.03374 .29303 L
.03917 .30539 L
.0519 .32676 L
.06739 .34606 L
.08815 .3662 L
.11469 .38649 L
.14497 .40499 L
.18072 .42252 L
.21742 .43701 L
.25312 .44848 L
.28916 .45791 L
.32992 .46636 L
.35295 .47021 L
.37452 .47325 L
.39672 .47585 L
.41769 .47782 L
.43577 .47915 L
.4553 .48022 L
.46645 .48066 L
.47705 .48097 L
.48658 .48115 L
.49697 .48124 L
.5081 .48123 L
.51817 .48111 L
.52978 .48085 L
.5407 .48048 L
.55082 .48003 L
.5601 .47953 L
Mistroke
.58095 .47809 L
.60262 .47611 L
.62216 .4739 L
.66524 .46748 L
.70389 .45977 L
.73905 .45093 L
.81158 .42585 L
.84792 .40863 L
.87803 .39092 L
.902 .37362 L
.92425 .35372 L
.94167 .33389 L
.95441 .315 L
.96021 .30407 L
.96527 .29225 L
.96764 .28539 L
.96945 .27913 L
.97096 .27275 L
.97205 .26685 L
.97282 .26124 L
.97335 .25531 L
.97359 .24935 L
.9736 .24596 L
.97352 .2428 L
.97317 .23708 L
.97262 .23187 L
.9717 .22587 L
.97056 .22019 L
.96762 .20934 L
.96397 .19924 L
.95247 .17664 L
.93714 .15541 L
.91623 .13361 L
.89428 .11557 L
.8678 .09787 L
.81267 .06994 L
.77752 .05641 L
.74346 .04565 L
.70485 .03575 L
.66109 .02703 L
.64087 .0238 L
.61916 .02085 L
.59881 .01856 L
.5796 .0168 L
.56153 .01549 L
.54201 .01445 L
.53086 .01402 L
.52026 .01373 L
.51073 .01357 L
.50034 .01349 L
Mistroke
.49455 .01349 L
.48843 .01352 L
.4775 .01368 L
.46574 .01398 L
.45907 .01421 L
.45286 .01447 L
.4314 .01565 L
.40855 .01742 L
.38656 .01965 L
.36596 .02221 L
.32808 .02821 L
.28523 .03719 L
.24738 .04734 L
.20847 .06038 L
.16974 .07664 L
.13847 .09291 L
.1127 .1092 L
.07097 .1446 L
.05399 .16492 L
.03978 .18807 L
.03438 .20004 L
.03194 .20668 L
.02997 .21298 L
.02843 .21889 L
.02709 .2253 L
.02617 .23115 L
.02557 .23655 L
.02519 .24239 L
.02509 .24793 L
.02522 .25291 L
.02558 .25832 L
.02625 .26419 L
.02675 .26746 L
.02728 .27042 L
.02992 .28155 L
.0333 .29183 L
.03793 .30281 L
.04888 .32229 L
.06612 .34464 L
.08902 .36693 L
.11459 .38642 L
.14108 .40282 L
.203 .43168 L
.24118 .4449 L
.27954 .45559 L
.31415 .46335 L
.3521 .47008 L
.37233 .47297 L
.3949 .47566 L
.41572 .47765 L
Mistroke
.4352 .47912 L
.44674 .4798 L
.45724 .48031 L
.46892 .48075 L
.47534 .48093 L
.4814 .48107 L
.49243 .48122 L
.50258 .48125 L
.51372 .48118 L
.52549 .48096 L
.53532 .48068 L
.54585 .48027 L
.56479 .47925 L
.58718 .47758 L
.60744 .47561 L
.65165 .46974 L
.69819 .46104 L
.74022 .45061 L
.77705 .4391 L
.80988 .42658 L
.84262 .4114 L
.89392 .37985 L
.91839 .35945 L
.93959 .33656 L
.95378 .31607 L
.96017 .30416 L
.96502 .29291 L
.9671 .28708 L
.96898 .28088 L
.97036 .27549 L
.97156 .26969 L
.97212 .26643 L
.97255 .26345 L
.97318 .25759 L
.97341 .25432 L
.97357 .25075 L
.97361 .24738 L
.97357 .24426 L
.97327 .23821 L
.97271 .23253 L
.97198 .22743 L
.97095 .22194 L
.96773 .20967 L
.96367 .19851 L
.95403 .17922 L
.93986 .15873 L
.9212 .13828 L
.90041 .12024 L
.87425 .10185 L
.842 .08357 L
Mistroke
.81056 .06905 L
.77445 .05536 L
.73983 .04462 L
.69966 .03458 L
.66158 .02711 L
.62482 .02157 L
.60506 .01922 L
.58378 .01716 L
.57146 .01617 L
.56024 .01542 L
.54956 .01481 L
.53823 .0143 L
.53257 .01409 L
.52635 .01389 L
.5154 .01364 L
.50923 .01355 L
.5026 .0135 L
.49635 .01349 L
.49064 .01351 L
.4796 .01364 L
.47337 .01377 L
.4676 .01393 L
.45703 .0143 L
.44582 .01481 L
.42649 .01599 L
.40577 .01768 L
.36871 .02185 L
.32569 .02865 L
.28754 .03664 L
.25034 .04647 L
.21271 .05882 L
.15161 .08567 L
.11921 .10479 L
.09251 .12453 L
.07218 .14335 L
.0538 .16519 L
.04671 .17574 L
.04017 .18729 L
.03546 .19742 L
.03131 .20859 L
.02937 .21516 L
.0279 .22128 L
.02678 .22714 L
.02631 .23015 L
.0259 .23341 L
.02557 .23662 L
.02534 .23958 L
.02511 .24539 L
.02514 .25068 L
.02542 .25625 L
Mistroke
.02592 .26159 L
.02659 .26644 L
.0276 .27203 L
.02879 .27731 L
.03148 .28664 L
.03522 .2967 L
.04681 .31905 L
.06128 .339 L
.07921 .3581 L
.10221 .37753 L
.15274 .40913 L
.18672 .4251 L
.22573 .43989 L
.2649 .45178 L
.30234 .46089 L
.34317 .46865 L
.38288 .4743 L
.40508 .47669 L
.42572 .47846 L
.44854 .4799 L
.46009 .48043 L
.46617 .48066 L
.47281 .48087 L
.48376 .48111 L
.49416 .48123 L
.50429 .48125 L
.51367 .48118 L
.52483 .48098 L
.53491 .4807 L
.54654 .48024 L
.55745 .47969 L
.57713 .4784 L
.5951 .47686 L
.6351 .4722 L
.67506 .46571 L
.71634 .45686 L
.78573 .43602 L
.82418 .42032 L
.85727 .40353 L
.88378 .38708 L
.90943 .36749 L
.92916 .34863 L
.94655 .32727 L
.95435 .3151 L
.96036 .30377 L
.96533 .29208 L
.96892 .28111 L
.97132 .27102 L
.97229 .26535 L
.97294 .2602 L
Mistroke
.9734 .25453 L
.97361 .24839 L
.97352 .2426 L
.97319 .23727 L
.97268 .23227 L
.97201 .22761 L
.97107 .22251 L
.96982 .21705 L
.96651 .20599 L
.96261 .19599 L
.95122 .17462 L
.93489 .15275 L
.91766 .13492 L
.89527 .1163 L
.86765 .09777 L
.83396 .07959 L
.79906 .06437 L
.76402 .0519 L
.72554 .04077 L
.68885 .03227 L
.64653 .02466 L
.62243 .02127 L
.5999 .01868 L
.57772 .01666 L
.55405 .01505 L
.54172 .01444 L
.53016 .01401 L
.52352 .01382 L
.51745 .01368 L
.51043 .01357 L
.50377 .01351 L
.49278 .0135 L
.48107 .01362 L
.47003 .01386 L
.46004 .01418 L
.44827 .01469 L
.43558 .01539 L
.4127 .01707 L
.39187 .01907 L
.36978 .02171 L
.33069 .02775 L
.28579 .03706 L
.24678 .04753 L
.20843 .0604 L
.16987 .07658 L
.13709 .09371 L
.10964 .11136 L
.08587 .13024 L
.06729 .14858 L
.05046 .16996 L
Mistroke
.04286 .18227 L
.03699 .19392 L
.03264 .20468 L
.02908 .21628 L
.02755 .22295 L
.02645 .22925 L
.02573 .23493 L
.02545 .23813 L
.02526 .24108 L
.0251 .24708 L
.02521 .25268 L
.02563 .25883 L
.02601 .26227 L
.02643 .26541 L
.02753 .27171 L
.0291 .27854 L
.03295 .29087 L
.03728 .3014 L
.04299 .3126 L
.05603 .3324 L
.07592 .35491 L
.09814 .3744 L
.15492 .41026 L
.18846 .42583 L
.22848 .44082 L
.26865 .45279 L
.30864 .46222 L
.34593 .46911 L
.38758 .47485 L
.40954 .47711 L
.43395 .47904 L
.44629 .47978 L
.45962 .48041 L
.46607 .48066 L
.47222 .48085 L
.48377 .48111 L
.49454 .48124 L
.50602 .48125 L
.51685 .48114 L
.52667 .48094 L
.53823 .48058 L
.55071 .48005 L
.57325 .47868 L
.59414 .47695 L
.61633 .47461 L
.6557 .4691 L
.70104 .46042 L
.74061 .45051 L
.77962 .43821 L
.81905 .42263 L
Mistroke
.85278 .40603 L
.88123 .38881 L
.90601 .37037 L
.9256 .35237 L
.94363 .33131 L
.95192 .31915 L
.95846 .30761 L
.96378 .29605 L
.96764 .28542 L
.9708 .27351 L
.97204 .26693 L
.97248 .26397 L
.97289 .26071 L
.9734 .25463 L
.97355 .25131 L
.97361 .2482 L
.97352 .24263 L
.97314 .23666 L
.9728 .23333 L
.97233 .22969 L
.97119 .2231 L
.96973 .2167 L
.96808 .21079 L
.96375 .19869 L
.95871 .18772 L
.94362 .16361 L
.92621 .14327 L
.90386 .12297 L
.85613 .09109 L
.8245 .07514 L
.79238 .0618 L
.75555 .04924 L
.71302 .03766 L
.67084 .02876 L
.63049 .02233 L
.59329 .01802 L
.57184 .01621 L
.55161 .01492 L
.5412 .01442 L
.53023 .01401 L
.52086 .01375 L
.5106 .01357 L
.49951 .01349 L
.4933 .0135 L
.48767 .01354 L
.4767 .0137 L
.46637 .01397 L
.45605 .01434 L
.445 .01485 L
.42513 .01609 L
Mistroke
.40166 .01807 L
.38044 .02037 L
.33521 .02696 L
.29375 .03521 L
.2252 .05442 L
.18963 .06783 L
.15913 .08181 L
.13123 .09719 L
.10432 .11525 L
.08393 .13197 L
.06486 .15132 L
.04791 .17383 L
.04058 .1865 L
.03502 .19849 L
.0309 .20989 L
.02811 .22034 L
.02695 .22615 L
.02645 .22921 L
.02601 .23247 L
.02542 .23845 L
.02514 .24397 L
.02512 .24958 L
.02538 .25571 L
.02591 .26148 L
.02665 .26683 L
.02762 .27212 L
.02869 .2769 L
.03178 .28755 L
.03617 .29893 L
.04214 .31107 L
.05611 .3325 L
.07292 .3519 L
.0943 .37133 L
.14121 .40289 L
.17222 .41869 L
.20296 .43166 L
.23841 .44404 L
.27938 .45555 L
.31913 .46434 L
.35721 .47086 L
.39454 .47562 L
.41365 .47748 L
.43489 .4791 L
.45577 .48025 L
.46763 .48071 L
.47868 .48101 L
.4904 .4812 L
.50105 .48126 L
.50695 .48124 L
.51334 .48119 L
Mistroke
.52493 .48098 L
.53487 .4807 L
.54579 .48028 L
.55716 .47971 L
.56777 .47906 L
.60678 .47568 L
.63017 .47288 L
.65206 .46969 L
.69218 .46233 L
.73366 .45242 L
.77639 .43934 L
.80576 .42829 L
Mfstroke
.92265 .3553 m
.94009 .33587 L
.95317 .31703 L
.95916 .30614 L
.96388 .29571 L
.96817 .28355 L
.96964 .27825 L
.971 .27239 L
.97205 .26665 L
.97278 .26127 L
.9733 .25557 L
.97356 .24944 L
.97352 .24376 L
.97324 .23836 L
.97279 .23353 L
.97207 .22825 L
.97091 .22198 L
.96959 .2163 L
.96564 .20368 L
.96081 .19211 L
.95523 .18137 L
.94012 .15914 L
.91954 .13678 L
.89841 .11877 L
.87168 .10033 L
.83907 .0822 L
.80015 .06491 L
.76038 .05086 L
.72116 .03978 L
.68119 .03085 L
.63708 .02337 L
.61371 .02032 L
.59151 .01797 L
.56693 .01597 L
.55302 .01511 L
.54022 .01449 L
.52979 .01411 L
.51862 .01381 L
.50808 .01365 L
.49849 .0136 L
.48721 .01365 L
.48085 .01373 L
.47499 .01384 L
.46423 .01414 L
.45285 .01457 L
.44198 .01511 L
.43034 .01582 L
.40941 .01744 L
.38474 .01994 L
.36246 .02278 L
Mistroke
.32204 .0294 L
.28052 .03839 L
.21099 .05948 L
.17243 .0754 L
.13946 .09234 L
.1131 .10891 L
.08776 .12854 L
.06675 .14914 L
.05084 .16934 L
.03807 .19148 L
.03278 .20417 L
.03088 .20983 L
.02915 .21586 L
.02791 .22105 L
.0268 .2268 L
.02603 .23204 L
.02551 .23696 L
.02515 .24274 L
.02506 .24804 L
.02523 .25385 L
.02571 .25996 L
.02633 .26496 L
.02722 .27028 L
.0294 .27982 L
.03298 .29108 L
.03714 .30118 L
.04915 .32276 L
.06612 .3447 L
.08395 .36255 L
.10689 .38107 L
.13524 .39954 L
.16953 .41752 L
.24028 .44471 L
.2812 .45609 L
.32095 .46478 L
.36624 .47224 L
.38964 .47517 L
.41581 .47775 L
.42697 .47864 L
.43878 .47943 L
.44902 .48001 L
.45998 .48051 L
.46619 .48074 L
.47184 .48092 L
.48289 .48118 L
.48908 .48127 L
.4958 .48132 L
.50215 .48134 L
.50801 .48131 L
.5184 .48119 L
Mistroke
.52811 .48097 L
.53876 .48063 L
.55019 .48014 L
.57339 .47874 L
.59447 .47698 L
.63588 .47215 L
.67886 .46504 L
.71797 .4565 L
.75193 .44724 L
.78987 .43451 L
.82785 .41863 L
.86022 .40184 L
.88726 .38465 L
.91157 .36561 L
.93047 .34718 L
.94762 .32568 L
.95534 .31332 L
.9613 .30169 L
.96597 .29027 L
.96972 .27801 L
.97117 .27162 L
.97222 .26561 L
.97269 .26216 L
.97303 .259 L
.97331 .25553 L
.9735 .25187 L
.97358 .24616 L
.97337 .24008 L
.97289 .23434 L
.97221 .22913 L
.97114 .22302 L
.96963 .21642 L
.96597 .20453 L
.96162 .19384 L
.95589 .18252 L
.9428 .16257 L
.92279 .13989 L
.90051 .12037 L
.87356 .10147 L
.84013 .08269 L
.76982 .05386 L
.72912 .04178 L
.68879 .03233 L
.65118 .02545 L
.6094 .01977 L
.5872 .01752 L
.56266 .01563 L
.55021 .01491 L
.53685 .0143 L
.53036 .01407 L
Mistroke
.52422 .01389 L
.5127 .01366 L
.50185 .01355 L
.49035 .01357 L
.48052 .01368 L
.46971 .01392 L
.45812 .0143 L
.44568 .01486 L
.42328 .01627 L
.40101 .01817 L
.37749 .02076 L
.33595 .02686 L
.28828 .03649 L
.24712 .04744 L
.21034 .0597 L
.17335 .07496 L
.1417 .09106 L
.11507 .10755 L
.09031 .12635 L
.07094 .14461 L
.05323 .16594 L
.04517 .17823 L
.03889 .18981 L
.034 .20096 L
.02983 .21341 L
.02818 .2199 L
.02694 .22603 L
.02598 .23251 L
.02559 .23616 L
.02532 .23951 L
.02509 .24526 L
.02511 .2506 L
.02541 .25646 L
.0257 .25974 L
.02604 .26272 L
.02695 .26873 L
.02827 .27523 L
.03155 .28695 L
.0356 .29765 L
.041 .30902 L
.05353 .32907 L
.07288 .35191 L
.09461 .37162 L
.12101 .39073 L
.1539 .40978 L
.22343 .43916 L
.26372 .45152 L
.30375 .46124 L
.34114 .46836 L
.38275 .47433 L
Mistroke
.40486 .47672 L
.42934 .47877 L
.44175 .47957 L
.45509 .48026 L
.46157 .48053 L
.46771 .48075 L
.47923 .48107 L
.49007 .48124 L
.50157 .4813 L
.5114 .48124 L
.52223 .48108 L
.53382 .48077 L
.54033 .48054 L
.54629 .48029 L
.56876 .47903 L
.59071 .4773 L
.61047 .47531 L
.65407 .46938 L
.69327 .46211 L
.72891 .4537 L
.80287 .42946 L
.84008 .41269 L
.87099 .3954 L
.89596 .37831 L
.91923 .35863 L
.93621 .34065 L
.95123 .32021 L
.95853 .30742 L
.96403 .29539 L
.96813 .28375 L
.96979 .27775 L
.97125 .27126 L
.97226 .26543 L
.97293 .26006 L
.97336 .25493 L
.97358 .24952 L
.97353 .24357 L
.97324 .23804 L
.97262 .23197 L
.97214 .22858 L
.97162 .2255 L
.96924 .2149 L
.96553 .20331 L
.96048 .19136 L
.95465 .18032 L
.94167 .16108 L
.92416 .14123 L
.89925 .11936 L
.87143 .10012 L
.84039 .08279 L
Mistroke
.80942 .0686 L
.73935 .04453 L
.69751 .03415 L
.65637 .02627 L
.617 .02063 L
.58003 .01687 L
.56047 .01546 L
.5492 .01483 L
.53889 .01435 L
.52798 .01397 L
.51627 .01369 L
.50541 .01355 L
.49511 .01352 L
.48494 .01359 L
.47398 .01379 L
.46364 .01408 L
.45418 .01444 L
.43228 .01562 L
.42131 .01639 L
.40937 .01738 L
.38691 .01963 L
.36319 .02262 L
.32139 .02947 L
.28087 .03826 L
.24432 .04827 L
.18137 .07136 L
.15149 .08573 L
.12172 .10313 L
.09611 .12158 L
.07265 .14284 L
.05474 .16387 L
.04196 .18388 L
.03706 .19372 L
.03266 .20457 L
.02942 .21491 L
.02722 .22457 L
.02624 .23056 L
.02586 .23358 L
.02553 .23689 L
.02517 .24277 L
.02508 .24824 L
.02515 .25157 L
.0253 .25471 L
.0258 .2606 L
.0262 .26389 L
.02665 .26692 L
.02795 .27377 L
.03074 .28435 L
.03488 .29591 L
.04039 .30782 L
Mistroke
.04664 .31881 L
.06122 .33897 L
.07767 .35666 L
.12483 .39316 L
.15279 .40919 L
.18568 .42469 L
.25178 .44812 L
.29589 .45949 L
.33947 .46806 L
.3799 .47396 L
.40311 .47653 L
.42469 .4784 L
.43582 .47918 L
.4464 .47981 L
.45603 .48028 L
.4663 .48069 L
.47745 .48101 L
.48779 .48119 L
.49892 .48128 L
.50526 .48127 L
.51121 .48123 L
.52112 .48108 L
.53154 .48082 L
.54044 .48051 L
.55015 .48009 L
.57179 .4788 L
.5918 .47718 L
.61527 .47475 L
.63719 .47192 L
.67738 .46529 L
.71912 .45618 L
.76215 .44406 L
.82867 .41824 L
.86197 .40083 L
.88975 .38289 L
.91469 .36285 L
.93457 .34258 L
.94387 .33097 L
.95261 .318 L
.9593 .30591 L
.96434 .29463 L
.96838 .28294 L
.97005 .27674 L
.97146 .27018 L
.9724 .26445 L
.97304 .25909 L
.97346 .25321 L
.97358 .24991 L
.9736 .2469 L
.97345 .24134 L
Mistroke
.97309 .23619 L
.97244 .23056 L
.97146 .22459 L
.96917 .21461 L
.96568 .20369 L
.96051 .1914 L
.95465 .18031 L
.93766 .15604 L
.91846 .13569 L
.89423 .11555 L
.83993 .08255 L
.80461 .06661 L
.76989 .05384 L
.73543 .04342 L
.69622 .03385 L
.6577 .02647 L
.62116 .02112 L
.6003 .01874 L
.58032 .01688 L
.56923 .01603 L
.55711 .01525 L
.54593 .01465 L
.5358 .01422 L
.52532 .01388 L
.51545 .01366 L
.50503 .01353 L
.49377 .01351 L
.48388 .01359 L
.47346 .01379 L
.46457 .01404 L
.45485 .0144 L
.4425 .015 L
.43086 .0157 L
.40917 .01738 L
.38602 .01972 L
.3612 .02289 L
.3175 .03021 L
.27862 .03881 L
.24241 .04886 L
.20561 .06146 L
.14588 .08874 L
.11444 .108 L
.08848 .12794 L
.0687 .14703 L
.05113 .16896 L
.04403 .18019 L
.0376 .19255 L
.03273 .20439 L
.0293 .21539 L
.02707 .22541 L
Mistroke
.02617 .23112 L
.02557 .23646 L
.0252 .24211 L
.02509 .24725 L
.02522 .25319 L
.02562 .25881 L
.02628 .26439 L
.02729 .27053 L
.02869 .27693 L
.03031 .28291 L
.03393 .29351 L
.03888 .30481 L
.05413 .32986 L
.07279 .35179 L
.0934 .37061 L
.11907 .38943 L
.17392 .41949 L
.21228 .43518 L
.25136 .44799 L
.2882 .4577 L
.33056 .46649 L
.35097 .46992 L
.37323 .4731 L
.3927 .47544 L
.41414 .47753 L
.42675 .47855 L
.43848 .47934 L
.45067 .48002 L
.46174 .48051 L
.47266 .48087 L
.48295 .48111 L
.49383 .48124 L
.50558 .48126 L
.51589 .48116 L
.5255 .48098 L
.53603 .48067 L
.54729 .48022 L
.55908 .47961 L
.5702 .47891 L
.59093 .47726 L
.6278 .47319 L
.66696 .46719 L
.70705 .45906 L
.74312 .4498 L
.78371 .43675 L
.81833 .42294 L
.87996 .38965 L
.90682 .36969 L
.93053 .34714 L
.9476 .32573 L
Mistroke
.95948 .30557 L
.96454 .29415 L
.96675 .28809 L
.96876 .28164 L
.97024 .27598 L
.97155 .26973 L
.97247 .26404 L
.97308 .25871 L
.97346 .25341 L
.97361 .24764 L
.9735 .2422 L
.97318 .23716 L
.97271 .23263 L
.97201 .22765 L
.97105 .22245 L
.96994 .21758 L
.96673 .20664 L
.96291 .1967 L
.95128 .17473 L
.93631 .15442 L
.91635 .13373 L
.87076 .09968 L
.83735 .08125 L
.80236 .06569 L
.7687 .05344 L
.72928 .04176 L
.69175 .03289 L
.64981 .02518 L
.62609 .02175 L
.60411 .01913 L
.58153 .01698 L
.5604 .01544 L
.54096 .01442 L
.53007 .01401 L
.52018 .01375 L
.50928 .01356 L
.49749 .01349 L
.48636 .01356 L
.47612 .01372 L
.46651 .01397 L
.45755 .01428 L
.43724 .01529 L
.41755 .01667 L
.3966 .01858 L
.35095 .0244 L
.30995 .03172 L
.26675 .04187 L
.2234 .05504 L
.15794 .0824 L
.12551 .10072 L
Mistroke
.0987 .11954 L
.07576 .13971 L
.05805 .15954 L
.04349 .18115 L
.03746 .19287 L
.03232 .20557 L
.029 .21657 L
.02757 .22281 L
.02654 .22858 L
.02587 .23364 L
.02536 .23921 L
.02511 .24503 L
.02513 .25047 L
.02538 .25577 L
.02583 .26079 L
.02641 .26529 L
.02723 .27018 L
.02979 .28109 L
.03303 .29112 L
.03808 .30314 L
.04379 .31401 L
.06032 .33784 L
.07895 .35786 L
.10251 .37776 L
.15215 .40883 L
.18473 .42426 L
.21763 .43709 L
.25523 .4491 L
.29845 .46004 L
.34116 .46833 L
.36206 .47157 L
.3819 .47419 L
.41936 .47797 L
.43946 .4794 L
.45081 .48002 L
.46121 .48048 L
.47203 .48085 L
.48209 .48109 L
.49314 .48123 L
.50492 .48126 L
.51615 .48115 L
.52673 .48094 L
.53622 .48066 L
.54647 .48025 L
.56749 .47909 L
.58989 .47735 L
.61086 .47524 L
.6298 .47293 L
.67521 .46569 L
.71668 .45678 L
Mistroke
.75746 .44553 L
.79303 .43331 L
.82902 .41808 L
.86416 .39955 L
.89161 .38155 L
.91364 .3638 L
.93274 .34468 L
.94739 .32606 L
.95984 .30483 L
.96485 .29335 L
.96896 .28095 L
.97055 .27465 L
.9719 .2678 L
.97239 .26465 L
.97281 .26131 L
.97335 .25531 L
.97359 .24956 L
.97357 .24417 L
.97327 .23826 L
.97298 .23495 L
.97263 .23192 L
.97172 .22594 L
.9706 .22033 L
.9678 .2099 L
.96378 .19877 L
.95828 .1869 L
.94536 .16598 L
.93018 .14747 L
.91004 .12812 L
.88399 .10825 L
.85293 .08933 L
.82006 .07315 L
.78617 .0595 L
.74663 .04657 L
.71188 .03739 L
.6719 .02896 L
.62717 .02189 L
.60213 .01891 L
.57837 .01671 L
.56751 .0159 L
.55605 .01517 L
.54612 .01465 L
.53549 .0142 L
.52399 .01383 L
.51329 .01361 L
.50674 .01353 L
.50055 .0135 L
.48899 .01353 L
.47867 .01367 L
.46759 .01393 L
Mistroke
.45716 .0143 L
.44764 .01472 L
.42446 .01614 L
.40263 .01798 L
.35989 .02307 L
.33621 .02679 L
.31465 .03077 L
.24352 .04852 L
.21015 .05976 L
.17569 .0739 L
.14465 .08943 L
.11524 .10745 L
.0928 .12429 L
.07208 .14344 L
.05377 .16523 L
.04065 .18637 L
.03456 .19962 L
.03211 .20619 L
.03017 .2123 L
.02871 .21776 L
.02738 .22379 L
.02635 .22986 L
.02592 .2332 L
.02559 .23632 L
.02521 .24212 L
.02511 .24536 L
.0251 .24829 L
.02527 .25402 L
.02569 .2594 L
.02603 .26246 L
.02647 .26569 L
.02748 .27146 L
.02887 .27765 L
.03077 .28441 L
.03478 .29563 L
.04024 .30751 L
.0531 .32843 L
.07051 .3494 L
.09058 .36826 L
.13691 .40044 L
.16506 .41532 L
.199 .43013 L
.23467 .44285 L
.27561 .4546 L
.31571 .46367 L
.35385 .47035 L
.39127 .47527 L
.41036 .47719 L
.43141 .47887 L
.44232 .47956 L
Mistroke
.4539 .48017 L
.45996 .48043 L
.46663 .48068 L
.47839 .48101 L
.48948 .4812 L
.49571 .48125 L
.5014 .48126 L
.51245 .4812 L
.52293 .48103 L
.53294 .48076 L
.54359 .48037 L
.56267 .47939 L
.58523 .47775 L
.6055 .47582 L
.65022 .46998 L
.69698 .46131 L
.7392 .4509 L
.77596 .43949 L
.80942 .42677 L
.84255 .41144 L
.89419 .37965 L
.92 .35792 L
.94002 .33601 L
.95416 .31542 L
.96049 .3035 L
.96524 .29232 L
.96889 .2812 L
.97133 .27094 L
.97226 .26554 L
.973 .25962 L
.97326 .25663 L
.97346 .25344 L
.97361 .24769 L
.9735 .24224 L
.97311 .23634 L
.97248 .23078 L
.97167 .22566 L
.96955 .21601 L
.96647 .20588 L
.96207 .19477 L
.9562 .18301 L
.94265 .16232 L
.92177 .13883 L
.89843 .11869 L
.87323 .10121 L
.84307 .08412 L
.78116 .05769 L
.74313 .04556 L
.70541 .03588 L
.6622 .02722 L
Mistroke
.63904 .02354 L
.61389 .02022 L
.59129 .01783 L
.57055 .01611 L
.5605 .01544 L
.54956 .01482 L
.53929 .01434 L
.52965 .01399 L
.51844 .0137 L
.51248 .0136 L
.50608 .01353 L
.49938 .01349 L
.49302 .0135 L
.48731 .01354 L
.48109 .01362 L
.46984 .01387 L
.46356 .01406 L
.45787 .01427 L
.43641 .01534 L
.42471 .01612 L
.4124 .01709 L
.39051 .01922 L
.34201 .02581 L
.30144 .03351 L
.25879 .04405 L
.21926 .05648 L
.1843 .07009 L
.12645 .10013 L
.09905 .11927 L
.07723 .13827 L
.05742 .16036 L
.04895 .17222 L
.04139 .18497 L
.03629 .19549 L
.03179 .20714 L
.03017 .2123 L
.02869 .21783 L
.02753 .22303 L
.02667 .22783 L
.02584 .2339 L
.02553 .2371 L
.02529 .24049 L
.0251 .24619 L
.02511 .24943 L
.0252 .25245 L
.02557 .25809 L
.02613 .26323 L
.02705 .26914 L
.02818 .27474 L
.03091 .28485 L
Mistroke
.03474 .29552 L
.04399 .31436 L
.05888 .33606 L
.07586 .35486 L
.09777 .37411 L
.12465 .39302 L
.18146 .42284 L
.21736 .437 L
.25317 .4485 L
.2947 .45919 L
.34128 .46834 L
.36318 .47172 L
.38675 .47476 L
.40736 .47691 L
.42972 .47875 L
.4423 .47956 L
.45385 .48017 L
.46549 .48064 L
.47658 .48097 L
.4828 .4811 L
.48943 .4812 L
.4957 .48125 L
.50138 .48126 L
.50808 .48124 L
.51532 .48116 L
.52216 .48104 L
.52845 .48089 L
.53883 .48056 L
.54994 .48009 L
.56992 .47892 L
.59352 .47701 L
.61485 .47479 L
.66036 .46833 L
.70208 .46019 L
.73857 .45108 L
.77683 .43919 L
.81173 .4258 L
.84634 .40948 L
.87543 .39261 L
.89919 .37584 L
.92049 .35745 L
.93692 .33983 L
.9518 .31934 L
.95797 .30854 L
.96353 .29667 L
.9676 .28553 L
.96906 .2806 L
.97043 .27517 L
.97144 .27037 L
.97231 .26521 L
Mistroke
.97299 .25974 L
.9734 .25462 L
.97354 .25152 L
.97361 .24822 L
.97351 .24228 L
.9733 .23864 L
.97301 .23522 L
.97266 .23216 L
.9722 .22885 L
.9711 .22267 L
.9696 .21618 L
.96603 .20463 L
.96154 .19358 L
.95642 .18341 L
.94156 .1609 L
.92297 .14001 L
.89836 .11864 L
.87309 .10112 L
.84291 .08404 L
.81305 .0701 L
.77744 .05639 L
.7089 .03669 L
.66842 .02832 L
.64575 .02454 L
.62435 .02151 L
.5858 .01734 L
.56517 .01574 L
.55442 .01508 L
.54303 .0145 L
.53706 .01425 L
.5305 .01402 L
.51895 .01371 L
.51243 .0136 L
.50544 .01352 L
.49884 .01349 L
.49282 .0135 L
.48117 .01362 L
.47459 .01375 L
.4685 .01391 L
.45734 .01429 L
.4455 .01483 L
.42397 .01617 L
.40387 .01786 L
.3587 .02324 L
.31919 .02988 L
.27748 .0391 L
.23606 .05085 L
.19984 .0637 L
.14168 .09108 L
.11347 .10867 L
Mistroke
.09084 .12593 L
.0702 .14542 L
.05237 .16719 L
.04058 .18651 L
.03533 .19774 L
.03138 .20837 L
.02962 .21426 L
.02802 .22072 L
.02683 .22684 L
.026 .23253 L
.02544 .23818 L
.02516 .2433 L
.02511 .24922 L
.02532 .25478 L
.02584 .26087 L
.02622 .26393 L
.02673 .26729 L
.02915 .27873 L
.031 .28514 L
.03335 .29197 L
.03858 .30417 L
.05242 .32747 L
.06932 .34813 L
.09219 .3696 L
.12114 .39077 L
.17938 .42193 L
.21727 .43696 L
.25549 .44917 L
.29579 .45944 L
.33491 .46725 L
.37705 .47358 L
.39977 .47617 L
.4243 .47835 L
.44548 .47974 L
.45747 .48033 L
.46855 .48074 L
.47827 .48101 L
.48896 .48119 L
.50013 .48126 L
.51058 .48122 L
.52075 .48107 L
.53039 .48084 L
.53903 .48055 L
.54844 .48016 L
.56943 .47895 L
.58877 .47744 L
.61199 .47511 L
.63309 .47248 L
.67964 .46485 L
.71915 .45617 L
Mistroke
.7589 .44509 L
.82209 .42127 L
.85405 .40533 L
.88093 .38901 L
.90632 .37012 L
.92963 .34812 L
.94732 .32616 L
.95421 .31536 L
.95973 .30506 L
.96423 .29494 L
.96759 .28557 L
.97045 .2751 L
.97164 .26929 L
.97251 .26375 L
.97311 .25843 L
.9735 .25274 L
.97361 .24737 L
.97352 .24251 L
.97315 .23677 L
.97283 .23355 L
.97245 .23058 L
.97158 .22513 L
.97038 .21938 L
.9671 .20772 L
.96295 .19677 L
.95248 .17664 L
.93739 .15569 L
.91665 .13399 L
.89509 .11616 L
.86884 .09849 L
.8139 .07046 L
.77967 .05716 L
.74621 .04645 L
.70829 .03654 L
.6649 .02769 L
.62569 .02169 L
.58836 .01756 L
.56745 .01589 L
.54833 .01475 L
.53771 .01428 L
.52616 .01389 L
.51525 .01364 L
.50517 .01352 L
.494 .0135 L
.4834 .01359 L
.47389 .01377 L
.46352 .01406 L
.45231 .0145 L
.44039 .01511 L
.41904 .01655 L
Mistroke
.39754 .01848 L
.37748 .02073 L
.34061 .02604 L
.29773 .03432 L
.25992 .04373 L
.22086 .05592 L
.18191 .07113 L
.14909 .08701 L
.12203 .10295 L
.07778 .13773 L
.05852 .15895 L
.05005 .17056 L
.04238 .18314 L
.03682 .19429 L
.03192 .20676 L
.03018 .21227 L
.0286 .21822 L
.02739 .22378 L
.02648 .22904 L
.02574 .23489 L
.02531 .2402 L
.0251 .24593 L
.02511 .24916 L
.02519 .25213 L
.02548 .2571 L
.02604 .26256 L
.02689 .26824 L
.02792 .27354 L
.03117 .28568 L
.0352 .29665 L
.04111 .30915 L
.04793 .32081 L
.06489 .34324 L
.08452 .363 L
.11016 .38334 L
.14179 .40322 L
.20958 .43417 L
.25265 .44835 L
.29474 .4592 L
.3334 .46699 L
.37716 .4736 L
.39967 .47616 L
.42401 .47833 L
.4359 .47917 L
.44717 .47983 L
.45821 .48036 L
.46834 .48074 L
.47857 .48101 L
.48959 .4812 L
.4998 .48126 L
Mistroke
.50951 .48123 L
.52076 .48107 L
.53119 .48082 L
.54262 .48041 L
.55478 .47984 L
.57934 .47823 L
.60228 .47616 L
.64451 .47085 L
.68331 .46413 L
.71784 .4565 L
.79049 .43427 L
.82284 .42093 L
.85471 .40496 L
.90384 .37215 L
.92795 .34992 L
.94632 .3276 L
.9589 .30673 L
.96434 .29468 L
.96826 .28339 L
.96976 .27797 L
.97107 .27224 L
.97199 .26728 L
.97274 .26197 L
.97329 .25623 L
.97356 .25088 L
.97362 .24761 L
.97358 .24452 L
.97331 .23875 L
.97284 .23366 L
.97212 .22828 L
.97131 .2237 L
.97022 .21867 L
.96704 .20753 L
.96313 .1972 L
.95089 .17411 L
.93577 .15377 L
.91385 .13146 L
.88886 .11163 L
.8329 .07908 L
.79676 .06348 L
.76144 .05108 L
.72639 .041 L
.68671 .03183 L
.64781 .02486 L
.6111 .0199 L
.58956 .01767 L
.56978 .01606 L
.55879 .01533 L
.54681 .01468 L
.53546 .01419 L
Mistroke
.52497 .01386 L
.5153 .01364 L
.50622 .01353 L
.49627 .01349 L
.48555 .01356 L
.47491 .01374 L
.46374 .01405 L
.45421 .01442 L
.44382 .01492 L
.41977 .01649 L
.39811 .01842 L
.37336 .02125 L
.35034 .02449 L
.31027 .03165 L
.26856 .04139 L
.19791 .06446 L
.16188 .08043 L
.13136 .09711 L
.1033 .11601 L
.08031 .13532 L
.05848 .15901 L
.05002 .1706 L
.04317 .18172 L
.03767 .19242 L
.03349 .20236 L
.02983 .21351 L
.02832 .2194 L
.02704 .22564 L
.02616 .23131 L
.02551 .23739 L
.02517 .24314 L
.0251 .24837 L
.02531 .25451 L
.02556 .25797 L
.02588 .26116 L
.02668 .26702 L
.02785 .27321 L
.03041 .28324 L
.03411 .29393 L
.04318 .31294 L
.05792 .33484 L
.07501 .35402 L
.09617 .37283 L
.12236 .39156 L
.17805 .42134 L
.21695 .43685 L
.2564 .44943 L
.29353 .45893 L
.33604 .46745 L
.3567 .47078 L
Mistroke
.37917 .47385 L
.39881 .47607 L
.42036 .47804 L
.43308 .47898 L
.44488 .47971 L
.45597 .48026 L
.46187 .48051 L
.46823 .48073 L
.4792 .48103 L
.48951 .4812 L
.50132 .48126 L
.51214 .4812 L
.52176 .48105 L
.53202 .48079 L
.54169 .48045 L
.55046 .48006 L
.5719 .47878 L
.59201 .47715 L
.63154 .47269 L
.67333 .46604 L
.71343 .45757 L
.74936 .44799 L
.7897 .43456 L
.82392 .42044 L
.88463 .3865 L
.91209 .36519 L
.93378 .34351 L
.95024 .3218 L
.96146 .30142 L
.96614 .28989 L
.96814 .28378 L
.96993 .27731 L
.9712 .2716 L
.97229 .26534 L
.973 .25963 L
.97342 .2543 L
.97361 .24896 L
.97354 .24317 L
.97323 .2377 L
.97273 .23266 L
.97209 .22813 L
.9712 .22314 L
.96876 .2131 L
.96518 .2023 L
.96024 .1908 L
.9485 .17047 L
.93089 .14823 L
.91064 .12864 L
.88438 .10851 L
.85204 .08884 L
Mistroke
.81743 .07199 L
.78181 .05792 L
.70861 .03662 L
.67046 .02869 L
.62713 .02188 L
.60485 .0192 L
.58068 .0169 L
.56889 .01599 L
.55768 .01526 L
.54767 .01472 L
.53658 .01424 L
.52635 .01389 L
.51673 .01367 L
.50657 .01353 L
.4956 .01349 L
.48596 .01356 L
.47581 .01372 L
.46715 .01395 L
.45768 .01427 L
.44646 .01478 L
.43628 .01535 L
.41354 .017 L
.39264 .01899 L
.37309 .02128 L
.33366 .02723 L
.29167 .03569 L
.24979 .04664 L
.21279 .05879 L
.15304 .08492 L
.12367 .10189 L
.09976 .11871 L
.078 .13752 L
.0587 .15873 L
.04436 .17965 L
.03473 .1992 L
.03043 .21143 L
.02759 .22277 L
.02652 .22873 L
.02605 .23216 L
.0257 .23529 L
.02541 .2386 L
.02521 .24214 L
.02511 .24543 L
.0251 .24854 L
.02529 .25419 L
.02577 .26017 L
.02641 .26528 L
.02737 .27089 L
.02869 .27689 L
.03044 .28333 L
Mistroke
.03448 .29488 L
.03934 .30571 L
.04561 .31709 L
.05968 .33705 L
.08088 .35967 L
.10412 .37896 L
.13221 .39767 L
.16664 .41607 L
.20234 .43142 L
.23834 .44402 L
.27662 .45485 L
.31321 .46316 L
.35536 .47058 L
.37941 .47388 L
.40198 .47639 L
.42399 .47833 L
.44758 .47985 L
.45984 .48043 L
.47138 .48083 L
.478 .481 L
.48407 .48112 L
.49074 .48121 L
.49777 .48126 L
.5087 .48123 L
.52038 .48108 L
.5314 .48081 L
.54141 .48046 L
.55314 .47993 L
.56585 .47919 L
.58881 .47744 L
.60935 .47541 L
.63123 .47274 L
.67001 .46664 L
.71455 .4573 L
.7534 .44678 L
.79142 .43392 L
.8298 .41771 L
.88984 .38283 L
.91528 .36233 L
.9353 .34175 L
.94985 .3224 L
.96177 .30073 L
.96638 .28921 L
.97014 .27643 L
.97152 .26995 L
.97213 .26638 L
.97261 .26299 L
.97298 .25983 L
.97328 .2564 L
.97358 .25039 L
Mistroke
.97359 .24479 L
.97348 .24161 L
.9733 .23862 L
.97272 .23261 L
.97226 .22924 L
.97176 .22615 L
.96937 .2153 L
.9678 .20987 L
.9658 .20397 L
.96103 .19249 L
.95463 .18023 L
.93976 .1586 L
.92141 .13848 L
.90127 .12091 L
.84496 .08509 L
.81162 .06949 L
.77162 .0544 L
.73198 .04247 L
.69232 .033 L
.65534 .02606 L
.61385 .02022 L
.58981 .0177 L
.56783 .01592 L
.55557 .01514 L
.54229 .01447 L
.53617 .01422 L
.52972 .014 L
.51815 .0137 L
.50745 .01354 L
.49599 .01349 L
.48518 .01357 L
.47534 .01373 L
.46379 .01405 L
.45728 .01429 L
.45128 .01455 L
.42862 .01584 L
.40724 .01755 L
.38782 .01952 L
.3448 .02536 L
.30794 .03213 L
.27057 .04086 L
.19714 .06477 L
.15997 .08139 L
.1288 .09867 L
.10179 .11716 L
.07675 .13874 L
.05739 .16041 L
.04344 .18125 L
.03415 .20066 L
.0303 .21186 L
Mistroke
.02766 .2224 L
.02662 .22813 L
.02588 .23358 L
.02542 .23848 L
.02515 .24381 L
.02512 .24961 L
.02521 .25253 L
.02539 .25576 L
.02591 .26146 L
.02665 .2668 L
.02764 .27222 L
.02897 .278 L
.03206 .28836 L
.03689 .30054 L
.04236 .31147 L
.05775 .33462 L
.0765 .35549 L
.11899 .38937 L
.14779 .40651 L
.17715 .42093 L
.20926 .43405 L
.24622 .44644 L
.27995 .45569 L
.31836 .46419 L
.34233 .46852 L
.36497 .47198 L
.38876 .47498 L
.41056 .47721 L
.43221 .47892 L
.45272 .48011 L
.46404 .48059 L
.47447 .48091 L
.48593 .48115 L
.4917 .48122 L
.49804 .48126 L
.50879 .48123 L
.51872 .48111 L
.52962 .48086 L
.54117 .48047 L
.55115 .48003 L
.5605 .47952 L
.58171 .47804 L
.60062 .47633 L
.61781 .47444 L
.65593 .46906 L
.69333 .46209 L
.73268 .45269 L
.80576 .42829 L
Mfstroke
.92298 .35544 m
.94043 .33595 L
.95352 .31705 L
.95951 .30613 L
.96423 .29566 L
.96851 .28346 L
.96999 .27815 L
.97133 .27227 L
.97238 .26652 L
.9731 .26112 L
.97361 .25541 L
.97386 .24926 L
.97382 .24357 L
.97353 .23816 L
.97307 .23331 L
.97234 .22802 L
.97117 .22173 L
.96983 .21605 L
.96586 .2034 L
.961 .19182 L
.95539 .18107 L
.94022 .15881 L
.91957 .13644 L
.89838 .11844 L
.87159 .10002 L
.83892 .08192 L
.79994 .06468 L
.76013 .05068 L
.72088 .03966 L
.68089 .03078 L
.63677 .02337 L
.61341 .02035 L
.59121 .01803 L
.56663 .01606 L
.55273 .01522 L
.53994 .01461 L
.52951 .01424 L
.51835 .01396 L
.50782 .01381 L
.49824 .01376 L
.48696 .01382 L
.48061 .01391 L
.47475 .01403 L
.464 .01434 L
.45263 .01478 L
.44177 .01533 L
.43014 .01605 L
.40923 .01768 L
.38459 .0202 L
.36234 .02305 L
Mistroke
.32197 .02968 L
.2805 .03867 L
.21107 .05974 L
.17256 .07564 L
.13964 .09254 L
.11331 .10907 L
.088 .12865 L
.067 .1492 L
.0511 .16935 L
.03833 .19144 L
.03304 .2041 L
.03113 .20975 L
.0294 .21577 L
.02815 .22095 L
.02703 .22669 L
.02626 .23191 L
.02573 .23682 L
.02537 .2426 L
.02527 .24789 L
.02544 .25369 L
.02591 .25979 L
.02652 .26478 L
.0274 .27009 L
.02957 .27962 L
.03313 .29086 L
.03726 .30096 L
.04923 .32252 L
.06616 .34445 L
.08394 .36231 L
.10684 .38083 L
.13514 .39932 L
.1694 .41734 L
.24009 .4446 L
.28098 .45602 L
.32073 .46475 L
.36602 .47226 L
.38942 .47521 L
.4156 .47782 L
.42676 .47871 L
.43857 .47952 L
.44881 .4801 L
.45978 .48062 L
.46599 .48085 L
.47164 .48103 L
.4827 .4813 L
.4889 .48139 L
.49562 .48145 L
.50198 .48147 L
.50784 .48145 L
.51823 .48133 L
Mistroke
.52795 .48113 L
.53861 .48079 L
.55004 .48031 L
.57326 .47892 L
.59435 .47717 L
.63581 .47235 L
.67882 .46525 L
.71797 .4567 L
.75197 .44744 L
.78994 .4347 L
.82796 .41879 L
.86036 .40198 L
.88743 .38475 L
.91175 .36568 L
.93065 .34721 L
.94781 .32567 L
.95553 .31329 L
.96149 .30165 L
.96615 .2902 L
.96989 .27792 L
.97133 .27153 L
.97238 .26551 L
.97285 .26206 L
.97319 .25889 L
.97347 .25541 L
.97365 .25175 L
.97372 .24604 L
.97351 .23995 L
.97302 .2342 L
.97234 .22899 L
.97126 .22287 L
.96974 .21627 L
.96606 .20437 L
.9617 .19367 L
.95596 .18235 L
.94283 .16239 L
.92279 .13971 L
.90048 .1202 L
.87349 .10131 L
.84003 .08255 L
.76968 .05378 L
.72897 .04173 L
.68863 .03231 L
.65102 .02546 L
.60924 .01981 L
.58704 .01758 L
.56251 .0157 L
.55006 .01499 L
.53671 .01439 L
.53022 .01416 L
Mistroke
.52408 .01399 L
.51257 .01376 L
.50173 .01366 L
.49023 .01368 L
.48041 .0138 L
.4696 .01404 L
.45802 .01443 L
.44558 .01499 L
.42319 .0164 L
.40094 .01832 L
.37743 .02091 L
.33593 .02701 L
.28829 .03664 L
.24716 .04758 L
.2104 .05983 L
.17344 .07508 L
.14181 .09115 L
.1152 .10762 L
.09045 .1264 L
.07108 .14463 L
.05336 .16593 L
.0453 .1782 L
.03902 .18977 L
.03413 .20091 L
.02995 .21334 L
.0283 .21983 L
.02706 .22595 L
.02609 .23243 L
.0257 .23607 L
.02543 .23942 L
.02519 .24516 L
.02521 .2505 L
.0255 .25636 L
.02579 .25964 L
.02613 .26261 L
.02703 .26862 L
.02834 .27511 L
.03162 .28683 L
.03565 .29753 L
.04105 .30889 L
.05355 .32893 L
.07287 .35178 L
.09457 .3715 L
.12095 .39062 L
.15382 .40969 L
.22332 .4391 L
.2636 .45148 L
.30363 .46123 L
.34101 .46838 L
.38264 .47436 L
Mistroke
.40475 .47676 L
.42923 .47882 L
.44165 .47963 L
.45499 .48033 L
.46147 .4806 L
.46762 .48083 L
.47914 .48114 L
.48998 .48132 L
.50149 .48138 L
.51132 .48133 L
.52215 .48117 L
.53375 .48086 L
.54026 .48063 L
.54622 .48038 L
.5687 .47913 L
.59066 .4774 L
.61044 .47542 L
.65405 .4695 L
.69327 .46222 L
.72893 .4538 L
.80293 .42955 L
.84016 .41276 L
.87108 .39545 L
.89606 .37834 L
.91933 .35864 L
.93631 .34064 L
.95133 .32018 L
.95863 .30739 L
.96412 .29534 L
.96822 .2837 L
.96988 .27769 L
.97133 .2712 L
.97233 .26536 L
.97301 .26 L
.97343 .25486 L
.97365 .24944 L
.9736 .24349 L
.9733 .23796 L
.97268 .23189 L
.9722 .2285 L
.97168 .22542 L
.96928 .21481 L
.96557 .20322 L
.9605 .19126 L
.95467 .18022 L
.94168 .16098 L
.92414 .14114 L
.89922 .11928 L
.87138 .10004 L
.84033 .08273 L
Mistroke
.80935 .06855 L
.73927 .04451 L
.69742 .03415 L
.65628 .02628 L
.61692 .02066 L
.57996 .01692 L
.5604 .01551 L
.54913 .01488 L
.53882 .01441 L
.52791 .01403 L
.51621 .01375 L
.50535 .01361 L
.49506 .01358 L
.48489 .01366 L
.47393 .01386 L
.46359 .01415 L
.45413 .01451 L
.43224 .0157 L
.42128 .01647 L
.40934 .01745 L
.38689 .01971 L
.36318 .0227 L
.32139 .02955 L
.28089 .03834 L
.24435 .04835 L
.18142 .07142 L
.15155 .08577 L
.12179 .10316 L
.09618 .1216 L
.07272 .14284 L
.05482 .16386 L
.04203 .18385 L
.03713 .19368 L
.03273 .20453 L
.02948 .21487 L
.02728 .22452 L
.0263 .23051 L
.02591 .23353 L
.02558 .23684 L
.02522 .24271 L
.02513 .24818 L
.0252 .25151 L
.02534 .25465 L
.02584 .26054 L
.02624 .26382 L
.02669 .26686 L
.02798 .27371 L
.03076 .28428 L
.0349 .29584 L
.0404 .30775 L
Mistroke
.04665 .31874 L
.06122 .3389 L
.07766 .35659 L
.12479 .39311 L
.15274 .40914 L
.18562 .42465 L
.25171 .44811 L
.29582 .45949 L
.33941 .46808 L
.37985 .47399 L
.40306 .47656 L
.42463 .47844 L
.43576 .47922 L
.44635 .47985 L
.45599 .48033 L
.46625 .48073 L
.47741 .48105 L
.48775 .48124 L
.49888 .48133 L
.50522 .48132 L
.51117 .48128 L
.52108 .48113 L
.53151 .48088 L
.54041 .48057 L
.55013 .48015 L
.57177 .47886 L
.59178 .47724 L
.61526 .47481 L
.63719 .47198 L
.67739 .46534 L
.71914 .45624 L
.76218 .44411 L
.82871 .41827 L
.86202 .40085 L
.8898 .3829 L
.91474 .36285 L
.93462 .34258 L
.94392 .33096 L
.95266 .31797 L
.95935 .30589 L
.96438 .2946 L
.96843 .2829 L
.97009 .2767 L
.9715 .27014 L
.97244 .26441 L
.97307 .25905 L
.9735 .25317 L
.97361 .24987 L
.97363 .24686 L
.97348 .24129 L
Mistroke
.97312 .23615 L
.97246 .23051 L
.97149 .22454 L
.96919 .21456 L
.9657 .20364 L
.96051 .19135 L
.95466 .18025 L
.93765 .15599 L
.91844 .13564 L
.89421 .1155 L
.83989 .08252 L
.80457 .06659 L
.76984 .05383 L
.73538 .04342 L
.69617 .03386 L
.65765 .02649 L
.62112 .02115 L
.60026 .01876 L
.58028 .01691 L
.56919 .01606 L
.55708 .01528 L
.5459 .01468 L
.53577 .01425 L
.52529 .01392 L
.51542 .0137 L
.505 .01357 L
.49375 .01355 L
.48386 .01363 L
.47344 .01383 L
.46455 .01408 L
.45483 .01444 L
.44248 .01504 L
.43085 .01574 L
.40916 .01743 L
.38602 .01977 L
.3612 .02293 L
.31751 .03025 L
.27864 .03885 L
.24243 .04889 L
.20564 .06149 L
.14592 .08876 L
.11448 .108 L
.08852 .12794 L
.06874 .14702 L
.05117 .16894 L
.04407 .18017 L
.03764 .19252 L
.03277 .20436 L
.02933 .21537 L
.0271 .22538 L
Mistroke
.0262 .23109 L
.0256 .23643 L
.02522 .24207 L
.02511 .24722 L
.02524 .25316 L
.02564 .25878 L
.02629 .26435 L
.02731 .2705 L
.0287 .27689 L
.03032 .28287 L
.03394 .29347 L
.03888 .30477 L
.05412 .32982 L
.07278 .35176 L
.09339 .37058 L
.11904 .38941 L
.17388 .41947 L
.21225 .43517 L
.25133 .44799 L
.28817 .45771 L
.33052 .4665 L
.35094 .46993 L
.3732 .47312 L
.39267 .47546 L
.41412 .47756 L
.42672 .47857 L
.43846 .47937 L
.45065 .48005 L
.46172 .48054 L
.47264 .4809 L
.48294 .48114 L
.49381 .48127 L
.50556 .48129 L
.51588 .48119 L
.52549 .48101 L
.53602 .4807 L
.54728 .48025 L
.55907 .47964 L
.5702 .47894 L
.59093 .47729 L
.6278 .47323 L
.66697 .46722 L
.70706 .45909 L
.74313 .44982 L
.78373 .43678 L
.81836 .42296 L
.87999 .38965 L
.90685 .36969 L
.93056 .34713 L
.94763 .32572 L
Mistroke
.9595 .30555 L
.96456 .29413 L
.96677 .28807 L
.96878 .28162 L
.97026 .27596 L
.97157 .26971 L
.97248 .26402 L
.9731 .25869 L
.97347 .25339 L
.97362 .24762 L
.97351 .24217 L
.97319 .23713 L
.97272 .23261 L
.97201 .22762 L
.97106 .22242 L
.96995 .21755 L
.96674 .20662 L
.96291 .19667 L
.95127 .1747 L
.93631 .1544 L
.91634 .1337 L
.87074 .09966 L
.83732 .08124 L
.80233 .06569 L
.76868 .05343 L
.72925 .04177 L
.69173 .0329 L
.64979 .02519 L
.62607 .02176 L
.60409 .01915 L
.58151 .01699 L
.56038 .01546 L
.54095 .01444 L
.53005 .01403 L
.52016 .01377 L
.50927 .01358 L
.49748 .01352 L
.48635 .01358 L
.47612 .01374 L
.4665 .01399 L
.45755 .01431 L
.43724 .01532 L
.41755 .01669 L
.3966 .0186 L
.35095 .02442 L
.30996 .03174 L
.26676 .04189 L
.22342 .05505 L
.15796 .08241 L
.12553 .10072 L
Mistroke
.09872 .11954 L
.07578 .1397 L
.05807 .15954 L
.0435 .18114 L
.03747 .19286 L
.03233 .20556 L
.02901 .21656 L
.02758 .22279 L
.02655 .22856 L
.02588 .23362 L
.02537 .23919 L
.02512 .24501 L
.02514 .25045 L
.02539 .25575 L
.02584 .26077 L
.02642 .26527 L
.02724 .27016 L
.02979 .28107 L
.03303 .2911 L
.03808 .30312 L
.04378 .31399 L
.06031 .33783 L
.07894 .35785 L
.10249 .37775 L
.15213 .40883 L
.18471 .42426 L
.21761 .43709 L
.25521 .4491 L
.29844 .46005 L
.34115 .46834 L
.36204 .47158 L
.38188 .4742 L
.41935 .47798 L
.43945 .47941 L
.4508 .48004 L
.4612 .4805 L
.47202 .48087 L
.48208 .4811 L
.49313 .48125 L
.50492 .48127 L
.51615 .48117 L
.52673 .48096 L
.53621 .48067 L
.54646 .48027 L
.56748 .4791 L
.58989 .47736 L
.61086 .47526 L
.6298 .47294 L
.67521 .4657 L
.71669 .4568 L
Mistroke
.75747 .44554 L
.79305 .43331 L
.82903 .41808 L
.86417 .39955 L
.89162 .38155 L
.91365 .3638 L
.93276 .34467 L
.9474 .32605 L
.95986 .30482 L
.96486 .29334 L
.96897 .28093 L
.97056 .27464 L
.9719 .26778 L
.97239 .26463 L
.97282 .26129 L
.97336 .2553 L
.9736 .24954 L
.97357 .24415 L
.97327 .23825 L
.97298 .23493 L
.97263 .23191 L
.97172 .22593 L
.9706 .22032 L
.9678 .20989 L
.96378 .19876 L
.95828 .18688 L
.94535 .16597 L
.93017 .14746 L
.91003 .12811 L
.88398 .10824 L
.85291 .08932 L
.82004 .07315 L
.78615 .0595 L
.74661 .04658 L
.71186 .0374 L
.67189 .02897 L
.62716 .0219 L
.60212 .01892 L
.57836 .01672 L
.5675 .01591 L
.55604 .01518 L
.54611 .01466 L
.53549 .01421 L
.52399 .01385 L
.51329 .01362 L
.50673 .01355 L
.50055 .01351 L
.48899 .01354 L
.47866 .01368 L
.46759 .01395 L
Mistroke
.45715 .01431 L
.44764 .01473 L
.42446 .01615 L
.40263 .01799 L
.3599 .02308 L
.33621 .0268 L
.31465 .03078 L
.24353 .04852 L
.21016 .05977 L
.1757 .0739 L
.14466 .08943 L
.11525 .10745 L
.09281 .12429 L
.07209 .14344 L
.05378 .16522 L
.04065 .18637 L
.03456 .19961 L
.03211 .20618 L
.03018 .21229 L
.02871 .21775 L
.02739 .22378 L
.02636 .22985 L
.02592 .23319 L
.0256 .23631 L
.02521 .2421 L
.02511 .24535 L
.0251 .24828 L
.02528 .25401 L
.02569 .25939 L
.02603 .26245 L
.02647 .26568 L
.02748 .27145 L
.02888 .27764 L
.03077 .2844 L
.03478 .29562 L
.04024 .30749 L
.05309 .32842 L
.0705 .34939 L
.09057 .36825 L
.1369 .40044 L
.16505 .41531 L
.19899 .43012 L
.23466 .44285 L
.2756 .45461 L
.31571 .46367 L
.35384 .47036 L
.39126 .47528 L
.41036 .4772 L
.4314 .47888 L
.44231 .47957 L
Mistroke
.45389 .48018 L
.45995 .48044 L
.46662 .48069 L
.47838 .48102 L
.48948 .48121 L
.49571 .48126 L
.5014 .48127 L
.51245 .48121 L
.52293 .48104 L
.53294 .48077 L
.54359 .48038 L
.56267 .4794 L
.58523 .47776 L
.6055 .47583 L
.65023 .46998 L
.69699 .46131 L
.73921 .45091 L
.77597 .43949 L
.80943 .42677 L
.84256 .41144 L
.8942 .37965 L
.92001 .35791 L
.94003 .336 L
.95417 .31542 L
.96049 .30349 L
.96525 .29231 L
.9689 .28119 L
.97133 .27093 L
.97226 .26553 L
.973 .25961 L
.97326 .25662 L
.97346 .25343 L
.97361 .24768 L
.97351 .24223 L
.97311 .23633 L
.97248 .23077 L
.97167 .22566 L
.96955 .216 L
.96647 .20587 L
.96207 .19476 L
.95619 .183 L
.94264 .16231 L
.92176 .13883 L
.89842 .11869 L
.87322 .10121 L
.84307 .08412 L
.78115 .05769 L
.74312 .04556 L
.70541 .03588 L
.6622 .02723 L
Mistroke
.63904 .02354 L
.61389 .02023 L
.59128 .01784 L
.57055 .01612 L
.5605 .01544 L
.54956 .01482 L
.53929 .01435 L
.52965 .014 L
.51843 .01371 L
.51248 .01361 L
.50608 .01353 L
.49938 .0135 L
.49302 .01351 L
.48731 .01355 L
.48108 .01363 L
.46984 .01388 L
.46356 .01407 L
.45787 .01427 L
.43641 .01535 L
.42471 .01613 L
.4124 .0171 L
.39051 .01922 L
.34202 .02582 L
.30144 .03351 L
.25879 .04405 L
.21926 .05648 L
.18431 .07009 L
.12646 .10012 L
.09906 .11926 L
.07723 .13826 L
.05742 .16036 L
.04895 .17222 L
.04139 .18496 L
.03629 .19549 L
.03179 .20713 L
.03017 .21229 L
.02869 .21782 L
.02754 .22302 L
.02667 .22782 L
.02584 .23389 L
.02553 .2371 L
.02529 .24048 L
.0251 .24618 L
.02511 .24942 L
.0252 .25245 L
.02557 .25808 L
.02613 .26322 L
.02704 .26914 L
.02818 .27474 L
.03091 .28485 L
Mistroke
.03473 .29551 L
.04399 .31436 L
.05888 .33606 L
.07585 .35485 L
.09777 .3741 L
.12465 .39302 L
.18145 .42284 L
.21736 .437 L
.25317 .4485 L
.2947 .4592 L
.34127 .46835 L
.36318 .47173 L
.38675 .47476 L
.40735 .47692 L
.42972 .47876 L
.4423 .47957 L
.45385 .48017 L
.46549 .48065 L
.47658 .48097 L
.4828 .4811 L
.48943 .4812 L
.4957 .48125 L
.50138 .48127 L
.50808 .48124 L
.51532 .48117 L
.52216 .48105 L
.52845 .4809 L
.53883 .48057 L
.54994 .48009 L
.56992 .47892 L
.59352 .47702 L
.61485 .47479 L
.66036 .46833 L
.70208 .46019 L
.73857 .45108 L
.77683 .43919 L
.81173 .4258 L
.84635 .40947 L
.87544 .39261 L
.8992 .37584 L
.92049 .35744 L
.93692 .33983 L
.9518 .31933 L
.95798 .30854 L
.96353 .29666 L
.9676 .28552 L
.96906 .2806 L
.97044 .27516 L
.97144 .27037 L
.97231 .2652 L
Mistroke
.97299 .25974 L
.9734 .25462 L
.97354 .25152 L
.97361 .24821 L
.97351 .24228 L
.9733 .23864 L
.97301 .23522 L
.97266 .23215 L
.9722 .22884 L
.9711 .22267 L
.96959 .21617 L
.96603 .20462 L
.96154 .19358 L
.95642 .18341 L
.94156 .16089 L
.92296 .14001 L
.89835 .11864 L
.87309 .10112 L
.8429 .08404 L
.81304 .0701 L
.77744 .05639 L
.70889 .03669 L
.66842 .02832 L
.64575 .02454 L
.62435 .02152 L
.5858 .01734 L
.56517 .01574 L
.55442 .01508 L
.54302 .01451 L
.53706 .01426 L
.5305 .01402 L
.51895 .01372 L
.51243 .0136 L
.50544 .01352 L
.49884 .01349 L
.49282 .0135 L
.48117 .01363 L
.47459 .01375 L
.4685 .01391 L
.45735 .01429 L
.44551 .01483 L
.42397 .01618 L
.40387 .01786 L
.3587 .02324 L
.31919 .02988 L
.27748 .0391 L
.23607 .05085 L
.19985 .0637 L
.14169 .09108 L
.11348 .10867 L
Mistroke
.09085 .12593 L
.07021 .14542 L
.05237 .16719 L
.04058 .18651 L
.03533 .19774 L
.03138 .20837 L
.02962 .21426 L
.02802 .22072 L
.02683 .22684 L
.026 .23253 L
.02544 .23818 L
.02516 .2433 L
.02511 .24921 L
.02532 .25478 L
.02584 .26087 L
.02622 .26393 L
.02673 .26729 L
.02915 .27873 L
.031 .28514 L
.03335 .29197 L
.03858 .30417 L
.05241 .32746 L
.06932 .34813 L
.09219 .3696 L
.12113 .39077 L
.17938 .42193 L
.21727 .43696 L
.25549 .44917 L
.29579 .45944 L
.33491 .46725 L
.37705 .47358 L
.39977 .47617 L
.4243 .47835 L
.44548 .47974 L
.45747 .48033 L
.46855 .48074 L
.47827 .48101 L
.48896 .48119 L
.50013 .48126 L
.51058 .48122 L
.52075 .48107 L
.53039 .48084 L
.53903 .48056 L
.54844 .48016 L
.56943 .47896 L
.58877 .47745 L
.61199 .47511 L
.63309 .47249 L
.67964 .46485 L
.71915 .45618 L
Mistroke
.7589 .44509 L
.8221 .42127 L
.85405 .40533 L
.88094 .38901 L
.90632 .37011 L
.92964 .34812 L
.94732 .32616 L
.95421 .31535 L
.95973 .30506 L
.96423 .29493 L
.96759 .28557 L
.97045 .27509 L
.97164 .26929 L
.97251 .26375 L
.97311 .25842 L
.9735 .25274 L
.97361 .24737 L
.97352 .2425 L
.97315 .23677 L
.97283 .23354 L
.97245 .23057 L
.97158 .22513 L
.97038 .21938 L
.9671 .20772 L
.96295 .19677 L
.95248 .17664 L
.93739 .15569 L
.91665 .13399 L
.89509 .11616 L
.86884 .09849 L
.8139 .07046 L
.77966 .05717 L
.7462 .04645 L
.70829 .03654 L
.6649 .02769 L
.62569 .02169 L
.58836 .01757 L
.56745 .0159 L
.54833 .01476 L
.53771 .01428 L
.52616 .01389 L
.51525 .01364 L
.50517 .01352 L
.494 .0135 L
.4834 .01359 L
.47389 .01377 L
.46352 .01406 L
.45231 .0145 L
.44039 .01511 L
.41904 .01655 L
Mistroke
.39754 .01848 L
.37748 .02073 L
.34061 .02605 L
.29774 .03432 L
.25993 .04373 L
.22086 .05592 L
.18191 .07113 L
.1491 .08701 L
.12203 .10295 L
.07778 .13773 L
.05852 .15895 L
.05005 .17056 L
.04238 .18313 L
.03682 .19429 L
.03192 .20676 L
.03018 .21227 L
.0286 .21822 L
.02739 .22378 L
.02648 .22904 L
.02574 .23489 L
.02531 .2402 L
.0251 .24593 L
.02511 .24916 L
.02519 .25213 L
.02548 .2571 L
.02604 .26256 L
.02689 .26824 L
.02792 .27354 L
.03117 .28568 L
.0352 .29665 L
.04111 .30915 L
.04792 .32081 L
.06489 .34324 L
.08452 .363 L
.11016 .38334 L
.14179 .40322 L
.20958 .43417 L
.25265 .44835 L
.29474 .4592 L
.3334 .46699 L
.37716 .4736 L
.39967 .47616 L
.42401 .47833 L
.4359 .47917 L
.44717 .47983 L
.45821 .48036 L
.46834 .48074 L
.47857 .48101 L
.48959 .4812 L
.4998 .48126 L
Mistroke
.50951 .48123 L
.52076 .48107 L
.53119 .48082 L
.54262 .48041 L
.55478 .47984 L
.57934 .47823 L
.60229 .47616 L
.64451 .47085 L
.68331 .46413 L
.71784 .4565 L
.79049 .43427 L
.82284 .42093 L
.85471 .40496 L
.90384 .37215 L
.92795 .34992 L
.94632 .3276 L
.9589 .30673 L
.96434 .29467 L
.96826 .28339 L
.96976 .27797 L
.97107 .27224 L
.97199 .26728 L
.97274 .26197 L
.97329 .25623 L
.97356 .25088 L
.97361 .24761 L
.97358 .24452 L
.97331 .23875 L
.97284 .23366 L
.97212 .22828 L
.97131 .2237 L
.97022 .21867 L
.96704 .20753 L
.96313 .1972 L
.95089 .17411 L
.93577 .15377 L
.91385 .13146 L
.88886 .11163 L
.8329 .07908 L
.79676 .06348 L
.76144 .05108 L
.72639 .041 L
.68671 .03183 L
.64781 .02486 L
.6111 .0199 L
.58956 .01767 L
.56978 .01606 L
.55879 .01533 L
.54681 .01468 L
.53547 .01419 L
Mistroke
.52497 .01386 L
.5153 .01364 L
.50622 .01353 L
.49627 .01349 L
.48555 .01356 L
.47491 .01374 L
.46374 .01406 L
.45421 .01442 L
.44382 .01492 L
.41977 .01649 L
.39811 .01842 L
.37336 .02125 L
.35034 .02449 L
.31028 .03165 L
.26856 .04139 L
.19791 .06446 L
.16188 .08043 L
.13136 .09711 L
.1033 .11601 L
.08031 .13531 L
.05848 .159 L
.05003 .1706 L
.04317 .18171 L
.03767 .19242 L
.03349 .20236 L
.02983 .21351 L
.02832 .2194 L
.02704 .22563 L
.02616 .23131 L
.02551 .23739 L
.02517 .24314 L
.0251 .24836 L
.02531 .25451 L
.02556 .25797 L
.02588 .26116 L
.02668 .26702 L
.02785 .2732 L
.03041 .28324 L
.0341 .29393 L
.04318 .31294 L
.05792 .33484 L
.07501 .35402 L
.09617 .37283 L
.12236 .39156 L
.17805 .42134 L
.21695 .43685 L
.2564 .44943 L
.29353 .45893 L
.33604 .46745 L
.3567 .47078 L
Mistroke
.37917 .47385 L
.39881 .47607 L
.42036 .47804 L
.43308 .47898 L
.44488 .47971 L
.45597 .48026 L
.46187 .48051 L
.46823 .48073 L
.4792 .48103 L
.48951 .4812 L
.50132 .48126 L
.51214 .4812 L
.52176 .48105 L
.53202 .48079 L
.54169 .48045 L
.55046 .48006 L
.5719 .47878 L
.59201 .47715 L
.63154 .47269 L
.67333 .46604 L
.71344 .45757 L
.74936 .44799 L
.7897 .43456 L
.82393 .42044 L
.88463 .3865 L
.91209 .36519 L
.93378 .34351 L
.95024 .32179 L
.96146 .30142 L
.96614 .28989 L
.96814 .28378 L
.96993 .27731 L
.9712 .2716 L
.97229 .26534 L
.973 .25963 L
.97342 .2543 L
.97361 .24896 L
.97354 .24317 L
.97323 .2377 L
.97273 .23266 L
.97209 .22813 L
.9712 .22314 L
.96876 .2131 L
.96518 .2023 L
.96024 .1908 L
.9485 .17047 L
.93088 .14823 L
.91064 .12864 L
.88438 .10851 L
.85203 .08884 L
Mistroke
.81743 .07199 L
.78181 .05792 L
.70861 .03662 L
.67046 .02869 L
.62713 .02188 L
.60485 .0192 L
.58068 .0169 L
.56889 .01599 L
.55768 .01527 L
.54767 .01472 L
.53658 .01424 L
.52635 .0139 L
.51673 .01367 L
.50657 .01353 L
.4956 .01349 L
.48596 .01356 L
.47581 .01372 L
.46715 .01395 L
.45768 .01427 L
.44646 .01478 L
.43628 .01535 L
.41354 .017 L
.39264 .01899 L
.37309 .02128 L
.33366 .02723 L
.29167 .03569 L
.24979 .04664 L
.21279 .05879 L
.15304 .08492 L
.12367 .10189 L
.09976 .11871 L
.078 .13752 L
.0587 .15873 L
.04436 .17965 L
.03473 .1992 L
.03043 .21143 L
.02759 .22277 L
.02652 .22873 L
.02605 .23216 L
.0257 .23529 L
.02541 .2386 L
.02521 .24214 L
.02511 .24543 L
.0251 .24854 L
.02529 .25418 L
.02577 .26017 L
.02641 .26528 L
.02737 .27089 L
.02869 .27689 L
.03044 .28333 L
Mistroke
.03448 .29488 L
.03934 .30571 L
.04561 .31709 L
.05968 .33705 L
.08088 .35967 L
.10412 .37896 L
.13221 .39767 L
.16664 .41607 L
.20234 .43143 L
.23834 .44402 L
.27662 .45486 L
.31321 .46316 L
.35536 .47058 L
.37941 .47388 L
.40198 .47639 L
.42399 .47833 L
.44758 .47985 L
.45984 .48043 L
.47138 .48083 L
.478 .481 L
.48407 .48112 L
.49074 .48121 L
.49777 .48126 L
.5087 .48123 L
.52038 .48108 L
.5314 .48081 L
.54141 .48046 L
.55315 .47993 L
.56585 .47919 L
.58881 .47744 L
.60935 .47541 L
.63123 .47274 L
.67002 .46664 L
.71455 .4573 L
.7534 .44678 L
.79142 .43392 L
.8298 .41771 L
.88984 .38283 L
.91528 .36233 L
.9353 .34175 L
.94985 .3224 L
.96177 .30073 L
.96638 .28921 L
.97014 .27643 L
.97152 .26995 L
.97213 .26638 L
.97261 .26299 L
.97298 .25983 L
.97328 .2564 L
.97358 .25039 L
Mistroke
.97359 .24479 L
.97348 .24161 L
.9733 .23862 L
.97272 .23261 L
.97226 .22924 L
.97176 .22615 L
.96937 .2153 L
.9678 .20987 L
.9658 .20397 L
.96103 .19249 L
.95463 .18023 L
.93976 .1586 L
.92141 .13848 L
.90127 .12091 L
.84496 .08509 L
.81162 .06949 L
.77162 .0544 L
.73198 .04247 L
.69232 .033 L
.65534 .02606 L
.61385 .02022 L
.58981 .0177 L
.56783 .01592 L
.55557 .01514 L
.54229 .01447 L
.53617 .01422 L
.52972 .014 L
.51815 .0137 L
.50745 .01354 L
.49599 .01349 L
.48518 .01357 L
.47534 .01373 L
.46379 .01405 L
.45728 .01429 L
.45128 .01455 L
.42862 .01584 L
.40724 .01755 L
.38782 .01952 L
.3448 .02536 L
.30794 .03213 L
.27057 .04086 L
.19714 .06477 L
.15997 .08139 L
.1288 .09867 L
.10179 .11716 L
.07675 .13874 L
.05739 .1604 L
.04344 .18125 L
.03415 .20066 L
.0303 .21186 L
Mistroke
.02766 .2224 L
.02662 .22813 L
.02588 .23358 L
.02542 .23848 L
.02515 .24381 L
.02512 .24961 L
.02521 .25253 L
.02539 .25576 L
.02591 .26146 L
.02665 .2668 L
.02764 .27222 L
.02897 .278 L
.03206 .28836 L
.03689 .30054 L
.04236 .31147 L
.05775 .33462 L
.0765 .35549 L
.11899 .38937 L
.14779 .40651 L
.17715 .42093 L
.20926 .43405 L
.24622 .44645 L
.27995 .45569 L
.31836 .46419 L
.34233 .46852 L
.36497 .47198 L
.38876 .47499 L
.41056 .47721 L
.43221 .47892 L
.45272 .48011 L
.46404 .48059 L
.47447 .48091 L
.48593 .48115 L
.4917 .48122 L
.49804 .48126 L
.50879 .48123 L
.51872 .48111 L
.52962 .48086 L
.54117 .48047 L
.55115 .48003 L
.5605 .47952 L
.58171 .47804 L
.60062 .47633 L
.61781 .47444 L
.65593 .46906 L
.69333 .46209 L
.73268 .45269 L
.80576 .42829 L
Mfstroke
.92334 .35527 m
.94076 .33572 L
.95381 .31677 L
.95977 .30582 L
.96446 .29533 L
.96871 .28312 L
.97017 .27779 L
.9715 .27191 L
.97252 .26615 L
.97324 .26075 L
.97373 .25503 L
.97396 .24888 L
.9739 .24319 L
.97359 .23777 L
.97311 .23292 L
.97237 .22764 L
.97118 .22135 L
.96982 .21567 L
.96581 .20302 L
.96091 .19146 L
.95527 .18071 L
.94004 .1585 L
.91933 .13618 L
.8981 .11823 L
.87127 .09987 L
.83858 .08185 L
.79959 .06469 L
.75979 .05076 L
.72056 .0398 L
.6806 .03098 L
.63653 .02361 L
.61319 .02062 L
.59102 .01831 L
.56648 .01636 L
.55259 .01552 L
.53982 .01493 L
.5294 .01456 L
.51826 .01428 L
.50774 .01413 L
.49817 .01408 L
.48692 .01415 L
.48057 .01424 L
.47472 .01436 L
.46398 .01466 L
.45263 .0151 L
.44179 .01565 L
.43017 .01636 L
.40929 .01799 L
.38468 .0205 L
.36246 .02333 L
Mistroke
.32214 .02993 L
.28071 .03888 L
.21134 .05986 L
.17285 .07569 L
.13993 .09253 L
.1136 .10901 L
.08827 .12854 L
.06725 .14904 L
.05131 .16914 L
.0385 .1912 L
.03318 .20385 L
.03126 .20949 L
.02951 .2155 L
.02826 .22068 L
.02713 .22641 L
.02634 .23164 L
.0258 .23654 L
.02542 .24232 L
.02532 .2476 L
.02547 .25341 L
.02592 .25951 L
.02652 .2645 L
.02739 .26981 L
.02954 .27934 L
.03307 .29059 L
.03719 .3007 L
.04911 .32228 L
.06599 .34425 L
.08374 .36214 L
.10661 .38071 L
.1349 .39925 L
.16914 .41732 L
.23984 .44468 L
.28076 .45614 L
.32053 .46491 L
.36586 .47245 L
.38928 .47542 L
.41548 .47804 L
.42666 .47894 L
.43848 .47975 L
.44873 .48033 L
.45971 .48085 L
.46593 .48109 L
.47158 .48127 L
.48265 .48153 L
.48886 .48163 L
.49559 .48169 L
.50195 .48171 L
.50781 .48169 L
.51822 .48157 L
Mistroke
.52795 .48136 L
.53862 .48103 L
.55006 .48054 L
.57331 .47914 L
.59442 .47739 L
.63591 .47255 L
.67896 .46542 L
.71814 .45685 L
.75216 .44755 L
.79015 .43477 L
.82818 .41881 L
.86057 .40195 L
.88763 .38469 L
.91194 .36558 L
.93083 .34708 L
.94795 .32551 L
.95566 .31312 L
.96159 .30146 L
.96624 .29001 L
.96996 .27773 L
.97139 .27133 L
.97243 .26531 L
.97289 .26185 L
.97323 .25869 L
.9735 .25521 L
.97368 .25155 L
.97374 .24584 L
.97351 .23974 L
.97302 .23399 L
.97233 .22879 L
.97124 .22267 L
.96971 .21607 L
.96601 .20418 L
.96163 .19349 L
.95587 .18217 L
.94272 .16224 L
.92264 .13959 L
.90031 .12011 L
.87331 .10126 L
.83985 .08254 L
.7695 .05384 L
.7288 .04182 L
.68849 .03243 L
.6509 .0256 L
.60915 .01997 L
.58697 .01774 L
.56245 .01587 L
.55002 .01516 L
.53668 .01456 L
.53019 .01434 L
Mistroke
.52406 .01416 L
.51256 .01393 L
.50172 .01383 L
.49022 .01385 L
.48041 .01397 L
.46961 .01421 L
.45804 .0146 L
.44561 .01516 L
.42324 .01657 L
.401 .01847 L
.37751 .02106 L
.33603 .02714 L
.28842 .03674 L
.2473 .04765 L
.21055 .05987 L
.1736 .07508 L
.14197 .09113 L
.11535 .10757 L
.09058 .12632 L
.0712 .14453 L
.05347 .16581 L
.04539 .17807 L
.0391 .18963 L
.03419 .20076 L
.03 .21319 L
.02833 .21968 L
.02709 .2258 L
.02611 .23227 L
.02571 .23592 L
.02544 .23927 L
.0252 .24501 L
.02521 .25035 L
.0255 .25621 L
.02578 .25949 L
.02611 .26246 L
.02701 .26847 L
.02831 .27497 L
.03158 .28669 L
.03559 .2974 L
.04098 .30876 L
.05346 .32883 L
.07276 .35169 L
.09445 .37144 L
.12082 .39059 L
.15368 .40969 L
.22319 .43915 L
.26349 .45156 L
.30353 .46133 L
.34093 .46848 L
.38258 .47448 L
Mistroke
.4047 .47689 L
.4292 .47895 L
.44162 .47976 L
.45497 .48046 L
.46146 .48073 L
.4676 .48095 L
.47913 .48127 L
.48997 .48145 L
.50149 .48151 L
.51133 .48146 L
.52216 .48129 L
.53377 .48099 L
.54029 .48075 L
.54625 .48051 L
.56874 .47925 L
.59071 .47752 L
.61049 .47552 L
.65413 .46959 L
.69336 .4623 L
.72904 .45386 L
.80304 .42956 L
.84027 .41274 L
.87119 .39541 L
.89616 .37829 L
.91942 .35857 L
.93639 .34056 L
.95139 .32009 L
.95868 .30729 L
.96416 .29524 L
.96825 .28359 L
.9699 .27758 L
.97135 .27108 L
.97235 .26525 L
.97302 .25989 L
.97344 .25475 L
.97364 .24933 L
.97359 .24339 L
.97329 .23785 L
.97266 .23178 L
.97218 .22839 L
.97165 .22531 L
.96925 .21471 L
.96553 .20312 L
.96045 .19117 L
.95461 .18014 L
.9416 .16091 L
.92406 .14108 L
.89912 .11924 L
.87128 .10003 L
.84023 .08274 L
Mistroke
.80925 .06858 L
.73919 .04457 L
.69735 .03422 L
.65623 .02637 L
.61688 .02075 L
.57993 .01701 L
.56038 .01561 L
.54911 .01497 L
.53881 .0145 L
.52791 .01412 L
.51621 .01384 L
.50535 .0137 L
.49507 .01368 L
.4849 .01375 L
.47395 .01395 L
.46362 .01424 L
.45416 .0146 L
.43227 .01578 L
.42132 .01655 L
.40938 .01753 L
.38694 .01979 L
.36324 .02277 L
.32146 .02961 L
.28097 .03837 L
.24444 .04837 L
.18151 .07141 L
.15164 .08575 L
.12187 .10313 L
.09625 .12155 L
.07278 .14278 L
.05486 .16379 L
.04206 .18377 L
.03715 .19361 L
.03275 .20445 L
.0295 .21479 L
.02728 .22444 L
.0263 .23043 L
.02591 .23345 L
.02558 .23676 L
.02521 .24263 L
.02512 .2481 L
.02518 .25143 L
.02533 .25458 L
.02582 .26046 L
.02622 .26375 L
.02667 .26678 L
.02796 .27363 L
.03073 .28421 L
.03486 .29577 L
.04036 .30769 L
Mistroke
.0466 .31868 L
.06116 .33885 L
.07759 .35656 L
.12472 .3931 L
.15267 .40915 L
.18555 .42468 L
.25165 .44815 L
.29577 .45954 L
.33937 .46814 L
.37982 .47405 L
.40304 .47663 L
.42462 .47851 L
.43576 .47929 L
.44634 .47992 L
.45599 .4804 L
.46625 .4808 L
.47741 .48112 L
.48776 .48131 L
.49889 .48139 L
.50523 .48139 L
.51119 .48135 L
.5211 .4812 L
.53153 .48094 L
.54043 .48063 L
.55015 .48021 L
.5718 .47892 L
.59182 .4773 L
.6153 .47486 L
.63724 .47203 L
.67744 .46538 L
.71919 .45626 L
.76224 .44412 L
.82877 .41826 L
.86208 .40083 L
.88985 .38287 L
.91479 .36281 L
.93466 .34252 L
.94395 .3309 L
.95269 .31792 L
.95937 .30583 L
.9644 .29454 L
.96843 .28284 L
.97009 .27665 L
.9715 .27008 L
.97244 .26435 L
.97307 .25899 L
.97349 .25311 L
.9736 .24981 L
.97362 .2468 L
.97347 .24123 L
Mistroke
.9731 .23609 L
.97244 .23045 L
.97146 .22448 L
.96916 .21451 L
.96567 .20359 L
.96048 .19131 L
.95462 .18021 L
.9376 .15596 L
.91839 .13562 L
.89415 .1155 L
.83984 .08253 L
.80452 .06661 L
.7698 .05386 L
.73534 .04346 L
.69614 .0339 L
.65763 .02653 L
.62111 .0212 L
.60025 .01881 L
.58027 .01696 L
.56919 .01611 L
.55707 .01533 L
.5459 .01473 L
.53577 .0143 L
.52529 .01396 L
.51543 .01374 L
.50501 .01361 L
.49376 .01359 L
.48387 .01368 L
.47346 .01387 L
.46457 .01412 L
.45485 .01449 L
.44251 .01508 L
.43087 .01578 L
.40919 .01746 L
.38605 .0198 L
.36123 .02296 L
.31755 .03027 L
.27868 .03886 L
.24248 .0489 L
.20569 .06149 L
.14596 .08874 L
.11452 .10798 L
.08855 .1279 L
.06876 .14698 L
.05118 .1689 L
.04408 .18012 L
.03765 .19248 L
.03277 .20432 L
.02933 .21532 L
.02709 .22534 L
Mistroke
.02619 .23105 L
.02559 .23639 L
.02521 .24203 L
.0251 .24718 L
.02523 .25312 L
.02563 .25874 L
.02628 .26432 L
.02729 .27046 L
.02868 .27686 L
.03029 .28284 L
.03391 .29344 L
.03886 .30474 L
.05409 .3298 L
.07274 .35174 L
.09335 .37058 L
.119 .38941 L
.17385 .41949 L
.21221 .43519 L
.2513 .44801 L
.28815 .45774 L
.33051 .46654 L
.35092 .46997 L
.37319 .47316 L
.39267 .47549 L
.41411 .47759 L
.42672 .47861 L
.43846 .4794 L
.45065 .48008 L
.46172 .48057 L
.47265 .48094 L
.48294 .48117 L
.49382 .48131 L
.50558 .48132 L
.51589 .48122 L
.5255 .48104 L
.53604 .48073 L
.5473 .48028 L
.55909 .47967 L
.57022 .47897 L
.59095 .47731 L
.62782 .47325 L
.667 .46724 L
.70709 .4591 L
.74317 .44983 L
.78377 .43677 L
.81839 .42295 L
.88002 .38963 L
.90687 .36966 L
.93058 .3471 L
.94764 .32569 L
Mistroke
.95951 .30552 L
.96456 .2941 L
.96677 .28803 L
.96878 .28159 L
.97025 .27592 L
.97157 .26968 L
.97248 .26398 L
.97309 .25866 L
.97346 .25336 L
.97361 .24759 L
.9735 .24214 L
.97318 .2371 L
.97271 .23258 L
.972 .22759 L
.97104 .2224 L
.96993 .21753 L
.96672 .20659 L
.96289 .19665 L
.95125 .17468 L
.93628 .15439 L
.91631 .1337 L
.87071 .09967 L
.8373 .08125 L
.80231 .0657 L
.76865 .05345 L
.72923 .04179 L
.69172 .03292 L
.64978 .02522 L
.62607 .02179 L
.60409 .01917 L
.58151 .01702 L
.56038 .01548 L
.54095 .01446 L
.53006 .01406 L
.52017 .01379 L
.50928 .01361 L
.49749 .01354 L
.48636 .0136 L
.47613 .01377 L
.46652 .01401 L
.45756 .01433 L
.43725 .01534 L
.41757 .01671 L
.39662 .01862 L
.35097 .02443 L
.30999 .03174 L
.26679 .04189 L
.22344 .05505 L
.15798 .0824 L
.12555 .10071 L
Mistroke
.09874 .11952 L
.07579 .13968 L
.05808 .15951 L
.04351 .18111 L
.03747 .19283 L
.03233 .20553 L
.02901 .21653 L
.02758 .22277 L
.02655 .22854 L
.02587 .2336 L
.02537 .23917 L
.02511 .24499 L
.02513 .25043 L
.02538 .25573 L
.02582 .26075 L
.0264 .26525 L
.02722 .27014 L
.02978 .28105 L
.03302 .29109 L
.03806 .3031 L
.04376 .31398 L
.06029 .33782 L
.07892 .35784 L
.10247 .37775 L
.15211 .40884 L
.18469 .42427 L
.21759 .43711 L
.25519 .44912 L
.29843 .46007 L
.34114 .46836 L
.36204 .4716 L
.38188 .47422 L
.41935 .478 L
.43945 .47943 L
.4508 .48006 L
.46121 .48052 L
.47203 .48089 L
.48209 .48112 L
.49314 .48127 L
.50493 .48129 L
.51616 .48119 L
.52674 .48097 L
.53622 .48069 L
.54648 .48028 L
.5675 .47912 L
.5899 .47738 L
.61087 .47527 L
.62982 .47295 L
.67523 .46571 L
.7167 .4568 L
Mistroke
.75749 .44554 L
.79306 .43331 L
.82905 .41808 L
.86419 .39954 L
.89163 .38154 L
.91366 .36378 L
.93277 .34466 L
.9474 .32603 L
.95986 .3048 L
.96486 .29332 L
.96897 .28092 L
.97055 .27462 L
.9719 .26777 L
.97239 .26462 L
.97281 .26128 L
.97335 .25528 L
.97359 .24953 L
.97357 .24414 L
.97327 .23823 L
.97297 .23492 L
.97262 .2319 L
.97171 .22592 L
.97059 .22031 L
.96779 .20988 L
.96377 .19875 L
.95826 .18687 L
.94534 .16596 L
.93016 .14746 L
.91001 .12811 L
.88396 .10825 L
.8529 .08933 L
.82003 .07316 L
.78614 .05951 L
.7466 .04659 L
.71186 .03741 L
.67189 .02898 L
.62716 .02191 L
.60212 .01894 L
.57837 .01674 L
.56751 .01593 L
.55605 .0152 L
.54612 .01467 L
.53549 .01422 L
.52399 .01386 L
.51329 .01364 L
.50674 .01356 L
.50056 .01352 L
.48899 .01355 L
.47867 .01369 L
.4676 .01396 L
Mistroke
.45716 .01432 L
.44765 .01474 L
.42447 .01616 L
.40264 .018 L
.35991 .02309 L
.33623 .0268 L
.31467 .03078 L
.24354 .04852 L
.21017 .05976 L
.17571 .0739 L
.14467 .08942 L
.11526 .10744 L
.09282 .12428 L
.0721 .14342 L
.05378 .16521 L
.04065 .18635 L
.03456 .1996 L
.03211 .20617 L
.03017 .21228 L
.02871 .21773 L
.02738 .22376 L
.02635 .22984 L
.02592 .23318 L
.02559 .2363 L
.0252 .24209 L
.02511 .24533 L
.02509 .24827 L
.02527 .254 L
.02568 .25938 L
.02602 .26244 L
.02647 .26567 L
.02747 .27144 L
.02887 .27763 L
.03076 .28439 L
.03477 .29561 L
.04023 .30749 L
.05308 .32841 L
.07049 .34939 L
.09056 .36825 L
.13689 .40044 L
.16504 .41532 L
.19898 .43013 L
.23465 .44286 L
.27559 .45462 L
.3157 .46368 L
.35384 .47037 L
.39126 .47529 L
.41036 .47721 L
.43141 .47889 L
.44232 .47958 L
Mistroke
.4539 .48019 L
.45996 .48045 L
.46663 .4807 L
.47839 .48103 L
.48948 .48121 L
.49571 .48127 L
.5014 .48128 L
.51245 .48122 L
.52294 .48105 L
.53295 .48078 L
.54359 .48039 L
.56268 .47941 L
.58524 .47776 L
.60551 .47584 L
.65024 .46999 L
.697 .46131 L
.73922 .45091 L
.77598 .43949 L
.80944 .42677 L
.84257 .41143 L
.8942 .37964 L
.92001 .3579 L
.94003 .33599 L
.95417 .31541 L
.96049 .30348 L
.96525 .29231 L
.96889 .28118 L
.97133 .27092 L
.97226 .26552 L
.973 .25961 L
.97326 .25662 L
.97346 .25342 L
.97361 .24768 L
.9735 .24222 L
.97311 .23632 L
.97247 .23076 L
.97167 .22565 L
.96954 .216 L
.96646 .20586 L
.96206 .19475 L
.95619 .183 L
.94264 .16231 L
.92175 .13883 L
.89841 .11869 L
.87322 .10121 L
.84306 .08413 L
.78114 .0577 L
.74312 .04557 L
.70541 .03589 L
.6622 .02724 L
Mistroke
.63904 .02355 L
.61389 .02024 L
.59128 .01785 L
.57055 .01613 L
.5605 .01545 L
.54957 .01483 L
.53929 .01436 L
.52965 .01401 L
.51844 .01372 L
.51249 .01361 L
.50608 .01354 L
.49939 .0135 L
.49303 .01351 L
.48732 .01355 L
.48109 .01364 L
.46984 .01388 L
.46356 .01407 L
.45788 .01428 L
.43642 .01535 L
.42472 .01613 L
.41241 .0171 L
.39052 .01923 L
.34203 .02582 L
.30145 .03351 L
.2588 .04405 L
.21927 .05648 L
.18432 .07009 L
.12647 .10012 L
.09906 .11926 L
.07723 .13826 L
.05742 .16035 L
.04895 .17221 L
.04139 .18495 L
.03629 .19548 L
.03179 .20713 L
.03017 .21229 L
.02869 .21782 L
.02753 .22301 L
.02666 .22782 L
.02584 .23389 L
.02553 .23709 L
.02529 .24048 L
.0251 .24618 L
.02511 .24941 L
.0252 .25244 L
.02556 .25808 L
.02612 .26322 L
.02704 .26913 L
.02818 .27473 L
.0309 .28485 L
Mistroke
.03473 .29551 L
.04398 .31436 L
.05887 .33605 L
.07585 .35485 L
.09776 .37411 L
.12464 .39303 L
.18145 .42285 L
.21736 .437 L
.25317 .44851 L
.2947 .4592 L
.34127 .46835 L
.36318 .47173 L
.38675 .47477 L
.40735 .47692 L
.42972 .47876 L
.4423 .47957 L
.45386 .48018 L
.4655 .48065 L
.47658 .48098 L
.4828 .48111 L
.48944 .4812 L
.4957 .48126 L
.50138 .48127 L
.50808 .48125 L
.51533 .48117 L
.52217 .48105 L
.52846 .4809 L
.53884 .48057 L
.54994 .48009 L
.56992 .47893 L
.59352 .47702 L
.61485 .47479 L
.66037 .46833 L
.70209 .46019 L
.73857 .45108 L
.77684 .43919 L
.81173 .4258 L
.84635 .40947 L
.87544 .3926 L
.8992 .37584 L
.92049 .35744 L
.93692 .33982 L
.9518 .31933 L
.95797 .30854 L
.96353 .29666 L
.9676 .28552 L
.96906 .28059 L
.97043 .27516 L
.97144 .27036 L
.97231 .2652 L
Mistroke
.97298 .25973 L
.9734 .25462 L
.97354 .25151 L
.97361 .24821 L
.9735 .24227 L
.9733 .23864 L
.973 .23522 L
.97266 .23215 L
.9722 .22884 L
.9711 .22266 L
.96959 .21617 L
.96603 .20462 L
.96153 .19358 L
.95642 .18341 L
.94155 .16089 L
.92296 .14001 L
.89835 .11864 L
.87309 .10112 L
.8429 .08404 L
.81304 .0701 L
.77744 .05639 L
.70889 .03669 L
.66842 .02833 L
.64575 .02454 L
.62435 .02152 L
.5858 .01734 L
.56517 .01575 L
.55443 .01508 L
.54303 .01451 L
.53706 .01426 L
.5305 .01403 L
.51895 .01372 L
.51244 .0136 L
.50545 .01353 L
.49884 .0135 L
.49282 .01351 L
.48117 .01363 L
.47459 .01376 L
.4685 .01391 L
.45735 .01429 L
.44551 .01483 L
.42398 .01618 L
.40388 .01787 L
.3587 .02324 L
.3192 .02988 L
.27748 .0391 L
.23607 .05085 L
.19985 .0637 L
.14169 .09108 L
.11348 .10867 L
Mistroke
.09085 .12592 L
.07021 .14542 L
.05237 .16719 L
.04058 .18651 L
.03533 .19773 L
.03138 .20837 L
.02962 .21426 L
.02802 .22072 L
.02683 .22683 L
.026 .23253 L
.02544 .23817 L
.02516 .2433 L
.02511 .24921 L
.02532 .25478 L
.02584 .26087 L
.02622 .26393 L
.02672 .26728 L
.02915 .27873 L
.03099 .28514 L
.03335 .29197 L
.03858 .30417 L
.05241 .32746 L
.06931 .34813 L
.09219 .3696 L
.12113 .39077 L
.17938 .42193 L
.21727 .43697 L
.25549 .44917 L
.29579 .45945 L
.33491 .46726 L
.37705 .47359 L
.39977 .47618 L
.4243 .47836 L
.44548 .47975 L
.45747 .48033 L
.46856 .48075 L
.47827 .48101 L
.48896 .48119 L
.50013 .48127 L
.51058 .48122 L
.52075 .48108 L
.53039 .48084 L
.53903 .48056 L
.54844 .48016 L
.56943 .47896 L
.58877 .47745 L
.61199 .47511 L
.63309 .47249 L
.67964 .46485 L
.71916 .45618 L
Mistroke
.75891 .44508 L
.8221 .42127 L
.85405 .40533 L
.88094 .389 L
.90632 .37011 L
.92964 .34812 L
.94732 .32616 L
.95421 .31535 L
.95973 .30506 L
.96423 .29493 L
.96759 .28557 L
.97045 .27509 L
.97164 .26928 L
.97251 .26375 L
.97311 .25842 L
.97349 .25274 L
.97361 .24737 L
.97352 .2425 L
.97315 .23677 L
.97283 .23354 L
.97245 .23057 L
.97157 .22512 L
.97038 .21938 L
.9671 .20772 L
.96294 .19677 L
.95247 .17664 L
.93738 .15569 L
.91665 .13399 L
.89508 .11616 L
.86884 .0985 L
.8139 .07047 L
.77966 .05717 L
.7462 .04645 L
.70829 .03655 L
.6649 .0277 L
.62569 .02169 L
.58836 .01757 L
.56745 .0159 L
.54833 .01476 L
.53771 .01428 L
.52617 .01389 L
.51525 .01365 L
.50517 .01352 L
.49401 .0135 L
.4834 .01359 L
.47389 .01377 L
.46352 .01406 L
.45231 .0145 L
.44039 .01511 L
.41904 .01655 L
Mistroke
.39754 .01848 L
.37748 .02073 L
.34061 .02604 L
.29774 .03432 L
.25993 .04373 L
.22086 .05592 L
.18191 .07113 L
.1491 .08701 L
.12203 .10295 L
.07778 .13773 L
.05852 .15895 L
.05005 .17055 L
.04238 .18313 L
.03682 .19429 L
.03192 .20676 L
.03018 .21227 L
.0286 .21822 L
.02738 .22378 L
.02648 .22904 L
.02574 .23488 L
.02531 .2402 L
.0251 .24593 L
.02511 .24916 L
.02519 .25213 L
.02548 .2571 L
.02604 .26256 L
.02689 .26824 L
.02792 .27354 L
.03117 .28568 L
.0352 .29665 L
.0411 .30915 L
.04792 .32081 L
.06489 .34324 L
.08452 .363 L
.11016 .38334 L
.14179 .40322 L
.20958 .43417 L
.25265 .44835 L
.29474 .45921 L
.3334 .46699 L
.37716 .4736 L
.39968 .47616 L
.42401 .47833 L
.4359 .47917 L
.44717 .47983 L
.45821 .48036 L
.46834 .48074 L
.47857 .48102 L
.48959 .4812 L
.4998 .48126 L
Mistroke
.50951 .48123 L
.52076 .48107 L
.53119 .48082 L
.54262 .48041 L
.55478 .47984 L
.57934 .47823 L
.60229 .47616 L
.64452 .47085 L
.68331 .46413 L
.71784 .4565 L
.79049 .43427 L
.82284 .42093 L
.85471 .40496 L
.90384 .37215 L
.92795 .34992 L
.94632 .3276 L
.9589 .30673 L
.96434 .29467 L
.96826 .28339 L
.96976 .27797 L
.97107 .27224 L
.97199 .26728 L
.97274 .26197 L
.97329 .25623 L
.97356 .25088 L
.97361 .24761 L
.97358 .24452 L
.97331 .23875 L
.97284 .23366 L
.97211 .22828 L
.97131 .2237 L
.97022 .21867 L
.96704 .20753 L
.96313 .1972 L
.95089 .17411 L
.93577 .15377 L
.91385 .13146 L
.88886 .11163 L
.8329 .07908 L
.79676 .06348 L
.76144 .05108 L
.72639 .041 L
.68671 .03183 L
.64781 .02486 L
.6111 .0199 L
.58956 .01767 L
.56978 .01606 L
.55879 .01533 L
.54681 .01468 L
.53547 .01419 L
Mistroke
.52497 .01386 L
.5153 .01364 L
.50623 .01353 L
.49627 .01349 L
.48555 .01356 L
.47491 .01374 L
.46374 .01406 L
.45421 .01442 L
.44382 .01492 L
.41977 .01649 L
.39811 .01842 L
.37336 .02125 L
.35034 .02449 L
.31028 .03165 L
.26856 .04139 L
.19791 .06446 L
.16188 .08043 L
.13136 .0971 L
.1033 .11601 L
.08031 .13531 L
.05848 .159 L
.05002 .1706 L
.04317 .18171 L
.03767 .19242 L
.03349 .20236 L
.02983 .21351 L
.02832 .2194 L
.02704 .22563 L
.02616 .23131 L
.0255 .23739 L
.02517 .24314 L
.0251 .24836 L
.0253 .25451 L
.02556 .25797 L
.02588 .26116 L
.02668 .26702 L
.02784 .2732 L
.03041 .28324 L
.0341 .29393 L
.04318 .31294 L
.05792 .33484 L
.07501 .35402 L
.09617 .37283 L
.12236 .39156 L
.17805 .42134 L
.21695 .43685 L
.2564 .44943 L
.29353 .45893 L
.33604 .46745 L
.3567 .47078 L
Mistroke
.37917 .47385 L
.39881 .47607 L
.42036 .47805 L
.43308 .47898 L
.44488 .47971 L
.45597 .48026 L
.46187 .48051 L
.46823 .48073 L
.47921 .48103 L
.48952 .4812 L
.50132 .48126 L
.51214 .4812 L
.52176 .48105 L
.53202 .48079 L
.5417 .48045 L
.55047 .48006 L
.5719 .47878 L
.59201 .47715 L
.63154 .47269 L
.67333 .46604 L
.71344 .45757 L
.74936 .44799 L
.7897 .43456 L
.82393 .42044 L
.88463 .3865 L
.91209 .36519 L
.93378 .34351 L
.95024 .32179 L
.96146 .30142 L
.96613 .28989 L
.96814 .28378 L
.96992 .2773 L
.9712 .2716 L
.97229 .26533 L
.973 .25963 L
.97342 .2543 L
.9736 .24896 L
.97354 .24317 L
.97323 .2377 L
.97272 .23266 L
.97209 .22813 L
.9712 .22314 L
.96876 .2131 L
.96518 .2023 L
.96023 .1908 L
.9485 .17047 L
.93088 .14823 L
.91064 .12864 L
.88438 .10851 L
.85203 .08884 L
Mistroke
.81743 .07199 L
.78181 .05792 L
.70861 .03662 L
.67046 .02869 L
.62713 .02188 L
.60485 .0192 L
.58068 .0169 L
.56889 .01599 L
.55768 .01527 L
.54767 .01472 L
.53658 .01424 L
.52635 .0139 L
.51673 .01367 L
.50657 .01353 L
.4956 .01349 L
.48596 .01356 L
.47581 .01372 L
.46715 .01395 L
.45768 .01427 L
.44646 .01478 L
.43628 .01535 L
.41354 .017 L
.39264 .01899 L
.37309 .02128 L
.33366 .02723 L
.29167 .03569 L
.24979 .04664 L
.21279 .05879 L
.15304 .08492 L
.12367 .10189 L
.09976 .11871 L
.078 .13752 L
.0587 .15873 L
.04436 .17965 L
.03473 .1992 L
.03043 .21143 L
.02759 .22277 L
.02652 .22873 L
.02605 .23216 L
.0257 .23529 L
.02541 .2386 L
.02521 .24214 L
.02511 .24543 L
.0251 .24854 L
.02529 .25418 L
.02577 .26017 L
.02641 .26528 L
.02737 .27089 L
.02869 .27689 L
.03044 .28333 L
Mistroke
.03448 .29488 L
.03934 .30571 L
.04561 .31709 L
.05968 .33705 L
.08088 .35967 L
.10412 .37896 L
.13221 .39767 L
.16664 .41607 L
.20234 .43143 L
.23834 .44402 L
.27662 .45486 L
.31321 .46316 L
.35536 .47058 L
.37941 .47388 L
.40198 .47639 L
.42399 .47833 L
.44758 .47985 L
.45984 .48043 L
.47138 .48083 L
.478 .481 L
.48407 .48112 L
.49074 .48121 L
.49777 .48126 L
.5087 .48123 L
.52038 .48108 L
.5314 .48081 L
.54141 .48046 L
.55315 .47993 L
.56585 .47919 L
.58881 .47744 L
.60935 .47541 L
.63123 .47274 L
.67002 .46664 L
.71455 .4573 L
.7534 .44678 L
.79142 .43392 L
.8298 .41771 L
.88984 .38283 L
.91528 .36233 L
.9353 .34175 L
.94985 .3224 L
.96177 .30073 L
.96638 .28921 L
.97014 .27643 L
.97152 .26995 L
.97213 .26638 L
.97261 .26299 L
.97298 .25983 L
.97328 .2564 L
.97358 .25039 L
Mistroke
.97359 .24479 L
.97348 .24161 L
.9733 .23862 L
.97272 .23261 L
.97226 .22924 L
.97176 .22615 L
.96937 .2153 L
.96779 .20987 L
.9658 .20397 L
.96103 .19249 L
.95463 .18023 L
.93976 .1586 L
.92141 .13848 L
.90127 .12091 L
.84496 .08509 L
.81162 .06949 L
.77162 .0544 L
.73198 .04247 L
.69232 .033 L
.65534 .02606 L
.61385 .02022 L
.58981 .0177 L
.56783 .01592 L
.55557 .01514 L
.54229 .01447 L
.53617 .01422 L
.52972 .014 L
.51815 .0137 L
.50745 .01354 L
.49599 .01349 L
.48518 .01357 L
.47534 .01373 L
.46379 .01405 L
.45728 .01429 L
.45128 .01455 L
.42862 .01584 L
.40724 .01755 L
.38782 .01952 L
.3448 .02536 L
.30794 .03213 L
.27057 .04086 L
.19714 .06477 L
.15997 .08138 L
.1288 .09867 L
.10179 .11716 L
.07675 .13874 L
.05739 .1604 L
.04344 .18125 L
.03415 .20066 L
.0303 .21186 L
Mistroke
.02766 .2224 L
.02662 .22813 L
.02588 .23358 L
.02542 .23848 L
.02515 .24381 L
.02512 .24961 L
.02521 .25253 L
.02539 .25576 L
.02591 .26146 L
.02665 .2668 L
.02764 .27222 L
.02897 .278 L
.03206 .28836 L
.03689 .30054 L
.04236 .31147 L
.05774 .33462 L
.0765 .35549 L
.11899 .38937 L
.14779 .40651 L
.17715 .42093 L
.20926 .43405 L
.24622 .44645 L
.27995 .45569 L
.31836 .46419 L
.34233 .46852 L
.36497 .47198 L
.38876 .47499 L
.41056 .47721 L
.43221 .47892 L
.45272 .48011 L
.46404 .48059 L
.47447 .48091 L
.48593 .48115 L
.4917 .48122 L
.49804 .48126 L
.50879 .48123 L
.51872 .48111 L
.52962 .48086 L
.54117 .48047 L
.55115 .48003 L
.5605 .47952 L
.58171 .47804 L
.60062 .47633 L
.61781 .47444 L
.65593 .46906 L
.69333 .46209 L
.73268 .45269 L
.80576 .42829 L
Mfstroke
.92348 .35465 m
.94079 .3351 L
.95373 .31616 L
.95964 .30523 L
.96427 .29476 L
.96847 .28257 L
.9699 .27726 L
.97121 .2714 L
.97221 .26566 L
.9729 .26027 L
.97337 .25457 L
.97358 .24845 L
.97349 .24277 L
.97317 .23738 L
.97268 .23255 L
.97192 .22729 L
.97071 .22102 L
.96934 .21537 L
.9653 .20278 L
.96038 .19127 L
.95472 .18058 L
.93947 .15848 L
.91877 .13628 L
.89757 .11843 L
.87079 .10017 L
.83817 .08223 L
.79928 .06515 L
.75958 .05126 L
.72045 .04033 L
.68059 .03151 L
.63662 .02412 L
.61334 .02111 L
.59121 .01879 L
.56672 .0168 L
.55285 .01595 L
.54011 .01533 L
.52971 .01495 L
.51859 .01466 L
.50808 .01449 L
.49853 .01443 L
.48729 .01447 L
.48095 .01455 L
.47511 .01466 L
.46438 .01494 L
.45304 .01537 L
.44221 .01589 L
.43061 .01658 L
.40975 .01817 L
.38515 .02063 L
.36294 .02341 L
Mistroke
.32262 .02992 L
.28119 .03878 L
.21175 .0596 L
.1732 .07536 L
.14021 .09214 L
.1138 .10858 L
.08838 .12808 L
.06727 .14858 L
.05125 .16869 L
.03836 .19078 L
.03299 .20345 L
.03106 .2091 L
.02929 .21513 L
.02802 .22032 L
.02687 .22607 L
.02607 .23131 L
.02552 .23622 L
.02513 .24201 L
.02501 .24732 L
.02514 .25314 L
.02559 .25926 L
.02618 .26426 L
.02704 .26959 L
.02917 .27916 L
.03268 .29045 L
.03679 .30059 L
.04869 .32225 L
.06558 .3443 L
.08335 .36226 L
.10624 .3809 L
.13457 .39951 L
.16888 .41763 L
.23972 .44506 L
.28071 .45653 L
.32056 .4653 L
.36596 .47282 L
.38942 .47577 L
.41566 .47836 L
.42685 .47925 L
.43869 .48005 L
.44895 .48063 L
.45995 .48113 L
.46617 .48136 L
.47183 .48153 L
.48291 .48179 L
.48912 .48188 L
.49586 .48193 L
.50223 .48194 L
.5081 .48191 L
.51851 .48178 L
Mistroke
.52825 .48156 L
.53893 .48121 L
.55038 .4807 L
.57364 .47927 L
.59476 .47749 L
.63627 .47258 L
.67931 .46538 L
.71848 .45674 L
.75248 .4474 L
.79043 .43455 L
.82841 .41855 L
.86075 .40165 L
.88775 .38436 L
.912 .36524 L
.93083 .34675 L
.94789 .32519 L
.95556 .31281 L
.96147 .30117 L
.96608 .28973 L
.96978 .27747 L
.9712 .27108 L
.97222 .26507 L
.97268 .26163 L
.97301 .25847 L
.97327 .255 L
.97345 .25134 L
.9735 .24564 L
.97326 .23956 L
.97276 .23383 L
.97207 .22863 L
.97097 .22253 L
.96943 .21595 L
.96572 .20409 L
.96134 .19343 L
.95557 .18214 L
.94242 .16226 L
.92235 .13968 L
.90004 .12025 L
.87308 .10145 L
.83966 .08277 L
.76941 .05412 L
.72877 .04211 L
.68851 .03271 L
.65097 .02587 L
.60927 .02021 L
.58711 .01797 L
.56262 .01608 L
.55019 .01536 L
.53686 .01475 L
.53038 .01452 L
Mistroke
.52425 .01434 L
.51276 .0141 L
.50193 .01399 L
.49044 .014 L
.48064 .01411 L
.46984 .01434 L
.45828 .01471 L
.44586 .01526 L
.42349 .01664 L
.40126 .01852 L
.37777 .02108 L
.33629 .02711 L
.28867 .03666 L
.24753 .04752 L
.21075 .0597 L
.17376 .07488 L
.14209 .0909 L
.11542 .10733 L
.09062 .12607 L
.07119 .14428 L
.05341 .16558 L
.04531 .17785 L
.03899 .18942 L
.03407 .20057 L
.02986 .21301 L
.02818 .21951 L
.02693 .22564 L
.02594 .23212 L
.02554 .23578 L
.02527 .23913 L
.02501 .24488 L
.02502 .25023 L
.0253 .2561 L
.02558 .25938 L
.02591 .26236 L
.0268 .26838 L
.02811 .27489 L
.03136 .28663 L
.03537 .29736 L
.04076 .30875 L
.05324 .32885 L
.07255 .35177 L
.09426 .37155 L
.12065 .39073 L
.15355 .40986 L
.22314 .43936 L
.26348 .45177 L
.30356 .46153 L
.34099 .46868 L
.38267 .47466 L
Mistroke
.40481 .47705 L
.42932 .4791 L
.44176 .4799 L
.45511 .48059 L
.4616 .48086 L
.46775 .48108 L
.47928 .48139 L
.49014 .48155 L
.50166 .48161 L
.5115 .48155 L
.52234 .48138 L
.53395 .48106 L
.54047 .48082 L
.54643 .48057 L
.56892 .47929 L
.5909 .47754 L
.61069 .47553 L
.65432 .46956 L
.69355 .46224 L
.72921 .45377 L
.80317 .42942 L
.84037 .41258 L
.87125 .39524 L
.89619 .37811 L
.91942 .35839 L
.93635 .34038 L
.95133 .31993 L
.95859 .30714 L
.96406 .2951 L
.96814 .28346 L
.96978 .27746 L
.97122 .27097 L
.97222 .26514 L
.97288 .25979 L
.9733 .25466 L
.9735 .24925 L
.97345 .24331 L
.97314 .23778 L
.97251 .23172 L
.97202 .22833 L
.9715 .22526 L
.96909 .21467 L
.96537 .2031 L
.96029 .19117 L
.95445 .18015 L
.94145 .16095 L
.92391 .14115 L
.89899 .11934 L
.87117 .10015 L
.84014 .08288 L
Mistroke
.80919 .06873 L
.73918 .04472 L
.69738 .03437 L
.65628 .0265 L
.61696 .02087 L
.58003 .01712 L
.56049 .0157 L
.54922 .01506 L
.53893 .01459 L
.52803 .0142 L
.51633 .01392 L
.50548 .01377 L
.4952 .01374 L
.48503 .01381 L
.47408 .014 L
.46375 .01428 L
.4543 .01464 L
.43241 .0158 L
.42146 .01657 L
.40952 .01754 L
.38708 .01978 L
.36338 .02275 L
.32159 .02956 L
.28109 .03831 L
.24455 .04828 L
.18158 .0713 L
.15169 .08563 L
.1219 .103 L
.09626 .12141 L
.07276 .14265 L
.05482 .16367 L
.042 .18367 L
.03708 .19351 L
.03266 .20436 L
.02941 .2147 L
.02719 .22436 L
.0262 .23036 L
.02581 .23338 L
.02548 .23669 L
.0251 .24257 L
.02501 .24805 L
.02507 .25138 L
.02522 .25453 L
.02571 .26042 L
.0261 .26371 L
.02655 .26675 L
.02784 .27361 L
.03061 .2842 L
.03474 .29577 L
.04024 .3077 L
Mistroke
.04648 .3187 L
.06105 .3389 L
.07749 .35662 L
.12464 .3932 L
.15261 .40926 L
.18551 .42479 L
.25166 .44827 L
.2958 .45965 L
.33942 .46824 L
.37988 .47414 L
.40311 .4767 L
.4247 .47858 L
.43584 .47936 L
.44643 .47998 L
.45607 .48045 L
.46634 .48085 L
.47751 .48117 L
.48785 .48135 L
.49899 .48143 L
.50533 .48142 L
.51129 .48138 L
.5212 .48123 L
.53163 .48097 L
.54053 .48065 L
.55025 .48023 L
.5719 .47893 L
.59192 .4773 L
.61541 .47484 L
.63734 .47201 L
.67754 .46534 L
.71928 .45621 L
.76231 .44405 L
.82882 .41817 L
.8621 .40073 L
.88986 .38277 L
.91477 .36271 L
.93463 .34244 L
.94391 .33082 L
.95264 .31784 L
.95931 .30576 L
.96433 .29448 L
.96836 .28278 L
.97002 .27659 L
.97143 .27003 L
.97236 .2643 L
.97299 .25895 L
.97341 .25307 L
.97352 .24977 L
.97354 .24677 L
.97338 .24121 L
Mistroke
.97301 .23607 L
.97236 .23043 L
.97138 .22447 L
.96907 .2145 L
.96558 .20359 L
.96039 .19132 L
.95453 .18023 L
.93752 .156 L
.91832 .13567 L
.89409 .11556 L
.83981 .08261 L
.8045 .0667 L
.7698 .05394 L
.73536 .04354 L
.69617 .03397 L
.65767 .0266 L
.62116 .02125 L
.6003 .01887 L
.58033 .01701 L
.56925 .01616 L
.55714 .01537 L
.54597 .01477 L
.53584 .01434 L
.52536 .014 L
.5155 .01377 L
.50508 .01364 L
.49383 .01362 L
.48395 .0137 L
.47353 .01389 L
.46465 .01414 L
.45493 .0145 L
.44258 .01509 L
.43095 .01579 L
.40927 .01746 L
.38613 .01979 L
.3613 .02294 L
.31762 .03024 L
.27874 .03882 L
.24253 .04884 L
.20573 .06143 L
.14598 .08867 L
.11452 .10791 L
.08854 .12783 L
.06874 .14692 L
.05115 .16884 L
.04404 .18007 L
.0376 .19243 L
.03272 .20428 L
.02928 .21529 L
.02704 .22531 L
Mistroke
.02613 .23102 L
.02553 .23636 L
.02515 .24201 L
.02503 .24716 L
.02517 .2531 L
.02556 .25873 L
.02621 .26431 L
.02723 .27045 L
.02862 .27685 L
.03023 .28284 L
.03385 .29345 L
.03879 .30475 L
.05403 .32983 L
.07269 .35178 L
.0933 .37062 L
.11897 .38946 L
.17383 .41954 L
.21221 .43525 L
.25131 .44807 L
.28816 .45779 L
.33054 .46659 L
.35096 .47001 L
.37323 .4732 L
.39271 .47553 L
.41416 .47763 L
.42677 .47864 L
.43851 .47943 L
.4507 .48011 L
.46177 .4806 L
.4727 .48096 L
.483 .48119 L
.49387 .48132 L
.50563 .48133 L
.51594 .48123 L
.52556 .48105 L
.53609 .48074 L
.54736 .48028 L
.55915 .47967 L
.57027 .47896 L
.59101 .47731 L
.62788 .47323 L
.66705 .46721 L
.70714 .45907 L
.74321 .44979 L
.7838 .43673 L
.81841 .4229 L
.88002 .38958 L
.90686 .36961 L
.93055 .34705 L
.94761 .32565 L
Mistroke
.95947 .30548 L
.96452 .29407 L
.96673 .28801 L
.96874 .28157 L
.97021 .2759 L
.97152 .26966 L
.97243 .26397 L
.97304 .25864 L
.97342 .25335 L
.97356 .24758 L
.97345 .24213 L
.97313 .23709 L
.97266 .23258 L
.97195 .22759 L
.97099 .2224 L
.96989 .21753 L
.96667 .2066 L
.96284 .19666 L
.9512 .1747 L
.93624 .15441 L
.91628 .13373 L
.87069 .09971 L
.83728 .0813 L
.80231 .06575 L
.76866 .0535 L
.72925 .04183 L
.69174 .03296 L
.64981 .02525 L
.6261 .02182 L
.60412 .0192 L
.58154 .01704 L
.56042 .0155 L
.54099 .01448 L
.5301 .01407 L
.52021 .0138 L
.50932 .01362 L
.49753 .01355 L
.4864 .01361 L
.47617 .01377 L
.46656 .01402 L
.4576 .01433 L
.43729 .01533 L
.41761 .01671 L
.39666 .01861 L
.35101 .02441 L
.31002 .03172 L
.26681 .04186 L
.22346 .05502 L
.15799 .08236 L
.12555 .10067 L
Mistroke
.09873 .11948 L
.07578 .13965 L
.05805 .15948 L
.04348 .18109 L
.03745 .19281 L
.0323 .20551 L
.02898 .21652 L
.02755 .22276 L
.02652 .22853 L
.02584 .23359 L
.02533 .23916 L
.02508 .24498 L
.02509 .25043 L
.02534 .25573 L
.02579 .26075 L
.02637 .26525 L
.02719 .27015 L
.02974 .28106 L
.03298 .29109 L
.03803 .30311 L
.04373 .31399 L
.06026 .33784 L
.0789 .35787 L
.10246 .37778 L
.1521 .40887 L
.18469 .4243 L
.2176 .43714 L
.2552 .44915 L
.29844 .46009 L
.34116 .46838 L
.36206 .47162 L
.3819 .47424 L
.41938 .47801 L
.43948 .47944 L
.45083 .48007 L
.46124 .48053 L
.47206 .48089 L
.48212 .48113 L
.49317 .48127 L
.50496 .48129 L
.51619 .48119 L
.52677 .48097 L
.53625 .48069 L
.54651 .48028 L
.56753 .47911 L
.58993 .47737 L
.6109 .47526 L
.62984 .47294 L
.67526 .46569 L
.71672 .45678 L
Mistroke
.75751 .44552 L
.79308 .43328 L
.82905 .41805 L
.86419 .39951 L
.89163 .38151 L
.91365 .36376 L
.93275 .34464 L
.94738 .32601 L
.95983 .30479 L
.96483 .29331 L
.96894 .28091 L
.97053 .27461 L
.97187 .26776 L
.97236 .26461 L
.97279 .26127 L
.97333 .25528 L
.97356 .24952 L
.97354 .24414 L
.97324 .23823 L
.97295 .23492 L
.9726 .2319 L
.97169 .22592 L
.97056 .22031 L
.96776 .20988 L
.96374 .19876 L
.95824 .18688 L
.94532 .16598 L
.93014 .14748 L
.91 .12813 L
.88395 .10827 L
.85289 .08936 L
.82003 .07318 L
.78615 .05953 L
.74661 .04661 L
.71187 .03743 L
.6719 .029 L
.62718 .02192 L
.60214 .01895 L
.57839 .01675 L
.56753 .01593 L
.55607 .0152 L
.54614 .01468 L
.53551 .01423 L
.52402 .01386 L
.51331 .01364 L
.50676 .01356 L
.50058 .01352 L
.48902 .01355 L
.47869 .01369 L
.46762 .01396 L
Mistroke
.45719 .01432 L
.44767 .01474 L
.4245 .01615 L
.40267 .01799 L
.35993 .02307 L
.33624 .02679 L
.31468 .03077 L
.24355 .0485 L
.21018 .05974 L
.17571 .07388 L
.14467 .0894 L
.11526 .10742 L
.09281 .12426 L
.07209 .14341 L
.05377 .16519 L
.04064 .18634 L
.03454 .19959 L
.03209 .20617 L
.03016 .21227 L
.02869 .21773 L
.02736 .22376 L
.02633 .22984 L
.0259 .23317 L
.02557 .2363 L
.02519 .24209 L
.02509 .24533 L
.02507 .24827 L
.02525 .254 L
.02566 .25938 L
.026 .26244 L
.02645 .26567 L
.02746 .27144 L
.02885 .27763 L
.03074 .2844 L
.03475 .29562 L
.04022 .3075 L
.05307 .32842 L
.07048 .3494 L
.09055 .36827 L
.13689 .40046 L
.16504 .41534 L
.19898 .43015 L
.23466 .44288 L
.2756 .45463 L
.31571 .4637 L
.35385 .47038 L
.39128 .47529 L
.41037 .47721 L
.43142 .47889 L
.44233 .47959 L
Mistroke
.45391 .48019 L
.45997 .48045 L
.46664 .4807 L
.4784 .48103 L
.4895 .48121 L
.49573 .48127 L
.50142 .48128 L
.51247 .48122 L
.52295 .48104 L
.53297 .48078 L
.54361 .48039 L
.56269 .4794 L
.58525 .47776 L
.60553 .47583 L
.65025 .46998 L
.69701 .4613 L
.73923 .45089 L
.77598 .43947 L
.80944 .42675 L
.84256 .41142 L
.8942 .37963 L
.92 .35789 L
.94002 .33598 L
.95416 .3154 L
.96048 .30347 L
.96523 .2923 L
.96888 .28118 L
.97132 .27092 L
.97224 .26552 L
.97298 .25961 L
.97325 .25662 L
.97345 .25342 L
.9736 .24768 L
.97349 .24222 L
.97309 .23633 L
.97246 .23076 L
.97165 .22565 L
.96953 .216 L
.96645 .20587 L
.96205 .19476 L
.95618 .18301 L
.94263 .16232 L
.92175 .13884 L
.89841 .11871 L
.87321 .10122 L
.84306 .08414 L
.78115 .05771 L
.74312 .04558 L
.70541 .0359 L
.66221 .02724 L
Mistroke
.63905 .02355 L
.6139 .02024 L
.5913 .01785 L
.57056 .01613 L
.56051 .01545 L
.54958 .01483 L
.5393 .01436 L
.52966 .01401 L
.51845 .01372 L
.5125 .01361 L
.50609 .01354 L
.4994 .0135 L
.49304 .01351 L
.48733 .01355 L
.4811 .01363 L
.46985 .01388 L
.46357 .01407 L
.45789 .01428 L
.43643 .01535 L
.42473 .01613 L
.41242 .0171 L
.39053 .01922 L
.34203 .02581 L
.30146 .0335 L
.2588 .04404 L
.21927 .05647 L
.18432 .07008 L
.12646 .10011 L
.09906 .11925 L
.07723 .13825 L
.05741 .16034 L
.04894 .17221 L
.04138 .18495 L
.03628 .19548 L
.03178 .20713 L
.03016 .21228 L
.02868 .21782 L
.02752 .22301 L
.02665 .22782 L
.02583 .23389 L
.02552 .23709 L
.02528 .24048 L
.02509 .24618 L
.0251 .24942 L
.02519 .25244 L
.02555 .25808 L
.02611 .26322 L
.02703 .26914 L
.02817 .27474 L
.03089 .28485 L
Mistroke
.03472 .29552 L
.04398 .31436 L
.05887 .33606 L
.07584 .35486 L
.09776 .37412 L
.12464 .39304 L
.18145 .42285 L
.21736 .43701 L
.25317 .44852 L
.2947 .45921 L
.34128 .46836 L
.36319 .47174 L
.38676 .47477 L
.40736 .47692 L
.42973 .47876 L
.44231 .47957 L
.45386 .48018 L
.4655 .48065 L
.47659 .48098 L
.48281 .48111 L
.48945 .4812 L
.49571 .48126 L
.50139 .48127 L
.50809 .48125 L
.51534 .48117 L
.52218 .48105 L
.52847 .4809 L
.53884 .48057 L
.54995 .48009 L
.56993 .47892 L
.59353 .47702 L
.61486 .47479 L
.66037 .46833 L
.70209 .46018 L
.73858 .45107 L
.77684 .43918 L
.81173 .42579 L
.84635 .40946 L
.87544 .39259 L
.8992 .37583 L
.92049 .35743 L
.93692 .33982 L
.9518 .31932 L
.95797 .30853 L
.96352 .29666 L
.96759 .28552 L
.96905 .28059 L
.97043 .27516 L
.97143 .27036 L
.9723 .2652 L
Mistroke
.97298 .25974 L
.97339 .25462 L
.97353 .25152 L
.9736 .24821 L
.9735 .24227 L
.97329 .23864 L
.973 .23522 L
.97265 .23215 L
.97219 .22884 L
.97109 .22267 L
.96958 .21617 L
.96602 .20463 L
.96153 .19358 L
.95641 .18341 L
.94155 .1609 L
.92296 .14001 L
.89835 .11865 L
.87309 .10113 L
.8429 .08405 L
.81304 .07011 L
.77744 .0564 L
.7089 .0367 L
.66843 .02833 L
.64575 .02455 L
.62436 .02152 L
.58581 .01734 L
.56518 .01575 L
.55443 .01508 L
.54303 .01451 L
.53707 .01426 L
.53051 .01403 L
.51896 .01372 L
.51244 .0136 L
.50545 .01353 L
.49885 .0135 L
.49283 .01351 L
.48118 .01363 L
.4746 .01375 L
.46851 .01391 L
.45735 .01429 L
.44551 .01483 L
.42398 .01618 L
.40388 .01786 L
.35871 .02324 L
.3192 .02988 L
.27748 .03909 L
.23607 .05084 L
.19985 .06369 L
.14169 .09107 L
.11347 .10866 L
Mistroke
.09084 .12592 L
.0702 .14541 L
.05236 .16718 L
.04057 .18651 L
.03532 .19773 L
.03138 .20836 L
.02961 .21426 L
.02801 .22072 L
.02682 .22684 L
.02599 .23253 L
.02544 .23817 L
.02516 .2433 L
.0251 .24921 L
.02531 .25478 L
.02584 .26087 L
.02621 .26393 L
.02672 .26729 L
.02915 .27873 L
.03099 .28514 L
.03334 .29197 L
.03857 .30417 L
.05241 .32747 L
.06931 .34814 L
.09219 .36961 L
.12113 .39078 L
.17938 .42194 L
.21727 .43697 L
.25549 .44918 L
.29579 .45945 L
.33491 .46726 L
.37706 .47359 L
.39978 .47618 L
.4243 .47836 L
.44548 .47975 L
.45748 .48033 L
.46856 .48075 L
.47827 .48101 L
.48897 .48119 L
.50014 .48126 L
.51059 .48122 L
.52075 .48107 L
.53039 .48084 L
.53904 .48056 L
.54844 .48016 L
.56944 .47895 L
.58878 .47744 L
.612 .47511 L
.6331 .47248 L
.67964 .46485 L
.71916 .45617 L
Mistroke
.75891 .44508 L
.8221 .42126 L
.85405 .40532 L
.88093 .389 L
.90632 .37011 L
.92963 .34811 L
.94732 .32616 L
.9542 .31535 L
.95973 .30506 L
.96423 .29493 L
.96758 .28557 L
.97045 .27509 L
.97164 .26928 L
.97251 .26375 L
.97311 .25842 L
.97349 .25274 L
.97361 .24737 L
.97351 .2425 L
.97315 .23677 L
.97282 .23354 L
.97245 .23058 L
.97157 .22513 L
.97038 .21938 L
.96709 .20772 L
.96294 .19677 L
.95247 .17664 L
.93738 .1557 L
.91664 .13399 L
.89508 .11617 L
.86884 .0985 L
.8139 .07047 L
.77967 .05717 L
.74621 .04645 L
.70829 .03655 L
.6649 .0277 L
.62569 .02169 L
.58836 .01757 L
.56746 .0159 L
.54834 .01476 L
.53771 .01428 L
.52617 .01389 L
.51525 .01364 L
.50517 .01352 L
.49401 .0135 L
.48341 .01359 L
.47389 .01377 L
.46353 .01406 L
.45231 .0145 L
.44039 .01511 L
.41905 .01655 L
Mistroke
.39754 .01848 L
.37748 .02073 L
.34062 .02604 L
.29774 .03432 L
.25993 .04373 L
.22086 .05591 L
.18191 .07113 L
.14909 .08701 L
.12203 .10294 L
.07778 .13773 L
.05852 .15895 L
.05005 .17055 L
.04238 .18313 L
.03681 .19429 L
.03191 .20676 L
.03018 .21227 L
.02859 .21822 L
.02738 .22378 L
.02647 .22904 L
.02573 .23489 L
.0253 .2402 L
.0251 .24593 L
.0251 .24916 L
.02518 .25213 L
.02548 .2571 L
.02604 .26256 L
.02688 .26824 L
.02791 .27354 L
.03117 .28568 L
.0352 .29665 L
.0411 .30915 L
.04792 .32081 L
.06489 .34324 L
.08452 .363 L
.11016 .38334 L
.14179 .40322 L
.20958 .43417 L
.25265 .44835 L
.29474 .45921 L
.3334 .46699 L
.37716 .4736 L
.39968 .47616 L
.42402 .47833 L
.4359 .47917 L
.44717 .47983 L
.45822 .48036 L
.46834 .48074 L
.47857 .48101 L
.48959 .4812 L
.4998 .48126 L
Mistroke
.50952 .48123 L
.52076 .48107 L
.53119 .48082 L
.54262 .48041 L
.55479 .47984 L
.57934 .47823 L
.60229 .47616 L
.64452 .47085 L
.68331 .46413 L
.71784 .4565 L
.79049 .43426 L
.82284 .42093 L
.85471 .40496 L
.90384 .37215 L
.92795 .34991 L
.94631 .3276 L
.9589 .30673 L
.96433 .29467 L
.96826 .28339 L
.96976 .27797 L
.97107 .27224 L
.97198 .26728 L
.97274 .26197 L
.97329 .25623 L
.97356 .25088 L
.97361 .24761 L
.97358 .24452 L
.97331 .23875 L
.97284 .23366 L
.97211 .22828 L
.9713 .2237 L
.97021 .21867 L
.96703 .20753 L
.96313 .19721 L
.95089 .17411 L
.93577 .15377 L
.91385 .13146 L
.88886 .11164 L
.8329 .07908 L
.79676 .06348 L
.76144 .05108 L
.72639 .041 L
.68671 .03184 L
.64781 .02486 L
.6111 .0199 L
.58956 .01767 L
.56979 .01606 L
.55879 .01533 L
.54681 .01468 L
.53547 .01419 L
Mistroke
.52497 .01386 L
.5153 .01364 L
.50623 .01353 L
.49627 .01349 L
.48555 .01356 L
.47491 .01374 L
.46374 .01405 L
.45421 .01442 L
.44382 .01492 L
.41977 .01649 L
.39811 .01842 L
.37337 .02124 L
.35034 .02449 L
.31028 .03165 L
.26856 .04139 L
.19791 .06446 L
.16188 .08043 L
.13136 .0971 L
.1033 .11601 L
.08031 .13531 L
.05848 .159 L
.05002 .1706 L
.04317 .18171 L
.03767 .19242 L
.03349 .20236 L
.02982 .21351 L
.02832 .2194 L
.02704 .22563 L
.02615 .23131 L
.0255 .23739 L
.02517 .24314 L
.0251 .24836 L
.0253 .25451 L
.02556 .25797 L
.02588 .26116 L
.02668 .26702 L
.02784 .27321 L
.03041 .28324 L
.0341 .29393 L
.04318 .31294 L
.05792 .33484 L
.07501 .35402 L
.09617 .37284 L
.12236 .39156 L
.17805 .42134 L
.21695 .43685 L
.2564 .44943 L
.29353 .45893 L
.33604 .46745 L
.35671 .47078 L
Mistroke
.37917 .47385 L
.39881 .47607 L
.42036 .47804 L
.43308 .47898 L
.44488 .47971 L
.45597 .48026 L
.46187 .48051 L
.46823 .48073 L
.47921 .48103 L
.48952 .4812 L
.50132 .48126 L
.51214 .4812 L
.52176 .48105 L
.53202 .48079 L
.5417 .48045 L
.55047 .48006 L
.5719 .47878 L
.59201 .47715 L
.63154 .47269 L
.67333 .46604 L
.71344 .45756 L
.74936 .44798 L
.7897 .43456 L
.82393 .42044 L
.88463 .3865 L
.91208 .36518 L
.93378 .34351 L
.95024 .32179 L
.96146 .30142 L
.96613 .28989 L
.96814 .28378 L
.96992 .27731 L
.9712 .2716 L
.97229 .26534 L
.973 .25963 L
.97342 .2543 L
.9736 .24896 L
.97354 .24317 L
.97323 .2377 L
.97272 .23266 L
.97209 .22813 L
.9712 .22314 L
.96876 .2131 L
.96518 .2023 L
.96023 .19081 L
.9485 .17047 L
.93088 .14824 L
.91064 .12864 L
.88438 .10851 L
.85204 .08884 L
Mistroke
.81743 .07199 L
.78181 .05792 L
.70861 .03662 L
.67047 .02869 L
.62713 .02188 L
.60485 .0192 L
.58069 .0169 L
.5689 .01599 L
.55768 .01527 L
.54767 .01472 L
.53658 .01424 L
.52635 .0139 L
.51673 .01367 L
.50657 .01353 L
.4956 .01349 L
.48596 .01356 L
.47581 .01372 L
.46715 .01395 L
.45768 .01427 L
.44646 .01478 L
.43628 .01535 L
.41354 .017 L
.39264 .01899 L
.37309 .02128 L
.33366 .02723 L
.29167 .03569 L
.24979 .04663 L
.21279 .05879 L
.15304 .08492 L
.12367 .10189 L
.09976 .11871 L
.07799 .13752 L
.0587 .15873 L
.04435 .17965 L
.03473 .1992 L
.03043 .21143 L
.02759 .22277 L
.02652 .22873 L
.02605 .23216 L
.0257 .23529 L
.02541 .2386 L
.02521 .24214 L
.02511 .24543 L
.0251 .24854 L
.02529 .25419 L
.02577 .26017 L
.02641 .26528 L
.02737 .27089 L
.02869 .27689 L
.03044 .28333 L
Mistroke
.03448 .29488 L
.03934 .30571 L
.04561 .31709 L
.05968 .33705 L
.08088 .35967 L
.10412 .37896 L
.13221 .39767 L
.16664 .41607 L
.20234 .43143 L
.23834 .44402 L
.27662 .45486 L
.31321 .46316 L
.35536 .47058 L
.37941 .47388 L
.40198 .47639 L
.42399 .47833 L
.44758 .47985 L
.45984 .48043 L
.47139 .48083 L
.478 .481 L
.48407 .48112 L
.49074 .48121 L
.49777 .48126 L
.5087 .48123 L
.52038 .48108 L
.5314 .48081 L
.54141 .48046 L
.55315 .47993 L
.56585 .47919 L
.58881 .47744 L
.60935 .47541 L
.63123 .47274 L
.67002 .46664 L
.71455 .4573 L
.7534 .44678 L
.79142 .43392 L
.8298 .41771 L
.88984 .38283 L
.91528 .36233 L
.9353 .34175 L
.94985 .3224 L
.96177 .30073 L
.96638 .28921 L
.97014 .27643 L
.97152 .26995 L
.97213 .26638 L
.97261 .26299 L
.97298 .25983 L
.97328 .2564 L
.97358 .25039 L
Mistroke
.97359 .24479 L
.97348 .24161 L
.9733 .23862 L
.97272 .23261 L
.97226 .22924 L
.97176 .22615 L
.96937 .2153 L
.96779 .20987 L
.9658 .20397 L
.96103 .19249 L
.95463 .18023 L
.93976 .1586 L
.92141 .13848 L
.90127 .12091 L
.84496 .08509 L
.81162 .06949 L
.77162 .0544 L
.73198 .04247 L
.69233 .033 L
.65534 .02606 L
.61385 .02022 L
.58981 .0177 L
.56783 .01592 L
.55557 .01514 L
.54229 .01447 L
.53617 .01422 L
.52972 .014 L
.51815 .0137 L
.50745 .01354 L
.49599 .01349 L
.48518 .01357 L
.47534 .01373 L
.46379 .01405 L
.45728 .01429 L
.45128 .01455 L
.42862 .01584 L
.40724 .01755 L
.38782 .01952 L
.3448 .02536 L
.30794 .03213 L
.27057 .04086 L
.19714 .06477 L
.15997 .08138 L
.1288 .09867 L
.10179 .11716 L
.07675 .13874 L
.05738 .1604 L
.04344 .18125 L
.03415 .20066 L
.0303 .21186 L
Mistroke
.02766 .2224 L
.02662 .22813 L
.02588 .23358 L
.02542 .23848 L
.02515 .24381 L
.02512 .24961 L
.02521 .25253 L
.02538 .25576 L
.02591 .26146 L
.02665 .2668 L
.02764 .27222 L
.02897 .278 L
.03206 .28836 L
.03689 .30054 L
.04236 .31147 L
.05774 .33462 L
.0765 .35549 L
.11899 .38937 L
.14779 .40651 L
.17715 .42093 L
.20926 .43405 L
.24622 .44645 L
.27995 .45569 L
.31836 .46419 L
.34233 .46852 L
.36497 .47198 L
.38876 .47498 L
.41056 .47721 L
.43221 .47892 L
.45272 .48011 L
.46404 .48059 L
.47447 .48091 L
.48593 .48115 L
.4917 .48122 L
.49804 .48126 L
.50879 .48123 L
.51872 .48111 L
.52962 .48086 L
.54117 .48047 L
.55115 .48003 L
.5605 .47952 L
.58172 .47804 L
.60062 .47633 L
.61781 .47444 L
.65593 .46906 L
.69333 .46209 L
.73268 .45269 L
.80576 .42829 L
Mfstroke
.92291 .3539 m
.9401 .33447 L
.95295 .31567 L
.95881 .30482 L
.96341 .29444 L
.96758 .28234 L
.969 .27708 L
.9703 .27126 L
.9713 .26556 L
.97199 .26022 L
.97245 .25457 L
.97266 .24849 L
.97258 .24286 L
.97226 .23751 L
.97178 .23271 L
.97103 .22749 L
.96983 .22128 L
.96847 .21566 L
.96447 .20317 L
.95959 .19173 L
.95398 .18111 L
.93885 .15914 L
.9183 .13705 L
.89723 .11926 L
.87062 .10103 L
.83818 .08309 L
.79947 .06596 L
.75994 .052 L
.72094 .04097 L
.6812 .03204 L
.63732 .02451 L
.61564 .02161 L
.59198 .01902 L
.57832 .01779 L
.56573 .01683 L
.55375 .01606 L
.5409 .01539 L
.52963 .01494 L
.51938 .01464 L
.50906 .01444 L
.49932 .01434 L
.48794 .01435 L
.47746 .01447 L
.46596 .01472 L
.46017 .0149 L
.4538 .01513 L
.43106 .0163 L
.41836 .01717 L
.40679 .01812 L
.38399 .02039 L
Mistroke
.36356 .02291 L
.32314 .02933 L
.28158 .03811 L
.2119 .05886 L
.17631 .07321 L
.14123 .09077 L
.11191 .10904 L
.08798 .12751 L
.06707 .14779 L
.05147 .1672 L
.03817 .18964 L
.03272 .20228 L
.0307 .20802 L
.0288 .21439 L
.02739 .22008 L
.02617 .22623 L
.02563 .22963 L
.02522 .23275 L
.02464 .23887 L
.02439 .24416 L
.02437 .24995 L
.02465 .25598 L
.02517 .26159 L
.02558 .2648 L
.02613 .26828 L
.02737 .27457 L
.03056 .28626 L
.0357 .29977 L
.04177 .31202 L
.0552 .33264 L
.07363 .35383 L
.11677 .389 L
.1488 .40814 L
.18273 .42446 L
.21557 .4374 L
.25436 .44986 L
.29106 .45933 L
.33237 .46772 L
.35576 .47152 L
.37754 .47448 L
.39996 .47699 L
.42103 .47885 L
.43936 .4801 L
.4488 .48061 L
.45906 .48107 L
.47033 .48144 L
.48099 .48169 L
.49137 .48181 L
.50096 .48184 L
.51105 .48176 L
Mistroke
.5205 .4816 L
.53085 .48132 L
.54197 .48091 L
.55356 .48034 L
.56455 .47968 L
.58507 .47812 L
.60781 .47586 L
.62899 .47326 L
.66782 .46715 L
.70829 .45877 L
.75007 .44764 L
.78471 .43616 L
.81891 .42235 L
.87308 .39358 L
.89908 .37531 L
.91965 .35751 L
.93946 .33581 L
.95414 .31432 L
.95938 .30445 L
.96403 .29385 L
.96725 .28471 L
.96997 .27456 L
.97112 .26886 L
.97194 .26363 L
.97258 .25787 L
.97295 .25181 L
.97303 .24651 L
.97289 .24159 L
.97251 .23619 L
.97184 .23044 L
.97091 .22475 L
.96958 .21853 L
.9659 .20602 L
.96133 .19458 L
.95606 .18401 L
.94071 .16083 L
.91908 .13716 L
.89416 .11632 L
.86667 .09801 L
.8061 .06798 L
.7702 .05468 L
.73563 .04419 L
.6965 .03458 L
.65243 .02622 L
.63197 .02314 L
.6101 .02036 L
.58962 .01822 L
.57039 .01661 L
.55223 .01543 L
.54287 .01496 L
Mistroke
.5327 .01454 L
.52154 .01419 L
.51097 .01398 L
.50067 .01388 L
.49116 .01388 L
.48006 .01399 L
.46951 .0142 L
.46005 .01449 L
.44973 .0149 L
.42675 .01621 L
.40554 .0179 L
.36748 .02213 L
.32781 .02829 L
.28222 .03785 L
.24133 .04903 L
.20695 .06073 L
.17177 .07538 L
.1136 .10812 L
.08729 .12843 L
.06659 .14871 L
.05079 .16867 L
.03954 .18754 L
.03465 .19819 L
.03042 .20991 L
.02887 .21531 L
.02748 .22108 L
.02644 .22646 L
.02568 .23148 L
.0251 .23677 L
.02474 .24258 L
.02465 .24824 L
.02484 .25428 L
.02529 .25991 L
.02595 .26522 L
.02674 .26998 L
.0278 .27512 L
.03108 .28689 L
.03579 .29921 L
.0474 .32085 L
.06168 .34024 L
.078 .35764 L
.1251 .39392 L
.15455 .41067 L
.19012 .4271 L
.22413 .4399 L
.26276 .45173 L
.3031 .46154 L
.34113 .46877 L
.38049 .47442 L
.39867 .47644 L
Mistroke
.4183 .47824 L
.42946 .47908 L
.43966 .47974 L
.45005 .4803 L
.45968 .48073 L
.47092 .48111 L
.47685 .48126 L
.48314 .48138 L
.49372 .48149 L
.50538 .48149 L
.51121 .48145 L
.51735 .48136 L
.5283 .48111 L
.54007 .48071 L
.55291 .48011 L
.57585 .47863 L
.59703 .47679 L
.63766 .47189 L
.67367 .46596 L
.71388 .45738 L
.75017 .44761 L
.82008 .42193 L
.85137 .40649 L
.88224 .38777 L
.90541 .37046 L
.92678 .35067 L
.94343 .331 L
.95552 .31237 L
.96113 .30131 L
.96544 .29078 L
.96895 .2797 L
.97039 .27378 L
.97162 .26737 L
.97236 .26223 L
.97292 .2566 L
.97322 .25072 L
.97325 .24523 L
.97305 .24009 L
.97268 .23542 L
.97203 .23003 L
.97119 .22495 L
.97004 .21945 L
.96849 .21342 L
.96442 .2013 L
.95956 .19022 L
.95406 .17998 L
.93843 .15754 L
.91676 .1346 L
.89215 .11447 L
.86583 .09713 L
Mistroke
.83052 .07838 L
.79513 .06326 L
.72229 .04031 L
.67907 .03065 L
.63674 .0235 L
.59648 .01859 L
.57328 .01655 L
.55146 .01513 L
.53959 .01456 L
.52831 .01414 L
.51818 .01388 L
.50714 .0137 L
.50144 .01366 L
.49514 .01365 L
.48857 .01368 L
.4824 .01374 L
.4714 .01396 L
.46521 .01413 L
.45955 .01432 L
.43977 .01523 L
.42145 .01644 L
.40147 .01814 L
.38032 .02041 L
.33785 .02648 L
.30041 .03367 L
.26168 .04314 L
.22278 .0551 L
.15963 .08133 L
.12882 .09839 L
.10316 .11581 L
.07899 .13622 L
.05742 .15993 L
.04925 .17129 L
.04181 .18363 L
.03645 .19447 L
.03178 .20634 L
.02977 .21274 L
.02822 .21865 L
.02703 .22421 L
.02602 .23032 L
.02538 .23583 L
.025 .24096 L
.02484 .24639 L
.02493 .2522 L
.02529 .25799 L
.02588 .26333 L
.02678 .26918 L
.02806 .27537 L
.0309 .2857 L
.03505 .29698 L
Mistroke
.04547 .31738 L
.05842 .33592 L
.07713 .3565 L
.10189 .37765 L
.12722 .39497 L
.15758 .41194 L
.19069 .42707 L
.22311 .43929 L
.29195 .45881 L
.33203 .46697 L
.35452 .47066 L
.37585 .47362 L
.41416 .47769 L
.4347 .47924 L
.44543 .47988 L
.45687 .48044 L
.46274 .48067 L
.46924 .48089 L
.48072 .48117 L
.48716 .48128 L
.49412 .48134 L
.5007 .48136 L
.50673 .48134 L
.51772 .48121 L
.52395 .48109 L
.52975 .48093 L
.54145 .48053 L
.55393 .47994 L
.57761 .4784 L
.5998 .47643 L
.64073 .47139 L
.6797 .46479 L
.72107 .45561 L
.76216 .44394 L
.7983 .43113 L
.85621 .40393 L
.88441 .38643 L
.90715 .36917 L
.92762 .34998 L
.94547 .32845 L
.95261 .31764 L
.9584 .30729 L
.96277 .29795 L
.96671 .2876 L
.97003 .27601 L
.97137 .26964 L
.97232 .26368 L
.97294 .25809 L
.97329 .25299 L
.97342 .24711 L
Mistroke
.97328 .24153 L
.97284 .2355 L
.9725 .23246 L
.97204 .22911 L
.97101 .22321 L
.96977 .21768 L
.96607 .20533 L
.96067 .19219 L
.94812 .17027 L
.93278 .15065 L
.91206 .13015 L
.88571 .10969 L
.85361 .08994 L
.81957 .07316 L
.7865 .05983 L
.74752 .04702 L
.71071 .03729 L
.66942 .02866 L
.64597 .02472 L
.62422 .02163 L
.60182 .019 L
.58085 .01702 L
.56147 .01559 L
.55151 .01501 L
.54074 .01449 L
.53454 .01424 L
.52884 .01405 L
.51764 .01376 L
.50745 .0136 L
.4967 .01355 L
.48712 .0136 L
.47688 .01375 L
.46723 .01398 L
.45845 .01428 L
.44816 .01472 L
.437 .01533 L
.41683 .01673 L
.39624 .01861 L
.3743 .02111 L
.33535 .02689 L
.29054 .03588 L
.25136 .04608 L
.21295 .05862 L
.17407 .0745 L
.11294 .10888 L
.08688 .12915 L
.06622 .14956 L
.05108 .16879 L
.03848 .19036 L
.03352 .20185 L
Mistroke
.02937 .2146 L
.02779 .22107 L
.02707 .22465 L
.02648 .22804 L
.02602 .23119 L
.02561 .23462 L
.02513 .24064 L
.02495 .24624 L
.02496 .24943 L
.02505 .25243 L
.02545 .25845 L
.0258 .26183 L
.02621 .26493 L
.02708 .27014 L
.02828 .27582 L
.03151 .2872 L
.03592 .29873 L
.04196 .31105 L
.05618 .33284 L
.07392 .35314 L
.09354 .37091 L
.14878 .40722 L
.18168 .4231 L
.22124 .4385 L
.26052 .45072 L
.29989 .46047 L
.33666 .46766 L
.37798 .47379 L
.40195 .47647 L
.42386 .47839 L
.4361 .47924 L
.44936 .48 L
.46192 .48056 L
.47348 .48093 L
.48426 .48116 L
.49431 .48128 L
.50534 .48129 L
.51715 .48116 L
.52308 .48105 L
.52953 .48089 L
.54123 .48049 L
.55259 .47997 L
.56307 .47937 L
.58449 .47781 L
.60396 .47597 L
.64713 .47042 L
.68416 .46392 L
.72179 .45545 L
.79589 .43212 L
.83355 .41581 L
Mistroke
.86523 .3988 L
.89278 .38057 L
.91846 .35923 L
.93847 .33777 L
.95305 .31708 L
.96294 .29779 L
.96713 .28664 L
.97009 .27613 L
.97132 .27041 L
.97223 .26498 L
.97284 .26009 L
.97328 .25477 L
.97349 .24898 L
.9735 .24606 L
.97342 .24283 L
.97307 .23713 L
.9725 .23179 L
.97168 .22636 L
.97054 .22058 L
.96778 .21021 L
.96334 .198 L
.95822 .18703 L
.9436 .16376 L
.92552 .14274 L
.88417 .10851 L
.85594 .09111 L
.82707 .07644 L
.79543 .06307 L
.7589 .05037 L
.7255 .04086 L
.6874 .03205 L
.66359 .02753 L
.64108 .0239 L
.61741 .0207 L
.59569 .01831 L
.57411 .01642 L
.55364 .01507 L
.54234 .0145 L
.53193 .0141 L
.52048 .01377 L
.5147 .01366 L
.50837 .01357 L
.49671 .01351 L
.48593 .01357 L
.48031 .01365 L
.47411 .01377 L
.46763 .01394 L
.46156 .01413 L
.45046 .01459 L
.44031 .01511 L
Mistroke
.41753 .01666 L
.39852 .01837 L
.37791 .02066 L
.3371 .0266 L
.29374 .03517 L
.24957 .04664 L
.17718 .07315 L
.14339 .09004 L
.11544 .10722 L
.08913 .12728 L
.06506 .15097 L
.04852 .17273 L
.03693 .19384 L
.03218 .20573 L
.02889 .2167 L
.0275 .22279 L
.02689 .22601 L
.02633 .22944 L
.02589 .23275 L
.02557 .23575 L
.02515 .24159 L
.02501 .24722 L
.02512 .25247 L
.0255 .25822 L
.02583 .26144 L
.0262 .26436 L
.02717 .27025 L
.02854 .27663 L
.0319 .28815 L
.036 .29874 L
.04137 .30982 L
.0536 .32926 L
.07172 .35079 L
.09243 .3699 L
.11882 .38935 L
.15188 .40878 L
.18674 .42519 L
.22196 .43868 L
.26096 .45077 L
.29825 .46005 L
.3364 .46756 L
.37344 .47316 L
.39278 .47547 L
.41342 .47749 L
.43623 .47921 L
.44719 .47985 L
.45736 .48034 L
.4682 .48075 L
.47393 .48091 L
.48002 .48106 L
Mistroke
.49024 .48121 L
.50153 .48127 L
.51154 .48121 L
.52233 .48104 L
.5325 .48078 L
.54182 .48044 L
.5527 .47994 L
.5628 .47937 L
.58561 .4777 L
.60766 .47557 L
.63097 .47275 L
.67286 .46609 L
.71112 .45808 L
.77826 .43864 L
.81094 .42608 L
.84418 .41054 L
.87351 .39377 L
.90132 .3741 L
.92355 .35435 L
.9405 .33531 L
.95413 .31537 L
.96379 .29586 L
.96801 .284 L
.96965 .27815 L
.9709 .27275 L
.97182 .2679 L
.9726 .26258 L
.97316 .25723 L
.97348 .25157 L
.97355 .24837 L
.97354 .24535 L
.97331 .23969 L
.97277 .2336 L
.97234 .23017 L
.97184 .227 L
.96948 .21595 L
.9679 .21041 L
.96586 .20433 L
.95655 .18377 L
.94975 .17246 L
.94256 .1623 L
.90736 .12593 L
.8837 .10812 L
.85501 .09054 L
.79539 .063 L
.75452 .04897 L
.71345 .0378 L
.67482 .02954 L
.65409 .02589 L
.63148 .02249 L
Mistroke
.60935 .01972 L
.58892 .01763 L
.56822 .01596 L
.54846 .01477 L
.53731 .01427 L
.53118 .01405 L
.52542 .01388 L
.51526 .01365 L
.50401 .01351 L
.49809 .01349 L
.49185 .01351 L
.48069 .01363 L
.47447 .01375 L
.46868 .0139 L
.45555 .01435 L
.44388 .01491 L
.43125 .01566 L
.40844 .01743 L
.38642 .01966 L
.3663 .02215 L
.32158 .0294 L
.27601 .03943 L
.23797 .0502 L
.20507 .06163 L
.172 .07554 L
.13902 .09254 L
.11183 .10976 L
.08957 .12695 L
.06986 .14572 L
.05474 .16383 L
.0407 .18619 L
.03507 .19824 L
.03047 .21114 L
.02896 .21659 L
.0276 .22246 L
.02659 .22801 L
.02589 .23309 L
.02534 .23905 L
.02515 .24242 L
.02507 .24553 L
.02511 .25125 L
.02546 .25732 L
.02601 .26264 L
.02672 .26751 L
.02772 .27284 L
.02903 .27844 L
.03183 .28781 L
.03571 .29798 L
.04767 .32049 L
.06263 .34069 L
Mistroke
.08264 .36135 L
.10868 .38234 L
.13515 .39946 L
.16646 .41603 L
.19732 .4295 L
.23385 .44262 L
.26645 .45224 L
.30365 .46119 L
.34706 .46931 L
.36752 .47234 L
.38958 .47509 L
.41168 .47732 L
.43185 .47891 L
.44165 .47953 L
.45226 .48009 L
.46156 .4805 L
.47153 .48084 L
.4832 .48111 L
.49409 .48124 L
.50074 .48126 L
.50704 .48124 L
.51883 .4811 L
.52486 .48098 L
.53125 .48081 L
.54271 .4804 L
.55501 .47982 L
.56853 .479 L
.59045 .47728 L
.61383 .47489 L
.65538 .46913 L
.69679 .46132 L
.73378 .45236 L
.77551 .43961 L
.81086 .42614 L
.87439 .39324 L
.90343 .37244 L
.92658 .35131 L
.94329 .33171 L
.95755 .30928 L
.96306 .2977 L
.9677 .28512 L
.96947 .27898 L
.97085 .27313 L
.97186 .26786 L
.97269 .26212 L
.97322 .25683 L
.9735 .25186 L
.97358 .2464 L
.97339 .24052 L
.97292 .23469 L
Mistroke
.97213 .22856 L
.9712 .22334 L
.96993 .21764 L
.96698 .20746 L
.96287 .19667 L
.95302 .17758 L
.9365 .15468 L
.91722 .13456 L
.89186 .11382 L
.86051 .0936 L
.79865 .06424 L
.75905 .05034 L
.71954 .03927 L
.67917 .03035 L
.65721 .02639 L
.63342 .02274 L
.61022 .0198 L
.58896 .01762 L
.5674 .01589 L
.55768 .01527 L
.54698 .01469 L
.5373 .01426 L
.5269 .01391 L
.51591 .01365 L
.50564 .01352 L
.49541 .01349 L
.48571 .01356 L
.47702 .01369 L
.46757 .01393 L
.4573 .01428 L
.44599 .0148 L
.42318 .01622 L
.4022 .01801 L
.38268 .02009 L
.34235 .02574 L
.29962 .03388 L
.25693 .04455 L
.21938 .05641 L
.15835 .08217 L
.12833 .09893 L
.10397 .11548 L
.08125 .1344 L
.06115 .15565 L
.04737 .17463 L
.03595 .1962 L
.0313 .20856 L
.02817 .21995 L
.0269 .22628 L
.02637 .22963 L
.0259 .23319 L
Mistroke
.02555 .23663 L
.02531 .23973 L
.02508 .2458 L
.02515 .25184 L
.02548 .25738 L
.02614 .26346 L
.02658 .26652 L
.02715 .26986 L
.02988 .28148 L
.03342 .29221 L
.03849 .30402 L
.04421 .31477 L
.06074 .33839 L
.07931 .35822 L
.10287 .37805 L
.1523 .40893 L
.18481 .42431 L
.21781 .43717 L
.2549 .44901 L
.29775 .45989 L
.3401 .46815 L
.36087 .4714 L
.3807 .47404 L
.40033 .47623 L
.42177 .47816 L
.4414 .47951 L
.45954 .48041 L
.46974 .48078 L
.47928 .48103 L
.48976 .4812 L
.50099 .48126 L
.51277 .48119 L
.52392 .481 L
.53392 .48073 L
.54479 .48032 L
.56548 .47921 L
.58765 .47753 L
.60842 .4755 L
.62729 .47324 L
.67025 .46659 L
.71389 .45744 L
.7545 .44643 L
.79016 .43437 L
.82628 .41934 L
.86179 .40092 L
.89186 .38135 L
.91581 .36182 L
.93508 .34198 L
.9514 .31995 L
.95709 .31017 L
Mistroke
.96229 .29952 L
.966 .29021 L
.96922 .27997 L
.97074 .27373 L
.97186 .26791 L
.97268 .26235 L
.97326 .25641 L
.97356 .25056 L
.97358 .24506 L
.97338 .24013 L
.97295 .23479 L
.97221 .22902 L
.9713 .22377 L
.96843 .21204 L
.96476 .20126 L
.96039 .19118 L
.94753 .16908 L
.92886 .14607 L
.90613 .12485 L
.87747 .10393 L
.84669 .08601 L
.81548 .07115 L
.74776 .04691 L
.70905 .03673 L
.66646 .02797 L
.62797 .02199 L
.59139 .01784 L
.57008 .01608 L
.55061 .01487 L
.53979 .01436 L
.52804 .01394 L
.51693 .01367 L
.50669 .01353 L
.49546 .01349 L
.48481 .01357 L
.47526 .01373 L
.46487 .01401 L
.4536 .01444 L
.44165 .01503 L
.42026 .01645 L
.40072 .01816 L
.38251 .02012 L
.34165 .02586 L
.29863 .03411 L
.26075 .04349 L
.22159 .05565 L
.18261 .07081 L
.1496 .08673 L
.12242 .10268 L
.07801 .13749 L
Mistroke
.05866 .15876 L
.05016 .17038 L
.04247 .18296 L
.03688 .19413 L
.03196 .2066 L
.03022 .21211 L
.02862 .21806 L
.02741 .22361 L
.02649 .22886 L
.02608 .23183 L
.02571 .23504 L
.02527 .24065 L
.02514 .24384 L
.02508 .24721 L
.02523 .25324 L
.02562 .25881 L
.02622 .26401 L
.02714 .2697 L
.02841 .27578 L
.0324 .28937 L
.03758 .30209 L
.05092 .32534 L
.06785 .34656 L
.08703 .36522 L
.11155 .38433 L
.14194 .40331 L
.17342 .41925 L
.20483 .43239 L
.27256 .45382 L
.3112 .46276 L
.35513 .47055 L
.37785 .47368 L
.40244 .47644 L
.42588 .47847 L
.43695 .47923 L
.44733 .47984 L
.45806 .48035 L
.46788 .48072 L
.47881 .48102 L
.49055 .4812 L
.50181 .48126 L
.50818 .48123 L
.51408 .48117 L
.52488 .48098 L
.53638 .48064 L
.54703 .48022 L
.55851 .47963 L
.57922 .47823 L
.59924 .47646 L
.61748 .47447 L
Mistroke
.65884 .46858 L
.70272 .46004 L
.74645 .44883 L
.78487 .43633 L
.81981 .42228 L
.8545 .40507 L
.88196 .38831 L
.90757 .36906 L
.9273 .35059 L
.94519 .32916 L
.95171 .31947 L
.95779 .30887 L
.96267 .29868 L
.96632 .28934 L
.96982 .2777 L
.97126 .27128 L
.9723 .26521 L
.973 .25956 L
.97341 .25436 L
.9736 .24865 L
.97351 .24261 L
.97312 .23652 L
.97277 .23311 L
.97236 .23 L
.97135 .22397 L
.97011 .21827 L
.96637 .20561 L
.96079 .192 L
.94794 .16966 L
.92963 .14689 L
.9104 .12844 L
.88551 .1093 L
.858 .09215 L
.82569 .0757 L
.76049 .05078 L
.72065 .03954 L
.68174 .03084 L
.63741 .0233 L
.61199 .02 L
.58859 .01758 L
.56829 .01595 L
.5458 .01463 L
.53445 .01415 L
.52818 .01395 L
.52222 .01378 L
.51065 .01357 L
.50008 .01349 L
.49021 .01351 L
.4797 .01364 L
.46979 .01387 L
Mistroke
.46083 .01415 L
.45026 .01459 L
.43886 .01519 L
.41829 .0166 L
.39624 .01861 L
.3723 .02138 L
.32504 .02877 L
.28289 .03775 L
.24533 .04796 L
.2083 .06044 L
.17098 .07606 L
.14094 .0915 L
.1123 .10948 L
.08966 .12693 L
.06835 .14741 L
.0525 .167 L
.04081 .18605 L
.03561 .19704 L
.0317 .20738 L
.02845 .21882 L
.0271 .22526 L
.02618 .23112 L
.02581 .23412 L
.02551 .2373 L
.02517 .24301 L
.0251 .24915 L
.0252 .25264 L
.02539 .2559 L
.02594 .26179 L
.0267 .26715 L
.02787 .27333 L
.02926 .27917 L
.0324 .28937 L
.03669 .30012 L
.04682 .31907 L
.06281 .34084 L
.08083 .35963 L
.10363 .3786 L
.13137 .39717 L
.18952 .42628 L
.22608 .44002 L
.26241 .45111 L
.30442 .46134 L
.35139 .46997 L
.37346 .47312 L
.39717 .4759 L
.41762 .47782 L
.44032 .47944 L
.4531 .48013 L
.46483 .48061 L
Mistroke
.47131 .48082 L
.47839 .48101 L
.48508 .48113 L
.49129 .48121 L
.49755 .48125 L
.50345 .48126 L
.51447 .48117 L
.52065 .48107 L
.52633 .48095 L
.53915 .48055 L
.54951 .4801 L
.5606 .47951 L
.58052 .47813 L
.60403 .47597 L
.62526 .47351 L
.67046 .46656 L
.71179 .45795 L
.74787 .44842 L
.78558 .43607 L
.81986 .42226 L
.85372 .4055 L
.88204 .38826 L
.90502 .37119 L
.92546 .35251 L
.94107 .33467 L
.955 .31397 L
.96105 .30231 L
.96568 .29114 L
.96903 .2807 L
.97131 .27101 L
.9722 .26592 L
.97292 .26032 L
.97341 .25446 L
.9736 .24897 L
.97353 .24302 L
.97337 .23966 L
.97313 .23654 L
.97249 .23083 L
.97151 .22477 L
.97025 .21882 L
.9688 .21325 L
.9654 .2029 L
.96022 .19077 L
.95436 .17979 L
.93742 .15574 L
.91917 .13634 L
.89586 .11675 L
.84482 .08502 L
.80852 .0682 L
.77109 .05422 L
Mistroke
.73554 .04344 L
.69428 .03341 L
.6527 .02563 L
.61252 .02006 L
.59 .01771 L
.56919 .01601 L
.54619 .01465 L
.53459 .01416 L
.5285 .01396 L
.52189 .01378 L
.51076 .01357 L
.50026 .01349 L
.49004 .01352 L
.48063 .01363 L
.47044 .01385 L
.45926 .01421 L
.4476 .01472 L
.43674 .01532 L
.41695 .01671 L
.39902 .01833 L
.35923 .02316 L
.31877 .02996 L
.27729 .03914 L
.208 .06056 L
.17312 .07507 L
.14306 .09031 L
.11366 .10854 L
.08582 .13028 L
.06509 .15105 L
.04951 .17137 L
.03712 .19362 L
.03205 .20636 L
.03025 .21203 L
.02863 .21806 L
.02748 .22328 L
.02648 .22904 L
.0258 .23429 L
.02537 .23921 L
.02512 .245 L
.02513 .2503 L
.02543 .25642 L
.026 .26222 L
.02671 .26722 L
.0277 .27254 L
.03007 .28206 L
.03385 .29328 L
.03819 .30335 L
.05064 .32491 L
.06806 .34677 L
.08626 .36454 L
Mistroke
.10957 .38292 L
.13833 .40126 L
.173 .41905 L
.24426 .44585 L
.28551 .45705 L
.3255 .46555 L
.37101 .4728 L
.3945 .47562 L
.42071 .47807 L
.43192 .4789 L
.44376 .47964 L
.45402 .48017 L
.465 .48062 L
.47123 .48082 L
.47688 .48097 L
.48794 .48118 L
.49414 .48124 L
.50086 .48126 L
.50721 .48124 L
.51306 .48119 L
.52345 .48101 L
.53317 .48075 L
.54381 .48036 L
.55522 .47982 L
.57838 .4783 L
.59938 .47645 L
.64081 .47139 L
.6837 .46405 L
.72269 .45529 L
.75645 .44584 L
.79416 .43288 L
.8318 .41676 L
.86379 .39977 L
.89042 .38241 L
.91436 .36316 L
.93285 .34456 L
.94952 .3229 L
.95695 .31047 L
.96262 .2988 L
.96702 .28731 L
.97047 .275 L
.97176 .26859 L
.97267 .26257 L
.97305 .25912 L
.97331 .25595 L
.97351 .2523 L
.97361 .24882 L
.97354 .2431 L
.97317 .23701 L
.97255 .23127 L
Mistroke
.97175 .22608 L
.97052 .21997 L
.96884 .21339 L
.96488 .20154 L
.96025 .19084 L
.95421 .17953 L
.94058 .15964 L
.91993 .13707 L
.89712 .11769 L
.8696 .09896 L
.83564 .0804 L
.80035 .06488 L
.76453 .05206 L
.72694 .04114 L
.69081 .03268 L
.64915 .02506 L
.6253 .02164 L
.60281 .01898 L
.58039 .01687 L
.55985 .01539 L
.54806 .01474 L
.5369 .01425 L
.5251 .01386 L
.51843 .0137 L
.51228 .01359 L
.50079 .01349 L
.49004 .01352 L
.47824 .01367 L
.47163 .01382 L
.46558 .01399 L
.45348 .01445 L
.44031 .01511 L
.41645 .01675 L
.39401 .01884 L
.37002 .02168 L
.32743 .02833 L
.28738 .03669 L
.25207 .04597 L
.17852 .07263 L
.14579 .0888 L
.11375 .10848 L
.08787 .12847 L
.0672 .14868 L
.052 .16772 L
.03922 .18919 L
.03419 .20054 L
.02991 .21321 L
.02827 .21962 L
.02688 .22655 L
.02637 .22975 L
Mistroke
.02593 .23312 L
.02537 .23914 L
.02512 .24474 L
.02514 .25072 L
.02543 .25635 L
.02591 .26147 L
.02676 .26748 L
.02801 .27396 L
.03117 .28567 L
.03511 .29643 L
.04041 .30783 L
.05276 .32795 L
.07193 .35088 L
.09348 .37066 L
.11974 .38986 L
.15248 .409 L
.18674 .42511 L
.22173 .43852 L
.29403 .45904 L
.33513 .46729 L
.35686 .4708 L
.38102 .47407 L
.40344 .47654 L
.42765 .4786 L
.44113 .47949 L
.45342 .48014 L
.46581 .48065 L
.47755 .48099 L
.4884 .48118 L
.49992 .48126 L
.50975 .48122 L
.52057 .48107 L
.53217 .48079 L
.53868 .48057 L
.54463 .48033 L
.56707 .47911 L
.58912 .47741 L
.60895 .47545 L
.65266 .46959 L
.69197 .46237 L
.72769 .45401 L
.80188 .42986 L
.83921 .41313 L
.87019 .39591 L
.89533 .3788 L
.91874 .35912 L
.93583 .34112 L
.95095 .32068 L
.95832 .30788 L
.96387 .29583 L
Mistroke
.96802 .28418 L
.9697 .27818 L
.97118 .27169 L
.97221 .26585 L
.97291 .26048 L
.97335 .25535 L
.97359 .24993 L
.97357 .24398 L
.97329 .23845 L
.97269 .23239 L
.97223 .229 L
.97172 .22593 L
.96936 .21527 L
.9676 .20925 L
.96568 .20365 L
.96058 .19152 L
.95484 .1806 L
.94188 .16131 L
.92439 .14143 L
.90176 .12129 L
.87277 .10092 L
.80969 .06868 L
.77183 .05447 L
.73375 .04295 L
.69737 .03408 L
.65747 .02642 L
.63615 .02312 L
.61244 .02005 L
.59037 .01775 L
.57011 .01608 L
.55856 .01532 L
.54597 .01464 L
.53905 .01433 L
.53264 .01409 L
.52612 .01389 L
.52 .01373 L
.50917 .01355 L
.50342 .01351 L
.49723 .01349 L
.49108 .01351 L
.48461 .01357 L
.47307 .01378 L
.46201 .01411 L
.45006 .0146 L
.42847 .01585 L
.40758 .01752 L
.3885 .01944 L
.34581 .0252 L
.30208 .03337 L
.2658 .04212 L
Mistroke
.2334 .0517 L
.16621 .07833 L
.13548 .09465 L
.10576 .11418 L
.08305 .13277 L
.06277 .15376 L
.04812 .1735 L
.04176 .18428 L
.03603 .19609 L
.03183 .20701 L
.02887 .21713 L
.02683 .22686 L
.0261 .23176 L
.02553 .23715 L
.02517 .24327 L
.02511 .24892 L
.02518 .25187 L
.02534 .25512 L
.02561 .25851 L
.02594 .26168 L
.02676 .26749 L
.02776 .2728 L
.03085 .28467 L
.03457 .2951 L
.03965 .30633 L
.05163 .32635 L
.06974 .34858 L
.09381 .37093 L
.14847 .40688 L
.18288 .42346 L
.21735 .43699 L
.2571 .44962 L
.30339 .46111 L
.34563 .46906 L
.38626 .4747 L
.40911 .47707 L
.43011 .47878 L
.44178 .47953 L
.45451 .48019 L
.46656 .48068 L
.47772 .48099 L
.48825 .48118 L
.49934 .48126 L
.5088 .48123 L
.51915 .4811 L
.53032 .48084 L
.53657 .48064 L
.54224 .48043 L
.56362 .47933 L
.58335 .47791 L
Mistroke
.60456 .47592 L
.64249 .47115 L
.6863 .46354 L
.73076 .4532 L
.76682 .44255 L
.80408 .42897 L
.80576 .42829 L
Mfstroke
.92158 .35386 m
.93878 .33468 L
.95169 .31609 L
.9576 .30536 L
.96225 .29508 L
.96649 .2831 L
.96795 .27788 L
.96929 .27211 L
.97033 .26646 L
.97105 .26116 L
.97157 .25555 L
.97183 .24951 L
.9718 .24391 L
.97152 .2386 L
.97108 .23383 L
.97038 .22863 L
.96924 .22244 L
.96794 .21685 L
.96406 .20439 L
.95931 .19298 L
.95381 .18238 L
.93893 .16039 L
.91863 .13822 L
.89776 .12033 L
.87134 .10196 L
.83908 .08383 L
.80051 .06647 L
.76106 .05227 L
.72209 .04101 L
.68233 .03186 L
.6384 .02411 L
.61667 .02111 L
.59295 .01842 L
.57926 .01714 L
.56664 .01613 L
.55461 .01532 L
.54172 .01461 L
.53042 .01413 L
.52013 .01379 L
.50978 .01356 L
.49999 .01345 L
.48857 .01343 L
.47805 .01352 L
.4665 .01375 L
.46068 .01392 L
.45429 .01414 L
.44234 .01466 L
.43145 .01527 L
.40707 .01707 L
.38467 .01927 L
Mistroke
.36363 .02185 L
.32082 .0287 L
.28335 .03663 L
.24202 .04782 L
.20537 .06027 L
.14653 .08692 L
.11764 .10424 L
.09412 .12149 L
.07315 .14044 L
.0546 .16189 L
.04096 .18301 L
.03617 .19257 L
.03193 .20282 L
.02993 .20865 L
.02805 .2151 L
.02662 .22106 L
.02557 .22653 L
.02464 .23299 L
.02429 .23638 L
.02403 .23994 L
.02381 .24596 L
.02382 .24937 L
.02391 .25254 L
.02432 .2587 L
.02499 .2645 L
.02583 .2697 L
.02699 .27532 L
.03051 .28784 L
.0349 .29925 L
.04608 .32031 L
.0622 .34208 L
.08116 .36164 L
.10147 .3785 L
.12869 .39691 L
.1622 .41513 L
.19693 .43037 L
.23215 .44295 L
.26974 .45386 L
.30589 .46228 L
.34755 .46984 L
.3714 .47323 L
.39391 .47585 L
.41458 .47778 L
.43685 .47936 L
.44961 .48004 L
.4617 .48053 L
.47258 .48086 L
.47872 .48099 L
.48439 .48107 L
.49587 .48115 L
Mistroke
.50662 .48111 L
.5184 .48094 L
.52502 .48078 L
.53106 .4806 L
.54315 .48013 L
.55631 .47945 L
.58016 .47777 L
.60255 .47567 L
.62649 .47282 L
.669 .46616 L
.70898 .45784 L
.74425 .44861 L
.81774 .42218 L
.85048 .40617 L
.8826 .3867 L
.90856 .36695 L
.92936 .34698 L
.94473 .32816 L
.95774 .30693 L
.9629 .2957 L
.96734 .28317 L
.96907 .27682 L
.97056 .26995 L
.97111 .26679 L
.9716 .26345 L
.97225 .25748 L
.97259 .25193 L
.97266 .246 L
.97247 .24041 L
.97207 .23533 L
.97133 .22937 L
.97019 .22292 L
.9688 .21685 L
.96724 .21128 L
.9589 .19022 L
.95259 .17863 L
.94582 .16822 L
.91182 .13085 L
.88738 .11164 L
.85669 .09232 L
.79116 .06204 L
.752 .04874 L
.71289 .03809 L
.67618 .03011 L
.63515 .02321 L
.61138 .0201 L
.58897 .01772 L
.56537 .01579 L
.5528 .01499 L
.53931 .01431 L
Mistroke
.52776 .01387 L
.52124 .01368 L
.5152 .01354 L
.50412 .01338 L
.49236 .01334 L
.48185 .01342 L
.47201 .0136 L
.46123 .0139 L
.44964 .01436 L
.43784 .01496 L
.42716 .01562 L
.40334 .01753 L
.38148 .01982 L
.36109 .02243 L
.31632 .02988 L
.26984 .04041 L
.23073 .05187 L
.19203 .06608 L
.15861 .08126 L
.13081 .09659 L
.08257 .13224 L
.06178 .15384 L
.04614 .17533 L
.04048 .18521 L
.03538 .19586 L
.03175 .20516 L
.02864 .21527 L
.02727 .22094 L
.02625 .22615 L
.02549 .23115 L
.0249 .23642 L
.02452 .24222 L
.02441 .24762 L
.02457 .25354 L
.02478 .25685 L
.02505 .25986 L
.02575 .26542 L
.02662 .27061 L
.02945 .28236 L
.03329 .2937 L
.0386 .30575 L
.05127 .32701 L
.06621 .34572 L
.0874 .36638 L
.11494 .38738 L
.17577 .42087 L
.2126 .43574 L
.24984 .44791 L
.28557 .45736 L
.32491 .46566 L
Mistroke
.34597 .46928 L
.36945 .47271 L
.39132 .47535 L
.41145 .47732 L
.43546 .47912 L
.44874 .47987 L
.46134 .48042 L
.473 .48078 L
.4838 .481 L
.48943 .48107 L
.49565 .48111 L
.50215 .48111 L
.50824 .48108 L
.51876 .48093 L
.52999 .48065 L
.54057 .48028 L
.55016 .47984 L
.57358 .47839 L
.59552 .47652 L
.63858 .47134 L
.66237 .46758 L
.68389 .46358 L
.75527 .44569 L
.78864 .4344 L
.82291 .42032 L
.8558 .40375 L
.88377 .38644 L
.90625 .36949 L
.92685 .35033 L
.94511 .32842 L
.95807 .30727 L
.96356 .29527 L
.9676 .28386 L
.96931 .27772 L
.97077 .27123 L
.9714 .26782 L
.97197 .26408 L
.97237 .26089 L
.9727 .25751 L
.97306 .25142 L
.97311 .2458 L
.97288 .23975 L
.97262 .23632 L
.97228 .2331 L
.97146 .22732 L
.97047 .22204 L
.96739 .21021 L
.96369 .19983 L
.95863 .18864 L
.94669 .16869 L
Mistroke
.92866 .14652 L
.90467 .1242 L
.85016 .08826 L
.81588 .07168 L
.7815 .05812 L
.74184 .04543 L
.69561 .03386 L
.65344 .02584 L
.61284 .02013 L
.59001 .01771 L
.56901 .01596 L
.55734 .01519 L
.5446 .0145 L
.53254 .014 L
.52137 .01366 L
.51085 .01346 L
.49977 .01336 L
.49031 .01337 L
.47997 .01348 L
.4688 .01372 L
.46255 .01391 L
.45688 .01412 L
.44574 .01461 L
.43549 .01518 L
.41576 .01657 L
.39453 .01853 L
.35655 .02325 L
.31636 .03009 L
.27379 .03966 L
.23161 .05189 L
.19467 .06534 L
.16144 .08022 L
.12863 .09832 L
.10296 .11579 L
.07928 .13577 L
.05977 .1568 L
.04569 .17671 L
.04015 .18657 L
.0351 .19737 L
.03122 .20772 L
.02848 .21723 L
.0272 .2229 L
.02624 .22829 L
.02548 .23398 L
.02517 .2372 L
.02496 .24018 L
.02476 .24513 L
.02479 .25059 L
.02507 .25629 L
.02558 .26162 L
Mistroke
.02596 .26462 L
.02647 .26788 L
.02762 .27381 L
.03055 .2849 L
.03527 .2977 L
.04086 .30944 L
.05594 .33284 L
.07367 .35313 L
.09867 .3752 L
.12641 .39446 L
.18714 .42552 L
.22182 .43875 L
.26258 .4513 L
.29926 .46031 L
.34021 .46821 L
.38007 .47396 L
.41721 .47775 L
.43734 .4792 L
.44885 .47985 L
.45969 .48034 L
.47109 .48073 L
.48156 .48097 L
.49306 .48112 L
.49885 .48114 L
.50518 .48113 L
.5159 .48102 L
.52565 .48082 L
.53688 .48048 L
.54747 .48004 L
.56627 .47898 L
.58653 .47744 L
.60836 .4753 L
.63211 .47239 L
.67905 .4647 L
.72085 .45547 L
.75818 .44502 L
.79453 .43243 L
.83125 .4167 L
.86077 .4012 L
.88895 .38313 L
.91325 .36379 L
.93195 .34518 L
.9474 .32559 L
.95875 .30648 L
.96369 .29561 L
.96739 .28535 L
.97044 .274 L
.97168 .26761 L
.97251 .26177 L
.97308 .25565 L
Mistroke
.97334 .24998 L
.97336 .24703 L
.97331 .24376 L
.97316 .24036 L
.97294 .23717 L
.9723 .23133 L
.97148 .22598 L
.9703 .22014 L
.96876 .21401 L
.96551 .20391 L
.96111 .19323 L
.95077 .17438 L
.93457 .15274 L
.91632 .13399 L
.89354 .11527 L
.86579 .09688 L
.80763 .06798 L
.77118 .05437 L
.73486 .04334 L
.69288 .03316 L
.64577 .02455 L
.62391 .02145 L
.60035 .0187 L
.57788 .01662 L
.55739 .01519 L
.54471 .01451 L
.53304 .01403 L
.5264 .01381 L
.52021 .01365 L
.51374 .01352 L
.50666 .01343 L
.50044 .01339 L
.49456 .01339 L
.48355 .01347 L
.47738 .01357 L
.4717 .0137 L
.45885 .0141 L
.44857 .01454 L
.43754 .01513 L
.41768 .0165 L
.39423 .01866 L
.373 .02112 L
.32784 .02807 L
.28641 .03671 L
.24696 .04726 L
.21309 .05846 L
.17894 .07221 L
.14509 .08895 L
.11686 .10611 L
.09386 .12317 L
Mistroke
.07338 .14184 L
.05768 .15972 L
.04379 .18027 L
.03773 .19187 L
.03306 .203 L
.02968 .21338 L
.02735 .22305 L
.02644 .22812 L
.02568 .23372 L
.02517 .23958 L
.02494 .24508 L
.02496 .2507 L
.02529 .25684 L
.02557 .25994 L
.02595 .26325 L
.02688 .26919 L
.02809 .27512 L
.0295 .28069 L
.03283 .29106 L
.03791 .30317 L
.04369 .31418 L
.0605 .33832 L
.07846 .3576 L
.10148 .37716 L
.15205 .40891 L
.18798 .42574 L
.22519 .43979 L
.26439 .4517 L
.30176 .46079 L
.34288 .46861 L
.38275 .47426 L
.40508 .47666 L
.42578 .47841 L
.44866 .47985 L
.46023 .48037 L
.46631 .4806 L
.47293 .4808 L
.48396 .48104 L
.4944 .48116 L
.50457 .48117 L
.51396 .48109 L
.5241 .4809 L
.53526 .48059 L
.54689 .48012 L
.55778 .47957 L
.57751 .47825 L
.59546 .47671 L
.63538 .47203 L
.67559 .46547 L
.717 .45655 L
Mistroke
.78646 .43559 L
.82498 .41979 L
.858 .40294 L
.88444 .38646 L
.90993 .36688 L
.93097 .34647 L
.94699 .32641 L
.95991 .30441 L
.96532 .29178 L
.96727 .28614 L
.96906 .28012 L
.97035 .27496 L
.97152 .26925 L
.97235 .26404 L
.97292 .25913 L
.97334 .25338 L
.97349 .24809 L
.97338 .24229 L
.97298 .23619 L
.97242 .23121 L
.97159 .2259 L
.96952 .21636 L
.96608 .20511 L
.96203 .19498 L
.95036 .17351 L
.93374 .1516 L
.91624 .13375 L
.89361 .11519 L
.86565 .09667 L
.83168 .07857 L
.7614 .0511 L
.72091 .03962 L
.68145 .03078 L
.63646 .02314 L
.6107 .01982 L
.58705 .01741 L
.56422 .01563 L
.54308 .01445 L
.53199 .01401 L
.5256 .01381 L
.51979 .01367 L
.51363 .01355 L
.50703 .01347 L
.50092 .01343 L
.49513 .01342 L
.48462 .0135 L
.47347 .0137 L
.46396 .01397 L
.45348 .01436 L
.44228 .01491 L
Mistroke
.43024 .01564 L
.40857 .01733 L
.38758 .01944 L
.36541 .02219 L
.32625 .02844 L
.28134 .03802 L
.24248 .04872 L
.20423 .06187 L
.16597 .07832 L
.13352 .09569 L
.1065 .11351 L
.08299 .13269 L
.06478 .15127 L
.04841 .17289 L
.04111 .1853 L
.03554 .197 L
.03127 .20843 L
.02951 .21432 L
.02793 .22071 L
.02718 .22439 L
.02659 .22777 L
.02612 .23094 L
.0257 .23442 L
.0252 .24048 L
.02506 .24379 L
.02501 .24688 L
.02503 .24985 L
.02514 .25308 L
.02556 .25893 L
.02623 .26462 L
.02709 .26987 L
.02827 .27552 L
.02988 .28172 L
.03411 .29417 L
.03907 .30536 L
.04569 .31739 L
.06091 .33869 L
.0795 .35848 L
.09993 .37587 L
.15648 .41112 L
.19366 .42802 L
.23034 .44146 L
.26748 .45249 L
.30878 .46225 L
.34541 .46901 L
.3868 .47473 L
.4105 .47717 L
.43232 .47889 L
.44445 .47964 L
.45768 .48029 L
Mistroke
.46375 .48053 L
.47021 .48074 L
.48183 .48103 L
.4924 .48117 L
.50382 .4812 L
.51459 .48111 L
.52446 .48093 L
.5354 .48062 L
.54734 .48014 L
.55978 .47949 L
.57132 .47875 L
.59441 .47686 L
.61552 .47463 L
.66232 .46791 L
.70223 .46007 L
.74275 .44982 L
.80752 .42748 L
.84068 .41231 L
.86893 .3966 L
.89557 .37853 L
.92056 .35728 L
.93999 .33594 L
.9542 .31524 L
.95998 .30441 L
.96451 .29408 L
.9678 .28471 L
.97052 .27451 L
.9716 .26916 L
.97251 .26329 L
.97287 .26032 L
.97316 .25714 L
.97349 .25141 L
.97354 .24568 L
.97335 .24027 L
.97297 .23541 L
.97233 .23014 L
.9714 .22449 L
.97031 .21933 L
.96706 .20777 L
.96327 .19768 L
.95837 .18719 L
.94489 .16542 L
.92555 .14267 L
.90236 .12183 L
.87316 .10121 L
.8102 .06892 L
.77233 .05465 L
.73503 .0433 L
.69184 .03289 L
.64407 .02426 L
Mistroke
.62354 .02139 L
.60124 .01879 L
.58177 .01696 L
.56041 .0154 L
.54737 .01467 L
.53525 .01415 L
.52365 .01378 L
.51779 .01365 L
.5113 .01354 L
.50015 .01345 L
.49387 .01345 L
.48811 .01349 L
.4775 .01364 L
.46633 .01392 L
.45538 .01432 L
.44353 .01488 L
.42208 .01626 L
.40135 .01805 L
.38237 .02008 L
.34 .02608 L
.29654 .03452 L
.22851 .05325 L
.19291 .06641 L
.16198 .08032 L
.13185 .09675 L
.10269 .11641 L
.08049 .13508 L
.06069 .15618 L
.04524 .17807 L
.03493 .19858 L
.03125 .20866 L
.02965 .21399 L
.02822 .21965 L
.02718 .22462 L
.02628 .23009 L
.02568 .23507 L
.0253 .23972 L
.02507 .24559 L
.02506 .24856 L
.02514 .25183 L
.02548 .2576 L
.02606 .26301 L
.0265 .26609 L
.02704 .26934 L
.02823 .27513 L
.03192 .28809 L
.03625 .29921 L
.04121 .30943 L
.05571 .33204 L
.07269 .35172 L
Mistroke
.09111 .36874 L
.14202 .40337 L
.17235 .41877 L
.20741 .43337 L
.27673 .45488 L
.31821 .46415 L
.35848 .47103 L
.38165 .47413 L
.40392 .47656 L
.4163 .47768 L
.42985 .47873 L
.44227 .47953 L
.45372 .48013 L
.46481 .48058 L
.47654 .48093 L
.48832 .48115 L
.49501 .48121 L
.50124 .48123 L
.51256 .48116 L
.52286 .48099 L
.52856 .48085 L
.53474 .48067 L
.54596 .48023 L
.56692 .47908 L
.58901 .47738 L
.60773 .47554 L
.62818 .4731 L
.67248 .46615 L
.71837 .45632 L
.75954 .44484 L
.79502 .4325 L
.82742 .41879 L
.85907 .40247 L
.90748 .3691 L
.93108 .3465 L
.94877 .32397 L
.96072 .30294 L
.96577 .29084 L
.96772 .28507 L
.96931 .27957 L
.97063 .27416 L
.9718 .26824 L
.9726 .26285 L
.97314 .25786 L
.97348 .25247 L
.97358 .24651 L
.97353 .24352 L
.97338 .2403 L
.9729 .23447 L
.97225 .22936 L
Mistroke
.9713 .22379 L
.96859 .2126 L
.96516 .20232 L
.96117 .19285 L
.94797 .16973 L
.93203 .14953 L
.90918 .12741 L
.88348 .10792 L
.82564 .07568 L
.79222 .06174 L
.75261 .04834 L
.71684 .03858 L
.67664 .02984 L
.63733 .02327 L
.60049 .01872 L
.57853 .0167 L
.55849 .01529 L
.54732 .01468 L
.53522 .01416 L
.52377 .0138 L
.51324 .01358 L
.50344 .01348 L
.49429 .01347 L
.48426 .01355 L
.47352 .01375 L
.46226 .01407 L
.45163 .0145 L
.43176 .0156 L
.40969 .0173 L
.38646 .01964 L
.34545 .02522 L
.30265 .03321 L
.2575 .04438 L
.22041 .05604 L
.18393 .07022 L
.12642 .10012 L
.09923 .1191 L
.07743 .13804 L
.05762 .16006 L
.04913 .17192 L
.0415 .18472 L
.03597 .19617 L
.03119 .20892 L
.02952 .21455 L
.02802 .22063 L
.0269 .22634 L
.02609 .23164 L
.02572 .23485 L
.02542 .23827 L
.02519 .24206 L
Mistroke
.02509 .24549 L
.02509 .24875 L
.02518 .25227 L
.02535 .25559 L
.0256 .25864 L
.02626 .26436 L
.02676 .26759 L
.0273 .2706 L
.02861 .27662 L
.03036 .28313 L
.03454 .29508 L
.03958 .30624 L
.05183 .32666 L
.07061 .34953 L
.09205 .3695 L
.11532 .38693 L
.14369 .40429 L
.20282 .43161 L
.24316 .44551 L
.28401 .45668 L
.32243 .46496 L
.3659 .47209 L
.38792 .47487 L
.41202 .47732 L
.43499 .47909 L
.44597 .47975 L
.45626 .48026 L
.46557 .48062 L
.47556 .48092 L
.48667 .48114 L
.4968 .48123 L
.50736 .48122 L
.51883 .48109 L
.52966 .48084 L
.53967 .48051 L
.55034 .48004 L
.56181 .47942 L
.58248 .47795 L
.60686 .47565 L
.62898 .47301 L
.67364 .46596 L
.71889 .45621 L
.75775 .44542 L
.79113 .43401 L
.8247 .42006 L
.85798 .40311 L
.8856 .38581 L
.90808 .36862 L
.928 .34985 L
.94321 .33185 L
Mistroke
.95646 .31135 L
.96218 .29978 L
.96655 .28866 L
.96966 .27832 L
.97174 .26867 L
.97259 .2631 L
.97314 .25804 L
.97351 .2522 L
.9736 .2467 L
.97344 .24112 L
.97297 .23501 L
.97262 .23193 L
.97216 .22864 L
.9711 .22272 L
.96821 .21128 L
.96465 .20095 L
.95937 .18906 L
.95228 .17634 L
.9359 .15394 L
.9167 .13405 L
.89543 .11642 L
.86627 .09695 L
.83619 .08068 L
.76612 .05257 L
.72537 .04073 L
.68016 .03052 L
.63793 .02336 L
.59856 .01853 L
.57642 .01654 L
.5647 .01569 L
.55226 .01494 L
.54134 .01441 L
.53554 .01418 L
.52932 .01397 L
.51837 .01369 L
.50812 .01353 L
.49718 .01347 L
.48704 .01353 L
.47592 .0137 L
.47031 .01384 L
.46411 .01402 L
.45379 .01442 L
.44267 .01496 L
.42262 .01626 L
.40304 .01792 L
.38258 .0201 L
.34654 .02506 L
.3049 .03275 L
.26845 .0414 L
.23104 .05246 L
Mistroke
.19297 .06644 L
.16041 .08115 L
.13294 .09614 L
.08695 .12926 L
.0676 .14822 L
.05066 .16964 L
.04396 .18033 L
.03851 .19064 L
.03403 .20093 L
.03075 .21034 L
.02779 .22176 L
.02662 .22805 L
.02582 .23399 L
.02534 .23952 L
.02512 .2446 L
.02512 .25018 L
.0254 .25608 L
.02597 .26203 L
.02642 .26536 L
.02691 .26839 L
.02943 .27982 L
.03132 .28617 L
.03375 .29303 L
.03917 .30539 L
.05191 .32676 L
.0674 .34605 L
.08816 .36619 L
.11469 .38649 L
.14497 .40498 L
.18072 .42252 L
.21742 .43701 L
.25312 .44848 L
.28916 .45791 L
.32992 .46636 L
.35295 .4702 L
.37451 .47325 L
.39671 .47584 L
.41769 .47781 L
.43577 .47915 L
.4553 .48022 L
.46645 .48066 L
.47705 .48097 L
.48658 .48115 L
.49696 .48124 L
.50809 .48123 L
.51816 .48111 L
.52978 .48084 L
.54069 .48048 L
.55082 .48003 L
.5601 .47953 L
Mistroke
.58095 .47809 L
.60261 .47611 L
.62215 .47389 L
.66524 .46748 L
.70389 .45977 L
.73905 .45093 L
.81158 .42586 L
.84792 .40863 L
.87803 .39092 L
.902 .37362 L
.92425 .35373 L
.94167 .33389 L
.95441 .315 L
.96021 .30407 L
.96527 .29225 L
.96764 .28539 L
.96945 .27914 L
.97096 .27275 L
.97205 .26685 L
.97282 .26124 L
.97335 .25531 L
.97359 .24935 L
.9736 .24596 L
.97352 .2428 L
.97318 .23708 L
.97262 .23187 L
.97171 .22587 L
.97056 .2202 L
.96762 .20934 L
.96397 .19924 L
.95247 .17664 L
.93714 .15541 L
.91623 .13361 L
.89429 .11557 L
.8678 .09786 L
.81267 .06993 L
.77752 .05641 L
.74346 .04565 L
.70485 .03574 L
.66109 .02702 L
.64087 .0238 L
.61916 .02085 L
.59881 .01856 L
.5796 .0168 L
.56153 .01549 L
.54201 .01445 L
.53086 .01402 L
.52026 .01373 L
.51073 .01356 L
.50033 .01348 L
Mistroke
.49454 .01349 L
.48843 .01352 L
.47749 .01368 L
.46574 .01398 L
.45907 .01421 L
.45286 .01447 L
.4314 .01565 L
.40855 .01742 L
.38656 .01965 L
.36596 .02221 L
.32808 .02821 L
.28522 .03719 L
.24738 .04734 L
.20847 .06038 L
.16973 .07664 L
.13847 .09291 L
.11269 .10921 L
.07097 .1446 L
.05399 .16492 L
.03978 .18807 L
.03439 .20004 L
.03194 .20669 L
.02997 .21298 L
.02844 .21889 L
.0271 .22531 L
.02617 .23115 L
.02557 .23655 L
.0252 .24239 L
.02509 .24794 L
.02522 .25291 L
.02559 .25833 L
.02626 .26419 L
.02675 .26746 L
.02728 .27042 L
.02992 .28155 L
.0333 .29183 L
.03793 .30281 L
.04888 .32229 L
.06613 .34464 L
.08902 .36693 L
.11459 .38642 L
.14108 .40282 L
.203 .43168 L
.24118 .4449 L
.27954 .45558 L
.31415 .46335 L
.3521 .47008 L
.37233 .47297 L
.3949 .47566 L
.41572 .47765 L
Mistroke
.43519 .47912 L
.44674 .4798 L
.45723 .48031 L
.46892 .48075 L
.47534 .48093 L
.4814 .48106 L
.49242 .48122 L
.50258 .48125 L
.51372 .48118 L
.52549 .48096 L
.53532 .48068 L
.54585 .48027 L
.56479 .47925 L
.58718 .47758 L
.60744 .47561 L
.65165 .46975 L
.69819 .46104 L
.74022 .45061 L
.77705 .43911 L
.80987 .42658 L
.84262 .4114 L
.89392 .37985 L
.91839 .35945 L
.93959 .33656 L
.95378 .31607 L
.96017 .30416 L
.96502 .29291 L
.9671 .28708 L
.96898 .28088 L
.97036 .27549 L
.97157 .26969 L
.97212 .26643 L
.97255 .26345 L
.97319 .25759 L
.97342 .25432 L
.97357 .25075 L
.97361 .24738 L
.97357 .24426 L
.97327 .23821 L
.97271 .23253 L
.97198 .22743 L
.97095 .22195 L
.96773 .20967 L
.96368 .19851 L
.95403 .17922 L
.93986 .15873 L
.9212 .13828 L
.90042 .12024 L
.87425 .10185 L
.842 .08357 L
Mistroke
.81056 .06904 L
.77445 .05535 L
.73983 .04462 L
.69966 .03458 L
.66158 .02711 L
.62482 .02157 L
.60506 .01922 L
.58378 .01715 L
.57146 .01617 L
.56024 .01542 L
.54955 .01481 L
.53823 .01429 L
.53257 .01408 L
.52635 .01389 L
.5154 .01364 L
.50922 .01355 L
.5026 .0135 L
.49634 .01349 L
.49064 .01351 L
.4796 .01364 L
.47337 .01377 L
.4676 .01393 L
.45703 .0143 L
.44582 .01481 L
.42649 .01599 L
.40577 .01768 L
.36871 .02185 L
.32569 .02865 L
.28753 .03664 L
.25034 .04647 L
.21271 .05882 L
.15161 .08567 L
.11921 .10479 L
.09251 .12454 L
.07218 .14335 L
.0538 .16519 L
.04671 .17574 L
.04018 .18729 L
.03546 .19742 L
.03131 .20859 L
.02937 .21516 L
.0279 .22128 L
.02678 .22714 L
.02631 .23015 L
.0259 .23341 L
.02557 .23662 L
.02535 .23958 L
.02511 .24539 L
.02514 .25068 L
.02542 .25625 L
Mistroke
.02593 .26159 L
.02659 .26644 L
.0276 .27203 L
.02879 .27731 L
.03148 .28664 L
.03522 .2967 L
.04681 .31905 L
.06128 .339 L
.07921 .3581 L
.10221 .37753 L
.15274 .40913 L
.18672 .4251 L
.22573 .43989 L
.2649 .45178 L
.30234 .46088 L
.34317 .46865 L
.38288 .4743 L
.40508 .47669 L
.42572 .47846 L
.44854 .4799 L
.46009 .48043 L
.46617 .48066 L
.47281 .48087 L
.48376 .48111 L
.49416 .48123 L
.50429 .48125 L
.51367 .48118 L
.52483 .48098 L
.53491 .4807 L
.54654 .48024 L
.55745 .47969 L
.57713 .47839 L
.5951 .47686 L
.6351 .4722 L
.67506 .46571 L
.71634 .45686 L
.78573 .43603 L
.82418 .42032 L
.85727 .40353 L
.88378 .38708 L
.90943 .36749 L
.92916 .34863 L
.94655 .32727 L
.95435 .3151 L
.96036 .30377 L
.96534 .29208 L
.96892 .28111 L
.97132 .27102 L
.97229 .26535 L
.97294 .2602 L
Mistroke
.9734 .25453 L
.97361 .24839 L
.97352 .2426 L
.9732 .23727 L
.97268 .23227 L
.97201 .22761 L
.97107 .22251 L
.96982 .21705 L
.96651 .20599 L
.96261 .19599 L
.95122 .17462 L
.9349 .15275 L
.91766 .13492 L
.89527 .1163 L
.86765 .09777 L
.83396 .07959 L
.79906 .06437 L
.76402 .0519 L
.72554 .04077 L
.68885 .03227 L
.64653 .02465 L
.62243 .02126 L
.5999 .01868 L
.57772 .01665 L
.55405 .01505 L
.54172 .01444 L
.53016 .01401 L
.52352 .01382 L
.51745 .01368 L
.51043 .01357 L
.50377 .01351 L
.49277 .0135 L
.48107 .01362 L
.47003 .01386 L
.46004 .01418 L
.44827 .01469 L
.43558 .01539 L
.4127 .01707 L
.39187 .01907 L
.36978 .02171 L
.33068 .02775 L
.28579 .03706 L
.24678 .04753 L
.20843 .06041 L
.16987 .07658 L
.13709 .09371 L
.10964 .11136 L
.08587 .13024 L
.06729 .14858 L
.05046 .16996 L
Mistroke
.04286 .18227 L
.03699 .19392 L
.03264 .20468 L
.02908 .21628 L
.02755 .22295 L
.02645 .22925 L
.02573 .23493 L
.02545 .23813 L
.02526 .24108 L
.0251 .24708 L
.02521 .25269 L
.02564 .25883 L
.02601 .26227 L
.02643 .26541 L
.02754 .27171 L
.02911 .27854 L
.03295 .29087 L
.03728 .3014 L
.04299 .3126 L
.05603 .3324 L
.07592 .35491 L
.09814 .3744 L
.15492 .41026 L
.18846 .42583 L
.22848 .44082 L
.26865 .45279 L
.30864 .46222 L
.34593 .4691 L
.38758 .47485 L
.40954 .47711 L
.43395 .47904 L
.44629 .47978 L
.45961 .48041 L
.46607 .48066 L
.47222 .48085 L
.48377 .48111 L
.49453 .48124 L
.50602 .48125 L
.51685 .48114 L
.52666 .48094 L
.53823 .48058 L
.55071 .48005 L
.57325 .47868 L
.59414 .47695 L
.61633 .47461 L
.65569 .4691 L
.70104 .46042 L
.74061 .45051 L
.77962 .43821 L
.81905 .42263 L
Mistroke
.85278 .40603 L
.88123 .38881 L
.90601 .37037 L
.9256 .35237 L
.94363 .33132 L
.95192 .31915 L
.95846 .30761 L
.96378 .29605 L
.96764 .28542 L
.97081 .27351 L
.97204 .26693 L
.97248 .26397 L
.97289 .26071 L
.9734 .25463 L
.97355 .25131 L
.97361 .2482 L
.97352 .24263 L
.97314 .23666 L
.9728 .23333 L
.97233 .22969 L
.97119 .2231 L
.96973 .2167 L
.96808 .21079 L
.96375 .19869 L
.95871 .18772 L
.94362 .16361 L
.92621 .14327 L
.90386 .12297 L
.85613 .09109 L
.8245 .07514 L
.79238 .0618 L
.75555 .04924 L
.71302 .03766 L
.67084 .02876 L
.63049 .02233 L
.59328 .01802 L
.57184 .0162 L
.55161 .01492 L
.5412 .01442 L
.53023 .01401 L
.52085 .01375 L
.5106 .01357 L
.49951 .01349 L
.4933 .0135 L
.48767 .01354 L
.4767 .0137 L
.46637 .01397 L
.45605 .01434 L
.445 .01485 L
.42513 .01609 L
Mistroke
.40166 .01807 L
.38044 .02037 L
.33521 .02696 L
.29375 .03521 L
.2252 .05443 L
.18963 .06783 L
.15913 .08181 L
.13123 .09719 L
.10432 .11525 L
.08393 .13197 L
.06486 .15132 L
.04791 .17383 L
.04058 .1865 L
.03502 .19849 L
.0309 .20989 L
.02811 .22034 L
.02695 .22615 L
.02645 .22921 L
.02601 .23247 L
.02542 .23845 L
.02514 .24397 L
.02512 .24958 L
.02538 .25571 L
.02592 .26149 L
.02665 .26683 L
.02762 .27212 L
.02869 .2769 L
.03178 .28755 L
.03617 .29893 L
.04214 .31107 L
.05611 .3325 L
.07292 .3519 L
.0943 .37133 L
.14121 .40289 L
.17222 .41869 L
.20296 .43166 L
.23841 .44404 L
.27938 .45555 L
.31913 .46434 L
.35721 .47086 L
.39454 .47562 L
.41365 .47748 L
.43489 .4791 L
.45577 .48025 L
.46763 .48071 L
.47868 .48101 L
.4904 .4812 L
.50105 .48126 L
.50695 .48124 L
.51334 .48119 L
Mistroke
.52493 .48098 L
.53487 .4807 L
.54579 .48028 L
.55716 .47971 L
.56777 .47906 L
.60678 .47568 L
.63017 .47288 L
.65206 .46969 L
.69218 .46233 L
.73366 .45242 L
.77639 .43934 L
.80576 .42829 L
Mfstroke
.9228 .35488 m
.94016 .33544 L
.95317 .3166 L
.95911 .30572 L
.9638 .29529 L
.96805 .28315 L
.96951 .27785 L
.97084 .272 L
.97187 .26628 L
.97259 .2609 L
.97309 .25522 L
.97333 .2491 L
.97328 .24343 L
.97298 .23805 L
.97252 .23322 L
.97179 .22796 L
.97062 .2217 L
.96928 .21605 L
.96531 .20346 L
.96046 .19193 L
.95486 .18123 L
.93973 .15908 L
.91915 .1368 L
.89803 .11886 L
.87132 .1005 L
.83876 .08243 L
.79989 .0652 L
.76019 .05119 L
.72103 .04014 L
.68113 .03122 L
.6371 .02373 L
.61377 .02068 L
.5916 .01832 L
.56705 .0163 L
.55316 .01543 L
.54038 .0148 L
.52996 .01441 L
.51881 .01411 L
.50828 .01393 L
.49871 .01387 L
.48744 .01391 L
.48109 .01398 L
.47523 .01409 L
.46448 .01437 L
.45311 .01479 L
.44225 .01532 L
.43062 .01601 L
.40971 .0176 L
.38505 .02007 L
.36279 .02287 L
Mistroke
.32238 .02943 L
.28086 .03836 L
.2113 .05933 L
.1727 .0752 L
.13968 .09209 L
.11327 .10863 L
.08788 .12823 L
.06681 .14882 L
.05084 .16902 L
.03801 .19118 L
.03269 .20388 L
.03077 .20954 L
.02903 .21558 L
.02778 .22078 L
.02665 .22654 L
.02587 .23178 L
.02534 .23671 L
.02497 .2425 L
.02487 .24781 L
.02503 .25363 L
.0255 .25975 L
.02611 .26476 L
.02699 .27009 L
.02916 .27965 L
.03273 .29094 L
.03687 .30107 L
.04886 .3227 L
.06583 .3447 L
.08366 .3626 L
.10662 .38117 L
.13499 .39969 L
.16933 .41772 L
.24016 .44496 L
.28113 .45636 L
.32094 .46505 L
.36628 .4725 L
.38971 .47543 L
.4159 .478 L
.42708 .47887 L
.4389 .47966 L
.44914 .48023 L
.46012 .48073 L
.46633 .48096 L
.47198 .48113 L
.48305 .48138 L
.48925 .48146 L
.49597 .48151 L
.50233 .48152 L
.50819 .48149 L
.51858 .48136 L
Mistroke
.5283 .48114 L
.53896 .48079 L
.55039 .48028 L
.57361 .47886 L
.5947 .47708 L
.63613 .4722 L
.6791 .46504 L
.71821 .45645 L
.75217 .44716 L
.79008 .43439 L
.82804 .41846 L
.86037 .40165 L
.88737 .38443 L
.91164 .36538 L
.93049 .34695 L
.9476 .32545 L
.9553 .3131 L
.96124 .30147 L
.96589 .29006 L
.96961 .27781 L
.97105 .27143 L
.97209 .26543 L
.97256 .26198 L
.9729 .25883 L
.97317 .25536 L
.97336 .2517 L
.97343 .24601 L
.97321 .23993 L
.97272 .2342 L
.97204 .229 L
.97096 .2229 L
.96944 .21631 L
.96577 .20444 L
.96142 .19377 L
.95568 .18247 L
.94259 .16256 L
.92258 .13993 L
.90032 .12044 L
.87338 .10158 L
.83998 .08284 L
.76973 .05405 L
.72908 .04197 L
.68879 .03253 L
.65121 .02565 L
.60946 .01995 L
.58728 .01769 L
.56275 .01579 L
.55031 .01506 L
.53696 .01445 L
.53048 .01422 L
Mistroke
.52434 .01403 L
.51283 .01379 L
.50199 .01368 L
.49048 .01369 L
.48067 .0138 L
.46986 .01403 L
.45828 .0144 L
.44584 .01495 L
.42345 .01634 L
.40118 .01823 L
.37767 .0208 L
.33614 .02686 L
.28846 .03646 L
.24729 .04737 L
.21049 .0596 L
.17348 .07484 L
.1418 .09091 L
.11515 .10739 L
.09036 .12618 L
.07095 .14444 L
.05321 .16578 L
.04513 .17807 L
.03884 .18966 L
.03393 .20081 L
.02975 .21327 L
.02809 .21977 L
.02685 .2259 L
.02587 .23239 L
.02548 .23604 L
.02521 .2394 L
.02497 .24515 L
.02499 .2505 L
.02529 .25637 L
.02557 .25965 L
.02591 .26263 L
.02681 .26865 L
.02813 .27515 L
.03141 .28689 L
.03545 .29761 L
.04085 .30899 L
.05337 .32907 L
.07273 .35194 L
.09446 .37169 L
.12088 .39082 L
.15379 .4099 L
.22337 .4393 L
.26369 .45166 L
.30375 .46138 L
.34116 .46851 L
.3828 .47446 L
Mistroke
.40492 .47684 L
.42941 .47888 L
.44183 .47968 L
.45518 .48037 L
.46166 .48064 L
.4678 .48085 L
.47933 .48116 L
.49017 .48133 L
.50168 .48138 L
.51151 .48132 L
.52234 .48115 L
.53394 .48084 L
.54045 .4806 L
.54641 .48035 L
.56888 .47908 L
.59084 .47733 L
.61061 .47533 L
.6542 .46938 L
.6934 .46209 L
.72904 .45365 L
.80297 .42937 L
.84016 .41258 L
.87105 .39528 L
.896 .37818 L
.91924 .3585 L
.9362 .34052 L
.9512 .32009 L
.95849 .30731 L
.96397 .29528 L
.96807 .28365 L
.96972 .27766 L
.97117 .27117 L
.97218 .26534 L
.97285 .25998 L
.97327 .25485 L
.97349 .24944 L
.97344 .2435 L
.97314 .23797 L
.97252 .23192 L
.97204 .22853 L
.97152 .22545 L
.96913 .21485 L
.96542 .20328 L
.96036 .19134 L
.95454 .18031 L
.94156 .16109 L
.92405 .14126 L
.89915 .11942 L
.87134 .10019 L
.84032 .08288 L
Mistroke
.80937 .0687 L
.73934 .04463 L
.69751 .03425 L
.6564 .02637 L
.61704 .02072 L
.58009 .01696 L
.56054 .01554 L
.54926 .0149 L
.53896 .01442 L
.52805 .01404 L
.51634 .01375 L
.50549 .0136 L
.4952 .01357 L
.48502 .01364 L
.47407 .01383 L
.46373 .01412 L
.45427 .01448 L
.43237 .01565 L
.42141 .01642 L
.40947 .0174 L
.38701 .01964 L
.36329 .02262 L
.32148 .02945 L
.28097 .03822 L
.24441 .04822 L
.18143 .07129 L
.15154 .08564 L
.12175 .10304 L
.09613 .12149 L
.07264 .14275 L
.05472 .16379 L
.04192 .1838 L
.03702 .19364 L
.03261 .2045 L
.02937 .21485 L
.02716 .2245 L
.02618 .2305 L
.0258 .23352 L
.02546 .23684 L
.0251 .24272 L
.02501 .2482 L
.02508 .25152 L
.02523 .25467 L
.02572 .26056 L
.02612 .26385 L
.02657 .26689 L
.02787 .27374 L
.03066 .28433 L
.03479 .29589 L
.04031 .30781 L
Mistroke
.04656 .31881 L
.06114 .33899 L
.0776 .35669 L
.12477 .39322 L
.15274 .40926 L
.18564 .42476 L
.25177 .4482 L
.29589 .45956 L
.33949 .46813 L
.37994 .47403 L
.40316 .47659 L
.42473 .47846 L
.43587 .47924 L
.44645 .47986 L
.45609 .48033 L
.46636 .48073 L
.47751 .48105 L
.48785 .48123 L
.49898 .48131 L
.50532 .48131 L
.51127 .48126 L
.52118 .48111 L
.53161 .48085 L
.5405 .48054 L
.55022 .48011 L
.57186 .47882 L
.59187 .47719 L
.61535 .47475 L
.63727 .47192 L
.67745 .46527 L
.71918 .45615 L
.7622 .44402 L
.82871 .41818 L
.862 .40076 L
.88976 .38282 L
.91468 .36278 L
.93456 .34252 L
.94385 .33091 L
.95259 .31794 L
.95927 .30586 L
.9643 .29458 L
.96834 .28289 L
.97001 .2767 L
.97142 .27014 L
.97236 .26441 L
.97299 .25906 L
.97341 .25318 L
.97352 .24988 L
.97355 .24687 L
.9734 .24131 L
Mistroke
.97303 .23617 L
.97238 .23053 L
.97141 .22457 L
.96911 .2146 L
.96562 .20369 L
.96045 .1914 L
.95459 .18031 L
.9376 .15606 L
.91841 .13572 L
.89419 .11558 L
.8399 .0826 L
.8046 .06667 L
.76988 .0539 L
.73543 .04348 L
.69623 .0339 L
.65772 .02652 L
.62119 .02117 L
.60033 .01878 L
.58035 .01692 L
.56927 .01607 L
.55715 .01528 L
.54598 .01468 L
.53584 .01425 L
.52536 .01391 L
.5155 .01368 L
.50507 .01355 L
.49382 .01353 L
.48393 .01361 L
.47351 .0138 L
.46462 .01405 L
.4549 .01441 L
.44255 .01501 L
.43091 .01571 L
.40922 .01739 L
.38608 .01972 L
.36125 .02288 L
.31755 .03019 L
.27867 .03878 L
.24245 .04882 L
.20565 .06142 L
.1459 .0887 L
.11445 .10795 L
.08848 .12789 L
.06869 .14698 L
.05111 .16891 L
.04401 .18015 L
.03758 .19251 L
.0327 .20435 L
.02927 .21536 L
.02703 .22539 L
Mistroke
.02613 .2311 L
.02554 .23644 L
.02516 .24208 L
.02505 .24723 L
.02518 .25317 L
.02558 .2588 L
.02623 .26438 L
.02725 .27052 L
.02865 .27692 L
.03026 .2829 L
.03388 .29351 L
.03884 .30481 L
.05408 .32987 L
.07275 .35181 L
.09337 .37064 L
.11904 .38947 L
.1739 .41953 L
.21227 .43522 L
.25137 .44803 L
.28821 .45774 L
.33057 .46653 L
.35099 .46995 L
.37325 .47313 L
.39273 .47547 L
.41417 .47756 L
.42678 .47857 L
.43851 .47937 L
.4507 .48004 L
.46177 .48053 L
.4727 .48089 L
.48299 .48113 L
.49386 .48126 L
.50562 .48127 L
.51593 .48117 L
.52554 .48099 L
.53607 .48068 L
.54733 .48022 L
.55912 .47961 L
.57024 .47891 L
.59097 .47725 L
.62783 .47319 L
.667 .46718 L
.70708 .45904 L
.74315 .44977 L
.78374 .43672 L
.81835 .42291 L
.87997 .38961 L
.90682 .36965 L
.93052 .3471 L
.94759 .32571 L
Mistroke
.95946 .30554 L
.96451 .29413 L
.96673 .28806 L
.96874 .28162 L
.97021 .27596 L
.97152 .26972 L
.97244 .26402 L
.97305 .2587 L
.97343 .2534 L
.97358 .24763 L
.97347 .24219 L
.97315 .23715 L
.97268 .23263 L
.97197 .22764 L
.97102 .22245 L
.96991 .21758 L
.9667 .20664 L
.96288 .19671 L
.95124 .17474 L
.93628 .15444 L
.91633 .13375 L
.87074 .0997 L
.83733 .08128 L
.80235 .06572 L
.7687 .05347 L
.72928 .04179 L
.69177 .03292 L
.64983 .0252 L
.62611 .02177 L
.60413 .01915 L
.58155 .01699 L
.56042 .01545 L
.54099 .01443 L
.53009 .01402 L
.5202 .01376 L
.50931 .01357 L
.49752 .0135 L
.48639 .01356 L
.47615 .01373 L
.46654 .01397 L
.45758 .01429 L
.43727 .01529 L
.41758 .01667 L
.39663 .01857 L
.35097 .02439 L
.30998 .0317 L
.26677 .04185 L
.22342 .05502 L
.15795 .08237 L
.12551 .10069 L
Mistroke
.0987 .11951 L
.07575 .13968 L
.05804 .15952 L
.04347 .18113 L
.03744 .19286 L
.0323 .20556 L
.02898 .21656 L
.02755 .2228 L
.02652 .22857 L
.02584 .23363 L
.02534 .2392 L
.02509 .24502 L
.02511 .25047 L
.02536 .25576 L
.02581 .26078 L
.02639 .26529 L
.02721 .27018 L
.02976 .28109 L
.03301 .29112 L
.03806 .30314 L
.04376 .31402 L
.06029 .33786 L
.07893 .35788 L
.10249 .37778 L
.15214 .40886 L
.18473 .42429 L
.21763 .43712 L
.25523 .44912 L
.29846 .46006 L
.34118 .46835 L
.36207 .47158 L
.38191 .4742 L
.41938 .47798 L
.43948 .47941 L
.45082 .48003 L
.46123 .48049 L
.47205 .48086 L
.48211 .48109 L
.49316 .48124 L
.50494 .48126 L
.51617 .48116 L
.52675 .48094 L
.53624 .48066 L
.54649 .48025 L
.56751 .47908 L
.58991 .47734 L
.61088 .47524 L
.62982 .47292 L
.67523 .46568 L
.71669 .45677 L
Mistroke
.75747 .44552 L
.79304 .43329 L
.82902 .41806 L
.86416 .39953 L
.8916 .38153 L
.91363 .36378 L
.93274 .34467 L
.94738 .32604 L
.95983 .30482 L
.96483 .29334 L
.96895 .28094 L
.97053 .27464 L
.97188 .26779 L
.97237 .26464 L
.9728 .2613 L
.97334 .25531 L
.97357 .24955 L
.97355 .24417 L
.97325 .23826 L
.97296 .23495 L
.97261 .23192 L
.9717 .22594 L
.97058 .22033 L
.96778 .2099 L
.96376 .19878 L
.95826 .1869 L
.94534 .16599 L
.93017 .14748 L
.91002 .12814 L
.88398 .10827 L
.85292 .08935 L
.82006 .07317 L
.78617 .05951 L
.74663 .04659 L
.71188 .03741 L
.67191 .02897 L
.62718 .0219 L
.60214 .01892 L
.57838 .01672 L
.56753 .01591 L
.55607 .01518 L
.54613 .01465 L
.53551 .0142 L
.52401 .01384 L
.51331 .01362 L
.50675 .01354 L
.50057 .0135 L
.48901 .01353 L
.47868 .01367 L
.46761 .01393 L
Mistroke
.45717 .0143 L
.44766 .01472 L
.42448 .01614 L
.40265 .01798 L
.35991 .02306 L
.33622 .02678 L
.31466 .03076 L
.24353 .0485 L
.21016 .05975 L
.17569 .07388 L
.14465 .08941 L
.11524 .10744 L
.0928 .12428 L
.07208 .14343 L
.05376 .16522 L
.04064 .18637 L
.03454 .19961 L
.0321 .20619 L
.03016 .21229 L
.0287 .21775 L
.02737 .22378 L
.02634 .22986 L
.02591 .23319 L
.02558 .23632 L
.02519 .24211 L
.0251 .24535 L
.02508 .24829 L
.02526 .25402 L
.02567 .2594 L
.02602 .26246 L
.02646 .26569 L
.02747 .27146 L
.02886 .27765 L
.03076 .28441 L
.03477 .29563 L
.04023 .30751 L
.05309 .32843 L
.0705 .34941 L
.09057 .36827 L
.13691 .40046 L
.16506 .41533 L
.199 .43014 L
.23467 .44286 L
.27561 .45461 L
.31572 .46368 L
.35386 .47036 L
.39128 .47527 L
.41037 .4772 L
.43142 .47888 L
.44233 .47957 L
Mistroke
.45391 .48017 L
.45997 .48044 L
.46664 .48068 L
.4784 .48101 L
.48949 .4812 L
.49572 .48125 L
.50141 .48126 L
.51246 .4812 L
.52294 .48103 L
.53295 .48076 L
.5436 .48037 L
.56268 .47939 L
.58524 .47775 L
.60551 .47582 L
.65023 .46997 L
.69699 .4613 L
.73921 .45089 L
.77596 .43948 L
.80943 .42676 L
.84255 .41143 L
.89419 .37964 L
.91999 .35791 L
.94002 .336 L
.95416 .31542 L
.96048 .30349 L
.96524 .29232 L
.96889 .2812 L
.97132 .27094 L
.97225 .26553 L
.97299 .25962 L
.97325 .25663 L
.97345 .25344 L
.9736 .24769 L
.9735 .24224 L
.9731 .23634 L
.97247 .23078 L
.97166 .22567 L
.96954 .21601 L
.96646 .20588 L
.96206 .19477 L
.95619 .18301 L
.94264 .16232 L
.92176 .13884 L
.89842 .1187 L
.87323 .10122 L
.84307 .08413 L
.78116 .0577 L
.74313 .04557 L
.70542 .03589 L
.66221 .02723 L
Mistroke
.63905 .02354 L
.6139 .02023 L
.59129 .01784 L
.57056 .01612 L
.56051 .01544 L
.54957 .01482 L
.5393 .01435 L
.52966 .014 L
.51844 .0137 L
.51249 .0136 L
.50609 .01353 L
.49939 .01349 L
.49303 .0135 L
.48732 .01354 L
.48109 .01362 L
.46985 .01387 L
.46356 .01406 L
.45788 .01427 L
.43642 .01534 L
.42472 .01612 L
.41241 .01709 L
.39052 .01922 L
.34202 .02581 L
.30145 .0335 L
.25879 .04404 L
.21926 .05647 L
.1843 .07008 L
.12645 .10012 L
.09905 .11926 L
.07722 .13826 L
.05741 .16036 L
.04894 .17222 L
.04138 .18496 L
.03628 .19549 L
.03178 .20714 L
.03017 .2123 L
.02868 .21783 L
.02753 .22302 L
.02666 .22783 L
.02583 .2339 L
.02552 .2371 L
.02528 .24049 L
.02509 .24619 L
.02511 .24943 L
.02519 .25245 L
.02556 .25809 L
.02612 .26323 L
.02704 .26915 L
.02818 .27475 L
.0309 .28486 L
Mistroke
.03473 .29552 L
.04399 .31437 L
.05888 .33606 L
.07585 .35486 L
.09777 .37411 L
.12465 .39303 L
.18146 .42285 L
.21737 .437 L
.25318 .44851 L
.29471 .4592 L
.34128 .46835 L
.36319 .47173 L
.38676 .47476 L
.40736 .47691 L
.42972 .47875 L
.44231 .47956 L
.45386 .48017 L
.4655 .48064 L
.47658 .48097 L
.4828 .4811 L
.48944 .4812 L
.4957 .48125 L
.50139 .48126 L
.50808 .48124 L
.51533 .48116 L
.52217 .48104 L
.52846 .48089 L
.53884 .48056 L
.54994 .48008 L
.56992 .47892 L
.59352 .47701 L
.61485 .47478 L
.66036 .46833 L
.70208 .46018 L
.73857 .45107 L
.77683 .43918 L
.81173 .4258 L
.84634 .40947 L
.87543 .3926 L
.89919 .37584 L
.92049 .35744 L
.93692 .33983 L
.9518 .31933 L
.95797 .30854 L
.96352 .29666 L
.9676 .28553 L
.96906 .2806 L
.97043 .27517 L
.97143 .27037 L
.9723 .26521 L
Mistroke
.97298 .25974 L
.97339 .25462 L
.97354 .25152 L
.97361 .24822 L
.9735 .24228 L
.9733 .23864 L
.973 .23523 L
.97266 .23216 L
.9722 .22885 L
.9711 .22267 L
.96959 .21618 L
.96603 .20463 L
.96153 .19358 L
.95642 .18341 L
.94156 .1609 L
.92296 .14001 L
.89836 .11865 L
.87309 .10113 L
.84291 .08404 L
.81305 .0701 L
.77745 .05639 L
.7089 .03669 L
.66843 .02832 L
.64575 .02454 L
.62435 .02152 L
.58581 .01734 L
.56518 .01574 L
.55443 .01508 L
.54303 .0145 L
.53707 .01425 L
.53051 .01402 L
.51895 .01371 L
.51244 .0136 L
.50545 .01352 L
.49885 .01349 L
.49282 .0135 L
.48117 .01362 L
.47459 .01375 L
.4685 .01391 L
.45735 .01429 L
.44551 .01483 L
.42398 .01617 L
.40387 .01786 L
.3587 .02324 L
.31919 .02988 L
.27748 .03909 L
.23607 .05084 L
.19984 .06369 L
.14168 .09108 L
.11347 .10867 L
Mistroke
.09084 .12593 L
.0702 .14542 L
.05236 .16719 L
.04057 .18651 L
.03532 .19774 L
.03138 .20837 L
.02961 .21426 L
.02802 .22072 L
.02683 .22684 L
.026 .23253 L
.02544 .23818 L
.02516 .2433 L
.02511 .24922 L
.02532 .25478 L
.02584 .26087 L
.02622 .26393 L
.02672 .26729 L
.02915 .27873 L
.03099 .28514 L
.03335 .29197 L
.03858 .30417 L
.05241 .32747 L
.06932 .34814 L
.09219 .36961 L
.12114 .39078 L
.17938 .42193 L
.21728 .43697 L
.2555 .44917 L
.29579 .45944 L
.33491 .46725 L
.37706 .47358 L
.39978 .47617 L
.4243 .47835 L
.44548 .47974 L
.45748 .48033 L
.46856 .48074 L
.47827 .48101 L
.48896 .48119 L
.50013 .48126 L
.51058 .48122 L
.52075 .48107 L
.53039 .48084 L
.53903 .48055 L
.54844 .48016 L
.56943 .47895 L
.58877 .47744 L
.61199 .47511 L
.63309 .47248 L
.67964 .46485 L
.71915 .45617 L
Mistroke
.7589 .44508 L
.82209 .42127 L
.85405 .40533 L
.88093 .389 L
.90632 .37011 L
.92963 .34812 L
.94732 .32616 L
.9542 .31535 L
.95973 .30506 L
.96423 .29494 L
.96758 .28557 L
.97045 .2751 L
.97164 .26929 L
.97251 .26375 L
.97311 .25843 L
.97349 .25274 L
.97361 .24737 L
.97352 .24251 L
.97315 .23677 L
.97283 .23355 L
.97245 .23058 L
.97157 .22513 L
.97038 .21938 L
.9671 .20772 L
.96295 .19677 L
.95248 .17664 L
.93739 .1557 L
.91665 .13399 L
.89509 .11617 L
.86884 .0985 L
.8139 .07047 L
.77967 .05717 L
.74621 .04645 L
.70829 .03654 L
.6649 .02769 L
.62569 .02169 L
.58836 .01756 L
.56745 .01589 L
.54833 .01475 L
.53771 .01428 L
.52617 .01389 L
.51525 .01364 L
.50517 .01352 L
.49401 .0135 L
.4834 .01359 L
.47389 .01377 L
.46352 .01406 L
.45231 .0145 L
.44039 .0151 L
.41904 .01655 L
Mistroke
.39754 .01848 L
.37748 .02073 L
.34061 .02604 L
.29773 .03432 L
.25992 .04373 L
.22086 .05592 L
.18191 .07113 L
.14909 .08701 L
.12202 .10295 L
.07778 .13773 L
.05852 .15895 L
.05005 .17056 L
.04238 .18314 L
.03682 .19429 L
.03191 .20676 L
.03018 .21227 L
.0286 .21822 L
.02738 .22378 L
.02648 .22904 L
.02573 .23489 L
.02531 .2402 L
.0251 .24593 L
.02511 .24916 L
.02519 .25214 L
.02548 .2571 L
.02604 .26256 L
.02689 .26824 L
.02792 .27354 L
.03117 .28568 L
.0352 .29665 L
.04111 .30915 L
.04792 .32081 L
.06489 .34324 L
.08452 .363 L
.11016 .38334 L
.14179 .40322 L
.20958 .43417 L
.25265 .44835 L
.29474 .4592 L
.3334 .46699 L
.37716 .4736 L
.39968 .47616 L
.42401 .47833 L
.4359 .47917 L
.44717 .47983 L
.45821 .48036 L
.46834 .48073 L
.47857 .48101 L
.48959 .4812 L
.4998 .48126 L
Mistroke
.50951 .48123 L
.52076 .48107 L
.53119 .48082 L
.54262 .48041 L
.55478 .47984 L
.57934 .47823 L
.60229 .47616 L
.64451 .47085 L
.68331 .46413 L
.71784 .4565 L
.79049 .43427 L
.82284 .42093 L
.85471 .40496 L
.90384 .37215 L
.92795 .34992 L
.94632 .3276 L
.9589 .30673 L
.96433 .29468 L
.96826 .28339 L
.96976 .27797 L
.97107 .27224 L
.97199 .26728 L
.97274 .26197 L
.97329 .25623 L
.97356 .25088 L
.97361 .24761 L
.97358 .24453 L
.97331 .23875 L
.97284 .23366 L
.97211 .22828 L
.97131 .2237 L
.97022 .21867 L
.96704 .20753 L
.96313 .19721 L
.95089 .17411 L
.93577 .15377 L
.91385 .13146 L
.88886 .11163 L
.8329 .07908 L
.79676 .06348 L
.76144 .05108 L
.72639 .041 L
.68671 .03183 L
.64781 .02486 L
.6111 .0199 L
.58956 .01767 L
.56978 .01606 L
.55879 .01533 L
.54681 .01468 L
.53547 .01419 L
Mistroke
.52497 .01386 L
.5153 .01364 L
.50623 .01353 L
.49627 .01349 L
.48555 .01356 L
.47491 .01374 L
.46374 .01405 L
.45421 .01442 L
.44382 .01492 L
.41977 .01649 L
.39811 .01842 L
.37336 .02124 L
.35034 .02449 L
.31027 .03165 L
.26856 .04139 L
.19791 .06446 L
.16188 .08043 L
.13136 .09711 L
.1033 .11601 L
.08031 .13531 L
.05848 .159 L
.05002 .1706 L
.04317 .18172 L
.03767 .19242 L
.03349 .20236 L
.02983 .21351 L
.02832 .2194 L
.02704 .22564 L
.02616 .23131 L
.0255 .23739 L
.02517 .24314 L
.0251 .24837 L
.0253 .25451 L
.02556 .25797 L
.02588 .26116 L
.02668 .26702 L
.02785 .27321 L
.03041 .28324 L
.0341 .29393 L
.04318 .31294 L
.05792 .33484 L
.07501 .35402 L
.09617 .37283 L
.12236 .39156 L
.17805 .42134 L
.21695 .43685 L
.2564 .44943 L
.29353 .45893 L
.33604 .46745 L
.35671 .47078 L
Mistroke
.37917 .47385 L
.39881 .47607 L
.42036 .47804 L
.43308 .47898 L
.44488 .47971 L
.45597 .48026 L
.46187 .48051 L
.46823 .48073 L
.47921 .48103 L
.48952 .4812 L
.50132 .48126 L
.51214 .4812 L
.52176 .48105 L
.53202 .48079 L
.54169 .48045 L
.55046 .48006 L
.5719 .47878 L
.59201 .47715 L
.63154 .47269 L
.67333 .46604 L
.71343 .45756 L
.74936 .44799 L
.7897 .43456 L
.82392 .42044 L
.88463 .3865 L
.91208 .36519 L
.93378 .34351 L
.95024 .3218 L
.96146 .30142 L
.96613 .28989 L
.96814 .28378 L
.96992 .27731 L
.9712 .2716 L
.97229 .26534 L
.973 .25963 L
.97342 .2543 L
.9736 .24896 L
.97354 .24317 L
.97323 .2377 L
.97273 .23266 L
.97209 .22813 L
.9712 .22314 L
.96876 .2131 L
.96518 .2023 L
.96024 .19081 L
.9485 .17047 L
.93089 .14824 L
.91064 .12864 L
.88438 .10851 L
.85204 .08884 L
Mistroke
.81743 .07199 L
.78181 .05792 L
.70861 .03662 L
.67046 .02869 L
.62713 .02188 L
.60485 .0192 L
.58068 .0169 L
.56889 .01599 L
.55768 .01526 L
.54767 .01472 L
.53658 .01423 L
.52635 .01389 L
.51673 .01367 L
.50657 .01353 L
.4956 .01349 L
.48596 .01356 L
.47581 .01372 L
.46715 .01395 L
.45768 .01427 L
.44646 .01478 L
.43628 .01535 L
.41354 .017 L
.39264 .01899 L
.37309 .02128 L
.33366 .02723 L
.29167 .03569 L
.24979 .04663 L
.21279 .05879 L
.15304 .08492 L
.12367 .10189 L
.09976 .11871 L
.07799 .13752 L
.0587 .15873 L
.04436 .17965 L
.03473 .1992 L
.03043 .21143 L
.02759 .22277 L
.02652 .22873 L
.02605 .23216 L
.0257 .23529 L
.02541 .2386 L
.02521 .24214 L
.02511 .24543 L
.0251 .24854 L
.02529 .25419 L
.02577 .26017 L
.02641 .26528 L
.02737 .27089 L
.02869 .27689 L
.03044 .28333 L
Mistroke
.03448 .29488 L
.03934 .30571 L
.04561 .31709 L
.05968 .33705 L
.08088 .35967 L
.10412 .37896 L
.13221 .39767 L
.16664 .41607 L
.20234 .43143 L
.23834 .44402 L
.27662 .45486 L
.31321 .46316 L
.35536 .47058 L
.37941 .47388 L
.40198 .47639 L
.42399 .47833 L
.44758 .47985 L
.45984 .48043 L
.47138 .48083 L
.478 .481 L
.48407 .48112 L
.49074 .48121 L
.49777 .48126 L
.5087 .48123 L
.52038 .48108 L
.5314 .48081 L
.54141 .48046 L
.55315 .47993 L
.56585 .47919 L
.58881 .47744 L
.60935 .47541 L
.63123 .47274 L
.67002 .46664 L
.71455 .4573 L
.7534 .44678 L
.79142 .43392 L
.8298 .41771 L
.88984 .38283 L
.91528 .36233 L
.9353 .34175 L
.94985 .3224 L
.96177 .30073 L
.96638 .28921 L
.97014 .27643 L
.97152 .26995 L
.97213 .26638 L
.97261 .26299 L
.97298 .25983 L
.97328 .2564 L
.97358 .25039 L
Mistroke
.97359 .24479 L
.97348 .24161 L
.9733 .23862 L
.97272 .23261 L
.97226 .22924 L
.97176 .22615 L
.96937 .2153 L
.9678 .20987 L
.9658 .20397 L
.96103 .19249 L
.95463 .18023 L
.93976 .1586 L
.92141 .13848 L
.90127 .12091 L
.84496 .08509 L
.81162 .06949 L
.77162 .0544 L
.73198 .04247 L
.69233 .033 L
.65534 .02606 L
.61385 .02022 L
.58981 .0177 L
.56783 .01592 L
.55557 .01514 L
.54229 .01447 L
.53617 .01422 L
.52972 .014 L
.51815 .0137 L
.50745 .01354 L
.49599 .01349 L
.48518 .01357 L
.47534 .01373 L
.46379 .01405 L
.45728 .01429 L
.45128 .01455 L
.42862 .01584 L
.40724 .01755 L
.38782 .01952 L
.3448 .02536 L
.30794 .03213 L
.27057 .04086 L
.19714 .06477 L
.15997 .08139 L
.1288 .09867 L
.10179 .11716 L
.07675 .13874 L
.05739 .16041 L
.04344 .18125 L
.03415 .20066 L
.0303 .21186 L
Mistroke
.02766 .2224 L
.02662 .22813 L
.02588 .23358 L
.02542 .23848 L
.02515 .24381 L
.02512 .24961 L
.02521 .25253 L
.02539 .25576 L
.02591 .26146 L
.02665 .2668 L
.02764 .27222 L
.02897 .278 L
.03206 .28836 L
.03689 .30054 L
.04236 .31147 L
.05775 .33462 L
.0765 .35549 L
.11899 .38937 L
.14779 .40651 L
.17715 .42093 L
.20926 .43405 L
.24622 .44644 L
.27995 .45569 L
.31836 .46419 L
.34233 .46852 L
.36497 .47198 L
.38876 .47498 L
.41056 .47721 L
.43221 .47892 L
.45272 .48011 L
.46404 .48059 L
.47447 .48091 L
.48593 .48115 L
.4917 .48122 L
.49804 .48126 L
.50879 .48123 L
.51872 .48111 L
.52962 .48086 L
.54117 .48047 L
.55115 .48003 L
.5605 .47952 L
.58171 .47804 L
.60062 .47633 L
.61781 .47444 L
.65593 .46906 L
.69333 .46209 L
.73268 .45269 L
.80576 .42829 L
Mfstroke
.92307 .3549 m
.94043 .33541 L
.95343 .31653 L
.95937 .30562 L
.96405 .29517 L
.96829 .283 L
.96974 .2777 L
.97106 .27184 L
.97209 .2661 L
.9728 .26072 L
.97329 .25503 L
.97352 .2489 L
.97346 .24322 L
.97315 .23783 L
.97268 .233 L
.97194 .22773 L
.97076 .22147 L
.9694 .21581 L
.96541 .20321 L
.96053 .19168 L
.95491 .18097 L
.93973 .15882 L
.9191 .13655 L
.89793 .11863 L
.87118 .10029 L
.83858 .08226 L
.79968 .06509 L
.75996 .05112 L
.7208 .04011 L
.6809 .03124 L
.63687 .0238 L
.61355 .02077 L
.59139 .01843 L
.56685 .01644 L
.55297 .01558 L
.5402 .01496 L
.52979 .01457 L
.51865 .01427 L
.50812 .01411 L
.49855 .01405 L
.4873 .01409 L
.48095 .01417 L
.4751 .01428 L
.46435 .01457 L
.453 .015 L
.44215 .01552 L
.43052 .01622 L
.40963 .01782 L
.385 .02029 L
.36276 .0231 L
Mistroke
.32239 .02965 L
.28091 .03856 L
.21142 .0595 L
.17285 .07534 L
.13986 .09219 L
.11347 .1087 L
.08808 .12826 L
.06701 .14881 L
.05104 .16897 L
.0382 .19109 L
.03286 .20377 L
.03094 .20943 L
.02919 .21545 L
.02793 .22065 L
.0268 .2264 L
.02601 .23164 L
.02548 .23656 L
.0251 .24235 L
.025 .24765 L
.02515 .25347 L
.02561 .25958 L
.02621 .26459 L
.02708 .26992 L
.02924 .27947 L
.03279 .29075 L
.03692 .30088 L
.04887 .32251 L
.0658 .34451 L
.0836 .36242 L
.10652 .38101 L
.13487 .39956 L
.16918 .41762 L
.23999 .44493 L
.28096 .45635 L
.32076 .46508 L
.36612 .47257 L
.38955 .47551 L
.41576 .47809 L
.42694 .47898 L
.43876 .47977 L
.44901 .48035 L
.46 .48085 L
.46621 .48108 L
.47187 .48125 L
.48293 .48151 L
.48914 .4816 L
.49587 .48165 L
.50222 .48166 L
.50809 .48163 L
.51849 .4815 L
Mistroke
.52822 .48128 L
.53888 .48094 L
.55032 .48044 L
.57356 .47902 L
.59466 .47724 L
.63612 .47236 L
.67912 .4652 L
.71826 .4566 L
.75224 .4473 L
.79018 .43451 L
.82816 .41856 L
.8605 .40171 L
.88752 .38447 L
.91178 .36539 L
.93064 .34693 L
.94774 .3254 L
.95544 .31303 L
.96137 .3014 L
.96601 .28997 L
.96972 .27771 L
.97116 .27132 L
.97219 .26532 L
.97265 .26187 L
.97299 .25871 L
.97326 .25524 L
.97345 .25159 L
.97351 .24589 L
.97328 .2398 L
.97279 .23407 L
.97211 .22887 L
.97102 .22276 L
.96949 .21618 L
.96581 .2043 L
.96144 .19363 L
.95569 .18233 L
.94257 .16243 L
.92254 .1398 L
.90025 .12033 L
.87329 .10149 L
.83988 .08276 L
.76961 .05402 L
.72895 .04198 L
.68866 .03255 L
.65109 .02569 L
.60935 .02001 L
.58717 .01777 L
.56266 .01588 L
.55022 .01515 L
.53688 .01455 L
.5304 .01431 L
Mistroke
.52426 .01413 L
.51276 .01389 L
.50192 .01378 L
.49042 .0138 L
.48061 .01391 L
.4698 .01414 L
.45823 .01452 L
.4458 .01507 L
.42341 .01646 L
.40116 .01835 L
.37766 .02092 L
.33615 .02698 L
.2885 .03656 L
.24735 .04746 L
.21056 .05968 L
.17357 .0749 L
.1419 .09096 L
.11526 .10741 L
.09046 .12618 L
.07106 .14442 L
.05331 .16574 L
.04522 .17802 L
.03893 .1896 L
.03402 .20074 L
.02983 .21319 L
.02816 .21969 L
.02692 .22582 L
.02594 .2323 L
.02554 .23595 L
.02527 .23931 L
.02503 .24505 L
.02504 .2504 L
.02533 .25627 L
.02562 .25955 L
.02595 .26253 L
.02685 .26855 L
.02816 .27505 L
.03143 .28679 L
.03546 .29751 L
.04085 .30888 L
.05336 .32897 L
.07269 .35185 L
.09441 .3716 L
.12081 .39075 L
.15371 .40984 L
.22328 .43928 L
.2636 .45166 L
.30366 .46141 L
.34107 .46854 L
.38273 .47451 L
Mistroke
.40485 .4769 L
.42935 .47895 L
.44177 .47975 L
.45512 .48044 L
.46161 .48071 L
.46775 .48093 L
.47927 .48124 L
.49012 .48141 L
.50164 .48146 L
.51147 .48141 L
.5223 .48123 L
.53391 .48092 L
.54042 .48069 L
.54638 .48043 L
.56886 .47916 L
.59083 .47742 L
.6106 .47542 L
.65421 .46947 L
.69343 .46217 L
.72908 .45372 L
.80303 .42942 L
.84023 .41261 L
.87113 .3953 L
.89608 .37818 L
.91932 .35849 L
.93628 .3405 L
.95127 .32005 L
.95855 .30726 L
.96403 .29523 L
.96812 .28359 L
.96977 .2776 L
.97122 .2711 L
.97222 .26527 L
.97289 .25992 L
.97331 .25479 L
.97352 .24937 L
.97347 .24343 L
.97317 .2379 L
.97255 .23184 L
.97206 .22845 L
.97154 .22538 L
.96915 .21478 L
.96543 .20321 L
.96036 .19126 L
.95453 .18024 L
.94154 .16102 L
.92402 .1412 L
.89911 .11936 L
.87129 .10015 L
.84026 .08285 L
Mistroke
.8093 .06868 L
.73927 .04464 L
.69745 .03427 L
.65633 .0264 L
.61699 .02076 L
.58004 .01701 L
.56049 .01559 L
.54922 .01495 L
.53892 .01448 L
.52802 .01409 L
.51631 .01381 L
.50546 .01366 L
.49517 .01363 L
.485 .01371 L
.47404 .0139 L
.46371 .01418 L
.45425 .01454 L
.43236 .01571 L
.4214 .01648 L
.40946 .01746 L
.38701 .01971 L
.3633 .02268 L
.3215 .02951 L
.281 .03827 L
.24445 .04827 L
.18148 .07132 L
.1516 .08566 L
.12181 .10305 L
.09618 .12148 L
.0727 .14273 L
.05477 .16376 L
.04197 .18376 L
.03706 .1936 L
.03265 .20445 L
.0294 .2148 L
.02719 .22446 L
.02621 .23045 L
.02582 .23347 L
.02549 .23679 L
.02512 .24266 L
.02503 .24814 L
.0251 .25147 L
.02525 .25462 L
.02574 .26051 L
.02614 .2638 L
.02659 .26683 L
.02788 .27369 L
.03066 .28428 L
.03479 .29584 L
.0403 .30776 L
Mistroke
.04655 .31876 L
.06112 .33894 L
.07757 .35664 L
.12473 .39319 L
.1527 .40923 L
.18559 .42475 L
.25172 .44821 L
.29585 .45958 L
.33945 .46816 L
.3799 .47406 L
.40312 .47662 L
.4247 .4785 L
.43584 .47928 L
.44642 .4799 L
.45606 .48037 L
.46633 .48078 L
.47749 .48109 L
.48783 .48128 L
.49896 .48136 L
.5053 .48135 L
.51126 .48131 L
.52117 .48116 L
.5316 .4809 L
.54049 .48059 L
.55022 .48016 L
.57185 .47886 L
.59187 .47724 L
.61535 .47479 L
.63728 .47196 L
.67747 .46531 L
.71921 .45619 L
.76224 .44405 L
.82875 .41819 L
.86204 .40077 L
.8898 .38282 L
.91473 .36277 L
.93459 .3425 L
.94388 .33088 L
.95262 .31791 L
.9593 .30583 L
.96433 .29455 L
.96836 .28285 L
.97003 .27666 L
.97144 .2701 L
.97237 .26437 L
.973 .25902 L
.97343 .25314 L
.97354 .24984 L
.97356 .24683 L
.97341 .24127 L
Mistroke
.97304 .23613 L
.97239 .23049 L
.97141 .22453 L
.96911 .21456 L
.96562 .20364 L
.96044 .19136 L
.95458 .18027 L
.93758 .15602 L
.91838 .13569 L
.89416 .11556 L
.83987 .08259 L
.80456 .06666 L
.76984 .0539 L
.7354 .04349 L
.6962 .03392 L
.65769 .02654 L
.62117 .0212 L
.60031 .01881 L
.58033 .01695 L
.56925 .0161 L
.55713 .01531 L
.54596 .01472 L
.53583 .01428 L
.52535 .01394 L
.51548 .01372 L
.50506 .01359 L
.49381 .01356 L
.48392 .01365 L
.4735 .01384 L
.46462 .01409 L
.4549 .01445 L
.44255 .01504 L
.43091 .01574 L
.40923 .01742 L
.38608 .01975 L
.36126 .02291 L
.31757 .03022 L
.27869 .03881 L
.24247 .04884 L
.20567 .06144 L
.14593 .0887 L
.11448 .10794 L
.08851 .12788 L
.06871 .14697 L
.05113 .16889 L
.04403 .18012 L
.0376 .19249 L
.03272 .20433 L
.02928 .21534 L
.02705 .22536 L
Mistroke
.02614 .23107 L
.02555 .23641 L
.02517 .24205 L
.02505 .2472 L
.02519 .25314 L
.02559 .25877 L
.02624 .26435 L
.02725 .27049 L
.02865 .27689 L
.03026 .28287 L
.03388 .29348 L
.03883 .30478 L
.05407 .32985 L
.07274 .35179 L
.09335 .37062 L
.11901 .38945 L
.17387 .41952 L
.21225 .43522 L
.25134 .44804 L
.28819 .45775 L
.33055 .46654 L
.35097 .46997 L
.37323 .47315 L
.39271 .47549 L
.41416 .47758 L
.42676 .47859 L
.4385 .47939 L
.45069 .48007 L
.46176 .48055 L
.47269 .48092 L
.48298 .48115 L
.49386 .48128 L
.50561 .4813 L
.51592 .4812 L
.52554 .48101 L
.53607 .4807 L
.54733 .48025 L
.55912 .47964 L
.57024 .47893 L
.59098 .47728 L
.62784 .47321 L
.66701 .4672 L
.7071 .45906 L
.74317 .44979 L
.78376 .43673 L
.81837 .42292 L
.87999 .38961 L
.90684 .36965 L
.93054 .34709 L
.9476 .32569 L
Mistroke
.95947 .30552 L
.96452 .29411 L
.96674 .28804 L
.96875 .2816 L
.97022 .27594 L
.97153 .26969 L
.97244 .264 L
.97306 .25867 L
.97343 .25338 L
.97358 .24761 L
.97347 .24216 L
.97315 .23712 L
.97268 .2326 L
.97197 .22762 L
.97101 .22242 L
.96991 .21756 L
.9667 .20662 L
.96287 .19668 L
.95123 .17472 L
.93627 .15442 L
.91631 .13373 L
.87072 .0997 L
.83731 .08128 L
.80233 .06572 L
.76868 .05347 L
.72926 .0418 L
.69175 .03293 L
.64981 .02522 L
.6261 .02179 L
.60412 .01917 L
.58154 .01701 L
.56041 .01547 L
.54098 .01445 L
.53009 .01404 L
.5202 .01377 L
.5093 .01359 L
.49751 .01352 L
.48638 .01358 L
.47615 .01375 L
.46654 .01399 L
.45758 .01431 L
.43727 .01531 L
.41759 .01669 L
.39664 .01859 L
.35098 .0244 L
.30999 .03171 L
.26678 .04186 L
.22343 .05502 L
.15796 .08238 L
.12553 .10069 L
Mistroke
.09871 .11951 L
.07576 .13967 L
.05805 .15951 L
.04348 .18112 L
.03745 .19284 L
.03231 .20554 L
.02899 .21654 L
.02756 .22278 L
.02652 .22855 L
.02585 .23361 L
.02534 .23918 L
.02509 .245 L
.02511 .25045 L
.02536 .25575 L
.02581 .26077 L
.02639 .26527 L
.02721 .27016 L
.02976 .28108 L
.033 .29111 L
.03805 .30313 L
.04376 .31401 L
.06029 .33784 L
.07892 .35787 L
.10248 .37777 L
.15213 .40885 L
.18471 .42429 L
.21761 .43712 L
.25522 .44913 L
.29845 .46007 L
.34117 .46836 L
.36206 .4716 L
.3819 .47421 L
.41937 .47799 L
.43947 .47942 L
.45082 .48005 L
.46123 .48051 L
.47205 .48087 L
.48211 .48111 L
.49315 .48125 L
.50494 .48128 L
.51617 .48117 L
.52675 .48096 L
.53624 .48067 L
.54649 .48026 L
.56751 .4791 L
.58991 .47736 L
.61088 .47525 L
.62982 .47293 L
.67523 .46569 L
.7167 .45678 L
Mistroke
.75749 .44552 L
.79306 .43329 L
.82904 .41806 L
.86417 .39953 L
.89162 .38153 L
.91364 .36378 L
.93275 .34466 L
.94738 .32603 L
.95984 .30481 L
.96484 .29333 L
.96895 .28093 L
.97054 .27463 L
.97188 .26778 L
.97237 .26463 L
.9728 .26129 L
.97334 .25529 L
.97358 .24954 L
.97355 .24415 L
.97325 .23825 L
.97296 .23494 L
.97261 .23191 L
.9717 .22593 L
.97058 .22032 L
.96778 .20989 L
.96376 .19877 L
.95826 .18689 L
.94533 .16598 L
.93016 .14748 L
.91002 .12813 L
.88397 .10826 L
.85291 .08935 L
.82004 .07317 L
.78616 .05952 L
.74662 .04659 L
.71187 .03741 L
.67191 .02898 L
.62717 .02191 L
.60214 .01893 L
.57838 .01673 L
.56752 .01592 L
.55606 .01519 L
.54613 .01466 L
.53551 .01421 L
.52401 .01385 L
.51331 .01363 L
.50675 .01355 L
.50057 .01351 L
.48901 .01354 L
.47868 .01368 L
.46761 .01394 L
Mistroke
.45717 .01431 L
.44766 .01473 L
.42448 .01615 L
.40265 .01798 L
.35991 .02307 L
.33623 .02679 L
.31467 .03077 L
.24354 .04851 L
.21017 .05975 L
.1757 .07388 L
.14466 .08941 L
.11525 .10744 L
.09281 .12427 L
.07208 .14342 L
.05377 .16521 L
.04064 .18636 L
.03455 .1996 L
.0321 .20618 L
.03016 .21229 L
.0287 .21774 L
.02737 .22377 L
.02634 .22985 L
.02591 .23318 L
.02558 .23631 L
.02519 .2421 L
.0251 .24535 L
.02508 .24828 L
.02526 .25401 L
.02567 .25939 L
.02601 .26245 L
.02646 .26568 L
.02747 .27145 L
.02886 .27764 L
.03075 .2844 L
.03476 .29563 L
.04023 .3075 L
.05308 .32843 L
.07049 .3494 L
.09057 .36827 L
.1369 .40046 L
.16505 .41533 L
.19899 .43014 L
.23466 .44286 L
.27561 .45462 L
.31572 .46368 L
.35385 .47037 L
.39127 .47528 L
.41037 .4772 L
.43142 .47888 L
.44233 .47958 L
Mistroke
.45391 .48018 L
.45997 .48044 L
.46664 .48069 L
.4784 .48102 L
.48949 .48121 L
.49572 .48126 L
.50141 .48127 L
.51246 .48121 L
.52294 .48104 L
.53296 .48077 L
.5436 .48038 L
.56268 .4794 L
.58524 .47775 L
.60552 .47582 L
.65024 .46998 L
.697 .4613 L
.73921 .4509 L
.77597 .43948 L
.80943 .42676 L
.84256 .41143 L
.89419 .37964 L
.92 .3579 L
.94002 .33599 L
.95416 .31541 L
.96048 .30348 L
.96524 .29231 L
.96889 .28119 L
.97132 .27093 L
.97225 .26553 L
.97299 .25961 L
.97325 .25662 L
.97345 .25343 L
.9736 .24769 L
.97349 .24223 L
.9731 .23633 L
.97247 .23077 L
.97166 .22566 L
.96954 .21601 L
.96646 .20587 L
.96206 .19476 L
.95619 .18301 L
.94264 .16232 L
.92176 .13884 L
.89842 .1187 L
.87322 .10122 L
.84307 .08413 L
.78115 .0577 L
.74313 .04557 L
.70541 .03589 L
.66221 .02723 L
Mistroke
.63905 .02354 L
.61389 .02023 L
.59129 .01784 L
.57055 .01612 L
.56051 .01545 L
.54957 .01482 L
.5393 .01435 L
.52966 .014 L
.51844 .01371 L
.51249 .0136 L
.50609 .01353 L
.49939 .0135 L
.49303 .01351 L
.48732 .01355 L
.48109 .01363 L
.46985 .01387 L
.46357 .01406 L
.45788 .01427 L
.43642 .01534 L
.42472 .01612 L
.41241 .0171 L
.39052 .01922 L
.34202 .02581 L
.30145 .0335 L
.2588 .04404 L
.21926 .05647 L
.18431 .07008 L
.12646 .10012 L
.09905 .11926 L
.07723 .13826 L
.05741 .16035 L
.04895 .17221 L
.04139 .18496 L
.03628 .19548 L
.03178 .20713 L
.03017 .21229 L
.02868 .21782 L
.02753 .22302 L
.02666 .22782 L
.02583 .2339 L
.02552 .2371 L
.02528 .24048 L
.02509 .24618 L
.0251 .24942 L
.02519 .25245 L
.02556 .25808 L
.02612 .26322 L
.02704 .26914 L
.02817 .27474 L
.0309 .28485 L
Mistroke
.03473 .29552 L
.04398 .31436 L
.05887 .33606 L
.07585 .35486 L
.09777 .37411 L
.12465 .39303 L
.18145 .42285 L
.21736 .437 L
.25317 .44851 L
.2947 .4592 L
.34128 .46835 L
.36319 .47173 L
.38676 .47476 L
.40736 .47692 L
.42972 .47876 L
.44231 .47957 L
.45386 .48017 L
.4655 .48064 L
.47659 .48097 L
.48281 .4811 L
.48944 .4812 L
.4957 .48125 L
.50139 .48127 L
.50808 .48124 L
.51533 .48117 L
.52217 .48105 L
.52846 .4809 L
.53884 .48056 L
.54995 .48009 L
.56992 .47892 L
.59352 .47701 L
.61485 .47478 L
.66037 .46833 L
.70208 .46018 L
.73857 .45108 L
.77683 .43918 L
.81173 .4258 L
.84634 .40947 L
.87544 .3926 L
.89919 .37584 L
.92049 .35744 L
.93692 .33982 L
.9518 .31933 L
.95797 .30854 L
.96352 .29666 L
.9676 .28552 L
.96906 .2806 L
.97043 .27516 L
.97143 .27037 L
.9723 .2652 L
Mistroke
.97298 .25974 L
.97339 .25462 L
.97354 .25152 L
.97361 .24822 L
.9735 .24228 L
.9733 .23864 L
.973 .23522 L
.97266 .23216 L
.9722 .22885 L
.97109 .22267 L
.96959 .21617 L
.96603 .20463 L
.96153 .19358 L
.95641 .18341 L
.94155 .1609 L
.92296 .14001 L
.89835 .11864 L
.87309 .10113 L
.84291 .08404 L
.81304 .0701 L
.77744 .05639 L
.7089 .03669 L
.66843 .02833 L
.64575 .02454 L
.62435 .02152 L
.5858 .01734 L
.56518 .01574 L
.55443 .01508 L
.54303 .01451 L
.53707 .01426 L
.53051 .01402 L
.51895 .01372 L
.51244 .0136 L
.50545 .01352 L
.49885 .01349 L
.49282 .0135 L
.48118 .01362 L
.4746 .01375 L
.4685 .01391 L
.45735 .01429 L
.44551 .01483 L
.42398 .01617 L
.40388 .01786 L
.3587 .02324 L
.3192 .02988 L
.27748 .03909 L
.23607 .05084 L
.19985 .06369 L
.14169 .09108 L
.11347 .10867 L
Mistroke
.09084 .12592 L
.0702 .14542 L
.05236 .16719 L
.04057 .18651 L
.03532 .19773 L
.03138 .20837 L
.02961 .21426 L
.02802 .22072 L
.02683 .22684 L
.026 .23253 L
.02544 .23818 L
.02516 .2433 L
.02511 .24921 L
.02532 .25478 L
.02584 .26087 L
.02622 .26393 L
.02672 .26729 L
.02915 .27873 L
.03099 .28514 L
.03335 .29197 L
.03858 .30417 L
.05241 .32747 L
.06931 .34814 L
.09219 .3696 L
.12113 .39078 L
.17938 .42193 L
.21727 .43697 L
.2555 .44917 L
.29579 .45944 L
.33491 .46726 L
.37706 .47359 L
.39978 .47617 L
.4243 .47835 L
.44548 .47974 L
.45748 .48033 L
.46856 .48074 L
.47827 .48101 L
.48896 .48119 L
.50013 .48126 L
.51058 .48122 L
.52075 .48107 L
.53039 .48084 L
.53903 .48055 L
.54844 .48016 L
.56943 .47895 L
.58877 .47744 L
.61199 .47511 L
.63309 .47248 L
.67964 .46485 L
.71915 .45617 L
Mistroke
.7589 .44508 L
.82209 .42127 L
.85405 .40533 L
.88093 .389 L
.90632 .37011 L
.92963 .34812 L
.94732 .32616 L
.9542 .31535 L
.95973 .30506 L
.96423 .29493 L
.96758 .28557 L
.97045 .27509 L
.97164 .26929 L
.97251 .26375 L
.97311 .25843 L
.97349 .25274 L
.97361 .24737 L
.97351 .24251 L
.97315 .23677 L
.97283 .23354 L
.97245 .23058 L
.97157 .22513 L
.97038 .21938 L
.9671 .20772 L
.96294 .19677 L
.95247 .17664 L
.93739 .1557 L
.91665 .13399 L
.89509 .11617 L
.86884 .0985 L
.8139 .07047 L
.77967 .05717 L
.74621 .04645 L
.70829 .03655 L
.6649 .0277 L
.62569 .02169 L
.58836 .01757 L
.56745 .01589 L
.54833 .01476 L
.53771 .01428 L
.52617 .01389 L
.51525 .01364 L
.50517 .01352 L
.49401 .0135 L
.4834 .01359 L
.47389 .01377 L
.46352 .01406 L
.45231 .0145 L
.44039 .01511 L
.41904 .01655 L
Mistroke
.39754 .01848 L
.37748 .02073 L
.34061 .02604 L
.29774 .03432 L
.25993 .04373 L
.22086 .05592 L
.18191 .07113 L
.14909 .08701 L
.12203 .10295 L
.07778 .13773 L
.05852 .15895 L
.05005 .17056 L
.04238 .18313 L
.03682 .19429 L
.03191 .20676 L
.03018 .21227 L
.02859 .21822 L
.02738 .22378 L
.02648 .22904 L
.02573 .23489 L
.0253 .2402 L
.0251 .24593 L
.02511 .24916 L
.02519 .25213 L
.02548 .2571 L
.02604 .26256 L
.02689 .26824 L
.02792 .27354 L
.03117 .28568 L
.0352 .29665 L
.0411 .30915 L
.04792 .32081 L
.06489 .34324 L
.08452 .363 L
.11016 .38334 L
.14179 .40322 L
.20958 .43417 L
.25265 .44835 L
.29474 .4592 L
.3334 .46699 L
.37716 .4736 L
.39968 .47616 L
.42401 .47833 L
.4359 .47917 L
.44717 .47983 L
.45821 .48036 L
.46834 .48074 L
.47857 .48101 L
.48959 .4812 L
.4998 .48126 L
Mistroke
.50951 .48123 L
.52076 .48107 L
.53119 .48082 L
.54262 .48041 L
.55478 .47984 L
.57934 .47823 L
.60229 .47616 L
.64451 .47085 L
.68331 .46413 L
.71784 .4565 L
.79049 .43427 L
.82284 .42093 L
.85471 .40496 L
.90384 .37215 L
.92795 .34992 L
.94632 .3276 L
.9589 .30673 L
.96433 .29467 L
.96826 .28339 L
.96976 .27797 L
.97107 .27224 L
.97198 .26728 L
.97274 .26197 L
.97329 .25623 L
.97356 .25088 L
.97361 .24761 L
.97358 .24452 L
.97331 .23875 L
.97284 .23366 L
.97211 .22828 L
.97131 .2237 L
.97022 .21867 L
.96704 .20753 L
.96313 .1972 L
.95089 .17411 L
.93577 .15377 L
.91385 .13146 L
.88886 .11164 L
.8329 .07908 L
.79676 .06348 L
.76144 .05108 L
.72639 .041 L
.68671 .03183 L
.64781 .02486 L
.6111 .0199 L
.58956 .01767 L
.56978 .01606 L
.55879 .01533 L
.54681 .01468 L
.53547 .01419 L
Mistroke
.52497 .01386 L
.5153 .01364 L
.50623 .01353 L
.49627 .01349 L
.48555 .01356 L
.47491 .01374 L
.46374 .01405 L
.45421 .01442 L
.44382 .01492 L
.41977 .01649 L
.39811 .01842 L
.37336 .02124 L
.35034 .02449 L
.31028 .03165 L
.26856 .04139 L
.19791 .06446 L
.16188 .08043 L
.13136 .0971 L
.1033 .11601 L
.08031 .13531 L
.05848 .159 L
.05002 .1706 L
.04317 .18171 L
.03767 .19242 L
.03349 .20236 L
.02983 .21351 L
.02832 .2194 L
.02704 .22564 L
.02616 .23131 L
.0255 .23739 L
.02517 .24314 L
.0251 .24837 L
.0253 .25451 L
.02556 .25797 L
.02588 .26116 L
.02668 .26702 L
.02784 .27321 L
.03041 .28324 L
.0341 .29393 L
.04318 .31294 L
.05792 .33484 L
.07501 .35402 L
.09617 .37283 L
.12236 .39156 L
.17805 .42134 L
.21695 .43685 L
.2564 .44943 L
.29353 .45893 L
.33604 .46745 L
.35671 .47078 L
Mistroke
.37917 .47385 L
.39881 .47607 L
.42036 .47804 L
.43308 .47898 L
.44488 .47971 L
.45597 .48026 L
.46187 .48051 L
.46823 .48073 L
.47921 .48103 L
.48952 .4812 L
.50132 .48126 L
.51214 .4812 L
.52176 .48105 L
.53202 .48079 L
.5417 .48045 L
.55047 .48006 L
.5719 .47878 L
.59201 .47715 L
.63154 .47269 L
.67333 .46604 L
.71344 .45756 L
.74936 .44799 L
.7897 .43456 L
.82392 .42044 L
.88463 .3865 L
.91209 .36519 L
.93378 .34351 L
.95024 .32179 L
.96146 .30142 L
.96613 .28989 L
.96814 .28378 L
.96992 .27731 L
.9712 .2716 L
.97229 .26534 L
.973 .25963 L
.97342 .2543 L
.9736 .24896 L
.97354 .24317 L
.97323 .2377 L
.97272 .23266 L
.97209 .22813 L
.9712 .22314 L
.96876 .2131 L
.96518 .2023 L
.96024 .19081 L
.9485 .17047 L
.93088 .14824 L
.91064 .12864 L
.88438 .10851 L
.85204 .08884 L
Mistroke
.81743 .07199 L
.78181 .05792 L
.70861 .03662 L
.67046 .02869 L
.62713 .02188 L
.60485 .0192 L
.58068 .0169 L
.56889 .01599 L
.55768 .01527 L
.54767 .01472 L
.53658 .01424 L
.52635 .01389 L
.51673 .01367 L
.50657 .01353 L
.4956 .01349 L
.48596 .01356 L
.47581 .01372 L
.46715 .01395 L
.45768 .01427 L
.44646 .01478 L
.43628 .01535 L
.41354 .017 L
.39264 .01899 L
.37309 .02128 L
.33366 .02723 L
.29167 .03569 L
.24979 .04663 L
.21279 .05879 L
.15304 .08492 L
.12367 .10189 L
.09976 .11871 L
.07799 .13752 L
.0587 .15873 L
.04436 .17965 L
.03473 .1992 L
.03043 .21143 L
.02759 .22277 L
.02652 .22873 L
.02605 .23216 L
.0257 .23529 L
.02541 .2386 L
.02521 .24214 L
.02511 .24543 L
.0251 .24854 L
.02529 .25419 L
.02577 .26017 L
.02641 .26528 L
.02737 .27089 L
.02869 .27689 L
.03044 .28333 L
Mistroke
.03448 .29488 L
.03934 .30571 L
.04561 .31709 L
.05968 .33705 L
.08088 .35967 L
.10412 .37896 L
.13221 .39767 L
.16664 .41607 L
.20234 .43143 L
.23834 .44402 L
.27662 .45486 L
.31321 .46316 L
.35536 .47058 L
.37941 .47388 L
.40198 .47639 L
.42399 .47833 L
.44758 .47985 L
.45984 .48043 L
.47138 .48083 L
.478 .481 L
.48407 .48112 L
.49074 .48121 L
.49777 .48126 L
.5087 .48123 L
.52038 .48108 L
.5314 .48081 L
.54141 .48046 L
.55315 .47993 L
.56585 .47919 L
.58881 .47744 L
.60935 .47541 L
.63123 .47274 L
.67002 .46664 L
.71455 .4573 L
.7534 .44678 L
.79142 .43392 L
.8298 .41771 L
.88984 .38283 L
.91528 .36233 L
.9353 .34175 L
.94985 .3224 L
.96177 .30073 L
.96638 .28921 L
.97014 .27643 L
.97152 .26995 L
.97213 .26638 L
.97261 .26299 L
.97298 .25983 L
.97328 .2564 L
.97358 .25039 L
Mistroke
.97359 .24479 L
.97348 .24161 L
.9733 .23862 L
.97272 .23261 L
.97226 .22924 L
.97176 .22615 L
.96937 .2153 L
.96779 .20987 L
.9658 .20397 L
.96103 .19249 L
.95463 .18023 L
.93976 .1586 L
.92141 .13848 L
.90127 .12091 L
.84496 .08509 L
.81162 .06949 L
.77162 .0544 L
.73198 .04247 L
.69233 .033 L
.65534 .02606 L
.61385 .02022 L
.58981 .0177 L
.56783 .01592 L
.55557 .01514 L
.54229 .01447 L
.53617 .01422 L
.52972 .014 L
.51815 .0137 L
.50745 .01354 L
.49599 .01349 L
.48518 .01357 L
.47534 .01373 L
.46379 .01405 L
.45728 .01429 L
.45128 .01455 L
.42862 .01584 L
.40724 .01755 L
.38782 .01952 L
.3448 .02536 L
.30794 .03213 L
.27057 .04086 L
.19714 .06477 L
.15997 .08138 L
.1288 .09867 L
.10179 .11716 L
.07675 .13874 L
.05739 .16041 L
.04344 .18125 L
.03415 .20066 L
.0303 .21186 L
Mistroke
.02766 .2224 L
.02662 .22813 L
.02588 .23358 L
.02542 .23848 L
.02515 .24381 L
.02512 .24961 L
.02521 .25253 L
.02539 .25576 L
.02591 .26146 L
.02665 .2668 L
.02764 .27222 L
.02897 .278 L
.03206 .28836 L
.03689 .30054 L
.04236 .31147 L
.05775 .33462 L
.0765 .35549 L
.11899 .38937 L
.14779 .40651 L
.17715 .42093 L
.20926 .43405 L
.24622 .44645 L
.27995 .45569 L
.31836 .46419 L
.34233 .46852 L
.36497 .47198 L
.38876 .47498 L
.41056 .47721 L
.43221 .47892 L
.45272 .48011 L
.46404 .48059 L
.47447 .48091 L
.48593 .48115 L
.4917 .48122 L
.49804 .48126 L
.50879 .48123 L
.51872 .48111 L
.52962 .48086 L
.54117 .48047 L
.55115 .48003 L
.5605 .47952 L
.58171 .47804 L
.60062 .47633 L
.61781 .47444 L
.65593 .46906 L
.69333 .46209 L
.73268 .45269 L
.80576 .42829 L
Mfstroke
.92321 .35465 m
.94053 .33514 L
.95348 .31625 L
.9594 .30534 L
.96405 .29489 L
.96826 .28273 L
.96969 .27743 L
.97101 .27157 L
.97202 .26584 L
.97272 .26046 L
.9732 .25477 L
.97341 .24865 L
.97334 .24298 L
.97303 .2376 L
.97254 .23277 L
.97179 .22752 L
.9706 .22126 L
.96924 .2156 L
.96522 .20303 L
.96033 .19152 L
.9547 .18083 L
.93949 .15873 L
.91884 .13651 L
.89768 .11864 L
.87094 .10035 L
.83835 .08238 L
.79949 .06524 L
.7598 .05131 L
.72068 .04033 L
.68082 .03147 L
.63684 .02404 L
.61354 .02101 L
.59141 .01866 L
.56689 .01666 L
.55302 .0158 L
.54027 .01518 L
.52986 .01479 L
.51873 .01448 L
.50822 .01431 L
.49866 .01425 L
.48741 .01429 L
.48107 .01436 L
.47522 .01447 L
.46448 .01475 L
.45314 .01517 L
.4423 .01569 L
.43068 .01638 L
.4098 .01796 L
.38518 .02041 L
.36295 .0232 L
Mistroke
.3226 .02971 L
.28112 .03858 L
.21163 .05945 L
.17304 .07524 L
.14003 .09206 L
.11361 .10854 L
.08819 .12808 L
.06708 .14861 L
.05107 .16876 L
.03819 .19088 L
.03284 .20357 L
.03091 .20923 L
.02915 .21526 L
.02788 .22046 L
.02674 .22621 L
.02594 .23145 L
.0254 .23638 L
.02501 .24217 L
.0249 .24748 L
.02505 .2533 L
.0255 .25943 L
.0261 .26444 L
.02696 .26977 L
.02911 .27934 L
.03264 .29063 L
.03676 .30077 L
.0487 .32243 L
.06562 .34448 L
.08342 .36242 L
.10634 .38104 L
.1347 .39962 L
.16903 .41772 L
.23989 .44508 L
.28088 .45652 L
.32072 .46525 L
.36611 .47274 L
.38956 .47568 L
.41579 .47826 L
.42698 .47914 L
.43881 .47993 L
.44906 .48051 L
.46006 .481 L
.46627 .48123 L
.47193 .48141 L
.48301 .48165 L
.48922 .48174 L
.49595 .48179 L
.50231 .4818 L
.50818 .48177 L
.51859 .48163 L
Mistroke
.52832 .48141 L
.53899 .48106 L
.55044 .48055 L
.57368 .47912 L
.59479 .47733 L
.63626 .47243 L
.67928 .46523 L
.71842 .45661 L
.7524 .44727 L
.79033 .43445 L
.82829 .41847 L
.86062 .4016 L
.88761 .38434 L
.91185 .36525 L
.93069 .34678 L
.94776 .32525 L
.95544 .31288 L
.96135 .30125 L
.96598 .28983 L
.96968 .27757 L
.97111 .27119 L
.97214 .26518 L
.97259 .26174 L
.97293 .25858 L
.9732 .25511 L
.97337 .25146 L
.97343 .24577 L
.9732 .23969 L
.9727 .23396 L
.97202 .22876 L
.97092 .22267 L
.96939 .21608 L
.9657 .20422 L
.96133 .19356 L
.95557 .18227 L
.94244 .16239 L
.9224 .1398 L
.90012 .12035 L
.87317 .10154 L
.83976 .08284 L
.76953 .05413 L
.7289 .0421 L
.68863 .03268 L
.65108 .02582 L
.60936 .02014 L
.5872 .01789 L
.5627 .016 L
.55027 .01527 L
.53693 .01465 L
.53045 .01442 L
Mistroke
.52432 .01424 L
.51282 .01399 L
.50199 .01388 L
.49049 .01389 L
.48069 .014 L
.46989 .01423 L
.45831 .0146 L
.44589 .01515 L
.42351 .01653 L
.40126 .01841 L
.37777 .02097 L
.33627 .027 L
.28862 .03656 L
.24746 .04744 L
.21067 .05963 L
.17367 .07483 L
.14199 .09087 L
.11532 .10732 L
.09051 .12608 L
.07109 .14431 L
.05331 .16563 L
.04522 .17791 L
.03891 .18949 L
.03399 .20064 L
.02979 .21309 L
.02812 .21959 L
.02687 .22572 L
.02589 .23221 L
.02549 .23586 L
.02522 .23922 L
.02497 .24497 L
.02498 .25032 L
.02526 .25619 L
.02555 .25948 L
.02588 .26246 L
.02678 .26848 L
.02808 .27499 L
.03135 .28673 L
.03537 .29746 L
.04076 .30885 L
.05326 .32895 L
.07259 .35185 L
.09432 .37162 L
.12072 .39079 L
.15363 .4099 L
.22323 .43937 L
.26356 .45175 L
.30364 .4615 L
.34107 .46864 L
.38274 .4746 L
Mistroke
.40487 .47699 L
.42938 .47903 L
.44181 .47983 L
.45516 .48052 L
.46165 .48079 L
.4678 .481 L
.47932 .48131 L
.49017 .48148 L
.50169 .48153 L
.51153 .48147 L
.52237 .48129 L
.53397 .48098 L
.54049 .48074 L
.54645 .48049 L
.56894 .47921 L
.5909 .47746 L
.61068 .47545 L
.6543 .46948 L
.69351 .46216 L
.72916 .45371 L
.80311 .42938 L
.84029 .41255 L
.87118 .39523 L
.89611 .37811 L
.91934 .35841 L
.93629 .34042 L
.95126 .31997 L
.95854 .30719 L
.96401 .29515 L
.96809 .28352 L
.96974 .27753 L
.97118 .27104 L
.97218 .26521 L
.97285 .25985 L
.97327 .25472 L
.97347 .24932 L
.97342 .24338 L
.97312 .23785 L
.97249 .23179 L
.97201 .22841 L
.97149 .22533 L
.96908 .21474 L
.96537 .20317 L
.96029 .19124 L
.95446 .18022 L
.94147 .16102 L
.92395 .14121 L
.89904 .11939 L
.87122 .10018 L
.84021 .0829 L
Mistroke
.80926 .06874 L
.73925 .04471 L
.69744 .03434 L
.65634 .02647 L
.61701 .02083 L
.58007 .01707 L
.56053 .01565 L
.54926 .01501 L
.53896 .01453 L
.52806 .01414 L
.51635 .01386 L
.5055 .01371 L
.49522 .01368 L
.48505 .01375 L
.47409 .01394 L
.46376 .01422 L
.45431 .01458 L
.43242 .01574 L
.42146 .01651 L
.40952 .01748 L
.38707 .01972 L
.36336 .02269 L
.32157 .02951 L
.28106 .03826 L
.2445 .04825 L
.18153 .07128 L
.15164 .08561 L
.12184 .103 L
.0962 .12142 L
.07271 .14267 L
.05477 .1637 L
.04195 .18371 L
.03704 .19355 L
.03263 .2044 L
.02938 .21475 L
.02716 .22441 L
.02617 .23041 L
.02579 .23343 L
.02546 .23675 L
.02508 .24262 L
.02499 .2481 L
.02506 .25143 L
.02521 .25458 L
.0257 .26047 L
.0261 .26377 L
.02654 .2668 L
.02784 .27366 L
.03061 .28425 L
.03474 .29582 L
.04025 .30775 L
Mistroke
.04649 .31875 L
.06107 .33894 L
.07752 .35666 L
.12469 .39322 L
.15266 .40927 L
.18556 .42479 L
.2517 .44825 L
.29584 .45963 L
.33946 .46821 L
.37992 .4741 L
.40314 .47667 L
.42473 .47854 L
.43586 .47932 L
.44645 .47994 L
.45609 .48041 L
.46636 .48081 L
.47752 .48113 L
.48787 .48131 L
.499 .48139 L
.50534 .48138 L
.5113 .48134 L
.52121 .48118 L
.53164 .48092 L
.54053 .48061 L
.55026 .48018 L
.5719 .47888 L
.59192 .47725 L
.6154 .4748 L
.63732 .47197 L
.67752 .4653 L
.71925 .45618 L
.76228 .44403 L
.82878 .41816 L
.86206 .40073 L
.88982 .38278 L
.91473 .36273 L
.93459 .34246 L
.94388 .33084 L
.95261 .31787 L
.95929 .30579 L
.96431 .29451 L
.96834 .28282 L
.97 .27663 L
.97141 .27007 L
.97235 .26434 L
.97298 .25899 L
.9734 .25311 L
.97351 .24981 L
.97353 .24681 L
.97338 .24124 L
Mistroke
.97301 .23611 L
.97236 .23047 L
.97138 .22451 L
.96907 .21454 L
.96558 .20363 L
.9604 .19135 L
.95454 .18027 L
.93754 .15603 L
.91835 .1357 L
.89412 .11558 L
.83984 .08262 L
.80454 .0667 L
.76983 .05394 L
.73539 .04353 L
.6962 .03396 L
.65769 .02658 L
.62118 .02123 L
.60032 .01884 L
.58035 .01698 L
.56927 .01613 L
.55715 .01534 L
.54598 .01474 L
.53585 .01431 L
.52537 .01396 L
.51551 .01374 L
.50509 .01361 L
.49384 .01358 L
.48395 .01367 L
.47353 .01386 L
.46465 .0141 L
.45493 .01446 L
.44258 .01505 L
.43094 .01575 L
.40926 .01743 L
.38612 .01976 L
.36129 .02291 L
.3176 .03021 L
.27872 .0388 L
.2425 .04883 L
.2057 .06142 L
.14595 .08867 L
.11449 .10791 L
.08851 .12784 L
.06871 .14693 L
.05113 .16886 L
.04402 .18009 L
.03758 .19246 L
.03271 .2043 L
.02926 .21531 L
.02703 .22534 L
Mistroke
.02612 .23105 L
.02552 .23639 L
.02515 .24204 L
.02503 .24719 L
.02517 .25313 L
.02556 .25875 L
.02621 .26434 L
.02723 .27048 L
.02862 .27688 L
.03023 .28287 L
.03385 .29347 L
.0388 .30478 L
.05404 .32985 L
.07271 .3518 L
.09332 .37064 L
.11899 .38947 L
.17386 .41955 L
.21224 .43525 L
.25134 .44806 L
.28819 .45778 L
.33056 .46657 L
.35098 .47 L
.37324 .47318 L
.39272 .47551 L
.41417 .4776 L
.42678 .47861 L
.43852 .47941 L
.45071 .48009 L
.46178 .48057 L
.47271 .48093 L
.483 .48117 L
.49388 .4813 L
.50563 .48131 L
.51595 .48121 L
.52556 .48102 L
.53609 .48071 L
.54735 .48026 L
.55914 .47965 L
.57027 .47894 L
.591 .47728 L
.62787 .47321 L
.66704 .46719 L
.70712 .45905 L
.74319 .44978 L
.78377 .43672 L
.81839 .4229 L
.88 .38958 L
.90684 .36962 L
.93054 .34707 L
.9476 .32567 L
Mistroke
.95946 .3055 L
.96451 .29409 L
.96673 .28803 L
.96873 .28159 L
.9702 .27592 L
.97152 .26968 L
.97243 .26399 L
.97304 .25866 L
.97342 .25337 L
.97356 .2476 L
.97345 .24215 L
.97313 .23712 L
.97266 .2326 L
.97195 .22761 L
.97099 .22242 L
.96989 .21755 L
.96667 .20662 L
.96285 .19668 L
.95121 .17472 L
.93625 .15443 L
.91629 .13374 L
.87071 .09971 L
.8373 .0813 L
.80233 .06574 L
.76868 .05349 L
.72926 .04182 L
.69175 .03295 L
.64982 .02523 L
.62611 .0218 L
.60413 .01918 L
.58155 .01702 L
.56043 .01548 L
.541 .01446 L
.5301 .01405 L
.52021 .01378 L
.50932 .0136 L
.49753 .01353 L
.4864 .01359 L
.47617 .01375 L
.46656 .014 L
.4576 .01431 L
.43729 .01532 L
.4176 .01669 L
.39666 .01859 L
.351 .0244 L
.31001 .03171 L
.2668 .04185 L
.22344 .05501 L
.15797 .08236 L
.12553 .10067 L
Mistroke
.09871 .11949 L
.07576 .13966 L
.05804 .1595 L
.04347 .1811 L
.03744 .19283 L
.0323 .20553 L
.02897 .21653 L
.02754 .22277 L
.02651 .22854 L
.02583 .2336 L
.02533 .23917 L
.02508 .245 L
.02509 .25044 L
.02534 .25574 L
.02579 .26076 L
.02637 .26526 L
.02719 .27016 L
.02975 .28107 L
.03299 .29111 L
.03804 .30313 L
.04374 .31401 L
.06027 .33785 L
.07891 .35788 L
.10247 .37778 L
.15212 .40887 L
.18471 .4243 L
.21761 .43714 L
.25522 .44914 L
.29845 .46008 L
.34117 .46837 L
.36207 .47161 L
.38191 .47422 L
.41938 .478 L
.43949 .47943 L
.45083 .48005 L
.46124 .48051 L
.47206 .48088 L
.48212 .48111 L
.49317 .48126 L
.50496 .48128 L
.51619 .48117 L
.52676 .48096 L
.53625 .48068 L
.5465 .48027 L
.56752 .4791 L
.58993 .47736 L
.61089 .47525 L
.62984 .47293 L
.67525 .46568 L
.71671 .45677 L
Mistroke
.7575 .44551 L
.79306 .43328 L
.82904 .41805 L
.86418 .39952 L
.89162 .38152 L
.91364 .36377 L
.93274 .34465 L
.94738 .32602 L
.95983 .3048 L
.96483 .29332 L
.96894 .28092 L
.97053 .27462 L
.97187 .26777 L
.97236 .26462 L
.97279 .26128 L
.97333 .25529 L
.97356 .24954 L
.97354 .24415 L
.97324 .23825 L
.97295 .23493 L
.9726 .23191 L
.97169 .22593 L
.97057 .22032 L
.96777 .20989 L
.96375 .19877 L
.95824 .18689 L
.94532 .16598 L
.93015 .14748 L
.91001 .12814 L
.88396 .10827 L
.8529 .08936 L
.82004 .07318 L
.78616 .05953 L
.74662 .0466 L
.71188 .03742 L
.67191 .02899 L
.62718 .02191 L
.60214 .01894 L
.57839 .01674 L
.56753 .01592 L
.55607 .01519 L
.54614 .01467 L
.53552 .01422 L
.52402 .01385 L
.51331 .01363 L
.50676 .01355 L
.50058 .01351 L
.48902 .01354 L
.47869 .01368 L
.46762 .01395 L
Mistroke
.45718 .01431 L
.44767 .01473 L
.42449 .01615 L
.40266 .01798 L
.35992 .02307 L
.33624 .02678 L
.31468 .03076 L
.24354 .0485 L
.21017 .05974 L
.1757 .07388 L
.14466 .0894 L
.11525 .10743 L
.09281 .12426 L
.07208 .14342 L
.05376 .1652 L
.04063 .18635 L
.03454 .1996 L
.03209 .20617 L
.03015 .21228 L
.02869 .21774 L
.02736 .22377 L
.02633 .22985 L
.0259 .23318 L
.02558 .23631 L
.02519 .2421 L
.02509 .24534 L
.02508 .24828 L
.02525 .25401 L
.02567 .25939 L
.02601 .26245 L
.02645 .26568 L
.02746 .27145 L
.02885 .27764 L
.03074 .28441 L
.03476 .29563 L
.04022 .3075 L
.05307 .32843 L
.07048 .34941 L
.09056 .36827 L
.1369 .40046 L
.16505 .41534 L
.19899 .43015 L
.23466 .44287 L
.27561 .45463 L
.31572 .46369 L
.35386 .47037 L
.39128 .47529 L
.41037 .47721 L
.43142 .47889 L
.44233 .47958 L
Mistroke
.45391 .48018 L
.45997 .48045 L
.46664 .48069 L
.4784 .48102 L
.4895 .48121 L
.49573 .48126 L
.50142 .48127 L
.51247 .48121 L
.52295 .48104 L
.53296 .48077 L
.54361 .48038 L
.56269 .4794 L
.58525 .47775 L
.60552 .47582 L
.65024 .46997 L
.697 .4613 L
.73922 .45089 L
.77597 .43947 L
.80944 .42675 L
.84256 .41142 L
.89419 .37963 L
.92 .3579 L
.94002 .33599 L
.95416 .31541 L
.96048 .30348 L
.96523 .29231 L
.96888 .28119 L
.97131 .27093 L
.97224 .26553 L
.97298 .25961 L
.97325 .25662 L
.97345 .25343 L
.9736 .24768 L
.97349 .24223 L
.9731 .23633 L
.97246 .23077 L
.97166 .22566 L
.96953 .21601 L
.96646 .20588 L
.96205 .19477 L
.95618 .18301 L
.94263 .16232 L
.92175 .13884 L
.89841 .11871 L
.87322 .10122 L
.84307 .08414 L
.78115 .05771 L
.74313 .04558 L
.70542 .0359 L
.66221 .02724 L
Mistroke
.63905 .02355 L
.6139 .02024 L
.5913 .01785 L
.57056 .01612 L
.56051 .01545 L
.54958 .01483 L
.5393 .01435 L
.52966 .014 L
.51845 .01371 L
.5125 .01361 L
.50609 .01353 L
.4994 .0135 L
.49304 .01351 L
.48733 .01355 L
.4811 .01363 L
.46985 .01387 L
.46357 .01406 L
.45789 .01427 L
.43642 .01534 L
.42472 .01612 L
.41242 .01709 L
.39053 .01922 L
.34203 .02581 L
.30145 .0335 L
.2588 .04404 L
.21927 .05647 L
.18431 .07008 L
.12646 .10011 L
.09905 .11925 L
.07722 .13825 L
.05741 .16035 L
.04894 .17221 L
.04138 .18495 L
.03628 .19548 L
.03178 .20713 L
.03016 .21229 L
.02868 .21782 L
.02752 .22302 L
.02665 .22782 L
.02583 .23389 L
.02552 .23709 L
.02528 .24048 L
.02509 .24618 L
.0251 .24942 L
.02519 .25245 L
.02555 .25808 L
.02611 .26322 L
.02703 .26914 L
.02817 .27474 L
.03089 .28485 L
Mistroke
.03472 .29552 L
.04398 .31436 L
.05887 .33606 L
.07584 .35486 L
.09776 .37412 L
.12464 .39304 L
.18145 .42285 L
.21736 .43701 L
.25317 .44851 L
.2947 .45921 L
.34128 .46835 L
.36319 .47173 L
.38676 .47476 L
.40736 .47692 L
.42973 .47876 L
.44231 .47957 L
.45386 .48017 L
.4655 .48065 L
.47659 .48097 L
.48281 .4811 L
.48944 .4812 L
.49571 .48125 L
.50139 .48127 L
.50809 .48124 L
.51534 .48117 L
.52217 .48105 L
.52846 .4809 L
.53884 .48056 L
.54995 .48009 L
.56993 .47892 L
.59353 .47701 L
.61486 .47478 L
.66037 .46833 L
.70209 .46018 L
.73857 .45107 L
.77683 .43918 L
.81173 .42579 L
.84634 .40946 L
.87544 .3926 L
.89919 .37583 L
.92049 .35744 L
.93692 .33982 L
.95179 .31933 L
.95797 .30854 L
.96352 .29666 L
.96759 .28552 L
.96905 .2806 L
.97043 .27516 L
.97143 .27037 L
.9723 .2652 L
Mistroke
.97298 .25974 L
.97339 .25462 L
.97353 .25152 L
.9736 .24822 L
.9735 .24228 L
.97329 .23864 L
.973 .23522 L
.97265 .23216 L
.97219 .22885 L
.97109 .22267 L
.96959 .21618 L
.96602 .20463 L
.96153 .19358 L
.95641 .18341 L
.94155 .1609 L
.92296 .14002 L
.89835 .11865 L
.87309 .10113 L
.8429 .08404 L
.81304 .07011 L
.77744 .0564 L
.7089 .03669 L
.66843 .02833 L
.64575 .02454 L
.62436 .02152 L
.58581 .01734 L
.56518 .01574 L
.55443 .01508 L
.54303 .01451 L
.53707 .01426 L
.53051 .01402 L
.51895 .01372 L
.51244 .0136 L
.50545 .01352 L
.49885 .01349 L
.49282 .0135 L
.48118 .01362 L
.4746 .01375 L
.46851 .01391 L
.45735 .01429 L
.44551 .01483 L
.42398 .01617 L
.40388 .01786 L
.35871 .02324 L
.3192 .02988 L
.27748 .03909 L
.23607 .05084 L
.19985 .06369 L
.14169 .09107 L
.11347 .10866 L
Mistroke
.09084 .12592 L
.0702 .14541 L
.05236 .16719 L
.04057 .18651 L
.03532 .19773 L
.03138 .20837 L
.02961 .21426 L
.02801 .22072 L
.02682 .22684 L
.02599 .23253 L
.02544 .23818 L
.02516 .2433 L
.0251 .24921 L
.02531 .25478 L
.02584 .26087 L
.02622 .26393 L
.02672 .26729 L
.02915 .27873 L
.03099 .28514 L
.03335 .29197 L
.03858 .30417 L
.05241 .32747 L
.06931 .34814 L
.09219 .36961 L
.12113 .39078 L
.17938 .42194 L
.21727 .43697 L
.2555 .44918 L
.2958 .45945 L
.33491 .46726 L
.37706 .47359 L
.39978 .47617 L
.4243 .47836 L
.44548 .47974 L
.45748 .48033 L
.46856 .48074 L
.47827 .48101 L
.48897 .48119 L
.50014 .48126 L
.51059 .48122 L
.52075 .48107 L
.53039 .48084 L
.53904 .48055 L
.54844 .48016 L
.56943 .47895 L
.58878 .47744 L
.612 .47511 L
.63309 .47248 L
.67964 .46485 L
.71915 .45617 L
Mistroke
.75891 .44508 L
.82209 .42127 L
.85405 .40532 L
.88093 .389 L
.90632 .37011 L
.92963 .34812 L
.94731 .32616 L
.9542 .31535 L
.95973 .30506 L
.96423 .29493 L
.96758 .28557 L
.97045 .27509 L
.97164 .26929 L
.97251 .26375 L
.97311 .25843 L
.97349 .25274 L
.97361 .24737 L
.97351 .24251 L
.97315 .23677 L
.97282 .23354 L
.97245 .23058 L
.97157 .22513 L
.97038 .21938 L
.9671 .20772 L
.96294 .19677 L
.95247 .17664 L
.93738 .1557 L
.91665 .13399 L
.89509 .11617 L
.86884 .0985 L
.8139 .07047 L
.77967 .05717 L
.74621 .04645 L
.70829 .03655 L
.6649 .0277 L
.62569 .02169 L
.58836 .01757 L
.56746 .01589 L
.54834 .01476 L
.53771 .01428 L
.52617 .01389 L
.51525 .01364 L
.50517 .01352 L
.49401 .0135 L
.4834 .01359 L
.47389 .01377 L
.46353 .01406 L
.45231 .0145 L
.44039 .0151 L
.41905 .01655 L
Mistroke
.39754 .01848 L
.37748 .02073 L
.34061 .02604 L
.29774 .03432 L
.25993 .04373 L
.22086 .05591 L
.18191 .07113 L
.14909 .08701 L
.12203 .10294 L
.07778 .13773 L
.05852 .15895 L
.05005 .17055 L
.04238 .18313 L
.03681 .19429 L
.03191 .20676 L
.03018 .21227 L
.02859 .21822 L
.02738 .22378 L
.02647 .22904 L
.02573 .23489 L
.0253 .2402 L
.0251 .24593 L
.02511 .24916 L
.02519 .25213 L
.02548 .2571 L
.02604 .26256 L
.02688 .26824 L
.02791 .27354 L
.03117 .28568 L
.0352 .29665 L
.0411 .30915 L
.04792 .32081 L
.06489 .34324 L
.08452 .363 L
.11016 .38334 L
.14179 .40322 L
.20958 .43417 L
.25265 .44835 L
.29474 .45921 L
.3334 .46699 L
.37716 .4736 L
.39968 .47616 L
.42402 .47833 L
.4359 .47917 L
.44717 .47983 L
.45822 .48036 L
.46834 .48074 L
.47857 .48101 L
.48959 .4812 L
.4998 .48126 L
Mistroke
.50952 .48123 L
.52076 .48107 L
.53119 .48082 L
.54262 .48041 L
.55478 .47984 L
.57934 .47823 L
.60229 .47616 L
.64452 .47085 L
.68331 .46413 L
.71784 .4565 L
.79049 .43427 L
.82284 .42093 L
.85471 .40496 L
.90384 .37215 L
.92795 .34992 L
.94631 .3276 L
.9589 .30673 L
.96433 .29467 L
.96826 .28339 L
.96976 .27797 L
.97107 .27224 L
.97198 .26728 L
.97274 .26197 L
.97329 .25623 L
.97356 .25088 L
.97361 .24761 L
.97358 .24452 L
.97331 .23875 L
.97284 .23366 L
.97211 .22828 L
.9713 .2237 L
.97021 .21867 L
.96704 .20753 L
.96313 .19721 L
.95089 .17411 L
.93577 .15377 L
.91385 .13146 L
.88886 .11164 L
.8329 .07908 L
.79676 .06348 L
.76144 .05108 L
.72639 .041 L
.68671 .03183 L
.64781 .02486 L
.6111 .0199 L
.58956 .01767 L
.56979 .01606 L
.55879 .01533 L
.54681 .01468 L
.53547 .01419 L
Mistroke
.52497 .01386 L
.5153 .01364 L
.50623 .01353 L
.49627 .01349 L
.48555 .01356 L
.47491 .01374 L
.46374 .01405 L
.45421 .01442 L
.44382 .01492 L
.41977 .01649 L
.39811 .01842 L
.37336 .02124 L
.35034 .02449 L
.31028 .03165 L
.26856 .04139 L
.19791 .06446 L
.16188 .08043 L
.13136 .0971 L
.1033 .11601 L
.08031 .13531 L
.05848 .159 L
.05002 .1706 L
.04317 .18171 L
.03767 .19242 L
.03349 .20236 L
.02983 .21351 L
.02832 .2194 L
.02704 .22564 L
.02615 .23131 L
.0255 .23739 L
.02517 .24314 L
.0251 .24837 L
.0253 .25451 L
.02556 .25797 L
.02588 .26116 L
.02668 .26702 L
.02784 .27321 L
.03041 .28324 L
.0341 .29393 L
.04318 .31294 L
.05792 .33484 L
.07501 .35402 L
.09617 .37284 L
.12236 .39156 L
.17805 .42134 L
.21695 .43685 L
.2564 .44943 L
.29353 .45893 L
.33604 .46745 L
.35671 .47078 L
Mistroke
.37917 .47385 L
.39881 .47607 L
.42036 .47804 L
.43308 .47898 L
.44488 .47971 L
.45597 .48026 L
.46187 .48051 L
.46823 .48073 L
.47921 .48103 L
.48952 .4812 L
.50132 .48126 L
.51214 .4812 L
.52176 .48105 L
.53202 .48079 L
.5417 .48045 L
.55047 .48006 L
.5719 .47878 L
.59201 .47715 L
.63154 .47269 L
.67333 .46604 L
.71344 .45756 L
.74936 .44798 L
.7897 .43456 L
.82392 .42044 L
.88463 .3865 L
.91208 .36519 L
.93378 .34351 L
.95024 .32179 L
.96146 .30142 L
.96613 .28989 L
.96814 .28378 L
.96992 .27731 L
.9712 .2716 L
.97229 .26534 L
.973 .25963 L
.97342 .2543 L
.9736 .24896 L
.97354 .24317 L
.97323 .2377 L
.97272 .23266 L
.97209 .22813 L
.9712 .22314 L
.96876 .2131 L
.96518 .2023 L
.96023 .19081 L
.9485 .17047 L
.93088 .14824 L
.91064 .12864 L
.88438 .10851 L
.85204 .08884 L
Mistroke
.81743 .07199 L
.78181 .05792 L
.70861 .03662 L
.67046 .02869 L
.62713 .02188 L
.60485 .0192 L
.58068 .0169 L
.5689 .01599 L
.55768 .01527 L
.54767 .01472 L
.53658 .01424 L
.52635 .01389 L
.51673 .01367 L
.50657 .01353 L
.4956 .01349 L
.48596 .01356 L
.47581 .01372 L
.46715 .01395 L
.45768 .01427 L
.44646 .01478 L
.43628 .01535 L
.41354 .017 L
.39264 .01899 L
.37309 .02128 L
.33366 .02723 L
.29167 .03569 L
.24979 .04663 L
.21279 .05879 L
.15304 .08492 L
.12367 .10189 L
.09976 .11871 L
.07799 .13752 L
.0587 .15873 L
.04435 .17965 L
.03473 .1992 L
.03043 .21143 L
.02759 .22277 L
.02652 .22873 L
.02605 .23216 L
.0257 .23529 L
.02541 .2386 L
.02521 .24214 L
.02511 .24543 L
.0251 .24854 L
.02529 .25419 L
.02577 .26017 L
.02641 .26528 L
.02737 .27089 L
.02869 .27689 L
.03044 .28333 L
Mistroke
.03448 .29488 L
.03934 .30571 L
.04561 .31709 L
.05968 .33705 L
.08088 .35967 L
.10412 .37896 L
.13221 .39767 L
.16664 .41607 L
.20234 .43143 L
.23834 .44402 L
.27662 .45486 L
.31321 .46316 L
.35536 .47058 L
.37941 .47388 L
.40198 .47639 L
.42399 .47833 L
.44758 .47985 L
.45984 .48043 L
.47138 .48083 L
.478 .481 L
.48407 .48112 L
.49074 .48121 L
.49777 .48126 L
.5087 .48123 L
.52038 .48108 L
.5314 .48081 L
.54141 .48046 L
.55315 .47993 L
.56585 .47919 L
.58881 .47744 L
.60935 .47541 L
.63123 .47274 L
.67002 .46664 L
.71455 .4573 L
.7534 .44678 L
.79142 .43392 L
.8298 .41771 L
.88984 .38283 L
.91528 .36233 L
.9353 .34175 L
.94985 .3224 L
.96177 .30073 L
.96638 .28921 L
.97014 .27643 L
.97152 .26995 L
.97213 .26638 L
.97261 .26299 L
.97298 .25983 L
.97328 .2564 L
.97358 .25039 L
Mistroke
.97359 .24479 L
.97348 .24161 L
.9733 .23862 L
.97272 .23261 L
.97226 .22924 L
.97176 .22615 L
.96937 .2153 L
.96779 .20987 L
.9658 .20397 L
.96103 .19249 L
.95463 .18023 L
.93976 .1586 L
.92141 .13848 L
.90127 .12091 L
.84496 .08509 L
.81162 .06949 L
.77162 .0544 L
.73198 .04247 L
.69233 .033 L
.65534 .02606 L
.61385 .02022 L
.58981 .0177 L
.56783 .01592 L
.55557 .01514 L
.54229 .01447 L
.53617 .01422 L
.52972 .014 L
.51815 .0137 L
.50745 .01354 L
.49599 .01349 L
.48518 .01357 L
.47534 .01373 L
.46379 .01405 L
.45728 .01429 L
.45128 .01455 L
.42862 .01584 L
.40724 .01755 L
.38782 .01952 L
.3448 .02536 L
.30794 .03213 L
.27057 .04086 L
.19714 .06477 L
.15997 .08138 L
.1288 .09867 L
.10179 .11716 L
.07675 .13874 L
.05738 .16041 L
.04344 .18125 L
.03415 .20066 L
.0303 .21186 L
Mistroke
.02766 .2224 L
.02662 .22813 L
.02588 .23358 L
.02542 .23848 L
.02515 .24381 L
.02512 .24961 L
.02521 .25253 L
.02539 .25576 L
.02591 .26146 L
.02665 .2668 L
.02764 .27222 L
.02897 .278 L
.03206 .28836 L
.03689 .30054 L
.04236 .31147 L
.05775 .33462 L
.0765 .35549 L
.11899 .38937 L
.14779 .40651 L
.17715 .42093 L
.20926 .43405 L
.24622 .44645 L
.27995 .45569 L
.31836 .46419 L
.34233 .46852 L
.36497 .47198 L
.38876 .47498 L
.41056 .47721 L
.43221 .47892 L
.45272 .48011 L
.46404 .48059 L
.47447 .48091 L
.48593 .48115 L
.4917 .48122 L
.49804 .48126 L
.50879 .48123 L
.51872 .48111 L
.52962 .48086 L
.54117 .48047 L
.55115 .48003 L
.5605 .47952 L
.58171 .47804 L
.60062 .47633 L
.61781 .47444 L
.65593 .46906 L
.69333 .46209 L
.73268 .45269 L
.80576 .42829 L
Mfstroke
.92298 .35415 m
.94021 .3347 L
.9531 .31588 L
.95898 .30501 L
.9636 .29461 L
.96778 .2825 L
.96921 .27722 L
.97052 .27139 L
.97152 .26568 L
.97221 .26032 L
.97268 .25466 L
.9729 .24857 L
.97282 .24293 L
.9725 .23757 L
.97202 .23276 L
.97127 .22753 L
.97008 .2213 L
.96872 .21567 L
.96472 .20315 L
.95984 .19169 L
.95422 .18105 L
.93907 .15904 L
.91849 .13689 L
.8974 .11907 L
.87075 .10083 L
.83826 .08287 L
.7995 .06573 L
.75992 .05178 L
.72088 .04075 L
.6811 .03184 L
.63719 .02434 L
.61549 .02145 L
.59181 .01888 L
.57814 .01767 L
.56555 .01671 L
.55356 .01595 L
.54071 .0153 L
.52944 .01486 L
.51918 .01456 L
.50886 .01437 L
.49911 .01429 L
.48773 .01431 L
.47725 .01443 L
.46575 .0147 L
.45995 .01488 L
.45359 .01512 L
.43085 .0163 L
.41814 .01719 L
.40658 .01815 L
.38378 .02044 L
Mistroke
.36335 .02298 L
.32295 .02943 L
.28142 .03825 L
.21179 .05904 L
.17623 .0734 L
.1412 .09097 L
.11192 .10924 L
.08803 .1277 L
.06715 .14796 L
.05157 .16736 L
.0383 .18977 L
.03287 .20239 L
.03086 .20813 L
.02896 .21448 L
.02755 .22017 L
.02634 .22631 L
.0258 .2297 L
.02539 .23281 L
.02481 .23893 L
.02456 .24421 L
.02455 .24999 L
.02483 .25601 L
.02535 .26161 L
.02576 .26482 L
.02631 .26829 L
.02755 .27457 L
.03074 .28624 L
.03587 .29973 L
.04194 .31196 L
.05536 .33255 L
.07377 .35372 L
.11686 .38885 L
.14886 .40798 L
.18276 .42429 L
.21556 .43723 L
.25432 .4497 L
.291 .45918 L
.33228 .46759 L
.35565 .4714 L
.37742 .47438 L
.39983 .47689 L
.4209 .47877 L
.43922 .48003 L
.44866 .48055 L
.45891 .48101 L
.47018 .48139 L
.48084 .48164 L
.49122 .48178 L
.50081 .48181 L
.5109 .48174 L
Mistroke
.52034 .48158 L
.53069 .48131 L
.54181 .48091 L
.5534 .48035 L
.56439 .47969 L
.58492 .47814 L
.60766 .47591 L
.62884 .47332 L
.66769 .46723 L
.70818 .45887 L
.74998 .44776 L
.78464 .43629 L
.81886 .42249 L
.87308 .39373 L
.89911 .37545 L
.9197 .35764 L
.93954 .33592 L
.95424 .31441 L
.95949 .30454 L
.96414 .29393 L
.96736 .28478 L
.9701 .27462 L
.97125 .26891 L
.97207 .26367 L
.9727 .25791 L
.97308 .25184 L
.97316 .24653 L
.97302 .2416 L
.97265 .2362 L
.97198 .23044 L
.97104 .22475 L
.96971 .21851 L
.96603 .206 L
.96146 .19454 L
.95618 .18396 L
.94082 .16076 L
.91917 .13706 L
.89423 .11621 L
.86672 .09789 L
.80611 .06786 L
.77018 .05456 L
.73559 .04407 L
.69644 .03448 L
.65235 .02614 L
.63188 .02306 L
.61 .02029 L
.58952 .01816 L
.57029 .01656 L
.55212 .01539 L
.54276 .01492 L
Mistroke
.53259 .01451 L
.52142 .01417 L
.51085 .01396 L
.50056 .01386 L
.49105 .01387 L
.47994 .01398 L
.46939 .0142 L
.45993 .01449 L
.44962 .01491 L
.42663 .01623 L
.40543 .01793 L
.36737 .02218 L
.32772 .02836 L
.28214 .03794 L
.24127 .04913 L
.2069 .06083 L
.17175 .07549 L
.11362 .10823 L
.08733 .12853 L
.06665 .1488 L
.05086 .16874 L
.03962 .1876 L
.03474 .19824 L
.03051 .20995 L
.02896 .21535 L
.02757 .22111 L
.02653 .22648 L
.02577 .2315 L
.0252 .23679 L
.02483 .24259 L
.02474 .24824 L
.02494 .25428 L
.02538 .25991 L
.02604 .26521 L
.02683 .26997 L
.0279 .27511 L
.03118 .28686 L
.03589 .29918 L
.04748 .3208 L
.06175 .34018 L
.07807 .35756 L
.12513 .39384 L
.15457 .41058 L
.19011 .42701 L
.22411 .43982 L
.26272 .45165 L
.30305 .46147 L
.34107 .46871 L
.38041 .47437 L
.39859 .4764 L
Mistroke
.41823 .4782 L
.43958 .47971 L
.44916 .48024 L
.4596 .48071 L
.46597 .48094 L
.47187 .48112 L
.4835 .48137 L
.49407 .48149 L
.5053 .48149 L
.5162 .48138 L
.52793 .48112 L
.539 .48075 L
.54911 .48031 L
.57252 .4789 L
.59695 .47682 L
.63665 .47206 L
.67269 .46618 L
.711 .45812 L
.75013 .44768 L
.82353 .42044 L
.85975 .40189 L
.88929 .38295 L
.91364 .36347 L
.93289 .34413 L
.94915 .32297 L
.95661 .31053 L
.96232 .29881 L
.96656 .28781 L
.96996 .276 L
.97126 .26986 L
.97219 .26407 L
.9726 .26076 L
.9729 .25771 L
.97314 .25437 L
.97329 .25084 L
.97332 .24536 L
.97308 .2395 L
.9726 .23398 L
.97194 .22897 L
.9709 .22309 L
.96945 .21673 L
.96596 .20526 L
.96195 .19518 L
.95655 .18423 L
.94252 .16263 L
.92595 .14345 L
.90745 .12633 L
.88272 .10777 L
.85188 .08913 L
.82163 .07421 L
Mistroke
.78655 .05998 L
.74928 .04768 L
.71359 .03812 L
.67899 .0306 L
.63975 .02391 L
.59762 .01869 L
.57425 .01661 L
.56298 .01581 L
.55226 .01517 L
.54236 .01467 L
.53157 .01425 L
.52175 .01396 L
.51265 .01377 L
.50283 .01367 L
.492 .01366 L
.48069 .01378 L
.47008 .014 L
.45925 .01434 L
.44742 .01485 L
.42368 .01629 L
.40186 .01812 L
.38173 .02027 L
.33705 .02665 L
.29097 .03581 L
.24898 .0468 L
.21244 .05881 L
.17583 .07368 L
.13928 .09226 L
.08785 .12824 L
.0657 .15006 L
.04913 .17157 L
.03681 .19379 L
.03174 .20664 L
.0298 .21282 L
.02827 .21867 L
.02708 .22426 L
.02608 .23032 L
.02543 .23584 L
.02506 .24091 L
.02489 .24643 L
.02499 .25247 L
.02516 .25551 L
.02542 .25877 L
.02611 .26464 L
.02706 .2704 L
.02819 .27571 L
.03159 .28765 L
.03557 .29807 L
.04077 .30898 L
.05215 .32747 L
Mistroke
.06806 .34711 L
.08991 .368 L
.11441 .38658 L
.16932 .41761 L
.20443 .43249 L
.23953 .44463 L
.2801 .45596 L
.32633 .46591 L
.34882 .46976 L
.37299 .47324 L
.39568 .47591 L
.4171 .47793 L
.43731 .4794 L
.44773 .48 L
.4591 .48053 L
.46557 .48077 L
.47156 .48096 L
.47718 .4811 L
.48339 .48122 L
.49414 .48135 L
.50558 .48135 L
.51605 .48125 L
.52707 .48102 L
.53646 .48073 L
.54673 .48031 L
.5696 .479 L
.59075 .47731 L
.62865 .47309 L
.66825 .46695 L
.71197 .45787 L
.75049 .44758 L
.78959 .43451 L
.82932 .41781 L
.88698 .38469 L
.91298 .36419 L
.93339 .34372 L
.94966 .32238 L
.9566 .31078 L
.96271 .2982 L
.96729 .28596 L
.97036 .27476 L
.97147 .26933 L
.97239 .26344 L
.973 .25787 L
.97334 .25275 L
.97345 .24776 L
.97335 .24242 L
.97304 .23738 L
.97258 .23279 L
.97181 .22742 L
Mistroke
.97071 .2216 L
.96799 .21107 L
.96417 .20015 L
.95902 .1887 L
.94701 .1686 L
.93033 .14788 L
.91173 .12981 L
.88834 .11148 L
.85905 .09294 L
.80171 .06561 L
.76679 .05298 L
.73236 .04274 L
.69188 .03306 L
.64613 .02473 L
.6246 .02167 L
.60154 .01896 L
.5814 .01706 L
.57024 .01619 L
.55962 .01548 L
.54947 .0149 L
.53838 .01439 L
.52828 .01403 L
.51892 .01379 L
.5092 .01363 L
.50041 .01356 L
.49026 .01358 L
.48072 .01369 L
.47012 .01391 L
.45896 .01427 L
.44945 .01467 L
.43905 .01522 L
.41593 .01682 L
.39456 .0188 L
.35115 .02435 L
.30546 .03261 L
.26411 .04253 L
.22783 .05347 L
.16525 .07868 L
.13723 .09351 L
.10947 .11135 L
.08445 .13134 L
.06446 .15159 L
.04985 .17064 L
.03765 .19217 L
.03251 .20467 L
.029 .21612 L
.02752 .22251 L
.02687 .22588 L
.02629 .22944 L
.02587 .23257 L
Mistroke
.0255 .236 L
.02509 .24205 L
.02498 .24816 L
.02514 .25373 L
.02534 .25681 L
.02564 .26015 L
.02643 .26623 L
.02745 .27189 L
.02881 .27788 L
.032 .28858 L
.03624 .29939 L
.04176 .31063 L
.05427 .33025 L
.07141 .35053 L
.09433 .37152 L
.11754 .38856 L
.1455 .40542 L
.20326 .43192 L
.2422 .44534 L
.28035 .4559 L
.32431 .46543 L
.34744 .46944 L
.37272 .47311 L
.39518 .47577 L
.41592 .47775 L
.43692 .4793 L
.45697 .48036 L
.46827 .48079 L
.47459 .48097 L
.48032 .4811 L
.4915 .48126 L
.50202 .4813 L
.50801 .48128 L
.51433 .48121 L
.52564 .481 L
.53194 .48082 L
.5378 .48062 L
.5511 .48005 L
.56234 .47943 L
.57422 .47863 L
.59543 .47684 L
.61805 .4744 L
.64267 .47111 L
.68567 .46363 L
.7245 .45479 L
.79187 .43368 L
.82626 .41929 L
.8552 .4046 L
.88225 .38802 L
.90766 .36888 L
Mistroke
.92654 .35127 L
.94357 .33124 L
.95218 .31854 L
.95886 .30662 L
.96399 .29528 L
.96838 .28267 L
.96986 .27718 L
.97118 .27126 L
.97215 .26566 L
.97281 .26053 L
.9733 .25475 L
.97345 .25148 L
.97352 .24845 L
.97344 .2429 L
.97308 .237 L
.97252 .23174 L
.97164 .226 L
.97044 .22002 L
.96905 .21447 L
.96592 .20459 L
.96168 .19412 L
.94856 .17073 L
.93261 .15028 L
.91432 .132 L
.89102 .11329 L
.84027 .08281 L
.80823 .06817 L
.77589 .05594 L
.73483 .04333 L
.69518 .03368 L
.65193 .02557 L
.60954 .01977 L
.58592 .01739 L
.56381 .01569 L
.55101 .01493 L
.53938 .01438 L
.53292 .01413 L
.52592 .01391 L
.51931 .01375 L
.51323 .01364 L
.50195 .01352 L
.49126 .01353 L
.48167 .01363 L
.47125 .01385 L
.45994 .0142 L
.44794 .01471 L
.42649 .016 L
.40685 .01758 L
.38856 .01943 L
.34752 .02491 L
Mistroke
.30419 .03289 L
.26603 .04202 L
.22653 .05393 L
.18718 .06881 L
.15364 .08454 L
.126 .10034 L
.08066 .13489 L
.06075 .15607 L
.05196 .16765 L
.04397 .18018 L
.03811 .19134 L
.03289 .20378 L
.03102 .20928 L
.02929 .21521 L
.02794 .22076 L
.02691 .22599 L
.02642 .22897 L
.02597 .2322 L
.0254 .23783 L
.02519 .24103 L
.02506 .24441 L
.02507 .25046 L
.02534 .25606 L
.02582 .26128 L
.02661 .26699 L
.02775 .27309 L
.02933 .27965 L
.03144 .28675 L
.03636 .29952 L
.04245 .31177 L
.0492 .32289 L
.06436 .34273 L
.08503 .36355 L
.11063 .38376 L
.13863 .40151 L
.16858 .41707 L
.2044 .43229 L
.27391 .45422 L
.31626 .46382 L
.34027 .46822 L
.36331 .47178 L
.38514 .4746 L
.40904 .4771 L
.43097 .47887 L
.45128 .48006 L
.46248 .48055 L
.47313 .4809 L
.48269 .48111 L
.49311 .48124 L
.50442 .48127 L
Mistroke
.51014 .48123 L
.51645 .48116 L
.52758 .48092 L
.53802 .4806 L
.5479 .48019 L
.55829 .47965 L
.57679 .47842 L
.59657 .47672 L
.61804 .4744 L
.66227 .46799 L
.70791 .45884 L
.74899 .44806 L
.7843 .4365 L
.81805 .42302 L
.85092 .40699 L
.90135 .37409 L
.92413 .35379 L
.94175 .33371 L
.95677 .3107 L
.96315 .29743 L
.96767 .28514 L
.96939 .2792 L
.97073 .2736 L
.97173 .26849 L
.97255 .26308 L
.97317 .25717 L
.97349 .25172 L
.97355 .24586 L
.97347 .24254 L
.97331 .23944 L
.97282 .23393 L
.97213 .22872 L
.97132 .22405 L
.97024 .21899 L
.96705 .20772 L
.96316 .19739 L
.95207 .17608 L
.93542 .15344 L
.91328 .13101 L
.88836 .11134 L
.83076 .07811 L
.79739 .06377 L
.75801 .05004 L
.72212 .03994 L
.68201 .03092 L
.64274 .02411 L
.60616 .01937 L
.58592 .01736 L
.56348 .01564 L
.55213 .01497 L
Mistroke
.53991 .01438 L
.52835 .01396 L
.51778 .0137 L
.50729 .01354 L
.49758 .0135 L
.48691 .01355 L
.47558 .01373 L
.46579 .01399 L
.4566 .01432 L
.4357 .01538 L
.42497 .0161 L
.41327 .01701 L
.38984 .01928 L
.3486 .02474 L
.30195 .03338 L
.26037 .04358 L
.2223 .05539 L
.18377 .07029 L
.15254 .08514 L
.12259 .10254 L
.09864 .11954 L
.07585 .13957 L
.05857 .15882 L
.04553 .1776 L
.03962 .18831 L
.03441 .19989 L
.03192 .20662 L
.03 .21276 L
.02837 .21902 L
.02715 .2248 L
.02625 .23031 L
.02558 .23613 L
.02518 .24199 L
.02508 .24531 L
.02506 .24842 L
.02524 .25404 L
.02563 .25916 L
.02634 .26506 L
.02729 .27064 L
.02971 .28094 L
.03325 .29179 L
.04205 .31098 L
.05496 .33103 L
.0732 .35224 L
.09473 .37173 L
.12123 .39088 L
.17744 .4211 L
.21312 .4355 L
.2487 .44722 L
.29003 .45814 L
Mistroke
.33637 .46753 L
.35831 .47104 L
.38189 .47419 L
.40251 .47646 L
.42487 .47841 L
.43749 .47928 L
.44905 .47994 L
.46071 .48047 L
.4718 .48085 L
.47803 .48101 L
.48468 .48113 L
.49095 .48121 L
.49663 .48125 L
.50334 .48126 L
.51059 .48122 L
.51743 .48113 L
.52371 .48101 L
.53414 .48072 L
.54528 .4803 L
.56531 .47922 L
.58899 .47742 L
.61036 .47529 L
.65602 .46903 L
.69786 .4611 L
.73467 .45213 L
.77325 .44039 L
.80847 .42714 L
.84341 .41097 L
.87287 .39421 L
.89693 .37755 L
.91856 .35925 L
.93528 .34174 L
.95056 .32124 L
.95693 .31045 L
.96269 .29858 L
.96695 .28743 L
.96996 .27706 L
.97111 .27192 L
.97199 .2671 L
.9727 .26206 L
.97324 .25652 L
.97355 .25055 L
.97359 .24717 L
.97354 .24405 L
.97325 .23832 L
.97265 .23224 L
.97185 .22683 L
.97088 .22175 L
.96788 .21025 L
.96344 .19801 L
Mistroke
.95827 .18692 L
.94282 .16259 L
.9257 .1428 L
.90355 .12276 L
.85438 .09015 L
.81903 .07272 L
.78243 .05816 L
.7475 .04684 L
.70688 .03623 L
.66563 .02784 L
.62572 .0217 L
.60327 .01904 L
.58254 .01706 L
.57103 .01615 L
.55842 .01531 L
.54655 .01467 L
.53536 .01419 L
.52495 .01386 L
.51369 .01362 L
.50345 .01351 L
.49403 .0135 L
.4838 .01358 L
.4726 .01379 L
.46091 .01415 L
.45003 .0146 L
.43014 .01573 L
.41212 .01711 L
.3721 .0214 L
.35247 .02415 L
.33111 .02766 L
.28905 .03628 L
.21848 .05673 L
.1823 .07094 L
.14668 .0883 L
.11681 .10637 L
.0924 .1246 L
.07077 .14479 L
.05458 .16409 L
.04061 .1864 L
.0348 .19897 L
.03055 .21098 L
.02756 .22279 L
.0265 .22877 L
.02602 .23222 L
.02567 .23537 L
.02524 .241 L
.02508 .24704 L
.02519 .25265 L
.02554 .25796 L
.02622 .26409 L
Mistroke
.02674 .26751 L
.0273 .2706 L
.0301 .28223 L
.03216 .28872 L
.03478 .29568 L
.04056 .30815 L
.05407 .3298 L
.07027 .34918 L
.09187 .36936 L
.11914 .38949 L
.15205 .4088 L
.18682 .42516 L
.22047 .4381 L
.2601 .45048 L
.29715 .45976 L
.33869 .46791 L
.36222 .47159 L
.38406 .47444 L
.40653 .47684 L
.42758 .4786 L
.44694 .47982 L
.4578 .48034 L
.46768 .48071 L
.47855 .48101 L
.49033 .4812 L
.50146 .48126 L
.5117 .4812 L
.52132 .48106 L
.53029 .48084 L
.54012 .48051 L
.55064 .48005 L
.57204 .47877 L
.59143 .4772 L
.63318 .47246 L
.65389 .46939 L
.6764 .46546 L
.74985 .44783 L
.78806 .43516 L
.82625 .41936 L
.85881 .40264 L
.88597 .38555 L
.91061 .36646 L
.92973 .348 L
.9471 .32645 L
.95493 .31407 L
.96096 .30245 L
.96573 .29098 L
.96956 .27869 L
.97105 .27228 L
.97214 .26626 L
Mistroke
.97262 .26287 L
.97298 .25964 L
.9733 .25592 L
.97349 .25252 L
.9736 .24679 L
.97342 .24069 L
.97297 .23494 L
.97232 .22974 L
.97128 .22362 L
.9698 .21703 L
.96621 .20516 L
.96188 .19438 L
.95617 .18298 L
.9431 .16293 L
.92307 .14013 L
.9008 .12056 L
.87377 .10156 L
.84031 .08273 L
.80544 .06694 L
.77001 .05387 L
.73261 .04265 L
.69663 .03393 L
.65509 .02603 L
.63131 .02244 L
.60888 .01965 L
.58646 .01739 L
.56593 .01579 L
.55493 .01511 L
.54298 .0145 L
.5364 .01423 L
.53033 .01401 L
.52457 .01385 L
.51838 .0137 L
.50687 .01353 L
.4961 .01349 L
.48953 .01352 L
.48331 .01359 L
.47163 .01382 L
.46569 .01399 L
.45937 .01421 L
.44803 .0147 L
.43587 .01537 L
.42247 .01628 L
.40189 .01804 L
.37956 .02047 L
.33539 .02692 L
.29579 .03474 L
.26033 .04361 L
.18662 .06909 L
.15006 .08649 L
Mistroke
.12023 .1041 L
.09542 .12213 L
.0729 .14259 L
.05692 .16099 L
.04295 .18208 L
.03684 .19421 L
.03236 .20545 L
.03034 .2117 L
.02851 .21856 L
.02713 .22506 L
.02617 .23111 L
.02551 .23722 L
.02517 .24298 L
.02509 .24815 L
.02525 .25374 L
.02572 .25984 L
.02608 .26291 L
.02656 .26628 L
.02763 .27222 L
.02889 .27775 L
.03251 .28967 L
.03689 .30058 L
.05049 .3247 L
.06655 .34512 L
.08761 .36573 L
.13308 .3982 L
.1636 .41461 L
.19497 .42852 L
.26774 .45255 L
.3074 .46197 L
.35259 .47016 L
.39252 .47541 L
.41523 .47762 L
.43603 .47918 L
.45556 .48024 L
.46661 .48068 L
.47682 .48097 L
.48576 .48114 L
.49559 .48124 L
.50587 .48125 L
.51547 .48116 L
.52665 .48094 L
.53289 .48076 L
.53853 .48057 L
.55983 .47956 L
.57174 .47879 L
.58455 .4778 L
.6076 .47559 L
.65193 .4697 L
.69147 .46247 L
Mistroke
.72618 .45439 L
.76255 .44392 L
.82944 .41788 L
.862 .40081 L
.88949 .38308 L
.91144 .36574 L
.93135 .34623 L
.94883 .32392 L
.96095 .3025 L
.96597 .29034 L
.96953 .27883 L
.97107 .2722 L
.97217 .2661 L
.97264 .26274 L
.97305 .25906 L
.97333 .25558 L
.97351 .25234 L
.9736 .24637 L
.97354 .24337 L
.97339 .24007 L
.9729 .23423 L
.97219 .22879 L
.97104 .22239 L
.96969 .21657 L
.96564 .20357 L
.96104 .19251 L
.95485 .18064 L
.94056 .15963 L
.92312 .14017 L
.90087 .1206 L
.85203 .08884 L
.82104 .07359 L
.79022 .061 L
.7548 .04901 L
.71368 .03782 L
.67862 .03023 L
.6399 .02366 L
.61803 .02072 L
.59792 .01848 L
.57743 .01663 L
.55812 .01529 L
.54744 .01471 L
.53765 .01428 L
.52676 .0139 L
.51503 .01364 L
.5038 .01351 L
.49745 .01349 L
.49155 .01351 L
.48075 .01363 L
.46925 .01388 L
Mistroke
.45861 .01424 L
.44713 .01474 L
.42639 .016 L
.40634 .01763 L
.38804 .01949 L
.34655 .02508 L
.30244 .03329 L
.25839 .04415 L
.21957 .05636 L
.18428 .0701 L
.1491 .087 L
.12117 .1035 L
.09497 .12251 L
.07468 .14078 L
.05613 .16204 L
.0429 .1822 L
.03375 .20166 L
.03002 .21283 L
.02748 .22329 L
.02643 .22933 L
.02574 .23482 L
.02546 .23787 L
.02525 .24118 L
.02509 .24717 L
.02522 .25298 L
.02542 .25627 L
.02568 .25935 L
.02604 .2626 L
.02645 .26555 L
.02763 .27219 L
.02892 .27782 L
.03061 .28392 L
.0345 .29494 L
.04481 .31577 L
.05979 .3372 L
.07756 .35652 L
.09653 .37313 L
.12177 .39119 L
.15189 .4087 L
.21375 .4357 L
.25203 .44817 L
.28974 .45805 L
.33301 .46692 L
.35612 .47069 L
.38103 .47407 L
.40302 .4765 L
.4275 .47859 L
.43828 .47932 L
.44992 .47997 L
.46085 .48047 L
Mistroke
.47102 .48082 L
.47715 .48098 L
.48368 .48111 L
.49094 .48121 L
.49752 .48125 L
.50375 .48126 L
.51049 .48122 L
.51686 .48114 L
.52271 .48103 L
.53366 .48074 L
.53987 .48052 L
.54566 .48028 L
.55724 .4797 L
.5698 .47893 L
.59279 .47708 L
.61438 .47484 L
.65418 .46934 L
.69921 .46082 L
.73911 .45093 L
.77417 .4401 L
.80967 .42667 L
.86674 .39801 L
.89499 .37906 L
.92046 .35748 L
.9385 .33791 L
.95411 .31552 L
.96016 .30419 L
.96547 .29172 L
.96746 .28595 L
.96927 .27982 L
.97058 .27449 L
.97173 .26876 L
.97258 .26319 L
.97314 .2581 L
.97348 .25297 L
.97361 .2481 L
.97351 .24246 L
.97319 .23722 L
.97257 .23149 L
.97162 .2254 L
.97026 .21885 L
.96869 .21286 L
.96405 .19944 L
.95873 .18777 L
.95187 .17566 L
.937 .15523 L
.91654 .13389 L
.89171 .11368 L
.86461 .09596 L
.80542 .06692 L
Mistroke
.7681 .05323 L
.73136 .04231 L
.68892 .03229 L
.64191 .02396 L
.62139 .02114 L
.59955 .01864 L
.5805 .01688 L
.56003 .01541 L
.54838 .01476 L
.53778 .01428 L
.52711 .01392 L
.51703 .01367 L
.50525 .01352 L
.4944 .01349 L
.48872 .01353 L
.48248 .0136 L
.47597 .01372 L
.4699 .01387 L
.45979 .01419 L
.44881 .01466 L
.42891 .01582 L
.40964 .01733 L
.39192 .01906 L
.35235 .02418 L
.31141 .03142 L
.27201 .04049 L
.23748 .0504 L
.20235 .06272 L
.16668 .0781 L
.11415 .1082 L
.09004 .12661 L
.07076 .14483 L
.05307 .1662 L
.04543 .17783 L
.03863 .19039 L
.03381 .20152 L
.03167 .20748 L
.02971 .21392 L
.02822 .21984 L
.0271 .22528 L
.02623 .23076 L
.02563 .23597 L
.02524 .24141 L
.0251 .24635 L
.02518 .25204 L
.02551 .2574 L
.02602 .26237 L
.02667 .26694 L
.02758 .27193 L
.02876 .2772 L
Mistroke
.03199 .28816 L
.03589 .29829 L
.04795 .32085 L
.06408 .34231 L
.08616 .36445 L
.10933 .38275 L
.13747 .40077 L
.16564 .4156 L
.19958 .43035 L
.26574 .45201 L
.30511 .46148 L
.34828 .46948 L
.38625 .4747 L
.40811 .47698 L
.42862 .47867 L
.44017 .47943 L
.45272 .48011 L
.4646 .48061 L
.47557 .48094 L
.48548 .48114 L
.49639 .48125 L
.50778 .48124 L
.51843 .48111 L
.52438 .48099 L
.53086 .48082 L
.54263 .48041 L
.55407 .47988 L
.56465 .47927 L
.58848 .47747 L
.61361 .47493 L
.65973 .46843 L
.70071 .46049 L
.74377 .44961 L
.78647 .43575 L
.85069 .40716 L
.88207 .38824 L
.90761 .36903 L
.92904 .34876 L
.94777 .3255 L
.95471 .31448 L
.96091 .3026 L
.96529 .29219 L
.96898 .28088 L
.97041 .27525 L
.97153 .26988 L
.97233 .26505 L
.97298 .25976 L
.97339 .25478 L
.9736 .24946 L
.97358 .24444 L
Mistroke
.97338 .23988 L
.97289 .23406 L
.97218 .22871 L
.97114 .22285 L
.96973 .21668 L
.96664 .20637 L
.96224 .19515 L
.94946 .17192 L
.93315 .15075 L
.91516 .13263 L
.89219 .11402 L
.86347 .09529 L
.82901 .07723 L
.79342 .0622 L
.75829 .05008 L
.72375 .04032 L
.68421 .03133 L
.64293 .02411 L
.61963 .02092 L
.59819 .01851 L
.57893 .01675 L
.5579 .01528 L
.54629 .01465 L
.53556 .0142 L
.52528 .01386 L
.51438 .01363 L
.50506 .01352 L
.49503 .01349 L
.48557 .01356 L
.47693 .0137 L
.46683 .01395 L
.45584 .01435 L
.44547 .01483 L
.43587 .01537 L
.41247 .01709 L
.39113 .01915 L
.34384 .02551 L
.30345 .03307 L
.26252 .04301 L
.19678 .06491 L
.16309 .07984 L
.1344 .09529 L
.10696 .1133 L
.08122 .13446 L
.06109 .15576 L
.0463 .17639 L
.03626 .19556 L
.03195 .20666 L
.02885 .21717 L
.02763 .22258 L
Mistroke
.02659 .22828 L
.02593 .23316 L
.02542 .2385 L
.02513 .24428 L
.0251 .24752 L
.02513 .25045 L
.02541 .25617 L
.02592 .26155 L
.02667 .26691 L
.02773 .27265 L
.03033 .28297 L
.03458 .29512 L
.03952 .30608 L
.05373 .3293 L
.07146 .35039 L
.11212 .38471 L
.14001 .40222 L
.1687 .41705 L
.19983 .43045 L
.23592 .44325 L
.26896 .45287 L
.30681 .46184 L
.35044 .46982 L
.37322 .47309 L
.39791 .47598 L
.42135 .47812 L
.44283 .47959 L
.45323 .48014 L
.46454 .48061 L
.47524 .48093 L
.48513 .48114 L
.49627 .48125 L
.50686 .48124 L
.51636 .48115 L
.52673 .48094 L
.53794 .48059 L
.54987 .48009 L
.57125 .47883 L
.59279 .47708 L
.61292 .47501 L
.64996 .47002 L
.6931 .46213 L
.73123 .45307 L
.77073 .44126 L
.81024 .42643 L
.84359 .41091 L
.87122 .39527 L
.91674 .36099 L
.93677 .34001 L
.94567 .32851 L
Mistroke
.95381 .31602 L
.9598 .30494 L
.96517 .29253 L
.96892 .28111 L
.97145 .27031 L
.97236 .26485 L
.97306 .25902 L
.97346 .2535 L
.97361 .24849 L
.97352 .24259 L
.97334 .23927 L
.9731 .2362 L
.97246 .23058 L
.97149 .22464 L
.97029 .21897 L
.9687 .21291 L
.96507 .20203 L
.95947 .18925 L
.95316 .17775 L
.93937 .15812 L
.92054 .13764 L
.87678 .10346 L
.84562 .08543 L
.81311 .07012 L
.74524 .04616 L
.70373 .03549 L
.66389 .02751 L
.61865 .02079 L
.59542 .01823 L
.5697 .01605 L
.54736 .01471 L
.5347 .01416 L
.52298 .0138 L
.51274 .0136 L
.50144 .0135 L
.48963 .01352 L
.47857 .01367 L
.46838 .01391 L
.45769 .01427 L
.44857 .01467 L
.43864 .01521 L
.41651 .01675 L
.3961 .01863 L
.35029 .0245 L
.30993 .03172 L
.26522 .04228 L
.22535 .05438 L
.15846 .08214 L
.12898 .09856 L
.10033 .11828 L
Mistroke
.0792 .13637 L
.06017 .15689 L
.04585 .17714 L
.03598 .1962 L
.03198 .20659 L
.02861 .21817 L
.02734 .22402 L
.02679 .2271 L
.02629 .23034 L
.0256 .23633 L
.02522 .24183 L
.0251 .24692 L
.0252 .25237 L
.02552 .25751 L
.026 .26217 L
.02679 .26764 L
.02792 .27357 L
.03073 .28426 L
.03478 .29563 L
.04049 .30798 L
.05593 .33227 L
.07473 .35374 L
.09605 .37274 L
.12161 .39108 L
.15329 .40942 L
.18422 .42404 L
.21996 .43791 L
.25782 .44983 L
.29397 .45903 L
.32893 .46618 L
.36849 .47246 L
.38887 .475 L
.41093 .47724 L
.43443 .47907 L
.44499 .47971 L
.4565 .48028 L
.46797 .48072 L
.4786 .48101 L
.48876 .48119 L
.49956 .48126 L
.5092 .48123 L
.51824 .48112 L
.52815 .4809 L
.53881 .48056 L
.55048 .48006 L
.56129 .47947 L
.58572 .47771 L
.6093 .47541 L
.63419 .47233 L
.67834 .4651 L
Mistroke
.717 .4567 L
.76121 .44436 L
.80576 .42829 L
Mfstroke
.92212 .35385 m
.93931 .33457 L
.95219 .3159 L
.95808 .30513 L
.96272 .29481 L
.96692 .28278 L
.96837 .27754 L
.96969 .27175 L
.97071 .26608 L
.97142 .26076 L
.97191 .25514 L
.97215 .24908 L
.9721 .24347 L
.97181 .23814 L
.97135 .23337 L
.97062 .22816 L
.96947 .22196 L
.96814 .21636 L
.96421 .20389 L
.9594 .19247 L
.95386 .18186 L
.93888 .15989 L
.91848 .13775 L
.89753 .11991 L
.87103 .1016 L
.8387 .08355 L
.80008 .06628 L
.7606 .05218 L
.72163 .04101 L
.68188 .03195 L
.63797 .02429 L
.61626 .02133 L
.59256 .01868 L
.57888 .01742 L
.56628 .01643 L
.55427 .01563 L
.5414 .01494 L
.53011 .01447 L
.51984 .01415 L
.5095 .01393 L
.49973 .01382 L
.48833 .01381 L
.47782 .01391 L
.46629 .01415 L
.46049 .01432 L
.45411 .01455 L
.43131 .01569 L
.41857 .01656 L
.40697 .0175 L
.38411 .01976 L
Mistroke
.36362 .02228 L
.32309 .02871 L
.28141 .03752 L
.21154 .05839 L
.17586 .07283 L
.14072 .0905 L
.11135 .10888 L
.08741 .12747 L
.06649 .14785 L
.05091 .16737 L
.03766 .18991 L
.03224 .2026 L
.03024 .20837 L
.02836 .21476 L
.02696 .22047 L
.02576 .22664 L
.02523 .23005 L
.02483 .23318 L
.02427 .23932 L
.02404 .24462 L
.02405 .25042 L
.02435 .25647 L
.02489 .26209 L
.02532 .26531 L
.02588 .26879 L
.02715 .27509 L
.03039 .2868 L
.03559 .30031 L
.04171 .31257 L
.05524 .33318 L
.07377 .35435 L
.11707 .38941 L
.14919 .40847 L
.18318 .4247 L
.21605 .43755 L
.25486 .44991 L
.29156 .45929 L
.33286 .46759 L
.35622 .47134 L
.37799 .47426 L
.40038 .47672 L
.42143 .47855 L
.43974 .47978 L
.44916 .48027 L
.4594 .48071 L
.47065 .48108 L
.4813 .4813 L
.49167 .48142 L
.50124 .48143 L
.51131 .48135 L
Mistroke
.52074 .48118 L
.53107 .48089 L
.54217 .48047 L
.55374 .4799 L
.5647 .47923 L
.58519 .47766 L
.60788 .4754 L
.62902 .4728 L
.66777 .4667 L
.70816 .45834 L
.74986 .44726 L
.78443 .43583 L
.81857 .42208 L
.87267 .39345 L
.89865 .37526 L
.91923 .35754 L
.93906 .33592 L
.95376 .31451 L
.95902 .30467 L
.96369 .2941 L
.96696 .28488 L
.96968 .27486 L
.97083 .26925 L
.97165 .26409 L
.97224 .25915 L
.97263 .25394 L
.97281 .24821 L
.97273 .24288 L
.97237 .23704 L
.97204 .23378 L
.97167 .23082 L
.97079 .22532 L
.96974 .2202 L
.96654 .20861 L
.96234 .19742 L
.95667 .18557 L
.94338 .16464 L
.92794 .14626 L
.90622 .12595 L
.87819 .10533 L
.8167 .07246 L
.77953 .05783 L
.74204 .04588 L
.70612 .0366 L
.66663 .02847 L
.64547 .02491 L
.62193 .02157 L
.59999 .019 L
.57983 .01709 L
.55577 .01536 L
Mistroke
.54248 .01465 L
.53636 .01439 L
.52987 .01415 L
.51819 .01382 L
.5074 .01363 L
.49577 .01356 L
.48916 .01357 L
.48297 .01363 L
.47187 .01382 L
.46566 .01399 L
.46004 .01417 L
.43882 .01513 L
.42697 .01586 L
.41419 .01682 L
.39116 .01897 L
.3469 .02475 L
.30734 .0319 L
.27266 .0399 L
.23624 .05031 L
.16916 .07632 L
.13662 .09332 L
.10909 .11103 L
.08709 .12836 L
.06708 .14791 L
.04953 .17025 L
.03732 .19175 L
.03227 .20394 L
.02867 .21551 L
.0271 .22217 L
.02599 .2283 L
.02549 .23179 L
.02512 .23504 L
.02483 .23844 L
.02461 .24215 L
.0245 .24811 L
.02456 .25112 L
.0247 .25443 L
.02518 .26026 L
.02588 .26572 L
.02701 .27212 L
.02834 .27796 L
.03236 .291 L
.03693 .30208 L
.04309 .31399 L
.05735 .33509 L
.07474 .35459 L
.09698 .37423 L
.14587 .4061 L
.18017 .42284 L
.21455 .43649 L
Mistroke
.25423 .44925 L
.30047 .46084 L
.34268 .46887 L
.38329 .47457 L
.40613 .47698 L
.42712 .47871 L
.43879 .47948 L
.45152 .48016 L
.46356 .48065 L
.47472 .48098 L
.48526 .48118 L
.49636 .48128 L
.50583 .48126 L
.51618 .48114 L
.52737 .48089 L
.53362 .4807 L
.53929 .4805 L
.5607 .47942 L
.58044 .47802 L
.60167 .47607 L
.63964 .47135 L
.68352 .46382 L
.72806 .45357 L
.76762 .44191 L
.80156 .42956 L
.86222 .40019 L
.89079 .38161 L
.91433 .36259 L
.93163 .34527 L
.94688 .32602 L
.95349 .3157 L
.95971 .30411 L
.96437 .29338 L
.96784 .28328 L
.97056 .27253 L
.97162 .26682 L
.97245 .26069 L
.97275 .2576 L
.97298 .25425 L
.97318 .24816 L
.97307 .24222 L
.97271 .23675 L
.97216 .23165 L
.97144 .22689 L
.97044 .22167 L
.96912 .21608 L
.96561 .20474 L
.96147 .19449 L
.94893 .1719 L
.93032 .14826 L
Mistroke
.90824 .12715 L
.88406 .1088 L
.85546 .09117 L
.82085 .0739 L
.7875 .06034 L
.74972 .04779 L
.71362 .03807 L
.67221 .02922 L
.63321 .02286 L
.59592 .01839 L
.57307 .01638 L
.55178 .01498 L
.54062 .01444 L
.52828 .01397 L
.52207 .0138 L
.51538 .01365 L
.50905 .01355 L
.50325 .0135 L
.49259 .01348 L
.48267 .01356 L
.4718 .01377 L
.4602 .01412 L
.44802 .01462 L
.43655 .01524 L
.41519 .01674 L
.39544 .01856 L
.37473 .02091 L
.33821 .02625 L
.30001 .03358 L
.25967 .04353 L
.22027 .05582 L
.18531 .06933 L
.1273 .09921 L
.09981 .11826 L
.07783 .13723 L
.05783 .1593 L
.04925 .17117 L
.04156 .18396 L
.03592 .19553 L
.03104 .20838 L
.02934 .21407 L
.02781 .22019 L
.02666 .22593 L
.02584 .23126 L
.02545 .2345 L
.02514 .23795 L
.02492 .24141 L
.0248 .24523 L
.02478 .24852 L
.02487 .25206 L
Mistroke
.02504 .25539 L
.02528 .25845 L
.02598 .2645 L
.02651 .26792 L
.02709 .27109 L
.03002 .28304 L
.03422 .29509 L
.03928 .3063 L
.05156 .3268 L
.06877 .348 L
.09184 .36971 L
.14255 .40396 L
.17656 .42095 L
.21132 .43506 L
.25 .44778 L
.28882 .45801 L
.33574 .46752 L
.35846 .47114 L
.38012 .47405 L
.40091 .47635 L
.42015 .47807 L
.44166 .47955 L
.45301 .48014 L
.465 .48062 L
.47591 .48094 L
.4876 .48115 L
.49863 .48123 L
.50866 .4812 L
.52045 .48103 L
.5271 .48088 L
.53323 .48069 L
.54447 .48027 L
.55636 .47968 L
.57566 .47841 L
.59628 .47664 L
.63305 .47235 L
.67571 .46542 L
.71339 .45738 L
.75078 .44735 L
.78842 .4348 L
.8493 .40764 L
.88154 .3883 L
.90795 .36844 L
.92813 .34938 L
.94596 .32769 L
.95278 .31729 L
.95903 .30595 L
.96354 .29603 L
.96749 .28512 L
.9694 .27842 L
Mistroke
.97084 .27221 L
.97192 .26625 L
.97235 .2632 L
.97274 .25991 L
.97319 .25425 L
.97337 .24893 L
.97337 .24585 L
.97329 .2426 L
.97292 .23681 L
.97224 .23069 L
.97134 .22514 L
.97 .21875 L
.96842 .21275 L
.96487 .20214 L
.95996 .19078 L
.94482 .16562 L
.92609 .14348 L
.90584 .12488 L
.88052 .10616 L
.82623 .07614 L
.78833 .06046 L
.7495 .04755 L
.70894 .0368 L
.67056 .02879 L
.62849 .02211 L
.58794 .01755 L
.56532 .01576 L
.54442 .01456 L
.53343 .01411 L
.52712 .0139 L
.52137 .01374 L
.51528 .01362 L
.50876 .01352 L
.49701 .01345 L
.48679 .0135 L
.47595 .01367 L
.46671 .0139 L
.45654 .01426 L
.44565 .01475 L
.43396 .01541 L
.41293 .01696 L
.39195 .01896 L
.37219 .02128 L
.33572 .02674 L
.29414 .03497 L
.25795 .04412 L
.22092 .05572 L
.1835 .07025 L
.15157 .0855 L
.12484 .10093 L
Mistroke
.08061 .13479 L
.06215 .15422 L
.04632 .17604 L
.04018 .18692 L
.0353 .19737 L
.03173 .20677 L
.02866 .21724 L
.02733 .22319 L
.02634 .22879 L
.02559 .23472 L
.02528 .23805 L
.02509 .24111 L
.02493 .24627 L
.02501 .25191 L
.02537 .25779 L
.02596 .26325 L
.02641 .26637 L
.02699 .26975 L
.02827 .27588 L
.03151 .28726 L
.03664 .3004 L
.04265 .31234 L
.05607 .33272 L
.07445 .35369 L
.11742 .3885 L
.14926 .40745 L
.18301 .42365 L
.21924 .43777 L
.25431 .44892 L
.29071 .45835 L
.33174 .46674 L
.35495 .47055 L
.37661 .47355 L
.39891 .47609 L
.4199 .47801 L
.43811 .4793 L
.45771 .48032 L
.46892 .48073 L
.47954 .48101 L
.48909 .48116 L
.49946 .48122 L
.50957 .48118 L
.52072 .48103 L
.53235 .48073 L
.54324 .48033 L
.56263 .47933 L
.5834 .47783 L
.60448 .47585 L
.62675 .47324 L
.6661 .46724 L
Mistroke
.7113 .45796 L
.75043 .44754 L
.78905 .43467 L
.82775 .41853 L
.86066 .40144 L
.88814 .38389 L
.91222 .3649 L
.93096 .34649 L
.94794 .32503 L
.95559 .31269 L
.96148 .30107 L
.96608 .28968 L
.96977 .27744 L
.97118 .27107 L
.97221 .26507 L
.97266 .26163 L
.97299 .25847 L
.97326 .255 L
.97343 .25134 L
.97348 .24565 L
.97324 .23957 L
.97274 .23384 L
.97205 .22863 L
.97095 .22253 L
.96941 .21594 L
.96569 .20404 L
.96133 .19341 L
.95557 .18213 L
.94244 .16224 L
.92242 .13963 L
.90011 .12013 L
.87317 .10129 L
.83973 .08253 L
.76935 .05371 L
.72877 .04167 L
.68851 .03224 L
.65096 .02537 L
.60919 .01969 L
.58705 .01744 L
.56253 .01555 L
.55011 .01483 L
.53676 .01422 L
.53027 .01399 L
.52413 .01381 L
.5126 .01357 L
.50177 .01346 L
.49026 .01348 L
.48044 .01359 L
.46962 .01383 L
.45803 .01421 L
Mistroke
.44558 .01477 L
.42313 .01618 L
.40203 .01797 L
.37969 .02039 L
.34016 .02604 L
.29467 .03491 L
.25516 .04498 L
.2161 .0575 L
.17683 .07328 L
.1433 .09007 L
.11517 .10739 L
.09046 .12613 L
.07109 .14435 L
.05336 .16565 L
.04528 .17792 L
.03897 .1895 L
.03361 .2018 L
.02987 .21305 L
.0282 .21954 L
.02695 .22566 L
.02596 .23214 L
.02556 .23579 L
.02529 .23915 L
.02504 .24489 L
.02504 .25023 L
.02532 .25609 L
.0256 .25937 L
.02593 .26236 L
.02682 .26836 L
.02812 .27487 L
.03138 .28662 L
.03537 .29728 L
.04073 .30862 L
.05315 .32864 L
.07238 .35146 L
.094 .37119 L
.12026 .39028 L
.15304 .40936 L
.22242 .43881 L
.2625 .45117 L
.30238 .46092 L
.33963 .46808 L
.38117 .47409 L
.40319 .47651 L
.42761 .47859 L
.43999 .47941 L
.45331 .48012 L
.46592 .48063 L
.47744 .48096 L
.48889 .48116 L
Mistroke
.49949 .48123 L
.51113 .48118 L
.51701 .4811 L
.52349 .48098 L
.53431 .48068 L
.54595 .48023 L
.55692 .47968 L
.56696 .47907 L
.58882 .47739 L
.60854 .47544 L
.65208 .46962 L
.69125 .46246 L
.72693 .45413 L
.80099 .43014 L
.83833 .41349 L
.86943 .39629 L
.89448 .37935 L
.91791 .3598 L
.93506 .34193 L
.95031 .32157 L
.95774 .30886 L
.96338 .29686 L
.96762 .28526 L
.96936 .27928 L
.9709 .27279 L
.97207 .26636 L
.97285 .26044 L
.97333 .25478 L
.97355 .24879 L
.97349 .24342 L
.97322 .23841 L
.97269 .23292 L
.97185 .22705 L
.97077 .2214 L
.96928 .2152 L
.96528 .20274 L
.96042 .19133 L
.95487 .18078 L
.93895 .15769 L
.91666 .13407 L
.89256 .11436 L
.86321 .09519 L
.8323 .07883 L
.80164 .06543 L
.73076 .04217 L
.68858 .03223 L
.64715 .02475 L
.62806 .022 L
.60763 .0195 L
.58981 .01769 L
Mistroke
.57054 .0161 L
.55966 .01537 L
.5497 .01481 L
.53956 .01433 L
.53014 .01399 L
.51918 .0137 L
.51339 .01359 L
.50723 .01351 L
.4969 .01346 L
.48549 .01353 L
.47468 .01372 L
.46462 .01399 L
.4536 .01441 L
.44183 .01499 L
.4179 .0166 L
.39631 .01857 L
.35523 .0237 L
.31741 .03018 L
.27521 .03961 L
.23809 .05015 L
.20004 .06356 L
.16233 .08016 L
.13167 .09686 L
.10657 .11352 L
.08418 .13169 L
.06639 .14952 L
.04957 .1712 L
.04186 .184 L
.0361 .19581 L
.03171 .20723 L
.02858 .21809 L
.02728 .22409 L
.02635 .22963 L
.02561 .23572 L
.02536 .23879 L
.02516 .24216 L
.02506 .24823 L
.02522 .25384 L
.02542 .25677 L
.02571 .25999 L
.0261 .26336 L
.02656 .26652 L
.02881 .27756 L
.03052 .28373 L
.03236 .28936 L
.0414 .30979 L
.04727 .31986 L
.05469 .33067 L
.07356 .35262 L
.09844 .37467 L
Mistroke
.15443 .41004 L
.18921 .42617 L
.22402 .43933 L
.26404 .45156 L
.31066 .46265 L
.353 .47022 L
.39376 .47553 L
.41662 .47772 L
.43767 .47927 L
.44935 .47993 L
.46212 .4805 L
.46797 .48071 L
.4742 .48089 L
.48542 .48112 L
.49656 .48123 L
.50288 .48124 L
.50877 .48121 L
.515 .48114 L
.52067 .48105 L
.52721 .4809 L
.53339 .48072 L
.54434 .48031 L
.55444 .47983 L
.5772 .47836 L
.59978 .47638 L
.62442 .47359 L
.67317 .46603 L
.71425 .45733 L
.7564 .44582 L
.79355 .43307 L
.82571 .41958 L
.88312 .38749 L
.90842 .36831 L
.93117 .3464 L
.94091 .33483 L
.95008 .32199 L
.95694 .31043 L
.96293 .298 L
.96721 .28664 L
.96904 .28058 L
.97066 .27404 L
.97183 .26802 L
.97264 .26251 L
.97321 .25696 L
.97351 .2517 L
.97358 .24642 L
.9734 .24072 L
.97299 .23535 L
.9724 .23042 L
.97152 .22498 L
Mistroke
.97027 .21904 L
.96687 .20713 L
.96236 .19549 L
.95628 .18322 L
.94214 .16169 L
.92394 .14101 L
.90324 .12251 L
.85605 .09107 L
.82716 .07639 L
.79251 .06186 L
.7562 .04945 L
.71474 .03808 L
.67412 .02937 L
.63567 .02304 L
.61683 .02057 L
.59606 .01828 L
.57617 .01652 L
.55777 .01526 L
.54674 .01466 L
.53506 .01416 L
.52331 .0138 L
.51664 .01365 L
.51041 .01355 L
.49911 .01347 L
.48881 .01351 L
.48312 .01357 L
.47693 .01368 L
.4657 .01397 L
.45571 .01433 L
.44471 .01485 L
.42254 .01626 L
.40214 .018 L
.38316 .02002 L
.33802 .02645 L
.29798 .03424 L
.25587 .04484 L
.21413 .05828 L
.15008 .08646 L
.11907 .10485 L
.09431 .12302 L
.07432 .14112 L
.0563 .16178 L
.04292 .18212 L
.03383 .2014 L
.03006 .21261 L
.02754 .22292 L
.02652 .22864 L
.02609 .23166 L
.02572 .23488 L
.02525 .24078 L
Mistroke
.02508 .24626 L
.02515 .25175 L
.02551 .25768 L
.02611 .26326 L
.02689 .26838 L
.02896 .27807 L
.03198 .28821 L
.03635 .29939 L
.04218 .31119 L
.05566 .33193 L
.07646 .35548 L
.09969 .37562 L
.12499 .39325 L
.15521 .41043 L
.21724 .43696 L
.25541 .44915 L
.29317 .45884 L
.33644 .46752 L
.35961 .4712 L
.38469 .47451 L
.40865 .47702 L
.43057 .4788 L
.44122 .47949 L
.45276 .4801 L
.46369 .48056 L
.47377 .48088 L
.48556 .48113 L
.49657 .48124 L
.5029 .48125 L
.50866 .48122 L
.51532 .48115 L
.52162 .48104 L
.52772 .4809 L
.53419 .48071 L
.5458 .48026 L
.55826 .47963 L
.57197 .47876 L
.59485 .47687 L
.61565 .47467 L
.66166 .46809 L
.70092 .46042 L
.7406 .45049 L
.81039 .42635 L
.84525 .41002 L
.87389 .39357 L
.89777 .37693 L
.92028 .35763 L
.93693 .3398 L
.95148 .31982 L
.95799 .30848 L
Mistroke
.96297 .29796 L
.96706 .28715 L
.96998 .27703 L
.97124 .27131 L
.97229 .26521 L
.97276 .26171 L
.9731 .25842 L
.97333 .25546 L
.9735 .25227 L
.9736 .24629 L
.97353 .24328 L
.97338 .23998 L
.97288 .23415 L
.97217 .22871 L
.97108 .22266 L
.96956 .2161 L
.96589 .20427 L
.9612 .19288 L
.9559 .18249 L
.94049 .15955 L
.91921 .13639 L
.89664 .11734 L
.87293 .10103 L
.84441 .08482 L
.81 .06881 L
.7452 .04616 L
.70692 .03622 L
.66983 .02857 L
.62685 .02183 L
.60211 .0189 L
.57906 .01676 L
.55872 .01532 L
.54711 .01468 L
.53624 .01421 L
.52476 .01384 L
.51426 .01361 L
.50846 .01354 L
.50214 .01349 L
.49063 .0135 L
.4804 .01362 L
.4708 .01383 L
.46027 .01416 L
.44893 .01464 L
.42593 .01602 L
.40497 .01774 L
.36714 .02205 L
.32817 .02819 L
.28721 .03671 L
.25151 .04611 L
.21505 .05796 L
Mistroke
.17818 .07276 L
.14688 .08819 L
.12068 .10381 L
.07749 .138 L
.05974 .15741 L
.05145 .16849 L
.04459 .17923 L
.03914 .18933 L
.03419 .20051 L
.03062 .21077 L
.02809 .22038 L
.0269 .22637 L
.02639 .22954 L
.02595 .23288 L
.02564 .23581 L
.02537 .23903 L
.02512 .24469 L
.02512 .25021 L
.0254 .25611 L
.02593 .26168 L
.02663 .26675 L
.0278 .27304 L
.02917 .27883 L
.0333 .29186 L
.03811 .3032 L
.0444 .31508 L
.05904 .33626 L
.07586 .35487 L
.09743 .37384 L
.12489 .39318 L
.17952 .42199 L
.21318 .43549 L
.24661 .44656 L
.28609 .45718 L
.33097 .46655 L
.35217 .47009 L
.37494 .47331 L
.39487 .47565 L
.41649 .47772 L
.43759 .47927 L
.45697 .4803 L
.46632 .48066 L
.47652 .48096 L
.48617 .48114 L
.49512 .48124 L
.50651 .48124 L
.51722 .48112 L
.52684 .48093 L
.53721 .48061 L
.54853 .48014 L
Mistroke
.56046 .47951 L
.5817 .47803 L
.60413 .47596 L
.62513 .47352 L
.66378 .46773 L
.70411 .45972 L
.74601 .44896 L
.78068 .43783 L
.81514 .42433 L
.87005 .39599 L
.89624 .3781 L
.91718 .36057 L
.93749 .33914 L
.95277 .31775 L
.95825 .30799 L
.9632 .29744 L
.96671 .28822 L
.9697 .27816 L
.97112 .27196 L
.97215 .26624 L
.97287 .26075 L
.97337 .25495 L
.97359 .24974 L
.97358 .24488 L
.97336 .23954 L
.97285 .23383 L
.9721 .22819 L
.97095 .22199 L
.96942 .21553 L
.96767 .20949 L
.96379 .19879 L
.95853 .18739 L
.94252 .16215 L
.92305 .1401 L
.90223 .12167 L
.8758 .10284 L
.84467 .08494 L
.81209 .06969 L
.77741 .05638 L
.73716 .04388 L
.70188 .03508 L
.66148 .02709 L
.61628 .0205 L
.59105 .01781 L
.56719 .01587 L
.5557 .01514 L
.54476 .01458 L
.53492 .01417 L
.52416 .01383 L
.51249 .01359 L
Mistroke
.50597 .01352 L
.50005 .01349 L
.48853 .01352 L
.47768 .01368 L
.46729 .01393 L
.45618 .01433 L
.44571 .01481 L
.43619 .01534 L
.41299 .01704 L
.39122 .01913 L
.34861 .02475 L
.30372 .03301 L
.26637 .04197 L
.22862 .05327 L
.16686 .078 L
.13666 .09395 L
.11172 .10989 L
.08805 .12832 L
.06619 .1498 L
.05072 .16957 L
.03951 .18859 L
.03467 .19934 L
.03111 .2092 L
.0295 .2147 L
.02803 .22067 L
.02693 .22625 L
.02612 .23156 L
.02551 .2373 L
.02519 .24254 L
.02509 .24819 L
.02529 .25434 L
.02572 .25969 L
.02643 .26538 L
.02734 .27073 L
.02837 .27556 L
.03173 .28741 L
.03667 .30006 L
.04899 .32246 L
.06665 .34523 L
.09016 .3679 L
.11646 .38768 L
.14371 .40429 L
.20612 .43287 L
.24453 .44593 L
.28306 .45645 L
.3178 .46408 L
.35587 .47065 L
.37615 .47346 L
.39875 .47606 L
.41961 .47798 L
Mistroke
.43911 .47937 L
.45067 .48001 L
.46117 .48047 L
.47286 .48087 L
.47929 .48102 L
.48534 .48113 L
.49638 .48125 L
.50653 .48124 L
.51767 .48112 L
.52943 .48086 L
.53926 .48054 L
.54978 .48009 L
.5687 .479 L
.59107 .47723 L
.61129 .47518 L
.6554 .46914 L
.70179 .46025 L
.74364 .44964 L
.78028 .43798 L
.81289 .4253 L
.84538 .40997 L
.89614 .37818 L
.92026 .35766 L
.94108 .33466 L
.95493 .31411 L
.96111 .30216 L
.96577 .29089 L
.96775 .28505 L
.96953 .27884 L
.97082 .27345 L
.97192 .26764 L
.97243 .26438 L
.97281 .26139 L
.97334 .25554 L
.97351 .25226 L
.97361 .24869 L
.9736 .24532 L
.9735 .2422 L
.9731 .23615 L
.97244 .23048 L
.97162 .22539 L
.9705 .2199 L
.96708 .20765 L
.96283 .19651 L
.95286 .17727 L
.93834 .15686 L
.91934 .1365 L
.89825 .11856 L
.87178 .1003 L
.83922 .08217 L
Mistroke
.80754 .06779 L
.7712 .05426 L
.7364 .04367 L
.69606 .03379 L
.65786 .02648 L
.621 .02108 L
.60121 .01881 L
.57989 .01683 L
.56755 .0159 L
.55632 .01518 L
.54563 .01462 L
.53429 .01415 L
.52863 .01396 L
.52241 .01379 L
.51145 .01358 L
.50528 .01351 L
.49865 .01349 L
.4924 .0135 L
.48669 .01354 L
.47566 .01372 L
.46943 .01388 L
.46366 .01405 L
.4531 .01446 L
.44189 .01502 L
.42259 .01627 L
.40189 .01805 L
.36491 .02236 L
.322 .02934 L
.28398 .03749 L
.24696 .04747 L
.20954 .05999 L
.14889 .08712 L
.11682 .10639 L
.09045 .12626 L
.0703 .14532 L
.05243 .1671 L
.04568 .17741 L
.03947 .18868 L
.03499 .19856 L
.03104 .20945 L
.02913 .21609 L
.02768 .22229 L
.0266 .22822 L
.02616 .23127 L
.02577 .23456 L
.02547 .23781 L
.02527 .2408 L
.0251 .24669 L
.02518 .25203 L
.02553 .25767 L
Mistroke
.0262 .26375 L
.02707 .26928 L
.02839 .27564 L
.02995 .28165 L
.03345 .29224 L
.03832 .30363 L
.05337 .3288 L
.07207 .35103 L
.09208 .36951 L
.11719 .38817 L
.17112 .41818 L
.20682 .43313 L
.2474 .4468 L
.28782 .4576 L
.32621 .46568 L
.36784 .47237 L
.40812 .47698 L
.43055 .47881 L
.45136 .48004 L
.46227 .48052 L
.4743 .48091 L
.48036 .48105 L
.48688 .48116 L
.49865 .48126 L
.50957 .48122 L
.5197 .48109 L
.5308 .48083 L
.53699 .48062 L
.54259 .48041 L
.56398 .47931 L
.58399 .47785 L
.62081 .47407 L
.65975 .46843 L
.7007 .46049 L
.73737 .45141 L
.77869 .43854 L
.81378 .42493 L
.87661 .39185 L
.9053 .37096 L
.92817 .34969 L
.94447 .33017 L
.95837 .30778 L
.9637 .29625 L
.96817 .28369 L
.96986 .27756 L
.97118 .27172 L
.97212 .26646 L
.97289 .2607 L
.97338 .2549 L
.9736 .24942 L
Mistroke
.97358 .2445 L
.97334 .23919 L
.97281 .23339 L
.97195 .22727 L
.97097 .22206 L
.96964 .21636 L
.96659 .20621 L
.96237 .19543 L
.95229 .17634 L
.93567 .15365 L
.9163 .13367 L
.89089 .11308 L
.85944 .09295 L
.79756 .06379 L
.75792 .04997 L
.71828 .03894 L
.68016 .03053 L
.63691 .02322 L
.61459 .0203 L
.59045 .01775 L
.56744 .01589 L
.55723 .01524 L
.54639 .01466 L
.53634 .01422 L
.52525 .01386 L
.51516 .01364 L
.50571 .01352 L
.49457 .01349 L
.4844 .01357 L
.47266 .01379 L
.46153 .01413 L
.45192 .01452 L
.44171 .01503 L
.4234 .01621 L
.40177 .01806 L
.38235 .02014 L
.34048 .02606 L
.29768 .03433 L
.26257 .043 L
.2259 .05419 L
.18887 .06815 L
.15251 .0852 L
.09693 .12094 L
.07347 .14202 L
.05568 .16264 L
.04071 .18627 L
.03501 .19851 L
.03247 .20515 L
.03021 .21218 L
.02867 .21793 L
Mistroke
.0273 .22423 L
.02634 .22997 L
.02569 .23532 L
.02541 .23859 L
.02523 .24167 L
.0251 .24744 L
.02514 .25067 L
.02526 .25365 L
.02547 .25691 L
.02579 .26037 L
.02648 .26573 L
.02749 .27148 L
.02999 .2818 L
.03412 .29397 L
.03896 .30495 L
.05144 .32608 L
.06888 .34766 L
.08701 .36519 L
.11034 .38346 L
.13887 .40156 L
.17346 .41926 L
.20911 .43399 L
.2448 .44601 L
.28376 .45662 L
.32082 .46466 L
.36346 .47176 L
.38743 .47483 L
.41036 .47719 L
.43285 .47897 L
.44425 .47967 L
.45685 .4803 L
.4676 .48071 L
.47918 .48102 L
.49012 .4812 L
.50013 .48126 L
.50617 .48125 L
.51259 .4812 L
.52415 .481 L
.53123 .48081 L
.53788 .48059 L
.5503 .48007 L
.57306 .4787 L
.5975 .47663 L
.61818 .47439 L
.6401 .4715 L
.67883 .465 L
.72321 .45516 L
.76168 .44421 L
.79934 .43087 L
.83707 .4142 L
Mistroke
.869 .39664 L
.89559 .37861 L
.91839 .35945 L
.93605 .34087 L
.95183 .31928 L
.95845 .30762 L
.96415 .29515 L
.96818 .28366 L
.96993 .2773 L
.97127 .27127 L
.97225 .26564 L
.97301 .25952 L
.97344 .25395 L
.97361 .24881 L
.97353 .24271 L
.97317 .23701 L
.97285 .23374 L
.97248 .23076 L
.97138 .22407 L
.96998 .21768 L
.96806 .21074 L
.96356 .19823 L
.95819 .18671 L
.95112 .17447 L
.93509 .15297 L
.91562 .13304 L
.89454 .11575 L
.83616 .08066 L
.80193 .06551 L
.7612 .051 L
.72058 .03951 L
.68021 .03054 L
.64266 .02407 L
.60078 .01877 L
.57875 .01674 L
.55429 .01507 L
.54192 .01445 L
.53542 .01419 L
.52858 .01396 L
.52255 .01379 L
.51597 .01365 L
.5044 .01351 L
.4926 .0135 L
.48189 .01361 L
.47596 .01372 L
.46955 .01388 L
.45792 .01426 L
.44703 .01475 L
.43554 .01539 L
.41505 .01687 L
Mistroke
.39279 .01897 L
.37189 .02143 L
.33342 .02727 L
.29328 .03532 L
.25149 .04614 L
.21701 .05728 L
.18265 .07081 L
.12789 .09923 L
.10193 .11705 L
.08113 .13455 L
.06184 .15486 L
.04575 .1773 L
.04032 .18702 L
.0354 .19756 L
.03192 .20675 L
.02895 .21681 L
.02754 .22299 L
.02653 .22871 L
.02581 .23419 L
.02532 .24 L
.02512 .2452 L
.02513 .25007 L
.02536 .25541 L
.02588 .26114 L
.02628 .26433 L
.02673 .26732 L
.02778 .27291 L
.03107 .28535 L
.03493 .296 L
.04018 .30737 L
.05613 .33253 L
.07557 .35457 L
.0963 .37294 L
.12268 .39176 L
.15374 .40966 L
.18633 .42494 L
.22079 .4382 L
.26087 .45068 L
.296 .45949 L
.33633 .4675 L
.38134 .47411 L
.4065 .47683 L
.43035 .47879 L
.44124 .4795 L
.45273 .48011 L
.46256 .48053 L
.47332 .48088 L
.48498 .48113 L
.4915 .48122 L
.49743 .48125 L
Mistroke
.50897 .48123 L
.51985 .48109 L
.52917 .48087 L
.53917 .48055 L
.54859 .48015 L
.55718 .47971 L
.57811 .47832 L
.59783 .4766 L
.63648 .47201 L
.67754 .46525 L
.7119 .45793 L
.74705 .44867 L
.80576 .42829 L
Mfstroke
.92092 .35445 m
.93824 .33537 L
.95126 .31686 L
.96197 .2959 L
.9663 .28394 L
.96917 .27295 L
.97024 .26733 L
.97109 .26135 L
.97158 .25624 L
.97186 .2506 L
.97187 .24455 L
.97174 .24115 L
.97154 .23804 L
.97092 .23201 L
.97005 .2263 L
.969 .22102 L
.96763 .21542 L
.9645 .20539 L
.95968 .19358 L
.95428 .18301 L
.9385 .15963 L
.91979 .13907 L
.89487 .11779 L
.86388 .097 L
.80209 .06657 L
.76234 .05209 L
.72266 .04051 L
.68219 .03115 L
.63636 .0231 L
.61487 .02017 L
.59175 .01759 L
.57183 .01581 L
.56106 .01502 L
.54968 .01432 L
.53946 .01379 L
.52825 .01334 L
.51805 .01304 L
.50854 .01285 L
.49727 .01274 L
.48704 .01275 L
.47522 .01289 L
.46408 .01315 L
.45434 .01348 L
.44405 .01393 L
.42565 .01501 L
.40597 .01655 L
.38449 .01871 L
.33955 .0249 L
.29823 .03279 L
.26255 .04152 L
Mistroke
.2255 .05278 L
.18787 .06698 L
.15117 .08427 L
.09533 .12048 L
.07149 .14217 L
.05363 .16327 L
.03871 .18745 L
.03312 .19993 L
.03054 .20703 L
.02849 .21378 L
.02701 .21968 L
.02572 .22611 L
.02485 .23197 L
.02429 .23739 L
.02395 .24325 L
.02388 .24658 L
.0239 .24971 L
.02401 .25299 L
.02418 .25599 L
.02446 .25929 L
.02484 .26275 L
.02565 .2682 L
.02678 .27401 L
.0295 .2844 L
.03389 .29663 L
.03895 .30759 L
.05214 .32908 L
.07034 .35082 L
.08917 .36843 L
.11316 .38659 L
.14256 .4046 L
.17788 .42201 L
.25013 .448 L
.29164 .45869 L
.33181 .46673 L
.37743 .47346 L
.40093 .47603 L
.41368 .47718 L
.42718 .47821 L
.43814 .47891 L
.45018 .47955 L
.46114 .48 L
.47137 .48031 L
.47761 .48046 L
.4835 .48055 L
.49453 .48065 L
.50071 .48065 L
.50641 .48062 L
.51266 .48055 L
.51929 .48043 L
Mistroke
.52956 .48017 L
.54058 .47976 L
.56043 .47874 L
.5725 .47792 L
.58391 .47702 L
.6052 .47496 L
.64843 .46927 L
.68651 .46245 L
.7288 .45262 L
.76663 .44148 L
.8282 .41729 L
.85901 .40136 L
.88454 .38535 L
.90775 .36766 L
.92898 .34748 L
.94535 .32742 L
.95704 .30845 L
.96261 .29663 L
.96669 .28557 L
.96998 .27331 L
.97116 .26709 L
.97166 .26374 L
.97208 .26021 L
.97257 .25419 L
.97276 .24868 L
.97268 .24274 L
.9725 .23938 L
.97225 .23626 L
.9716 .23057 L
.97077 .22542 L
.96954 .21949 L
.96811 .21391 L
.96455 .20302 L
.96032 .19294 L
.94754 .17049 L
.93095 .14945 L
.90881 .128 L
.88446 .10934 L
.85821 .0929 L
.80154 .06576 L
.76522 .05255 L
.73029 .04217 L
.69079 .03269 L
.64636 .02451 L
.62574 .02151 L
.60372 .01884 L
.58311 .0168 L
.56376 .0153 L
.5455 .01422 L
.53524 .01377 L
Mistroke
.52588 .01344 L
.51561 .01319 L
.50445 .01303 L
.4939 .01299 L
.48417 .01305 L
.47302 .01323 L
.46244 .01352 L
.45296 .01388 L
.44262 .01437 L
.41959 .01586 L
.39835 .01772 L
.36029 .02228 L
.32069 .02882 L
.27525 .03884 L
.23461 .05048 L
.20052 .06259 L
.16575 .0777 L
.1086 .11124 L
.08297 .13194 L
.06296 .15254 L
.04787 .17275 L
.03729 .1918 L
.03279 .20253 L
.0308 .20823 L
.02898 .21432 L
.02765 .21964 L
.02645 .22554 L
.02561 .23091 L
.02503 .23596 L
.02464 .24145 L
.0245 .24732 L
.02462 .25286 L
.02495 .25789 L
.0256 .26379 L
.0261 .26712 L
.02663 .27018 L
.02935 .28171 L
.03299 .29268 L
.03815 .3046 L
.05218 .3281 L
.0681 .3476 L
.08895 .36751 L
.13568 .40016 L
.16805 .41708 L
.20095 .43112 L
.24325 .44567 L
.28412 .45674 L
.32506 .4654 L
.36495 .47182 L
.38585 .47445 L
Mistroke
.40814 .47674 L
.41989 .47774 L
.43282 .47868 L
.44467 .47939 L
.45565 .47992 L
.46651 .48033 L
.47805 .48064 L
.48964 .48081 L
.49624 .48086 L
.50243 .48086 L
.51357 .48077 L
.52376 .48058 L
.53494 .48025 L
.54668 .47978 L
.5671 .47862 L
.58597 .47718 L
.62825 .47258 L
.65156 .4692 L
.67319 .46549 L
.71256 .45718 L
.75306 .44627 L
.79425 .43223 L
.85617 .40354 L
.88638 .38467 L
.91096 .36554 L
.93275 .344 L
.94873 .32331 L
.95589 .31153 L
.96231 .29848 L
.96703 .28597 L
.96872 .28028 L
.97022 .27427 L
.97128 .26897 L
.97218 .26315 L
.97275 .25785 L
.97308 .25291 L
.9732 .24706 L
.97307 .24174 L
.9729 .23879 L
.97263 .2356 L
.97193 .22981 L
.9711 .22481 L
.96995 .21931 L
.96685 .20825 L
.96307 .1981 L
.95875 .18869 L
.94488 .16596 L
.92833 .146 L
.90485 .12419 L
.87846 .10488 L
Mistroke
.82035 .07346 L
.78319 .05852 L
.74702 .04672 L
.71132 .03723 L
.67101 .0287 L
.63163 .02233 L
.59453 .01794 L
.5729 .01605 L
.55304 .01474 L
.54202 .01419 L
.53619 .01394 L
.53 .01372 L
.51863 .01341 L
.50811 .01324 L
.49852 .01317 L
.48818 .01321 L
.47842 .01333 L
.46948 .01353 L
.45958 .01385 L
.44877 .0143 L
.42706 .01557 L
.40315 .01754 L
.38162 .01982 L
.33427 .02669 L
.2919 .0352 L
.2536 .04508 L
.18294 .07024 L
.15119 .08546 L
.11973 .10401 L
.09606 .1212 L
.07411 .14091 L
.0569 .16054 L
.04429 .17919 L
.03839 .19024 L
.03379 .20077 L
.02966 .21304 L
.02824 .21848 L
.02701 .22424 L
.02615 .22933 L
.02545 .23491 L
.02504 .23999 L
.02484 .24473 L
.02485 .25033 L
.02508 .25543 L
.02561 .26131 L
.02637 .26686 L
.02739 .27238 L
.02879 .27845 L
.03257 .29065 L
.03717 .30181 L
Mistroke
.04242 .31214 L
.05755 .33478 L
.07873 .35796 L
.10287 .37828 L
.12881 .39581 L
.1637 .41478 L
.19878 .43011 L
.27112 .45342 L
.31414 .46328 L
.35634 .4706 L
.39642 .47566 L
.41954 .47779 L
.4413 .4793 L
.45314 .47992 L
.46439 .48038 L
.4745 .48069 L
.48552 .48091 L
.49121 .48097 L
.4975 .48101 L
.50406 .48101 L
.51023 .48097 L
.52123 .4808 L
.52742 .48066 L
.53309 .48049 L
.54264 .48014 L
.55284 .47966 L
.57116 .47855 L
.59281 .47678 L
.61233 .47477 L
.65412 .46904 L
.69247 .46194 L
.72959 .45319 L
.76848 .44169 L
.80405 .42867 L
.83935 .41275 L
.86923 .3962 L
.89368 .37974 L
.91572 .36162 L
.93282 .34428 L
.94864 .32386 L
.95527 .3131 L
.96131 .30128 L
.96584 .29014 L
.96908 .27981 L
.97134 .26986 L
.97217 .26483 L
.97284 .25931 L
.9731 .25621 L
.9733 .25285 L
.97342 .24672 L
Mistroke
.97324 .24077 L
.97282 .23527 L
.97208 .22934 L
.97094 .22282 L
.96936 .21603 L
.96754 .2097 L
.96338 .19827 L
.9586 .18792 L
.94455 .16516 L
.92782 .14518 L
.90607 .12496 L
.85752 .09197 L
.82246 .07428 L
.78612 .0595 L
.75139 .04796 L
.711 .03713 L
.66975 .02848 L
.62984 .02212 L
.60778 .01939 L
.58663 .01726 L
.57488 .01628 L
.56203 .01537 L
.5504 .01469 L
.53943 .01418 L
.52898 .01379 L
.51769 .0135 L
.50742 .01335 L
.49799 .0133 L
.48773 .01334 L
.47651 .01351 L
.4648 .01381 L
.4539 .01422 L
.43395 .01528 L
.41589 .01658 L
.39519 .0185 L
.37579 .02071 L
.33636 .02652 L
.2943 .03485 L
.2523 .04567 L
.21513 .05772 L
.15505 .08366 L
.12544 .10055 L
.10129 .11733 L
.07932 .13604 L
.05976 .15717 L
.04515 .17804 L
.03526 .19757 L
.0308 .20977 L
.02781 .2211 L
.02666 .22706 L
Mistroke
.02574 .23361 L
.02542 .23692 L
.02516 .24047 L
.02502 .24382 L
.02497 .24687 L
.02509 .25285 L
.02546 .25838 L
.02616 .26443 L
.02663 .26749 L
.02724 .27085 L
.03006 .28247 L
.03372 .29329 L
.04384 .31434 L
.05124 .32599 L
.05917 .3366 L
.07998 .35896 L
.10279 .37807 L
.15289 .40926 L
.18472 .42427 L
.21721 .43694 L
.29176 .45847 L
.33205 .46667 L
.35585 .47056 L
.37794 .47359 L
.39702 .47578 L
.41802 .47773 L
.4296 .47862 L
.44038 .47932 L
.45136 .47991 L
.46172 .48037 L
.47142 .48069 L
.48192 .48094 L
.49146 .48107 L
.50023 .48111 L
.50976 .48107 L
.5202 .48093 L
.53109 .48066 L
.54123 .48031 L
.55248 .4798 L
.56439 .47912 L
.58566 .47755 L
.60835 .47535 L
.63309 .47231 L
.67638 .4653 L
.71555 .45689 L
.78377 .43657 L
.81876 .4226 L
.84831 .40829 L
.87607 .39206 L
.90229 .37326 L
Mistroke
.92193 .35591 L
.93982 .33612 L
.94898 .32354 L
.95617 .31172 L
.9618 .30045 L
.96673 .2879 L
.96846 .28243 L
.97003 .27653 L
.97115 .27141 L
.97213 .26583 L
.97258 .26256 L
.97292 .25952 L
.97337 .25353 L
.97353 .24809 L
.97342 .2423 L
.97309 .23703 L
.97246 .23128 L
.97152 .22528 L
.97037 .21971 L
.96768 .20978 L
.96389 .19925 L
.95826 .18704 L
.95179 .17568 L
.93672 .15501 L
.91901 .13627 L
.89984 .11985 L
.8473 .08633 L
.81733 .07195 L
.7824 .05812 L
.71321 .03766 L
.66793 .02817 L
.64493 .02434 L
.62326 .02129 L
.6018 .01879 L
.58216 .01693 L
.56018 .01532 L
.54806 .01464 L
.53661 .01413 L
.52624 .01378 L
.51512 .01353 L
.50461 .0134 L
.49503 .01338 L
.48379 .01347 L
.47745 .01357 L
.47158 .01371 L
.46083 .01404 L
.44943 .01451 L
.42699 .01583 L
.40607 .01753 L
.38332 .0199 L
Mistroke
.3591 .02306 L
.31944 .02971 L
.27916 .03855 L
.21199 .05897 L
.1773 .07306 L
.14826 .08736 L
.1199 .10424 L
.0929 .12412 L
.07158 .14387 L
.05532 .16302 L
.04292 .18204 L
.03786 .19188 L
.03329 .20274 L
.0312 .20876 L
.02953 .21436 L
.02808 .22018 L
.02701 .22547 L
.02618 .23069 L
.02561 .23561 L
.02522 .24081 L
.02504 .24642 L
.02513 .25214 L
.0253 .25537 L
.02554 .25839 L
.02624 .26447 L
.02677 .26788 L
.02733 .27097 L
.03013 .28246 L
.03378 .29323 L
.04356 .31371 L
.05573 .33207 L
.07242 .35144 L
.09376 .37093 L
.14432 .40464 L
.17775 .4212 L
.21112 .43472 L
.24415 .44579 L
.28224 .45621 L
.31704 .46388 L
.35597 .47061 L
.3797 .47385 L
.40182 .47631 L
.42317 .47819 L
.43412 .47898 L
.4459 .47969 L
.4566 .48021 L
.46638 .48059 L
.47623 .48088 L
.48557 .48106 L
.49643 .48117 L
Mistroke
.50649 .48116 L
.51752 .48104 L
.52924 .48078 L
.54072 .4804 L
.55124 .47993 L
.57484 .47848 L
.59551 .47673 L
.61708 .47443 L
.66202 .46796 L
.70944 .45842 L
.75091 .44744 L
.78786 .43516 L
.85002 .40745 L
.88019 .38943 L
.9047 .37139 L
.92764 .35018 L
.94712 .32638 L
.95421 .31528 L
.95994 .30456 L
.96429 .2947 L
.96801 .28408 L
.96971 .27801 L
.97098 .27249 L
.97202 .26687 L
.97274 .26168 L
.9733 .2556 L
.97348 .2524 L
.97357 .24902 L
.97351 .24334 L
.97336 .24012 L
.97315 .23711 L
.97259 .23182 L
.97172 .22609 L
.97064 .22069 L
.96944 .21572 L
.9666 .20635 L
.9628 .1965 L
.95232 .17644 L
.93683 .15506 L
.91754 .13484 L
.89326 .11483 L
.84058 .08285 L
.80657 .06738 L
.77237 .05463 L
.73264 .04262 L
.68715 .03188 L
.64111 .02379 L
.62042 .02096 L
.59741 .01837 L
.57548 .01642 L
Mistroke
.55483 .01504 L
.54338 .01446 L
.53291 .01404 L
.52711 .01385 L
.5208 .01369 L
.5093 .01349 L
.49907 .01343 L
.48946 .01346 L
.47891 .0136 L
.46754 .01387 L
.45629 .01426 L
.44445 .01482 L
.42336 .01615 L
.40392 .01779 L
.38595 .01966 L
.34577 .02514 L
.30377 .03294 L
.26012 .04362 L
.22365 .0549 L
.18745 .0687 L
.15729 .08268 L
.12708 .09969 L
.0824 .13333 L
.06187 .15478 L
.04641 .17617 L
.03603 .19603 L
.03166 .20747 L
.02858 .21819 L
.02727 .22425 L
.02671 .22745 L
.0262 .23083 L
.02583 .23379 L
.02551 .23705 L
.02516 .24278 L
.02508 .24836 L
.02527 .25434 L
.02573 .25998 L
.02637 .26512 L
.02747 .27149 L
.02878 .27736 L
.03281 .29056 L
.03756 .30206 L
.04382 .31409 L
.05827 .33531 L
.07492 .35394 L
.09632 .37297 L
.12361 .39236 L
.17797 .42129 L
.2115 .43486 L
.24483 .446 L
Mistroke
.28419 .4567 L
.32897 .46616 L
.35012 .46974 L
.37286 .473 L
.39276 .47539 L
.41435 .4775 L
.43543 .47909 L
.45479 .48016 L
.46414 .48054 L
.47433 .48086 L
.48398 .48107 L
.49292 .48118 L
.50431 .48121 L
.51502 .48112 L
.52463 .48094 L
.535 .48065 L
.54633 .4802 L
.55826 .4796 L
.57951 .47817 L
.60195 .47614 L
.62296 .47376 L
.66165 .46806 L
.70204 .46015 L
.74404 .44949 L
.77879 .43846 L
.81338 .42506 L
.86856 .39688 L
.89492 .37908 L
.91602 .36162 L
.93564 .34133 L
.95204 .31893 L
.95762 .30919 L
.96267 .29865 L
.96628 .28945 L
.96937 .2794 L
.97086 .27321 L
.97194 .26749 L
.97272 .26201 L
.97328 .25621 L
.97355 .251 L
.9736 .24614 L
.97342 .2408 L
.97298 .23508 L
.97228 .22945 L
.9712 .22324 L
.96974 .21678 L
.96805 .21073 L
.96428 .20003 L
.95914 .18861 L
.9434 .16333 L
Mistroke
.92417 .14121 L
.90355 .12273 L
.87731 .10381 L
.84637 .08582 L
.81395 .07047 L
.77943 .05706 L
.73931 .04446 L
.70413 .03556 L
.66382 .02747 L
.6187 .02077 L
.5935 .01801 L
.56966 .01601 L
.55818 .01526 L
.54724 .01467 L
.53728 .01423 L
.52665 .01387 L
.51513 .0136 L
.50442 .01348 L
.49787 .01345 L
.49169 .01347 L
.48016 .0136 L
.46978 .01383 L
.45866 .0142 L
.44819 .01466 L
.43867 .01517 L
.41546 .0168 L
.39366 .01885 L
.351 .02435 L
.30602 .0325 L
.26858 .04135 L
.23072 .05255 L
.16869 .07712 L
.13832 .09298 L
.11322 .10883 L
.08935 .12719 L
.06726 .1486 L
.05157 .16831 L
.04016 .1873 L
.0352 .19803 L
.03154 .20788 L
.02986 .21337 L
.02833 .21934 L
.02716 .22492 L
.0263 .23023 L
.02562 .23596 L
.02525 .2412 L
.02509 .24685 L
.02522 .253 L
.02558 .25835 L
.02623 .26403 L
Mistroke
.02708 .26938 L
.02806 .27422 L
.03129 .28607 L
.03608 .29874 L
.04184 .31053 L
.04816 .32118 L
.0639 .34211 L
.08553 .36389 L
.1127 .38511 L
.14194 .4033 L
.17344 .41924 L
.21092 .43465 L
.24646 .4465 L
.28635 .45723 L
.32389 .46523 L
.3667 .47219 L
.38584 .47462 L
.40665 .47682 L
.42654 .4785 L
.44469 .47967 L
.45628 .48025 L
.46722 .48067 L
.47879 .48099 L
.48532 .48111 L
.49133 .48119 L
.50139 .48123 L
.51244 .48117 L
.52397 .48098 L
.53472 .48068 L
.54744 .48018 L
.55946 .47955 L
.58189 .478 L
.60584 .47576 L
.6316 .47266 L
.67448 .4658 L
.71837 .45635 L
.75415 .44653 L
.79148 .43388 L
.82518 .41985 L
.85765 .4033 L
.90692 .3696 L
.92897 .34883 L
.94571 .32844 L
.95969 .30515 L
.96544 .29179 L
.96762 .28546 L
.96936 .2795 L
.97071 .27394 L
.97172 .26884 L
.97259 .26316 L
Mistroke
.97323 .25705 L
.97355 .2512 L
.97361 .24788 L
.97358 .24481 L
.97334 .23918 L
.97279 .2332 L
.97201 .22766 L
.97089 .22168 L
.96811 .21092 L
.96449 .20053 L
.96037 .19108 L
.94802 .16977 L
.93005 .14733 L
.90659 .12521 L
.88064 .10599 L
.85187 .08874 L
.81703 .07181 L
.78356 .05854 L
.74553 .04624 L
.70944 .0368 L
.6679 .02821 L
.62883 .02209 L
.59133 .01782 L
.56986 .01604 L
.54977 .01481 L
.53817 .01428 L
.52762 .01391 L
.52177 .01376 L
.51543 .01363 L
.50392 .01349 L
.49277 .01348 L
.48643 .01353 L
.48051 .01361 L
.47427 .01374 L
.46858 .01388 L
.4558 .01433 L
.44495 .01484 L
.43316 .01552 L
.41183 .01712 L
.39245 .01899 L
.37124 .0215 L
.3291 .02802 L
.29131 .03575 L
.25716 .04449 L
.18563 .06951 L
.15352 .08467 L
.12181 .10308 L
.09781 .12024 L
.07562 .13984 L
.05818 .15939 L
Mistroke
.0454 .17789 L
.03456 .19961 L
.03063 .21076 L
.02884 .21722 L
.02751 .22315 L
.02655 .22858 L
.02586 .23375 L
.02537 .23922 L
.02511 .24519 L
.02513 .25039 L
.02539 .25592 L
.02587 .26113 L
.0265 .26585 L
.02757 .27188 L
.02902 .27822 L
.03245 .2895 L
.03733 .30151 L
.04407 .31449 L
.05969 .33707 L
.07824 .35718 L
.10113 .37671 L
.13011 .3964 L
.15892 .41229 L
.19255 .42752 L
.22516 .43969 L
.26346 .45138 L
.29733 .45977 L
.33581 .4674 L
.37776 .47366 L
.40108 .47629 L
.42299 .47824 L
.43364 .47901 L
.44373 .47963 L
.45292 .48011 L
.46266 .48052 L
.4733 .48087 L
.48311 .48109 L
.49368 .48122 L
.50531 .48124 L
.51126 .4812 L
.51775 .48111 L
.52954 .48085 L
.54101 .48046 L
.55162 .47999 L
.57556 .4785 L
.60084 .47629 L
.62454 .4736 L
.64654 .47053 L
.68673 .46344 L
.72454 .45481 L
Mistroke
.76403 .44345 L
.80018 .43053 L
.83596 .41474 L
.86641 .39821 L
.89126 .38181 L
.93114 .34648 L
.94751 .32588 L
.95485 .31425 L
.96065 .30316 L
.96506 .29282 L
.9683 .28326 L
.97101 .27256 L
.97209 .26663 L
.97286 .26098 L
.97338 .25491 L
.9736 .2494 L
.97361 .24634 L
.97354 .24303 L
.97318 .23704 L
.97257 .23142 L
.97165 .2255 L
.97063 .22045 L
.96927 .21493 L
.96527 .20256 L
.95958 .18946 L
.94568 .16642 L
.92711 .1442 L
.90603 .12475 L
.87944 .10519 L
.8457 .08547 L
.77997 .05726 L
.73985 .04462 L
.69999 .03465 L
.6612 .02704 L
.61737 .02063 L
.59482 .01816 L
.57048 .0161 L
.5586 .01531 L
.54734 .01469 L
.53728 .01425 L
.5262 .01388 L
.51587 .01364 L
.5062 .01352 L
.49598 .01348 L
.48499 .01356 L
.47481 .01373 L
.46515 .014 L
.45649 .01431 L
.44705 .01474 L
.42563 .01604 L
Mistroke
.40297 .01794 L
.36279 .02265 L
.34055 .02605 L
.31747 .03021 L
.27737 .03912 L
.23629 .05077 L
.19421 .06594 L
.16072 .08101 L
.12825 .09901 L
.10302 .11622 L
.07976 .13583 L
.05942 .15783 L
.04466 .17913 L
.03821 .19128 L
.03331 .20284 L
.02924 .21567 L
.02756 .22293 L
.02639 .22961 L
.02572 .23506 L
.02527 .24089 L
.0251 .2464 L
.02516 .25139 L
.0255 .25728 L
.02581 .26059 L
.02618 .26364 L
.02706 .26923 L
.02827 .27513 L
.03153 .2868 L
.0356 .29759 L
.04845 .32162 L
.06464 .34295 L
.08678 .36499 L
.10998 .38321 L
.13819 .40117 L
.16945 .4174 L
.20031 .43063 L
.26655 .45222 L
.30578 .46162 L
.34885 .46957 L
.38673 .47474 L
.40855 .47702 L
.42906 .4787 L
.44056 .47945 L
.45308 .48012 L
.46493 .48061 L
.47589 .48094 L
.48578 .48114 L
.49667 .48124 L
.50806 .48123 L
.51871 .4811 L
Mistroke
.52464 .48098 L
.53111 .48081 L
.54287 .4804 L
.55429 .47986 L
.56488 .47925 L
.58871 .47744 L
.61388 .47489 L
.65979 .46842 L
.70066 .4605 L
.74361 .44966 L
.78628 .43582 L
.85043 .4073 L
.88182 .38841 L
.90742 .3692 L
.92879 .34903 L
.94754 .32585 L
.95449 .31488 L
.96072 .30302 L
.96513 .29264 L
.96886 .28133 L
.97024 .276 L
.97144 .27037 L
.97226 .26555 L
.97293 .26028 L
.97336 .2553 L
.97359 .24999 L
.97359 .24497 L
.97342 .24041 L
.97295 .2346 L
.97227 .22926 L
.97125 .2234 L
.96987 .21723 L
.96683 .2069 L
.96247 .19566 L
.94986 .17252 L
.93371 .15138 L
.91587 .13328 L
.89304 .11464 L
.86452 .0959 L
.83022 .0778 L
.75968 .05051 L
.71806 .03888 L
.6779 .03008 L
.63211 .02254 L
.60853 .0196 L
.58236 .01703 L
.57041 .0161 L
.55906 .01534 L
.54871 .01477 L
.53771 .01427 L
Mistroke
.53201 .01406 L
.52572 .01387 L
.51463 .01363 L
.5084 .01354 L
.50168 .01349 L
.49533 .01349 L
.48953 .01352 L
.47903 .01365 L
.46928 .01388 L
.4586 .01423 L
.44723 .01474 L
.42405 .01616 L
.40316 .01792 L
.36099 .02291 L
.31759 .03019 L
.28181 .03802 L
.24417 .04832 L
.20598 .06133 L
.1681 .07742 L
.10924 .11165 L
.08393 .13197 L
.06427 .15201 L
.0471 .17512 L
.04025 .18715 L
.03414 .20067 L
.03009 .21258 L
.02742 .2236 L
.02643 .22939 L
.02598 .23272 L
.02565 .23575 L
.02539 .23897 L
.0252 .2424 L
.02511 .24559 L
.0251 .2486 L
.02528 .25408 L
.02574 .25989 L
.02635 .26485 L
.02726 .27028 L
.0285 .27611 L
.03015 .28234 L
.03395 .29353 L
.03898 .30499 L
.04556 .317 L
.06047 .33801 L
.08315 .36175 L
.1081 .38187 L
.13533 .39952 L
.16838 .41689 L
.20244 .43146 L
.2366 .44346 L
Mistroke
.27494 .45442 L
.31155 .46282 L
.35375 .47033 L
.37782 .47367 L
.40036 .47623 L
.42243 .4782 L
.44605 .47977 L
.45834 .48036 L
.46989 .48078 L
.47651 .48096 L
.48258 .48109 L
.48925 .48119 L
.49628 .48125 L
.50723 .48124 L
.51892 .4811 L
.52995 .48085 L
.53995 .48052 L
.5517 .48 L
.5644 .47928 L
.58733 .47757 L
.60799 .47555 L
.62995 .4729 L
.66886 .46685 L
.71355 .45754 L
.75249 .44705 L
.79065 .43421 L
.82913 .41803 L
.8893 .38322 L
.91491 .36266 L
.93504 .34205 L
.94968 .32266 L
.96166 .30098 L
.9663 .28943 L
.97009 .27663 L
.97149 .27014 L
.9721 .26656 L
.97259 .26317 L
.97296 .26001 L
.97327 .25658 L
.97357 .25057 L
.97359 .24496 L
.97349 .24177 L
.97331 .23878 L
.97274 .23277 L
.97229 .2294 L
.97179 .22631 L
.97072 .22085 L
.96926 .21491 L
.96586 .20415 L
.96109 .19261 L
Mistroke
.95467 .18031 L
.93978 .15863 L
.92139 .13846 L
.90123 .12087 L
.84481 .08501 L
.81142 .0694 L
.77144 .05433 L
.73161 .04237 L
.69185 .03289 L
.65476 .02596 L
.61322 .02014 L
.59139 .01784 L
.56707 .01586 L
.55478 .01509 L
.54148 .01443 L
.53536 .01419 L
.5289 .01397 L
.51734 .01368 L
.50661 .01353 L
.49514 .01349 L
.48432 .01357 L
.47449 .01375 L
.46294 .01408 L
.45044 .01458 L
.43866 .0152 L
.42782 .0159 L
.38686 .01962 L
.3642 .02246 L
.34376 .02553 L
.26949 .04115 L
.2307 .05259 L
.19114 .06721 L
.12792 .09922 L
.09975 .11873 L
.077 .13849 L
.05989 .15724 L
.0451 .17839 L
.03897 .18971 L
.03351 .20232 L
.03127 .20873 L
.02925 .21564 L
.02782 .22163 L
.02661 .22817 L
.02616 .23133 L
.02576 .23469 L
.02528 .24072 L
.0251 .24638 L
.02512 .2496 L
.02521 .25262 L
.02558 .25821 L
Mistroke
.02614 .26333 L
.02701 .26893 L
.0282 .27481 L
.03149 .28666 L
.03565 .29772 L
.04617 .31801 L
.06137 .33911 L
.08219 .36088 L
.10394 .37882 L
.1303 .39652 L
.18532 .42451 L
.22005 .43794 L
.25383 .44869 L
.29211 .4586 L
.3357 .46739 L
.35572 .47063 L
.37731 .47361 L
.39756 .47594 L
.41675 .47775 L
.43473 .47909 L
.45424 .48018 L
.46481 .48061 L
.47598 .48095 L
.48552 .48114 L
.49598 .48125 L
.50771 .48124 L
.51854 .48111 L
.52419 .481 L
.53042 .48084 L
.54299 .4804 L
.554 .47988 L
.56581 .47919 L
.58707 .47759 L
.60892 .47545 L
.62947 .47297 L
.66737 .46712 L
.7101 .45835 L
.74803 .44838 L
.78707 .43554 L
.82615 .41942 L
.86049 .4017 L
.88862 .38371 L
.9117 .36553 L
.93311 .34428 L
.94864 .32422 L
.95985 .30482 L
.96464 .2939 L
.96813 .28383 L
.96969 .27823 L
.9711 .27212 L
Mistroke
.97214 .26633 L
.97286 .26096 L
.97335 .25549 L
.97359 .24972 L
.97359 .24479 L
.97336 .23941 L
.97284 .2336 L
.97242 .23035 L
.97198 .2274 L
.97088 .22161 L
.96963 .21629 L
.96654 .20607 L
.96222 .1951 L
.95182 .17557 L
.93687 .15507 L
.91623 .1336 L
.89023 .1126 L
.86208 .09447 L
.83144 .07838 L
.79475 .0627 L
.75987 .05058 L
.72047 .03949 L
.67949 .03039 L
.64102 .02382 L
.62205 .02122 L
.60134 .01883 L
.58151 .01696 L
.56333 .01561 L
.55321 .01501 L
.54219 .01446 L
.53052 .01402 L
.51946 .01372 L
.50911 .01355 L
.49812 .01349 L
.48874 .01353 L
.4784 .01367 L
.4725 .0138 L
.46631 .01397 L
.45525 .01437 L
.44338 .01494 L
.43045 .01572 L
.40735 .01754 L
.38608 .01971 L
.34021 .02611 L
.29991 .03384 L
.2554 .04501 L
.21585 .05769 L
.15036 .08634 L
.12171 .10315 L
.09405 .12327 L
Mistroke
.07382 .14166 L
.05582 .16245 L
.04251 .18291 L
.03359 .20211 L
.0301 .21255 L
.02851 .2186 L
.02731 .22417 L
.02633 .23004 L
.02593 .23313 L
.02559 .23638 L
.02522 .24187 L
.0251 .24787 L
.02525 .25346 L
.02561 .25854 L
.02629 .26439 L
.02719 .2699 L
.02941 .27968 L
.0327 .2902 L
.03732 .30149 L
.04364 .31375 L
.06028 .33779 L
.08014 .35897 L
.10239 .37766 L
.12885 .39563 L
.16143 .41354 L
.19308 .42775 L
.22949 .44115 L
.26793 .4526 L
.30452 .46136 L
.34271 .46858 L
.3797 .47391 L
.39926 .47612 L
.42041 .47805 L
.43263 .47895 L
.4438 .47965 L
.45443 .48019 L
.46574 .48065 L
.47751 .48099 L
.4884 .48118 L
.50012 .48126 L
.5068 .48124 L
.51306 .48119 L
.52431 .481 L
.53461 .48071 L
.5459 .48027 L
.55776 .47968 L
.57733 .47838 L
.59809 .47658 L
.63498 .47222 L
.67775 .46521 L
Mistroke
.71527 .45713 L
.76036 .44463 L
.80575 .42829 L
Mfstroke
.92239 .35439 m
.93967 .33504 L
.95262 .3163 L
.95854 .30547 L
.96321 .2951 L
.96744 .28302 L
.9689 .27776 L
.97023 .27194 L
.97125 .26624 L
.97197 .2609 L
.97247 .25524 L
.97272 .24916 L
.97267 .24352 L
.97238 .23817 L
.97192 .23336 L
.97119 .22813 L
.97003 .2219 L
.9687 .21627 L
.96476 .20374 L
.95994 .19227 L
.95438 .18161 L
.93933 .15955 L
.91885 .13733 L
.89783 .11943 L
.87123 .10108 L
.83879 .08301 L
.80005 .06575 L
.76046 .05168 L
.72139 .04055 L
.68156 .03155 L
.63758 .02397 L
.61584 .02105 L
.59212 .01845 L
.57843 .01722 L
.56581 .01625 L
.5538 .01548 L
.54092 .01482 L
.52963 .01437 L
.51935 .01407 L
.50901 .01387 L
.49924 .01379 L
.48784 .0138 L
.47733 .01393 L
.4658 .01419 L
.46 .01437 L
.45362 .01461 L
.43083 .0158 L
.41809 .01669 L
.4065 .01766 L
.38366 .01997 L
Mistroke
.36319 .02252 L
.32271 .02902 L
.2811 .0379 L
.21137 .05883 L
.17578 .07329 L
.14073 .09095 L
.11146 .10932 L
.08759 .12787 L
.06675 .1482 L
.05122 .16766 L
.03802 .19013 L
.03262 .20278 L
.03063 .20852 L
.02875 .21489 L
.02737 .22058 L
.02617 .22673 L
.02564 .23013 L
.02524 .23324 L
.02469 .23936 L
.02446 .24465 L
.02447 .25043 L
.02476 .25646 L
.02531 .26205 L
.02574 .26526 L
.02629 .26873 L
.02756 .27501 L
.03078 .28667 L
.03597 .30015 L
.04208 .31236 L
.05556 .33292 L
.07404 .35403 L
.11722 .38903 L
.14925 .40808 L
.18316 .42431 L
.21596 .43717 L
.2547 .44956 L
.29135 .45899 L
.33259 .46734 L
.35593 .47112 L
.37767 .47407 L
.40005 .47657 L
.42108 .47843 L
.43938 .47968 L
.4488 .48019 L
.45904 .48065 L
.47029 .48103 L
.48093 .48128 L
.4913 .48141 L
.50087 .48143 L
.51095 .48137 L
Mistroke
.52038 .48121 L
.53071 .48094 L
.54181 .48054 L
.55339 .47998 L
.56436 .47933 L
.58485 .47778 L
.60755 .47556 L
.62871 .47299 L
.6675 .46693 L
.70794 .45862 L
.74969 .44757 L
.78432 .43616 L
.81853 .42242 L
.87274 .39377 L
.89878 .37556 L
.9194 .35781 L
.93928 .33614 L
.95402 .31467 L
.9593 .30482 L
.96398 .29422 L
.96725 .28497 L
.96998 .27493 L
.97113 .26929 L
.97196 .26412 L
.97254 .25917 L
.97294 .25395 L
.97311 .2482 L
.97303 .24286 L
.97267 .23701 L
.97235 .23373 L
.97197 .23076 L
.97109 .22525 L
.97004 .22012 L
.96683 .2085 L
.96262 .19728 L
.95693 .1854 L
.9436 .16444 L
.92813 .14602 L
.90635 .12568 L
.87827 .10504 L
.81666 .07218 L
.77944 .05757 L
.7419 .04564 L
.70594 .03639 L
.66642 .0283 L
.64525 .02477 L
.62169 .02145 L
.59974 .01891 L
.57957 .01702 L
.55551 .01532 L
Mistroke
.54221 .01463 L
.5361 .01437 L
.5296 .01413 L
.51793 .01382 L
.50713 .01364 L
.49551 .01358 L
.4889 .01361 L
.4827 .01367 L
.47161 .01388 L
.4654 .01404 L
.45978 .01423 L
.43857 .01522 L
.42672 .01596 L
.41394 .01693 L
.39094 .01911 L
.3467 .02493 L
.30717 .03211 L
.27253 .04013 L
.23615 .05055 L
.16916 .07656 L
.13667 .09355 L
.10918 .11125 L
.08722 .12856 L
.06725 .14808 L
.04972 .17038 L
.03753 .19183 L
.03249 .204 L
.02889 .21554 L
.02732 .22219 L
.02621 .22831 L
.02572 .23179 L
.02535 .23504 L
.02505 .23843 L
.02484 .24214 L
.02473 .24809 L
.02478 .25109 L
.02492 .25439 L
.0254 .26022 L
.02609 .26566 L
.02722 .27205 L
.02855 .27788 L
.03256 .29089 L
.03712 .30196 L
.04326 .31385 L
.0575 .33492 L
.07486 .3544 L
.09706 .37402 L
.14588 .40589 L
.18013 .42264 L
.21447 .4363 L
Mistroke
.25412 .44908 L
.30032 .46071 L
.34251 .46876 L
.38311 .4745 L
.40594 .47693 L
.42693 .47868 L
.4386 .47945 L
.45132 .48014 L
.46337 .48065 L
.47452 .48099 L
.48507 .4812 L
.49616 .4813 L
.50564 .48129 L
.51599 .48118 L
.52718 .48094 L
.53344 .48076 L
.53911 .48055 L
.55026 .48006 L
.56052 .4795 L
.58027 .47811 L
.60151 .47617 L
.6395 .47148 L
.67975 .46469 L
.72235 .45519 L
.76458 .44306 L
.80155 .42974 L
.83493 .41497 L
.86788 .39701 L
.8937 .37968 L
.91754 .35986 L
.93555 .34102 L
.95154 .31923 L
.95719 .30943 L
.96236 .29871 L
.96635 .28843 L
.96921 .279 L
.97048 .27372 L
.97159 .26798 L
.97247 .2619 L
.97302 .25614 L
.97329 .25075 L
.97332 .24503 L
.97312 .24015 L
.97269 .23478 L
.97231 .23156 L
.97187 .2285 L
.97084 .22276 L
.96942 .21661 L
.96752 .20992 L
.96317 .19801 L
Mistroke
.95808 .1871 L
.94335 .1637 L
.92594 .1434 L
.90131 .12128 L
.87393 .10196 L
.81367 .07062 L
.77919 .05723 L
.73865 .0445 L
.70209 .0353 L
.66127 .02721 L
.62149 .02126 L
.58443 .0173 L
.56428 .01575 L
.55262 .01504 L
.5419 .0145 L
.53062 .01407 L
.52468 .01389 L
.51843 .01373 L
.50789 .01357 L
.49636 .0135 L
.4856 .01357 L
.47584 .01372 L
.46458 .01402 L
.45397 .01441 L
.43514 .01538 L
.41483 .01684 L
.39292 .01889 L
.36909 .02172 L
.32198 .02923 L
.27998 .03833 L
.24248 .04867 L
.20585 .06119 L
.16884 .07686 L
.13907 .09234 L
.11064 .11041 L
.08608 .12977 L
.06716 .14842 L
.05151 .16806 L
.03999 .1872 L
.03494 .19814 L
.03115 .20844 L
.02801 .21985 L
.02672 .22628 L
.02584 .23214 L
.02551 .23513 L
.02523 .2383 L
.02494 .24399 L
.02492 .25012 L
.02505 .2536 L
.02526 .25687 L
Mistroke
.02586 .26274 L
.02666 .2681 L
.02787 .27428 L
.02932 .28013 L
.03252 .29029 L
.03688 .30101 L
.04714 .31995 L
.06327 .34168 L
.08147 .36049 L
.10425 .3793 L
.13201 .39777 L
.1902 .42674 L
.22668 .44038 L
.26302 .45141 L
.30502 .46158 L
.32761 .46605 L
.3521 .47017 L
.37358 .47321 L
.39761 .47601 L
.4197 .47804 L
.44061 .4795 L
.4526 .48013 L
.46527 .48065 L
.4761 .48097 L
.48225 .4811 L
.48797 .48118 L
.49464 .48124 L
.50095 .48126 L
.51274 .48119 L
.51934 .48109 L
.52543 .48096 L
.53211 .48077 L
.53918 .48052 L
.56036 .47949 L
.5722 .47872 L
.58299 .47789 L
.62339 .47368 L
.64558 .47061 L
.66941 .46666 L
.71158 .4579 L
.75325 .44669 L
.79022 .43423 L
.85217 .40619 L
.88222 .38796 L
.90649 .36978 L
.92913 .34844 L
.9482 .32461 L
.95518 .31337 L
.96076 .30256 L
.96497 .29262 L
Mistroke
.96853 .28196 L
.96999 .27642 L
.9713 .27029 L
.97223 .2647 L
.97287 .25944 L
.97313 .25643 L
.97332 .25327 L
.97347 .2476 L
.97332 .24151 L
.97311 .23806 L
.97282 .23485 L
.97216 .22953 L
.97117 .22378 L
.96869 .2134 L
.96542 .20337 L
.96166 .19422 L
.95052 .17381 L
.9349 .15298 L
.91518 .13284 L
.89394 .11549 L
.86786 .09805 L
.83591 .08068 L
.80349 .06626 L
.77117 .05436 L
.70201 .03519 L
.65984 .02688 L
.63708 .0233 L
.61272 .02013 L
.59108 .01784 L
.56715 .01589 L
.55658 .01522 L
.54524 .01461 L
.53451 .01416 L
.52473 .01385 L
.5144 .01362 L
.50343 .0135 L
.49407 .01348 L
.48375 .01357 L
.47269 .01377 L
.46649 .01394 L
.46081 .01413 L
.44969 .01459 L
.43938 .01513 L
.41976 .01645 L
.3985 .01833 L
.36028 .02295 L
.31746 .03014 L
.27293 .04016 L
.23303 .05172 L
.1985 .06412 L
Mistroke
.13985 .09199 L
.11419 .10804 L
.08937 .12703 L
.0674 .14829 L
.05062 .16952 L
.03905 .18929 L
.03401 .2007 L
.03033 .21137 L
.02882 .21688 L
.02746 .22284 L
.02645 .22849 L
.02576 .23368 L
.02525 .23944 L
.02508 .2427 L
.025 .24574 L
.02507 .25188 L
.02525 .25532 L
.02549 .25844 L
.02581 .26156 L
.02624 .26486 L
.02724 .27077 L
.02863 .27711 L
.03055 .28405 L
.03497 .29637 L
.04025 .30775 L
.05381 .32959 L
.07323 .35237 L
.09579 .37266 L
.12014 .39024 L
.17431 .41974 L
.2087 .43392 L
.24206 .44525 L
.28001 .45576 L
.32199 .46493 L
.35912 .47117 L
.40089 .4763 L
.42482 .4784 L
.44678 .47981 L
.45897 .48039 L
.46542 .48063 L
.47226 .48085 L
.47823 .481 L
.48482 .48112 L
.49644 .48124 L
.50808 .48122 L
.51874 .48109 L
.53044 .48082 L
.53631 .48063 L
.54271 .48038 L
.56509 .47921 L
Mistroke
.58577 .47767 L
.60884 .47542 L
.62987 .47287 L
.67634 .46542 L
.71583 .45692 L
.75569 .446 L
.81909 .42253 L
.85126 .40676 L
.87845 .39055 L
.904 .37192 L
.92762 .35015 L
.94566 .32839 L
.95274 .31766 L
.95847 .30741 L
.96315 .29736 L
.96669 .28805 L
.96976 .27763 L
.97102 .27212 L
.97206 .26631 L
.97277 .26101 L
.97328 .25534 L
.97351 .24998 L
.97352 .24511 L
.97327 .23939 L
.97302 .23616 L
.97271 .23318 L
.97195 .22772 L
.97087 .22195 L
.96786 .21036 L
.96398 .19945 L
.95401 .17933 L
.93947 .15837 L
.9193 .13656 L
.89826 .11866 L
.8725 .10083 L
.81829 .07243 L
.78093 .05766 L
.74407 .04587 L
.70126 .03497 L
.65385 .02584 L
.63339 .02274 L
.61117 .01992 L
.59176 .01788 L
.57048 .01611 L
.55745 .01525 L
.54535 .0146 L
.53376 .01412 L
.52783 .01393 L
.52143 .01376 L
.51042 .01356 L
Mistroke
.50007 .01348 L
.49408 .01348 L
.48777 .01352 L
.4765 .01369 L
.46548 .01398 L
.45927 .01419 L
.45355 .01442 L
.43199 .01559 L
.4125 .01705 L
.39203 .01902 L
.35014 .02447 L
.30546 .0326 L
.26867 .04131 L
.23101 .05243 L
.16892 .07697 L
.13637 .09406 L
.10942 .11145 L
.08178 .13386 L
.06118 .15557 L
.04566 .17735 L
.03494 .19853 L
.03068 .21041 L
.02781 .22141 L
.02671 .2272 L
.02582 .23356 L
.0255 .23677 L
.02525 .24021 L
.0251 .24346 L
.02504 .24641 L
.02512 .25193 L
.02543 .2571 L
.02601 .26276 L
.02693 .26884 L
.02822 .27517 L
.02975 .28116 L
.03343 .29235 L
.04264 .31208 L
.05641 .33298 L
.07563 .35471 L
.10075 .37648 L
.15693 .41134 L
.1921 .42739 L
.22721 .44043 L
.26754 .45252 L
.31439 .46342 L
.35695 .47083 L
.39784 .47597 L
.42078 .47808 L
.44185 .47953 L
.45356 .48014 L
Mistroke
.45974 .48041 L
.46632 .48066 L
.47206 .48084 L
.4784 .481 L
.4896 .48118 L
.50044 .48125 L
.51053 .4812 L
.52161 .48104 L
.5278 .48089 L
.53343 .48073 L
.54479 .4803 L
.55708 .47969 L
.5793 .47821 L
.59982 .47638 L
.62135 .47398 L
.65931 .46847 L
.70182 .46021 L
.73997 .45065 L
.77933 .43827 L
.81919 .42252 L
.85355 .40555 L
.88213 .38815 L
.90807 .36859 L
.92812 .34968 L
.94446 .33011 L
.95663 .31098 L
.96163 .30095 L
.96597 .29023 L
.96786 .28458 L
.96962 .27835 L
.97087 .27303 L
.97193 .26736 L
.97278 .26129 L
.97329 .25568 L
.97355 .24963 L
.97357 .24618 L
.97349 .24296 L
.97315 .23715 L
.97258 .23184 L
.9717 .22603 L
.97047 .21992 L
.96758 .20934 L
.96407 .19958 L
.95317 .17785 L
.9453 .16596 L
.93675 .15499 L
.91793 .13522 L
.89372 .11519 L
.86319 .09516 L
.80259 .0658 L
Mistroke
.76378 .05184 L
.72509 .04068 L
.68218 .03093 L
.64145 .02389 L
.61844 .02077 L
.59305 .018 L
.56882 .01598 L
.55783 .01527 L
.54621 .01464 L
.53599 .0142 L
.52478 .01384 L
.51457 .01362 L
.50505 .0135 L
.49379 .01348 L
.48354 .01357 L
.47788 .01367 L
.47173 .0138 L
.46057 .01415 L
.45092 .01455 L
.44032 .01509 L
.41896 .01653 L
.39932 .01828 L
.38106 .02027 L
.33674 .02667 L
.29748 .03434 L
.25409 .04535 L
.2152 .05789 L
.1508 .08607 L
.11964 .10447 L
.09478 .12263 L
.07468 .14075 L
.05657 .16141 L
.04312 .18175 L
.03397 .20102 L
.03015 .21227 L
.02759 .22262 L
.02655 .22836 L
.02612 .23139 L
.02574 .23462 L
.02526 .24054 L
.02508 .24602 L
.02512 .25101 L
.0254 .25638 L
.02588 .26145 L
.02651 .26609 L
.02741 .27123 L
.02864 .27682 L
.03192 .28804 L
.03677 .30034 L
.04227 .31137 L
Mistroke
.05834 .33542 L
.07765 .35664 L
.09959 .37556 L
.15368 .40965 L
.18547 .42459 L
.22348 .43914 L
.25811 .44992 L
.29725 .45977 L
.33575 .4674 L
.372 .47293 L
.39334 .47549 L
.41362 .47747 L
.42493 .47839 L
.43719 .47924 L
.44742 .47984 L
.45866 .48037 L
.46935 .48076 L
.47934 .48102 L
.4899 .48119 L
.5012 .48125 L
.51173 .48119 L
.52168 .48104 L
.53061 .48082 L
.5403 .48049 L
.55171 .47998 L
.56239 .47939 L
.5866 .47762 L
.60998 .47532 L
.63485 .47222 L
.6788 .46499 L
.71761 .45653 L
.75469 .44636 L
.79205 .43366 L
.85239 .40621 L
.88425 .38673 L
.9103 .36671 L
.93015 .34754 L
.94762 .32569 L
.95423 .31528 L
.96026 .30393 L
.96458 .29399 L
.96834 .28306 L
.97013 .27636 L
.97146 .27014 L
.97243 .26418 L
.97281 .26117 L
.97315 .25783 L
.9735 .2521 L
.97359 .24887 L
.97359 .2459 L
Mistroke
.9734 .24045 L
.97294 .23471 L
.97214 .2286 L
.97116 .22306 L
.96971 .21668 L
.96802 .21068 L
.9643 .20009 L
.9592 .18873 L
.94362 .16364 L
.92449 .14155 L
.90398 .12309 L
.87838 .10452 L
.82366 .07478 L
.78556 .05928 L
.74655 .04655 L
.70583 .03598 L
.66729 .02812 L
.64725 .02477 L
.62526 .02163 L
.60603 .01933 L
.58473 .01724 L
.56187 .01552 L
.54932 .0148 L
.53758 .01427 L
.52656 .01389 L
.5165 .01366 L
.50489 .01351 L
.49388 .01349 L
.48445 .01356 L
.47406 .01375 L
.46321 .01406 L
.45305 .01446 L
.43497 .01542 L
.41557 .01681 L
.39422 .01881 L
.37197 .02141 L
.33294 .02734 L
.29163 .03568 L
.25565 .04492 L
.21886 .0566 L
.18166 .07122 L
.14998 .08652 L
.12346 .10201 L
.07961 .13595 L
.06142 .15535 L
.04584 .17713 L
.03981 .18798 L
.03503 .19841 L
.03123 .20879 L
.02857 .21826 L
Mistroke
.02729 .22418 L
.02636 .22977 L
.02564 .23567 L
.02537 .239 L
.0252 .24206 L
.02508 .24719 L
.0252 .25282 L
.02561 .25868 L
.02624 .26414 L
.02671 .26725 L
.02731 .27062 L
.02864 .27673 L
.03195 .28809 L
.03718 .30121 L
.04328 .31314 L
.05677 .33339 L
.07524 .35426 L
.11831 .38893 L
.15016 .40779 L
.18395 .42393 L
.22021 .438 L
.25534 .44913 L
.29164 .45849 L
.3326 .46684 L
.35576 .47064 L
.3774 .47362 L
.39967 .47616 L
.42066 .47806 L
.43883 .47935 L
.4584 .48036 L
.46959 .48077 L
.4802 .48104 L
.48974 .48119 L
.50012 .48125 L
.51021 .48121 L
.52135 .48105 L
.53298 .48075 L
.54388 .48035 L
.56327 .47934 L
.58407 .47784 L
.60506 .47586 L
.62727 .47325 L
.66653 .46725 L
.71164 .45798 L
.75075 .44756 L
.78929 .4347 L
.82797 .41856 L
.86087 .40146 L
.88837 .38387 L
.91236 .36493 L
Mistroke
.93107 .34654 L
.94803 .32511 L
.95567 .31278 L
.96157 .30114 L
.96617 .28977 L
.96986 .27754 L
.9714 .27051 L
.97201 .26705 L
.97249 .26387 L
.97315 .2579 L
.97338 .25475 L
.97354 .25143 L
.97359 .24575 L
.97336 .23967 L
.97286 .23394 L
.97217 .22872 L
.97108 .22262 L
.96954 .21601 L
.96583 .20409 L
.96149 .19349 L
.95576 .18223 L
.94268 .16237 L
.92273 .13978 L
.90046 .12028 L
.84352 .08435 L
.80991 .06878 L
.7699 .05383 L
.72949 .04181 L
.68934 .03237 L
.65189 .0255 L
.61017 .01979 L
.5881 .01754 L
.56363 .01563 L
.55124 .0149 L
.5379 .01428 L
.53143 .01405 L
.52528 .01386 L
.51375 .01361 L
.50294 .0135 L
.49144 .0135 L
.48163 .01361 L
.4708 .01384 L
.45923 .01421 L
.44676 .01476 L
.42428 .01614 L
.40326 .01791 L
.38098 .0203 L
.34152 .02589 L
.29608 .03468 L
.25654 .04467 L
Mistroke
.2175 .05709 L
.17815 .07278 L
.14453 .08948 L
.11627 .10675 L
.09151 .12536 L
.07204 .14348 L
.05417 .16466 L
.046 .17689 L
.03958 .18845 L
.03413 .20068 L
.03028 .2119 L
.02866 .21793 L
.02725 .22448 L
.02662 .22809 L
.02614 .23141 L
.02576 .23457 L
.02545 .23795 L
.02515 .24367 L
.0251 .24901 L
.02519 .25227 L
.02535 .25535 L
.02587 .26113 L
.02671 .2672 L
.02775 .2728 L
.03108 .28541 L
.0351 .29642 L
.03967 .30639 L
.05304 .32835 L
.06823 .34697 L
.08753 .36565 L
.1389 .40158 L
.17366 .41935 L
.2092 .43403 L
.24644 .44651 L
.28931 .45795 L
.33178 .4667 L
.37229 .47296 L
.40969 .47712 L
.43122 .47885 L
.45148 .48005 L
.46247 .48052 L
.47292 .48087 L
.48231 .48108 L
.49255 .48122 L
.50366 .48125 L
.50987 .48122 L
.51549 .48115 L
.52644 .48094 L
.53672 .48063 L
.54712 .48021 L
Mistroke
.55822 .47965 L
.57816 .47831 L
.6017 .47621 L
.62291 .47381 L
.66816 .46697 L
.70949 .45849 L
.77777 .43885 L
.81307 .42522 L
.84323 .41108 L
.87094 .39544 L
.89751 .37714 L
.91756 .36021 L
.93618 .34071 L
.94571 .32845 L
.95334 .31681 L
.95999 .30452 L
.9649 .29322 L
.96867 .28197 L
.97126 .2713 L
.97228 .2654 L
.97296 .25997 L
.97343 .25399 L
.97356 .25098 L
.97361 .24767 L
.97347 .24162 L
.97308 .23602 L
.97235 .22989 L
.97187 .2268 L
.97124 .22339 L
.96832 .21161 L
.96454 .20066 L
.95484 .18061 L
.94059 .15966 L
.92056 .13766 L
.89477 .11593 L
.86657 .09712 L
.83779 .08146 L
.77232 .05463 L
.73252 .04262 L
.69289 .03312 L
.65476 .02597 L
.61859 .02079 L
.59775 .01846 L
.57807 .01668 L
.55739 .01524 L
.54638 .01465 L
.53452 .01415 L
.52839 .01395 L
.52263 .01379 L
.51185 .01359 L
Mistroke
.50023 .01349 L
.49368 .01349 L
.48767 .01353 L
.47758 .01368 L
.46653 .01396 L
.45501 .01438 L
.44428 .01489 L
.41961 .0165 L
.39731 .0185 L
.37184 .02144 L
.34806 .02484 L
.30624 .03248 L
.26904 .04126 L
.23045 .05266 L
.19155 .06703 L
.15833 .0822 L
.13059 .09757 L
.08456 .1314 L
.0651 .15105 L
.04805 .17361 L
.04118 .18536 L
.03517 .19811 L
.03077 .21029 L
.02914 .21605 L
.02786 .22146 L
.02679 .22706 L
.02604 .23219 L
.02546 .23789 L
.02514 .24401 L
.02512 .24988 L
.02523 .2532 L
.02542 .25628 L
.02596 .26191 L
.02682 .26788 L
.02789 .27342 L
.02932 .27938 L
.03267 .2901 L
.03684 .30044 L
.04146 .30981 L
.05494 .33095 L
.07409 .3531 L
.09873 .37486 L
.12567 .39367 L
.15542 .41052 L
.1912 .42698 L
.22543 .43979 L
.26411 .45157 L
.30076 .46054 L
.34277 .46859 L
.38217 .47421 L
Mistroke
.40034 .47623 L
.41986 .478 L
.43177 .47889 L
.4426 .47958 L
.45365 .48015 L
.46383 .48058 L
.47577 .48094 L
.48206 .48108 L
.4887 .48118 L
.49989 .48126 L
.50624 .48125 L
.51217 .4812 L
.52358 .48101 L
.53438 .48071 L
.54407 .48035 L
.55458 .47985 L
.57805 .47832 L
.5996 .47643 L
.63659 .472 L
.67644 .46545 L
.71664 .45679 L
.75274 .44697 L
.82298 .42087 L
.85427 .4052 L
.88494 .38628 L
.90798 .36872 L
.92905 .34875 L
.94538 .32891 L
.95709 .31021 L
.96217 .29983 L
.9667 .28827 L
.96855 .2824 L
.97022 .27607 L
.9714 .27058 L
.9724 .26459 L
.97309 .25864 L
.97348 .25312 L
.97361 .24784 L
.9735 .24223 L
.97315 .23671 L
.97258 .23152 L
.97188 .22687 L
.97093 .22186 L
.96792 .21029 L
.96335 .19774 L
.95719 .18482 L
.95016 .17298 L
.9346 .15241 L
.91385 .13145 L
.86122 .09398 L
Mistroke
.82543 .07557 L
.78896 .06052 L
.71488 .03811 L
.67465 .02947 L
.65284 .02565 L
.62862 .02207 L
.60798 .01954 L
.58572 .01733 L
.57331 .01631 L
.56201 .01553 L
.55048 .01486 L
.53984 .01436 L
.52993 .014 L
.51943 .01372 L
.50889 .01355 L
.4973 .01349 L
.48729 .01354 L
.47655 .01371 L
.46642 .01397 L
.45719 .01429 L
.44572 .01481 L
.43355 .01551 L
.41179 .01714 L
.38858 .01943 L
.36325 .02259 L
.319 .02991 L
.27894 .03873 L
.20485 .06176 L
.17117 .07598 L
.13757 .09343 L
.11179 .10984 L
.08757 .12874 L
.06939 .14629 L
.05337 .16578 L
.04602 .17686 L
.03918 .18928 L
.03406 .20088 L
.03038 .21161 L
.02873 .21769 L
.02728 .22435 L
.02664 .22801 L
.02614 .23141 L
.02574 .23487 L
.02545 .23813 L
.02525 .24117 L
.02513 .24447 L
.02513 .25021 L
.02525 .25347 L
.02547 .25691 L
.02573 .25985 L
Mistroke
.02611 .26307 L
.02708 .26933 L
.0283 .27524 L
.03135 .28625 L
.03577 .29799 L
.04187 .31057 L
.0562 .33262 L
.07316 .35215 L
.09336 .37056 L
.11866 .38915 L
.17291 .41901 L
.20876 .43386 L
.24948 .44742 L
.29001 .45811 L
.32849 .4661 L
.37019 .47269 L
.41051 .4772 L
.43296 .47897 L
.45378 .48016 L
.46471 .48061 L
.47099 .48082 L
.47674 .48097 L
.4828 .4811 L
.48932 .48119 L
.50109 .48126 L
.51122 .48121 L
.52199 .48105 L
.53214 .48079 L
.54133 .48046 L
.55215 .47997 L
.56382 .47932 L
.58485 .47778 L
.60473 .4759 L
.62551 .47348 L
.66205 .46804 L
.70327 .45992 L
.73929 .45088 L
.77617 .43941 L
.8136 .425 L
.84547 .40993 L
.87227 .39461 L
.9168 .36093 L
.93529 .34176 L
.95128 .32016 L
.95752 .3094 L
.96252 .29903 L
.96655 .2887 L
.96943 .27925 L
.97075 .27376 L
.9719 .26781 L
Mistroke
.97241 .26453 L
.97279 .26151 L
.97334 .25556 L
.97358 .25045 L
.97359 .24483 L
.97332 .23896 L
.97282 .23349 L
.97243 .2304 L
.97191 .22703 L
.97073 .22092 L
.96769 .20954 L
.96278 .19639 L
.95696 .18439 L
.94403 .16415 L
.92615 .14322 L
.88408 .10831 L
.85446 .09016 L
.81953 .07291 L
.7837 .0586 L
.74884 .04722 L
.71301 .03766 L
.67243 .02905 L
.64949 .02512 L
.62799 .02199 L
.60585 .01931 L
.58491 .01726 L
.56687 .01585 L
.54738 .01471 L
.53624 .01422 L
.52565 .01387 L
.51613 .01366 L
.50574 .01352 L
.49462 .01349 L
.48455 .01357 L
.47293 .01379 L
.46201 .01411 L
.45188 .01452 L
.44259 .01498 L
.4217 .01634 L
.40004 .01823 L
.38049 .02036 L
.33733 .02659 L
.29858 .03413 L
.26327 .04281 L
.19034 .06754 L
.15371 .08458 L
.12327 .10215 L
.09902 .11929 L
.07643 .13905 L
.05866 .15878 L
Mistroke
.04557 .17759 L
.03985 .18794 L
.03475 .19914 L
.03039 .21157 L
.02874 .21763 L
.02749 .22323 L
.0264 .22957 L
.02596 .23291 L
.02559 .23645 L
.0252 .24241 L
.02511 .2458 L
.02511 .24896 L
.02533 .25485 L
.02578 .26023 L
.02613 .2632 L
.02659 .26642 L
.02765 .27228 L
.03034 .28298 L
.0343 .29442 L
.04423 .31477 L
.05158 .32628 L
.06056 .33814 L
.0797 .35857 L
.1296 .39609 L
.16393 .41476 L
.19935 .43026 L
.23578 .4432 L
.27792 .45518 L
.31981 .46447 L
.35993 .47126 L
.39702 .47588 L
.41841 .47788 L
.43859 .47934 L
.44953 .47995 L
.45995 .48043 L
.46932 .48077 L
.47956 .48103 L
.49066 .48121 L
.49686 .48125 L
.50249 .48126 L
.51346 .48119 L
.52378 .48101 L
.53414 .48072 L
.54523 .4803 L
.56518 .47923 L
.58876 .47744 L
.61007 .47533 L
.65559 .46912 L
.69735 .46123 L
.73413 .4523 L
Mistroke
.76663 .44262 L
.83367 .41586 L
.86216 .40073 L
.88973 .38291 L
.91073 .36637 L
.93047 .34721 L
.94821 .32485 L
.9555 .3131 L
.96195 .30032 L
.96674 .28815 L
.97001 .27697 L
.97121 .27155 L
.97224 .26567 L
.97295 .2601 L
.97338 .25495 L
.9736 .24912 L
.97356 .24359 L
.9733 .23862 L
.97279 .23322 L
.97197 .22737 L
.97078 .22116 L
.96785 .21005 L
.96383 .19888 L
.9591 .1885 L
.94784 .1695 L
.93028 .14758 L
.91042 .12845 L
.88496 .10891 L
.8536 .08969 L
.82124 .07367 L
.78919 .06061 L
.72044 .03948 L
.67908 .03032 L
.65662 .02627 L
.63237 .02259 L
.6109 .01987 L
.58697 .01744 L
.56501 .01573 L
.5443 .01456 L
.53378 .01413 L
.52254 .01379 L
.51193 .01359 L
.50229 .0135 L
.49092 .01351 L
.48452 .01357 L
.47863 .01367 L
.4678 .01393 L
.45637 .01433 L
.44541 .01483 L
.43369 .01551 L
Mistroke
.41264 .01707 L
.38781 .01952 L
.36542 .02229 L
.32681 .02845 L
.28617 .03697 L
.21709 .05725 L
.18316 .07059 L
.15367 .0846 L
.12193 .10301 L
.09631 .12144 L
.07486 .14061 L
.05556 .1628 L
.04077 .18614 L
.03472 .19921 L
.03246 .20518 L
.0304 .21154 L
.02883 .21729 L
.02741 .22364 L
.02642 .22943 L
.02574 .23486 L
.02545 .23814 L
.02525 .24126 L
.0251 .24711 L
.02513 .25038 L
.02525 .25341 L
.02546 .25674 L
.02578 .26028 L
.02656 .26626 L
.02774 .2727 L
.03074 .28432 L
.03474 .29552 L
.03933 .3057 L
.0505 .32471 L
.06629 .34482 L
.08656 .3648 L
.10878 .38235 L
.13634 .40011 L
.16999 .41765 L
.20252 .4315 L
.23968 .44443 L
.27508 .45446 L
.31601 .46372 L
.35463 .47047 L
.39182 .47533 L
.41313 .47744 L
.43311 .47898 L
.44444 .47968 L
.45516 .48022 L
.4611 .48048 L
.46754 .48071 L
Mistroke
.47881 .48102 L
.48994 .4812 L
.49627 .48125 L
.50219 .48126 L
.50843 .48123 L
.51412 .48118 L
.5207 .48107 L
.52693 .48093 L
.53792 .48059 L
.5481 .48017 L
.57105 .47884 L
.59242 .47711 L
.61235 .47507 L
.64901 .47016 L
.68747 .4633 L
.72746 .45407 L
.76687 .44254 L
.80576 .42829 L
Mfstroke
.92256 .35428 m
.93982 .33491 L
.95274 .31614 L
.95865 .30531 L
.9633 .29493 L
.96752 .28284 L
.96896 .27758 L
.97029 .27176 L
.9713 .26606 L
.97201 .26071 L
.97251 .25506 L
.97274 .24897 L
.97268 .24333 L
.97238 .23798 L
.97191 .23318 L
.97118 .22795 L
.97001 .22172 L
.96868 .21609 L
.96472 .20357 L
.95988 .1921 L
.9543 .18145 L
.93922 .15941 L
.91872 .13722 L
.89768 .11934 L
.87107 .10103 L
.83862 .083 L
.79988 .06577 L
.7603 .05174 L
.72124 .04064 L
.68143 .03166 L
.63748 .02411 L
.61576 .02119 L
.59205 .0186 L
.57837 .01737 L
.56576 .01641 L
.55375 .01564 L
.54088 .01497 L
.5296 .01453 L
.51933 .01423 L
.50899 .01403 L
.49923 .01394 L
.48783 .01396 L
.47733 .01408 L
.46581 .01435 L
.46001 .01453 L
.45364 .01477 L
.43086 .01595 L
.41814 .01684 L
.40656 .0178 L
.38372 .0201 L
Mistroke
.36326 .02265 L
.3228 .02913 L
.28122 .03798 L
.21151 .05887 L
.17593 .0733 L
.14088 .09093 L
.1116 .10927 L
.08772 .12779 L
.06686 .1481 L
.05131 .16755 L
.03809 .19 L
.03267 .20265 L
.03068 .20839 L
.0288 .21475 L
.0274 .22045 L
.0262 .22659 L
.02567 .22999 L
.02526 .23311 L
.0247 .23922 L
.02447 .24451 L
.02447 .25029 L
.02476 .25632 L
.0253 .26191 L
.02572 .26512 L
.02627 .26859 L
.02753 .27487 L
.03075 .28655 L
.03592 .30002 L
.04201 .31225 L
.05548 .33282 L
.07394 .35395 L
.1171 .38899 L
.14912 .40807 L
.18303 .42433 L
.21584 .43721 L
.25459 .44962 L
.29125 .45907 L
.33251 .46743 L
.35586 .47122 L
.37761 .47418 L
.4 .47668 L
.42105 .47855 L
.43935 .4798 L
.44878 .48031 L
.45902 .48077 L
.47028 .48115 L
.48092 .48139 L
.4913 .48152 L
.50087 .48155 L
.51095 .48148 L
Mistroke
.52039 .48133 L
.53073 .48106 L
.54183 .48065 L
.55341 .48009 L
.56439 .47944 L
.58489 .47789 L
.6076 .47566 L
.62877 .47308 L
.66758 .46701 L
.70802 .45868 L
.74979 .44761 L
.78443 .43618 L
.81864 .42242 L
.87284 .39374 L
.89888 .3755 L
.91949 .35774 L
.93935 .33606 L
.95407 .31458 L
.95934 .30472 L
.96401 .29412 L
.96725 .28498 L
.97 .27483 L
.97116 .26912 L
.97199 .26389 L
.97264 .25813 L
.97302 .25206 L
.97311 .24676 L
.97298 .24183 L
.97262 .23643 L
.97196 .23066 L
.97104 .22497 L
.96971 .21874 L
.96606 .20622 L
.96151 .19475 L
.95625 .18417 L
.94093 .16094 L
.91932 .13721 L
.8944 .11633 L
.86691 .09796 L
.80631 .06786 L
.77038 .05452 L
.73578 .044 L
.69662 .03437 L
.6525 .026 L
.63201 .02291 L
.61012 .02013 L
.58963 .01799 L
.57038 .01639 L
.55219 .01521 L
.54283 .01474 L
Mistroke
.53265 .01432 L
.52148 .01398 L
.5109 .01377 L
.50059 .01368 L
.49107 .01368 L
.47996 .01379 L
.4694 .01401 L
.45993 .01431 L
.44961 .01473 L
.42661 .01605 L
.40538 .01775 L
.3673 .02201 L
.32762 .02821 L
.28201 .03781 L
.24112 .04903 L
.20674 .06077 L
.17158 .07546 L
.11345 .10826 L
.08717 .1286 L
.0665 .1489 L
.05074 .16887 L
.03952 .18774 L
.03465 .19838 L
.03043 .2101 L
.02889 .2155 L
.02751 .22127 L
.02648 .22664 L
.02573 .23166 L
.02516 .23695 L
.0248 .24275 L
.02472 .24841 L
.02492 .25445 L
.02538 .26007 L
.02604 .26538 L
.02684 .27013 L
.02791 .27527 L
.0312 .28702 L
.03593 .29933 L
.04755 .32094 L
.06185 .3403 L
.07818 .35767 L
.12527 .39389 L
.15472 .4106 L
.19026 .427 L
.22426 .43978 L
.26286 .45158 L
.30317 .46139 L
.34117 .4686 L
.3805 .47425 L
.39867 .47628 L
Mistroke
.41829 .47807 L
.43963 .47958 L
.44921 .4801 L
.45964 .48057 L
.46601 .4808 L
.4719 .48098 L
.48352 .48124 L
.49409 .48135 L
.50531 .48135 L
.51621 .48124 L
.52793 .48098 L
.53899 .48062 L
.5491 .48018 L
.57249 .47876 L
.59691 .47669 L
.63659 .47195 L
.67261 .46608 L
.7109 .45803 L
.75002 .44762 L
.8234 .42043 L
.85962 .4019 L
.88917 .38299 L
.91353 .36353 L
.93279 .34421 L
.94907 .32306 L
.95654 .31063 L
.96226 .29892 L
.96651 .28793 L
.96992 .27612 L
.97122 .26998 L
.97216 .26419 L
.97258 .26088 L
.97288 .25783 L
.97312 .25449 L
.97328 .25096 L
.97332 .24548 L
.97308 .23962 L
.9726 .2341 L
.97195 .22909 L
.97092 .22321 L
.96947 .21684 L
.96599 .20537 L
.96199 .19529 L
.9566 .18433 L
.94259 .16272 L
.92604 .14352 L
.90754 .12639 L
.88282 .10781 L
.85199 .08914 L
.82174 .0742 L
Mistroke
.78666 .05996 L
.74938 .04764 L
.71368 .03805 L
.67907 .03052 L
.63981 .02382 L
.59767 .0186 L
.57429 .01651 L
.56301 .01571 L
.55229 .01506 L
.54238 .01457 L
.53159 .01414 L
.52176 .01385 L
.51266 .01367 L
.50284 .01357 L
.492 .01356 L
.48069 .01367 L
.47007 .0139 L
.45923 .01424 L
.4474 .01475 L
.42366 .01619 L
.40182 .01803 L
.38169 .02018 L
.33699 .02658 L
.29089 .03575 L
.2489 .04676 L
.21235 .05878 L
.17574 .07368 L
.13919 .09228 L
.08777 .12829 L
.06563 .15012 L
.04907 .17165 L
.03677 .19388 L
.03171 .20672 L
.02978 .21291 L
.02825 .21876 L
.02706 .22435 L
.02606 .23041 L
.02542 .23593 L
.02505 .241 L
.02489 .24651 L
.02499 .25256 L
.02516 .2556 L
.02542 .25886 L
.02612 .26472 L
.02708 .27049 L
.02821 .27579 L
.03162 .28773 L
.0356 .29814 L
.04081 .30906 L
.0522 .32754 L
Mistroke
.06813 .34717 L
.08998 .36803 L
.11449 .38661 L
.1694 .4176 L
.20451 .43246 L
.2396 .4446 L
.28016 .45591 L
.32638 .46585 L
.34886 .4697 L
.37303 .47317 L
.39571 .47584 L
.41713 .47786 L
.43733 .47933 L
.44774 .47993 L
.45911 .48045 L
.46558 .48069 L
.47157 .48088 L
.47718 .48103 L
.48339 .48115 L
.49414 .48127 L
.50557 .48128 L
.51604 .48117 L
.52705 .48094 L
.53645 .48065 L
.54672 .48024 L
.56957 .47893 L
.59072 .47724 L
.62861 .47303 L
.6682 .4669 L
.71191 .45783 L
.75043 .44755 L
.78952 .43449 L
.82925 .41782 L
.88692 .38472 L
.91292 .36424 L
.93334 .34377 L
.94963 .32244 L
.95657 .31084 L
.96268 .29826 L
.96728 .28602 L
.97035 .27483 L
.97146 .26939 L
.97239 .26351 L
.973 .25794 L
.97334 .25281 L
.97346 .24782 L
.97336 .24248 L
.97305 .23744 L
.97259 .23285 L
.97183 .22748 L
Mistroke
.97073 .22166 L
.96801 .21113 L
.96419 .20021 L
.95905 .18875 L
.94705 .16864 L
.93038 .14792 L
.91178 .12983 L
.8884 .11149 L
.85911 .09294 L
.80176 .06559 L
.76684 .05295 L
.73241 .0427 L
.69191 .03301 L
.64616 .02468 L
.62463 .02162 L
.60156 .01891 L
.58142 .01701 L
.57026 .01614 L
.55963 .01542 L
.54947 .01485 L
.53838 .01434 L
.52829 .01398 L
.51892 .01373 L
.5092 .01357 L
.50041 .01351 L
.49025 .01352 L
.48071 .01363 L
.47011 .01386 L
.45895 .01422 L
.44943 .01462 L
.43903 .01517 L
.41591 .01677 L
.39453 .01876 L
.35112 .02432 L
.30542 .03259 L
.26406 .04251 L
.22778 .05346 L
.1652 .07869 L
.13718 .09353 L
.10943 .11137 L
.08441 .13138 L
.06443 .15163 L
.04983 .17068 L
.03764 .19222 L
.0325 .20472 L
.02899 .21617 L
.02751 .22256 L
.02687 .22592 L
.02629 .22949 L
.02587 .23261 L
Mistroke
.02551 .23605 L
.02509 .24209 L
.02498 .2482 L
.02515 .25378 L
.02535 .25685 L
.02565 .2602 L
.02645 .26627 L
.02746 .27193 L
.02883 .27792 L
.03202 .28862 L
.03627 .29943 L
.04179 .31066 L
.0543 .33028 L
.07145 .35055 L
.09437 .37154 L
.11758 .38857 L
.14554 .40542 L
.2033 .4319 L
.24224 .44532 L
.28038 .45587 L
.32433 .46539 L
.34746 .46941 L
.37274 .47307 L
.39519 .47573 L
.41592 .47771 L
.43692 .47926 L
.45697 .48032 L
.46827 .48075 L
.47459 .48093 L
.48032 .48106 L
.49149 .48122 L
.50201 .48126 L
.508 .48124 L
.51432 .48117 L
.52563 .48096 L
.53192 .48079 L
.53779 .48059 L
.55109 .48001 L
.56232 .47939 L
.5742 .47859 L
.59541 .47681 L
.61802 .47438 L
.64264 .47108 L
.68564 .46361 L
.72446 .45477 L
.79183 .43368 L
.82622 .41929 L
.85516 .40462 L
.88222 .38804 L
.90763 .3689 L
Mistroke
.92652 .3513 L
.94355 .33127 L
.95217 .31858 L
.95885 .30666 L
.96399 .29532 L
.96837 .28271 L
.96986 .27721 L
.97118 .27129 L
.97215 .26569 L
.97281 .26057 L
.9733 .25479 L
.97346 .25152 L
.97352 .24849 L
.97345 .24293 L
.97309 .23703 L
.97253 .23178 L
.97165 .22603 L
.97045 .22005 L
.96906 .2145 L
.96594 .20462 L
.9617 .19415 L
.94859 .17075 L
.93263 .1503 L
.91435 .13201 L
.89105 .1133 L
.8403 .0828 L
.80826 .06816 L
.77591 .05592 L
.73485 .0433 L
.69519 .03366 L
.65195 .02554 L
.60954 .01974 L
.58592 .01736 L
.56381 .01566 L
.55101 .0149 L
.53938 .01435 L
.53291 .01411 L
.52592 .01389 L
.51931 .01372 L
.51323 .01361 L
.50194 .0135 L
.49126 .0135 L
.48166 .01361 L
.47124 .01382 L
.45992 .01418 L
.44793 .01469 L
.42647 .01597 L
.40683 .01756 L
.38854 .01941 L
.3475 .02489 L
Mistroke
.30416 .03288 L
.266 .04202 L
.2265 .05392 L
.18715 .06881 L
.15361 .08455 L
.12597 .10035 L
.08064 .13491 L
.06074 .1561 L
.05195 .16768 L
.04396 .18021 L
.0381 .19136 L
.03289 .2038 L
.03102 .2093 L
.02929 .21524 L
.02794 .22078 L
.02691 .22601 L
.02642 .229 L
.02598 .23222 L
.02541 .23786 L
.0252 .24106 L
.02507 .24444 L
.02507 .25048 L
.02535 .25608 L
.02583 .2613 L
.02662 .26701 L
.02776 .27311 L
.02934 .27967 L
.03146 .28677 L
.03637 .29954 L
.04247 .31179 L
.04922 .32291 L
.06438 .34274 L
.08505 .36355 L
.11065 .38376 L
.13865 .4015 L
.1686 .41706 L
.20442 .43227 L
.27392 .4542 L
.31627 .4638 L
.34028 .4682 L
.36332 .47176 L
.38514 .47458 L
.40904 .47708 L
.43097 .47884 L
.45127 .48004 L
.46248 .48053 L
.47312 .48088 L
.48269 .48109 L
.4931 .48122 L
.50442 .48125 L
Mistroke
.51013 .48121 L
.51644 .48114 L
.52757 .48091 L
.53801 .48058 L
.54789 .48017 L
.55828 .47963 L
.57677 .47841 L
.59656 .4767 L
.61802 .47439 L
.66225 .46798 L
.70789 .45883 L
.74897 .44806 L
.78428 .43651 L
.81804 .42303 L
.8509 .407 L
.90133 .3741 L
.92412 .35381 L
.94174 .33373 L
.95676 .31072 L
.96315 .29745 L
.96767 .28516 L
.96939 .27922 L
.97074 .27362 L
.97173 .26851 L
.97255 .2631 L
.97318 .25718 L
.97349 .25174 L
.97356 .24588 L
.97347 .24256 L
.97331 .23946 L
.97283 .23394 L
.97214 .22873 L
.97133 .22407 L
.97025 .21901 L
.96706 .20773 L
.96317 .19741 L
.95209 .17609 L
.93543 .15344 L
.91329 .13101 L
.88837 .11134 L
.83078 .0781 L
.7974 .06376 L
.75802 .05003 L
.72213 .03993 L
.68202 .03091 L
.64275 .02409 L
.60616 .01935 L
.58591 .01735 L
.56348 .01563 L
.55213 .01495 L
Mistroke
.5399 .01437 L
.52834 .01395 L
.51777 .01368 L
.50729 .01353 L
.49757 .01348 L
.48691 .01354 L
.47557 .01372 L
.46578 .01398 L
.45659 .0143 L
.43569 .01537 L
.42496 .01608 L
.41326 .017 L
.38982 .01927 L
.34858 .02474 L
.30193 .03337 L
.26035 .04358 L
.22229 .05539 L
.18376 .07029 L
.15253 .08515 L
.12258 .10255 L
.09863 .11955 L
.07584 .13959 L
.05857 .15884 L
.04553 .17761 L
.03962 .18832 L
.03441 .19991 L
.03193 .20664 L
.03 .21277 L
.02837 .21903 L
.02716 .22481 L
.02626 .23032 L
.02558 .23615 L
.02518 .242 L
.02508 .24533 L
.02507 .24843 L
.02525 .25405 L
.02564 .25917 L
.02635 .26507 L
.02729 .27065 L
.02972 .28095 L
.03326 .2918 L
.04206 .31099 L
.05497 .33103 L
.07321 .35224 L
.09475 .37173 L
.12124 .39087 L
.17745 .42109 L
.21313 .43549 L
.24871 .44721 L
.29004 .45813 L
Mistroke
.33637 .46751 L
.35831 .47103 L
.38189 .47418 L
.40251 .47645 L
.42487 .47839 L
.43748 .47927 L
.44905 .47993 L
.46071 .48046 L
.47179 .48084 L
.47803 .48099 L
.48467 .48112 L
.49095 .4812 L
.49663 .48124 L
.50334 .48125 L
.51058 .48121 L
.51742 .48112 L
.52371 .481 L
.53413 .48071 L
.54527 .48029 L
.5653 .47921 L
.58898 .47741 L
.61035 .47528 L
.65601 .46903 L
.69785 .4611 L
.73466 .45213 L
.77324 .44039 L
.80846 .42715 L
.8434 .41098 L
.87286 .39421 L
.89693 .37756 L
.91855 .35926 L
.93527 .34175 L
.95056 .32125 L
.95693 .31046 L
.96269 .29859 L
.96696 .28744 L
.96996 .27707 L
.97111 .27193 L
.97199 .26711 L
.9727 .26207 L
.97325 .25653 L
.97355 .25056 L
.97359 .24718 L
.97355 .24406 L
.97326 .23833 L
.97265 .23224 L
.97186 .22683 L
.97089 .22176 L
.96789 .21026 L
.96345 .19802 L
Mistroke
.95827 .18693 L
.94283 .16259 L
.92571 .1428 L
.90356 .12276 L
.85438 .09014 L
.81904 .07271 L
.78243 .05816 L
.7475 .04684 L
.70689 .03622 L
.66564 .02783 L
.62572 .02169 L
.60327 .01903 L
.58254 .01705 L
.57102 .01614 L
.55841 .01531 L
.54655 .01466 L
.53535 .01418 L
.52495 .01385 L
.51368 .01361 L
.50344 .0135 L
.49402 .01349 L
.4838 .01358 L
.47259 .01379 L
.46091 .01414 L
.45002 .0146 L
.43013 .01573 L
.41211 .01711 L
.37209 .02139 L
.35246 .02415 L
.33111 .02766 L
.28904 .03628 L
.21847 .05674 L
.1823 .07094 L
.14667 .0883 L
.1168 .10638 L
.09239 .12461 L
.07077 .1448 L
.05458 .1641 L
.04061 .18641 L
.0348 .19898 L
.03055 .21098 L
.02756 .2228 L
.0265 .22878 L
.02602 .23222 L
.02567 .23537 L
.02525 .241 L
.02508 .24705 L
.02519 .25265 L
.02554 .25797 L
.02623 .2641 L
Mistroke
.02675 .26751 L
.0273 .2706 L
.0301 .28224 L
.03217 .28873 L
.03479 .29569 L
.04056 .30815 L
.05408 .3298 L
.07028 .34918 L
.09187 .36936 L
.11914 .38949 L
.15206 .40879 L
.18683 .42516 L
.22048 .4381 L
.2601 .45047 L
.29715 .45975 L
.33869 .46791 L
.36222 .47159 L
.38406 .47444 L
.40653 .47683 L
.42758 .47859 L
.44694 .47982 L
.4578 .48034 L
.46767 .48071 L
.47855 .48101 L
.49033 .4812 L
.50146 .48126 L
.5117 .4812 L
.52131 .48105 L
.53028 .48084 L
.54011 .4805 L
.55063 .48004 L
.57203 .47876 L
.59142 .4772 L
.63317 .47246 L
.65388 .46938 L
.67639 .46545 L
.74985 .44783 L
.78806 .43516 L
.82624 .41936 L
.8588 .40265 L
.88597 .38555 L
.91061 .36646 L
.92973 .348 L
.9471 .32645 L
.95493 .31408 L
.96097 .30246 L
.96573 .29098 L
.96956 .27869 L
.97105 .27228 L
.97214 .26626 L
Mistroke
.97262 .26287 L
.97299 .25965 L
.9733 .25593 L
.97349 .25252 L
.9736 .24679 L
.97342 .2407 L
.97297 .23495 L
.97233 .22975 L
.97128 .22362 L
.9698 .21703 L
.96621 .20516 L
.96189 .19438 L
.95617 .18298 L
.9431 .16293 L
.92307 .14013 L
.90081 .12056 L
.87377 .10156 L
.84031 .08273 L
.80544 .06694 L
.77001 .05387 L
.73261 .04264 L
.69663 .03392 L
.65509 .02602 L
.6313 .02244 L
.60888 .01964 L
.58645 .01739 L
.56593 .01579 L
.55492 .0151 L
.54298 .0145 L
.53639 .01422 L
.53033 .01401 L
.52456 .01384 L
.51838 .0137 L
.50686 .01353 L
.4961 .01349 L
.48953 .01352 L
.4833 .01358 L
.47163 .01382 L
.46569 .01398 L
.45937 .0142 L
.44803 .01469 L
.43586 .01537 L
.42246 .01628 L
.40189 .01804 L
.37956 .02047 L
.33538 .02692 L
.29578 .03474 L
.26032 .04361 L
.18662 .06909 L
.15005 .08649 L
Mistroke
.12023 .10411 L
.09542 .12214 L
.0729 .14259 L
.05692 .161 L
.04296 .18209 L
.03685 .19421 L
.03236 .20545 L
.03034 .21171 L
.02851 .21856 L
.02714 .22506 L
.02617 .23111 L
.02551 .23722 L
.02517 .24298 L
.02509 .24815 L
.02525 .25374 L
.02573 .25985 L
.02608 .26292 L
.02656 .26628 L
.02763 .27223 L
.0289 .27776 L
.03251 .28968 L
.0369 .30058 L
.05049 .3247 L
.06655 .34512 L
.08762 .36573 L
.13308 .3982 L
.1636 .41461 L
.19497 .42852 L
.26774 .45255 L
.3074 .46197 L
.35259 .47016 L
.39252 .4754 L
.41523 .47762 L
.43602 .47917 L
.45556 .48024 L
.46661 .48067 L
.47681 .48097 L
.48575 .48114 L
.49559 .48124 L
.50586 .48125 L
.51547 .48116 L
.52665 .48094 L
.53289 .48076 L
.53853 .48057 L
.55983 .47955 L
.57173 .47879 L
.58454 .4778 L
.60759 .47559 L
.65193 .4697 L
.69147 .46247 L
Mistroke
.72618 .45439 L
.76255 .44393 L
.82943 .41788 L
.862 .40081 L
.88949 .38308 L
.91144 .36574 L
.93135 .34624 L
.94883 .32392 L
.96095 .3025 L
.96597 .29035 L
.96953 .27883 L
.97107 .2722 L
.97217 .26611 L
.97264 .26274 L
.97305 .25906 L
.97333 .25558 L
.97351 .25234 L
.97361 .24638 L
.97354 .24337 L
.97339 .24007 L
.9729 .23423 L
.97219 .22879 L
.97104 .22239 L
.96969 .21657 L
.96565 .20358 L
.96104 .19251 L
.95486 .18064 L
.94057 .15963 L
.92312 .14017 L
.90087 .1206 L
.85203 .08884 L
.82104 .07359 L
.79023 .06099 L
.7548 .04901 L
.71368 .03782 L
.67862 .03023 L
.6399 .02366 L
.61803 .02072 L
.59792 .01848 L
.57743 .01663 L
.55812 .01529 L
.54744 .01471 L
.53765 .01427 L
.52676 .0139 L
.51503 .01364 L
.5038 .01351 L
.49744 .01349 L
.49155 .0135 L
.48075 .01363 L
.46925 .01388 L
Mistroke
.45861 .01423 L
.44712 .01474 L
.42639 .01599 L
.40633 .01763 L
.38804 .01949 L
.34655 .02508 L
.30244 .03329 L
.25839 .04416 L
.21957 .05636 L
.18428 .0701 L
.1491 .087 L
.12117 .1035 L
.09497 .12252 L
.07468 .14078 L
.05613 .16204 L
.0429 .1822 L
.03375 .20166 L
.03002 .21283 L
.02748 .22329 L
.02643 .22933 L
.02574 .23483 L
.02546 .23787 L
.02525 .24118 L
.02509 .24717 L
.02522 .25298 L
.02542 .25628 L
.02568 .25935 L
.02605 .2626 L
.02645 .26555 L
.02763 .27219 L
.02892 .27782 L
.03062 .28392 L
.0345 .29494 L
.04482 .31577 L
.05979 .3372 L
.07756 .35652 L
.09654 .37313 L
.12177 .39119 L
.15189 .40869 L
.21375 .4357 L
.25203 .44817 L
.28974 .45805 L
.33301 .46692 L
.35612 .47069 L
.38103 .47407 L
.40302 .47649 L
.42749 .47859 L
.43828 .47932 L
.44992 .47997 L
.46085 .48046 L
Mistroke
.47102 .48082 L
.47715 .48098 L
.48368 .48111 L
.49094 .48121 L
.49751 .48125 L
.50375 .48126 L
.51049 .48122 L
.51685 .48114 L
.52271 .48103 L
.53366 .48074 L
.53987 .48052 L
.54566 .48028 L
.55724 .4797 L
.5698 .47892 L
.59279 .47708 L
.61438 .47484 L
.65418 .46934 L
.69921 .46082 L
.73911 .45093 L
.77417 .4401 L
.80967 .42667 L
.86674 .39801 L
.89499 .37906 L
.92045 .35748 L
.9385 .33791 L
.95411 .31552 L
.96016 .30419 L
.96547 .29172 L
.96746 .28596 L
.96927 .27982 L
.97059 .2745 L
.97173 .26876 L
.97259 .26319 L
.97314 .2581 L
.97348 .25297 L
.97361 .2481 L
.97351 .24246 L
.97319 .23723 L
.97258 .23149 L
.97163 .2254 L
.97026 .21885 L
.96869 .21286 L
.96406 .19944 L
.95873 .18777 L
.95187 .17566 L
.937 .15523 L
.91654 .13389 L
.89171 .11368 L
.86461 .09596 L
.80542 .06692 L
Mistroke
.7681 .05323 L
.73136 .04231 L
.68892 .03229 L
.64191 .02396 L
.62139 .02113 L
.59955 .01864 L
.5805 .01688 L
.56003 .01541 L
.54838 .01475 L
.53778 .01428 L
.52711 .01391 L
.51703 .01367 L
.50525 .01352 L
.49439 .01349 L
.48872 .01353 L
.48248 .0136 L
.47597 .01372 L
.46989 .01386 L
.45979 .01419 L
.44881 .01466 L
.42891 .01582 L
.40964 .01733 L
.39192 .01906 L
.35235 .02418 L
.31141 .03142 L
.27201 .04049 L
.23748 .0504 L
.20235 .06272 L
.16668 .0781 L
.11415 .1082 L
.09004 .12661 L
.07076 .14483 L
.05307 .1662 L
.04543 .17783 L
.03863 .19039 L
.03381 .20152 L
.03168 .20748 L
.02971 .21392 L
.02822 .21984 L
.0271 .22528 L
.02623 .23076 L
.02563 .23597 L
.02524 .24141 L
.0251 .24635 L
.02518 .25205 L
.02551 .2574 L
.02602 .26237 L
.02667 .26694 L
.02758 .27193 L
.02876 .2772 L
Mistroke
.03199 .28816 L
.0359 .29829 L
.04795 .32085 L
.06408 .34231 L
.08616 .36445 L
.10933 .38275 L
.13747 .40077 L
.16564 .41559 L
.19958 .43035 L
.26574 .45201 L
.30511 .46148 L
.34828 .46948 L
.38625 .4747 L
.40811 .47698 L
.42862 .47867 L
.44016 .47943 L
.45272 .48011 L
.4646 .48061 L
.47557 .48094 L
.48548 .48114 L
.49639 .48125 L
.50778 .48124 L
.51843 .48111 L
.52438 .48099 L
.53086 .48082 L
.54263 .48041 L
.55407 .47988 L
.56464 .47927 L
.58848 .47747 L
.61361 .47493 L
.65973 .46843 L
.70071 .46049 L
.74376 .44961 L
.78647 .43575 L
.85069 .40716 L
.88207 .38824 L
.90761 .36903 L
.92904 .34876 L
.94777 .3255 L
.95471 .31448 L
.96091 .3026 L
.96529 .29219 L
.96898 .28088 L
.97042 .27525 L
.97153 .26988 L
.97233 .26505 L
.97298 .25976 L
.97339 .25478 L
.9736 .24946 L
.97358 .24444 L
Mistroke
.97338 .23988 L
.97289 .23406 L
.97218 .22871 L
.97114 .22285 L
.96973 .21668 L
.96664 .20637 L
.96224 .19515 L
.94947 .17192 L
.93315 .15075 L
.91516 .13263 L
.89219 .11402 L
.86347 .09529 L
.82902 .07723 L
.79342 .06219 L
.75829 .05008 L
.72375 .04032 L
.68421 .03133 L
.64293 .02411 L
.61963 .02092 L
.59819 .0185 L
.57893 .01675 L
.5579 .01528 L
.54629 .01465 L
.53556 .0142 L
.52528 .01386 L
.51438 .01363 L
.50506 .01352 L
.49503 .01349 L
.48557 .01356 L
.47693 .0137 L
.46683 .01395 L
.45583 .01435 L
.44547 .01483 L
.43587 .01537 L
.41247 .01709 L
.39113 .01915 L
.34384 .02551 L
.30345 .03307 L
.26252 .04302 L
.19678 .06491 L
.16309 .07984 L
.1344 .09529 L
.10696 .1133 L
.08122 .13446 L
.06109 .15576 L
.0463 .17639 L
.03626 .19556 L
.03195 .20666 L
.02886 .21717 L
.02763 .22258 L
Mistroke
.02659 .22828 L
.02593 .23316 L
.02542 .2385 L
.02514 .24428 L
.0251 .24752 L
.02513 .25045 L
.02541 .25617 L
.02592 .26155 L
.02667 .26691 L
.02773 .27265 L
.03033 .28297 L
.03458 .29512 L
.03952 .30608 L
.05373 .3293 L
.07146 .35039 L
.11212 .38471 L
.14001 .40222 L
.16871 .41705 L
.19983 .43045 L
.23592 .44325 L
.26896 .45287 L
.30681 .46184 L
.35044 .46982 L
.37321 .47309 L
.39791 .47598 L
.42135 .47812 L
.44283 .47959 L
.45323 .48014 L
.46454 .4806 L
.47524 .48093 L
.48513 .48114 L
.49627 .48125 L
.50686 .48124 L
.51636 .48115 L
.52673 .48094 L
.53794 .48059 L
.54987 .48009 L
.57125 .47883 L
.59279 .47708 L
.61292 .47501 L
.64996 .47002 L
.6931 .46213 L
.73123 .45307 L
.77073 .44126 L
.81024 .42643 L
.84359 .41091 L
.87122 .39527 L
.91674 .36099 L
.93677 .34001 L
.94567 .32851 L
Mistroke
.95381 .31602 L
.9598 .30494 L
.96517 .29253 L
.96892 .28111 L
.97145 .27031 L
.97236 .26485 L
.97306 .25902 L
.97346 .2535 L
.97361 .24849 L
.97352 .24259 L
.97335 .23927 L
.9731 .2362 L
.97246 .23058 L
.97149 .22464 L
.97029 .21897 L
.9687 .21291 L
.96507 .20203 L
.95947 .18924 L
.95316 .17775 L
.93937 .15812 L
.92054 .13764 L
.87678 .10346 L
.84562 .08543 L
.81311 .07012 L
.74524 .04616 L
.70373 .03549 L
.66389 .02751 L
.61865 .02079 L
.59542 .01823 L
.5697 .01605 L
.54736 .01471 L
.5347 .01416 L
.52298 .0138 L
.51274 .0136 L
.50144 .0135 L
.48963 .01352 L
.47857 .01367 L
.46838 .01391 L
.45769 .01427 L
.44857 .01467 L
.43864 .01521 L
.41651 .01675 L
.3961 .01863 L
.35029 .0245 L
.30993 .03172 L
.26522 .04228 L
.22535 .05438 L
.15846 .08214 L
.12898 .09856 L
.10033 .11828 L
Mistroke
.0792 .13637 L
.06017 .15689 L
.04585 .17714 L
.03598 .1962 L
.03198 .20659 L
.02861 .21817 L
.02734 .22402 L
.02679 .2271 L
.02629 .23034 L
.0256 .23633 L
.02522 .24183 L
.0251 .24692 L
.0252 .25237 L
.02552 .25751 L
.026 .26217 L
.02679 .26764 L
.02792 .27357 L
.03073 .28426 L
.03478 .29563 L
.04049 .30798 L
.05593 .33227 L
.07473 .35374 L
.09605 .37274 L
.12161 .39108 L
.15329 .40942 L
.18422 .42404 L
.21996 .43791 L
.25782 .44983 L
.29397 .45903 L
.32893 .46618 L
.36849 .47246 L
.38887 .475 L
.41093 .47724 L
.43443 .47907 L
.44499 .47971 L
.4565 .48028 L
.46797 .48072 L
.4786 .48101 L
.48876 .48119 L
.49956 .48126 L
.5092 .48123 L
.51824 .48112 L
.52815 .4809 L
.53881 .48056 L
.55048 .48006 L
.56129 .47947 L
.58572 .47771 L
.6093 .47541 L
.63419 .47233 L
.67834 .4651 L
Mistroke
.717 .4567 L
.76121 .44436 L
.80576 .42829 L
Mfstroke
.92241 .35411 m
.93965 .33477 L
.95255 .31603 L
.95845 .30522 L
.96309 .29486 L
.96731 .2828 L
.96875 .27754 L
.97007 .27173 L
.97109 .26605 L
.9718 .26071 L
.97229 .25506 L
.97252 .24899 L
.97247 .24336 L
.97217 .23802 L
.9717 .23323 L
.97097 .228 L
.96981 .22179 L
.96847 .21617 L
.96452 .20367 L
.95969 .19222 L
.95413 .18159 L
.93908 .15957 L
.91861 .1374 L
.8976 .11954 L
.87104 .10124 L
.83863 .0832 L
.79994 .06597 L
.76039 .05191 L
.72137 .04079 L
.68158 .03178 L
.63765 .02419 L
.61593 .02126 L
.59223 .01865 L
.57855 .01741 L
.56595 .01643 L
.55394 .01565 L
.54107 .01498 L
.52979 .01452 L
.51951 .01422 L
.50918 .01401 L
.49941 .01392 L
.48802 .01392 L
.47751 .01404 L
.46599 .01429 L
.46019 .01447 L
.45381 .0147 L
.43103 .01587 L
.4183 .01675 L
.40672 .0177 L
.38387 .01999 L
Mistroke
.3634 .02253 L
.32292 .02899 L
.2813 .03782 L
.21154 .0587 L
.17592 .07312 L
.14084 .09077 L
.11152 .10912 L
.08762 .12766 L
.06673 .148 L
.05118 .16747 L
.03793 .18995 L
.03252 .20262 L
.03052 .20837 L
.02864 .21474 L
.02724 .22044 L
.02604 .2266 L
.02551 .23 L
.0251 .23312 L
.02455 .23924 L
.02431 .24454 L
.02431 .25032 L
.0246 .25636 L
.02514 .26196 L
.02557 .26518 L
.02612 .26865 L
.02738 .27494 L
.03061 .28662 L
.03579 .30012 L
.04189 .31235 L
.05538 .33294 L
.07387 .35409 L
.11707 .38915 L
.14913 .40822 L
.18307 .42447 L
.2159 .43734 L
.25468 .44974 L
.29136 .45916 L
.33263 .4675 L
.35599 .47127 L
.37775 .47422 L
.40014 .47671 L
.42118 .47856 L
.43949 .4798 L
.44892 .48031 L
.45916 .48076 L
.47042 .48113 L
.48106 .48137 L
.49143 .4815 L
.50101 .48152 L
.51109 .48145 L
Mistroke
.52052 .48129 L
.53086 .48101 L
.54196 .4806 L
.55354 .48003 L
.56451 .47937 L
.58501 .47781 L
.60771 .47557 L
.62887 .47298 L
.66766 .4669 L
.70808 .45856 L
.74983 .44749 L
.78444 .43605 L
.81863 .4223 L
.87279 .39363 L
.8988 .37541 L
.9194 .35766 L
.93925 .336 L
.95396 .31454 L
.95923 .30469 L
.9639 .2941 L
.96713 .28497 L
.96988 .27483 L
.97104 .26913 L
.97187 .2639 L
.97252 .25814 L
.97291 .25208 L
.973 .24679 L
.97287 .24186 L
.97251 .23646 L
.97185 .23071 L
.97093 .22502 L
.96961 .21879 L
.96596 .20629 L
.96142 .19483 L
.95617 .18425 L
.94087 .16104 L
.91928 .13732 L
.89438 .11644 L
.86691 .09807 L
.80635 .06795 L
.77043 .05461 L
.73585 .04407 L
.6967 .03443 L
.65259 .02604 L
.63211 .02294 L
.61022 .02015 L
.58973 .018 L
.57048 .01639 L
.5523 .01521 L
.54294 .01473 L
Mistroke
.53275 .01431 L
.52158 .01396 L
.511 .01375 L
.50069 .01365 L
.49117 .01365 L
.48006 .01376 L
.4695 .01397 L
.46003 .01426 L
.4497 .01468 L
.42669 .01599 L
.40546 .01769 L
.36737 .02194 L
.32768 .02813 L
.28205 .03772 L
.24114 .04894 L
.20674 .06067 L
.17156 .07537 L
.1134 .10819 L
.08711 .12854 L
.06643 .14885 L
.05066 .16884 L
.03944 .18772 L
.03456 .19838 L
.03035 .2101 L
.0288 .21551 L
.02743 .22128 L
.02639 .22666 L
.02564 .23168 L
.02508 .23698 L
.02472 .24278 L
.02464 .24844 L
.02484 .25448 L
.0253 .26011 L
.02597 .26542 L
.02677 .27017 L
.02784 .27532 L
.03114 .28707 L
.03587 .29939 L
.0475 .32101 L
.06181 .34037 L
.07815 .35775 L
.12528 .39397 L
.15474 .41068 L
.1903 .42707 L
.2243 .43984 L
.26292 .45163 L
.30324 .46142 L
.34124 .46863 L
.38057 .47426 L
.39874 .47628 L
Mistroke
.41836 .47807 L
.42951 .47891 L
.4397 .47957 L
.45009 .48013 L
.45971 .48056 L
.47094 .48094 L
.47687 .48109 L
.48316 .48121 L
.49372 .48132 L
.50538 .48133 L
.51121 .48128 L
.51734 .48119 L
.52828 .48094 L
.54004 .48054 L
.55287 .47995 L
.5758 .47848 L
.59696 .47664 L
.63757 .47176 L
.67356 .46585 L
.71375 .45729 L
.75003 .44755 L
.81992 .42192 L
.85122 .40652 L
.8821 .38782 L
.90528 .37054 L
.92667 .35077 L
.94334 .33112 L
.95544 .3125 L
.96107 .30145 L
.9654 .29093 L
.96891 .27985 L
.97036 .27393 L
.9716 .26752 L
.97234 .26238 L
.97291 .25675 L
.97322 .25086 L
.97326 .24538 L
.97306 .24024 L
.9727 .23556 L
.97205 .23017 L
.97122 .22509 L
.97008 .21959 L
.96853 .21355 L
.96448 .20143 L
.95963 .19034 L
.95414 .18009 L
.93853 .15763 L
.91688 .13467 L
.89228 .11451 L
.86596 .09715 L
Mistroke
.83066 .07836 L
.79526 .06322 L
.72239 .04023 L
.67915 .03055 L
.63681 .02339 L
.59652 .01847 L
.57331 .01643 L
.55148 .01501 L
.5396 .01443 L
.52832 .01402 L
.51818 .01375 L
.50714 .01358 L
.50143 .01354 L
.49513 .01353 L
.48856 .01356 L
.48239 .01362 L
.47137 .01384 L
.46519 .01401 L
.45952 .0142 L
.43973 .01512 L
.4214 .01633 L
.40142 .01804 L
.38026 .02031 L
.33777 .0264 L
.30031 .0336 L
.26157 .04309 L
.22266 .05508 L
.15952 .08135 L
.12872 .09843 L
.10306 .11587 L
.0789 .1363 L
.05735 .16003 L
.04919 .17139 L
.04176 .18373 L
.03641 .19458 L
.03176 .20644 L
.02975 .21285 L
.02821 .21876 L
.02702 .22432 L
.02602 .23043 L
.02538 .23593 L
.02501 .24107 L
.02485 .2465 L
.02494 .25231 L
.02531 .2581 L
.0259 .26344 L
.02681 .26928 L
.02809 .27547 L
.03094 .28579 L
.0351 .29707 L
Mistroke
.04554 .31746 L
.05849 .33598 L
.07722 .35654 L
.10199 .37767 L
.12732 .39498 L
.15768 .41193 L
.19078 .42704 L
.2232 .43924 L
.29202 .45874 L
.33208 .46689 L
.35457 .47058 L
.37589 .47354 L
.41418 .4776 L
.43471 .47915 L
.44544 .47979 L
.45687 .48034 L
.46274 .48058 L
.46924 .4808 L
.48071 .48108 L
.48716 .48119 L
.49411 .48125 L
.50068 .48127 L
.50671 .48125 L
.5177 .48112 L
.52393 .481 L
.52973 .48085 L
.54142 .48044 L
.5539 .47986 L
.57757 .47832 L
.59976 .47635 L
.64067 .47133 L
.67963 .46474 L
.721 .45558 L
.76208 .44392 L
.79822 .43113 L
.85613 .40396 L
.88434 .38647 L
.90709 .36923 L
.92757 .35005 L
.94543 .32852 L
.95258 .31771 L
.95837 .30737 L
.96275 .29803 L
.9667 .28768 L
.97003 .27609 L
.97137 .26972 L
.97232 .26376 L
.97295 .25817 L
.9733 .25307 L
.97343 .24718 L
Mistroke
.97329 .24161 L
.97286 .23558 L
.97252 .23254 L
.97207 .22918 L
.97103 .22328 L
.9698 .21775 L
.96611 .2054 L
.96072 .19225 L
.94817 .17032 L
.93284 .15069 L
.91213 .13018 L
.88578 .10969 L
.85368 .08993 L
.81964 .07313 L
.78657 .05979 L
.74758 .04698 L
.71076 .03723 L
.66945 .0286 L
.646 .02465 L
.62424 .02156 L
.60183 .01893 L
.58086 .01695 L
.56147 .01553 L
.55151 .01494 L
.54073 .01442 L
.53453 .01417 L
.52883 .01398 L
.51763 .01369 L
.50744 .01354 L
.49669 .01349 L
.48711 .01353 L
.47687 .01369 L
.46721 .01392 L
.45843 .01422 L
.44813 .01467 L
.43697 .01527 L
.4168 .01668 L
.39621 .01856 L
.37426 .02106 L
.3353 .02686 L
.29048 .03586 L
.2513 .04607 L
.21289 .05862 L
.17401 .07452 L
.11288 .10891 L
.08684 .12919 L
.06619 .14961 L
.05105 .16884 L
.03847 .19042 L
.03352 .20191 L
Mistroke
.02937 .21466 L
.02779 .22113 L
.02707 .2247 L
.02649 .22809 L
.02603 .23125 L
.02562 .23468 L
.02514 .24069 L
.02496 .2463 L
.02498 .24949 L
.02507 .25248 L
.02547 .2585 L
.02582 .26188 L
.02623 .26498 L
.0271 .27019 L
.0283 .27587 L
.03154 .28724 L
.03596 .29877 L
.042 .31109 L
.05622 .33287 L
.07397 .35316 L
.09359 .37092 L
.14883 .40721 L
.18172 .42308 L
.22128 .43847 L
.26056 .45068 L
.29992 .46043 L
.33668 .46761 L
.378 .47374 L
.40195 .47642 L
.42387 .47834 L
.4361 .4792 L
.44936 .47996 L
.46191 .48051 L
.47348 .48089 L
.48424 .48112 L
.49429 .48123 L
.50532 .48124 L
.51713 .48112 L
.52307 .481 L
.52951 .48084 L
.54121 .48044 L
.55257 .47993 L
.56305 .47933 L
.58446 .47777 L
.60393 .47594 L
.64709 .4704 L
.68412 .4639 L
.72174 .45544 L
.79585 .43213 L
.8335 .41583 L
Mistroke
.86519 .39882 L
.89274 .3806 L
.91843 .35927 L
.93845 .33781 L
.95304 .31712 L
.96293 .29783 L
.96712 .28668 L
.9701 .27617 L
.97132 .27046 L
.97224 .26502 L
.97285 .26013 L
.97329 .25481 L
.9735 .24902 L
.97351 .2461 L
.97343 .24287 L
.97309 .23717 L
.97252 .23183 L
.9717 .2264 L
.97056 .22061 L
.96781 .21024 L
.96337 .19802 L
.95825 .18706 L
.94363 .16378 L
.92556 .14275 L
.88421 .1085 L
.85598 .09111 L
.8271 .07643 L
.79546 .06305 L
.75893 .05035 L
.72553 .04083 L
.68742 .03202 L
.66361 .0275 L
.64109 .02386 L
.61741 .02066 L
.59569 .01827 L
.5741 .01638 L
.55364 .01503 L
.54233 .01447 L
.53192 .01406 L
.52047 .01374 L
.51469 .01362 L
.50836 .01353 L
.4967 .01348 L
.48592 .01354 L
.48029 .01362 L
.47409 .01374 L
.46762 .01391 L
.46155 .01411 L
.44029 .01508 L
.42839 .01583 L
Mistroke
.41751 .01663 L
.37788 .02064 L
.35825 .02325 L
.33707 .02658 L
.29371 .03516 L
.24954 .04664 L
.17715 .07316 L
.14336 .09006 L
.11542 .10724 L
.08911 .1273 L
.06505 .151 L
.04851 .17276 L
.03693 .19387 L
.03218 .20576 L
.02889 .21673 L
.0275 .22282 L
.02689 .22604 L
.02634 .22947 L
.0259 .23278 L
.02558 .23578 L
.02516 .24162 L
.02502 .24725 L
.02513 .2525 L
.02551 .25824 L
.02584 .26146 L
.02621 .26439 L
.02718 .27028 L
.02856 .27666 L
.03192 .28817 L
.03602 .29875 L
.04139 .30984 L
.05363 .32927 L
.07175 .3508 L
.09245 .3699 L
.11885 .38935 L
.15191 .40877 L
.18676 .42518 L
.22198 .43866 L
.26097 .45075 L
.29826 .46002 L
.3364 .46753 L
.37344 .47313 L
.39278 .47544 L
.41341 .47746 L
.43623 .47919 L
.44719 .47983 L
.45736 .48032 L
.4682 .48072 L
.47392 .48089 L
.48001 .48103 L
Mistroke
.49023 .48119 L
.50152 .48125 L
.51153 .48119 L
.52231 .48102 L
.53249 .48076 L
.54181 .48042 L
.55268 .47993 L
.56278 .47936 L
.58559 .47769 L
.60764 .47556 L
.63095 .47274 L
.67284 .46609 L
.7111 .45807 L
.77823 .43864 L
.81092 .42609 L
.84416 .41055 L
.87349 .39378 L
.9013 .37412 L
.92354 .35438 L
.94049 .33533 L
.95412 .31539 L
.96379 .29588 L
.96802 .28403 L
.96965 .27817 L
.97091 .27277 L
.97183 .26792 L
.97261 .2626 L
.97316 .25725 L
.97349 .25159 L
.97356 .24839 L
.97355 .24537 L
.97332 .23971 L
.97279 .23362 L
.97235 .23018 L
.97186 .22701 L
.96949 .21597 L
.96791 .21042 L
.96588 .20434 L
.95657 .18378 L
.94977 .17247 L
.94258 .16231 L
.90738 .12593 L
.88372 .10811 L
.85503 .09053 L
.7954 .06299 L
.75454 .04895 L
.71346 .03779 L
.67483 .02952 L
.6541 .02587 L
.63149 .02247 L
Mistroke
.60935 .0197 L
.58892 .01761 L
.56822 .01594 L
.54846 .01475 L
.5373 .01425 L
.53118 .01403 L
.52541 .01386 L
.51525 .01363 L
.50401 .0135 L
.49808 .01348 L
.49184 .01349 L
.48068 .01361 L
.47446 .01374 L
.46867 .01388 L
.45554 .01434 L
.44387 .01489 L
.43124 .01564 L
.40843 .01742 L
.38641 .01965 L
.36629 .02215 L
.32156 .02939 L
.276 .03943 L
.23795 .05021 L
.20506 .06164 L
.17199 .07555 L
.13901 .09256 L
.11182 .10977 L
.08956 .12697 L
.06985 .14574 L
.05474 .16384 L
.0407 .1862 L
.03507 .19826 L
.03047 .21115 L
.02896 .21661 L
.02761 .22248 L
.0266 .22803 L
.0259 .2331 L
.02534 .23906 L
.02516 .24243 L
.02507 .24555 L
.02512 .25127 L
.02547 .25734 L
.02602 .26265 L
.02673 .26752 L
.02773 .27285 L
.02904 .27845 L
.03184 .28782 L
.03573 .29799 L
.04769 .3205 L
.06265 .34069 L
Mistroke
.08265 .36135 L
.1087 .38234 L
.13516 .39945 L
.16647 .41602 L
.19733 .42949 L
.23386 .4426 L
.26646 .45222 L
.30365 .46118 L
.34706 .46929 L
.36752 .47233 L
.38958 .47508 L
.41167 .4773 L
.43185 .47889 L
.44164 .47952 L
.45225 .48008 L
.46155 .48049 L
.47152 .48082 L
.48319 .48109 L
.49408 .48123 L
.50073 .48125 L
.50703 .48123 L
.51882 .48109 L
.52485 .48097 L
.53124 .4808 L
.5427 .48039 L
.555 .47981 L
.56852 .479 L
.59044 .47728 L
.61382 .47488 L
.65536 .46913 L
.69678 .46132 L
.73377 .45236 L
.77549 .43962 L
.81085 .42614 L
.87438 .39325 L
.90343 .37245 L
.92657 .35132 L
.94329 .33173 L
.95755 .3093 L
.96306 .29772 L
.9677 .28513 L
.96947 .27899 L
.97086 .27314 L
.97186 .26787 L
.97269 .26213 L
.97322 .25684 L
.97351 .25187 L
.97359 .24641 L
.9734 .24053 L
.97293 .2347 L
Mistroke
.97213 .22857 L
.97121 .22335 L
.96994 .21765 L
.96699 .20746 L
.96288 .19668 L
.95303 .17759 L
.93651 .15468 L
.91723 .13456 L
.89187 .11382 L
.86052 .0936 L
.79866 .06423 L
.75905 .05033 L
.71954 .03926 L
.67917 .03034 L
.65722 .02638 L
.63342 .02273 L
.61022 .01979 L
.58896 .01761 L
.5674 .01588 L
.55768 .01526 L
.54698 .01468 L
.53729 .01425 L
.5269 .0139 L
.5159 .01364 L
.50564 .01351 L
.4954 .01348 L
.48571 .01355 L
.47701 .01369 L
.46756 .01392 L
.45729 .01428 L
.44598 .01479 L
.42317 .01622 L
.40219 .018 L
.38267 .02009 L
.34235 .02574 L
.29961 .03388 L
.25692 .04455 L
.21937 .05642 L
.15834 .08218 L
.12833 .09894 L
.10396 .11549 L
.08125 .13441 L
.06115 .15566 L
.04737 .17464 L
.03596 .19621 L
.0313 .20857 L
.02817 .21996 L
.02691 .22629 L
.02637 .22964 L
.0259 .2332 L
Mistroke
.02555 .23663 L
.02532 .23974 L
.02509 .24581 L
.02516 .25185 L
.02549 .25739 L
.02614 .26347 L
.02659 .26652 L
.02716 .26986 L
.02988 .28148 L
.03343 .29222 L
.03849 .30403 L
.04421 .31478 L
.06075 .33839 L
.07932 .35822 L
.10288 .37805 L
.15231 .40892 L
.18482 .4243 L
.21781 .43716 L
.2549 .449 L
.29775 .45988 L
.3401 .46814 L
.36087 .47139 L
.38069 .47403 L
.40033 .47622 L
.42177 .47815 L
.44139 .4795 L
.45954 .48041 L
.46974 .48077 L
.47928 .48102 L
.48975 .48119 L
.50099 .48125 L
.51277 .48119 L
.52392 .481 L
.53392 .48072 L
.54479 .48031 L
.56547 .4792 L
.58765 .47753 L
.60841 .4755 L
.62728 .47324 L
.67024 .46659 L
.71388 .45744 L
.75449 .44643 L
.79015 .43438 L
.82627 .41935 L
.86179 .40092 L
.89186 .38136 L
.91581 .36182 L
.93508 .34199 L
.9514 .31995 L
.9571 .31018 L
Mistroke
.96229 .29953 L
.966 .29022 L
.96922 .27998 L
.97074 .27373 L
.97187 .26792 L
.97268 .26235 L
.97327 .25642 L
.97356 .25057 L
.97358 .24507 L
.97339 .24013 L
.97295 .2348 L
.97222 .22902 L
.97131 .22377 L
.96844 .21204 L
.96477 .20126 L
.9604 .19118 L
.94754 .16908 L
.92887 .14607 L
.90614 .12485 L
.87747 .10392 L
.8467 .086 L
.81548 .07115 L
.74776 .0469 L
.70905 .03672 L
.66646 .02797 L
.62797 .02199 L
.59139 .01784 L
.57008 .01607 L
.55061 .01486 L
.53978 .01436 L
.52804 .01394 L
.51693 .01367 L
.50669 .01352 L
.49546 .01348 L
.48481 .01356 L
.47526 .01373 L
.46486 .01401 L
.4536 .01443 L
.44165 .01503 L
.42026 .01644 L
.40072 .01815 L
.38251 .02011 L
.34165 .02586 L
.29862 .03411 L
.26074 .04349 L
.22159 .05565 L
.18261 .07082 L
.1496 .08673 L
.12242 .10268 L
.07801 .1375 L
Mistroke
.05866 .15876 L
.05016 .17038 L
.04247 .18296 L
.03688 .19413 L
.03196 .2066 L
.03022 .21211 L
.02863 .21806 L
.02741 .22362 L
.0265 .22886 L
.02608 .23183 L
.02571 .23504 L
.02527 .24066 L
.02514 .24384 L
.02509 .24721 L
.02523 .25324 L
.02563 .25882 L
.02623 .26401 L
.02714 .26971 L
.02842 .27579 L
.0324 .28938 L
.03759 .30209 L
.05093 .32534 L
.06785 .34656 L
.08703 .36522 L
.11156 .38433 L
.14195 .40331 L
.17342 .41925 L
.20483 .43238 L
.27256 .45382 L
.3112 .46275 L
.35513 .47054 L
.37785 .47368 L
.40243 .47643 L
.42588 .47847 L
.43695 .47923 L
.44733 .47984 L
.45806 .48035 L
.46788 .48072 L
.4788 .48101 L
.49055 .4812 L
.5018 .48126 L
.50817 .48123 L
.51407 .48117 L
.52488 .48098 L
.53637 .48064 L
.54703 .48022 L
.5585 .47963 L
.57921 .47823 L
.59923 .47646 L
.61747 .47447 L
Mistroke
.65884 .46858 L
.70271 .46004 L
.74644 .44883 L
.78487 .43633 L
.81981 .42229 L
.8545 .40507 L
.88196 .38831 L
.90757 .36906 L
.9273 .35059 L
.9452 .32916 L
.95171 .31947 L
.9578 .30887 L
.96267 .29868 L
.96632 .28934 L
.96982 .27771 L
.97126 .27128 L
.9723 .26521 L
.973 .25957 L
.97341 .25436 L
.9736 .24865 L
.97352 .24261 L
.97313 .23652 L
.97277 .23311 L
.97237 .23 L
.97135 .22397 L
.97012 .21827 L
.96638 .20561 L
.9608 .192 L
.94794 .16966 L
.92964 .14689 L
.9104 .12844 L
.88552 .1093 L
.858 .09214 L
.82569 .0757 L
.76049 .05077 L
.72065 .03953 L
.68174 .03084 L
.63741 .02329 L
.61199 .02 L
.58859 .01758 L
.56829 .01595 L
.5458 .01463 L
.53444 .01415 L
.52817 .01394 L
.52221 .01378 L
.51065 .01357 L
.50008 .01349 L
.49021 .01351 L
.4797 .01364 L
.46979 .01387 L
Mistroke
.46082 .01415 L
.45025 .01459 L
.43886 .01519 L
.41829 .0166 L
.39624 .01861 L
.3723 .02138 L
.32504 .02877 L
.28288 .03776 L
.24532 .04796 L
.2083 .06045 L
.17098 .07606 L
.14094 .0915 L
.1123 .10948 L
.08966 .12693 L
.06835 .14741 L
.0525 .167 L
.04081 .18605 L
.03562 .19704 L
.03171 .20738 L
.02845 .21882 L
.0271 .22526 L
.02618 .23112 L
.02581 .23412 L
.02551 .2373 L
.02517 .24301 L
.02511 .24915 L
.02521 .25264 L
.02539 .2559 L
.02595 .26179 L
.0267 .26715 L
.02787 .27333 L
.02927 .27917 L
.03241 .28937 L
.03669 .30012 L
.04682 .31907 L
.06282 .34084 L
.08084 .35963 L
.10363 .3786 L
.13137 .39717 L
.18953 .42628 L
.22608 .44001 L
.26241 .45111 L
.30442 .46133 L
.35139 .46997 L
.37346 .47312 L
.39717 .4759 L
.41762 .47782 L
.44032 .47944 L
.4531 .48013 L
.46483 .48061 L
Mistroke
.4713 .48082 L
.47838 .48101 L
.48507 .48113 L
.49129 .48121 L
.49755 .48125 L
.50345 .48126 L
.51447 .48117 L
.52065 .48107 L
.52633 .48094 L
.53915 .48055 L
.54951 .4801 L
.5606 .47951 L
.58052 .47813 L
.60403 .47597 L
.62525 .47351 L
.67046 .46656 L
.71179 .45795 L
.74787 .44842 L
.78558 .43608 L
.81986 .42227 L
.85372 .40551 L
.88203 .38826 L
.90502 .37119 L
.92546 .35251 L
.94107 .33468 L
.955 .31398 L
.96105 .30231 L
.96568 .29114 L
.96903 .2807 L
.97132 .27101 L
.9722 .26593 L
.97292 .26032 L
.97341 .25446 L
.9736 .24898 L
.97354 .24302 L
.97337 .23966 L
.97313 .23654 L
.97249 .23083 L
.97151 .22477 L
.97025 .21882 L
.9688 .21325 L
.9654 .2029 L
.96022 .19077 L
.95437 .17979 L
.93742 .15574 L
.91917 .13634 L
.89587 .11675 L
.84482 .08502 L
.80852 .0682 L
.77109 .05422 L
Mistroke
.73554 .04343 L
.69428 .03341 L
.6527 .02563 L
.61252 .02006 L
.59 .01771 L
.56919 .01601 L
.54619 .01465 L
.53459 .01416 L
.5285 .01395 L
.52189 .01378 L
.51076 .01357 L
.50026 .01349 L
.49004 .01352 L
.48063 .01363 L
.47044 .01385 L
.45925 .01421 L
.4476 .01472 L
.43674 .01532 L
.41695 .01671 L
.39902 .01833 L
.35923 .02316 L
.31876 .02996 L
.27729 .03914 L
.208 .06056 L
.17312 .07507 L
.14306 .09031 L
.11366 .10854 L
.08582 .13028 L
.06509 .15105 L
.04951 .17137 L
.03712 .19362 L
.03205 .20636 L
.03025 .21203 L
.02863 .21806 L
.02748 .22328 L
.02648 .22904 L
.0258 .23429 L
.02537 .23921 L
.02512 .245 L
.02513 .2503 L
.02543 .25642 L
.026 .26222 L
.02671 .26722 L
.0277 .27254 L
.03007 .28206 L
.03385 .29328 L
.03819 .30335 L
.05064 .32491 L
.06806 .34677 L
.08626 .36454 L
Mistroke
.10957 .38292 L
.13833 .40126 L
.173 .41905 L
.24426 .44585 L
.28551 .45705 L
.3255 .46555 L
.37101 .4728 L
.3945 .47562 L
.42071 .47807 L
.43192 .4789 L
.44376 .47964 L
.45402 .48017 L
.465 .48062 L
.47122 .48082 L
.47688 .48097 L
.48794 .48117 L
.49414 .48124 L
.50086 .48126 L
.50721 .48124 L
.51306 .48119 L
.52345 .48101 L
.53317 .48075 L
.54381 .48036 L
.55522 .47982 L
.57838 .4783 L
.59938 .47645 L
.64081 .47139 L
.6837 .46405 L
.72268 .45529 L
.75645 .44584 L
.79416 .43288 L
.8318 .41676 L
.86379 .39977 L
.89042 .38241 L
.91436 .36316 L
.93285 .34457 L
.94952 .3229 L
.95695 .31047 L
.96262 .2988 L
.96702 .28731 L
.97047 .27501 L
.97176 .26859 L
.97267 .26257 L
.97305 .25912 L
.97331 .25595 L
.97352 .2523 L
.97361 .24882 L
.97354 .24311 L
.97317 .23701 L
.97255 .23127 L
Mistroke
.97175 .22608 L
.97052 .21997 L
.96884 .21339 L
.96488 .20154 L
.96025 .19084 L
.95422 .17953 L
.94058 .15964 L
.91994 .13706 L
.89712 .11769 L
.8696 .09896 L
.83564 .0804 L
.80035 .06488 L
.76453 .05206 L
.72694 .04114 L
.69081 .03268 L
.64915 .02506 L
.6253 .02164 L
.60281 .01898 L
.58039 .01687 L
.55985 .01539 L
.54806 .01474 L
.5369 .01425 L
.5251 .01386 L
.51843 .0137 L
.51228 .01359 L
.50079 .01349 L
.49004 .01352 L
.47824 .01367 L
.47162 .01382 L
.46558 .01399 L
.45347 .01445 L
.44031 .01511 L
.41645 .01675 L
.39401 .01884 L
.37002 .02168 L
.32743 .02833 L
.28737 .03669 L
.25207 .04597 L
.17852 .07263 L
.14579 .0888 L
.11375 .10848 L
.08787 .12847 L
.0672 .14868 L
.052 .16772 L
.03922 .18919 L
.03419 .20054 L
.02991 .21321 L
.02827 .21962 L
.02688 .22655 L
.02637 .22975 L
Mistroke
.02593 .23312 L
.02537 .23914 L
.02512 .24474 L
.02514 .25072 L
.02543 .25635 L
.02591 .26147 L
.02676 .26748 L
.02801 .27396 L
.03117 .28567 L
.03511 .29643 L
.04041 .30783 L
.05276 .32795 L
.07193 .35088 L
.09348 .37066 L
.11974 .38986 L
.15248 .409 L
.18674 .42511 L
.22173 .43852 L
.29403 .45904 L
.33512 .46729 L
.35686 .4708 L
.38102 .47407 L
.40344 .47654 L
.42765 .4786 L
.44112 .47949 L
.45342 .48014 L
.46581 .48065 L
.47755 .48099 L
.4884 .48118 L
.49992 .48126 L
.50974 .48122 L
.52057 .48107 L
.53217 .48079 L
.53868 .48057 L
.54463 .48033 L
.56707 .47911 L
.58912 .47741 L
.60894 .47545 L
.65266 .46959 L
.69197 .46237 L
.72769 .45401 L
.80188 .42986 L
.83921 .41313 L
.87019 .39591 L
.89533 .3788 L
.91874 .35912 L
.93584 .34112 L
.95095 .32068 L
.95832 .30788 L
.96387 .29583 L
Mistroke
.96802 .28418 L
.96971 .27818 L
.97118 .27169 L
.97221 .26585 L
.97291 .26048 L
.97335 .25535 L
.97359 .24993 L
.97357 .24398 L
.97329 .23845 L
.97269 .23239 L
.97223 .229 L
.97172 .22593 L
.96936 .21527 L
.9676 .20925 L
.96568 .20365 L
.96058 .19152 L
.95484 .1806 L
.94188 .16131 L
.92439 .14143 L
.90176 .12129 L
.87277 .10092 L
.80969 .06868 L
.77183 .05447 L
.73375 .04295 L
.69737 .03408 L
.65747 .02642 L
.63615 .02312 L
.61244 .02005 L
.59037 .01775 L
.57011 .01608 L
.55856 .01532 L
.54597 .01464 L
.53905 .01433 L
.53264 .01409 L
.52612 .01389 L
.52 .01373 L
.50917 .01355 L
.50342 .01351 L
.49723 .01349 L
.49108 .01351 L
.48461 .01357 L
.47307 .01378 L
.46201 .01411 L
.45006 .0146 L
.42847 .01585 L
.40758 .01752 L
.3885 .01944 L
.34581 .0252 L
.30207 .03337 L
.2658 .04212 L
Mistroke
.2334 .0517 L
.16621 .07833 L
.13548 .09465 L
.10576 .11418 L
.08305 .13277 L
.06277 .15376 L
.04812 .1735 L
.04176 .18428 L
.03603 .19609 L
.03183 .20701 L
.02887 .21713 L
.02683 .22686 L
.0261 .23176 L
.02553 .23715 L
.02517 .24327 L
.02511 .24892 L
.02518 .25187 L
.02534 .25512 L
.02561 .25851 L
.02594 .26168 L
.02676 .26749 L
.02776 .2728 L
.03085 .28467 L
.03457 .29509 L
.03965 .30633 L
.05163 .32634 L
.06974 .34858 L
.09381 .37093 L
.14847 .40688 L
.18288 .42346 L
.21735 .43699 L
.2571 .44962 L
.30339 .46111 L
.34563 .46906 L
.38626 .4747 L
.40911 .47707 L
.43011 .47878 L
.44178 .47953 L
.45451 .48019 L
.46656 .48068 L
.47772 .48099 L
.48825 .48118 L
.49934 .48126 L
.5088 .48123 L
.51915 .4811 L
.53032 .48084 L
.53657 .48064 L
.54224 .48043 L
.56362 .47933 L
.58335 .47791 L
Mistroke
.60456 .47592 L
.64249 .47115 L
.6863 .46354 L
.73076 .4532 L
.76682 .44255 L
.80408 .42897 L
.80576 .42829 L
Mfstroke
.92187 .35405 m
.9391 .33481 L
.95202 .31617 L
.95793 .3054 L
.96259 .29509 L
.96683 .28308 L
.96829 .27784 L
.96962 .27205 L
.97065 .26639 L
.97138 .26107 L
.97189 .25544 L
.97214 .24939 L
.9721 .24378 L
.97183 .23844 L
.97138 .23366 L
.97067 .22845 L
.96952 .22225 L
.96821 .21665 L
.96431 .20416 L
.95953 .19273 L
.95401 .18211 L
.93907 .16009 L
.91871 .1379 L
.89779 .12001 L
.8713 .10165 L
.83898 .08354 L
.80035 .06621 L
.76085 .05206 L
.72184 .04085 L
.68206 .03175 L
.63811 .02406 L
.61638 .02109 L
.59266 .01843 L
.57896 .01717 L
.56634 .01617 L
.55432 .01538 L
.54144 .01468 L
.53014 .01421 L
.51985 .01389 L
.5095 .01367 L
.49972 .01357 L
.48831 .01356 L
.47779 .01366 L
.46625 .01391 L
.46044 .01408 L
.45405 .01431 L
.43123 .01546 L
.41848 .01633 L
.40687 .01727 L
.38398 .01955 L
Mistroke
.36347 .02209 L
.32291 .02855 L
.28121 .0374 L
.21131 .05835 L
.17563 .07283 L
.14049 .09055 L
.11114 .10898 L
.08722 .1276 L
.06633 .14802 L
.05078 .16756 L
.03757 .19012 L
.03217 .20282 L
.03018 .20859 L
.02831 .21498 L
.02693 .22069 L
.02574 .22686 L
.02521 .23027 L
.02482 .2334 L
.02427 .23954 L
.02405 .24484 L
.02407 .25064 L
.02438 .25669 L
.02493 .2623 L
.02537 .26552 L
.02593 .269 L
.02721 .27529 L
.03047 .28699 L
.03569 .3005 L
.04183 .31274 L
.05539 .33332 L
.07395 .35445 L
.11727 .38945 L
.14939 .40846 L
.18337 .42465 L
.21623 .43747 L
.25502 .44979 L
.29171 .45915 L
.33297 .46743 L
.35632 .47117 L
.37807 .47408 L
.40044 .47654 L
.42147 .47837 L
.43976 .47959 L
.44918 .48009 L
.45942 .48053 L
.47066 .48089 L
.48129 .48112 L
.49165 .48124 L
.50122 .48125 L
.51128 .48117 L
Mistroke
.52071 .481 L
.53103 .48072 L
.54212 .4803 L
.55368 .47973 L
.56464 .47906 L
.58511 .4775 L
.60778 .47525 L
.62891 .47266 L
.66764 .46658 L
.70801 .45826 L
.74969 .44721 L
.78426 .43581 L
.8184 .42209 L
.87251 .39352 L
.89851 .37536 L
.9191 .35766 L
.93896 .33606 L
.95369 .31466 L
.95897 .30483 L
.96365 .29426 L
.96693 .28504 L
.96966 .27503 L
.97082 .26941 L
.97165 .26425 L
.97224 .25931 L
.97264 .2541 L
.97283 .24837 L
.97275 .24304 L
.9724 .2372 L
.97208 .23393 L
.97172 .23097 L
.97084 .22547 L
.9698 .22034 L
.96661 .20874 L
.96243 .19755 L
.95676 .18569 L
.94349 .16474 L
.92807 .14633 L
.90636 .126 L
.87834 .10534 L
.81684 .07242 L
.77966 .05776 L
.74215 .04579 L
.70621 .03649 L
.66671 .02834 L
.64554 .02479 L
.62198 .02144 L
.60003 .01887 L
.57985 .01696 L
.55578 .01522 L
Mistroke
.54248 .01452 L
.53636 .01425 L
.52986 .01401 L
.51818 .01368 L
.50738 .0135 L
.49575 .01343 L
.48913 .01344 L
.48293 .0135 L
.47183 .0137 L
.46562 .01386 L
.46 .01404 L
.43876 .01501 L
.4269 .01575 L
.41412 .01671 L
.39108 .01887 L
.3468 .02467 L
.30723 .03184 L
.27254 .03986 L
.23611 .05029 L
.16903 .07634 L
.13651 .09337 L
.10899 .1111 L
.087 .12845 L
.06701 .14801 L
.04948 .17036 L
.03729 .19187 L
.03225 .20406 L
.02866 .21563 L
.0271 .22229 L
.02599 .22841 L
.0255 .23191 L
.02513 .23516 L
.02484 .23855 L
.02463 .24227 L
.02453 .24823 L
.02458 .25123 L
.02473 .25454 L
.02521 .26037 L
.02592 .26583 L
.02706 .27223 L
.02839 .27806 L
.03242 .29109 L
.037 .30216 L
.04317 .31406 L
.05744 .33515 L
.07484 .35463 L
.09709 .37425 L
.14598 .40609 L
.18027 .4228 L
.21464 .43644 L
Mistroke
.25431 .44918 L
.30053 .46076 L
.34272 .46877 L
.38332 .47447 L
.40614 .47688 L
.42713 .47861 L
.43879 .47938 L
.45151 .48006 L
.46356 .48055 L
.47471 .48088 L
.48524 .48109 L
.49634 .48118 L
.50581 .48116 L
.51615 .48105 L
.52734 .4808 L
.53359 .48061 L
.53926 .48041 L
.56065 .47934 L
.58039 .47795 L
.60161 .476 L
.63957 .4713 L
.68344 .46377 L
.72797 .45355 L
.76412 .44301 L
.80147 .42957 L
.83631 .41409 L
.86634 .39774 L
.91371 .36316 L
.93459 .34192 L
.95007 .32127 L
.95713 .30925 L
.96261 .29776 L
.96713 .28563 L
.96903 .27914 L
.97068 .2721 L
.97172 .26632 L
.97243 .26106 L
.97296 .25498 L
.97319 .24922 L
.97315 .2439 L
.97291 .23899 L
.97242 .2336 L
.97163 .2279 L
.97058 .2222 L
.96914 .21608 L
.96576 .2051 L
.96043 .19218 L
.95433 .18055 L
.93892 .15821 L
.91719 .13502 L
Mistroke
.89221 .11451 L
.86543 .09685 L
.83461 .08026 L
.79784 .0642 L
.7628 .05176 L
.72346 .04044 L
.68617 .03188 L
.64367 .02432 L
.6246 .02162 L
.60392 .01915 L
.58602 .01738 L
.56611 .0158 L
.55519 .0151 L
.54338 .01449 L
.53686 .01421 L
.53087 .01399 L
.51911 .01366 L
.50895 .01348 L
.49784 .01341 L
.48623 .01346 L
.47544 .01362 L
.46926 .01377 L
.46257 .01397 L
.45045 .01445 L
.43867 .01506 L
.42785 .01574 L
.40339 .01772 L
.37776 .02049 L
.33542 .02668 L
.29703 .0342 L
.25662 .04435 L
.21564 .05743 L
.14771 .08739 L
.11484 .10734 L
.08845 .12755 L
.06708 .14835 L
.05132 .16815 L
.04411 .17947 L
.03757 .19192 L
.03262 .20384 L
.02913 .21491 L
.0277 .22078 L
.02661 .22635 L
.02585 .23136 L
.02525 .23681 L
.02488 .24275 L
.02481 .24575 L
.02481 .24905 L
.02503 .25488 L
.02549 .26034 L
Mistroke
.02619 .2658 L
.02708 .27097 L
.02936 .28065 L
.03267 .29098 L
.0373 .30215 L
.05044 .32513 L
.06936 .3486 L
.09165 .36951 L
.11537 .38726 L
.14295 .40414 L
.17537 .42036 L
.24074 .44493 L
.28053 .45596 L
.31949 .46449 L
.36384 .47186 L
.3893 .47506 L
.41281 .47741 L
.43291 .47895 L
.44454 .47966 L
.45524 .48019 L
.4665 .48062 L
.47243 .4808 L
.47867 .48095 L
.4892 .48112 L
.50072 .48118 L
.51145 .48112 L
.5212 .48097 L
.53244 .48067 L
.54304 .48028 L
.56186 .47931 L
.58216 .47786 L
.60403 .47582 L
.62784 .47301 L
.67493 .46554 L
.71692 .4565 L
.75445 .44622 L
.79105 .43381 L
.82808 .41826 L
.85789 .40291 L
.88642 .38497 L
.91109 .36576 L
.93014 .34724 L
.94596 .32773 L
.95766 .30868 L
.96281 .29783 L
.9667 .28759 L
.96996 .27625 L
.97132 .26987 L
.97226 .26403 L
.97294 .25791 L
Mistroke
.9733 .25224 L
.97339 .24928 L
.97339 .24602 L
.97331 .24261 L
.97314 .23942 L
.97262 .23357 L
.97189 .22823 L
.97082 .22237 L
.96939 .21623 L
.96633 .20611 L
.96212 .19541 L
.95214 .17649 L
.93634 .15476 L
.91843 .13591 L
.896 .11708 L
.86859 .09854 L
.81096 .06936 L
.77477 .05559 L
.73866 .04439 L
.69687 .03403 L
.64993 .02522 L
.62813 .02202 L
.60462 .01917 L
.58408 .01717 L
.56174 .01548 L
.54791 .01469 L
.53518 .01413 L
.52298 .01375 L
.51683 .01361 L
.5101 .0135 L
.49837 .01342 L
.4918 .01343 L
.48583 .01348 L
.47421 .01367 L
.46323 .01398 L
.45293 .01438 L
.44159 .01494 L
.41877 .01646 L
.39778 .01833 L
.37829 .0205 L
.33519 .02681 L
.2904 .03582 L
.24913 .04665 L
.21293 .05856 L
.173 .07494 L
.14013 .09177 L
.08881 .12744 L
.06656 .14915 L
.04976 .17072 L
.03797 .19143 L
Mistroke
.03293 .20343 L
.02932 .21476 L
.02782 .22094 L
.02668 .22681 L
.0259 .23209 L
.02532 .23785 L
.02512 .24082 L
.02499 .24411 L
.02494 .24754 L
.02499 .25076 L
.02528 .2565 L
.02557 .25973 L
.02591 .26269 L
.02664 .26768 L
.02765 .273 L
.03005 .28254 L
.03389 .29379 L
.03828 .3039 L
.05082 .32543 L
.06626 .345 L
.08518 .36377 L
.10971 .38318 L
.13712 .40069 L
.17009 .41781 L
.20389 .43211 L
.23702 .44367 L
.30715 .46195 L
.34701 .46929 L
.36939 .47258 L
.39073 .4752 L
.4109 .47722 L
.43288 .47894 L
.44264 .47954 L
.45297 .48008 L
.46248 .48048 L
.4715 .48078 L
.48304 .48105 L
.49355 .48118 L
.50488 .48119 L
.51127 .48115 L
.51718 .48107 L
.527 .48086 L
.53782 .48052 L
.5491 .48005 L
.55965 .47949 L
.58372 .47778 L
.60559 .47571 L
.65396 .46927 L
.6936 .46191 L
.73423 .45214 L
Mistroke
.8019 .42971 L
.83907 .41306 L
.87066 .39547 L
.8957 .37837 L
.91954 .3582 L
.93886 .33728 L
.9532 .31684 L
.95941 .30547 L
.96427 .29454 L
.96652 .28845 L
.96862 .28178 L
.97019 .27574 L
.97139 .27005 L
.97221 .26513 L
.97287 .25981 L
.97333 .25391 L
.9735 .24848 L
.97343 .24315 L
.97309 .23731 L
.97243 .23122 L
.97155 .22556 L
.97047 .22023 L
.96923 .21521 L
.96636 .20586 L
.96245 .19589 L
.95727 .18519 L
.94369 .16387 L
.92744 .14469 L
.90586 .12472 L
.87853 .1047 L
.84575 .08558 L
.81099 .06929 L
.77369 .05515 L
.73759 .04403 L
.70098 .03489 L
.65974 .0268 L
.63645 .02315 L
.61471 .02031 L
.59235 .01791 L
.5713 .01614 L
.55307 .01497 L
.54368 .01449 L
.53346 .01408 L
.52225 .01374 L
.51162 .01354 L
.50127 .01345 L
.49169 .01345 L
.48166 .01356 L
.47225 .01375 L
.46193 .01406 L
Mistroke
.45084 .0145 L
.42833 .01579 L
.40782 .01742 L
.36656 .02206 L
.34389 .02542 L
.32361 .02895 L
.25036 .04637 L
.21232 .05887 L
.17406 .07454 L
.1414 .09114 L
.11398 .10821 L
.08943 .12702 L
.07022 .14529 L
.05267 .16662 L
.0447 .17891 L
.03849 .19052 L
.03324 .20282 L
.02959 .21409 L
.02797 .22058 L
.02678 .2267 L
.02585 .23318 L
.02548 .23684 L
.02523 .2402 L
.02503 .24593 L
.02508 .25127 L
.02541 .25713 L
.02572 .26041 L
.02607 .26339 L
.02702 .2694 L
.02837 .2759 L
.03173 .28764 L
.03581 .29829 L
.04127 .30961 L
.05386 .3296 L
.07328 .35236 L
.09507 .37203 L
.12148 .39106 L
.15442 .41006 L
.22405 .43935 L
.26423 .45162 L
.30419 .46129 L
.3415 .46837 L
.38309 .47431 L
.40512 .47668 L
.42956 .47871 L
.44195 .47951 L
.45527 .4802 L
.46174 .48047 L
.46788 .48069 L
.4794 .48099 L
Mistroke
.49021 .48116 L
.50171 .48122 L
.51153 .48116 L
.52236 .48099 L
.53394 .48068 L
.54045 .48045 L
.54641 .4802 L
.5689 .47893 L
.59075 .47721 L
.61045 .47522 L
.65394 .46932 L
.69305 .46208 L
.72866 .45368 L
.80252 .42953 L
.83972 .4128 L
.87068 .39553 L
.89559 .37853 L
.91886 .35893 L
.93585 .34101 L
.95093 .32061 L
.95826 .30788 L
.9638 .29587 L
.96794 .28426 L
.96963 .27827 L
.97111 .27178 L
.97223 .26535 L
.97297 .25943 L
.97339 .25376 L
.97356 .24777 L
.97346 .2424 L
.97315 .23739 L
.97258 .2319 L
.97169 .22603 L
.97056 .22039 L
.96901 .21419 L
.96491 .20174 L
.95996 .19034 L
.95432 .17981 L
.9382 .15675 L
.91571 .13319 L
.89145 .11354 L
.86193 .09443 L
.83088 .07814 L
.8001 .06481 L
.72903 .04169 L
.68676 .03184 L
.64527 .02445 L
.62616 .02174 L
.60571 .01928 L
.58787 .0175 L
Mistroke
.56858 .01595 L
.5577 .01524 L
.54773 .0147 L
.53758 .01425 L
.52816 .01392 L
.5172 .01365 L
.51141 .01355 L
.50525 .01349 L
.49492 .01346 L
.4835 .01355 L
.4727 .01376 L
.46264 .01405 L
.45162 .01449 L
.43986 .01509 L
.41595 .01675 L
.39436 .01876 L
.35334 .02398 L
.31557 .03054 L
.27345 .04006 L
.23642 .05068 L
.19848 .06418 L
.16091 .08086 L
.1304 .09764 L
.10544 .11436 L
.0832 .13258 L
.06556 .15046 L
.04893 .17218 L
.04187 .184 L
.03567 .19683 L
.03107 .20922 L
.02929 .21534 L
.02792 .221 L
.02693 .22607 L
.02608 .23164 L
.02548 .23726 L
.02513 .24319 L
.02507 .24926 L
.02529 .25487 L
.02551 .2578 L
.02582 .26103 L
.02673 .26755 L
.02782 .27325 L
.02928 .27937 L
.03273 .29037 L
.03709 .30108 L
.04273 .31221 L
.05541 .33162 L
.07421 .35326 L
.09544 .37228 L
.1224 .39162 L
Mistroke
.15581 .41074 L
.19173 .42721 L
.22771 .44057 L
.26361 .45144 L
.30519 .4615 L
.344 .46878 L
.38136 .4741 L
.40232 .47641 L
.42164 .47813 L
.43236 .47891 L
.44409 .47964 L
.45451 .48017 L
.46552 .48062 L
.4712 .4808 L
.47742 .48096 L
.48837 .48116 L
.49455 .48121 L
.50116 .48123 L
.50741 .48121 L
.51309 .48116 L
.52411 .48097 L
.53033 .48081 L
.53607 .48063 L
.5466 .48021 L
.55774 .47965 L
.57808 .47829 L
.59703 .47665 L
.63957 .47154 L
.66142 .46811 L
.684 .46396 L
.72316 .45513 L
.76331 .44365 L
.80431 .42884 L
.83948 .41296 L
.86952 .39628 L
.91654 .36113 L
.93716 .3395 L
.95222 .3186 L
.95855 .30737 L
.96424 .29485 L
.9666 .28847 L
.96876 .2816 L
.97029 .27567 L
.97165 .26911 L
.97259 .26299 L
.97319 .25724 L
.97353 .25116 L
.97359 .24774 L
.97356 .2446 L
.97332 .23932 L
Mistroke
.9728 .23355 L
.97197 .22754 L
.97093 .22195 L
.96752 .20909 L
.96324 .19752 L
.9569 .18434 L
.94957 .17212 L
.93309 .15072 L
.91432 .1319 L
.8902 .11261 L
.86029 .09346 L
.82898 .07723 L
.79775 .06387 L
.7303 .04202 L
.68967 .03244 L
.66751 .02815 L
.64345 .02418 L
.61997 .02095 L
.59842 .01852 L
.57655 .01655 L
.55581 .01514 L
.54547 .0146 L
.53438 .01413 L
.52389 .01381 L
.51432 .01361 L
.50308 .01348 L
.49673 .01347 L
.49086 .01349 L
.48009 .01362 L
.46867 .01388 L
.45781 .01425 L
.44614 .01477 L
.42509 .01607 L
.40025 .01818 L
.37772 .02067 L
.3409 .02597 L
.30179 .0334 L
.26255 .04298 L
.22782 .05351 L
.19166 .06696 L
.15562 .08356 L
.12689 .09983 L
.09991 .11858 L
.07882 .1367 L
.05943 .15778 L
.04542 .17782 L
.03556 .19715 L
.03118 .20896 L
.02816 .22 L
.02689 .2264 L
Mistroke
.02602 .2322 L
.02567 .23543 L
.02537 .23891 L
.02519 .2422 L
.0251 .24522 L
.02513 .25075 L
.02538 .2559 L
.0259 .26155 L
.02676 .26758 L
.02798 .27389 L
.02943 .27983 L
.03294 .29089 L
.0371 .30105 L
.04246 .31168 L
.05446 .33033 L
.07071 .34964 L
.09244 .36982 L
.11866 .38916 L
.14701 .4061 L
.20825 .43368 L
.24636 .44649 L
.28385 .45664 L
.32694 .46581 L
.34995 .46974 L
.37468 .47327 L
.39682 .47585 L
.42139 .47811 L
.43224 .47891 L
.44391 .47964 L
.45488 .4802 L
.46506 .48061 L
.47111 .48081 L
.47781 .48098 L
.48454 .48111 L
.4917 .4812 L
.49797 .48124 L
.50473 .48124 L
.51112 .4812 L
.51697 .48112 L
.52798 .48089 L
.53421 .4807 L
.54001 .4805 L
.55162 .47999 L
.56417 .47928 L
.58735 .47755 L
.60906 .47542 L
.64904 .47014 L
.69432 .46186 L
.73436 .45221 L
.76996 .4415 L
Mistroke
.80591 .42821 L
.86375 .39977 L
.89387 .37988 L
.91841 .35941 L
.93684 .33991 L
.95283 .31765 L
.95914 .30624 L
.9647 .29372 L
.96873 .28176 L
.97022 .27604 L
.97137 .27068 L
.97221 .26582 L
.97289 .2606 L
.97338 .2548 L
.97359 .24952 L
.97356 .24401 L
.97325 .23803 L
.97268 .23239 L
.97193 .22719 L
.97087 .22163 L
.96945 .21566 L
.96613 .20493 L
.96094 .19232 L
.95502 .18094 L
.93936 .15812 L
.91805 .1353 L
.89471 .11589 L
.87042 .09946 L
.84119 .08317 L
.80627 .06727 L
.77116 .05424 L
.7368 .04378 L
.69971 .03459 L
.66454 .02762 L
.62465 .02154 L
.60227 .01892 L
.58082 .0169 L
.56089 .01545 L
.54234 .01446 L
.53265 .01408 L
.52191 .01377 L
.51069 .01356 L
.50014 .01348 L
.48939 .01351 L
.47763 .01367 L
.47169 .01381 L
.46535 .01399 L
.45394 .01441 L
.44257 .01497 L
.43186 .01561 L
Mistroke
.41188 .01712 L
.38849 .01943 L
.36714 .02205 L
.31992 .02973 L
.2819 .03799 L
.24282 .04872 L
.1781 .0728 L
.14308 .09029 L
.11341 .1087 L
.08796 .12838 L
.06836 .14739 L
.05148 .16846 L
.03928 .18906 L
.03415 .20064 L
.03043 .2114 L
.02875 .21756 L
.02747 .22332 L
.02642 .22935 L
.02599 .23255 L
.02562 .23598 L
.02522 .24169 L
.02509 .24699 L
.02521 .25279 L
.02537 .25572 L
.02564 .25895 L
.02627 .26434 L
.02722 .27014 L
.02964 .28058 L
.0329 .29078 L
.03727 .3014 L
.04742 .32002 L
.06336 .34149 L
.08133 .36009 L
.10418 .37901 L
.13279 .39802 L
.16261 .41413 L
.19266 .42757 L
.25798 .44987 L
.295 .45926 L
.33646 .46752 L
.37688 .47355 L
.39508 .47567 L
.41463 .47756 L
.42679 .47853 L
.43784 .47928 L
.4491 .47992 L
.45948 .4804 L
.47166 .48083 L
.47808 .48099 L
.48485 .48112 L
Mistroke
.49625 .48124 L
.50272 .48125 L
.50875 .48122 L
.52041 .48107 L
.53142 .4808 L
.5413 .48046 L
.55201 .47997 L
.57593 .47848 L
.59786 .47659 L
.63816 .47177 L
.68041 .46469 L
.71889 .45623 L
.75264 .447 L
.78996 .43445 L
.82774 .41867 L
.88717 .38472 L
.91296 .3644 L
.93338 .34396 L
.9483 .32472 L
.96066 .30313 L
.96549 .29166 L
.96951 .27891 L
.97102 .27245 L
.97171 .26888 L
.97226 .2655 L
.97269 .26235 L
.97306 .25892 L
.97349 .25291 L
.97361 .24731 L
.97357 .24413 L
.97345 .24114 L
.97299 .23513 L
.97261 .23175 L
.97217 .22866 L
.97 .21779 L
.96854 .21236 L
.96666 .20643 L
.96215 .19495 L
.956 .18267 L
.94161 .16096 L
.92371 .14075 L
.90395 .12305 L
.84846 .08692 L
.81546 .07113 L
.77579 .05581 L
.73647 .04369 L
.69707 .03401 L
.66028 .02689 L
.61894 .02082 L
.59498 .01818 L
Mistroke
.57306 .01629 L
.56084 .01545 L
.54757 .01471 L
.53501 .01417 L
.52345 .01381 L
.51268 .01359 L
.50263 .01349 L
.49161 .0135 L
.48542 .01356 L
.4798 .01364 L
.46846 .0139 L
.46207 .0141 L
.45616 .01433 L
.44529 .01483 L
.43388 .01549 L
.4125 .01708 L
.39306 .01894 L
.34995 .02454 L
.31369 .03095 L
.27542 .03961 L
.23553 .05101 L
.19565 .06536 L
.13234 .09651 L
.10353 .11583 L
.08061 .13503 L
.05973 .15743 L
.05089 .16931 L
.04281 .18235 L
.03695 .194 L
.03261 .20477 L
.02923 .2157 L
.02792 .22118 L
.02695 .22614 L
.02606 .23204 L
.02569 .23528 L
.02543 .23832 L
.02515 .24376 L
.02511 .24962 L
.02521 .25272 L
.02541 .25612 L
.02571 .25966 L
.02609 .26295 L
.02699 .26885 L
.02827 .27514 L
.03159 .28697 L
.03637 .29938 L
.04816 .32117 L
.06531 .34372 L
.08933 .3672 L
.11407 .38606 L
Mistroke
.14456 .40476 L
.2087 .43384 L
.24733 .44678 L
.28534 .457 L
.32904 .4662 L
.35209 .47008 L
.37744 .47363 L
.40201 .47639 L
.42484 .47839 L
.44683 .47981 L
.45796 .48034 L
.46424 .48059 L
.47019 .48079 L
.48131 .48106 L
.49146 .48121 L
.5024 .48126 L
.50857 .48123 L
.51429 .48117 L
.52378 .481 L
.53424 .48072 L
.54515 .4803 L
.55537 .4798 L
.57689 .47841 L
.59678 .4767 L
.64126 .47133 L
.68339 .46411 L
.72666 .45427 L
.76503 .44313 L
.79915 .43094 L
.8565 .40396 L
.88276 .38777 L
.90821 .36853 L
.93064 .34702 L
.94757 .32579 L
.95423 .31531 L
.95967 .30519 L
.96385 .29589 L
.96748 .28589 L
.96918 .28017 L
.97048 .27497 L
.97157 .26966 L
.97237 .26478 L
.97305 .25905 L
.97331 .25603 L
.97349 .25284 L
.97361 .24748 L
.97348 .2416 L
.97304 .23552 L
.97236 .22991 L
.97132 .22376 L
Mistroke
.96987 .21726 L
.96666 .20642 L
.96199 .19459 L
.95033 .17324 L
.9359 .15392 L
.91495 .13244 L
.89209 .11395 L
.86345 .09527 L
.82895 .0772 L
.79399 .06241 L
.75989 .05058 L
.7232 .04017 L
.68786 .03207 L
.645 .02442 L
.62235 .02125 L
.59714 .0184 L
.57496 .01644 L
.55408 .01505 L
.54251 .01448 L
.53192 .01406 L
.52607 .01388 L
.51968 .01372 L
.50807 .01354 L
.49723 .01349 L
.48729 .01354 L
.47638 .01371 L
.46489 .01401 L
.45489 .01438 L
.44559 .01482 L
.42455 .01613 L
.40148 .01809 L
.38069 .02034 L
.3349 .02701 L
.29214 .03557 L
.24791 .04719 L
.20891 .06022 L
.17495 .07423 L
.11798 .10561 L
.09263 .12444 L
.06954 .14613 L
.0597 .15747 L
.05032 .17016 L
.04324 .18159 L
.03696 .19398 L
.03203 .20642 L
.0287 .21781 L
.02747 .22334 L
.02643 .22934 L
.02572 .23501 L
.0253 .24024 L
Mistroke
.0251 .24612 L
.02517 .25168 L
.02545 .25668 L
.02599 .2621 L
.02684 .26799 L
.02807 .27422 L
.03106 .28535 L
.03473 .2955 L
.03895 .30493 L
.05136 .32596 L
.06913 .34793 L
.08915 .36704 L
.11479 .38655 L
.14626 .40568 L
.17895 .42173 L
.21122 .43477 L
.28035 .45579 L
.32195 .46488 L
.34451 .46887 L
.36881 .4725 L
.39035 .47516 L
.41431 .47754 L
.43629 .47919 L
.45696 .4803 L
.46812 .48072 L
.47436 .48091 L
.48001 .48104 L
.49104 .48121 L
.50142 .48126 L
.50733 .48124 L
.51357 .48118 L
.52473 .48098 L
.53094 .48082 L
.53672 .48063 L
.54984 .48009 L
.56124 .47947 L
.57199 .47877 L
.59203 .47715 L
.61342 .47495 L
.63639 .47202 L
.67596 .46555 L
.71649 .45683 L
.78439 .43651 L
.8186 .42283 L
.84752 .40885 L
.87585 .39234 L
.90313 .37272 L
.92463 .35336 L
.94128 .33441 L
.95408 .31557 L
Mistroke
.96425 .29489 L
.96838 .28298 L
.97001 .27695 L
.97146 .27029 L
.9724 .26459 L
.97311 .25847 L
.9735 .25269 L
.97362 .24741 L
.97357 .2442 L
.97344 .2408 L
.97295 .23469 L
.97255 .23131 L
.97209 .22814 L
.97073 .22092 L
.9692 .21467 L
.9675 .20896 L
.9627 .19619 L
.95166 .17531 L
.93536 .15329 L
.91386 .13146 L
.88995 .11241 L
.86221 .09455 L
.82841 .07695 L
.79573 .06308 L
.75849 .05015 L
.72293 .04011 L
.68192 .03087 L
.64323 .02415 L
.60607 .01933 L
.58348 .01713 L
.56236 .01555 L
.55014 .01484 L
.53904 .01433 L
.53288 .0141 L
.52621 .01389 L
.51995 .01373 L
.51411 .01362 L
.50344 .0135 L
.49175 .0135 L
.48036 .01363 L
.47398 .01376 L
.46817 .01391 L
.45779 .01427 L
.44654 .01477 L
.42617 .01601 L
.4066 .0176 L
.38521 .01981 L
.34265 .02571 L
.30437 .03288 L
.26974 .04108 L
Mistroke
.19643 .06505 L
.16333 .07972 L
.13051 .09762 L
.10544 .11441 L
.08209 .13365 L
.06473 .15147 L
.04966 .17115 L
.04279 .18239 L
.03652 .19495 L
.032 .20653 L
.02878 .21746 L
.02732 .22411 L
.02674 .22739 L
.02628 .23043 L
.02562 .23612 L
.02538 .23912 L
.0252 .24232 L
.02511 .24547 L
.02511 .24888 L
.02519 .25209 L
.02534 .25503 L
.02559 .25829 L
.02596 .26186 L
.02646 .26558 L
.02703 .26904 L
.02821 .27485 L
.0298 .28113 L
.03353 .29245 L
.03819 .30335 L
.04337 .31328 L
.05824 .33524 L
.07852 .35744 L
.12461 .393 L
.15583 .41073 L
.18738 .42538 L
.21893 .43755 L
.2556 .4492 L
.28936 .45796 L
.32734 .46589 L
.35065 .46986 L
.37244 .47299 L
.39312 .47547 L
.41604 .47769 L
.43681 .47923 L
.4563 .48027 L
.46711 .48069 L
.47697 .48097 L
.48836 .48118 L
.49916 .48126 L
.5099 .48122 L
Mistroke
.51602 .48115 L
.52176 .48105 L
.53329 .48075 L
.53977 .48052 L
.54571 .48028 L
.56657 .47914 L
.58841 .47747 L
.61204 .4751 L
.63379 .47239 L
.682 .46439 L
.723 .45521 L
.76522 .44308 L
.80015 .43055 L
.83445 .41548 L
.86271 .40041 L
.89058 .3823 L
.91124 .36593 L
.93063 .34704 L
.94827 .32476 L
.95488 .3142 L
.96083 .30277 L
.96563 .29129 L
.96901 .28079 L
.97032 .27569 L
.97148 .27016 L
.97235 .26493 L
.97295 .26011 L
.97341 .25447 L
.97361 .24844 L
.97353 .24274 L
.97322 .23755 L
.97258 .23147 L
.97208 .22805 L
.97153 .22489 L
.97023 .21873 L
.96873 .21298 L
.96494 .20168 L
.95953 .18937 L
.94473 .16511 L
.92813 .14528 L
.90602 .12474 L
.88073 .10605 L
.84995 .08772 L
.81774 .07212 L
.78606 .05945 L
.71842 .03897 L
.67886 .03027 L
.63547 .02302 L
.59744 .01843 L
.57554 .01648 L
Mistroke
.55493 .0151 L
.54347 .01452 L
.53741 .01427 L
.53097 .01403 L
.52535 .01387 L
.51914 .01372 L
.50817 .01354 L
.49756 .01349 L
.48612 .01355 L
.47532 .01373 L
.46542 .014 L
.45387 .01443 L
.44314 .01495 L
.4189 .01656 L
.39546 .01869 L
.37069 .02159 L
.3255 .02869 L
.28528 .03718 L
.24318 .04862 L
.20139 .06309 L
.13912 .09254 L
.10887 .11191 L
.08437 .13158 L
.06431 .15196 L
.0553 .16315 L
.04695 .17535 L
.04017 .1873 L
.0351 .19829 L
.03103 .20947 L
.02955 .21452 L
.02816 .22008 L
.02713 .22512 L
.02626 .23053 L
.0256 .23626 L
.02523 .2416 L
.0251 .24694 L
.02518 .25199 L
.02544 .25652 L
.02591 .26143 L
.02665 .26678 L
.02773 .27266 L
.0308 .28451 L
.03468 .29538 L
.03921 .30546 L
.05152 .32618 L
.06914 .34794 L
.09197 .36942 L
.11702 .38806 L
.17034 .41782 L
.20434 .4322 L
Mistroke
.23747 .44374 L
.27489 .45442 L
.31647 .46381 L
.35328 .47026 L
.39484 .47565 L
.41859 .4779 L
.44045 .47945 L
.45258 .4801 L
.45899 .48039 L
.46583 .48065 L
.47241 .48086 L
.47837 .48101 L
.49 .4812 L
.5016 .48126 L
.51225 .4812 L
.52393 .481 L
.52981 .48086 L
.53624 .48065 L
.54708 .48022 L
.55865 .47963 L
.57943 .47822 L
.61098 .47523 L
.63968 .47156 L
.67059 .46654 L
.70251 .46009 L
.7537 .44669 L
.80576 .42829 L
Mfstroke
.92103 .3545 m
.93835 .3354 L
.95138 .31687 L
.96209 .29589 L
.96641 .28391 L
.96928 .27292 L
.97035 .26729 L
.9712 .2613 L
.97168 .25619 L
.97196 .25054 L
.97197 .24449 L
.97184 .24108 L
.97164 .23797 L
.97101 .23194 L
.97014 .22622 L
.96909 .22095 L
.96771 .21534 L
.96458 .2053 L
.95974 .19348 L
.95434 .18291 L
.93854 .15952 L
.91981 .13896 L
.89486 .11767 L
.86385 .0969 L
.80202 .06649 L
.76225 .05202 L
.72257 .04047 L
.68209 .03112 L
.66008 .02695 L
.63626 .0231 L
.61519 .02023 L
.59165 .0176 L
.57003 .01571 L
.56028 .01501 L
.54958 .01435 L
.53981 .01385 L
.52935 .01343 L
.51828 .01309 L
.50798 .01289 L
.49767 .01279 L
.48794 .0128 L
.4792 .01288 L
.46973 .01306 L
.45937 .01336 L
.448 .01381 L
.43614 .01442 L
.42509 .01512 L
.40541 .01668 L
.38443 .01879 L
.33914 .02506 L
Mistroke
.29847 .03283 L
.2557 .04352 L
.21283 .05732 L
.17495 .07273 L
.14242 .08913 L
.09093 .1242 L
.07064 .14317 L
.0524 .16509 L
.04485 .17652 L
.03803 .18898 L
.0332 .19991 L
.02909 .21191 L
.02754 .21774 L
.02619 .22396 L
.02529 .22927 L
.02456 .23515 L
.02414 .24063 L
.02396 .24654 L
.02405 .25212 L
.02435 .25723 L
.02485 .26221 L
.0255 .26683 L
.02641 .27189 L
.02761 .27727 L
.03081 .28821 L
.03456 .29804 L
.04601 .31984 L
.06243 .34202 L
.07983 .36007 L
.10232 .37878 L
.13024 .39746 L
.16412 .41564 L
.23421 .44314 L
.27482 .45466 L
.31432 .46348 L
.35936 .47109 L
.38265 .4741 L
.4087 .47677 L
.43157 .47853 L
.4527 .47969 L
.46381 .48013 L
.47018 .48032 L
.47599 .48046 L
.48214 .48057 L
.48872 .48065 L
.49482 .48069 L
.50058 .48069 L
.51109 .48061 L
.52222 .48041 L
.53172 .48014 L
Mistroke
.54215 .47975 L
.55333 .4792 L
.56532 .47848 L
.58688 .47681 L
.60903 .4746 L
.63237 .47169 L
.67347 .46505 L
.7205 .45482 L
.76094 .44338 L
.79699 .43071 L
.83305 .41506 L
.86377 .39866 L
.88946 .38196 L
.91326 .36295 L
.9317 .34457 L
.94836 .32315 L
.95581 .31085 L
.96153 .29928 L
.96597 .28791 L
.96948 .27572 L
.97081 .26937 L
.97175 .2634 L
.97216 .25997 L
.97245 .25683 L
.97267 .25338 L
.97279 .24975 L
.97277 .24408 L
.97245 .23802 L
.97188 .23232 L
.97112 .22715 L
.96995 .22108 L
.96833 .21452 L
.96448 .20271 L
.95998 .19209 L
.95408 .18084 L
.94071 .16101 L
.92039 .13847 L
.89785 .11906 L
.87065 .10026 L
.83697 .08157 L
.76625 .05288 L
.72536 .04086 L
.68486 .03146 L
.6471 .02464 L
.60517 .01902 L
.5829 .01681 L
.55829 .01497 L
.54581 .01427 L
.53893 .01395 L
.53241 .01369 L
Mistroke
.52634 .01349 L
.51975 .01331 L
.50821 .0131 L
.49741 .01302 L
.49127 .01303 L
.48552 .01307 L
.47394 .01325 L
.46743 .01341 L
.46149 .01359 L
.45094 .01401 L
.43946 .01458 L
.41861 .01597 L
.39618 .01798 L
.37215 .02073 L
.32945 .02725 L
.28925 .03549 L
.25376 .0447 L
.17979 .07127 L
.14682 .08744 L
.11447 .10717 L
.08841 .12716 L
.06754 .14741 L
.05214 .16649 L
.03916 .18804 L
.03403 .19941 L
.02964 .21212 L
.02794 .21855 L
.02649 .22551 L
.02596 .22872 L
.02549 .2321 L
.02488 .23815 L
.02459 .24377 L
.02456 .24977 L
.0248 .25543 L
.02525 .26057 L
.02605 .2666 L
.02726 .27312 L
.03034 .28489 L
.0342 .29565 L
.03942 .30707 L
.05161 .32723 L
.07059 .35021 L
.09201 .37004 L
.11811 .38926 L
.1507 .40843 L
.21974 .43801 L
.2598 .45047 L
.29964 .46029 L
.33687 .46751 L
.37834 .47357 L
Mistroke
.40038 .47602 L
.42478 .47814 L
.43716 .47897 L
.45047 .47971 L
.46306 .48023 L
.47455 .48058 L
.48601 .4808 L
.4966 .48089 L
.50823 .48085 L
.5141 .48079 L
.52057 .48068 L
.53138 .4804 L
.543 .47997 L
.55395 .47944 L
.56395 .47886 L
.58589 .47722 L
.60566 .47531 L
.64927 .4696 L
.68853 .46253 L
.72426 .45433 L
.79855 .4306 L
.83604 .41413 L
.86727 .39712 L
.89257 .38028 L
.91624 .36085 L
.9336 .34307 L
.94908 .32283 L
.95667 .31015 L
.96245 .2982 L
.96684 .28664 L
.96864 .28067 L
.97025 .27421 L
.9714 .26841 L
.97221 .26307 L
.97277 .25796 L
.97312 .25256 L
.97323 .24663 L
.97307 .24111 L
.9726 .23506 L
.97221 .23167 L
.97177 .2286 L
.96966 .218 L
.96804 .212 L
.96625 .20641 L
.96145 .1943 L
.95597 .18337 L
.94351 .16405 L
.92652 .14408 L
.90443 .12382 L
.87598 .10325 L
Mistroke
.81371 .07054 L
.77632 .05609 L
.7386 .0443 L
.70251 .03518 L
.66281 .02723 L
.64161 .02378 L
.61799 .02055 L
.59599 .0181 L
.57576 .01629 L
.55166 .01469 L
.53834 .01405 L
.53221 .01382 L
.52569 .01361 L
.514 .01334 L
.50317 .01321 L
.49152 .01321 L
.48489 .01326 L
.47867 .01335 L
.46816 .01359 L
.45694 .01397 L
.44638 .01444 L
.43681 .01497 L
.41344 .01664 L
.39155 .01873 L
.34868 .02435 L
.30364 .03263 L
.26606 .04164 L
.22821 .053 L
.16638 .07783 L
.13594 .09398 L
.11091 .11006 L
.08717 .12867 L
.06537 .1503 L
.04923 .17128 L
.04282 .18179 L
.03783 .19144 L
.03377 .20088 L
.03023 .21117 L
.02866 .21687 L
.02745 .22213 L
.02652 .22709 L
.02574 .23248 L
.02516 .23839 L
.02488 .24399 L
.02485 .24943 L
.02504 .25446 L
.02547 .25989 L
.02623 .26586 L
.02734 .27207 L
.02866 .27788 L
Mistroke
.03179 .28838 L
.03545 .29791 L
.04646 .31896 L
.06243 .34074 L
.08456 .36331 L
.10971 .38324 L
.1365 .40037 L
.16771 .4167 L
.20487 .43246 L
.24019 .44461 L
.2798 .45562 L
.31725 .4639 L
.3599 .47113 L
.37901 .47369 L
.39974 .47601 L
.41767 .47765 L
.4376 .47909 L
.44929 .47975 L
.46029 .48024 L
.47193 .48063 L
.47849 .48079 L
.4845 .48091 L
.49463 .48101 L
.50572 .48102 L
.5173 .48089 L
.52806 .48066 L
.53421 .48047 L
.54088 .48023 L
.55296 .47968 L
.57547 .47825 L
.60155 .47595 L
.62534 .47322 L
.66493 .46725 L
.7071 .45875 L
.74915 .44775 L
.78629 .43552 L
.82071 .4216 L
.85504 .40449 L
.88223 .38785 L
.9077 .36867 L
.92912 .34837 L
.94507 .32902 L
.95155 .31939 L
.95763 .30881 L
.96249 .29864 L
.96616 .28927 L
.96947 .27837 L
.97087 .27233 L
.97191 .26661 L
.97264 .2613 L
Mistroke
.9731 .2564 L
.97338 .25101 L
.97342 .24528 L
.97318 .23956 L
.97293 .23634 L
.97263 .23339 L
.97188 .22797 L
.97084 .22228 L
.96773 .21026 L
.96297 .19726 L
.95701 .18486 L
.95048 .17378 L
.93202 .14972 L
.91042 .12862 L
.8863 .10997 L
.82897 .07728 L
.79575 .06312 L
.75637 .04948 L
.72071 .03951 L
.68063 .03055 L
.64141 .02378 L
.60466 .01906 L
.58264 .01692 L
.56255 .01542 L
.55135 .01475 L
.53922 .01418 L
.52775 .01377 L
.5172 .01351 L
.50737 .01336 L
.4982 .01331 L
.48813 .01335 L
.47737 .0135 L
.46608 .01379 L
.45542 .01417 L
.44587 .01461 L
.43552 .01519 L
.41351 .01679 L
.38947 .01912 L
.34174 .02564 L
.29898 .03382 L
.26055 .04334 L
.22297 .05497 L
.18467 .06973 L
.1536 .08443 L
.12358 .10175 L
.09734 .12042 L
.07677 .13852 L
.06052 .15625 L
.04608 .17652 L
.04019 .187 L
Mistroke
.03492 .1984 L
.03056 .21058 L
.02901 .21606 L
.02761 .22205 L
.02651 .22802 L
.02576 .23355 L
.02527 .23884 L
.02501 .24447 L
.02499 .24949 L
.02517 .2542 L
.02557 .25937 L
.02624 .26492 L
.02727 .27099 L
.0285 .27661 L
.03225 .28928 L
.03719 .30148 L
.04384 .31432 L
.05944 .33693 L
.07744 .35654 L
.09942 .37549 L
.12638 .39418 L
.1833 .42366 L
.21912 .43761 L
.25495 .44899 L
.29647 .45954 L
.3432 .46858 L
.36486 .47187 L
.38824 .47483 L
.40868 .47693 L
.43096 .47872 L
.44473 .47958 L
.45742 .4802 L
.46958 .48065 L
.47571 .48081 L
.48244 .48096 L
.49414 .4811 L
.5007 .48112 L
.50667 .48111 L
.51828 .48097 L
.52925 .48073 L
.53954 .48039 L
.55086 .47989 L
.57368 .4785 L
.59468 .47675 L
.6142 .4747 L
.6574 .46866 L
.70239 .45996 L
.74184 .45 L
.77665 .4391 L
.81534 .42411 L
Mistroke
.84755 .4087 L
.90356 .37225 L
.92792 .34981 L
.94636 .32738 L
.95874 .30687 L
.96413 .29496 L
.96808 .28371 L
.96978 .27757 L
.97109 .27173 L
.97204 .26647 L
.9728 .26074 L
.97309 .25777 L
.97333 .2545 L
.97348 .25108 L
.97353 .24787 L
.97342 .24213 L
.97324 .23891 L
.973 .23595 L
.97243 .23097 L
.97159 .22565 L
.9695 .21611 L
.96603 .20485 L
.96196 .19471 L
.95015 .17309 L
.93535 .15338 L
.91709 .13447 L
.89325 .11485 L
.86648 .0971 L
.8341 .07967 L
.80084 .06507 L
.76811 .05321 L
.69861 .0343 L
.65907 .02662 L
.63683 .02314 L
.61559 .02035 L
.59552 .01816 L
.57361 .01625 L
.55357 .01494 L
.54389 .01445 L
.53505 .01408 L
.52435 .01374 L
.51287 .0135 L
.50222 .0134 L
.49214 .0134 L
.48041 .01353 L
.46958 .01377 L
.46393 .01394 L
.4577 .01416 L
.44512 .01474 L
.42171 .01623 L
Mistroke
.39668 .01845 L
.37331 .02113 L
.35215 .02409 L
.31231 .03112 L
.27136 .04054 L
.20293 .06239 L
.1652 .07871 L
.13299 .09603 L
.10736 .11291 L
.08281 .1329 L
.06281 .15362 L
.04779 .17392 L
.03596 .19612 L
.03118 .20884 L
.0295 .2145 L
.028 .22056 L
.02687 .22628 L
.02608 .23146 L
.02551 .23669 L
.02518 .2416 L
.02504 .24736 L
.02516 .25265 L
.02555 .25845 L
.02626 .26456 L
.02706 .26952 L
.02815 .27482 L
.03069 .28433 L
.03469 .29554 L
.03924 .30562 L
.05194 .32687 L
.06962 .34851 L
.08797 .36607 L
.1115 .38431 L
.14032 .4024 L
.17513 .42002 L
.24672 .44657 L
.28766 .45752 L
.32747 .46587 L
.37274 .47297 L
.39861 .47599 L
.42235 .47813 L
.43345 .47894 L
.44522 .47965 L
.45541 .48016 L
.46637 .48059 L
.47254 .48079 L
.47818 .48093 L
.48921 .48111 L
.49539 .48117 L
.5021 .48118 L
Mistroke
.50845 .48115 L
.51432 .48109 L
.52465 .48091 L
.53434 .48064 L
.54495 .48023 L
.55638 .47967 L
.57953 .47813 L
.60062 .47624 L
.64156 .4712 L
.68413 .46388 L
.72284 .45517 L
.75652 .44575 L
.79397 .43288 L
.83153 .41682 L
.86347 .39989 L
.89019 .38253 L
.91391 .36351 L
.93236 .34507 L
.94902 .32358 L
.9565 .31123 L
.96225 .29957 L
.96669 .28819 L
.97022 .27595 L
.97167 .26892 L
.97224 .26546 L
.97267 .26228 L
.97325 .2563 L
.97344 .25316 L
.97356 .24984 L
.97354 .24416 L
.97323 .23808 L
.97265 .23235 L
.9719 .22714 L
.97072 .22105 L
.9691 .21444 L
.96523 .20253 L
.96075 .19196 L
.95488 .18073 L
.94155 .16093 L
.92131 .13842 L
.89879 .11899 L
.8414 .08327 L
.80759 .0678 L
.76738 .05297 L
.72683 .04108 L
.68656 .03177 L
.64903 .025 L
.60723 .01941 L
.58514 .01722 L
.56064 .01539 L
Mistroke
.54824 .01469 L
.5414 .01437 L
.53489 .01411 L
.52885 .01391 L
.52227 .01373 L
.51073 .01351 L
.5 .01343 L
.49389 .01344 L
.48815 .01347 L
.4766 .01365 L
.47011 .0138 L
.46415 .01398 L
.45415 .01436 L
.44322 .01489 L
.42127 .01631 L
.39907 .01826 L
.37522 .02095 L
.33273 .02733 L
.29271 .03539 L
.25724 .04443 L
.18329 .07048 L
.15019 .08638 L
.11754 .10586 L
.09138 .12544 L
.07024 .14535 L
.05454 .16413 L
.04112 .18544 L
.03527 .19783 L
.03109 .20921 L
.02925 .21557 L
.02763 .22247 L
.02646 .22901 L
.0257 .23504 L
.02526 .24065 L
.02508 .24588 L
.02515 .25163 L
.0253 .25484 L
.02552 .25778 L
.02617 .26367 L
.02666 .267 L
.0272 .27007 L
.02993 .28164 L
.0336 .29268 L
.03786 .3027 L
.05053 .32477 L
.06512 .34353 L
.08383 .36238 L
.13404 .39876 L
.16822 .41682 L
.20329 .43178 L
Mistroke
.24011 .44455 L
.28259 .45631 L
.32475 .46538 L
.36505 .47195 L
.4023 .47638 L
.42376 .47827 L
.44398 .47961 L
.45494 .48017 L
.46538 .48059 L
.47476 .48088 L
.48499 .48109 L
.4961 .4812 L
.50231 .48122 L
.50793 .48119 L
.51888 .48106 L
.52918 .48083 L
.53958 .48049 L
.55069 .48 L
.57066 .47882 L
.59425 .4769 L
.61553 .47466 L
.66097 .46818 L
.70256 .46004 L
.77145 .44098 L
.80719 .42767 L
.8378 .4138 L
.866 .39843 L
.89317 .38039 L
.91377 .36367 L
.93302 .34435 L
.95021 .32182 L
.95765 .30914 L
.96331 .29717 L
.96751 .28576 L
.97039 .27532 L
.97159 .26951 L
.97211 .26644 L
.97258 .26319 L
.9732 .25722 L
.97353 .25172 L
.9736 .24606 L
.97352 .24287 L
.97337 .23991 L
.97292 .23449 L
.97217 .22873 L
.97128 .22362 L
.97024 .21882 L
.96716 .20795 L
.96277 .19638 L
.95775 .18589 L
Mistroke
.94305 .16285 L
.92783 .14497 L
.90792 .12632 L
.85819 .09225 L
.82523 .07547 L
.79114 .06132 L
.7208 .03955 L
.67837 .03015 L
.63773 .02332 L
.61419 .02023 L
.59188 .01786 L
.56839 .01593 L
.55586 .01513 L
.54234 .01444 L
.53047 .01399 L
.5197 .0137 L
.51373 .01358 L
.50726 .0135 L
.49554 .01346 L
.48452 .01354 L
.47289 .01376 L
.46298 .01405 L
.45212 .01448 L
.43931 .01513 L
.42768 .01587 L
.40169 .01804 L
.37786 .02065 L
.35558 .02366 L
.31352 .03096 L
.27602 .03943 L
.23705 .05051 L
.19766 .06454 L
.16395 .0794 L
.1357 .0945 L
.08854 .12788 L
.06842 .14733 L
.05061 .16972 L
.04335 .18139 L
.03691 .19408 L
.03209 .20622 L
.03026 .21196 L
.0288 .21736 L
.02754 .22294 L
.02662 .22806 L
.02585 .23375 L
.02532 .23987 L
.0251 .24574 L
.0251 .24906 L
.02518 .25214 L
.02553 .25777 L
Mistroke
.02619 .26375 L
.02707 .2693 L
.0283 .27527 L
.03128 .28603 L
.03509 .2964 L
.03939 .30583 L
.05215 .32709 L
.07054 .34943 L
.09442 .37143 L
.12071 .39049 L
.14987 .40762 L
.18506 .42439 L
.21883 .4375 L
.2571 .44961 L
.29341 .45888 L
.33513 .46727 L
.37433 .47321 L
.41188 .4773 L
.43455 .47906 L
.44544 .47971 L
.45573 .48023 L
.46161 .48047 L
.46797 .4807 L
.47908 .481 L
.48539 .48112 L
.49206 .4812 L
.49776 .48123 L
.50402 .48123 L
.51552 .48113 L
.52599 .48093 L
.53178 .48077 L
.53807 .48056 L
.54949 .48008 L
.57142 .47879 L
.59158 .47717 L
.62871 .47305 L
.66878 .46684 L
.70927 .45853 L
.74571 .44904 L
.81682 .4236 L
.84865 .40824 L
.87997 .38964 L
.90362 .37232 L
.92539 .35257 L
.94242 .33292 L
.95479 .31434 L
.96066 .30314 L
.96517 .29252 L
.96886 .28132 L
.97039 .27535 L
Mistroke
.97171 .2689 L
.97255 .26343 L
.97319 .25746 L
.97353 .25181 L
.97361 .24657 L
.97346 .24137 L
.97314 .23667 L
.97254 .23126 L
.97176 .22617 L
.97065 .22059 L
.96914 .21448 L
.96516 .20226 L
.96036 .19108 L
.95494 .18079 L
.93942 .15818 L
.91792 .13516 L
.89313 .11471 L
.86666 .09717 L
.83468 .07993 L
.79562 .06303 L
.72236 .03995 L
.67898 .03028 L
.63669 .02318 L
.59592 .01826 L
.57249 .01624 L
.55055 .01485 L
.53852 .01429 L
.52716 .0139 L
.51695 .01365 L
.50588 .0135 L
.50012 .01347 L
.49379 .01348 L
.48719 .01352 L
.48101 .01361 L
.46998 .01385 L
.46379 .01403 L
.45815 .01424 L
.43717 .01528 L
.41784 .01663 L
.39677 .01854 L
.37458 .02107 L
.33801 .02646 L
.29877 .03408 L
.25971 .04378 L
.22071 .05596 L
.15766 .08254 L
.12691 .09984 L
.10147 .1174 L
.0774 .1381 L
.05641 .16167 L
Mistroke
.04852 .17288 L
.04137 .185 L
.03622 .19564 L
.03176 .20723 L
.02975 .21376 L
.02823 .21977 L
.02699 .2259 L
.02612 .2316 L
.02574 .2348 L
.02544 .23822 L
.02521 .24202 L
.02511 .24546 L
.0251 .24872 L
.02519 .25224 L
.02537 .25557 L
.02562 .25863 L
.02624 .26404 L
.02717 .26982 L
.02955 .28021 L
.03144 .28652 L
.03354 .29247 L
.03826 .30351 L
.05097 .32539 L
.06939 .34821 L
.08989 .36767 L
.11231 .38484 L
.14271 .40373 L
.17386 .41944 L
.2457 .44628 L
.28719 .45744 L
.33307 .46692 L
.35483 .47049 L
.37566 .47339 L
.39482 .47564 L
.41528 .47761 L
.43776 .47927 L
.44779 .47985 L
.4586 .48036 L
.47022 .48078 L
.48111 .48105 L
.48776 .48116 L
.49407 .48122 L
.49974 .48125 L
.50591 .48124 L
.51706 .48112 L
.52754 .4809 L
.53694 .48062 L
.54708 .48021 L
.5698 .47892 L
.59053 .47727 L
Mistroke
.62796 .47316 L
.66658 .46725 L
.7076 .45893 L
.74343 .4497 L
.78006 .43805 L
.81719 .42345 L
.84874 .4082 L
.87523 .39274 L
.91907 .3588 L
.93716 .33954 L
.95272 .31784 L
.95874 .30706 L
.96353 .29665 L
.96735 .2863 L
.97004 .27683 L
.97133 .27095 L
.97228 .26539 L
.97301 .25951 L
.9733 .25619 L
.97348 .25314 L
.97361 .24802 L
.97351 .2424 L
.97313 .23654 L
.97252 .23108 L
.97207 .22798 L
.97148 .22462 L
.97018 .21852 L
.96691 .20716 L
.96175 .19404 L
.95568 .18207 L
.94235 .16192 L
.92407 .14111 L
.88132 .10644 L
.85135 .08846 L
.81608 .0714 L
.77998 .05727 L
.74489 .04606 L
.70889 .03667 L
.66816 .02826 L
.64515 .02444 L
.6236 .02141 L
.6014 .01883 L
.58043 .01687 L
.56237 .01554 L
.54286 .01449 L
.53171 .01405 L
.52112 .01375 L
.51159 .01358 L
.5012 .01349 L
.49008 .01351 L
Mistroke
.48001 .01363 L
.4684 .0139 L
.45749 .01427 L
.44737 .01472 L
.43808 .01523 L
.41722 .01669 L
.39561 .01867 L
.3761 .02089 L
.33308 .02732 L
.29448 .03504 L
.25935 .04389 L
.18691 .06898 L
.1506 .0862 L
.1205 .10394 L
.09659 .12121 L
.07438 .14109 L
.057 .1609 L
.04427 .1798 L
.03874 .19017 L
.03386 .20139 L
.03154 .20791 L
.02973 .21385 L
.02829 .21951 L
.02706 .22552 L
.02656 .22852 L
.02609 .23182 L
.02549 .23764 L
.02527 .24091 L
.02513 .24443 L
.0251 .24776 L
.02515 .25079 L
.02545 .25664 L
.02575 .25995 L
.0261 .26302 L
.02695 .26862 L
.02814 .27456 L
.03147 .2866 L
.03627 .29915 L
.04813 .32112 L
.06543 .34385 L
.08955 .36738 L
.11454 .38638 L
.14517 .40509 L
.20939 .43409 L
.24862 .44716 L
.28701 .4574 L
.33115 .46658 L
.35437 .47042 L
.37976 .47391 L
.40223 .47641 L
Mistroke
.42299 .47824 L
.43302 .47897 L
.44401 .47965 L
.45434 .48018 L
.46409 .48058 L
.47003 .48078 L
.47647 .48096 L
.48771 .48117 L
.4941 .48123 L
.50085 .48125 L
.50661 .48124 L
.51293 .48119 L
.52425 .48099 L
.53059 .48083 L
.53637 .48064 L
.54759 .48019 L
.55819 .47965 L
.57911 .47824 L
.59863 .47652 L
.64245 .47115 L
.68397 .464 L
.72702 .45418 L
.76307 .44377 L
.79886 .43106 L
.85626 .4041 L
.88453 .38657 L
.9072 .36938 L
.92817 .34969 L
.94663 .32715 L
.95343 .31668 L
.95957 .3054 L
.96429 .29481 L
.96783 .28479 L
.97039 .27536 L
.9715 .27005 L
.97231 .26518 L
.97298 .25985 L
.97343 .25404 L
.97361 .24855 L
.97355 .24345 L
.97321 .23745 L
.97293 .23443 L
.97253 .23113 L
.97161 .22528 L
.97049 .21985 L
.96708 .20766 L
.96206 .19475 L
.95606 .18276 L
.94926 .17161 L
.93367 .15134 L
Mistroke
.91498 .13246 L
.89481 .11595 L
.86986 .09911 L
.83978 .08245 L
.80658 .06739 L
.77377 .05512 L
.70378 .0355 L
.66418 .02756 L
.61944 .02089 L
.59639 .01832 L
.57154 .01618 L
.5594 .01536 L
.54791 .01473 L
.53757 .01427 L
.52636 .01389 L
.51532 .01364 L
.50524 .01351 L
.4936 .01349 L
.48257 .0136 L
.47241 .0138 L
.463 .01407 L
.4527 .01448 L
.44176 .01502 L
.41917 .01653 L
.39811 .01842 L
.37495 .02104 L
.35086 .0244 L
.30667 .03239 L
.26771 .04161 L
.22788 .05352 L
.18723 .06884 L
.15288 .08501 L
.12357 .10195 L
.07798 .13754 L
.05822 .15933 L
.04394 .18037 L
.03804 .19164 L
.0328 .20423 L
.03068 .21062 L
.02877 .21753 L
.02733 .2241 L
.02633 .23007 L
.02561 .23615 L
.02522 .24188 L
.0251 .24793 L
.02516 .25133 L
.0253 .25446 L
.02572 .25971 L
.02644 .26545 L
.02748 .27144 L
Mistroke
.02872 .277 L
.03255 .28977 L
.03722 .30128 L
.05174 .32649 L
.06866 .34743 L
.09144 .36897 L
.11668 .38783 L
.14355 .4042 L
.20515 .4325 L
.24169 .44506 L
.28354 .45657 L
.3272 .46586 L
.35173 .47002 L
.37494 .47331 L
.39676 .47586 L
.41678 .47775 L
.43919 .47937 L
.45156 .48005 L
.46326 .48056 L
.47355 .48089 L
.48461 .48112 L
.49506 .48124 L
.50461 .48125 L
.51578 .48115 L
.52209 .48104 L
.52794 .4809 L
.53865 .48056 L
.55003 .48008 L
.56192 .47943 L
.57471 .47858 L
.59774 .47661 L
.64011 .4715 L
.67961 .46485 L
.71981 .45601 L
.78692 .43559 L
.8214 .42158 L
.85034 .40735 L
.8786 .39055 L
.90559 .37072 L
.92686 .35107 L
.94315 .33196 L
.95557 .31298 L
.96065 .30315 L
.96526 .29228 L
.96902 .28075 L
.97038 .27541 L
.97157 .26969 L
.97248 .26403 L
.97307 .25888 L
.97345 .2537 L
Mistroke
.97361 .24881 L
.97354 .24309 L
.97318 .23705 L
.97263 .23189 L
.97178 .22624 L
.97057 .22018 L
.96893 .21371 L
.9651 .20211 L
.96056 .19148 L
.95454 .18008 L
.94077 .15987 L
.92398 .14101 L
.9056 .12439 L
.88232 .10711 L
.85392 .08986 L
.79474 .0627 L
.7565 .04953 L
.71359 .03779 L
.67517 .02957 L
.63162 .02248 L
.60973 .01974 L
.58572 .01733 L
.56285 .01558 L
.55189 .01494 L
.54162 .01444 L
.53236 .01408 L
.52239 .01379 L
.51132 .01358 L
.5012 .01349 L
.49068 .01351 L
.47922 .01365 L
.4684 .01391 L
.45837 .01425 L
.44666 .01477 L
.43403 .01548 L
.41126 .01719 L
.38928 .01935 L
.36928 .02177 L
.32468 .02884 L
.27939 .03862 L
.24077 .04937 L
.2075 .06075 L
.17404 .07465 L
.14079 .09159 L
.11325 .10883 L
.09077 .12599 L
.07085 .14474 L
.0556 .16276 L
.04239 .18313 L
.03692 .19408 L
Mistroke
.03227 .20574 L
.02915 .21603 L
.02704 .22566 L
.02617 .23121 L
.0256 .23626 L
.02521 .2421 L
.0251 .24761 L
.02523 .25315 L
.02568 .25924 L
.02601 .26231 L
.02646 .26559 L
.0275 .27151 L
.03032 .28293 L
.03384 .29326 L
.03906 .30513 L
.04608 .31786 L
.06237 .3403 L
.08136 .36012 L
.10246 .37772 L
.13139 .39717 L
.16132 .41349 L
.23102 .44166 L
.27162 .45357 L
.31679 .46388 L
.35873 .47108 L
.39791 .47598 L
.41993 .47801 L
.4316 .47888 L
.44402 .47966 L
.45489 .48021 L
.46689 .48069 L
.47783 .48099 L
.48808 .48118 L
.49819 .48126 L
.50922 .48123 L
.51964 .48109 L
.52931 .48087 L
.53887 .48056 L
.54752 .4802 L
.56685 .47912 L
.58761 .47754 L
.60987 .47535 L
.64959 .47007 L
.69074 .46263 L
.72773 .454 L
.76955 .44166 L
.80524 .4285 L
.86953 .39632 L
.8992 .37584 L
.92311 .35488 L
Mistroke
.94028 .33568 L
.95524 .31357 L
.96112 .30215 L
.96621 .28968 L
.96811 .2839 L
.96981 .27778 L
.97112 .27203 L
.97207 .26679 L
.97279 .26153 L
.97327 .25656 L
.97355 .2513 L
.9736 .2456 L
.97343 .24062 L
.97302 .23535 L
.97249 .23085 L
.97172 .22592 L
.97056 .22014 L
.96925 .21487 L
.96548 .20309 L
.96095 .1923 L
.95575 .1822 L
.94106 .16025 L
.92419 .14123 L
.9007 .12046 L
.87492 .10227 L
.82091 .07353 L
.78651 .05962 L
.7527 .04837 L
.71595 .03837 L
.67477 .02949 L
.63451 .02288 L
.59693 .01838 L
.57367 .01634 L
.55203 .01494 L
.54068 .0144 L
.52815 .01395 L
.52183 .01378 L
.51503 .01364 L
.50861 .01355 L
.50273 .0135 L
.49189 .0135 L
.48182 .01361 L
.47077 .01384 L
.45901 .01422 L
.44665 .01477 L
.43502 .01542 L
.41339 .01701 L
.39235 .01902 L
.37287 .02131 L
.32944 .02797 L
Mistroke
.28855 .03641 L
.24668 .04756 L
.20999 .05982 L
.1775 .07308 L
.12359 .10194 L
.09961 .11883 L
.07669 .1388 L
.05699 .16092 L
.04949 .1714 L
.04265 .18265 L
.03762 .19255 L
.03307 .20351 L
.02981 .21357 L
.02754 .22301 L
.02652 .22877 L
.02581 .23423 L
.02538 .23913 L
.02513 .24445 L
.02513 .25025 L
.02543 .2564 L
.02593 .26163 L
.02675 .26739 L
.02788 .27335 L
.02919 .27887 L
.0331 .29129 L
.03761 .30212 L
.0435 .3135 L
.05777 .33465 L
.07403 .35303 L
.09692 .37343 L
.12602 .39388 L
.15711 .41138 L
.18912 .42611 L
.25862 .45005 L
.29862 .46007 L
.3434 .46869 L
.36652 .47219 L
.39202 .47535 L
.4164 .47772 L
.42811 .47863 L
.43914 .47937 L
.44987 .47997 L
.45971 .48042 L
.47067 .48081 L
.47643 .48096 L
.48249 .48109 L
.49392 .48124 L
.50456 .48125 L
.51623 .48115 L
.52275 .48103 L
Mistroke
.52867 .48089 L
.53768 .4806 L
.54609 .48026 L
.56517 .47923 L
.58366 .47788 L
.60338 .47604 L
.6386 .47171 L
.67008 .46663 L
.70567 .45938 L
.74293 .44985 L
.80576 .42829 L
Mfstroke
.92047 .35574 m
.93802 .3367 L
.95126 .31818 L
.96221 .29718 L
.96666 .28517 L
.96965 .27414 L
.97077 .26848 L
.97168 .26247 L
.97221 .25732 L
.97254 .25165 L
.97261 .24555 L
.97251 .24213 L
.97233 .239 L
.97176 .23292 L
.97093 .22716 L
.96992 .22184 L
.96858 .21619 L
.96551 .20606 L
.96075 .19414 L
.9554 .18345 L
.93969 .15982 L
.92099 .13902 L
.89603 .11748 L
.86495 .09645 L
.80288 .06569 L
.76293 .05107 L
.72305 .03942 L
.68237 .03002 L
.66024 .02584 L
.6363 .02199 L
.61513 .01913 L
.59148 .01653 L
.56975 .01466 L
.55996 .01398 L
.54922 .01334 L
.53941 .01286 L
.5289 .01246 L
.51779 .01215 L
.50745 .01198 L
.4971 .01191 L
.48733 .01194 L
.47856 .01206 L
.46906 .01226 L
.45867 .01259 L
.44725 .01308 L
.42428 .01447 L
.40314 .01624 L
.38352 .01831 L
.34052 .02438 L
.29518 .03325 L
Mistroke
.25426 .04376 L
.21833 .05531 L
.15684 .08163 L
.1267 .09872 L
.10236 .11553 L
.07953 .13489 L
.05948 .15654 L
.04582 .17584 L
.03957 .18699 L
.03463 .19767 L
.03011 .21022 L
.02714 .22173 L
.02595 .2282 L
.02515 .2342 L
.02486 .23733 L
.02462 .24078 L
.02448 .24438 L
.02445 .24776 L
.0246 .25352 L
.02505 .25956 L
.02568 .26471 L
.0266 .27032 L
.0279 .27636 L
.02961 .28279 L
.03356 .29425 L
.03879 .30597 L
.04558 .31815 L
.06089 .33931 L
.08169 .36095 L
.10942 .38311 L
.1372 .4007 L
.17058 .41783 L
.239 .44378 L
.27971 .45501 L
.31925 .4636 L
.36429 .47097 L
.38756 .47388 L
.41358 .47644 L
.42468 .47732 L
.43642 .47812 L
.44659 .4787 L
.4575 .47921 L
.46367 .47944 L
.46929 .47962 L
.48028 .47989 L
.48644 .47999 L
.49312 .48005 L
.49944 .48008 L
.50526 .48006 L
.51559 .47996 L
Mistroke
.52526 .47976 L
.53585 .47945 L
.54722 .47899 L
.57032 .47766 L
.5913 .47598 L
.63254 .47133 L
.65518 .46797 L
.67538 .46446 L
.74834 .44719 L
.7863 .43479 L
.82438 .41929 L
.85692 .40287 L
.88418 .38601 L
.90878 .3673 L
.92799 .34914 L
.94555 .32791 L
.95352 .31568 L
.95972 .30416 L
.96454 .29305 L
.96864 .28064 L
.97026 .27416 L
.97146 .26806 L
.97239 .2616 L
.97276 .25796 L
.973 .25462 L
.97321 .24889 L
.97316 .24356 L
.97284 .23771 L
.97253 .23443 L
.97218 .23147 L
.97124 .22547 L
.96989 .21898 L
.96656 .20729 L
.96246 .19657 L
.95699 .18519 L
.94435 .16512 L
.92485 .14222 L
.903 .12246 L
.87643 .10328 L
.84335 .08416 L
.77349 .05467 L
.73292 .04224 L
.69265 .03248 L
.65504 .02534 L
.61321 .01939 L
.59096 .01701 L
.56636 .01499 L
.55388 .01421 L
.54048 .01354 L
.53397 .01328 L
Mistroke
.5278 .01307 L
.51625 .01279 L
.50535 .01264 L
.4938 .01261 L
.48394 .01269 L
.47307 .01289 L
.46144 .01323 L
.44894 .01375 L
.43716 .01438 L
.42642 .01509 L
.38452 .01899 L
.36145 .02196 L
.3408 .02514 L
.2659 .0413 L
.22672 .05317 L
.18716 .0682 L
.15316 .08426 L
.12444 .10085 L
.07776 .13728 L
.05861 .15837 L
.04269 .18205 L
.03656 .19425 L
.03134 .20772 L
.02946 .21393 L
.02781 .22057 L
.02669 .22625 L
.02619 .22931 L
.02576 .23253 L
.02517 .23859 L
.0249 .24415 L
.02489 .25013 L
.02501 .25351 L
.02521 .25666 L
.02578 .26239 L
.02653 .26758 L
.02768 .27356 L
.02903 .27918 L
.03243 .29012 L
.03652 .30025 L
.04899 .3228 L
.06529 .34391 L
.08714 .36542 L
.11121 .38409 L
.13721 .40054 L
.19344 .42766 L
.22943 .44081 L
.26407 .45117 L
.30325 .46062 L
.34737 .46881 L
.36783 .47181 L
Mistroke
.38969 .47451 L
.41016 .47657 L
.42939 .47811 L
.44753 .47922 L
.45774 .4797 L
.46705 .48005 L
.47726 .48033 L
.48837 .48053 L
.49886 .4806 L
.50856 .48057 L
.51908 .48044 L
.53013 .48018 L
.53956 .47987 L
.54984 .47942 L
.57274 .47806 L
.59389 .47632 L
.63181 .47201 L
.67134 .46579 L
.71673 .45619 L
.75746 .44501 L
.7917 .43333 L
.82676 .41871 L
.88462 .38617 L
.91082 .366 L
.93146 .34584 L
.94722 .32603 L
.95847 .30728 L
.96336 .2967 L
.96761 .28505 L
.96917 .27968 L
.97057 .27394 L
.97163 .26859 L
.9724 .26359 L
.97299 .25834 L
.97337 .25257 L
.97348 .24696 L
.97331 .24095 L
.97289 .23535 L
.97225 .23007 L
.97148 .22534 L
.97044 .22022 L
.96723 .20852 L
.96259 .19625 L
.95113 .17467 L
.93701 .15534 L
.92082 .13796 L
.87404 .10164 L
.84479 .08486 L
.80943 .06836 L
.77558 .05548 L
Mistroke
.73708 .04354 L
.69687 .0336 L
.65892 .02625 L
.61961 .02047 L
.58179 .01653 L
.56049 .01496 L
.55023 .01437 L
.54049 .01391 L
.52897 .01349 L
.51846 .01322 L
.50714 .01305 L
.50073 .01301 L
.49481 .013 L
.48384 .01309 L
.47354 .01328 L
.46226 .01362 L
.45012 .01411 L
.4381 .01475 L
.4255 .01558 L
.40309 .01746 L
.36334 .02212 L
.32722 .02794 L
.28881 .03594 L
.24953 .04634 L
.17595 .07349 L
.13959 .09203 L
.10989 .11098 L
.08541 .13047 L
.06602 .14984 L
.04962 .17105 L
.04208 .18352 L
.0363 .19528 L
.03201 .20628 L
.02855 .2181 L
.0271 .2249 L
.02653 .22824 L
.02609 .23131 L
.02546 .23707 L
.02524 .2401 L
.0251 .2433 L
.02504 .24879 L
.02524 .25466 L
.0257 .26019 L
.02634 .26521 L
.02735 .2711 L
.02877 .27748 L
.03221 .28898 L
.03617 .29907 L
.04152 .31004 L
.05545 .33168 L
Mistroke
.07194 .35091 L
.09039 .36807 L
.115 .38662 L
.14574 .40528 L
.17589 .4202 L
.21089 .43445 L
.24805 .44675 L
.28367 .45633 L
.31821 .46386 L
.35742 .47056 L
.39941 .47579 L
.42272 .47788 L
.43396 .47869 L
.44466 .47934 L
.45453 .47984 L
.4653 .48028 L
.4751 .48057 L
.48419 .48076 L
.49398 .48088 L
.5048 .4809 L
.5161 .48079 L
.5267 .48058 L
.53751 .48025 L
.54931 .47976 L
.5616 .4791 L
.57301 .47835 L
.61493 .47444 L
.63849 .47141 L
.6596 .46814 L
.70571 .45908 L
.74397 .4493 L
.78234 .43702 L
.84442 .41031 L
.87456 .39303 L
.89958 .37543 L
.9232 .3547 L
.9438 .33101 L
.95138 .31994 L
.95826 .30792 L
.9632 .29738 L
.96747 .28584 L
.96954 .2787 L
.97107 .2721 L
.9722 .26578 L
.97264 .26259 L
.97302 .25908 L
.97346 .25299 L
.97357 .24957 L
.97358 .24646 L
.97339 .24041 L
Mistroke
.97293 .23469 L
.97225 .22933 L
.97123 .22344 L
.96986 .21731 L
.96829 .21158 L
.96481 .20141 L
.96011 .19058 L
.94573 .1665 L
.92825 .14537 L
.90801 .12635 L
.88272 .10731 L
.82845 .07684 L
.79035 .06087 L
.75148 .04781 L
.7148 .03787 L
.6726 .02885 L
.62993 .022 L
.60904 .01941 L
.58901 .01736 L
.56611 .01554 L
.54507 .01433 L
.53327 .01385 L
.52232 .01352 L
.516 .01339 L
.51028 .0133 L
.50368 .01324 L
.49747 .01323 L
.48786 .01327 L
.47734 .01343 L
.46636 .01371 L
.45615 .01408 L
.4379 .015 L
.41847 .01634 L
.39581 .01841 L
.37461 .02085 L
.3356 .02667 L
.29738 .0342 L
.25698 .04438 L
.21969 .05617 L
.18226 .07085 L
.1502 .08632 L
.12356 .10188 L
.07968 .13587 L
.06118 .15563 L
.04551 .17768 L
.03946 .1887 L
.03472 .19921 L
.03128 .20868 L
.02837 .21915 L
.02712 .22518 L
Mistroke
.02622 .23082 L
.02555 .23679 L
.02531 .24015 L
.02516 .2432 L
.0251 .24866 L
.02531 .25459 L
.02577 .26019 L
.02642 .26536 L
.02745 .27128 L
.02867 .27682 L
.03241 .28937 L
.0373 .30145 L
.04395 .31428 L
.05866 .33575 L
.07592 .35487 L
.09863 .37471 L
.12698 .3944 L
.16098 .41321 L
.19662 .42905 L
.23096 .44149 L
.27118 .45329 L
.31158 .46266 L
.35086 .4697 L
.39353 .47532 L
.4179 .47765 L
.42876 .47849 L
.44036 .47925 L
.45129 .47985 L
.46121 .48029 L
.4712 .48063 L
.48061 .48086 L
.49164 .48103 L
.50178 .48107 L
.51291 .481 L
.52464 .4808 L
.53419 .48054 L
.54439 .48015 L
.56274 .4792 L
.58444 .47764 L
.60406 .4758 L
.64565 .47052 L
.68853 .46294 L
.72383 .45487 L
.76103 .44431 L
.79857 .43108 L
.83586 .41472 L
.86747 .39752 L
.89364 .38003 L
.91726 .36049 L
.93535 .34169 L
Mistroke
.9515 .31982 L
.95855 .30744 L
.96398 .29558 L
.96813 .28386 L
.96991 .27741 L
.97126 .27135 L
.97217 .26617 L
.97291 .26061 L
.97321 .25744 L
.97342 .25443 L
.97362 .24878 L
.97353 .24263 L
.97337 .23952 L
.9731 .23609 L
.97239 .23005 L
.97145 .22438 L
.97001 .21776 L
.96836 .21171 L
.96355 .19817 L
.95837 .18704 L
.95275 .17705 L
.93706 .15526 L
.91884 .13598 L
.89854 .11872 L
.84303 .08401 L
.80626 .06716 L
.76933 .05352 L
.73385 .04285 L
.69374 .03317 L
.65434 .02576 L
.61726 .02048 L
.5944 .01799 L
.57298 .01615 L
.54931 .01466 L
.53602 .01407 L
.53016 .01387 L
.52395 .01369 L
.51239 .01346 L
.50174 .01336 L
.49028 .01338 L
.48378 .01345 L
.47772 .01355 L
.46673 .01382 L
.45673 .01418 L
.44521 .01471 L
.43433 .01534 L
.4134 .01688 L
.39391 .01873 L
.35018 .0244 L
.30881 .03185 L
Mistroke
.26601 .04199 L
.23022 .05268 L
.19477 .06567 L
.13811 .09309 L
.11029 .11088 L
.08809 .12828 L
.06635 .14964 L
.04986 .17087 L
.04376 .1807 L
.03823 .19126 L
.03422 .2005 L
.03072 .21051 L
.02913 .21617 L
.0279 .22135 L
.02688 .22663 L
.02614 .23154 L
.02553 .23725 L
.02532 .24026 L
.02517 .24347 L
.02513 .24942 L
.02534 .2548 L
.02581 .26042 L
.02648 .26564 L
.02748 .27136 L
.02885 .27746 L
.03259 .28983 L
.0371 .30097 L
.04874 .32202 L
.06319 .34123 L
.08392 .36241 L
.10669 .38079 L
.13519 .39937 L
.1698 .41749 L
.20398 .43197 L
.23757 .44368 L
.2737 .45401 L
.3088 .46216 L
.351 .46981 L
.37577 .47331 L
.39854 .47594 L
.42049 .47795 L
.44134 .4794 L
.45284 .48001 L
.46346 .48046 L
.47514 .48083 L
.48102 .48096 L
.48749 .48107 L
.49911 .48116 L
.50987 .48112 L
.52167 .48096 L
Mistroke
.52762 .48082 L
.53419 .48063 L
.54515 .48021 L
.55694 .47963 L
.57818 .47823 L
.59893 .47641 L
.62058 .47402 L
.65864 .46854 L
.70153 .46025 L
.73979 .45069 L
.77928 .43829 L
.81905 .4226 L
.85388 .4054 L
.88266 .38784 L
.90642 .37003 L
.92873 .34911 L
.94509 .32934 L
.95715 .31013 L
.96243 .2993 L
.96637 .28928 L
.96818 .28371 L
.96987 .27761 L
.9711 .27219 L
.97214 .26645 L
.97256 .2635 L
.97295 .26026 L
.97342 .25456 L
.97357 .25135 L
.97363 .24791 L
.9736 .24466 L
.9735 .2417 L
.9731 .23596 L
.97275 .23273 L
.97235 .22974 L
.97143 .22427 L
.97019 .21848 L
.96719 .20793 L
.96354 .19813 L
.95224 .17621 L
.94471 .16504 L
.93562 .15355 L
.91648 .13379 L
.89192 .11378 L
.86072 .09364 L
.82788 .07664 L
.79392 .06232 L
.72378 .04025 L
.68137 .03069 L
.64078 .02371 L
.61724 .02054 L
Mistroke
.59495 .01811 L
.57148 .0161 L
.55891 .01526 L
.54549 .01454 L
.53454 .01408 L
.52871 .01389 L
.52241 .01372 L
.51137 .01351 L
.50099 .01342 L
.49511 .01342 L
.48867 .01346 L
.48194 .01354 L
.47568 .01366 L
.46447 .01396 L
.4582 .01419 L
.4525 .01443 L
.43087 .01563 L
.40755 .01746 L
.38572 .0197 L
.36577 .02219 L
.32939 .02793 L
.29055 .03591 L
.21717 .05719 L
.18083 .07159 L
.1491 .087 L
.09802 .12009 L
.07486 .14062 L
.05711 .16079 L
.04198 .1839 L
.03558 .19718 L
.03108 .20938 L
.02818 .22008 L
.02696 .22618 L
.0261 .2319 L
.02548 .23794 L
.02518 .24345 L
.02512 .2465 L
.02514 .24982 L
.02541 .25584 L
.02587 .26097 L
.02664 .26662 L
.02772 .2725 L
.02899 .27801 L
.03188 .28778 L
.03589 .29822 L
.04855 .32173 L
.05669 .33322 L
.06691 .34547 L
.11177 .38443 L
.14133 .40291 L
Mistroke
.1725 .41877 L
.23826 .44394 L
.27869 .45532 L
.31781 .46402 L
.3624 .47155 L
.38539 .47454 L
.41101 .47719 L
.43299 .47892 L
.44548 .47969 L
.4571 .48026 L
.4683 .48068 L
.47845 .48096 L
.49019 .48115 L
.50123 .48121 L
.51134 .48116 L
.522 .481 L
.53109 .48077 L
.54104 .48043 L
.55176 .47995 L
.5632 .47931 L
.58374 .47783 L
.60733 .47559 L
.63266 .4725 L
.67766 .4652 L
.71982 .45598 L
.75699 .44566 L
.79118 .434 L
.8255 .41971 L
.88001 .38963 L
.90656 .36993 L
.93005 .34769 L
.9463 .32764 L
.95985 .30487 L
.96488 .29334 L
.96707 .28721 L
.96905 .28071 L
.97049 .27498 L
.97177 .26868 L
.97264 .26293 L
.97321 .25755 L
.97355 .25192 L
.97363 .24658 L
.9735 .24179 L
.97315 .23657 L
.97252 .23092 L
.97156 .22493 L
.9705 .21982 L
.96909 .2142 L
.96501 .20181 L
.96015 .19058 L
Mistroke
.94532 .16589 L
.92795 .14505 L
.90551 .12428 L
.85433 .09006 L
.82054 .07332 L
.78701 .05976 L
.75358 .0486 L
.71529 .03817 L
.68031 .03051 L
.64144 .02384 L
.61953 .02086 L
.59926 .01857 L
.57847 .01668 L
.55903 .01531 L
.54807 .0147 L
.53636 .01419 L
.52966 .01396 L
.52335 .01378 L
.51768 .01365 L
.51154 .01355 L
.50007 .01346 L
.4943 .01346 L
.48796 .0135 L
.47675 .01367 L
.4663 .01394 L
.45465 .01437 L
.44202 .01498 L
.41916 .01651 L
.39708 .0185 L
.37685 .02078 L
.33183 .02753 L
.28578 .03705 L
.2474 .04733 L
.21406 .05833 L
.18042 .07178 L
.14666 .08833 L
.09785 .12022 L
.07603 .13946 L
.05903 .15833 L
.04395 .18037 L
.03735 .19315 L
.03251 .20509 L
.02926 .21565 L
.02783 .22169 L
.02676 .22734 L
.02592 .23332 L
.02541 .23879 L
.02524 .24181 L
.02513 .2451 L
.02517 .25109 L
Mistroke
.02549 .25697 L
.02605 .26249 L
.02677 .26744 L
.02777 .27277 L
.03087 .28469 L
.03476 .29554 L
.04439 .31501 L
.058 .33492 L
.07663 .35559 L
.09692 .37341 L
.1221 .39137 L
.15308 .40928 L
.18482 .42427 L
.2165 .43666 L
.28455 .45679 L
.32252 .46496 L
.36483 .47192 L
.38574 .47461 L
.40583 .47674 L
.42578 .47843 L
.44398 .47963 L
.45529 .4802 L
.46597 .48063 L
.47726 .48096 L
.48363 .48109 L
.48949 .48117 L
.49932 .48123 L
.5101 .4812 L
.52136 .48104 L
.53186 .48077 L
.53781 .48058 L
.54428 .48032 L
.55602 .47975 L
.57794 .47832 L
.60333 .47603 L
.62656 .47333 L
.666 .46734 L
.70717 .45903 L
.77693 .43915 L
.81386 .42489 L
.84946 .40783 L
.87936 .39006 L
.90337 .37254 L
.92367 .35433 L
.94198 .33351 L
.95034 .32166 L
.95694 .31052 L
.96255 .29901 L
.96677 .28811 L
.96958 .2787 L
Mistroke
.97074 .27384 L
.97179 .26853 L
.97266 .26272 L
.97323 .25719 L
.97355 .25181 L
.97363 .24681 L
.97346 .24106 L
.97306 .23565 L
.9725 .23081 L
.97167 .22558 L
.97051 .21987 L
.96899 .21388 L
.96553 .20321 L
.96066 .19166 L
.95502 .18089 L
.94182 .1612 L
.92387 .14088 L
.9002 .12005 L
.8762 .10307 L
.84757 .08643 L
.78892 .06048 L
.75278 .04837 L
.71783 .03881 L
.67772 .03003 L
.63396 .02278 L
.61506 .02034 L
.59469 .01814 L
.57693 .01657 L
.55759 .01524 L
.54568 .01461 L
.53469 .01415 L
.52417 .01382 L
.51302 .01359 L
.50303 .01349 L
.49369 .01348 L
.48345 .01357 L
.47246 .01378 L
.46164 .01411 L
.44971 .0146 L
.43728 .01527 L
.42564 .01604 L
.40497 .01774 L
.38287 .02007 L
.33358 .02723 L
.28996 .03608 L
.25309 .04567 L
.21485 .05805 L
.17796 .07288 L
.14604 .08867 L
.11782 .10572 L
Mistroke
.09098 .12583 L
.07188 .14367 L
.05444 .16433 L
.04001 .18763 L
.03413 .20071 L
.03183 .20706 L
.02995 .21312 L
.02849 .21869 L
.0272 .2248 L
.0263 .23036 L
.02568 .23553 L
.02524 .24168 L
.02511 .24726 L
.02514 .25035 L
.02527 .25369 L
.02574 .25974 L
.02646 .2655 L
.02736 .27074 L
.0302 .28246 L
.03384 .29322 L
.03818 .3033 L
.05097 .32538 L
.06957 .34839 L
.09222 .3696 L
.12081 .39054 L
.15152 .40848 L
.1827 .42336 L
.25022 .44762 L
.28884 .45782 L
.33138 .46661 L
.36979 .47262 L
.40634 .4768 L
.42762 .47859 L
.44708 .47981 L
.4579 .48033 L
.46964 .48076 L
.48076 .48105 L
.49101 .4812 L
.5022 .48125 L
.51283 .48118 L
.52236 .48103 L
.53274 .48076 L
.54399 .48035 L
.55593 .47977 L
.5773 .47838 L
.59886 .47649 L
.61896 .47429 L
.65589 .46907 L
.6989 .46089 L
.73682 .45156 L
Mistroke
.77602 .43947 L
.8151 .42436 L
.84813 .40854 L
.87538 .39265 L
.91997 .35795 L
.93944 .33676 L
.94801 .32516 L
.95579 .3126 L
.96145 .30145 L
.96646 .28899 L
.96824 .28349 L
.96987 .27754 L
.97113 .27199 L
.97208 .26674 L
.97252 .26378 L
.97291 .26057 L
.97339 .25497 L
.97354 .25179 L
.97362 .24843 L
.97352 .24241 L
.97317 .23684 L
.97261 .23165 L
.97174 .22596 L
.97051 .21988 L
.96663 .2063 L
.96155 .19359 L
.9484 .17031 L
.93166 .14908 L
.91264 .13037 L
.88828 .11121 L
.85804 .09215 L
.82676 .07617 L
.7955 .06298 L
.72802 .04141 L
.68951 .0324 L
.64566 .02451 L
.62299 .02133 L
.59843 .01852 L
.57501 .01643 L
.56394 .01565 L
.55355 .01502 L
.54285 .01449 L
.53305 .0141 L
.52216 .01378 L
.51043 .01356 L
.49919 .01348 L
.49284 .01349 L
.48694 .01354 L
.47614 .01371 L
.46465 .01402 L
Mistroke
.45402 .01442 L
.44254 .01498 L
.42184 .01633 L
.40181 .01805 L
.38355 .02 L
.34218 .02578 L
.29823 .03421 L
.2544 .04529 L
.21583 .0577 L
.18081 .07162 L
.14597 .08871 L
.11836 .10536 L
.09253 .12452 L
.07261 .14291 L
.05448 .16427 L
.04165 .1845 L
.03701 .19389 L
.03289 .20402 L
.02937 .2152 L
.02814 .22022 L
.02704 .22568 L
.02649 .22902 L
.02606 .23211 L
.02545 .23819 L
.02516 .24372 L
.02512 .24957 L
.02536 .25529 L
.02591 .26142 L
.02672 .2672 L
.0277 .27246 L
.03104 .28526 L
.03547 .29727 L
.04604 .31778 L
.059 .3362 L
.07661 .35558 L
.09903 .37508 L
.15671 .41117 L
.19503 .42853 L
.23339 .44242 L
.27241 .45377 L
.31059 .46262 L
.35196 .47005 L
.37609 .47345 L
.39867 .47605 L
.42009 .47801 L
.44298 .47959 L
.45489 .48021 L
.46608 .48065 L
.47238 .48085 L
.47838 .481 L
Mistroke
.48529 .48113 L
.49162 .48121 L
.50225 .48126 L
.51358 .48118 L
.52427 .48099 L
.53395 .48073 L
.54535 .48029 L
.55766 .47968 L
.57987 .47818 L
.59956 .47643 L
.62098 .47405 L
.66343 .4678 L
.70154 .46031 L
.73581 .45184 L
.7738 .44023 L
.81241 .42552 L
.84374 .41084 L
.87391 .39358 L
.89803 .37675 L
.92111 .35685 L
.93867 .33771 L
.95203 .31898 L
.96299 .29796 L
.96751 .28582 L
.97061 .27442 L
.97184 .26818 L
.97271 .26227 L
.97324 .25696 L
.97356 .2512 L
.97362 .2482 L
.9736 .24491 L
.97348 .24147 L
.97328 .23826 L
.97271 .23252 L
.97228 .2293 L
.9718 .22637 L
.96942 .2155 L
.96635 .20549 L
.96201 .19462 L
.95631 .1832 L
.94285 .16257 L
.9275 .14461 L
.90648 .12511 L
.88047 .10587 L
.82505 .07539 L
.78982 .06083 L
.75455 .04892 L
.71385 .03785 L
.66736 .02812 L
.64505 .02442 L
Mistroke
.621 .02108 L
.59843 .01852 L
.57706 .0166 L
.557 .01522 L
.54567 .01462 L
.53527 .01418 L
.52448 .01384 L
.51837 .0137 L
.51268 .0136 L
.50117 .01349 L
.49473 .01349 L
.48889 .01352 L
.47853 .01367 L
.46758 .01393 L
.45824 .01425 L
.448 .0147 L
.42524 .01608 L
.40413 .01783 L
.36637 .02217 L
.3268 .02845 L
.2836 .03759 L
.24542 .04794 L
.2067 .06106 L
.16723 .07784 L
.11012 .11103 L
.08437 .13158 L
.06413 .15217 L
.04889 .17233 L
.03642 .19521 L
.03184 .207 L
.02983 .21353 L
.02825 .21973 L
.02706 .22552 L
.02655 .22858 L
.02609 .23183 L
.0255 .23757 L
.02518 .24287 L
.0251 .24819 L
.02523 .25306 L
.02562 .25867 L
.02624 .264 L
.02701 .26889 L
.02789 .27341 L
.03054 .28363 L
.03447 .29485 L
.03895 .3049 L
.05204 .32693 L
.0688 .34757 L
.09057 .36824 L
.1392 .40175 L
Mistroke
.17111 .41817 L
.20365 .43193 L
.24178 .44508 L
.28597 .45715 L
.3305 .46646 L
.35065 .46985 L
.37321 .47308 L
.39325 .47548 L
.41505 .4776 L
.42715 .47856 L
.43828 .47932 L
.44887 .47992 L
.4602 .48044 L
.47065 .4808 L
.48015 .48104 L
.48971 .4812 L
.49874 .48126 L
.50927 .48123 L
.51898 .4811 L
.52962 .48086 L
.54087 .48048 L
.55092 .48004 L
.56168 .47945 L
.58104 .47809 L
.60388 .47599 L
.62454 .47361 L
.66536 .46747 L
.70737 .45899 L
.778 .43878 L
.8174 .42336 L
.85123 .40688 L
.87843 .39067 L
.90475 .37142 L
.92547 .3525 L
.94376 .33115 L
.95206 .31893 L
.95847 .30759 L
.96385 .29589 L
.96779 .28495 L
.97053 .27477 L
.97159 .26961 L
.9725 .26391 L
.97314 .25819 L
.97338 .25498 L
.97353 .25204 L
.97361 .24633 L
.97345 .2409 L
.97308 .23589 L
.97246 .23056 L
.97166 .22554 L
Mistroke
.97075 .22099 L
.96781 .2099 L
.9641 .19953 L
.95375 .17873 L
.9382 .15667 L
.91748 .13475 L
.89422 .11551 L
.84395 .08456 L
.8114 .0694 L
.77933 .05704 L
.74335 .04562 L
.703 .03533 L
.6671 .02808 L
.62621 .02175 L
.60292 .01899 L
.58134 .01695 L
.55744 .01525 L
.54537 .01461 L
.53856 .01431 L
.53212 .01407 L
.52037 .01374 L
.50968 .01356 L
.49815 .01349 L
.49165 .01351 L
.48566 .01356 L
.47566 .01372 L
.46467 .01402 L
.4532 .01446 L
.4425 .01499 L
.41967 .0165 L
.39865 .01837 L
.35178 .02427 L
.31166 .03137 L
.27054 .04087 L
.23209 .05213 L
.19802 .06442 L
.1409 .09153 L
.11458 .10792 L
.0892 .12733 L
.06691 .14901 L
.05021 .17033 L
.04363 .18091 L
.03831 .19108 L
.03424 .20043 L
.03073 .21044 L
.02925 .21565 L
.02787 .22141 L
.02685 .22673 L
.02612 .23161 L
.02551 .23735 L
Mistroke
.0253 .24037 L
.02516 .24355 L
.02511 .2489 L
.02532 .25475 L
.02554 .25774 L
.02585 .2609 L
.02661 .26655 L
.02772 .27262 L
.0293 .27926 L
.03303 .29108 L
.03756 .302 L
.04869 .32198 L
.06439 .34266 L
.08732 .36546 L
.11345 .38563 L
.14006 .40224 L
.17282 .41896 L
.24086 .4448 L
.28184 .45616 L
.32227 .46494 L
.36121 .47144 L
.39785 .47597 L
.41731 .47779 L
.43878 .47935 L
.44966 .47996 L
.46132 .48048 L
.47235 .48086 L
.4824 .48109 L
.49301 .48123 L
.50294 .48126 L
.51384 .48118 L
.52556 .48097 L
.53141 .48081 L
.53779 .4806 L
.54939 .48011 L
.57108 .47884 L
.59141 .47721 L
.61289 .47501 L
.65094 .46986 L
.69774 .46114 L
.73988 .45071 L
.77549 .43965 L
.81211 .42564 L
.87292 .39421 L
.90085 .37455 L
.92318 .35481 L
.94059 .33529 L
.95337 .31677 L
.95913 .30629 L
.96432 .29472 L
Mistroke
.96818 .28368 L
.97083 .27338 L
.97188 .26793 L
.97272 .26217 L
.97322 .25725 L
.97353 .25187 L
.97361 .24605 L
.97353 .24279 L
.97338 .23983 L
.97289 .23408 L
.97218 .22866 L
.97129 .22359 L
.97011 .21823 L
.96742 .20868 L
.96368 .1985 L
.95856 .18742 L
.94459 .16491 L
.92478 .14181 L
.90174 .12128 L
.87724 .10376 L
.84951 .08748 L
.81687 .07174 L
.75115 .0479 L
.70714 .03627 L
.6637 .02748 L
.62334 .02138 L
.60019 .01871 L
.5787 .01673 L
.56751 .0159 L
.55689 .01522 L
.54721 .0147 L
.53692 .01425 L
.52572 .01388 L
.51535 .01364 L
.50419 .01351 L
.49784 .01349 L
.49188 .01351 L
.48192 .01361 L
.47146 .01383 L
.46253 .01409 L
.4528 .01448 L
.4311 .01568 L
.41106 .01721 L
.38744 .01956 L
.36543 .02229 L
.32509 .02877 L
.28315 .0377 L
.23995 .04962 L
.17273 .07526 L
.13905 .09258 L
Mistroke
.11098 .11042 L
.08567 .13041 L
.06548 .15061 L
.056 .16221 L
.04708 .17515 L
.04071 .18627 L
.03504 .19844 L
.03088 .20997 L
.0294 .21506 L
.02804 .22064 L
.02705 .22559 L
.02621 .2309 L
.02558 .23651 L
.02523 .24174 L
.02512 .24498 L
.0251 .24797 L
.02516 .25125 L
.02532 .25473 L
.02581 .26056 L
.02622 .26387 L
.02668 .26697 L
.02896 .27795 L
.03067 .28409 L
.03252 .28967 L
.04312 .31283 L
.05112 .32561 L
.0598 .3372 L
.10305 .37816 L
.13024 .39648 L
.16346 .41454 L
.19574 .42882 L
.23251 .44214 L
.26784 .45258 L
.30855 .46221 L
.34703 .46928 L
.38394 .47442 L
.40665 .47684 L
.42784 .47861 L
.45126 .48004 L
.46313 .48055 L
.46952 .48077 L
.47625 .48096 L
.4877 .48117 L
.49821 .48126 L
.50952 .48123 L
.51592 .48115 L
.52187 .48105 L
.53271 .48077 L
.54254 .48042 L
.55387 .47989 L
Mistroke
.56453 .47927 L
.58442 .47782 L
.60531 .47584 L
.64222 .47119 L
.68096 .46459 L
.72203 .45546 L
.76386 .44352 L
.80576 .42829 L
Mfstroke
.92118 .35483 m
.93856 .33569 L
.95163 .31711 L
.96238 .29608 L
.96672 .28407 L
.9696 .27304 L
.97068 .26739 L
.97153 .26139 L
.97201 .25626 L
.9723 .2506 L
.97231 .24453 L
.97218 .24111 L
.97198 .23799 L
.97135 .23195 L
.97048 .22621 L
.96943 .22092 L
.96805 .21529 L
.96491 .20522 L
.96006 .19337 L
.95465 .18277 L
.93881 .15932 L
.92004 .13871 L
.89504 .11739 L
.86396 .09659 L
.80201 .06617 L
.76218 .05172 L
.72243 .04019 L
.68191 .03088 L
.65988 .02673 L
.63603 .0229 L
.61495 .02006 L
.59139 .01746 L
.56975 .01559 L
.56 .0149 L
.5493 .01426 L
.53953 .01377 L
.52906 .01336 L
.51799 .01304 L
.50769 .01285 L
.49738 .01277 L
.48764 .01278 L
.4789 .01288 L
.46944 .01307 L
.45908 .01338 L
.4477 .01385 L
.43585 .01447 L
.4248 .01518 L
.38416 .0189 L
.36176 .02173 L
.34126 .02483 L
Mistroke
.29599 .03353 L
.25777 .04312 L
.21919 .05526 L
.18372 .06909 L
.15291 .08373 L
.10298 .11494 L
.08099 .13331 L
.06076 .15466 L
.05217 .16584 L
.04421 .17808 L
.03838 .18883 L
.03317 .20068 L
.02915 .21261 L
.02776 .21789 L
.02649 .22373 L
.02555 .22923 L
.02489 .2344 L
.02443 .23986 L
.02421 .24574 L
.02425 .25076 L
.02452 .25624 L
.02507 .26195 L
.02582 .26725 L
.02673 .27222 L
.02773 .27671 L
.03058 .28675 L
.03454 .29734 L
.03995 .30883 L
.05426 .33142 L
.07138 .35145 L
.09059 .36922 L
.1444 .4053 L
.18028 .42279 L
.21611 .43686 L
.25189 .4483 L
.29206 .45862 L
.3278 .46589 L
.36854 .47224 L
.39173 .47503 L
.41324 .47709 L
.43705 .47882 L
.44908 .47948 L
.46229 .48004 L
.47401 .48039 L
.48467 .48059 L
.49058 .48066 L
.49699 .48069 L
.50863 .48064 L
.51953 .48048 L
.53106 .48018 L
Mistroke
.5409 .47982 L
.55171 .47932 L
.57368 .47794 L
.59747 .47588 L
.64014 .47068 L
.68057 .46381 L
.71681 .45587 L
.79301 .43241 L
.83122 .41613 L
.86263 .39954 L
.8894 .38224 L
.91402 .36252 L
.93207 .34443 L
.94792 .32413 L
.9552 .31235 L
.96076 .30143 L
.96537 .29018 L
.96867 .27968 L
.97013 .27371 L
.97135 .26735 L
.97182 .26427 L
.97224 .26095 L
.97259 .25731 L
.97282 .25388 L
.97295 .2509 L
.973 .24765 L
.97296 .24425 L
.97283 .24109 L
.97241 .23542 L
.97166 .22938 L
.97068 .22369 L
.96929 .21745 L
.9655 .20493 L
.96082 .19347 L
.95545 .18288 L
.93986 .15964 L
.91797 .13591 L
.89278 .11501 L
.86503 .09665 L
.80395 .06656 L
.76777 .05325 L
.73295 .04276 L
.69356 .03319 L
.64921 .0249 L
.62863 .02186 L
.60664 .01913 L
.58606 .01705 L
.56673 .0155 L
.54848 .01438 L
.53822 .0139 L
Mistroke
.52887 .01356 L
.5186 .01328 L
.50745 .01309 L
.4969 .01303 L
.48717 .01307 L
.47603 .01323 L
.46544 .01349 L
.45596 .01383 L
.44561 .01429 L
.42257 .01572 L
.40132 .01753 L
.36322 .02199 L
.32356 .02842 L
.27802 .03831 L
.23726 .04981 L
.20304 .0618 L
.1681 .07677 L
.11056 .11006 L
.08467 .13064 L
.06441 .15113 L
.04906 .17125 L
.03823 .19022 L
.03358 .20092 L
.02962 .21267 L
.02819 .21809 L
.02694 .22386 L
.02608 .22881 L
.02537 .23427 L
.0249 .23994 L
.02469 .24522 L
.02472 .25101 L
.02486 .25425 L
.02506 .25719 L
.02569 .26314 L
.02617 .26649 L
.02669 .26957 L
.02938 .28118 L
.03254 .29098 L
.03694 .30166 L
.04873 .32278 L
.06589 .34493 L
.0891 .36743 L
.14251 .40388 L
.17559 .42041 L
.20907 .43408 L
.25197 .44817 L
.2933 .45881 L
.3346 .46706 L
.37476 .47309 L
.39726 .47568 L
Mistroke
.41815 .4776 L
.44126 .47921 L
.45295 .47982 L
.45918 .48009 L
.4658 .48033 L
.47744 .48065 L
.48822 .48083 L
.49982 .4809 L
.50642 .48088 L
.51261 .48083 L
.52374 .48063 L
.53393 .48034 L
.54509 .47991 L
.55681 .47932 L
.57718 .47797 L
.596 .47634 L
.63808 .47133 L
.66124 .46771 L
.68272 .46378 L
.72174 .45505 L
.76177 .4437 L
.80236 .4292 L
.86305 .39975 L
.89244 .3805 L
.91618 .36104 L
.93703 .3392 L
.9521 .31828 L
.95874 .3064 L
.96458 .29325 L
.96676 .28717 L
.96874 .28066 L
.97016 .27506 L
.97141 .26891 L
.97229 .26323 L
.97287 .25792 L
.97323 .25232 L
.97332 .24632 L
.97314 .24073 L
.97274 .23545 L
.97218 .23072 L
.97137 .22559 L
.97023 .22 L
.96868 .21387 L
.96459 .20156 L
.95968 .19029 L
.95411 .17988 L
.9405 .15996 L
.92505 .14243 L
.8804 .10604 L
.85315 .0896 L
Mistroke
.82097 .07365 L
.75591 .04934 L
.71227 .03741 L
.66905 .02831 L
.62885 .02194 L
.60574 .01911 L
.58426 .01699 L
.56254 .01534 L
.54263 .01424 L
.53159 .0138 L
.52576 .01362 L
.51956 .01346 L
.50818 .01327 L
.49765 .01321 L
.48806 .01325 L
.47773 .01339 L
.46798 .01362 L
.45905 .01392 L
.44917 .01434 L
.43838 .01491 L
.41674 .01641 L
.39293 .01863 L
.37152 .02114 L
.3245 .02853 L
.28253 .0375 L
.2447 .04781 L
.17521 .07379 L
.14415 .08938 L
.11355 .10831 L
.09065 .12578 L
.06959 .14575 L
.05326 .16558 L
.04148 .18438 L
.03598 .1957 L
.03194 .20607 L
.03009 .21187 L
.02841 .21816 L
.02722 .22361 L
.0262 .2296 L
.02551 .23519 L
.0251 .24041 L
.02491 .24592 L
.02498 .25182 L
.0253 .25731 L
.02584 .26249 L
.0265 .26714 L
.02743 .27217 L
.03033 .28363 L
.03478 .29614 L
.04082 .30901 L
Mistroke
.04775 .32087 L
.06311 .34143 L
.08374 .36249 L
.13545 .39969 L
.17072 .41805 L
.20688 .43317 L
.24359 .44562 L
.28021 .45569 L
.32448 .46526 L
.36616 .47201 L
.40646 .47666 L
.42966 .47857 L
.45149 .47986 L
.46335 .48036 L
.47462 .48071 L
.48474 .48092 L
.49577 .48103 L
.50147 .48105 L
.50775 .48102 L
.51432 .48095 L
.52048 .48085 L
.53148 .48058 L
.53765 .48037 L
.54332 .48015 L
.56304 .47913 L
.58131 .47783 L
.60122 .47602 L
.62231 .47364 L
.66461 .46735 L
.70189 .45998 L
.74032 .45034 L
.77891 .43822 L
.84146 .41177 L
.8719 .39463 L
.89723 .37715 L
.9212 .35654 L
.94221 .33297 L
.94998 .32194 L
.95707 .30997 L
.96219 .29946 L
.96667 .28795 L
.96886 .28083 L
.97051 .27424 L
.97175 .26793 L
.97225 .2647 L
.97269 .26125 L
.97323 .25523 L
.97346 .24962 L
.97348 .24619 L
.9734 .24295 L
Mistroke
.97303 .23687 L
.97245 .23152 L
.97154 .22563 L
.97028 .2195 L
.96881 .21376 L
.96552 .20359 L
.96101 .19274 L
.94709 .16862 L
.93 .14742 L
.91013 .12831 L
.88521 .10916 L
.83155 .07846 L
.79377 .06232 L
.75518 .04909 L
.71871 .03899 L
.67671 .02977 L
.6342 .02273 L
.59339 .0179 L
.57055 .01597 L
.54954 .01467 L
.53789 .01413 L
.53173 .01391 L
.52517 .01371 L
.51885 .01355 L
.51314 .01345 L
.50198 .01334 L
.49161 .01334 L
.48067 .01346 L
.47134 .01366 L
.46113 .01397 L
.45013 .01442 L
.43839 .01504 L
.41732 .0165 L
.39619 .01843 L
.37639 .02068 L
.33991 .02597 L
.30154 .0333 L
.26095 .04327 L
.22343 .05486 L
.18572 .06932 L
.15334 .08461 L
.12639 .10001 L
.08183 .13375 L
.06293 .15341 L
.04683 .17538 L
.04056 .18636 L
.03561 .19685 L
.03198 .2063 L
.02887 .21676 L
.0275 .22279 L
Mistroke
.02648 .22843 L
.0257 .2344 L
.02539 .23776 L
.02519 .24081 L
.02502 .24628 L
.02511 .25222 L
.02546 .25782 L
.02601 .263 L
.02692 .26893 L
.02804 .27448 L
.03153 .28706 L
.0362 .29919 L
.0426 .31207 L
.0569 .33365 L
.0738 .35289 L
.09614 .37287 L
.12413 .39273 L
.15778 .41173 L
.19314 .42776 L
.22726 .44038 L
.26727 .45238 L
.30477 .46134 L
.34668 .46914 L
.37039 .47262 L
.39236 .47529 L
.41493 .47749 L
.43603 .47907 L
.45548 .48012 L
.46638 .48055 L
.47627 .48084 L
.48717 .48104 L
.49896 .48113 L
.51009 .4811 L
.52032 .48095 L
.52994 .48072 L
.5389 .48043 L
.54872 .48001 L
.55921 .47946 L
.58054 .478 L
.59984 .47627 L
.64153 .47115 L
.68455 .46375 L
.71999 .45583 L
.75739 .44543 L
.79517 .43237 L
.83275 .41619 L
.86467 .39914 L
.89115 .38179 L
.91512 .36238 L
.93355 .34368 L
Mistroke
.9501 .3219 L
.95737 .30957 L
.96302 .29775 L
.96738 .28605 L
.96927 .27961 L
.97074 .27357 L
.97182 .26797 L
.97258 .26284 L
.97317 .25714 L
.97351 .25102 L
.97356 .24786 L
.97353 .24451 L
.97324 .23848 L
.97295 .23514 L
.97259 .23201 L
.97148 .22487 L
.97017 .21869 L
.96869 .21304 L
.96438 .20039 L
.95941 .18923 L
.95398 .17922 L
.93869 .15735 L
.92085 .13799 L
.90087 .12063 L
.84604 .08566 L
.80961 .06863 L
.77295 .05482 L
.73768 .04398 L
.69778 .03412 L
.65853 .02653 L
.62156 .02108 L
.59876 .01848 L
.57739 .01655 L
.55375 .01495 L
.54047 .0143 L
.53461 .01407 L
.52842 .01386 L
.51686 .01358 L
.50622 .01343 L
.49476 .0134 L
.48826 .01344 L
.48219 .01351 L
.4712 .01374 L
.4612 .01404 L
.44967 .01452 L
.43878 .0151 L
.41783 .01655 L
.3983 .0183 L
.35447 .02376 L
.31296 .03101 L
Mistroke
.26997 .04093 L
.23396 .05143 L
.19826 .06424 L
.14107 .09136 L
.11291 .10899 L
.09037 .12627 L
.06956 .14604 L
.05131 .16864 L
.0446 .17915 L
.03856 .19046 L
.03394 .20108 L
.03049 .21111 L
.02802 .22055 L
.02696 .22587 L
.0262 .23074 L
.02559 .23607 L
.02519 .24189 L
.02506 .24738 L
.02517 .25247 L
.02557 .25848 L
.02588 .2615 L
.02631 .26481 L
.02729 .27066 L
.02846 .27609 L
.032 .28829 L
.03715 .30119 L
.05019 .32429 L
.06599 .34452 L
.08465 .36314 L
.10851 .38218 L
.16059 .41312 L
.19277 .4276 L
.22524 .4397 L
.26642 .45216 L
.30618 .46166 L
.34947 .46962 L
.39192 .47528 L
.41555 .47758 L
.43768 .47922 L
.45048 .47994 L
.46212 .48045 L
.46858 .48067 L
.47558 .48087 L
.4822 .48102 L
.48829 .48111 L
.49954 .48119 L
.5102 .48115 L
.51977 .48102 L
.53017 .48077 L
.54145 .48039 L
Mistroke
.55342 .47984 L
.57484 .4785 L
.59442 .47686 L
.61267 .47496 L
.65362 .46937 L
.69679 .46128 L
.73481 .45205 L
.77415 .44005 L
.81334 .42506 L
.84664 .40927 L
.87408 .39343 L
.91902 .35881 L
.9387 .33762 L
.94737 .32604 L
.95525 .3135 L
.96101 .30235 L
.96611 .28991 L
.96793 .28441 L
.96961 .27847 L
.97091 .27292 L
.9719 .26769 L
.97236 .26472 L
.97278 .2615 L
.9733 .25588 L
.97348 .25269 L
.97358 .24932 L
.97353 .24328 L
.97321 .2377 L
.97268 .23249 L
.97185 .22679 L
.97066 .22071 L
.96904 .21416 L
.96687 .20708 L
.96186 .19434 L
.94885 .17102 L
.93198 .14946 L
.90962 .12777 L
.88476 .10878 L
.8589 .09264 L
.79813 .06399 L
.76241 .05136 L
.72246 .03996 L
.68834 .03213 L
.65064 .02526 L
.62848 .02201 L
.6081 .01951 L
.58731 .01742 L
.56773 .01586 L
.54721 .01465 L
.53629 .01417 L
Mistroke
.52455 .01379 L
.51866 .01365 L
.51225 .01354 L
.50056 .01344 L
.48919 .01347 L
.47866 .01361 L
.46891 .01384 L
.45975 .01414 L
.44973 .01457 L
.43893 .01514 L
.41704 .01665 L
.3971 .01847 L
.3553 .02369 L
.31083 .03149 L
.26633 .04194 L
.22706 .05375 L
.19111 .06718 L
.15522 .08376 L
.1266 .10001 L
.09967 .11876 L
.07867 .13685 L
.05933 .15792 L
.04535 .17795 L
.0355 .19729 L
.03115 .20904 L
.02816 .22005 L
.02689 .22641 L
.02603 .2322 L
.02567 .23541 L
.02538 .23889 L
.0252 .24218 L
.0251 .2452 L
.02513 .2507 L
.02538 .25584 L
.0259 .26147 L
.02675 .26749 L
.02796 .27378 L
.02941 .27972 L
.0329 .29078 L
.03704 .3009 L
.04237 .31151 L
.05434 .33014 L
.07054 .34944 L
.09225 .36965 L
.11695 .38801 L
.14654 .40583 L
.20757 .4334 L
.24551 .44621 L
.28292 .45639 L
.32592 .4656 L
Mistroke
.34891 .46955 L
.37366 .47311 L
.39567 .47571 L
.42014 .47799 L
.43093 .4788 L
.44257 .47954 L
.45351 .48011 L
.46368 .48054 L
.47033 .48076 L
.47637 .48092 L
.48307 .48106 L
.49022 .48116 L
.49647 .48121 L
.50322 .48122 L
.50959 .48119 L
.51545 .48112 L
.52643 .48091 L
.53265 .48073 L
.53845 .48054 L
.55014 .48004 L
.56262 .47935 L
.58555 .47768 L
.61025 .47527 L
.65431 .46929 L
.6959 .4615 L
.73285 .45261 L
.76837 .44202 L
.80433 .42885 L
.86232 .40061 L
.89117 .38186 L
.91727 .36048 L
.93588 .34106 L
.95211 .31882 L
.95851 .3075 L
.96418 .29504 L
.96833 .28314 L
.96989 .27743 L
.9711 .27209 L
.97205 .26684 L
.97273 .26205 L
.97325 .25671 L
.97356 .25099 L
.97359 .2455 L
.97336 .23952 L
.97286 .23388 L
.97217 .22867 L
.97119 .22313 L
.96984 .21717 L
.96667 .20645 L
.96165 .19384 L
Mistroke
.95588 .18244 L
.94052 .15957 L
.91949 .13664 L
.89652 .11723 L
.87252 .10075 L
.84361 .08438 L
.80896 .06836 L
.77414 .05523 L
.73997 .04464 L
.70305 .03532 L
.66796 .02821 L
.62835 .02201 L
.60608 .01931 L
.58471 .01721 L
.56488 .01569 L
.54638 .01463 L
.5357 .01417 L
.526 .01386 L
.5148 .01361 L
.50423 .01348 L
.49354 .01347 L
.4818 .01358 L
.47589 .01369 L
.46956 .01385 L
.45815 .01423 L
.4468 .01473 L
.43608 .01533 L
.41608 .01676 L
.39269 .01896 L
.37129 .02149 L
.32389 .02896 L
.28589 .03702 L
.24672 .04753 L
.18164 .07123 L
.148 .08759 L
.11634 .1067 L
.0905 .12621 L
.07048 .14512 L
.05323 .16598 L
.04061 .18644 L
.03524 .19794 L
.03129 .20866 L
.02806 .22053 L
.02688 .22655 L
.02637 .22972 L
.02592 .23318 L
.02539 .23888 L
.02513 .2443 L
.02511 .24958 L
.0253 .25447 L
Mistroke
.02578 .26028 L
.02645 .26552 L
.0275 .27157 L
.02877 .27723 L
.03174 .28743 L
.03523 .29672 L
.04573 .3173 L
.06019 .33767 L
.07963 .35849 L
.12436 .39283 L
.15729 .41146 L
.19188 .42724 L
.22522 .43971 L
.26436 .45162 L
.3016 .46071 L
.3433 .46866 L
.3669 .47222 L
.3888 .47497 L
.41131 .47725 L
.4324 .47892 L
.45178 .48005 L
.46266 .48052 L
.47253 .48084 L
.48342 .48109 L
.4952 .48122 L
.50633 .48123 L
.51657 .48112 L
.52617 .48093 L
.53514 .48067 L
.54496 .48029 L
.55547 .47978 L
.57684 .4784 L
.5962 .47674 L
.63784 .4718 L
.68092 .46458 L
.71643 .45683 L
.754 .44658 L
.79194 .43371 L
.8298 .4177 L
.86201 .40081 L
.88882 .38356 L
.91306 .36432 L
.9318 .34574 L
.94873 .32409 L
.9563 .31166 L
.96209 .30001 L
.96662 .2885 L
.9702 .27619 L
.97155 .26977 L
.97251 .26374 L
Mistroke
.97293 .26028 L
.97323 .25712 L
.97346 .25346 L
.97359 .24999 L
.97358 .24426 L
.97327 .23817 L
.9727 .23242 L
.97194 .22723 L
.97077 .22111 L
.96916 .21453 L
.96532 .20268 L
.96077 .19192 L
.95482 .18056 L
.94133 .1606 L
.92083 .13792 L
.89815 .11848 L
.87072 .09964 L
.83687 .081 L
.80167 .0654 L
.76597 .05252 L
.72833 .04149 L
.69217 .03295 L
.65046 .02526 L
.6266 .02179 L
.60412 .01911 L
.58164 .01696 L
.56108 .01546 L
.54927 .01479 L
.53811 .01428 L
.5263 .01388 L
.51963 .01371 L
.51349 .0136 L
.50197 .01348 L
.49121 .01349 L
.4794 .01364 L
.47278 .01378 L
.46675 .01394 L
.45463 .01438 L
.44147 .01503 L
.41763 .01665 L
.39722 .0185 L
.37541 .02097 L
.3366 .02671 L
.29195 .03561 L
.25277 .04575 L
.17903 .07239 L
.14623 .08856 L
.11416 .1082 L
.08813 .12825 L
.06738 .14848 L
Mistroke
.05211 .16756 L
.0393 .18904 L
.03424 .20042 L
.02994 .21311 L
.02829 .21953 L
.02689 .22647 L
.02636 .22984 L
.02594 .23304 L
.02538 .23905 L
.02513 .24467 L
.02514 .25065 L
.02542 .25629 L
.02591 .2614 L
.02675 .26741 L
.028 .2739 L
.03114 .28558 L
.03509 .29639 L
.04041 .30782 L
.05279 .32798 L
.07201 .35096 L
.09359 .37074 L
.11993 .38998 L
.15272 .40912 L
.18702 .42522 L
.222 .43861 L
.29455 .45915 L
.33575 .46739 L
.35753 .47089 L
.3817 .47415 L
.40419 .4766 L
.42844 .47865 L
.44194 .47953 L
.45425 .48017 L
.4602 .48043 L
.46665 .48067 L
.47838 .481 L
.48917 .48118 L
.49531 .48123 L
.50105 .48125 L
.51263 .48119 L
.51912 .48109 L
.52505 .48097 L
.5356 .48067 L
.54707 .48021 L
.56789 .47905 L
.59049 .47728 L
.61467 .4748 L
.65769 .46877 L
.69827 .46102 L
.73414 .45229 L
Mistroke
.80934 .42681 L
.84305 .41118 L
.87626 .39207 L
.90339 .37252 L
.9253 .35267 L
.94167 .3339 L
.95575 .31267 L
.96147 .3014 L
.96652 .28881 L
.96855 .28242 L
.97036 .27551 L
.9717 .26897 L
.97262 .26296 L
.97323 .25703 L
.97355 .25152 L
.9736 .24546 L
.9735 .24208 L
.97333 .23901 L
.97281 .23339 L
.97196 .22731 L
.97088 .22159 L
.96964 .21634 L
.96621 .2051 L
.96216 .19495 L
.94993 .17261 L
.93483 .15266 L
.9173 .13459 L
.86757 .09772 L
.83364 .07943 L
.79893 .06432 L
.76552 .05238 L
.72728 .04122 L
.69264 .03306 L
.65333 .02573 L
.60841 .01958 L
.58345 .01712 L
.57141 .01617 L
.56 .0154 L
.54939 .0148 L
.53785 .01428 L
.52734 .01391 L
.51763 .01368 L
.50713 .01353 L
.49556 .01348 L
.48974 .01351 L
.48348 .01358 L
.47218 .0138 L
.46606 .01397 L
.4603 .01417 L
.44955 .01462 L
Mistroke
.42555 .01605 L
.40495 .01775 L
.38288 .02007 L
.33371 .02721 L
.29012 .03604 L
.25332 .0456 L
.2151 .05796 L
.17822 .07276 L
.14624 .08855 L
.11811 .10552 L
.09129 .12556 L
.07218 .14334 L
.05469 .16397 L
.04022 .18721 L
.0343 .20026 L
.03208 .20629 L
.03007 .21266 L
.0286 .21822 L
.02728 .22432 L
.02636 .22988 L
.02572 .23505 L
.02525 .2412 L
.0251 .24678 L
.02512 .24987 L
.02524 .25322 L
.02568 .25929 L
.02638 .26502 L
.02725 .27024 L
.02854 .27624 L
.03003 .28192 L
.03334 .29193 L
.0379 .30272 L
.05181 .32659 L
.06901 .34779 L
.09175 .36923 L
.11599 .38736 L
.14609 .40559 L
.18161 .4229 L
.21504 .43616 L
.25427 .44881 L
.29243 .45867 L
.32859 .46612 L
.37285 .47304 L
.39772 .47595 L
.42149 .47813 L
.43222 .47892 L
.44364 .47963 L
.45354 .48014 L
.46421 .48059 L
.47566 .48094 L
Mistroke
.48641 .48115 L
.49296 .48122 L
.49919 .48125 L
.5109 .48121 L
.52199 .48104 L
.52824 .48089 L
.53399 .48072 L
.54454 .48033 L
.55567 .47979 L
.57491 .47856 L
.59589 .47679 L
.61811 .4744 L
.64166 .47127 L
.68319 .46415 L
.72325 .45514 L
.75948 .4449 L
.82183 .42139 L
.85107 .40695 L
.88027 .38945 L
.90532 .37095 L
.92827 .34958 L
.94564 .32856 L
.95197 .31906 L
.95799 .30851 L
.96252 .29905 L
.96651 .28883 L
.96834 .28314 L
.96977 .27794 L
.97091 .27303 L
.97191 .26774 L
.97271 .26221 L
.97323 .25702 L
.97344 .25386 L
.97357 .25085 L
.9736 .24521 L
.97335 .23929 L
.97286 .2338 L
.97204 .22779 L
.97084 .22141 L
.96783 .20997 L
.96401 .19931 L
.95434 .17973 L
.93863 .1572 L
.92032 .13743 L
.89618 .11698 L
.86644 .09704 L
.80632 .06728 L
.76824 .05327 L
.73126 .04227 L
.69511 .03359 L
Mistroke
.65429 .02588 L
.63514 .02297 L
.61456 .0203 L
.59674 .01836 L
.5771 .0166 L
.55597 .01516 L
.54441 .01456 L
.53363 .01412 L
.52348 .01381 L
.51426 .01362 L
.50361 .0135 L
.49356 .01349 L
.48259 .0136 L
.471 .01383 L
.46111 .01414 L
.45027 .01459 L
.43863 .0152 L
.42618 .01601 L
.40383 .01786 L
.36124 .02287 L
.3219 .02936 L
.28767 .03661 L
.25186 .04603 L
.18388 .07028 L
.1494 .08685 L
.12025 .10411 L
.09505 .12246 L
.07235 .14317 L
.05233 .16725 L
.04473 .17902 L
.03866 .19034 L
.03394 .20118 L
.02995 .21307 L
.02857 .21835 L
.02735 .22397 L
.02652 .22877 L
.02583 .23407 L
.02552 .23723 L
.02531 .24023 L
.02511 .24586 L
.02518 .25192 L
.02536 .25535 L
.02561 .25853 L
.02628 .26434 L
.02713 .26959 L
.02839 .27563 L
.02985 .2813 L
.03319 .29151 L
.03764 .30219 L
.04801 .32093 L
Mistroke
.06249 .34044 L
.08218 .36087 L
.10696 .38104 L
.13401 .39874 L
.19314 .42777 L
.23039 .44145 L
.26711 .45238 L
.30952 .4624 L
.35653 .47075 L
.377 .47357 L
.3988 .47607 L
.41781 .47783 L
.43826 .47932 L
.44989 .47997 L
.46047 .48045 L
.47113 .48082 L
.4812 .48106 L
.49297 .48123 L
.50382 .48126 L
.50949 .48122 L
.51573 .48115 L
.52224 .48104 L
.52832 .48089 L
.5384 .48057 L
.54937 .48011 L
.56926 .47896 L
.58851 .47746 L
.60623 .47574 L
.6458 .47065 L
.68677 .46344 L
.73016 .45336 L
.76799 .44217 L
.80615 .42813 L
.84445 .41046 L
.8993 .37577 L
.92344 .35455 L
.94191 .33359 L
.95636 .31156 L
.96263 .29879 L
.96718 .28684 L
.97017 .27631 L
.97146 .27028 L
.97239 .26463 L
.97309 .25866 L
.97348 .2532 L
.97358 .25018 L
.97362 .24689 L
.97344 .24089 L
.97299 .23505 L
.97231 .22955 L
Mistroke
.97148 .22462 L
.97037 .2193 L
.96701 .20743 L
.96288 .19661 L
.95284 .17722 L
.93877 .15738 L
.91981 .13694 L
.89922 .1193 L
.87376 .10154 L
.84247 .08381 L
.81054 .06904 L
.77866 .05681 L
.71023 .037 L
.67232 .02903 L
.63004 .02226 L
.6102 .01979 L
.58909 .01763 L
.57093 .01614 L
.55093 .01488 L
.53858 .01431 L
.52689 .01391 L
.51639 .01366 L
.50498 .01351 L
.49906 .01349 L
.49255 .0135 L
.48575 .01356 L
.47938 .01365 L
.46801 .01392 L
.46164 .01412 L
.45582 .01435 L
.43419 .01547 L
.42201 .01632 L
.41075 .01723 L
.36865 .02186 L
.34598 .02517 L
.32547 .0287 L
.28052 .03834 L
.24277 .04875 L
.20519 .06163 L
.1466 .08836 L
.11766 .10582 L
.09383 .12345 L
.07199 .14354 L
.05276 .16664 L
.04558 .17759 L
.03911 .18942 L
.03449 .19979 L
.03054 .21108 L
.02905 .21641 L
.02774 .22204 L
Mistroke
.02676 .22727 L
.02605 .23214 L
.02556 .23673 L
.02523 .24163 L
.0251 .24707 L
.02519 .25201 L
.02555 .25783 L
.02612 .26318 L
.02703 .26905 L
.0283 .27523 L
.03114 .28557 L
.03528 .29683 L
.04054 .30806 L
.04748 .3201 L
.06327 .34136 L
.08241 .36108 L
.1033 .37835 L
.16091 .41328 L
.19484 .42846 L
.23557 .44313 L
.27325 .45399 L
.31499 .46352 L
.35197 .47006 L
.39358 .47552 L
.41749 .47781 L
.43943 .47939 L
.45163 .48006 L
.45807 .48035 L
.4649 .48062 L
.47088 .48081 L
.47746 .48099 L
.48907 .48119 L
.50073 .48126 L
.5114 .48121 L
.51729 .48113 L
.52371 .48101 L
.53539 .48068 L
.54625 .48026 L
.55781 .47967 L
.57851 .47829 L
.60139 .47625 L
.6253 .47351 L
.66729 .46713 L
.71094 .45816 L
.75647 .44584 L
.79344 .43315 L
.83016 .41755 L
.88748 .38452 L
.91314 .36426 L
.93311 .34427 L
Mistroke
.95062 .3212 L
.95764 .30918 L
.96393 .29569 L
.96815 .28377 L
.97097 .27276 L
.97204 .26695 L
.9729 .26059 L
.97321 .25738 L
.97344 .25394 L
.97357 .2507 L
.97362 .24775 L
.97349 .24193 L
.97314 .23657 L
.97247 .23069 L
.97203 .22774 L
.97146 .22449 L
.9688 .21323 L
.96536 .20278 L
.96038 .1911 L
.95474 .18043 L
.93841 .15694 L
.92006 .13719 L
.89668 .11736 L
.87003 .09922 L
.84192 .08353 L
.78239 .05813 L
.74761 .04685 L
.70734 .03632 L
.66331 .02741 L
.64163 .02391 L
.62082 .02106 L
.60137 .01883 L
.58003 .01684 L
.5605 .01544 L
.54237 .01447 L
.53223 .01408 L
.52272 .0138 L
.51227 .01359 L
.50102 .01349 L
.48983 .01352 L
.47808 .01368 L
.46806 .01392 L
.45713 .0143 L
.44534 .01484 L
.43451 .01546 L
.41019 .01728 L
.38893 .01939 L
.36669 .02212 L
.32886 .02808 L
.28863 .03639 L
Mistroke
.24756 .0473 L
.20615 .06126 L
.13993 .09208 L
.1105 .11076 L
.08675 .12946 L
.06483 .15136 L
.05539 .16303 L
.04659 .17593 L
.04014 .18737 L
.03521 .19801 L
.03141 .2083 L
.02836 .21924 L
.02714 .22507 L
.0266 .22828 L
.02616 .23132 L
.02552 .23724 L
.02519 .24262 L
.02511 .24573 L
.02511 .24902 L
.02533 .25493 L
.02558 .25821 L
.02589 .26128 L
.02689 .26825 L
.02802 .27401 L
.02953 .28014 L
.03302 .29108 L
.03847 .30393 L
.0446 .3154 L
.05996 .3374 L
.07824 .35718 L
.12144 .39097 L
.15059 .408 L
.18014 .42226 L
.21277 .43534 L
.25016 .44762 L
.28426 .45675 L
.32291 .46506 L
.34714 .4693 L
.36993 .47265 L
.39157 .4753 L
.41571 .47766 L
.43748 .47927 L
.44747 .47985 L
.45801 .48035 L
.46936 .48077 L
.47978 .48104 L
.491 .48121 L
.49736 .48125 L
.50327 .48126 L
.51399 .48118 L
Mistroke
.52533 .48097 L
.53499 .4807 L
.5456 .48029 L
.55699 .47972 L
.56918 .47897 L
.59107 .47724 L
.61293 .47501 L
.63345 .47243 L
.67123 .46642 L
.70691 .4591 L
.73878 .45102 L
.80576 .42829 L
Mfstroke
.92118 .3547 m
.93854 .33557 L
.95159 .317 L
.96232 .29597 L
.96665 .28397 L
.96952 .27295 L
.97059 .26731 L
.97144 .26132 L
.97192 .25619 L
.97221 .25053 L
.97221 .24446 L
.97208 .24105 L
.97188 .23794 L
.97125 .23189 L
.97038 .22616 L
.96932 .22087 L
.96794 .21525 L
.9648 .2052 L
.95995 .19336 L
.95454 .18277 L
.9387 .15934 L
.91994 .13876 L
.89494 .11745 L
.86388 .09667 L
.80197 .06627 L
.76216 .05182 L
.72243 .04029 L
.68193 .03098 L
.6599 .02683 L
.63607 .023 L
.61499 .02015 L
.59145 .01754 L
.56982 .01566 L
.56007 .01497 L
.54937 .01433 L
.5396 .01384 L
.52914 .01342 L
.51807 .0131 L
.50777 .0129 L
.49746 .01282 L
.48773 .01283 L
.47899 .01292 L
.46953 .01311 L
.45917 .01342 L
.4478 .01388 L
.43595 .0145 L
.42489 .0152 L
.40522 .01678 L
.38426 .01891 L
.339 .0252 L
Mistroke
.29835 .033 L
.25562 .0437 L
.21279 .05751 L
.17495 .07293 L
.14246 .08932 L
.09103 .12435 L
.07077 .1433 L
.05255 .1652 L
.04501 .17661 L
.0382 .18905 L
.03337 .19996 L
.02927 .21194 L
.02771 .21777 L
.02637 .22397 L
.02547 .22928 L
.02474 .23514 L
.02432 .24062 L
.02413 .24652 L
.02422 .25209 L
.02452 .25719 L
.02502 .26216 L
.02567 .26678 L
.02658 .27183 L
.02778 .2772 L
.03097 .28813 L
.03471 .29794 L
.04614 .31972 L
.06254 .34188 L
.07991 .35991 L
.10238 .37862 L
.13026 .39729 L
.1641 .41548 L
.23413 .443 L
.27472 .45454 L
.3142 .46339 L
.35922 .47102 L
.3825 .47405 L
.40855 .47674 L
.43142 .47851 L
.45254 .47969 L
.46365 .48013 L
.47003 .48033 L
.47583 .48047 L
.48198 .48059 L
.48856 .48067 L
.49466 .48071 L
.50043 .48072 L
.51094 .48065 L
.52207 .48045 L
.53157 .48019 L
Mistroke
.54201 .4798 L
.55319 .47926 L
.56519 .47855 L
.58675 .47689 L
.60891 .47469 L
.63225 .47179 L
.67338 .46517 L
.72044 .45495 L
.76091 .44353 L
.79697 .43085 L
.83307 .4152 L
.86382 .39879 L
.88953 .38208 L
.91335 .36305 L
.9318 .34465 L
.94847 .32321 L
.95594 .31089 L
.96166 .29931 L
.9661 .28793 L
.96961 .27573 L
.97094 .26937 L
.97188 .26339 L
.97229 .25996 L
.97257 .25681 L
.97279 .25336 L
.97292 .24972 L
.9729 .24404 L
.97258 .23799 L
.972 .23228 L
.97124 .2271 L
.97007 .22102 L
.96845 .21446 L
.96459 .20263 L
.96008 .19201 L
.95417 .18075 L
.94078 .16091 L
.92044 .13835 L
.89788 .11894 L
.87066 .10014 L
.83695 .08145 L
.76619 .05278 L
.72528 .04078 L
.68476 .0314 L
.647 .0246 L
.60506 .01899 L
.58279 .0168 L
.55817 .01497 L
.54569 .01427 L
.53881 .01396 L
.5323 .0137 L
Mistroke
.52623 .0135 L
.51964 .01333 L
.50809 .01312 L
.4973 .01305 L
.49116 .01306 L
.48541 .0131 L
.47383 .01329 L
.46733 .01345 L
.46138 .01364 L
.45084 .01406 L
.43936 .01464 L
.41852 .01604 L
.39609 .01805 L
.37207 .02081 L
.32939 .02734 L
.28921 .03559 L
.25373 .04481 L
.1798 .07137 L
.14685 .08754 L
.11452 .10726 L
.08848 .12724 L
.06761 .14746 L
.05223 .16653 L
.03925 .18806 L
.03413 .19943 L
.02974 .21212 L
.02804 .21855 L
.02659 .2255 L
.02605 .22871 L
.02558 .23209 L
.02498 .23813 L
.02468 .24375 L
.02465 .24974 L
.02489 .2554 L
.02534 .26053 L
.02614 .26656 L
.02734 .27308 L
.03042 .28484 L
.03427 .29559 L
.03948 .30701 L
.05166 .32716 L
.07063 .35012 L
.09203 .36995 L
.11811 .38917 L
.15068 .40834 L
.21969 .43794 L
.25974 .45041 L
.29957 .46024 L
.33679 .46747 L
.37826 .47356 L
Mistroke
.40029 .47601 L
.4247 .47813 L
.43708 .47898 L
.45039 .47971 L
.46298 .48025 L
.47447 .4806 L
.48593 .48082 L
.49652 .48091 L
.50815 .48088 L
.51402 .48082 L
.52049 .48071 L
.5313 .48043 L
.54293 .48001 L
.55388 .47949 L
.56388 .4789 L
.58583 .47727 L
.6056 .47537 L
.64922 .46966 L
.68849 .4626 L
.72424 .4544 L
.79856 .43068 L
.83606 .4142 L
.8673 .39719 L
.89261 .38033 L
.91629 .3609 L
.93367 .34311 L
.94915 .32285 L
.95674 .31016 L
.96252 .29821 L
.96691 .28664 L
.96871 .28067 L
.97032 .2742 L
.97147 .2684 L
.97228 .26305 L
.97284 .25794 L
.97318 .25254 L
.97329 .24661 L
.97313 .24108 L
.97267 .23503 L
.97227 .23164 L
.97183 .22856 L
.96972 .21796 L
.9681 .21196 L
.96631 .20636 L
.9615 .19425 L
.95602 .18331 L
.94354 .16399 L
.92654 .14401 L
.90444 .12376 L
.87598 .10319 L
Mistroke
.81369 .07048 L
.77629 .05604 L
.73856 .04426 L
.70245 .03515 L
.66275 .02721 L
.64155 .02377 L
.61793 .02055 L
.59593 .0181 L
.57569 .01629 L
.5516 .0147 L
.53828 .01406 L
.53215 .01383 L
.52563 .01362 L
.51394 .01336 L
.50311 .01324 L
.49146 .01323 L
.48483 .01329 L
.47861 .01338 L
.4681 .01362 L
.45689 .014 L
.44633 .01448 L
.43676 .015 L
.41339 .01668 L
.39151 .01877 L
.34865 .0244 L
.30362 .03268 L
.26605 .0417 L
.22821 .05305 L
.1664 .07789 L
.13597 .09402 L
.11094 .1101 L
.08722 .1287 L
.06542 .15032 L
.04928 .17129 L
.04287 .1818 L
.03788 .19144 L
.03382 .20088 L
.03028 .21117 L
.02871 .21686 L
.0275 .22212 L
.02657 .22707 L
.02579 .23247 L
.02521 .23838 L
.02492 .24397 L
.02489 .24941 L
.02508 .25444 L
.02552 .25986 L
.02628 .26583 L
.02738 .27204 L
.0287 .27785 L
Mistroke
.03183 .28835 L
.03548 .29787 L
.04649 .31891 L
.06245 .34069 L
.08457 .36326 L
.1097 .38319 L
.13649 .40032 L
.16769 .41666 L
.20484 .43242 L
.24016 .44458 L
.27976 .4556 L
.31721 .46388 L
.35985 .47113 L
.37897 .47369 L
.39969 .47601 L
.41762 .47766 L
.43756 .4791 L
.44924 .47976 L
.46025 .48025 L
.47189 .48065 L
.47844 .48081 L
.48446 .48092 L
.49459 .48103 L
.50568 .48104 L
.51726 .48091 L
.52803 .48068 L
.53418 .4805 L
.54084 .48025 L
.55292 .4797 L
.57544 .47828 L
.60152 .47599 L
.62532 .47325 L
.66491 .46729 L
.70709 .45879 L
.74914 .44779 L
.78629 .43556 L
.82072 .42164 L
.85506 .40452 L
.88225 .38788 L
.90773 .3687 L
.92916 .34839 L
.94511 .32902 L
.95158 .31939 L
.95766 .30881 L
.96253 .29863 L
.9662 .28926 L
.96951 .27836 L
.9709 .27232 L
.97195 .26659 L
.97267 .26129 L
Mistroke
.97313 .25638 L
.97341 .25099 L
.97345 .24526 L
.97322 .23954 L
.97297 .23632 L
.97266 .23337 L
.97191 .22795 L
.97087 .22226 L
.96776 .21024 L
.96299 .19723 L
.95703 .18482 L
.9505 .17374 L
.93203 .14968 L
.91042 .12859 L
.8863 .10994 L
.82895 .07725 L
.79573 .06309 L
.75635 .04946 L
.72068 .03949 L
.6806 .03054 L
.64138 .02378 L
.60463 .01906 L
.58261 .01693 L
.56252 .01543 L
.55132 .01476 L
.53919 .01419 L
.52772 .01378 L
.51717 .01352 L
.50734 .01338 L
.49817 .01333 L
.48811 .01337 L
.47735 .01352 L
.46606 .01381 L
.4554 .01419 L
.44585 .01463 L
.4355 .01521 L
.41349 .01682 L
.38945 .01915 L
.34173 .02567 L
.29897 .03385 L
.26055 .04337 L
.22298 .055 L
.18468 .06975 L
.15361 .08445 L
.1236 .10177 L
.09737 .12043 L
.07679 .13853 L
.06055 .15625 L
.04611 .17652 L
.04021 .187 L
Mistroke
.03495 .19839 L
.03059 .21057 L
.02904 .21605 L
.02764 .22204 L
.02654 .22801 L
.02578 .23354 L
.0253 .23883 L
.02503 .24446 L
.02502 .24948 L
.02519 .25419 L
.02559 .25935 L
.02626 .26491 L
.02729 .27097 L
.02852 .27659 L
.03227 .28926 L
.0372 .30146 L
.04385 .3143 L
.05945 .3369 L
.07745 .35651 L
.09942 .37546 L
.12637 .39415 L
.18328 .42364 L
.2191 .4376 L
.25493 .44897 L
.29645 .45953 L
.34317 .46858 L
.36483 .47187 L
.38822 .47483 L
.40866 .47693 L
.43093 .47873 L
.4447 .47959 L
.4574 .48021 L
.46956 .48066 L
.47569 .48083 L
.48242 .48097 L
.49412 .48111 L
.50068 .48114 L
.50665 .48112 L
.51826 .48099 L
.52923 .48074 L
.53952 .4804 L
.55085 .47991 L
.57367 .47852 L
.59466 .47677 L
.61419 .47472 L
.65739 .46868 L
.70239 .45998 L
.74184 .45003 L
.77666 .43912 L
.81535 .42413 L
Mistroke
.84757 .40871 L
.90357 .37226 L
.92794 .34982 L
.94638 .32738 L
.95876 .30687 L
.96415 .29496 L
.9681 .2837 L
.96979 .27756 L
.97111 .27172 L
.97205 .26646 L
.97282 .26073 L
.97311 .25776 L
.97334 .25449 L
.9735 .25107 L
.97355 .24785 L
.97344 .24212 L
.97326 .23889 L
.97301 .23594 L
.97244 .23096 L
.97161 .22564 L
.96951 .2161 L
.96604 .20483 L
.96197 .19469 L
.95015 .17307 L
.93535 .15336 L
.91709 .13445 L
.89324 .11484 L
.86647 .09708 L
.83409 .07966 L
.80082 .06506 L
.7681 .0532 L
.69859 .0343 L
.65906 .02662 L
.63681 .02314 L
.61557 .02035 L
.5955 .01816 L
.57359 .01626 L
.55355 .01494 L
.54387 .01445 L
.53503 .01409 L
.52433 .01375 L
.51285 .01351 L
.50221 .01341 L
.49213 .01341 L
.4804 .01354 L
.46957 .01378 L
.46392 .01395 L
.45769 .01417 L
.44511 .01475 L
.4217 .01624 L
Mistroke
.39667 .01847 L
.3733 .02115 L
.35215 .02411 L
.31231 .03113 L
.27136 .04056 L
.20294 .0624 L
.16521 .07872 L
.133 .09604 L
.10738 .11292 L
.08283 .1329 L
.06282 .15362 L
.0478 .17392 L
.03597 .19612 L
.03119 .20883 L
.02951 .2145 L
.02802 .22056 L
.02689 .22627 L
.0261 .23146 L
.02552 .23668 L
.02519 .24159 L
.02506 .24735 L
.02517 .25264 L
.02556 .25844 L
.02627 .26455 L
.02707 .26951 L
.02816 .27481 L
.0307 .28432 L
.0347 .29552 L
.03924 .30561 L
.05195 .32686 L
.06962 .34849 L
.08797 .36606 L
.11149 .38429 L
.14031 .40239 L
.17512 .42001 L
.24671 .44656 L
.28765 .45752 L
.32746 .46587 L
.37272 .47297 L
.3986 .47599 L
.42234 .47814 L
.43344 .47894 L
.44521 .47966 L
.4554 .48017 L
.46636 .4806 L
.47253 .48079 L
.47817 .48093 L
.4892 .48112 L
.49538 .48117 L
.50209 .48119 L
Mistroke
.50844 .48116 L
.51431 .4811 L
.52464 .48092 L
.53433 .48064 L
.54495 .48024 L
.55637 .47968 L
.57953 .47814 L
.60061 .47625 L
.64156 .47121 L
.68413 .4639 L
.72284 .45518 L
.75652 .44576 L
.79398 .43289 L
.83154 .41683 L
.86348 .3999 L
.8902 .38253 L
.91392 .36351 L
.93237 .34507 L
.94903 .32358 L
.95651 .31122 L
.96226 .29957 L
.9667 .28819 L
.97023 .27595 L
.97168 .26891 L
.97225 .26545 L
.97268 .26227 L
.97326 .2563 L
.97345 .25315 L
.97356 .24983 L
.97355 .24415 L
.97323 .23808 L
.97266 .23235 L
.9719 .22714 L
.97073 .22104 L
.96911 .21444 L
.96523 .20252 L
.96076 .19195 L
.95488 .18072 L
.94155 .16091 L
.92131 .13841 L
.89879 .11899 L
.84139 .08326 L
.80758 .06779 L
.76737 .05297 L
.72682 .04108 L
.68655 .03177 L
.64902 .025 L
.60722 .01942 L
.58513 .01723 L
.56064 .01539 L
Mistroke
.54823 .0147 L
.54139 .01438 L
.53489 .01412 L
.52884 .01392 L
.52226 .01374 L
.51072 .01352 L
.49999 .01344 L
.49388 .01344 L
.48814 .01348 L
.4766 .01365 L
.4701 .01381 L
.46415 .01399 L
.45415 .01436 L
.44322 .01489 L
.42127 .01632 L
.39907 .01827 L
.37521 .02096 L
.33273 .02734 L
.29271 .0354 L
.25724 .04444 L
.1833 .07049 L
.1502 .08639 L
.11755 .10586 L
.09139 .12544 L
.07025 .14535 L
.05455 .16413 L
.04112 .18543 L
.03527 .19783 L
.0311 .20921 L
.02925 .21556 L
.02763 .22247 L
.02647 .22901 L
.02571 .23504 L
.02527 .24064 L
.02509 .24588 L
.02515 .25162 L
.02531 .25484 L
.02552 .25777 L
.02617 .26367 L
.02666 .26699 L
.0272 .27006 L
.02993 .28164 L
.0336 .29268 L
.03786 .30269 L
.05053 .32477 L
.06512 .34352 L
.08382 .36238 L
.13403 .39875 L
.16822 .41681 L
.20328 .43177 L
Mistroke
.2401 .44455 L
.28258 .45631 L
.32475 .46538 L
.36504 .47195 L
.4023 .47639 L
.42375 .47827 L
.44397 .47962 L
.45494 .48018 L
.46537 .4806 L
.47475 .48088 L
.48499 .48109 L
.4961 .48121 L
.5023 .48122 L
.50792 .4812 L
.51888 .48107 L
.52917 .48083 L
.53957 .48049 L
.55069 .48001 L
.57066 .47883 L
.59425 .47691 L
.61553 .47467 L
.66097 .46819 L
.70256 .46004 L
.77145 .44099 L
.80719 .42767 L
.83781 .41381 L
.86601 .39843 L
.89317 .38039 L
.91377 .36367 L
.93303 .34435 L
.95021 .32182 L
.95765 .30914 L
.96331 .29717 L
.96752 .28576 L
.97039 .27532 L
.97159 .2695 L
.97211 .26644 L
.97258 .26319 L
.97321 .25722 L
.97353 .25172 L
.9736 .24606 L
.97352 .24286 L
.97338 .2399 L
.97292 .23448 L
.97218 .22873 L
.97128 .22361 L
.97024 .21882 L
.96717 .20794 L
.96277 .19637 L
.95775 .18589 L
Mistroke
.94304 .16285 L
.92783 .14497 L
.90792 .12632 L
.85819 .09224 L
.82522 .07547 L
.79113 .06132 L
.7208 .03955 L
.67837 .03016 L
.63773 .02332 L
.61418 .02023 L
.59187 .01786 L
.56838 .01593 L
.55585 .01513 L
.54234 .01444 L
.53047 .01399 L
.5197 .0137 L
.51372 .01359 L
.50726 .01351 L
.49553 .01346 L
.48452 .01354 L
.47289 .01376 L
.46297 .01405 L
.45211 .01448 L
.43931 .01514 L
.42767 .01588 L
.40169 .01804 L
.37786 .02065 L
.35558 .02367 L
.31352 .03097 L
.27602 .03944 L
.23705 .05051 L
.19766 .06454 L
.16395 .0794 L
.1357 .09451 L
.08855 .12788 L
.06842 .14733 L
.05061 .16972 L
.04335 .18139 L
.03691 .19408 L
.0321 .20622 L
.03027 .21196 L
.0288 .21735 L
.02755 .22294 L
.02663 .22806 L
.02585 .23375 L
.02532 .23987 L
.0251 .24574 L
.0251 .24906 L
.02518 .25213 L
.02554 .25776 L
Mistroke
.02619 .26375 L
.02707 .2693 L
.0283 .27527 L
.03128 .28602 L
.03509 .2964 L
.03939 .30582 L
.05215 .32709 L
.07054 .34943 L
.09442 .37143 L
.12071 .39049 L
.14987 .40762 L
.18506 .42439 L
.21883 .4375 L
.2571 .44961 L
.29341 .45888 L
.33513 .46727 L
.37433 .47321 L
.41188 .4773 L
.43455 .47906 L
.44544 .47972 L
.45573 .48023 L
.4616 .48047 L
.46796 .4807 L
.47907 .481 L
.48539 .48112 L
.49206 .4812 L
.49776 .48123 L
.50402 .48124 L
.51551 .48114 L
.52599 .48094 L
.53178 .48078 L
.53807 .48057 L
.54949 .48009 L
.57142 .47879 L
.59158 .47717 L
.62871 .47305 L
.66878 .46685 L
.70927 .45853 L
.74571 .44904 L
.81682 .4236 L
.84865 .40825 L
.87997 .38964 L
.90362 .37232 L
.92539 .35257 L
.94242 .33291 L
.95479 .31434 L
.96066 .30314 L
.96517 .29251 L
.96886 .28132 L
.97039 .27534 L
Mistroke
.97171 .2689 L
.97255 .26343 L
.9732 .25746 L
.97353 .25181 L
.97361 .24656 L
.97347 .24137 L
.97314 .23667 L
.97255 .23125 L
.97176 .22617 L
.97065 .22058 L
.96914 .21448 L
.96516 .20226 L
.96036 .19107 L
.95494 .18078 L
.93942 .15818 L
.91792 .13516 L
.89312 .1147 L
.86666 .09717 L
.83468 .07993 L
.79562 .06303 L
.72236 .03995 L
.67898 .03028 L
.63669 .02318 L
.59592 .01826 L
.57248 .01624 L
.55054 .01485 L
.53852 .0143 L
.52716 .0139 L
.51695 .01366 L
.50588 .01351 L
.50012 .01348 L
.49379 .01348 L
.48719 .01353 L
.48101 .01361 L
.46998 .01385 L
.46379 .01404 L
.45815 .01424 L
.43717 .01528 L
.41784 .01663 L
.39677 .01854 L
.37458 .02108 L
.33801 .02647 L
.29877 .03408 L
.25971 .04378 L
.22071 .05596 L
.15766 .08254 L
.12691 .09984 L
.10147 .1174 L
.0774 .1381 L
.05641 .16167 L
Mistroke
.04852 .17288 L
.04137 .185 L
.03622 .19564 L
.03176 .20722 L
.02976 .21376 L
.02823 .21977 L
.02699 .2259 L
.02612 .2316 L
.02575 .2348 L
.02544 .23822 L
.02521 .24201 L
.02511 .24545 L
.0251 .24871 L
.02519 .25224 L
.02537 .25557 L
.02562 .25862 L
.02624 .26403 L
.02717 .26982 L
.02955 .28021 L
.03144 .28652 L
.03354 .29247 L
.03826 .30351 L
.05097 .32539 L
.06939 .34821 L
.08989 .36767 L
.11231 .38484 L
.14271 .40373 L
.17385 .41944 L
.2457 .44628 L
.28719 .45744 L
.33307 .46692 L
.35483 .47049 L
.37566 .47339 L
.39482 .47564 L
.41528 .47761 L
.43776 .47928 L
.44779 .47985 L
.4586 .48036 L
.47022 .48078 L
.48111 .48105 L
.48776 .48116 L
.49407 .48123 L
.49974 .48125 L
.50591 .48124 L
.51706 .48112 L
.52754 .48091 L
.53694 .48062 L
.54708 .48021 L
.5698 .47892 L
.59053 .47728 L
Mistroke
.62796 .47316 L
.66658 .46725 L
.7076 .45893 L
.74343 .4497 L
.78006 .43805 L
.81719 .42345 L
.84874 .4082 L
.87523 .39274 L
.91907 .3588 L
.93717 .33953 L
.95272 .31784 L
.95874 .30705 L
.96354 .29665 L
.96736 .2863 L
.97004 .27683 L
.97133 .27095 L
.97228 .26539 L
.97301 .25951 L
.9733 .25619 L
.97348 .25313 L
.97361 .24802 L
.97351 .2424 L
.97313 .23654 L
.97252 .23107 L
.97207 .22798 L
.97148 .22462 L
.97018 .21852 L
.96691 .20716 L
.96175 .19403 L
.95568 .18207 L
.94235 .16192 L
.92407 .1411 L
.88132 .10644 L
.85135 .08846 L
.81608 .0714 L
.77998 .05727 L
.74489 .04606 L
.70889 .03668 L
.66816 .02827 L
.64515 .02444 L
.62359 .02141 L
.6014 .01883 L
.58042 .01687 L
.56237 .01555 L
.54285 .01449 L
.53171 .01405 L
.52111 .01375 L
.51159 .01358 L
.5012 .01349 L
.49008 .01351 L
Mistroke
.48001 .01363 L
.4684 .0139 L
.45749 .01427 L
.44737 .01473 L
.43808 .01523 L
.41722 .01669 L
.39561 .01867 L
.3761 .02089 L
.33308 .02732 L
.29448 .03504 L
.25935 .04389 L
.18691 .06898 L
.15061 .0862 L
.1205 .10394 L
.09659 .12121 L
.07439 .14109 L
.057 .1609 L
.04427 .17979 L
.03874 .19017 L
.03386 .20139 L
.03154 .2079 L
.02973 .21385 L
.0283 .21951 L
.02706 .22552 L
.02656 .22852 L
.02609 .23182 L
.02549 .23764 L
.02527 .24091 L
.02513 .24443 L
.0251 .24775 L
.02515 .25079 L
.02545 .25664 L
.02575 .25995 L
.0261 .26301 L
.02695 .26862 L
.02814 .27456 L
.03147 .2866 L
.03627 .29915 L
.04813 .32112 L
.06543 .34385 L
.08955 .36738 L
.11454 .38638 L
.14517 .40508 L
.20939 .43409 L
.24862 .44716 L
.28701 .4574 L
.33115 .46658 L
.35437 .47042 L
.37976 .47391 L
.40223 .47641 L
Mistroke
.42299 .47825 L
.43302 .47897 L
.44401 .47965 L
.45434 .48018 L
.46409 .48058 L
.47003 .48078 L
.47647 .48096 L
.48771 .48117 L
.4941 .48123 L
.50085 .48126 L
.50661 .48124 L
.51293 .48119 L
.52425 .48099 L
.53059 .48083 L
.53637 .48064 L
.54759 .48019 L
.55819 .47965 L
.57911 .47824 L
.59863 .47652 L
.64245 .47115 L
.68397 .464 L
.72702 .45418 L
.76307 .44377 L
.79886 .43106 L
.85626 .4041 L
.88453 .38657 L
.9072 .36938 L
.92817 .34969 L
.94663 .32715 L
.95343 .31668 L
.95957 .3054 L
.96429 .2948 L
.96784 .28479 L
.97039 .27536 L
.9715 .27004 L
.97232 .26518 L
.97298 .25985 L
.97343 .25404 L
.97361 .24855 L
.97355 .24345 L
.97321 .23745 L
.97293 .23443 L
.97253 .23113 L
.97161 .22528 L
.97049 .21985 L
.96708 .20766 L
.96206 .19474 L
.95606 .18276 L
.94926 .17161 L
.93367 .15134 L
Mistroke
.91498 .13246 L
.89481 .11595 L
.86986 .09911 L
.83978 .08245 L
.80658 .06739 L
.77377 .05512 L
.70378 .0355 L
.66418 .02756 L
.61944 .02089 L
.59639 .01832 L
.57154 .01618 L
.5594 .01536 L
.54791 .01473 L
.53757 .01427 L
.52636 .01389 L
.51532 .01364 L
.50524 .01351 L
.4936 .01349 L
.48257 .0136 L
.47241 .0138 L
.463 .01407 L
.4527 .01448 L
.44176 .01502 L
.41918 .01653 L
.39811 .01842 L
.37495 .02104 L
.35086 .0244 L
.30667 .03239 L
.26771 .04161 L
.22788 .05352 L
.18723 .06884 L
.15288 .08501 L
.12357 .10195 L
.07798 .13754 L
.05822 .15933 L
.04394 .18037 L
.03804 .19164 L
.0328 .20423 L
.03068 .21062 L
.02877 .21753 L
.02733 .2241 L
.02633 .23007 L
.02562 .23615 L
.02522 .24188 L
.0251 .24793 L
.02516 .25133 L
.0253 .25446 L
.02572 .25971 L
.02644 .26545 L
.02748 .27144 L
Mistroke
.02872 .277 L
.03255 .28977 L
.03722 .30127 L
.05174 .32649 L
.06866 .34743 L
.09144 .36897 L
.11668 .38783 L
.14355 .4042 L
.20515 .4325 L
.24169 .44506 L
.28354 .45657 L
.3272 .46586 L
.35173 .47002 L
.37494 .47331 L
.39676 .47586 L
.41678 .47775 L
.43919 .47937 L
.45156 .48005 L
.46326 .48056 L
.47355 .48089 L
.48461 .48113 L
.49506 .48124 L
.50461 .48125 L
.51578 .48115 L
.52209 .48104 L
.52794 .4809 L
.53865 .48056 L
.55003 .48008 L
.56192 .47943 L
.57471 .47858 L
.59774 .47661 L
.64011 .4715 L
.67961 .46485 L
.71981 .45601 L
.78692 .43559 L
.8214 .42158 L
.85034 .40735 L
.8786 .39055 L
.90559 .37072 L
.92686 .35107 L
.94315 .33196 L
.95557 .31298 L
.96066 .30315 L
.96526 .29228 L
.96902 .28075 L
.97038 .27541 L
.97157 .26969 L
.97248 .26403 L
.97307 .25888 L
.97345 .2537 L
Mistroke
.97361 .24881 L
.97354 .24309 L
.97318 .23705 L
.97263 .23189 L
.97178 .22624 L
.97057 .22018 L
.96893 .21371 L
.9651 .2021 L
.96056 .19148 L
.95454 .18007 L
.94076 .15987 L
.92398 .14101 L
.9056 .12439 L
.88232 .10711 L
.85392 .08986 L
.79474 .0627 L
.7565 .04953 L
.71359 .0378 L
.67517 .02957 L
.63162 .02248 L
.60973 .01974 L
.58572 .01733 L
.56285 .01558 L
.55189 .01494 L
.54161 .01444 L
.53236 .01408 L
.52239 .01379 L
.51132 .01358 L
.5012 .01349 L
.49068 .01351 L
.47922 .01365 L
.4684 .01391 L
.45837 .01425 L
.44666 .01477 L
.43403 .01549 L
.41126 .01719 L
.38928 .01935 L
.36928 .02177 L
.32468 .02884 L
.27939 .03862 L
.24077 .04937 L
.2075 .06075 L
.17404 .07465 L
.14079 .09159 L
.11325 .10883 L
.09077 .12599 L
.07085 .14474 L
.0556 .16276 L
.04239 .18313 L
.03692 .19408 L
Mistroke
.03227 .20574 L
.02915 .21603 L
.02704 .22566 L
.02617 .23121 L
.0256 .23626 L
.02521 .2421 L
.0251 .24761 L
.02523 .25315 L
.02568 .25924 L
.02601 .26231 L
.02646 .26559 L
.0275 .27151 L
.03032 .28293 L
.03384 .29326 L
.03906 .30513 L
.04608 .31786 L
.06237 .3403 L
.08136 .36012 L
.10246 .37772 L
.13139 .39717 L
.16132 .41349 L
.23102 .44166 L
.27162 .45357 L
.31679 .46388 L
.35872 .47108 L
.39791 .47598 L
.41993 .47801 L
.4316 .47888 L
.44402 .47966 L
.45489 .48021 L
.46689 .48069 L
.47783 .48099 L
.48808 .48118 L
.49819 .48126 L
.50922 .48123 L
.51964 .48109 L
.52931 .48087 L
.53887 .48056 L
.54752 .4802 L
.56685 .47912 L
.58761 .47754 L
.60987 .47535 L
.64959 .47007 L
.69074 .46263 L
.72773 .454 L
.76955 .44166 L
.80524 .4285 L
.86953 .39632 L
.8992 .37584 L
.92311 .35488 L
Mistroke
.94028 .33568 L
.95524 .31357 L
.96112 .30215 L
.96621 .28968 L
.96811 .2839 L
.96981 .27778 L
.97112 .27203 L
.97207 .26679 L
.97279 .26153 L
.97327 .25656 L
.97355 .2513 L
.9736 .2456 L
.97343 .24062 L
.97302 .23535 L
.97249 .23085 L
.97172 .22592 L
.97056 .22014 L
.96925 .21487 L
.96548 .20309 L
.96095 .1923 L
.95575 .1822 L
.94106 .16025 L
.92419 .14123 L
.9007 .12046 L
.87492 .10227 L
.82091 .07353 L
.78651 .05962 L
.7527 .04837 L
.71595 .03837 L
.67477 .02949 L
.63451 .02288 L
.59693 .01838 L
.57367 .01634 L
.55203 .01494 L
.54068 .0144 L
.52815 .01395 L
.52183 .01378 L
.51503 .01364 L
.50861 .01355 L
.50273 .0135 L
.49189 .0135 L
.48182 .01361 L
.47077 .01384 L
.45901 .01422 L
.44665 .01477 L
.43502 .01542 L
.41339 .01701 L
.39235 .01902 L
.37287 .02131 L
.32944 .02797 L
Mistroke
.28855 .03641 L
.24668 .04756 L
.20999 .05982 L
.17751 .07308 L
.12359 .10194 L
.09961 .11883 L
.07669 .1388 L
.05699 .16092 L
.04949 .1714 L
.04265 .18265 L
.03762 .19255 L
.03307 .20351 L
.02981 .21357 L
.02754 .22301 L
.02652 .22877 L
.02581 .23423 L
.02538 .23913 L
.02513 .24445 L
.02513 .25025 L
.02543 .2564 L
.02593 .26163 L
.02674 .26739 L
.02788 .27335 L
.02919 .27887 L
.0331 .29129 L
.03761 .30212 L
.0435 .3135 L
.05777 .33465 L
.07403 .35303 L
.09692 .37343 L
.12602 .39388 L
.15711 .41138 L
.18912 .42611 L
.25862 .45005 L
.29862 .46007 L
.3434 .46869 L
.36652 .47219 L
.39202 .47535 L
.4164 .47772 L
.42811 .47863 L
.43914 .47937 L
.44987 .47997 L
.45971 .48042 L
.47067 .48081 L
.47643 .48096 L
.48249 .48109 L
.49392 .48124 L
.50456 .48126 L
.51623 .48115 L
.52275 .48103 L
Mistroke
.52867 .48089 L
.53768 .4806 L
.54609 .48026 L
.56517 .47923 L
.58366 .47788 L
.60338 .47604 L
.6386 .47171 L
.67008 .46663 L
.70567 .45938 L
.74293 .44985 L
.80576 .42829 L
Mfstroke
.92097 .35486 m
.93836 .33575 L
.95144 .31721 L
.96221 .2962 L
.96657 .28421 L
.96946 .2732 L
.97055 .26756 L
.9714 .26156 L
.9719 .25643 L
.97219 .25078 L
.97221 .24471 L
.97209 .2413 L
.97189 .23818 L
.97128 .23214 L
.97041 .2264 L
.96937 .22111 L
.968 .21549 L
.96487 .20542 L
.96005 .19357 L
.95465 .18297 L
.93886 .15951 L
.92012 .13888 L
.89515 .11754 L
.8641 .0967 L
.80219 .06622 L
.76236 .05173 L
.72261 .04017 L
.68209 .03083 L
.66004 .02666 L
.63619 .02282 L
.61509 .01996 L
.59153 .01734 L
.56988 .01546 L
.56012 .01477 L
.54942 .01412 L
.53963 .01363 L
.52916 .01321 L
.51809 .01289 L
.50777 .0127 L
.49746 .01261 L
.48772 .01263 L
.47897 .01272 L
.4695 .01291 L
.45913 .01322 L
.44775 .01368 L
.43589 .0143 L
.42483 .01501 L
.40514 .0166 L
.38416 .01874 L
.33887 .02506 L
Mistroke
.29819 .03288 L
.25545 .04362 L
.2126 .05747 L
.17476 .07293 L
.14227 .08935 L
.09087 .12446 L
.07063 .14343 L
.05244 .16535 L
.04491 .17677 L
.03812 .18922 L
.03331 .20013 L
.03118 .20593 L
.02922 .21212 L
.0277 .21783 L
.02634 .22415 L
.02538 .22991 L
.02473 .23532 L
.02431 .24086 L
.02414 .24594 L
.02421 .25151 L
.02454 .25736 L
.02505 .2623 L
.0258 .26756 L
.02672 .27251 L
.02773 .27698 L
.0309 .2879 L
.03479 .2981 L
.04564 .31889 L
.06173 .34089 L
.08299 .36269 L
.10674 .38176 L
.15778 .41228 L
.19069 .42716 L
.22307 .43924 L
.25925 .45033 L
.29977 .46026 L
.33576 .4672 L
.37671 .4732 L
.39999 .47578 L
.42155 .47766 L
.44541 .47919 L
.45746 .47975 L
.46426 .48 L
.47069 .48019 L
.48241 .48044 L
.49307 .48056 L
.50456 .48056 L
.51104 .4805 L
.51702 .48041 L
.52698 .48018 L
Mistroke
.53793 .47982 L
.54935 .47932 L
.56002 .47873 L
.58271 .4771 L
.6036 .47513 L
.65015 .46904 L
.68997 .4618 L
.73076 .4522 L
.76886 .44087 L
.8026 .42856 L
.85913 .40148 L
.88512 .38516 L
.91016 .36585 L
.93213 .34429 L
.94856 .32309 L
.95501 .31258 L
.96023 .30248 L
.9642 .29319 L
.96762 .28323 L
.96906 .27805 L
.97038 .27233 L
.97136 .26704 L
.97205 .26219 L
.97262 .25647 L
.9728 .25347 L
.97292 .25031 L
.97293 .24498 L
.97268 .23916 L
.97211 .23305 L
.97131 .22743 L
.97014 .22128 L
.96855 .21479 L
.9651 .20395 L
.96017 .19217 L
.94803 .17087 L
.93318 .15165 L
.91169 .13024 L
.88841 .11186 L
.85932 .09331 L
.82447 .07541 L
.78892 .06067 L
.75438 .04893 L
.71725 .03863 L
.68162 .03066 L
.63832 .02316 L
.61503 .02004 L
.59015 .01735 L
.56825 .01553 L
.54771 .01426 L
.53586 .01373 L
Mistroke
.52506 .01336 L
.51908 .0132 L
.51258 .01308 L
.50076 .01295 L
.4898 .01296 L
.47977 .01307 L
.4682 .01332 L
.45721 .01369 L
.44713 .01413 L
.43778 .01463 L
.41668 .01609 L
.39348 .01823 L
.37266 .02064 L
.32691 .02771 L
.28416 .03672 L
.24017 .04882 L
.2015 .06232 L
.16802 .07674 L
.11183 .10911 L
.0871 .12844 L
.06485 .15058 L
.05543 .16216 L
.04657 .17507 L
.03997 .18668 L
.03423 .19921 L
.03021 .2106 L
.02851 .21669 L
.02702 .22328 L
.02598 .22932 L
.02528 .23488 L
.02486 .24019 L
.02466 .24579 L
.02472 .25155 L
.02487 .25479 L
.02509 .25778 L
.02568 .26327 L
.02658 .26907 L
.02761 .27424 L
.02878 .27907 L
.03216 .28999 L
.03691 .30164 L
.04224 .31214 L
.05763 .33512 L
.07435 .35388 L
.09617 .37325 L
.14473 .40509 L
.17852 .4217 L
.21324 .43558 L
.28449 .45671 L
.32744 .46574 L
Mistroke
.36833 .47219 L
.39017 .47486 L
.41439 .47723 L
.42668 .4782 L
.43991 .47907 L
.45128 .47968 L
.46386 .4802 L
.46954 .48038 L
.47566 .48055 L
.48673 .48075 L
.49292 .48081 L
.49942 .48084 L
.51104 .48078 L
.52185 .4806 L
.53188 .48034 L
.54287 .47994 L
.55458 .47938 L
.58095 .47761 L
.60561 .4753 L
.65091 .46934 L
.69284 .46165 L
.73 .45287 L
.76854 .44146 L
.80724 .42716 L
.84065 .4119 L
.86843 .3965 L
.91439 .36265 L
.93472 .3419 L
.94381 .33052 L
.95218 .31812 L
.95835 .30712 L
.96396 .29479 L
.96793 .28343 L
.97067 .27266 L
.97168 .26725 L
.9725 .26145 L
.97301 .25597 L
.97326 .25098 L
.97329 .24511 L
.97318 .2418 L
.97301 .23875 L
.97248 .23314 L
.97164 .22721 L
.97056 .22157 L
.96911 .21551 L
.96572 .20464 L
.96041 .19185 L
.95435 .18033 L
.94103 .16065 L
.92269 .14007 L
Mistroke
.8797 .10557 L
.84905 .08737 L
.81695 .07185 L
.7497 .04743 L
.7085 .03649 L
.66884 .02824 L
.62375 .02122 L
.60056 .01851 L
.57482 .01617 L
.55258 .01469 L
.53995 .01407 L
.52825 .01364 L
.51803 .01338 L
.50674 .01321 L
.49494 .01316 L
.48387 .01325 L
.47369 .01343 L
.46299 .01373 L
.45387 .01408 L
.44391 .01455 L
.42175 .01597 L
.40127 .01773 L
.35533 .02335 L
.31476 .03036 L
.26977 .04069 L
.22953 .05259 L
.16208 .07998 L
.13224 .09623 L
.10312 .11581 L
.08158 .13379 L
.06208 .15422 L
.04728 .17442 L
.03696 .19347 L
.03234 .20491 L
.02911 .21536 L
.02771 .22119 L
.02651 .22751 L
.02568 .2335 L
.02518 .239 L
.02494 .24412 L
.0249 .2489 L
.02508 .25414 L
.02552 .25974 L
.02626 .26561 L
.02722 .27115 L
.02969 .28148 L
.03351 .29294 L
.03875 .30495 L
.05117 .326 L
.06874 .34775 L
Mistroke
.09291 .37037 L
.11921 .38963 L
.14762 .4065 L
.20895 .43393 L
.24708 .44665 L
.28458 .45673 L
.32768 .46582 L
.35069 .46971 L
.37542 .4732 L
.39752 .47575 L
.42206 .47797 L
.4329 .47876 L
.44455 .47947 L
.45551 .48001 L
.46568 .48041 L
.47172 .4806 L
.4784 .48077 L
.48513 .48089 L
.49227 .48098 L
.49854 .48101 L
.50529 .481 L
.51166 .48095 L
.51751 .48087 L
.5285 .48063 L
.53473 .48044 L
.54052 .48023 L
.55211 .47971 L
.56465 .47899 L
.58779 .47725 L
.60945 .47511 L
.64937 .46982 L
.69458 .46154 L
.73457 .4519 L
.77008 .44121 L
.80596 .42795 L
.8637 .39959 L
.89376 .37974 L
.91828 .35933 L
.93669 .33987 L
.95268 .31764 L
.95899 .30626 L
.96454 .29377 L
.96858 .28184 L
.97007 .27613 L
.97123 .27078 L
.97207 .26592 L
.97275 .26072 L
.97325 .25493 L
.97346 .24965 L
.97344 .24415 L
Mistroke
.97313 .23818 L
.97258 .23254 L
.97183 .22734 L
.97078 .22179 L
.96937 .21583 L
.96607 .20511 L
.9609 .19251 L
.955 .18113 L
.93937 .1583 L
.91809 .13545 L
.89481 .11604 L
.87056 .0996 L
.84137 .08328 L
.80648 .06734 L
.7714 .05428 L
.73704 .04378 L
.69996 .03455 L
.66478 .02755 L
.62491 .02145 L
.60253 .0188 L
.58108 .01677 L
.56116 .01531 L
.5426 .01431 L
.53188 .01389 L
.52217 .0136 L
.51094 .01339 L
.50038 .0133 L
.48963 .01333 L
.47786 .01349 L
.47193 .01362 L
.46559 .0138 L
.45417 .01422 L
.4428 .01477 L
.43207 .01541 L
.41208 .01691 L
.38868 .01921 L
.36731 .02183 L
.32003 .02951 L
.28201 .03777 L
.24292 .04851 L
.17815 .07262 L
.14312 .09011 L
.11342 .10855 L
.08795 .12826 L
.06832 .1473 L
.05144 .16836 L
.03923 .18897 L
.03409 .20055 L
.03037 .21132 L
.02869 .21748 L
Mistroke
.0274 .22324 L
.02636 .22928 L
.02592 .23248 L
.02555 .23591 L
.02515 .24163 L
.02501 .24692 L
.02513 .25272 L
.02529 .25565 L
.02555 .25889 L
.02618 .26428 L
.02713 .27007 L
.02955 .28052 L
.0328 .29071 L
.03716 .30134 L
.0473 .31997 L
.06322 .34141 L
.08116 .36 L
.10398 .3789 L
.13256 .39791 L
.16234 .41399 L
.19236 .42743 L
.25763 .44972 L
.29458 .45909 L
.33598 .46734 L
.37635 .47338 L
.39453 .4755 L
.41407 .47739 L
.4262 .47837 L
.43724 .47912 L
.44849 .47977 L
.45886 .48025 L
.47103 .48068 L
.47743 .48085 L
.4842 .48098 L
.49559 .4811 L
.50206 .48112 L
.50809 .48109 L
.51973 .48094 L
.53074 .48068 L
.54061 .48034 L
.55132 .47987 L
.57523 .47839 L
.59716 .47652 L
.63741 .47173 L
.67963 .4647 L
.71809 .45629 L
.75186 .4471 L
.82361 .42046 L
.85546 .40443 L
.88654 .38507 L
Mistroke
.91238 .36482 L
.93287 .34445 L
.94787 .32525 L
.96033 .3037 L
.96521 .29225 L
.9693 .27952 L
.97084 .27307 L
.97155 .26951 L
.97212 .26612 L
.97256 .26298 L
.97295 .25955 L
.97341 .25354 L
.97356 .24795 L
.97353 .24477 L
.97343 .24178 L
.97301 .23577 L
.97264 .2324 L
.97222 .2293 L
.97133 .22411 L
.97011 .21843 L
.96683 .20706 L
.96238 .19558 L
.95631 .1833 L
.94204 .16158 L
.92426 .14134 L
.9046 .12361 L
.84933 .08738 L
.81643 .07153 L
.77682 .05613 L
.7376 .04395 L
.69827 .03421 L
.66153 .02703 L
.62021 .0209 L
.59628 .01822 L
.57437 .0163 L
.56215 .01544 L
.54889 .01468 L
.53633 .01412 L
.52476 .01375 L
.514 .01351 L
.50395 .0134 L
.49292 .01339 L
.48673 .01344 L
.4811 .01351 L
.46976 .01376 L
.46336 .01396 L
.45745 .01417 L
.44657 .01466 L
.43514 .01531 L
.41377 .01687 L
Mistroke
.39433 .0187 L
.3512 .02425 L
.31491 .03061 L
.27657 .03922 L
.23662 .05057 L
.19666 .06487 L
.13315 .09596 L
.10425 .11523 L
.08122 .1344 L
.06023 .15676 L
.05132 .16863 L
.04316 .18166 L
.03723 .1933 L
.03283 .20406 L
.02939 .21499 L
.02804 .22046 L
.02704 .22543 L
.02612 .23132 L
.02574 .23456 L
.02546 .2376 L
.02514 .24304 L
.02507 .24891 L
.02515 .25201 L
.02533 .2554 L
.02561 .25894 L
.02597 .26224 L
.02684 .26814 L
.02808 .27443 L
.03132 .28626 L
.03603 .29867 L
.04768 .32047 L
.06468 .34303 L
.08855 .36654 L
.11315 .38543 L
.14351 .40417 L
.20745 .43334 L
.24595 .44632 L
.28386 .4566 L
.32746 .46585 L
.35046 .46976 L
.37578 .47335 L
.4003 .47615 L
.42311 .47819 L
.44507 .47964 L
.45619 .48019 L
.46246 .48045 L
.46842 .48066 L
.47953 .48095 L
.48967 .48112 L
.5006 .48118 L
Mistroke
.50677 .48116 L
.51249 .48112 L
.52197 .48097 L
.53244 .4807 L
.54335 .4803 L
.55358 .47982 L
.57508 .47847 L
.59496 .4768 L
.61839 .47429 L
.63944 .47151 L
.68159 .46439 L
.72492 .45465 L
.76019 .44461 L
.79631 .43199 L
.85512 .40468 L
.8829 .38764 L
.9059 .37043 L
.92919 .34856 L
.94641 .32743 L
.95349 .31652 L
.96003 .30441 L
.96509 .29267 L
.96867 .28192 L
.97036 .27542 L
.97162 .26928 L
.97262 .26278 L
.97303 .25911 L
.97331 .25574 L
.97357 .25008 L
.9736 .24687 L
.97355 .24387 L
.97322 .23783 L
.97291 .23444 L
.97254 .23136 L
.9717 .22589 L
.97068 .22077 L
.96755 .20916 L
.96343 .19796 L
.95782 .18605 L
.94467 .16505 L
.92932 .14655 L
.90889 .12714 L
.8826 .1073 L
.85128 .08842 L
.8183 .07235 L
.78396 .05867 L
.74405 .04579 L
.70899 .03667 L
.66883 .02835 L
.62375 .02138 L
Mistroke
.59857 .01849 L
.57478 .01637 L
.56329 .01556 L
.55236 .01491 L
.5424 .01442 L
.53178 .014 L
.52025 .01368 L
.50956 .0135 L
.49805 .01343 L
.4915 .01345 L
.48534 .0135 L
.47488 .01368 L
.46372 .01399 L
.45319 .0144 L
.44364 .01487 L
.42031 .01639 L
.39843 .01833 L
.35555 .02364 L
.31036 .03158 L
.27265 .04027 L
.23454 .05129 L
.17203 .07554 L
.14123 .09131 L
.11577 .10707 L
.0915 .12535 L
.06902 .14667 L
.05222 .16738 L
.04545 .17778 L
.04013 .18735 L
.03575 .19671 L
.03185 .20693 L
.03008 .2126 L
.02868 .21783 L
.02758 .22277 L
.0266 .22816 L
.02582 .23402 L
.02534 .23958 L
.02511 .24499 L
.02511 .25001 L
.02535 .2554 L
.02589 .26136 L
.02627 .26434 L
.02676 .26756 L
.02787 .27337 L
.03063 .28399 L
.03455 .29507 L
.04409 .31454 L
.05937 .33668 L
.07739 .35636 L
.10116 .37673 L
Mistroke
.13087 .39686 L
.19582 .42883 L
.23753 .44373 L
.27868 .45534 L
.31648 .46378 L
.3596 .47117 L
.38181 .47413 L
.40596 .47674 L
.42898 .47866 L
.45016 .47994 L
.46166 .48045 L
.47249 .48082 L
.48223 .48104 L
.49276 .48118 L
.50429 .48121 L
.51009 .48118 L
.51645 .4811 L
.5277 .48087 L
.53818 .48054 L
.54876 .4801 L
.55874 .47958 L
.57737 .47834 L
.5973 .47661 L
.61876 .47428 L
.66346 .46776 L
.70922 .45853 L
.74655 .44878 L
.78548 .43609 L
.81975 .42229 L
.85281 .40599 L
.90319 .37267 L
.92591 .35204 L
.94326 .33179 L
.95794 .30861 L
.96408 .2953 L
.96835 .28306 L
.97104 .27237 L
.97214 .26627 L
.9729 .26056 L
.9734 .25453 L
.9736 .24902 L
.9736 .24598 L
.97352 .24266 L
.97314 .23664 L
.97258 .23153 L
.97171 .22589 L
.97052 .22002 L
.96915 .21452 L
.96608 .20477 L
.96188 .19435 L
Mistroke
.9488 .17093 L
.94046 .15949 L
.93002 .14729 L
.88443 .10854 L
.85459 .09023 L
.82317 .07452 L
.75699 .04966 L
.7164 .03845 L
.67713 .02991 L
.63242 .02256 L
.60936 .01967 L
.58367 .01712 L
.56171 .01548 L
.54922 .01477 L
.5376 .01424 L
.52641 .01386 L
.51626 .01363 L
.50453 .01348 L
.49349 .01347 L
.4834 .01356 L
.47276 .01376 L
.46368 .01402 L
.45373 .01441 L
.4316 .01561 L
.41108 .01718 L
.38738 .01953 L
.36519 .0223 L
.32445 .02886 L
.28213 .03792 L
.2384 .05009 L
.17191 .07562 L
.13852 .09287 L
.11056 .1107 L
.0866 .12958 L
.06535 .15076 L
.05592 .16232 L
.04701 .17526 L
.04016 .18732 L
.03497 .19861 L
.0308 .21021 L
.02909 .21625 L
.02756 .2229 L
.02653 .22871 L
.02581 .23416 L
.02532 .23991 L
.02517 .24314 L
.0251 .2461 L
.02517 .25163 L
.02546 .25676 L
.02602 .26238 L
Mistroke
.02691 .26835 L
.02803 .27404 L
.02932 .27937 L
.03237 .28926 L
.03702 .30084 L
.04315 .31288 L
.05716 .33386 L
.07646 .35544 L
.10237 .37764 L
.13049 .39663 L
.16045 .41304 L
.22427 .43938 L
.26377 .45146 L
.3022 .46084 L
.34618 .46913 L
.37073 .47274 L
.3944 .47558 L
.41495 .47757 L
.43757 .47925 L
.44757 .47983 L
.45826 .48034 L
.46836 .48071 L
.47754 .48097 L
.48917 .48117 L
.49988 .48124 L
.51163 .48118 L
.51755 .48111 L
.52405 .48098 L
.53497 .48067 L
.54666 .48022 L
.56769 .47905 L
.58844 .47745 L
.61083 .47522 L
.65089 .46985 L
.68882 .463 L
.72276 .45526 L
.75864 .44515 L
.79516 .43248 L
.85445 .4051 L
.88417 .38681 L
.91134 .36584 L
.93092 .34672 L
.9483 .32472 L
.95525 .31355 L
.96155 .30123 L
.9663 .28943 L
.96964 .27844 L
.97078 .27364 L
.97179 .26846 L
.97264 .26277 L
Mistroke
.9732 .25744 L
.97355 .25145 L
.97361 .24577 L
.97343 .24067 L
.973 .23511 L
.97264 .23194 L
.97215 .22851 L
.97103 .22232 L
.96809 .21082 L
.96327 .19752 L
.95754 .18547 L
.94393 .16401 L
.92529 .14233 L
.90347 .12265 L
.88044 .10585 L
.85251 .08909 L
.8188 .07258 L
.78481 .05899 L
.75127 .04793 L
.71492 .0381 L
.68022 .03052 L
.64114 .02382 L
.6206 .02102 L
.5979 .01846 L
.57918 .01676 L
.55907 .01533 L
.54789 .01471 L
.53772 .01426 L
.52748 .01391 L
.51781 .01367 L
.50716 .01352 L
.49545 .01347 L
.48955 .0135 L
.48323 .01357 L
.47181 .0138 L
.46047 .01415 L
.44972 .0146 L
.42965 .01576 L
.40618 .01763 L
.38465 .01986 L
.3368 .02667 L
.2985 .03414 L
.25881 .04403 L
.19245 .06666 L
.15792 .08241 L
.12514 .10095 L
.09814 .11998 L
.07695 .13854 L
.0585 .15898 L
.04465 .17915 L
Mistroke
.03895 .18974 L
.03397 .20112 L
.0318 .20711 L
.02976 .21375 L
.02824 .21976 L
.02707 .2255 L
.02623 .23079 L
.02558 .23657 L
.02522 .24184 L
.0251 .24672 L
.02521 .25252 L
.02554 .25778 L
.02621 .26383 L
.02712 .26952 L
.02943 .27977 L
.03232 .28912 L
.03634 .29929 L
.04151 .30991 L
.05542 .33159 L
.07161 .35055 L
.09426 .37129 L
.11941 .38963 L
.17212 .41863 L
.20593 .43279 L
.23946 .44436 L
.27525 .4545 L
.31566 .46364 L
.35526 .47055 L
.39252 .47539 L
.41425 .47752 L
.43463 .47907 L
.44618 .47977 L
.45712 .4803 L
.46318 .48054 L
.46976 .48077 L
.48125 .48106 L
.4926 .48121 L
.49906 .48125 L
.5051 .48124 L
.51146 .4812 L
.51727 .48112 L
.52397 .48099 L
.53032 .48083 L
.54153 .48045 L
.5519 .47998 L
.57531 .47852 L
.59865 .47651 L
.6199 .47418 L
.66687 .4672 L
.70687 .4591 L
Mistroke
.74725 .4486 L
.8118 .42577 L
.84467 .41034 L
.8725 .39447 L
.89898 .37601 L
.92356 .35443 L
.94252 .33279 L
.95616 .31192 L
.96515 .29257 L
.96884 .2814 L
.97135 .27085 L
.97232 .26514 L
.97299 .2597 L
.97339 .25481 L
.9736 .24946 L
.97356 .24368 L
.97342 .24045 L
.97322 .23752 L
.97262 .23181 L
.97182 .22645 L
.97077 .22109 L
.96939 .21537 L
.9662 .20509 L
.96127 .193 L
.95571 .18213 L
.94019 .15914 L
.92128 .13835 L
.87867 .10469 L
.84979 .08762 L
.82027 .07324 L
.78835 .06029 L
.75151 .048 L
.7179 .03884 L
.67953 .0304 L
.63542 .023 L
.6108 .01985 L
.58759 .01748 L
.56561 .01576 L
.5455 .01461 L
.53432 .01414 L
.52843 .01395 L
.52218 .01378 L
.5107 .01356 L
.50011 .01348 L
.48932 .01351 L
.47756 .01368 L
.46646 .01396 L
.45618 .01433 L
.43682 .01531 L
.41631 .01676 L
Mistroke
.39231 .01902 L
.36996 .02168 L
.32902 .02804 L
.29128 .03577 L
.2579 .04429 L
.18834 .06837 L
.15742 .08267 L
.12731 .09959 L
.08181 .13391 L
.06016 .15691 L
.05133 .16869 L
.04427 .1798 L
.03891 .18984 L
.034 .20105 L
.03013 .21245 L
.02848 .21873 L
.02722 .22465 L
.02632 .23012 L
.02563 .23596 L
.02524 .24149 L
.0251 .2465 L
.0252 .25241 L
.02539 .25574 L
.02564 .25881 L
.0263 .26443 L
.02728 .27037 L
.02849 .27605 L
.03009 .28212 L
.03375 .293 L
.03938 .30579 L
.04572 .31727 L
.05958 .33692 L
.07846 .35738 L
.12231 .39153 L
.15357 .40956 L
.18615 .42486 L
.25414 .44877 L
.29572 .45942 L
.3356 .46737 L
.38088 .47405 L
.40411 .47659 L
.42983 .47875 L
.45221 .48008 L
.46489 .48061 L
.47662 .48096 L
.48688 .48116 L
.4982 .48125 L
.50389 .48125 L
.51001 .48122 L
.52107 .48106 L
Mistroke
.53172 .48079 L
.54332 .48038 L
.55425 .47986 L
.56438 .47928 L
.58342 .4779 L
.60357 .47602 L
.62714 .47327 L
.65228 .46965 L
.69668 .46137 L
.73808 .45121 L
.77422 .44008 L
.80768 .4275 L
.84089 .41229 L
.89278 .3807 L
.91877 .35909 L
.93903 .33726 L
.95339 .31674 L
.95985 .30484 L
.96474 .29366 L
.9685 .2826 L
.97105 .27238 L
.97204 .267 L
.97284 .2611 L
.97314 .25812 L
.97338 .25493 L
.9736 .24919 L
.97356 .24375 L
.97325 .23786 L
.97268 .23231 L
.97194 .2272 L
.97109 .2226 L
.96995 .21755 L
.967 .2074 L
.96228 .19523 L
.95689 .18426 L
.94106 .16025 L
.92198 .13904 L
.90014 .12002 L
.84703 .08616 L
.81226 .06976 L
.77803 .05659 L
.74387 .04577 L
.70501 .03578 L
.66674 .02801 L
.63048 .02232 L
.60955 .01972 L
.58953 .01767 L
.56627 .01581 L
.55593 .01516 L
.54494 .01459 L
Mistroke
.53535 .01418 L
.52476 .01385 L
.51511 .01364 L
.50606 .01352 L
.49542 .01349 L
.48568 .01356 L
.475 .01374 L
.46377 .01405 L
.45221 .0145 L
.44174 .01503 L
.41835 .0166 L
.39686 .01855 L
.37677 .02081 L
.33255 .02742 L
.2864 .03692 L
.24791 .04719 L
.21384 .05841 L
.17607 .07373 L
.14456 .08948 L
.11679 .10641 L
.09029 .1264 L
.06685 .14908 L
.04922 .17181 L
.04296 .18209 L
.03725 .19335 L
.03318 .20321 L
.02966 .2141 L
.0281 .22039 L
.02693 .22626 L
.02601 .23248 L
.02563 .23597 L
.02538 .23914 L
.02513 .24483 L
.0251 .24804 L
.02515 .25101 L
.02544 .25645 L
.026 .2622 L
.02689 .26822 L
.02796 .27371 L
.03127 .286 L
.03546 .29727 L
.04043 .30785 L
.05491 .3309 L
.07587 .35486 L
.09984 .37571 L
.12615 .39396 L
.18406 .42396 L
.22092 .43824 L
.25719 .44965 L
.29923 .4602 L
Mistroke
.3457 .46907 L
.36744 .47231 L
.3883 .47493 L
.40745 .47692 L
.42794 .47862 L
.43858 .47933 L
.45035 .47999 L
.46121 .48048 L
.47117 .48082 L
.4829 .4811 L
.48906 .48119 L
.49555 .48124 L
.50648 .48124 L
.51268 .48119 L
.51844 .48111 L
.52867 .48089 L
.53975 .48052 L
.5502 .48007 L
.5598 .47956 L
.57793 .47833 L
.59701 .47668 L
.63612 .47206 L
.67804 .46515 L
.72055 .45583 L
.75897 .44506 L
.82483 .42003 L
.85743 .40344 L
.88457 .38654 L
.91044 .36663 L
.93373 .34357 L
.94303 .33212 L
.95154 .31975 L
.95822 .30807 L
.96338 .29703 L
.96728 .28654 L
.97043 .27522 L
.97174 .26873 L
.97226 .26553 L
.97267 .26257 L
.97323 .25704 L
.97356 .25102 L
.97361 .24605 L
.97343 .2407 L
.97305 .23565 L
.97252 .23104 L
.97168 .22566 L
.97048 .21981 L
.96758 .2092 L
.96357 .19825 L
.9582 .18673 L
Mistroke
.94572 .16647 L
.92686 .14395 L
.90555 .12434 L
.87862 .10466 L
.84467 .08494 L
.77837 .05671 L
.73804 .04412 L
.69824 .03427 L
.65675 .02629 L
.6343 .02285 L
.61009 .01978 L
.58876 .0176 L
.56499 .01572 L
.55454 .01508 L
.54323 .01451 L
.53254 .01409 L
.52271 .0138 L
.51307 .0136 L
.50277 .0135 L
.49304 .0135 L
.48419 .01358 L
.4738 .01377 L
.46254 .01409 L
.45192 .01452 L
.44215 .01501 L
.42268 .01627 L
.40139 .0181 L
.35898 .0232 L
.31511 .03068 L
.27501 .03972 L
.20511 .06166 L
.1698 .07662 L
.13985 .09212 L
.11064 .11066 L
.08342 .13244 L
.06158 .15518 L
.04584 .17716 L
.03485 .19891 L
.03085 .21006 L
.02906 .21638 L
.02767 .22239 L
.02667 .2278 L
.02587 .23368 L
.02538 .23904 L
.02515 .24399 L
.02511 .24934 L
.02535 .25523 L
.02558 .25819 L
.0259 .26138 L
.0267 .26713 L
Mistroke
.02763 .27218 L
.02889 .27768 L
.03217 .28869 L
.03612 .29879 L
.04055 .30808 L
.05443 .33025 L
.0742 .3532 L
.09716 .37362 L
.12175 .39117 L
.17661 .42069 L
.20789 .43354 L
.24468 .44598 L
.28544 .45703 L
.32596 .46563 L
.36357 .47178 L
.40557 .47674 L
.42754 .47859 L
.44027 .47944 L
.452 .48008 L
.46433 .4806 L
.47082 .48081 L
.47767 .48099 L
.48921 .48119 L
.49576 .48125 L
.50186 .48126 L
.51353 .48118 L
.52456 .48099 L
.53445 .48071 L
.54517 .4803 L
.55682 .47973 L
.56913 .47897 L
.5911 .47724 L
.61311 .47498 L
.63382 .47238 L
.67196 .46629 L
.71168 .45798 L
.75309 .44687 L
.78711 .43552 L
.82103 .42175 L
.87498 .3929 L
.90275 .37304 L
.92457 .35342 L
.94415 .33061 L
.95228 .31856 L
.95958 .30538 L
.96476 .2936 L
.96845 .28275 L
.96988 .27748 L
.97117 .27174 L
.97214 .26631 L
Mistroke
.97282 .26127 L
.97335 .25544 L
.97359 .24996 L
.97357 .24394 L
.97343 .24057 L
.97321 .23747 L
.97259 .2316 L
.97212 .22828 L
.97159 .22519 L
.97028 .21894 L
.96854 .21235 L
.96443 .20036 L
.95957 .18944 L
.94493 .16538 L
.9283 .14545 L
.90597 .12469 L
.88273 .10739 L
.85448 .09018 L
.79576 .06309 L
.75739 .0498 L
.7196 .03927 L
.67608 .02974 L
.65311 .0257 L
.62787 .02197 L
.60331 .01904 L
.58051 .01688 L
.55853 .01531 L
.54741 .01471 L
.5352 .01418 L
.52407 .01383 L
.51391 .01362 L
.50219 .0135 L
.49109 .01351 L
.48084 .01363 L
.47138 .01383 L
.461 .01415 L
.45001 .01461 L
.42881 .01583 L
.40666 .0176 L
.3676 .022 L
.32657 .02849 L
.28332 .03766 L
.2474 .04735 L
.21111 .05941 L
.15211 .08541 L
.12087 .1037 L
.09556 .12204 L
.0719 .14364 L
.05189 .16788 L
.04509 .1784 L
Mistroke
.03888 .18988 L
.03443 .19994 L
.03056 .211 L
.02871 .21778 L
.02733 .22407 L
.02632 .23011 L
.02593 .23316 L
.02558 .23654 L
.0252 .24235 L
.02511 .24562 L
.0251 .24862 L
.02529 .25414 L
.02575 .25995 L
.02647 .26566 L
.02756 .27184 L
.03035 .283 L
.03404 .29377 L
.03831 .30361 L
.05101 .32545 L
.06888 .34766 L
.08774 .36583 L
.10817 .38191 L
.16378 .41469 L
.19695 .42931 L
.2361 .4433 L
.27285 .45389 L
.31396 .46331 L
.35628 .47072 L
.39571 .47575 L
.41504 .4776 L
.43609 .47918 L
.4458 .47976 L
.45608 .48027 L
.46566 .48064 L
.47453 .48091 L
.48543 .48114 L
.49119 .48121 L
.4973 .48125 L
.50755 .48124 L
.51886 .48111 L
.52888 .48088 L
.53967 .48053 L
.54983 .48009 L
.55913 .4796 L
.58005 .47817 L
.60276 .47611 L
.64775 .47036 L
.68631 .46353 L
.72598 .45445 L
.79248 .43352 L
Mistroke
.80576 .42829 L
Mfstroke
.92067 .3554 m
.93816 .33633 L
.95134 .31781 L
.96222 .2968 L
.96663 .2848 L
.96958 .27377 L
.97069 .26812 L
.97158 .26211 L
.9721 .25697 L
.97241 .25131 L
.97246 .24522 L
.97235 .2418 L
.97216 .23868 L
.97157 .23261 L
.97073 .22686 L
.96971 .22155 L
.96836 .21591 L
.96527 .20581 L
.96048 .19391 L
.95511 .18326 L
.93937 .15969 L
.92065 .13896 L
.89569 .1175 L
.86462 .09654 L
.80261 .06589 L
.76271 .05132 L
.72287 .03971 L
.68225 .03033 L
.66016 .02616 L
.63625 .02231 L
.61511 .01945 L
.59149 .01685 L
.5698 .01497 L
.56002 .01429 L
.54929 .01365 L
.53949 .01316 L
.529 .01276 L
.5179 .01244 L
.50757 .01226 L
.49723 .01219 L
.48747 .01221 L
.47871 .01232 L
.46923 .01252 L
.45884 .01284 L
.44744 .01332 L
.42449 .01469 L
.40337 .01643 L
.38377 .01848 L
.34079 .0245 L
.29547 .03331 L
Mistroke
.25456 .04376 L
.21862 .05525 L
.15709 .08148 L
.12693 .09853 L
.10255 .1153 L
.07967 .13463 L
.05957 .15627 L
.04586 .17557 L
.03462 .1974 L
.03007 .20994 L
.02707 .22147 L
.02588 .22787 L
.02536 .23149 L
.02497 .23484 L
.0245 .241 L
.02437 .2441 L
.02433 .24752 L
.02449 .25362 L
.0249 .2592 L
.02565 .26531 L
.02614 .26838 L
.02676 .27172 L
.02966 .28337 L
.03336 .29409 L
.03867 .306 L
.04461 .31679 L
.06164 .34042 L
.08066 .36021 L
.10462 .37987 L
.15476 .4104 L
.18757 .4255 L
.22071 .43805 L
.25821 .44966 L
.30135 .46022 L
.34391 .46817 L
.36473 .47127 L
.38454 .47377 L
.40388 .4758 L
.42177 .47733 L
.44176 .47865 L
.45231 .47919 L
.46344 .47964 L
.47357 .47995 L
.48442 .48016 L
.49466 .48026 L
.50398 .48026 L
.51494 .48015 L
.52111 .48004 L
.52681 .47991 L
.53727 .47957 L
Mistroke
.54832 .47911 L
.57059 .4778 L
.59161 .4761 L
.63055 .47172 L
.67148 .46527 L
.71457 .4562 L
.7504 .44662 L
.78657 .4347 L
.84542 .40903 L
.8767 .39091 L
.90204 .37275 L
.92577 .35133 L
.94586 .3273 L
.95272 .31683 L
.95899 .30543 L
.96349 .29542 L
.96742 .28443 L
.96932 .27768 L
.97073 .27142 L
.97178 .26541 L
.97219 .26237 L
.97256 .25901 L
.97298 .25322 L
.97309 .24997 L
.97312 .24698 L
.97298 .24148 L
.97256 .23569 L
.97187 .22997 L
.97082 .22379 L
.96954 .21797 L
.96812 .21262 L
.96028 .19199 L
.95482 .18147 L
.94772 .17009 L
.92999 .14781 L
.91096 .12931 L
.88702 .1106 L
.83539 .08032 L
.80022 .06474 L
.765 .05201 L
.72026 .0391 L
.67753 .02957 L
.63506 .02242 L
.59404 .01747 L
.57113 .01549 L
.54994 .01414 L
.5388 .01362 L
.52657 .01318 L
.52039 .01302 L
.51377 .01288 L
Mistroke
.50752 .01279 L
.50184 .01275 L
.49121 .01275 L
.48126 .01285 L
.47034 .01308 L
.45862 .01345 L
.44639 .01399 L
.43479 .01464 L
.41312 .01622 L
.3931 .01813 L
.37467 .02027 L
.33362 .02643 L
.28999 .03529 L
.25213 .04519 L
.21312 .05796 L
.17488 .0736 L
.14456 .08885 L
.11464 .10727 L
.09052 .12563 L
.07156 .14342 L
.05312 .16552 L
.04537 .17726 L
.03832 .19027 L
.0331 .20247 L
.02939 .21388 L
.02796 .21954 L
.02685 .22487 L
.02595 .23044 L
.02525 .2366 L
.02489 .24208 L
.02478 .24793 L
.02493 .25345 L
.02528 .25847 L
.02596 .26435 L
.02647 .26767 L
.02702 .27072 L
.02979 .28222 L
.03347 .29315 L
.03867 .30503 L
.05278 .32844 L
.06876 .34787 L
.08965 .36769 L
.13642 .40021 L
.16879 .41706 L
.20168 .43105 L
.24396 .44554 L
.2848 .45658 L
.32571 .46522 L
.36556 .47163 L
.38644 .47426 L
Mistroke
.40872 .47655 L
.42045 .47755 L
.43338 .47849 L
.44522 .4792 L
.45619 .47974 L
.46704 .48015 L
.47857 .48046 L
.49015 .48064 L
.49675 .48069 L
.50293 .48069 L
.51406 .4806 L
.52425 .48042 L
.53542 .4801 L
.54715 .47963 L
.56756 .47849 L
.58642 .47705 L
.60697 .47507 L
.62868 .47248 L
.67642 .46488 L
.71971 .45548 L
.75678 .44522 L
.79463 .43221 L
.85655 .40351 L
.88675 .38463 L
.91132 .36549 L
.9331 .34392 L
.94906 .3232 L
.95621 .3114 L
.96261 .29832 L
.96731 .28579 L
.969 .28009 L
.97048 .27407 L
.97154 .26875 L
.97242 .26293 L
.97299 .25762 L
.9733 .25266 L
.97342 .2468 L
.97327 .24147 L
.9731 .23852 L
.97282 .23533 L
.97211 .22952 L
.97126 .22451 L
.97009 .219 L
.96697 .20792 L
.96316 .19775 L
.95881 .18832 L
.94486 .16556 L
.92824 .14557 L
.90467 .12373 L
.87818 .10441 L
Mistroke
.8199 .07299 L
.78265 .05807 L
.7464 .04629 L
.71062 .03684 L
.67024 .02835 L
.63081 .02203 L
.59366 .01769 L
.57201 .01583 L
.55213 .01455 L
.5411 .01401 L
.53527 .01378 L
.52907 .01356 L
.5177 .01327 L
.50717 .01311 L
.49757 .01306 L
.48723 .01311 L
.47747 .01326 L
.46852 .01347 L
.45862 .0138 L
.44781 .01428 L
.4261 .01558 L
.40219 .01759 L
.38067 .01991 L
.33334 .02686 L
.29101 .03544 L
.25277 .04539 L
.18225 .07066 L
.15057 .08593 L
.11922 .10452 L
.09564 .12173 L
.07379 .14146 L
.05667 .16109 L
.04415 .17974 L
.03831 .19078 L
.03376 .20131 L
.03165 .20719 L
.02968 .21357 L
.02831 .2189 L
.02708 .22475 L
.02617 .23033 L
.02555 .23554 L
.02514 .24105 L
.02498 .24694 L
.02508 .25243 L
.02541 .25762 L
.02589 .26227 L
.02661 .26731 L
.02773 .27325 L
.02905 .2788 L
.033 .29134 L
Mistroke
.0381 .30342 L
.04496 .31621 L
.06087 .33864 L
.07925 .35821 L
.10108 .3767 L
.12794 .39506 L
.18468 .42414 L
.22406 .43918 L
.26392 .45133 L
.30133 .46045 L
.34413 .46856 L
.36482 .47169 L
.38731 .47454 L
.40696 .47659 L
.42853 .47837 L
.44123 .4792 L
.45302 .47982 L
.46431 .48029 L
.4701 .48048 L
.47634 .48065 L
.48708 .48085 L
.49717 .48094 L
.50302 .48094 L
.50918 .48091 L
.52019 .48076 L
.53048 .48052 L
.53983 .4802 L
.5506 .47973 L
.56076 .47918 L
.57876 .47795 L
.59816 .47625 L
.64155 .47098 L
.68053 .46438 L
.71848 .45606 L
.75744 .44528 L
.82192 .42114 L
.85678 .40362 L
.88629 .38519 L
.91157 .36549 L
.93101 .34648 L
.94775 .3254 L
.95979 .30478 L
.96484 .2932 L
.96847 .28243 L
.97011 .27627 L
.97134 .27051 L
.97234 .26448 L
.97275 .26129 L
.9731 .25786 L
.97345 .25214 L
Mistroke
.97355 .24684 L
.97338 .24104 L
.97319 .23811 L
.97291 .23488 L
.97223 .22949 L
.97124 .22369 L
.96874 .21326 L
.9654 .20307 L
.96095 .19245 L
.95066 .17384 L
.93453 .15238 L
.9164 .13378 L
.89337 .11488 L
.86458 .09589 L
.83458 .07982 L
.8044 .0664 L
.73882 .04419 L
.70164 .03485 L
.66004 .02666 L
.6195 .02069 L
.60125 .0186 L
.58166 .01676 L
.56947 .01581 L
.55839 .01508 L
.5471 .01446 L
.53671 .01401 L
.5245 .01361 L
.51807 .01346 L
.5113 .01335 L
.49988 .01326 L
.4934 .01326 L
.48737 .01331 L
.47569 .01349 L
.46466 .01379 L
.45478 .01416 L
.44406 .01467 L
.42014 .01623 L
.39822 .01818 L
.35788 .02314 L
.31565 .03036 L
.27722 .03897 L
.24354 .04833 L
.20632 .06104 L
.16871 .077 L
.10969 .11123 L
.08413 .13171 L
.06397 .15227 L
.0493 .17161 L
.03724 .19327 L
.03257 .20478 L
Mistroke
.02872 .21756 L
.0273 .22403 L
.02667 .2276 L
.02616 .23099 L
.02578 .23415 L
.02545 .23758 L
.02512 .24359 L
.02507 .24919 L
.02516 .25237 L
.02532 .25536 L
.02587 .26137 L
.0263 .26475 L
.02678 .26784 L
.02911 .27869 L
.03065 .28412 L
.03261 .29003 L
.03729 .30151 L
.04362 .31376 L
.05834 .3354 L
.07654 .35553 L
.09656 .37313 L
.15258 .40899 L
.18579 .42463 L
.22566 .43977 L
.26517 .45174 L
.30471 .46126 L
.34159 .46824 L
.383 .47415 L
.407 .47671 L
.42893 .47853 L
.44117 .47933 L
.45444 .48002 L
.46055 .48028 L
.467 .48052 L
.47856 .48084 L
.48924 .48102 L
.50069 .48109 L
.5115 .48104 L
.52133 .48089 L
.53287 .48059 L
.53937 .48037 L
.54538 .48013 L
.56803 .47888 L
.5894 .47722 L
.60882 .4753 L
.65184 .46957 L
.68872 .4629 L
.72615 .45427 L
.79974 .4306 L
.83706 .41412 L
Mistroke
.86839 .39694 L
.89556 .37857 L
.92081 .35709 L
.94038 .33551 L
.95455 .31473 L
.96404 .29537 L
.968 .28419 L
.97076 .27366 L
.97186 .26793 L
.97266 .26249 L
.97317 .25759 L
.9735 .25226 L
.9736 .24647 L
.97354 .24354 L
.97339 .24031 L
.97293 .23461 L
.97225 .22927 L
.97132 .22384 L
.97005 .21806 L
.96708 .20769 L
.96238 .1955 L
.95703 .18455 L
.94191 .16135 L
.92338 .1404 L
.88126 .10637 L
.85264 .08912 L
.82342 .07459 L
.79147 .06138 L
.75464 .04887 L
.72101 .03952 L
.68268 .03091 L
.65875 .02652 L
.63614 .023 L
.61238 .01992 L
.59059 .01764 L
.56895 .01587 L
.54844 .01463 L
.53712 .01413 L
.52669 .01378 L
.51523 .01351 L
.50945 .01343 L
.50311 .01338 L
.49145 .01338 L
.48066 .0135 L
.47504 .01361 L
.46884 .01377 L
.45629 .01421 L
.44532 .01471 L
.43353 .0154 L
.4123 .01698 L
Mistroke
.39157 .01899 L
.36998 .02157 L
.33207 .0274 L
.28941 .03611 L
.25146 .04606 L
.2124 .05886 L
.17321 .07497 L
.13894 .09259 L
.1108 .11051 L
.08768 .12862 L
.06616 .14982 L
.05055 .16981 L
.03923 .18917 L
.03437 .20007 L
.03082 .21013 L
.02922 .21572 L
.02778 .22184 L
.02669 .22763 L
.02594 .23301 L
.02538 .23902 L
.02521 .24205 L
.02511 .24537 L
.02515 .25124 L
.02545 .25672 L
.02575 .26004 L
.02612 .26318 L
.02703 .26905 L
.02832 .27534 L
.03009 .28216 L
.03399 .29363 L
.03931 .30566 L
.0519 .32673 L
.06747 .3461 L
.08505 .36345 L
.13519 .39939 L
.16551 .41548 L
.20191 .4312 L
.23655 .44338 L
.27576 .45456 L
.3165 .46374 L
.35483 .47041 L
.37373 .47307 L
.39441 .47552 L
.4142 .47744 L
.43239 .47884 L
.45339 .48005 L
.46499 .48053 L
.47601 .48086 L
.48618 .48106 L
.49561 .48115 L
Mistroke
.50595 .48116 L
.51694 .48105 L
.5279 .48082 L
.53407 .48064 L
.53971 .48044 L
.56103 .4794 L
.57229 .47867 L
.58456 .47772 L
.60913 .47535 L
.65445 .46923 L
.70127 .4603 L
.74346 .44964 L
.77975 .43812 L
.81383 .42487 L
.84707 .40906 L
.8983 .37652 L
.92157 .35639 L
.93968 .33644 L
.95526 .31354 L
.96196 .30031 L
.96678 .28805 L
.96864 .28212 L
.97012 .27652 L
.97124 .27142 L
.97219 .26602 L
.97295 .2601 L
.9734 .25466 L
.97361 .2488 L
.9736 .24547 L
.97352 .24237 L
.97316 .23685 L
.9726 .23163 L
.9719 .22696 L
.97094 .22189 L
.96802 .21058 L
.96437 .20022 L
.9538 .17881 L
.94605 .16693 L
.93768 .15603 L
.91783 .13505 L
.8916 .11357 L
.83478 .07994 L
.79881 .06422 L
.76265 .05141 L
.72725 .04116 L
.69232 .03293 L
.65053 .02522 L
.61147 .01987 L
.59053 .01769 L
.5708 .01606 L
Mistroke
.54901 .01472 L
.53674 .01417 L
.52551 .0138 L
.51379 .01355 L
.50292 .01344 L
.49725 .01342 L
.49099 .01344 L
.48445 .01351 L
.47831 .01361 L
.46709 .01388 L
.45681 .01424 L
.44554 .01476 L
.43369 .01545 L
.41423 .01688 L
.39357 .01883 L
.35684 .02346 L
.31432 .03079 L
.27701 .03917 L
.23953 .04972 L
.20211 .06278 L
.14208 .09084 L
.11329 .10879 L
.08961 .12697 L
.0676 .14825 L
.05786 .1598 L
.04882 .17244 L
.04159 .18461 L
.03615 .19583 L
.03176 .20724 L
.02863 .2181 L
.02729 .2243 L
.02669 .2277 L
.02622 .23087 L
.02559 .2365 L
.02536 .23948 L
.02519 .24267 L
.02511 .24611 L
.02513 .24984 L
.02525 .25336 L
.02545 .25662 L
.02571 .25954 L
.02608 .26277 L
.02708 .26929 L
.02828 .27514 L
.02985 .28128 L
.03344 .29217 L
.0384 .30377 L
.04512 .31625 L
.06048 .33801 L
.07845 .35735 L
Mistroke
.10157 .37702 L
.13076 .39677 L
.15978 .41269 L
.19354 .42789 L
.22638 .44007 L
.26481 .45172 L
.29879 .46006 L
.33725 .46761 L
.36019 .47124 L
.38178 .47412 L
.40439 .47658 L
.42506 .47836 L
.4349 .47905 L
.44556 .47969 L
.4548 .48016 L
.46494 .48057 L
.47576 .4809 L
.48719 .48112 L
.49778 .48121 L
.50766 .48119 L
.51927 .48105 L
.52582 .48091 L
.53187 .48075 L
.54296 .48035 L
.5547 .4798 L
.57495 .47852 L
.59712 .47663 L
.62049 .47407 L
.64533 .47069 L
.68916 .46292 L
.72925 .45357 L
.76475 .44321 L
.80438 .42884 L
.83754 .41395 L
.8958 .37845 L
.92154 .35643 L
.94135 .33432 L
.95498 .31403 L
.9611 .30221 L
.96574 .29101 L
.96781 .2849 L
.96948 .27908 L
.97076 .27377 L
.97186 .26811 L
.97232 .26519 L
.97275 .26196 L
.9733 .25625 L
.97349 .25305 L
.9736 .24958 L
.97362 .24632 L
Mistroke
.97356 .24332 L
.97329 .23832 L
.97277 .23299 L
.97207 .22796 L
.97126 .2234 L
.96853 .21228 L
.96502 .20186 L
.95534 .18146 L
.94834 .17021 L
.94091 .16004 L
.92361 .14062 L
.90126 .12087 L
.85177 .08867 L
.81644 .07153 L
.77972 .05715 L
.74093 .0449 L
.70384 .03548 L
.66305 .02733 L
.62339 .02135 L
.60117 .01877 L
.58054 .01685 L
.55771 .01523 L
.54616 .01461 L
.53346 .01408 L
.52246 .01376 L
.51203 .01356 L
.50266 .01347 L
.49247 .01347 L
.48139 .01359 L
.46965 .01384 L
.45963 .01417 L
.4486 .01464 L
.42905 .01578 L
.40811 .01744 L
.3707 .02156 L
.32848 .02812 L
.2905 .03594 L
.25058 .04639 L
.2104 .05966 L
.17133 .0759 L
.13792 .09323 L
.11129 .1102 L
.08574 .13035 L
.06522 .15092 L
.0497 .1711 L
.03732 .1932 L
.03223 .20588 L
.03041 .21153 L
.02876 .21757 L
.02749 .22328 L
Mistroke
.02658 .22846 L
.02588 .23367 L
.02542 .23858 L
.02514 .24434 L
.02513 .24963 L
.02537 .25543 L
.02593 .26154 L
.02661 .26651 L
.02757 .27182 L
.02987 .28134 L
.03359 .29258 L
.03789 .30269 L
.05007 .32405 L
.0672 .34582 L
.08513 .36352 L
.1082 .38192 L
.13658 .40023 L
.17096 .41808 L
.24189 .4451 L
.28258 .45631 L
.3222 .4649 L
.36731 .47227 L
.39312 .47544 L
.41681 .47773 L
.4279 .47859 L
.43965 .47938 L
.44984 .47994 L
.46079 .48044 L
.46696 .48066 L
.47259 .48084 L
.48363 .48109 L
.4898 .48117 L
.49652 .48123 L
.50287 .48124 L
.50874 .48121 L
.51908 .48108 L
.52878 .48086 L
.5394 .48052 L
.55084 .48002 L
.57404 .47861 L
.59517 .47684 L
.63626 .47203 L
.67902 .46495 L
.71796 .45646 L
.75187 .44723 L
.78965 .43458 L
.82759 .41875 L
.85994 .40201 L
.88706 .38481 L
.91124 .36594 L
Mistroke
.93012 .3476 L
.94729 .32622 L
.95505 .31391 L
.96107 .30228 L
.96577 .29093 L
.96958 .27871 L
.97119 .27168 L
.97184 .26822 L
.97234 .26504 L
.97306 .25907 L
.97332 .25593 L
.97351 .25261 L
.97362 .24692 L
.97345 .24084 L
.973 .2351 L
.97237 .22989 L
.97133 .22378 L
.96986 .21717 L
.96626 .20523 L
.96201 .19462 L
.95639 .18334 L
.9435 .16344 L
.92376 .14078 L
.90168 .12122 L
.84508 .08513 L
.81161 .06947 L
.77174 .05442 L
.73144 .04231 L
.69138 .03278 L
.65399 .02582 L
.61233 .02002 L
.59028 .01772 L
.56582 .01576 L
.55343 .015 L
.5401 .01436 L
.53363 .01411 L
.52748 .01391 L
.51595 .01364 L
.50515 .0135 L
.49365 .01348 L
.48384 .01357 L
.473 .01377 L
.46142 .01412 L
.44895 .01464 L
.42646 .01598 L
.40542 .0177 L
.38312 .02004 L
.3436 .02554 L
.29808 .03423 L
.25845 .04414 L
Mistroke
.21929 .05646 L
.1798 .07206 L
.14603 .08867 L
.1176 .10586 L
.09268 .1244 L
.07303 .14247 L
.05497 .16361 L
.04668 .1758 L
.04016 .18735 L
.03459 .19956 L
.03063 .21077 L
.02896 .2168 L
.02748 .22334 L
.02682 .22694 L
.02631 .23027 L
.0259 .23342 L
.02556 .23681 L
.0252 .24252 L
.0251 .24786 L
.02516 .25112 L
.02529 .2542 L
.02576 .25998 L
.02654 .26606 L
.02753 .27166 L
.02892 .27779 L
.03074 .28427 L
.03459 .29513 L
.0397 .30642 L
.05151 .32616 L
.06793 .34661 L
.09008 .36782 L
.11267 .38509 L
.14002 .40221 L
.19679 .42923 L
.23525 .44302 L
.27302 .45392 L
.31663 .46383 L
.33961 .46805 L
.36475 .47193 L
.38712 .47478 L
.40778 .47694 L
.42872 .47867 L
.44873 .4799 L
.46002 .48042 L
.46622 .48065 L
.47205 .48083 L
.48343 .4811 L
.49373 .48122 L
.49973 .48125 L
.50605 .48124 L
Mistroke
.51736 .48112 L
.52366 .481 L
.52953 .48085 L
.54284 .48039 L
.5541 .47987 L
.56602 .47917 L
.58731 .47756 L
.61003 .47532 L
.63477 .47224 L
.67806 .46515 L
.7172 .45665 L
.78534 .43617 L
.82025 .4221 L
.84969 .4077 L
.87736 .39137 L
.90346 .37247 L
.92297 .35503 L
.9407 .33516 L
.94976 .32254 L
.95685 .31068 L
.96238 .29938 L
.96719 .28681 L
.96887 .28132 L
.97039 .27541 L
.97146 .27029 L
.97239 .2647 L
.97281 .26142 L
.97312 .25838 L
.97352 .25239 L
.97362 .24694 L
.97346 .24115 L
.97308 .23588 L
.9724 .23011 L
.97139 .22411 L
.97019 .21854 L
.9674 .2086 L
.96351 .19808 L
.95116 .17452 L
.93588 .15389 L
.91819 .1354 L
.8955 .11646 L
.84574 .08549 L
.81414 .07055 L
.78217 .05804 L
.74149 .04508 L
.70213 .03512 L
.65912 .02668 L
.61689 .02057 L
.59334 .01802 L
.57128 .01616 L
Mistroke
.55874 .01532 L
.54689 .01467 L
.54032 .01438 L
.5332 .0141 L
.52682 .0139 L
.52078 .01374 L
.50967 .01355 L
.49955 .01348 L
.48865 .01352 L
.48249 .01359 L
.47681 .01369 L
.46736 .01393 L
.45694 .0143 L
.44609 .01479 L
.43593 .01536 L
.41277 .01706 L
.39173 .01908 L
.34513 .0253 L
.30421 .03291 L
.26133 .04334 L
.21909 .05654 L
.18255 .07085 L
.14994 .08656 L
.11824 .10544 L
.09371 .12355 L
.07152 .14404 L
.05503 .16351 L
.0477 .17417 L
.04095 .18581 L
.03579 .19667 L
.03195 .20669 L
.02894 .21685 L
.02777 .2219 L
.02688 .22655 L
.02603 .23236 L
.02569 .23542 L
.02541 .23865 L
.02515 .24408 L
.02513 .25004 L
.02536 .25535 L
.02587 .26104 L
.02659 .26639 L
.02745 .27125 L
.03031 .28287 L
.03468 .29536 L
.04 .307 L
.04592 .31759 L
.05882 .33597 L
.07641 .35539 L
.12214 .39141 L
Mistroke
.15248 .40899 L
.18441 .42411 L
.25139 .44797 L
.29211 .45859 L
.33164 .46666 L
.37652 .47351 L
.40215 .4764 L
.42564 .47845 L
.4462 .47977 L
.45792 .48034 L
.46888 .48075 L
.48047 .48105 L
.49105 .48121 L
.4969 .48125 L
.50326 .48125 L
.51484 .48116 L
.52469 .48098 L
.53555 .48067 L
.54688 .48022 L
.55749 .47969 L
.57636 .47845 L
.59657 .47672 L
.64238 .47116 L
.66493 .46754 L
.68914 .46296 L
.76743 .44235 L
.8054 .42844 L
.8385 .41349 L
.89211 .38119 L
.91683 .36091 L
.93592 .34102 L
.95255 .31813 L
.95916 .30624 L
.96501 .29295 L
.96881 .28152 L
.97047 .27502 L
.9717 .26897 L
.9726 .26313 L
.97317 .25784 L
.97354 .25173 L
.97361 .24597 L
.97344 .24071 L
.97301 .23516 L
.97244 .23043 L
.9716 .22525 L
.97046 .21969 L
.96895 .21375 L
.96549 .20312 L
.96031 .19095 L
.95328 .17795 L
Mistroke
.93685 .15504 L
.91648 .13383 L
.89405 .11538 L
.86913 .09866 L
.83911 .08211 L
.77739 .05636 L
.73787 .04407 L
.69388 .03332 L
.65471 .02595 L
.61058 .01983 L
.58834 .01756 L
.57656 .01656 L
.56405 .01566 L
.55307 .015 L
.54096 .01441 L
.52993 .014 L
.51961 .01372 L
.50881 .01355 L
.49857 .01349 L
.48937 .01352 L
.47936 .01365 L
.4685 .0139 L
.45697 .0143 L
.44714 .01474 L
.43631 .01534 L
.41237 .01709 L
.3906 .01921 L
.34239 .02575 L
.30125 .03355 L
.25969 .0438 L
.18979 .06777 L
.15482 .084 L
.12605 .10038 L
.10206 .11696 L
.07938 .1362 L
.06258 .15398 L
.04785 .17393 L
.04125 .18523 L
.03619 .19573 L
.032 .20652 L
.029 .21663 L
.02768 .22233 L
.02658 .22843 L
.02608 .23191 L
.02571 .2352 L
.02545 .23816 L
.02525 .24136 L
.0251 .24733 L
.02514 .25034 L
.02526 .25364 L
Mistroke
.0257 .25947 L
.02636 .26491 L
.02739 .27096 L
.02885 .27751 L
.03241 .28935 L
.03699 .30075 L
.04219 .31115 L
.05737 .33413 L
.07844 .35736 L
.10079 .37644 L
.12431 .3928 L
.15264 .40908 L
.18688 .42517 L
.25139 .44798 L
.28956 .458 L
.32658 .46575 L
.36942 .47258 L
.3941 .47557 L
.4171 .47777 L
.4374 .47926 L
.44912 .47993 L
.45985 .48042 L
.47119 .48082 L
.47745 .48098 L
.48339 .4811 L
.49393 .48123 L
.50543 .48125 L
.51672 .48114 L
.52733 .48092 L
.53685 .48063 L
.54711 .48022 L
.5701 .4789 L
.59109 .47724 L
.62896 .47304 L
.668 .467 L
.70899 .45861 L
.74477 .44933 L
.78133 .43761 L
.81837 .42293 L
.84983 .40763 L
.87622 .39211 L
.91983 .35808 L
.9378 .33877 L
.95321 .31704 L
.95916 .30623 L
.96388 .29582 L
.96763 .28546 L
.97025 .27598 L
.9715 .27009 L
.97241 .26453 L
Mistroke
.9731 .25865 L
.97336 .25533 L
.97352 .25227 L
.97362 .24715 L
.97348 .24154 L
.97306 .23568 L
.97241 .23021 L
.97132 .22376 L
.96997 .21766 L
.96663 .2063 L
.96183 .19421 L
.95521 .18125 L
.94102 .1602 L
.92423 .14126 L
.90211 .12157 L
.87421 .10182 L
.8427 .08392 L
.80578 .06706 L
.76812 .05323 L
.73163 .04237 L
.69503 .03357 L
.65375 .0258 L
.6305 .02233 L
.60875 .01963 L
.5864 .01738 L
.5653 .01574 L
.54716 .01469 L
.53694 .01425 L
.52758 .01393 L
.51736 .01368 L
.5062 .01352 L
.49566 .01349 L
.48588 .01356 L
.47484 .01374 L
.46447 .01403 L
.45517 .01437 L
.44513 .01485 L
.42266 .01627 L
.40215 .01802 L
.36131 .02287 L
.31872 .02997 L
.27995 .03848 L
.24611 .04773 L
.20851 .06038 L
.17065 .07622 L
.13838 .09297 L
.11128 .11021 L
.08728 .129 L
.06848 .14728 L
.05139 .16859 L
Mistroke
.04365 .18088 L
.03764 .1925 L
.03283 .20415 L
.02946 .21484 L
.02797 .22098 L
.02684 .2268 L
.02595 .23295 L
.02559 .23642 L
.02535 .23962 L
.02511 .24562 L
.02516 .25123 L
.02551 .25737 L
.02584 .26082 L
.02623 .26396 L
.02725 .27026 L
.02874 .27709 L
.03244 .28945 L
.03664 .29998 L
.04222 .31121 L
.05503 .33105 L
.07464 .35364 L
.09663 .3732 L
.15298 .40926 L
.18633 .42493 L
.22617 .44004 L
.26619 .45213 L
.30607 .46168 L
.34328 .46867 L
.38486 .47453 L
.40679 .47686 L
.43117 .47885 L
.44351 .47963 L
.45683 .4803 L
.46328 .48056 L
.46942 .48077 L
.48097 .48106 L
.49174 .48122 L
.50322 .48126 L
.51405 .48118 L
.52387 .48101 L
.53544 .48068 L
.54194 .48044 L
.54792 .48018 L
.57048 .47888 L
.59213 .47714 L
.61172 .47514 L
.65499 .46922 L
.69391 .46196 L
.72945 .45354 L
.80304 .42939 L
Mistroke
.84016 .41266 L
.87112 .39533 L
.89583 .37843 L
.91898 .35889 L
.9359 .34105 L
.95096 .32067 L
.95751 .30943 L
.96329 .29724 L
.96594 .29043 L
.96802 .2842 L
.96979 .27784 L
.97113 .27195 L
.97212 .26648 L
.97289 .26067 L
.97339 .25483 L
.97355 .25151 L
.97361 .24841 L
.97353 .2428 L
.97323 .23768 L
.97262 .23178 L
.97177 .22619 L
.97062 .22041 L
.96907 .2142 L
.96545 .20302 L
.96093 .19225 L
.95591 .18249 L
.9415 .16081 L
.92192 .13898 L
.87986 .10547 L
.85123 .0884 L
.82175 .0739 L
.78709 .05983 L
.74659 .04656 L
.70877 .03665 L
.66683 .02803 L
.62782 .02197 L
.6052 .01924 L
.58377 .01716 L
.56399 .01566 L
.54579 .01463 L
.53621 .01422 L
.52573 .01388 L
.51477 .01363 L
.50459 .01351 L
.49313 .0135 L
.48736 .01354 L
.48103 .01362 L
.46982 .01387 L
.45937 .01421 L
.44706 .01475 L
Mistroke
.43586 .01537 L
.41081 .01723 L
.38941 .01934 L
.36638 .02217 L
.32532 .02872 L
.28693 .03679 L
.24788 .0472 L
.18334 .07051 L
.15177 .08559 L
.12539 .1008 L
.10003 .11851 L
.07615 .13933 L
.05882 .15858 L
.04579 .17724 L
.03541 .19755 L
.03114 .20913 L
.02953 .2146 L
.02824 .21975 L
.0271 .22532 L
.02628 .23042 L
.02562 .2361 L
.02521 .24221 L
.0251 .24806 L
.02516 .25137 L
.0253 .25444 L
.02576 .26006 L
.02653 .26604 L
.02751 .27156 L
.02885 .27751 L
.03202 .28824 L
.03602 .29858 L
.04049 .30798 L
.05361 .32913 L
.07239 .35136 L
.09665 .37322 L
.1233 .39216 L
.15266 .40909 L
.18808 .42567 L
.222 .43862 L
.26045 .45056 L
.29685 .45968 L
.33868 .4679 L
.37796 .47369 L
.4156 .47765 L
.43711 .47925 L
.44745 .47985 L
.45722 .48032 L
.46882 .48075 L
.47937 .48103 L
.49075 .48121 L
Mistroke
.49716 .48125 L
.50307 .48126 L
.51414 .48118 L
.52447 .48099 L
.5358 .48067 L
.54795 .48018 L
.56062 .47951 L
.57261 .47873 L
.59498 .47688 L
.63489 .47224 L
.67102 .46646 L
.70946 .45851 L
.74861 .44821 L
.80576 .42829 L
Mfstroke
.92062 .35639 m
.93828 .33729 L
.95162 .31872 L
.96265 .29763 L
.96715 .28557 L
.97017 .27448 L
.97131 .26879 L
.97223 .26275 L
.97277 .25758 L
.97312 .25188 L
.97319 .24575 L
.9731 .24231 L
.97292 .23916 L
.97236 .23305 L
.97154 .22726 L
.97053 .22191 L
.9692 .21623 L
.96613 .20605 L
.96136 .19406 L
.956 .18332 L
.94025 .15956 L
.92149 .13866 L
.89645 .11703 L
.86525 .09593 L
.80298 .06511 L
.76291 .0505 L
.72291 .03887 L
.68214 .02952 L
.65996 .02537 L
.63597 .02156 L
.61476 .01874 L
.59107 .01618 L
.56931 .01435 L
.55951 .01369 L
.54876 .01308 L
.53893 .01262 L
.52842 .01224 L
.5173 .01195 L
.50694 .0118 L
.49659 .01176 L
.48681 .01181 L
.47804 .01194 L
.46853 .01217 L
.45814 .01253 L
.44672 .01304 L
.42374 .01449 L
.40261 .0163 L
.383 .01842 L
.34002 .02458 L
.29474 .03354 L
Mistroke
.25389 .04413 L
.21803 .05573 L
.15669 .08212 L
.12665 .09922 L
.1024 .11602 L
.07965 .13535 L
.05969 .15696 L
.0461 .17622 L
.03988 .18733 L
.03497 .19798 L
.03048 .21048 L
.02753 .22196 L
.02635 .22841 L
.02557 .23438 L
.02528 .2375 L
.02505 .24093 L
.02491 .24453 L
.02488 .24789 L
.02504 .25362 L
.0255 .25964 L
.02612 .26477 L
.02705 .27036 L
.02835 .27638 L
.03006 .28278 L
.03401 .2942 L
.03923 .30587 L
.04601 .318 L
.06128 .33909 L
.08203 .36066 L
.10969 .38275 L
.13739 .40031 L
.17069 .41741 L
.23895 .44336 L
.27958 .45462 L
.31906 .46324 L
.36403 .47067 L
.38727 .47361 L
.41326 .47621 L
.43607 .47792 L
.44697 .47856 L
.45714 .47905 L
.46822 .47946 L
.47409 .47963 L
.48036 .47978 L
.48696 .47989 L
.4932 .47996 L
.50488 .47998 L
.51536 .47989 L
.52646 .47968 L
.53592 .4794 L
Mistroke
.54632 .479 L
.55747 .47845 L
.56942 .47772 L
.59091 .47604 L
.61298 .47382 L
.63624 .47091 L
.6772 .46425 L
.72405 .454 L
.76432 .44253 L
.8002 .42981 L
.83607 .4141 L
.8666 .39761 L
.89209 .38081 L
.91566 .36168 L
.93387 .34317 L
.95024 .32159 L
.95745 .30934 L
.96307 .29755 L
.96738 .28596 L
.96927 .27957 L
.97072 .27354 L
.9718 .26798 L
.97256 .26287 L
.97315 .25718 L
.97349 .25104 L
.97354 .24806 L
.97352 .24488 L
.97327 .23916 L
.97298 .23565 L
.97262 .23235 L
.9717 .22619 L
.97039 .21968 L
.96887 .21371 L
.96436 .20032 L
.95945 .18927 L
.95407 .1793 L
.9389 .15747 L
.92118 .1381 L
.90126 .12065 L
.84665 .08552 L
.81025 .06836 L
.77345 .05436 L
.73468 .04246 L
.69044 .03178 L
.64682 .02383 L
.62558 .02078 L
.60555 .01837 L
.58566 .0164 L
.56742 .01496 L
.54705 .01375 L
Mistroke
.53581 .01327 L
.52516 .01293 L
.5148 .0127 L
.50381 .01258 L
.49442 .01257 L
.48408 .01265 L
.473 .01287 L
.46677 .01304 L
.46108 .01323 L
.43961 .01425 L
.42818 .01499 L
.41745 .0158 L
.3975 .01763 L
.35347 .02322 L
.31643 .02968 L
.27772 .03838 L
.23699 .04998 L
.1967 .06447 L
.16194 .08002 L
.13308 .09578 L
.08452 .13128 L
.06352 .15277 L
.04767 .17415 L
.04191 .18397 L
.03669 .19455 L
.03296 .20379 L
.02973 .21384 L
.0283 .21947 L
.02722 .22466 L
.02639 .22962 L
.02574 .23486 L
.02528 .24062 L
.0251 .24599 L
.02518 .25187 L
.02534 .25516 L
.02557 .25815 L
.02619 .26368 L
.02699 .26883 L
.02813 .27448 L
.02964 .28052 L
.03366 .29274 L
.03842 .30377 L
.05046 .32455 L
.0653 .34356 L
.08633 .36439 L
.10939 .38252 L
.13814 .4008 L
.1731 .41867 L
.21085 .43414 L
.24824 .4465 L
Mistroke
.28529 .45639 L
.32781 .46534 L
.3674 .47164 L
.40521 .47602 L
.42639 .47782 L
.4458 .47907 L
.45658 .4796 L
.46832 .48005 L
.47943 .48035 L
.4897 .48052 L
.50022 .48058 L
.51129 .48054 L
.52073 .4804 L
.53104 .48016 L
.54218 .47978 L
.55404 .47923 L
.57531 .47791 L
.59671 .4761 L
.61672 .47398 L
.65357 .4689 L
.69639 .46095 L
.73428 .45183 L
.7735 .43998 L
.81276 .42509 L
.84574 .40958 L
.87309 .39395 L
.91809 .35969 L
.93783 .33873 L
.94659 .32724 L
.9546 .31475 L
.96045 .30367 L
.96569 .29125 L
.96757 .28576 L
.96932 .27982 L
.97068 .27427 L
.97174 .269 L
.97263 .26319 L
.9732 .2579 L
.97356 .2522 L
.97365 .24898 L
.97365 .24601 L
.9735 .24106 L
.97309 .23561 L
.97241 .22992 L
.97153 .22461 L
.9702 .21838 L
.96863 .21247 L
.96492 .20146 L
.95979 .18975 L
.95289 .17716 L
Mistroke
.93637 .15431 L
.9138 .1312 L
.88809 .11083 L
.86133 .09375 L
.83123 .07794 L
.7964 .06295 L
.72736 .0408 L
.68589 .03119 L
.64565 .02402 L
.62244 .02077 L
.60018 .0182 L
.57425 .01588 L
.56279 .01508 L
.55041 .01436 L
.5394 .01384 L
.5293 .01348 L
.51962 .01323 L
.50942 .01306 L
.49821 .013 L
.48777 .01305 L
.47632 .01323 L
.46992 .01339 L
.46411 .01357 L
.45236 .01403 L
.44155 .01458 L
.41724 .01625 L
.39597 .01822 L
.37368 .0208 L
.33495 .02664 L
.29975 .03355 L
.2246 .0544 L
.18915 .06786 L
.15362 .0845 L
.12532 .10077 L
.09861 .11959 L
.07588 .13961 L
.05873 .15875 L
.04492 .17878 L
.0352 .1982 L
.03117 .20924 L
.02833 .21962 L
.02711 .22561 L
.02625 .23107 L
.02588 .2341 L
.02557 .23739 L
.02522 .24337 L
.02517 .24913 L
.02526 .25241 L
.02543 .25548 L
.02568 .2587 L
Mistroke
.026 .26165 L
.02696 .26828 L
.02806 .27389 L
.02956 .27999 L
.03308 .29103 L
.03764 .30201 L
.04266 .31185 L
.05688 .33334 L
.0736 .35242 L
.09236 .36954 L
.14451 .40448 L
.17545 .41989 L
.21258 .43496 L
.24658 .44622 L
.28511 .4566 L
.32029 .4642 L
.35893 .47074 L
.38046 .47363 L
.40453 .47627 L
.42663 .47816 L
.44754 .47948 L
.45954 .48005 L
.46609 .4803 L
.47219 .48049 L
.48302 .48074 L
.48875 .48083 L
.49488 .48089 L
.50149 .48091 L
.50866 .48088 L
.51543 .48081 L
.52168 .48071 L
.5273 .48058 L
.53349 .48041 L
.54599 .47994 L
.55789 .47935 L
.56916 .47865 L
.5902 .47701 L
.61267 .47475 L
.63689 .47169 L
.67945 .46465 L
.71757 .45636 L
.75712 .44548 L
.79727 .43156 L
.83008 .4175 L
.86172 .40094 L
.88741 .38456 L
.91213 .36518 L
.92994 .34785 L
.94602 .32811 L
.95381 .31615 L
Mistroke
.95989 .30489 L
.9646 .2942 L
.96866 .28226 L
.97005 .27709 L
.97129 .27151 L
.97215 .26667 L
.97288 .26136 L
.9734 .25569 L
.97366 .24972 L
.97364 .24419 L
.9734 .23905 L
.97283 .23296 L
.97237 .22953 L
.97187 .22638 L
.97075 .22071 L
.96922 .21449 L
.9658 .20378 L
.96115 .19256 L
.94682 .16787 L
.92875 .14578 L
.90748 .12578 L
.88012 .10546 L
.85263 .08896 L
.82022 .073 L
.78519 .0589 L
.75129 .04769 L
.71809 .03863 L
.68016 .03025 L
.63886 .02323 L
.61736 .02036 L
.59409 .01783 L
.57204 .01595 L
.55184 .01467 L
.54207 .0142 L
.53144 .01379 L
.52139 .01351 L
.5121 .01334 L
.5014 .01324 L
.48989 .01327 L
.47903 .01341 L
.46909 .01365 L
.4575 .01404 L
.44488 .01463 L
.42198 .0161 L
.39832 .01819 L
.37336 .02105 L
.32937 .02782 L
.28538 .03703 L
.24675 .04743 L
.20757 .06066 L
Mistroke
.16789 .07748 L
.11034 .11088 L
.0845 .13151 L
.0643 .15204 L
.04813 .17359 L
.04084 .18614 L
.03531 .19794 L
.03146 .20835 L
.02826 .21994 L
.02708 .2258 L
.02657 .22888 L
.02612 .23212 L
.02551 .23811 L
.02522 .2436 L
.02517 .249 L
.02534 .25391 L
.02577 .25957 L
.02643 .26491 L
.02724 .26984 L
.02817 .27437 L
.03089 .28457 L
.03451 .29478 L
.0395 .30587 L
.05273 .32777 L
.07093 .34971 L
.09215 .36942 L
.14149 .40289 L
.17394 .41931 L
.20678 .43294 L
.24522 .44595 L
.28945 .45778 L
.33481 .46703 L
.35526 .47036 L
.37801 .4735 L
.39833 .47582 L
.4203 .47784 L
.43252 .47875 L
.44369 .47945 L
.45432 .48 L
.46562 .48046 L
.47572 .48076 L
.48686 .48098 L
.49699 .48107 L
.5065 .48107 L
.51767 .48095 L
.5279 .48074 L
.5391 .48038 L
.55087 .47988 L
.57073 .47871 L
.58908 .47727 L
Mistroke
.63018 .47275 L
.6527 .46947 L
.67313 .46597 L
.71794 .45639 L
.75559 .44605 L
.79315 .43323 L
.85168 .40662 L
.88064 .38922 L
.90455 .37161 L
.92636 .35165 L
.94564 .32864 L
.95285 .31774 L
.95936 .30594 L
.96403 .2956 L
.96804 .28431 L
.96955 .279 L
.97089 .27339 L
.9719 .26818 L
.97263 .26331 L
.97314 .25873 L
.9735 .25383 L
.97367 .2484 L
.97361 .24345 L
.97329 .23764 L
.97274 .23229 L
.97187 .22642 L
.97064 .22023 L
.96786 .20988 L
.96377 .19858 L
.95861 .18739 L
.95177 .17536 L
.93616 .15411 L
.9172 .13438 L
.89644 .11706 L
.83918 .08202 L
.80165 .06526 L
.76471 .05197 L
.72726 .04108 L
.6857 .03148 L
.64886 .02487 L
.60731 .01932 L
.5835 .01699 L
.56161 .01537 L
.54944 .01467 L
.53618 .01408 L
.5301 .01387 L
.52363 .01369 L
.512 .01346 L
.5014 .01337 L
.48998 .01339 L
Mistroke
.47919 .01353 L
.46932 .01376 L
.45838 .01413 L
.44644 .01467 L
.42249 .01618 L
.40017 .01812 L
.37622 .0208 L
.33361 .02716 L
.29346 .03522 L
.25793 .04425 L
.18379 .07031 L
.15063 .0862 L
.11796 .10565 L
.09166 .12529 L
.07044 .14523 L
.05469 .16405 L
.04124 .18536 L
.03536 .19779 L
.03118 .20918 L
.02933 .21555 L
.0277 .22245 L
.02654 .22899 L
.02577 .23501 L
.02533 .24063 L
.02516 .24586 L
.02522 .25161 L
.02559 .25775 L
.02589 .26084 L
.02631 .26419 L
.02731 .27026 L
.02857 .27616 L
.02999 .28158 L
.03367 .29267 L
.03794 .30271 L
.05065 .32482 L
.06613 .34454 L
.08402 .36245 L
.13435 .39884 L
.16858 .41689 L
.20364 .43182 L
.24062 .44462 L
.28321 .45638 L
.32549 .46544 L
.36582 .47199 L
.40318 .47641 L
.42467 .47828 L
.44489 .47961 L
.45588 .48016 L
.46632 .48057 L
.47571 .48085 L
Mistroke
.48594 .48106 L
.49705 .48116 L
.50267 .48117 L
.50887 .48114 L
.51981 .481 L
.53008 .48077 L
.54053 .48042 L
.55169 .47992 L
.57171 .47872 L
.59537 .47677 L
.61667 .47451 L
.66219 .46797 L
.70377 .45977 L
.77266 .4406 L
.80835 .42722 L
.83886 .41332 L
.86708 .39783 L
.89419 .37969 L
.91472 .36288 L
.93384 .3435 L
.9437 .33128 L
.95164 .31968 L
.9586 .30742 L
.96379 .29615 L
.96784 .28492 L
.97069 .27425 L
.97185 .26836 L
.97266 .26293 L
.97328 .25696 L
.97348 .25395 L
.97361 .25065 L
.97363 .24457 L
.97337 .23894 L
.97313 .23601 L
.97278 .23278 L
.97182 .22625 L
.97069 .22054 L
.96917 .21442 L
.96564 .20341 L
.96118 .19269 L
.95545 .18157 L
.9426 .16217 L
.92358 .14054 L
.90217 .12155 L
.87502 .10226 L
.84144 .08321 L
.80529 .06678 L
.76912 .05348 L
.73306 .04268 L
.69134 .03271 L
Mistroke
.65239 .0255 L
.61495 .02027 L
.59394 .01801 L
.5746 .01634 L
.56386 .01558 L
.55212 .01488 L
.54096 .01434 L
.53069 .01396 L
.5206 .01368 L
.50995 .0135 L
.49926 .01343 L
.48754 .01348 L
.4774 .01363 L
.46656 .01391 L
.45634 .01427 L
.44706 .0147 L
.42443 .01609 L
.40005 .01819 L
.37726 .02072 L
.35647 .02353 L
.31564 .03055 L
.27238 .04038 L
.22959 .05295 L
.19215 .0668 L
.15931 .08173 L
.12689 .09988 L
.10157 .11736 L
.07821 .13735 L
.05905 .15834 L
.04524 .17822 L
.03983 .18805 L
.03491 .19883 L
.03117 .20917 L
.02853 .21866 L
.02732 .22429 L
.02642 .22964 L
.02573 .2353 L
.02546 .2385 L
.02528 .24146 L
.02514 .24638 L
.02521 .25181 L
.02555 .25748 L
.02611 .26279 L
.027 .2687 L
.02826 .2749 L
.03129 .28592 L
.03567 .29767 L
.04179 .31034 L
.05681 .33334 L
.07785 .35674 L
Mistroke
.10219 .37745 L
.12783 .39495 L
.15667 .4111 L
.19031 .42654 L
.25751 .44968 L
.29806 .45989 L
.33765 .46767 L
.38251 .4742 L
.4082 .47694 L
.43192 .47885 L
.44336 .47957 L
.45416 .48013 L
.46388 .48053 L
.47439 .48087 L
.48591 .4811 L
.49171 .48117 L
.49807 .48121 L
.50933 .48119 L
.51983 .48105 L
.53043 .4808 L
.54045 .48046 L
.54943 .48007 L
.55916 .47956 L
.5809 .47807 L
.60085 .47627 L
.64224 .47116 L
.68658 .46346 L
.731 .45313 L
.77045 .44136 L
.83845 .41353 L
.86834 .39706 L
.89727 .37736 L
.91872 .35917 L
.93794 .33863 L
.95244 .31836 L
.96241 .29937 L
.96654 .28881 L
.97 .27711 L
.97131 .27117 L
.97191 .2679 L
.9724 .26479 L
.97311 .25876 L
.9735 .25324 L
.97364 .24808 L
.97355 .24258 L
.97328 .2379 L
.97276 .23273 L
.97197 .2272 L
.97083 .22126 L
.96804 .21056 L
Mistroke
.96394 .19906 L
.95819 .18664 L
.94267 .16228 L
.92377 .14076 L
.90247 .12182 L
.8765 .10324 L
.84445 .08478 L
.81315 .0701 L
.77721 .05626 L
.74266 .04538 L
.70259 .03519 L
.66459 .0276 L
.62792 .02194 L
.60709 .01941 L
.58466 .0172 L
.57166 .01616 L
.55984 .01536 L
.54778 .01469 L
.53666 .0142 L
.52607 .01385 L
.51488 .0136 L
.50363 .01348 L
.49724 .01346 L
.49129 .01348 L
.48049 .01361 L
.47066 .01382 L
.45932 .01419 L
.44861 .01465 L
.42878 .01581 L
.40784 .01747 L
.37072 .02157 L
.33165 .02757 L
.28995 .03608 L
.25116 .04623 L
.21259 .05887 L
.1506 .08622 L
.12055 .10393 L
.09587 .12182 L
.0727 .14284 L
.05277 .16666 L
.04534 .17802 L
.03872 .19027 L
.03403 .20101 L
.03009 .21267 L
.02838 .21925 L
.02713 .22529 L
.02617 .23137 L
.02555 .23716 L
.02532 .24041 L
.02517 .24388 L
Mistroke
.02512 .24715 L
.02515 .25011 L
.02528 .2536 L
.02553 .25737 L
.02587 .26093 L
.02628 .26419 L
.02716 .26961 L
.02836 .27539 L
.03122 .28576 L
.03578 .29797 L
.04102 .30893 L
.05589 .33217 L
.0742 .35317 L
.09445 .37141 L
.12035 .39023 L
.14897 .40711 L
.18316 .42354 L
.21791 .43715 L
.25183 .44808 L
.28856 .45774 L
.32325 .4651 L
.36347 .47174 L
.38449 .47446 L
.4075 .4769 L
.42906 .47868 L
.43857 .47931 L
.44903 .47991 L
.45827 .48034 L
.4682 .48071 L
.4787 .48099 L
.48852 .48116 L
.49451 .48122 L
.50088 .48124 L
.51231 .48118 L
.51866 .48109 L
.52461 .48097 L
.53114 .4808 L
.53817 .48057 L
.55009 .48006 L
.5626 .47938 L
.58487 .47777 L
.60628 .47573 L
.62602 .47341 L
.66996 .46665 L
.71141 .45805 L
.75426 .44652 L
.78986 .43451 L
.82497 .41997 L
.85404 .40535 L
.88291 .38769 L
Mistroke
.92491 .35309 L
.94378 .33114 L
.95144 .31995 L
.95756 .30938 L
.96261 .29888 L
.96637 .28927 L
.96964 .2785 L
.97102 .27256 L
.97206 .26695 L
.97284 .26131 L
.97316 .25811 L
.97339 .25512 L
.97362 .24909 L
.97362 .24571 L
.97354 .24263 L
.9732 .23712 L
.97255 .23115 L
.97167 .22552 L
.97062 .22034 L
.96748 .20884 L
.96276 .19629 L
.95643 .18338 L
.9492 .17149 L
.93374 .15139 L
.91282 .13051 L
.8886 .11142 L
.85888 .09261 L
.82759 .07654 L
.79664 .0634 L
.73018 .04197 L
.69117 .03273 L
.64823 .0249 L
.61049 .01981 L
.58872 .01758 L
.5682 .01593 L
.55678 .0152 L
.54432 .01455 L
.53252 .01407 L
.52157 .01376 L
.51173 .01357 L
.50085 .01348 L
.48949 .01351 L
.47881 .01365 L
.46708 .01394 L
.46118 .01413 L
.45474 .01438 L
.43273 .01556 L
.42037 .01644 L
.40721 .01754 L
.38368 .01998 L
Mistroke
.33815 .02645 L
.29747 .03438 L
.25476 .04519 L
.21216 .05903 L
.14824 .08748 L
.11689 .10635 L
.09126 .1256 L
.07004 .14561 L
.05135 .16867 L
.04442 .17957 L
.03818 .19138 L
.03342 .2026 L
.02998 .21303 L
.02859 .21832 L
.02733 .22413 L
.02635 .22999 L
.02594 .2332 L
.02562 .2362 L
.02524 .24173 L
.02511 .24678 L
.02522 .2526 L
.02558 .25811 L
.02612 .26305 L
.02691 .26828 L
.02889 .27763 L
.03183 .28763 L
.03603 .29856 L
.04771 .32045 L
.06437 .34262 L
.08198 .36067 L
.10464 .37932 L
.13286 .39804 L
.16693 .41619 L
.23722 .44364 L
.2784 .45529 L
.31828 .46416 L
.36376 .47179 L
.38723 .4748 L
.41336 .47744 L
.42521 .47841 L
.4365 .4792 L
.44679 .4798 L
.45777 .48033 L
.46403 .48058 L
.4697 .48077 L
.48077 .48105 L
.48698 .48115 L
.4937 .48123 L
.50004 .48125 L
.50587 .48124 L
Mistroke
.51632 .48114 L
.52606 .48095 L
.53673 .48063 L
.54813 .48017 L
.56007 .47954 L
.57133 .47882 L
.59231 .47712 L
.63235 .47258 L
.67537 .46566 L
.71866 .4563 L
.75732 .44558 L
.82066 .42192 L
.85244 .40622 L
.87878 .39044 L
.90318 .3727 L
.92553 .35245 L
.94292 .33228 L
.95543 .31324 L
.96153 .30128 L
.96606 .29012 L
.96983 .27775 L
.97124 .27147 L
.97189 .26793 L
.97241 .26456 L
.97312 .25847 L
.9735 .25291 L
.97363 .24691 L
.97357 .24353 L
.97343 .24039 L
.97302 .2352 L
.97231 .22947 L
.97128 .2235 L
.97004 .21791 L
.9668 .20677 L
.96285 .19651 L
.95063 .17368 L
.9345 .15228 L
.91286 .13056 L
.88881 .11158 L
.86288 .09493 L
.80685 .06749 L
.77399 .05519 L
.73548 .04341 L
.69303 .03314 L
.65158 .02544 L
.63126 .02242 L
.61171 .01996 L
.59378 .01806 L
.57454 .0164 L
.56355 .01562 L
Mistroke
.55356 .01502 L
.54338 .01451 L
.534 .01413 L
.523 .0138 L
.51721 .01367 L
.5111 .01357 L
.50081 .01349 L
.48951 .01352 L
.47784 .01368 L
.46706 .01394 L
.46144 .01413 L
.45525 .01437 L
.44274 .01497 L
.42005 .01647 L
.39893 .01834 L
.3601 .02304 L
.31934 .02985 L
.27609 .03945 L
.23293 .05186 L
.19513 .06558 L
.16335 .07972 L
.10798 .11257 L
.08296 .13287 L
.06321 .15325 L
.04843 .17303 L
.03794 .19187 L
.03368 .2019 L
.02997 .21303 L
.0285 .21867 L
.02721 .22475 L
.02627 .2305 L
.02566 .23576 L
.02523 .24179 L
.02511 .24746 L
.02522 .25255 L
.02557 .25804 L
.02625 .26404 L
.0267 .26705 L
.02728 .27035 L
.02994 .28159 L
.03339 .29205 L
.03809 .30312 L
.04915 .32268 L
.06776 .34643 L
.08989 .36765 L
.11309 .38538 L
.1422 .40344 L
.20557 .43265 L
.24448 .44591 L
.2832 .45648 L
Mistroke
.32029 .46455 L
.35672 .47078 L
.3772 .47359 L
.39983 .47617 L
.42069 .47806 L
.44002 .47942 L
.45103 .48003 L
.46269 .48053 L
.47442 .48091 L
.48108 .48106 L
.48731 .48116 L
.49859 .48125 L
.50887 .48123 L
.51456 .48117 L
.52074 .48107 L
.53198 .48079 L
.54195 .48044 L
.55294 .47993 L
.5751 .47855 L
.59549 .47683 L
.61449 .47483 L
.6596 .46846 L
.69967 .46072 L
.74181 .45017 L
.78363 .43679 L
.84773 .40875 L
.87881 .39042 L
.90367 .3723 L
.92374 .35426 L
.94188 .33364 L
.95537 .31334 L
.96458 .29407 L
.96842 .28289 L
.971 .2726 L
.97206 .2669 L
.9725 .26388 L
.9729 .26066 L
.9734 .25476 L
.97361 .24929 L
.97357 .24381 L
.97325 .23789 L
.97269 .2323 L
.97194 .22718 L
.97109 .22256 L
.96994 .2175 L
.96699 .20736 L
.96223 .1951 L
.9568 .1841 L
.94091 .16005 L
.92175 .1388 L
Mistroke
.89991 .11983 L
.84632 .08579 L
.81476 .07082 L
.77692 .0562 L
.74252 .04538 L
.70351 .03544 L
.66513 .02773 L
.6289 .02211 L
.60772 .01951 L
.58755 .01749 L
.56411 .01566 L
.55372 .01503 L
.5427 .01448 L
.53302 .0141 L
.52236 .01379 L
.51267 .0136 L
.5036 .0135 L
.49291 .0135 L
.48315 .01359 L
.4719 .01381 L
.46124 .01414 L
.45069 .01457 L
.43906 .01518 L
.41562 .01682 L
.39407 .01884 L
.37401 .02116 L
.32979 .02791 L
.28382 .03754 L
.24514 .04803 L
.21106 .05943 L
.17333 .07498 L
.14203 .0909 L
.1144 .10804 L
.0882 .1282 L
.06511 .15104 L
.04792 .17382 L
.04179 .18424 L
.03624 .19561 L
.03234 .20556 L
.02903 .21651 L
.02751 .22319 L
.02643 .2294 L
.0257 .23535 L
.02541 .23868 L
.02523 .2417 L
.0251 .24742 L
.02515 .25064 L
.02526 .25361 L
.02566 .25905 L
.02635 .26479 L
Mistroke
.02737 .27086 L
.02857 .27637 L
.03217 .28867 L
.03663 .29995 L
.04183 .31049 L
.05686 .33347 L
.07834 .35726 L
.10047 .3762 L
.12433 .39282 L
.15632 .41097 L
.18877 .42596 L
.26285 .45122 L
.30526 .46151 L
.3519 .47005 L
.37396 .47318 L
.39503 .47567 L
.41437 .47754 L
.43499 .47911 L
.44575 .47975 L
.4576 .48033 L
.4684 .48074 L
.47852 .48101 L
.48464 .48113 L
.49045 .4812 L
.50136 .48126 L
.5131 .48119 L
.51973 .48109 L
.52588 .48096 L
.5362 .48065 L
.54732 .48021 L
.5674 .47909 L
.58684 .47761 L
.60458 .47592 L
.64438 .47087 L
.68523 .46375 L
.72553 .45457 L
.76054 .44457 L
.79615 .43211 L
.832 .41667 L
.86223 .40069 L
.88736 .3846 L
.92825 .34961 L
.94468 .32989 L
.95222 .31868 L
.95836 .30782 L
.96313 .29762 L
.96734 .28637 L
.96885 .28138 L
.97024 .27604 L
.97125 .27136 L
Mistroke
.97213 .2664 L
.97258 .26332 L
.97297 .25994 L
.97344 .25398 L
.97358 .25062 L
.97362 .24702 L
.97356 .24362 L
.97343 .24052 L
.97294 .23453 L
.97254 .23114 L
.97208 .22802 L
.97103 .2223 L
.96962 .21623 L
.96625 .20523 L
.96218 .19499 L
.94963 .17215 L
.93435 .15211 L
.91361 .13123 L
.88773 .11083 L
.86003 .09329 L
.80256 .06576 L
.76657 .05272 L
.73182 .04243 L
.69303 .03315 L
.65026 .02524 L
.61266 .02008 L
.59094 .0178 L
.57043 .0161 L
.55907 .01535 L
.54664 .01467 L
.53487 .01417 L
.52393 .01383 L
.51308 .01361 L
.50325 .0135 L
.49189 .01351 L
.48121 .01362 L
.4695 .01388 L
.46361 .01406 L
.45716 .01429 L
.43515 .01542 L
.42279 .01626 L
.40961 .01734 L
.38602 .01972 L
.34058 .02605 L
.2999 .03384 L
.25715 .04451 L
.21442 .0582 L
.15024 .0864 L
.11867 .10515 L
.09278 .12432 L
Mistroke
.07077 .14483 L
.05399 .16493 L
.04046 .18675 L
.03499 .19856 L
.03046 .21133 L
.02767 .22239 L
.02654 .22865 L
.02579 .23443 L
.02535 .2395 L
.02512 .24507 L
.02515 .25089 L
.02543 .25633 L
.02593 .26162 L
.02663 .26664 L
.02742 .27113 L
.02848 .276 L
.03156 .28687 L
.03528 .29684 L
.04583 .31745 L
.06123 .33894 L
.07944 .35831 L
.09914 .37517 L
.15496 .41028 L
.18783 .42557 L
.227 .44032 L
.26707 .45237 L
.30699 .46188 L
.34423 .46883 L
.38583 .47465 L
.40777 .47695 L
.43216 .47892 L
.44451 .47969 L
.45782 .48034 L
.46428 .4806 L
.47042 .4808 L
.48197 .48108 L
.49274 .48123 L
.50422 .48126 L
.51505 .48117 L
.52487 .48098 L
.53643 .48065 L
.54892 .48014 L
.56068 .47951 L
.57147 .47881 L
.61269 .47503 L
.63546 .47216 L
.65594 .46906 L
.73034 .45331 L
.76922 .44177 L
.80874 .42706 L
Mistroke
.84279 .41132 L
.87175 .39494 L
.91849 .35936 L
.93788 .33867 L
.94631 .32762 L
.95426 .31527 L
.96039 .30372 L
.96566 .29121 L
.96801 .28422 L
.96979 .27784 L
.97126 .27133 L
.9723 .26531 L
.97299 .25971 L
.97345 .25378 L
.97362 .24782 L
.97358 .24444 L
.97346 .24127 L
.97304 .23556 L
.97243 .23035 L
.97143 .22435 L
.97022 .21867 L
.96678 .20675 L
.96246 .19564 L
.95166 .17531 L
.93612 .15418 L
.91498 .13247 L
.89289 .11454 L
.86624 .09692 L
.81082 .06915 L
.77566 .05577 L
.74157 .04511 L
.70296 .03532 L
.65916 .0267 L
.63897 .02352 L
.61727 .02063 L
.59693 .01838 L
.5777 .01666 L
.55965 .01538 L
.54012 .01438 L
.52952 .01399 L
.51837 .0137 L
.50883 .01355 L
.49841 .01349 L
.49266 .0135 L
.48657 .01355 L
.47568 .01373 L
.46396 .01405 L
.45732 .01429 L
.45112 .01455 L
.42973 .01577 L
Mistroke
.40693 .01758 L
.38501 .01983 L
.36446 .02243 L
.32664 .02848 L
.28394 .03751 L
.24618 .04771 L
.20739 .0608 L
.16872 .07713 L
.13766 .09338 L
.11202 .10968 L
.07053 .14508 L
.05367 .16538 L
.03956 .18852 L
.03422 .20048 L
.0318 .20712 L
.02985 .21342 L
.02834 .21932 L
.02702 .22575 L
.02612 .2316 L
.02554 .23701 L
.02518 .24282 L
.0251 .24834 L
.02524 .2533 L
.02563 .2587 L
.02631 .26455 L
.02682 .26781 L
.02735 .27076 L
.03002 .28188 L
.03341 .29212 L
.03806 .30308 L
.04905 .32254 L
.0663 .34483 L
.08921 .36709 L
.11479 .38655 L
.14133 .40296 L
.2031 .43172 L
.2412 .44491 L
.27953 .45559 L
.31407 .46333 L
.35198 .47006 L
.37218 .47295 L
.39474 .47564 L
.41556 .47765 L
.43507 .47911 L
.45594 .48026 L
.46701 .48069 L
.47317 .48088 L
.47885 .48102 L
.48484 .48113 L
.49132 .48121 L
Mistroke
.50309 .48126 L
.51379 .48118 L
.52511 .48098 L
.53491 .4807 L
.54541 .4803 L
.56433 .47929 L
.58669 .47763 L
.60696 .47567 L
.65108 .46984 L
.69762 .46117 L
.73964 .45078 L
.77654 .43929 L
.80576 .42829 L
Mfstroke
.92128 .35753 m
.93913 .33827 L
.95262 .31952 L
.96378 .29822 L
.96833 .28603 L
.97138 .27482 L
.97254 .26907 L
.97347 .26296 L
.97402 .25774 L
.97437 .25197 L
.97445 .24578 L
.97435 .2423 L
.97418 .23911 L
.97361 .23294 L
.97278 .22709 L
.97177 .22168 L
.97042 .21594 L
.96732 .20565 L
.96251 .19354 L
.9571 .1827 L
.9412 .15874 L
.92227 .13768 L
.89701 .11593 L
.86556 .09475 L
.80285 .06394 L
.76253 .04941 L
.72233 .0379 L
.68139 .0287 L
.65913 .02463 L
.63507 .02092 L
.6138 .01819 L
.59006 .01574 L
.56827 .01401 L
.55845 .0134 L
.54769 .01283 L
.53715 .0124 L
.52733 .01209 L
.51695 .01187 L
.50585 .01176 L
.49549 .01176 L
.48571 .01186 L
.47694 .01203 L
.46744 .01231 L
.45705 .01271 L
.44565 .01327 L
.4227 .01482 L
.4016 .01673 L
.38203 .01892 L
.33917 .02524 L
.29404 .03436 L
Mistroke
.25335 .04505 L
.21767 .05672 L
.15668 .08314 L
.12683 .1002 L
.10274 .11694 L
.08016 .13617 L
.06035 .15765 L
.04686 .17677 L
.04069 .1878 L
.03582 .19837 L
.03136 .21077 L
.02843 .22215 L
.02727 .22855 L
.02649 .23447 L
.0262 .23757 L
.02597 .24098 L
.02583 .24454 L
.0258 .24788 L
.02596 .25357 L
.02641 .25954 L
.02703 .26463 L
.02796 .27017 L
.02924 .27615 L
.03094 .2825 L
.03485 .29383 L
.04004 .30542 L
.04676 .31747 L
.06192 .33843 L
.08253 .35989 L
.11001 .38191 L
.13755 .39943 L
.17067 .41654 L
.23862 .44259 L
.27911 .45395 L
.31846 .46268 L
.36333 .47026 L
.38654 .47327 L
.41249 .47596 L
.43529 .47775 L
.45634 .47895 L
.46742 .4794 L
.47377 .47961 L
.47956 .47976 L
.48569 .47989 L
.49225 .47998 L
.49833 .48003 L
.50408 .48005 L
.51456 .47999 L
.52567 .47982 L
.53514 .47958 L
Mistroke
.54555 .47921 L
.55671 .47869 L
.56867 .478 L
.59019 .47639 L
.6123 .47423 L
.6356 .47138 L
.67665 .46483 L
.72364 .45467 L
.76406 .44326 L
.80007 .43056 L
.8361 .41484 L
.86677 .39832 L
.89238 .38146 L
.91606 .36225 L
.93436 .34365 L
.95082 .32196 L
.95806 .30964 L
.96371 .29777 L
.96804 .28612 L
.96993 .27969 L
.9714 .27363 L
.97247 .26803 L
.97323 .26289 L
.97383 .25717 L
.97416 .25099 L
.97422 .248 L
.97419 .2448 L
.97393 .23904 L
.97364 .23552 L
.97328 .2322 L
.97235 .226 L
.97103 .21946 L
.9695 .21346 L
.96495 .2 L
.96001 .18889 L
.95459 .17888 L
.93934 .15696 L
.92152 .13753 L
.9015 .12004 L
.84665 .08489 L
.81012 .06775 L
.7732 .0538 L
.73433 .04197 L
.68999 .03139 L
.64631 .02353 L
.62504 .02054 L
.60499 .01817 L
.58509 .01626 L
.56684 .01487 L
.54646 .01371 L
Mistroke
.53522 .01326 L
.52457 .01294 L
.51421 .01274 L
.50322 .01264 L
.49384 .01265 L
.4835 .01277 L
.47243 .01301 L
.46621 .0132 L
.46052 .0134 L
.43906 .01447 L
.42765 .01523 L
.41693 .01607 L
.39701 .01794 L
.35304 .02361 L
.31607 .03014 L
.27745 .03888 L
.23682 .05052 L
.19664 .06502 L
.162 .08056 L
.13323 .09628 L
.08484 .13168 L
.06391 .15309 L
.04812 .17438 L
.04237 .18416 L
.03717 .19469 L
.03344 .2039 L
.03022 .2139 L
.02879 .21951 L
.02771 .22467 L
.02689 .22962 L
.02623 .23483 L
.02578 .24057 L
.02559 .24591 L
.02566 .25177 L
.02583 .25505 L
.02605 .25803 L
.02666 .26353 L
.02746 .26867 L
.02859 .27429 L
.03009 .2803 L
.03408 .29248 L
.03882 .30348 L
.0508 .32419 L
.06558 .34315 L
.08652 .36394 L
.1095 .38205 L
.13815 .40033 L
.17301 .41822 L
.21067 .43373 L
.24798 .44613 L
Mistroke
.28498 .45609 L
.32744 .46511 L
.367 .47148 L
.40479 .47594 L
.42596 .47777 L
.44537 .47906 L
.45615 .47961 L
.46789 .48008 L
.479 .4804 L
.48928 .48059 L
.4998 .48067 L
.51087 .48065 L
.52032 .48053 L
.53063 .4803 L
.54178 .47994 L
.55365 .47941 L
.57494 .47812 L
.59636 .47635 L
.61639 .47425 L
.65329 .46922 L
.69618 .46131 L
.73414 .45222 L
.77343 .44038 L
.81278 .42549 L
.84583 .40996 L
.87324 .3943 L
.91835 .35995 L
.93814 .33893 L
.94692 .32741 L
.95494 .31487 L
.9608 .30376 L
.96605 .2913 L
.96793 .2858 L
.96968 .27983 L
.97105 .27426 L
.9721 .26898 L
.97299 .26315 L
.97356 .25785 L
.97392 .25213 L
.974 .2489 L
.974 .24592 L
.97384 .24095 L
.97343 .23549 L
.97274 .22979 L
.97186 .22446 L
.97052 .21821 L
.96894 .21229 L
.96521 .20125 L
.96007 .18951 L
.95313 .1769 L
Mistroke
.93656 .154 L
.91392 .13087 L
.88814 .11049 L
.86131 .0934 L
.83115 .07761 L
.79626 .06266 L
.72713 .04058 L
.68562 .03102 L
.64535 .02391 L
.62214 .02069 L
.59987 .01815 L
.57393 .01587 L
.56248 .01508 L
.55009 .01437 L
.53909 .01388 L
.52898 .01353 L
.51931 .01329 L
.50912 .01314 L
.4979 .01309 L
.48747 .01315 L
.47603 .01335 L
.46963 .01351 L
.46382 .0137 L
.45208 .01417 L
.44128 .01473 L
.41698 .01643 L
.39573 .01842 L
.37347 .02102 L
.33477 .02689 L
.29962 .03382 L
.22457 .05469 L
.18918 .06815 L
.15371 .08477 L
.12545 .10101 L
.09878 .1198 L
.07609 .13978 L
.05897 .15887 L
.04518 .17886 L
.03546 .19823 L
.03143 .20924 L
.0286 .2196 L
.02737 .22557 L
.02651 .23102 L
.02614 .23404 L
.02583 .23733 L
.02548 .2433 L
.02542 .24905 L
.02551 .25232 L
.02567 .25538 L
.02593 .2586 L
Mistroke
.02624 .26154 L
.02719 .26816 L
.02829 .27376 L
.02978 .27985 L
.03329 .29087 L
.03784 .30183 L
.04284 .31165 L
.05702 .33312 L
.0737 .35218 L
.09241 .36929 L
.14448 .40423 L
.17537 .41966 L
.21245 .43476 L
.24642 .44605 L
.28492 .45646 L
.32008 .4641 L
.35871 .47068 L
.38023 .47359 L
.40429 .47625 L
.4264 .47816 L
.44731 .47951 L
.45931 .48009 L
.46586 .48034 L
.47197 .48054 L
.4828 .48081 L
.48853 .4809 L
.49466 .48096 L
.50127 .48099 L
.50845 .48097 L
.51522 .48091 L
.52147 .48081 L
.5271 .48069 L
.53329 .48051 L
.54579 .48005 L
.55769 .47947 L
.56897 .47879 L
.59003 .47716 L
.61251 .47491 L
.63675 .47186 L
.67935 .46485 L
.7175 .45657 L
.75709 .4457 L
.79729 .43177 L
.83014 .4177 L
.86181 .40112 L
.88753 .38472 L
.91228 .36531 L
.93011 .34795 L
.9462 .32818 L
.954 .31619 L
Mistroke
.96008 .30491 L
.96479 .2942 L
.96886 .28225 L
.97024 .27707 L
.97148 .27147 L
.97234 .26662 L
.97307 .26131 L
.97358 .25563 L
.97384 .24965 L
.97382 .24411 L
.97357 .23896 L
.973 .23287 L
.97254 .22943 L
.97204 .22627 L
.97091 .22059 L
.96938 .21437 L
.96595 .20365 L
.96128 .19242 L
.94692 .16771 L
.92882 .1456 L
.90751 .1256 L
.88011 .10528 L
.85259 .08878 L
.82015 .07284 L
.78509 .05876 L
.75116 .04757 L
.71794 .03854 L
.68 .03019 L
.63869 .0232 L
.61719 .02035 L
.59392 .01783 L
.57187 .01597 L
.55168 .0147 L
.54191 .01424 L
.53128 .01384 L
.52123 .01356 L
.51195 .0134 L
.50125 .01331 L
.48974 .01334 L
.47888 .01349 L
.46895 .01373 L
.45736 .01414 L
.44474 .01473 L
.42186 .01621 L
.3982 .01832 L
.37326 .02119 L
.3293 .02797 L
.28534 .03718 L
.24674 .04759 L
.20759 .06081 L
Mistroke
.16795 .07763 L
.11044 .11099 L
.08462 .13159 L
.06444 .15209 L
.04827 .17362 L
.04098 .18615 L
.03545 .19794 L
.0316 .20833 L
.0284 .21991 L
.02721 .22576 L
.0267 .22883 L
.02625 .23208 L
.02565 .23805 L
.02535 .24354 L
.0253 .24894 L
.02546 .25384 L
.02589 .2595 L
.02654 .26483 L
.02736 .26975 L
.02828 .27429 L
.031 .28448 L
.03461 .29467 L
.03959 .30576 L
.0528 .32765 L
.07097 .34957 L
.09216 .36929 L
.14145 .40276 L
.17387 .41919 L
.2067 .43284 L
.24512 .44587 L
.28933 .45773 L
.33468 .467 L
.35513 .47034 L
.37788 .4735 L
.39821 .47583 L
.42018 .47786 L
.4324 .47878 L
.44357 .47948 L
.4542 .48003 L
.4655 .4805 L
.4756 .48081 L
.48674 .48103 L
.49688 .48113 L
.50639 .48113 L
.51757 .48102 L
.52779 .48081 L
.53901 .48046 L
.55078 .47996 L
.57064 .47879 L
.58899 .47736 L
Mistroke
.63011 .47285 L
.65265 .46957 L
.67309 .46608 L
.71792 .45651 L
.75559 .44616 L
.79317 .43334 L
.85174 .40672 L
.88072 .3893 L
.90464 .37167 L
.92646 .35169 L
.94574 .32866 L
.95295 .31775 L
.95947 .30594 L
.96413 .29559 L
.96814 .28429 L
.96965 .27898 L
.97099 .27336 L
.97199 .26814 L
.97273 .26327 L
.97324 .25869 L
.9736 .25379 L
.97376 .24834 L
.9737 .24339 L
.97337 .23758 L
.97282 .23223 L
.97195 .22636 L
.97072 .22016 L
.96793 .2098 L
.96384 .1985 L
.95866 .1873 L
.95181 .17527 L
.93619 .15401 L
.9172 .13428 L
.89643 .11696 L
.83913 .08193 L
.80159 .06519 L
.76463 .05192 L
.72718 .04103 L
.68561 .03145 L
.64877 .02486 L
.60722 .01933 L
.58341 .01701 L
.56152 .01539 L
.54936 .0147 L
.5361 .01412 L
.53001 .01391 L
.52355 .01373 L
.51192 .0135 L
.50132 .01342 L
.4899 .01344 L
Mistroke
.47912 .01359 L
.46925 .01382 L
.45831 .01419 L
.44638 .01473 L
.42243 .01625 L
.40012 .01819 L
.37618 .02087 L
.33358 .02724 L
.29345 .0353 L
.25793 .04433 L
.18383 .07038 L
.15067 .08627 L
.11802 .1057 L
.09173 .12533 L
.07052 .14525 L
.05477 .16406 L
.04132 .18535 L
.03544 .19777 L
.03125 .20916 L
.0294 .21552 L
.02778 .22242 L
.02661 .22896 L
.02584 .23498 L
.0254 .24059 L
.02522 .24582 L
.02528 .25156 L
.02565 .2577 L
.02595 .26079 L
.02637 .26414 L
.02736 .27021 L
.02862 .2761 L
.03003 .28152 L
.03372 .2926 L
.03798 .30264 L
.05067 .32475 L
.06614 .34447 L
.08402 .36238 L
.13432 .39878 L
.16854 .41683 L
.20359 .43177 L
.24056 .44458 L
.28315 .45636 L
.32543 .46543 L
.36576 .47199 L
.40311 .47642 L
.42461 .4783 L
.44482 .47963 L
.45582 .48019 L
.46626 .4806 L
.47565 .48088 L
Mistroke
.48588 .48109 L
.497 .4812 L
.50261 .48121 L
.50881 .48118 L
.51976 .48105 L
.53003 .48081 L
.54049 .48046 L
.55164 .47997 L
.57168 .47877 L
.59534 .47683 L
.61665 .47457 L
.66218 .46803 L
.70376 .45984 L
.77268 .44066 L
.80838 .42727 L
.8389 .41336 L
.86712 .39787 L
.89424 .37972 L
.91477 .3629 L
.9339 .34351 L
.94376 .33128 L
.95169 .31967 L
.95866 .30741 L
.96384 .29613 L
.96789 .2849 L
.97074 .27423 L
.9719 .26834 L
.97271 .2629 L
.97333 .25693 L
.97353 .25392 L
.97366 .25062 L
.97367 .24453 L
.97341 .23891 L
.97317 .23597 L
.97282 .23274 L
.97186 .22621 L
.97073 .2205 L
.96921 .21437 L
.96567 .20336 L
.9612 .19264 L
.95547 .18152 L
.94261 .16211 L
.92359 .14049 L
.90217 .1215 L
.875 .10221 L
.84141 .08317 L
.80525 .06675 L
.76908 .05346 L
.73301 .04266 L
.69129 .0327 L
Mistroke
.65234 .0255 L
.6149 .02028 L
.59389 .01803 L
.57455 .01636 L
.56381 .0156 L
.55208 .0149 L
.54091 .01437 L
.53065 .01399 L
.52056 .01371 L
.50991 .01353 L
.49922 .01346 L
.48751 .01351 L
.47736 .01367 L
.46652 .01394 L
.45631 .01431 L
.44703 .01473 L
.4244 .01613 L
.40003 .01823 L
.37724 .02076 L
.35646 .02357 L
.31563 .03059 L
.27239 .04042 L
.2296 .05299 L
.19217 .06683 L
.15934 .08176 L
.12693 .0999 L
.1016 .11737 L
.07825 .13736 L
.05909 .15834 L
.04528 .17821 L
.03987 .18804 L
.03495 .19882 L
.0312 .20915 L
.02857 .21864 L
.02736 .22427 L
.02646 .22962 L
.02576 .23527 L
.02549 .23847 L
.02531 .24143 L
.02517 .24635 L
.02524 .25178 L
.02558 .25745 L
.02614 .26276 L
.02703 .26866 L
.02828 .27487 L
.03131 .28589 L
.03569 .29764 L
.0418 .31031 L
.05681 .33331 L
.07785 .3567 L
Mistroke
.10218 .37742 L
.12781 .39491 L
.15665 .41107 L
.19028 .42652 L
.25748 .44967 L
.29803 .45989 L
.33761 .46767 L
.38248 .47421 L
.40817 .47695 L
.43189 .47887 L
.44333 .47959 L
.45413 .48015 L
.46385 .48055 L
.47436 .48089 L
.48588 .48113 L
.49168 .4812 L
.49804 .48124 L
.5093 .48121 L
.5198 .48108 L
.53041 .48083 L
.54043 .48049 L
.54941 .4801 L
.55914 .47959 L
.58089 .4781 L
.60083 .47631 L
.64223 .4712 L
.68658 .4635 L
.731 .45316 L
.77046 .44139 L
.83847 .41355 L
.86837 .39708 L
.8973 .37737 L
.91875 .35918 L
.93798 .33863 L
.95247 .31835 L
.96243 .29936 L
.96657 .2888 L
.97003 .27709 L
.97134 .27116 L
.97194 .26788 L
.97242 .26477 L
.97314 .25874 L
.97352 .25322 L
.97366 .24806 L
.97357 .24256 L
.97329 .23787 L
.97278 .2327 L
.97199 .22718 L
.97085 .22124 L
.96805 .21053 L
Mistroke
.96395 .19904 L
.95819 .18662 L
.94267 .16226 L
.92377 .14073 L
.90247 .12179 L
.87649 .10322 L
.84444 .08476 L
.81313 .07008 L
.77718 .05625 L
.74264 .04537 L
.70256 .03519 L
.66456 .0276 L
.6279 .02195 L
.60706 .01942 L
.58464 .01721 L
.57164 .01617 L
.55982 .01537 L
.54776 .01471 L
.53664 .01422 L
.52605 .01387 L
.51486 .01362 L
.50361 .0135 L
.49723 .01348 L
.49127 .0135 L
.48047 .01363 L
.47064 .01384 L
.45931 .01421 L
.4486 .01467 L
.42876 .01583 L
.40784 .0175 L
.37071 .0216 L
.33165 .02759 L
.28996 .0361 L
.25116 .04626 L
.2126 .05889 L
.15062 .08624 L
.12057 .10394 L
.09589 .12182 L
.07272 .14284 L
.0528 .16665 L
.04537 .17802 L
.03874 .19026 L
.03405 .201 L
.03011 .21265 L
.02839 .21924 L
.02714 .22528 L
.02619 .23136 L
.02556 .23714 L
.02533 .2404 L
.02518 .24386 L
Mistroke
.02513 .24713 L
.02516 .25009 L
.02529 .25358 L
.02554 .25735 L
.02589 .26091 L
.02629 .26417 L
.02717 .26959 L
.02837 .27537 L
.03123 .28574 L
.03579 .29795 L
.04102 .30891 L
.05589 .33215 L
.0742 .35315 L
.09444 .37139 L
.12034 .39021 L
.14896 .4071 L
.18314 .42353 L
.21789 .43714 L
.25182 .44807 L
.28855 .45774 L
.32323 .4651 L
.36345 .47174 L
.38448 .47447 L
.40749 .47691 L
.42905 .47869 L
.43855 .47932 L
.44902 .47992 L
.45826 .48035 L
.46819 .48072 L
.47869 .48101 L
.48851 .48118 L
.4945 .48123 L
.50086 .48126 L
.5123 .4812 L
.51865 .48111 L
.5246 .48099 L
.53113 .48082 L
.53816 .48058 L
.55008 .48008 L
.56259 .4794 L
.58487 .47778 L
.60628 .47575 L
.62602 .47343 L
.66996 .46667 L
.71141 .45806 L
.75426 .44654 L
.78987 .43453 L
.82498 .41999 L
.85405 .40536 L
.88293 .3877 L
Mistroke
.92493 .35309 L
.94379 .33114 L
.95145 .31994 L
.95757 .30937 L
.96262 .29888 L
.96638 .28926 L
.96965 .27849 L
.97104 .27255 L
.97207 .26694 L
.97285 .2613 L
.97317 .2581 L
.9734 .25511 L
.97363 .24908 L
.97363 .24569 L
.97355 .24261 L
.97321 .23711 L
.97256 .23114 L
.97168 .22551 L
.97063 .22032 L
.96749 .20882 L
.96276 .19627 L
.95643 .18336 L
.9492 .17147 L
.93374 .15138 L
.91281 .13049 L
.88859 .11141 L
.85887 .0926 L
.82758 .07653 L
.79663 .0634 L
.73017 .04197 L
.69115 .03273 L
.64821 .0249 L
.61048 .01982 L
.58871 .01759 L
.56819 .01594 L
.55677 .0152 L
.54431 .01455 L
.53251 .01408 L
.52156 .01377 L
.51172 .01358 L
.50084 .01349 L
.48948 .01352 L
.4788 .01366 L
.46707 .01395 L
.46118 .01414 L
.45473 .0144 L
.43273 .01557 L
.42037 .01645 L
.40721 .01756 L
.38367 .01999 L
Mistroke
.33815 .02647 L
.29748 .03439 L
.25476 .04521 L
.21217 .05904 L
.14825 .08749 L
.1169 .10636 L
.09127 .1256 L
.07006 .14561 L
.05136 .16867 L
.04443 .17956 L
.03819 .19137 L
.03342 .2026 L
.02999 .21303 L
.0286 .21831 L
.02734 .22412 L
.02636 .22998 L
.02594 .23319 L
.02563 .23619 L
.02525 .24172 L
.02512 .24677 L
.02523 .25259 L
.02559 .2581 L
.02613 .26304 L
.02691 .26827 L
.02889 .27762 L
.03183 .28762 L
.03603 .29855 L
.04771 .32043 L
.06437 .3426 L
.08198 .36066 L
.10463 .37931 L
.13285 .39803 L
.16693 .41619 L
.23721 .44364 L
.27839 .45529 L
.31827 .46416 L
.36375 .4718 L
.38722 .4748 L
.41335 .47745 L
.4252 .47842 L
.43649 .4792 L
.44679 .47981 L
.45777 .48034 L
.46402 .48058 L
.46969 .48078 L
.48076 .48106 L
.48698 .48116 L
.4937 .48123 L
.50004 .48126 L
.50587 .48125 L
Mistroke
.51632 .48115 L
.52605 .48096 L
.53672 .48064 L
.54813 .48017 L
.56007 .47955 L
.57133 .47883 L
.59231 .47713 L
.63235 .47259 L
.67538 .46567 L
.71866 .45631 L
.75732 .44559 L
.82067 .42193 L
.85245 .40622 L
.87879 .39045 L
.90319 .3727 L
.92554 .35245 L
.94293 .33228 L
.95544 .31324 L
.96154 .30128 L
.96607 .29012 L
.96983 .27774 L
.97124 .27147 L
.9719 .26792 L
.97242 .26455 L
.97313 .25846 L
.97351 .2529 L
.97363 .24691 L
.97357 .24352 L
.97343 .24039 L
.97302 .23519 L
.97231 .22946 L
.97128 .22349 L
.97005 .2179 L
.9668 .20677 L
.96285 .1965 L
.95063 .17368 L
.9345 .15227 L
.91285 .13055 L
.8888 .11157 L
.86288 .09492 L
.80684 .06749 L
.77398 .05519 L
.73547 .04341 L
.69302 .03314 L
.65158 .02544 L
.63125 .02243 L
.61171 .01996 L
.59378 .01807 L
.57453 .01641 L
.56354 .01563 L
Mistroke
.55355 .01503 L
.54337 .01452 L
.534 .01414 L
.523 .01381 L
.51721 .01368 L
.5111 .01358 L
.5008 .0135 L
.48951 .01352 L
.47784 .01368 L
.46706 .01395 L
.46144 .01414 L
.45525 .01438 L
.44274 .01498 L
.42005 .01647 L
.39893 .01835 L
.3601 .02304 L
.31934 .02986 L
.27609 .03945 L
.23293 .05187 L
.19513 .06559 L
.16335 .07972 L
.10798 .11257 L
.08296 .13287 L
.06322 .15325 L
.04844 .17303 L
.03795 .19186 L
.03368 .20189 L
.02998 .21303 L
.0285 .21867 L
.02721 .22475 L
.02628 .2305 L
.02566 .23576 L
.02524 .24178 L
.02511 .24745 L
.02522 .25254 L
.02557 .25803 L
.02625 .26403 L
.0267 .26705 L
.02728 .27034 L
.02994 .28158 L
.03339 .29204 L
.03809 .30312 L
.04915 .32267 L
.06776 .34643 L
.08988 .36765 L
.11309 .38537 L
.1422 .40343 L
.20556 .43265 L
.24448 .44591 L
.2832 .45648 L
Mistroke
.32028 .46456 L
.35671 .47078 L
.3772 .4736 L
.39983 .47617 L
.42069 .47807 L
.44002 .47943 L
.45103 .48003 L
.46269 .48054 L
.47441 .48091 L
.48108 .48107 L
.4873 .48117 L
.49858 .48126 L
.50887 .48123 L
.51456 .48117 L
.52074 .48107 L
.53197 .4808 L
.54195 .48044 L
.55294 .47994 L
.5751 .47855 L
.59549 .47683 L
.61449 .47483 L
.6596 .46846 L
.69967 .46073 L
.74181 .45018 L
.78363 .43679 L
.84774 .40875 L
.87882 .39042 L
.90367 .3723 L
.92375 .35426 L
.94188 .33364 L
.95538 .31334 L
.96459 .29406 L
.96842 .28289 L
.97101 .2726 L
.97206 .26689 L
.97251 .26387 L
.9729 .26066 L
.9734 .25476 L
.97361 .24929 L
.97357 .2438 L
.97325 .23788 L
.97269 .2323 L
.97195 .22718 L
.97109 .22255 L
.96994 .2175 L
.96699 .20735 L
.96223 .1951 L
.9568 .18409 L
.94091 .16004 L
.92175 .1388 L
Mistroke
.89991 .11983 L
.84631 .08579 L
.81476 .07082 L
.77692 .0562 L
.74251 .04538 L
.70351 .03544 L
.66512 .02773 L
.62889 .02211 L
.60772 .01951 L
.58755 .01749 L
.56411 .01567 L
.55371 .01504 L
.5427 .01449 L
.53301 .01411 L
.52236 .01379 L
.51267 .0136 L
.5036 .01351 L
.49291 .0135 L
.48315 .01359 L
.4719 .01382 L
.46124 .01414 L
.45069 .01458 L
.43906 .01518 L
.41562 .01683 L
.39407 .01884 L
.37401 .02117 L
.32979 .02791 L
.28382 .03754 L
.24515 .04803 L
.21106 .05944 L
.17334 .07498 L
.14203 .0909 L
.1144 .10804 L
.0882 .1282 L
.06512 .15104 L
.04793 .17382 L
.04179 .18424 L
.03624 .19561 L
.03234 .20556 L
.02903 .21651 L
.02751 .22318 L
.02643 .2294 L
.0257 .23535 L
.02541 .23868 L
.02523 .2417 L
.0251 .24742 L
.02515 .25064 L
.02526 .2536 L
.02566 .25905 L
.02635 .26479 L
Mistroke
.02737 .27085 L
.02857 .27636 L
.03217 .28867 L
.03663 .29994 L
.04183 .31048 L
.05686 .33347 L
.07833 .35726 L
.10047 .37619 L
.12433 .39281 L
.15632 .41097 L
.18877 .42596 L
.26285 .45122 L
.30526 .46151 L
.3519 .47005 L
.37396 .47318 L
.39503 .47568 L
.41437 .47754 L
.43499 .47911 L
.44574 .47976 L
.4576 .48033 L
.4684 .48074 L
.47852 .48101 L
.48464 .48113 L
.49045 .48121 L
.50136 .48126 L
.5131 .48119 L
.51973 .48109 L
.52588 .48096 L
.5362 .48066 L
.54732 .48021 L
.5674 .47909 L
.58684 .47761 L
.60458 .47592 L
.64438 .47087 L
.68524 .46375 L
.72553 .45457 L
.76055 .44457 L
.79616 .43212 L
.832 .41667 L
.86223 .40069 L
.88736 .3846 L
.92825 .34961 L
.94468 .32989 L
.95222 .31867 L
.95836 .30781 L
.96313 .29762 L
.96734 .28636 L
.96885 .28138 L
.97024 .27604 L
.97125 .27136 L
Mistroke
.97213 .2664 L
.97258 .26332 L
.97297 .25993 L
.97344 .25397 L
.97358 .25062 L
.97362 .24701 L
.97356 .24362 L
.97343 .24052 L
.97294 .23452 L
.97254 .23114 L
.97208 .22802 L
.97103 .22229 L
.96962 .21623 L
.96625 .20522 L
.96218 .19499 L
.94963 .17215 L
.93434 .15211 L
.91361 .13123 L
.88773 .11083 L
.86003 .09329 L
.80256 .06576 L
.76656 .05272 L
.73182 .04243 L
.69303 .03315 L
.65026 .02524 L
.61266 .02008 L
.59094 .0178 L
.57043 .0161 L
.55907 .01535 L
.54664 .01467 L
.53487 .01417 L
.52393 .01383 L
.51308 .01361 L
.50325 .01351 L
.49189 .01351 L
.48121 .01362 L
.4695 .01388 L
.46361 .01406 L
.45716 .0143 L
.43515 .01542 L
.42279 .01626 L
.40961 .01734 L
.38602 .01972 L
.34058 .02605 L
.29991 .03384 L
.25715 .04451 L
.21442 .05821 L
.15024 .0864 L
.11868 .10515 L
.09278 .12432 L
Mistroke
.07077 .14483 L
.054 .16492 L
.04046 .18675 L
.03499 .19856 L
.03046 .21133 L
.02767 .22238 L
.02654 .22864 L
.02579 .23442 L
.02535 .23949 L
.02512 .24507 L
.02515 .25089 L
.02543 .25633 L
.02593 .26162 L
.02663 .26663 L
.02742 .27112 L
.02848 .276 L
.03156 .28686 L
.03528 .29683 L
.04583 .31745 L
.06123 .33894 L
.07944 .35831 L
.09914 .37517 L
.15496 .41028 L
.18783 .42557 L
.22699 .44032 L
.26706 .45237 L
.30698 .46188 L
.34423 .46883 L
.38583 .47465 L
.40777 .47695 L
.43216 .47892 L
.44451 .47969 L
.45782 .48034 L
.46428 .4806 L
.47042 .4808 L
.48197 .48108 L
.49274 .48123 L
.50422 .48126 L
.51505 .48117 L
.52487 .48099 L
.53643 .48065 L
.54892 .48014 L
.56068 .47951 L
.57147 .47881 L
.61269 .47503 L
.63546 .47216 L
.65594 .46906 L
.73034 .45331 L
.76922 .44177 L
.80874 .42706 L
Mistroke
.84279 .41132 L
.87176 .39494 L
.91849 .35936 L
.93789 .33867 L
.94631 .32762 L
.95426 .31527 L
.96039 .30372 L
.96566 .29121 L
.96801 .28422 L
.96979 .27784 L
.97126 .27133 L
.9723 .26531 L
.97299 .25971 L
.97345 .25378 L
.97362 .24782 L
.97358 .24444 L
.97347 .24127 L
.97304 .23556 L
.97243 .23035 L
.97143 .22435 L
.97022 .21867 L
.96678 .20675 L
.96246 .19564 L
.95166 .17531 L
.93612 .15418 L
.91498 .13247 L
.89289 .11454 L
.86624 .09692 L
.81082 .06915 L
.77566 .05577 L
.74157 .04511 L
.70296 .03532 L
.65916 .0267 L
.63897 .02352 L
.61727 .02063 L
.59693 .01838 L
.5777 .01666 L
.55965 .01538 L
.54012 .01438 L
.52952 .01399 L
.51837 .0137 L
.50883 .01355 L
.49841 .01349 L
.49266 .0135 L
.48657 .01355 L
.47568 .01373 L
.46396 .01405 L
.45732 .01429 L
.45112 .01456 L
.42973 .01577 L
Mistroke
.40693 .01758 L
.38501 .01984 L
.36446 .02243 L
.32664 .02848 L
.28394 .03751 L
.24618 .04771 L
.20739 .0608 L
.16872 .07713 L
.13766 .09338 L
.11202 .10968 L
.07053 .14508 L
.05367 .16538 L
.03956 .18852 L
.03422 .20048 L
.0318 .20712 L
.02985 .21342 L
.02834 .21932 L
.02702 .22575 L
.02612 .2316 L
.02554 .23701 L
.02518 .24282 L
.0251 .24834 L
.02524 .2533 L
.02563 .2587 L
.02631 .26455 L
.02682 .26781 L
.02735 .27076 L
.03002 .28187 L
.03341 .29212 L
.03806 .30308 L
.04905 .32254 L
.0663 .34483 L
.08921 .36709 L
.11479 .38655 L
.14133 .40296 L
.2031 .43172 L
.2412 .44491 L
.27953 .45559 L
.31407 .46334 L
.35198 .47006 L
.37218 .47295 L
.39474 .47565 L
.41556 .47765 L
.43507 .47912 L
.45594 .48026 L
.46701 .48069 L
.47317 .48088 L
.47885 .48102 L
.48484 .48113 L
.49132 .48122 L
Mistroke
.50309 .48126 L
.51379 .48118 L
.52511 .48098 L
.53491 .4807 L
.54541 .4803 L
.56433 .47929 L
.58669 .47763 L
.60696 .47567 L
.65108 .46984 L
.69762 .46117 L
.73964 .45078 L
.77654 .43929 L
.80576 .42829 L
Mfstroke
.92124 .35712 m
.93902 .33789 L
.95244 .31917 L
.96355 .29791 L
.96806 .28575 L
.97109 .27457 L
.97224 .26884 L
.97316 .26274 L
.9737 .25753 L
.97404 .25178 L
.97411 .24561 L
.97401 .24214 L
.97383 .23896 L
.97326 .23281 L
.97242 .22697 L
.9714 .22159 L
.97005 .21586 L
.96695 .20561 L
.96214 .19354 L
.95673 .18274 L
.94084 .15885 L
.92194 .13786 L
.89672 .11617 L
.86533 .09505 L
.80274 .06429 L
.7625 .04976 L
.72237 .03825 L
.68149 .02902 L
.65926 .02494 L
.63524 .02121 L
.61399 .01847 L
.59028 .01599 L
.56851 .01424 L
.5587 .01361 L
.54795 .01304 L
.53812 .01261 L
.52761 .01227 L
.51649 .01202 L
.50614 .01191 L
.49579 .01189 L
.48602 .01198 L
.47725 .01214 L
.46776 .0124 L
.45737 .01279 L
.44597 .01334 L
.42302 .01485 L
.40192 .01673 L
.38236 .0189 L
.33948 .02516 L
.29433 .03421 L
Mistroke
.25361 .04485 L
.21788 .05648 L
.15681 .08285 L
.1269 .0999 L
.10276 .11663 L
.08012 .13588 L
.06025 .15737 L
.04672 .17651 L
.04052 .18756 L
.03564 .19815 L
.03116 .21057 L
.02821 .22198 L
.02704 .22839 L
.02625 .23433 L
.02596 .23743 L
.02572 .24085 L
.02558 .24442 L
.02555 .24777 L
.0257 .25347 L
.02615 .25945 L
.02677 .26455 L
.02769 .27011 L
.02897 .2761 L
.03067 .28246 L
.03458 .29383 L
.03977 .30545 L
.04649 .31753 L
.06167 .33854 L
.0823 .36005 L
.10982 .38211 L
.1374 .39966 L
.17057 .41679 L
.23861 .44285 L
.27915 .4542 L
.31856 .46292 L
.36347 .47046 L
.38669 .47346 L
.41267 .47613 L
.43548 .4779 L
.45655 .47907 L
.46763 .47952 L
.47399 .47972 L
.47978 .47986 L
.48591 .47999 L
.49247 .48007 L
.49856 .48012 L
.50431 .48013 L
.51479 .48006 L
.5259 .47988 L
.53537 .47962 L
Mistroke
.54578 .47924 L
.55694 .47872 L
.56891 .47801 L
.59043 .47638 L
.61253 .4742 L
.63583 .47133 L
.67687 .46473 L
.72383 .45453 L
.76422 .44308 L
.8002 .43036 L
.83618 .41462 L
.86681 .3981 L
.89238 .38124 L
.91602 .36203 L
.93429 .34345 L
.9507 .32178 L
.95793 .30947 L
.96357 .29762 L
.96788 .28599 L
.96977 .27957 L
.97122 .27352 L
.9723 .26793 L
.97305 .26279 L
.97364 .25708 L
.97397 .25092 L
.97402 .24793 L
.974 .24474 L
.97374 .23899 L
.97345 .23547 L
.97308 .23216 L
.97215 .22597 L
.97083 .21944 L
.9693 .21345 L
.96475 .20001 L
.95981 .18892 L
.9544 .17893 L
.93915 .15704 L
.92136 .13765 L
.90136 .12018 L
.84657 .08507 L
.81008 .06794 L
.7732 .05399 L
.73436 .04215 L
.69006 .03156 L
.64641 .02368 L
.62516 .02067 L
.60512 .0183 L
.58522 .01637 L
.56699 .01497 L
.54662 .0138 L
Mistroke
.53538 .01333 L
.52473 .01301 L
.51438 .0128 L
.50339 .0127 L
.49401 .0127 L
.48368 .01281 L
.4726 .01304 L
.46638 .01322 L
.46069 .01342 L
.43923 .01448 L
.42782 .01523 L
.4171 .01605 L
.39718 .01791 L
.35321 .02355 L
.31622 .03005 L
.27758 .03877 L
.23693 .05039 L
.19673 .06487 L
.16205 .0804 L
.13325 .09612 L
.0848 .13153 L
.06384 .15295 L
.04802 .17426 L
.04227 .18405 L
.03706 .19459 L
.03332 .2038 L
.0301 .21382 L
.02867 .21944 L
.02758 .2246 L
.02675 .22955 L
.0261 .23478 L
.02564 .24052 L
.02545 .24587 L
.02552 .25174 L
.02568 .25502 L
.02591 .258 L
.02652 .26351 L
.02731 .26866 L
.02844 .27428 L
.02994 .28031 L
.03394 .2925 L
.03867 .30351 L
.05067 .32425 L
.06546 .34323 L
.08641 .36405 L
.10941 .38217 L
.13809 .40046 L
.17298 .41836 L
.21067 .43387 L
.24801 .44627 L
Mistroke
.28503 .45622 L
.32751 .46522 L
.36709 .47158 L
.4049 .47601 L
.42607 .47784 L
.44549 .47912 L
.45627 .47966 L
.46801 .48012 L
.47912 .48044 L
.4894 .48062 L
.49992 .4807 L
.51099 .48067 L
.52044 .48054 L
.53076 .48031 L
.5419 .47994 L
.55378 .47941 L
.57507 .4781 L
.59649 .47632 L
.61652 .47421 L
.65341 .46916 L
.69628 .46123 L
.73423 .45213 L
.7735 .44027 L
.81282 .42537 L
.84586 .40984 L
.87324 .39418 L
.91831 .35984 L
.93808 .33883 L
.94685 .32732 L
.95486 .31479 L
.96072 .30369 L
.96596 .29124 L
.96784 .28574 L
.96959 .27978 L
.97095 .27421 L
.972 .26894 L
.97289 .26312 L
.97346 .25782 L
.97381 .2521 L
.9739 .24888 L
.9739 .2459 L
.97374 .24094 L
.97333 .23548 L
.97264 .22978 L
.97175 .22446 L
.97041 .21821 L
.96884 .2123 L
.9651 .20127 L
.95996 .18954 L
.95303 .17694 L
Mistroke
.93647 .15406 L
.91385 .13095 L
.88808 .11058 L
.86128 .0935 L
.83113 .07771 L
.79626 .06276 L
.72717 .04067 L
.68567 .0311 L
.64542 .02398 L
.62221 .02075 L
.59995 .01821 L
.57402 .01591 L
.56256 .01512 L
.55018 .01441 L
.53918 .01391 L
.52907 .01355 L
.5194 .01331 L
.50921 .01315 L
.498 .0131 L
.48756 .01316 L
.47612 .01335 L
.46973 .01351 L
.46392 .0137 L
.45217 .01417 L
.44137 .01472 L
.41707 .01641 L
.39582 .01839 L
.37355 .02098 L
.33485 .02684 L
.29969 .03376 L
.22462 .05461 L
.1892 .06806 L
.15372 .08468 L
.12545 .10093 L
.09876 .11972 L
.07606 .1397 L
.05892 .1588 L
.04512 .1788 L
.0354 .19819 L
.03136 .20921 L
.02852 .21957 L
.0273 .22555 L
.02644 .231 L
.02607 .23403 L
.02575 .23731 L
.0254 .24328 L
.02534 .24904 L
.02543 .25231 L
.0256 .25538 L
.02585 .2586 L
Mistroke
.02616 .26154 L
.02712 .26817 L
.02821 .27377 L
.0297 .27986 L
.03321 .29089 L
.03776 .30186 L
.04276 .31168 L
.05695 .33316 L
.07364 .35224 L
.09237 .36935 L
.14446 .40431 L
.17536 .41974 L
.21246 .43483 L
.24645 .44612 L
.28495 .45653 L
.32012 .46415 L
.35876 .47072 L
.38029 .47363 L
.40436 .47629 L
.42647 .47819 L
.44738 .47953 L
.45937 .48011 L
.46593 .48036 L
.47204 .48056 L
.48286 .48082 L
.4886 .48091 L
.49473 .48097 L
.50134 .48099 L
.50851 .48097 L
.51529 .48091 L
.52154 .48081 L
.52716 .48068 L
.53336 .48051 L
.54586 .48005 L
.55776 .47946 L
.56904 .47877 L
.5901 .47714 L
.61257 .47488 L
.63681 .47183 L
.6794 .4648 L
.71755 .45652 L
.75713 .44564 L
.79731 .43171 L
.83014 .41764 L
.86181 .40106 L
.88752 .38465 L
.91225 .36525 L
.93008 .3479 L
.94616 .32813 L
.95395 .31616 L
Mistroke
.96003 .30488 L
.96474 .29417 L
.9688 .28223 L
.97018 .27705 L
.97142 .27146 L
.97229 .26661 L
.97301 .2613 L
.97353 .25562 L
.97378 .24965 L
.97376 .24411 L
.97352 .23897 L
.97294 .23287 L
.97249 .22944 L
.97198 .22628 L
.97086 .22061 L
.96932 .21439 L
.96589 .20366 L
.96123 .19244 L
.94687 .16774 L
.92878 .14564 L
.90748 .12565 L
.88009 .10533 L
.85258 .08884 L
.82015 .07289 L
.7851 .05881 L
.75118 .04762 L
.71797 .03858 L
.68003 .03023 L
.63873 .02323 L
.61724 .02037 L
.59396 .01785 L
.57192 .01598 L
.55172 .01471 L
.54196 .01424 L
.53133 .01384 L
.52128 .01357 L
.512 .0134 L
.5013 .01331 L
.48979 .01334 L
.47893 .01349 L
.469 .01373 L
.45741 .01413 L
.44479 .01472 L
.42191 .0162 L
.39825 .0183 L
.3733 .02116 L
.32933 .02793 L
.28537 .03714 L
.24676 .04755 L
.2076 .06076 L
Mistroke
.16795 .07758 L
.11043 .11095 L
.08459 .13155 L
.06441 .15206 L
.04824 .17359 L
.04094 .18613 L
.03541 .19792 L
.03156 .20832 L
.02836 .2199 L
.02717 .22575 L
.02666 .22883 L
.02621 .23207 L
.0256 .23805 L
.02531 .24354 L
.02526 .24894 L
.02542 .25384 L
.02585 .2595 L
.0265 .26484 L
.02731 .26976 L
.02824 .2743 L
.03096 .28449 L
.03457 .29469 L
.03955 .30578 L
.05276 .32767 L
.07094 .34961 L
.09214 .36932 L
.14145 .4028 L
.17388 .41923 L
.20671 .43288 L
.24514 .4459 L
.28936 .45776 L
.33471 .46703 L
.35516 .47036 L
.37791 .47351 L
.39824 .47584 L
.42022 .47787 L
.43244 .47878 L
.44361 .47948 L
.45424 .48004 L
.46554 .4805 L
.47564 .48081 L
.48678 .48103 L
.49692 .48113 L
.50643 .48113 L
.5176 .48101 L
.52783 .4808 L
.53904 .48045 L
.55081 .47995 L
.57067 .47878 L
.58903 .47735 L
Mistroke
.63014 .47283 L
.65268 .46955 L
.67312 .46605 L
.71794 .45648 L
.75561 .44613 L
.79318 .4333 L
.85174 .40668 L
.88071 .38927 L
.90462 .37165 L
.92644 .35166 L
.94572 .32864 L
.95292 .31773 L
.95944 .30593 L
.9641 .29558 L
.96811 .28428 L
.96962 .27897 L
.97096 .27336 L
.97196 .26814 L
.9727 .26327 L
.97321 .25869 L
.97357 .25379 L
.97373 .24835 L
.97367 .2434 L
.97334 .23759 L
.97279 .23223 L
.97192 .22637 L
.97069 .22017 L
.9679 .20981 L
.96381 .19851 L
.95864 .18732 L
.95179 .17529 L
.93617 .15404 L
.91719 .1343 L
.89642 .11699 L
.83913 .08196 L
.8016 .06522 L
.76465 .05194 L
.7272 .04106 L
.68563 .03147 L
.64879 .02488 L
.60725 .01934 L
.58344 .01702 L
.56155 .0154 L
.54939 .0147 L
.53612 .01412 L
.53004 .01391 L
.52357 .01373 L
.51195 .0135 L
.50135 .01341 L
.48993 .01344 L
Mistroke
.47915 .01358 L
.46928 .01381 L
.45834 .01418 L
.4464 .01472 L
.42246 .01623 L
.40014 .01818 L
.3762 .02086 L
.3336 .02722 L
.29346 .03528 L
.25794 .04431 L
.18383 .07035 L
.15067 .08624 L
.11801 .10568 L
.09171 .12531 L
.0705 .14524 L
.05475 .16404 L
.04129 .18534 L
.03542 .19777 L
.03123 .20915 L
.02938 .21552 L
.02775 .22242 L
.02658 .22896 L
.02582 .23498 L
.02538 .24059 L
.0252 .24583 L
.02526 .25157 L
.02563 .25771 L
.02593 .2608 L
.02635 .26415 L
.02734 .27022 L
.0286 .27611 L
.03001 .28153 L
.0337 .29262 L
.03796 .30265 L
.05066 .32477 L
.06613 .34449 L
.08401 .3624 L
.13432 .3988 L
.16855 .41685 L
.2036 .43179 L
.24057 .4446 L
.28316 .45637 L
.32544 .46544 L
.36578 .472 L
.40313 .47642 L
.42463 .4783 L
.44484 .47964 L
.45584 .48019 L
.46628 .4806 L
.47567 .48088 L
Mistroke
.4859 .48109 L
.49702 .4812 L
.50263 .48121 L
.50883 .48118 L
.51978 .48104 L
.53005 .4808 L
.5405 .48045 L
.55166 .47996 L
.57169 .47876 L
.59535 .47682 L
.61666 .47455 L
.66219 .46802 L
.70377 .45982 L
.77268 .44064 L
.80838 .42725 L
.83889 .41335 L
.86712 .39785 L
.89423 .3797 L
.91476 .36289 L
.93388 .3435 L
.94374 .33127 L
.95168 .31967 L
.95864 .30741 L
.96383 .29613 L
.96788 .2849 L
.97072 .27423 L
.97188 .26834 L
.9727 .26291 L
.97331 .25693 L
.97351 .25393 L
.97364 .25062 L
.97365 .24454 L
.97339 .23891 L
.97315 .23598 L
.97281 .23275 L
.97185 .22622 L
.97071 .22051 L
.96919 .21438 L
.96566 .20337 L
.96119 .19265 L
.95545 .18153 L
.9426 .16213 L
.92358 .14051 L
.90216 .12151 L
.875 .10223 L
.84141 .08318 L
.80526 .06677 L
.76909 .05347 L
.73302 .04267 L
.69131 .03271 L
Mistroke
.65236 .02551 L
.61491 .02028 L
.59391 .01803 L
.57457 .01636 L
.56383 .0156 L
.55209 .0149 L
.54093 .01437 L
.53066 .01398 L
.52057 .01371 L
.50993 .01353 L
.49923 .01346 L
.48752 .01351 L
.47738 .01366 L
.46654 .01394 L
.45632 .0143 L
.44704 .01473 L
.42441 .01612 L
.40004 .01822 L
.37725 .02075 L
.35646 .02356 L
.31564 .03058 L
.27239 .04041 L
.22961 .05298 L
.19217 .06682 L
.15934 .08175 L
.12692 .09989 L
.1016 .11736 L
.07824 .13736 L
.05908 .15834 L
.04527 .17821 L
.03986 .18804 L
.03494 .19882 L
.03119 .20915 L
.02855 .21864 L
.02735 .22427 L
.02645 .22962 L
.02575 .23528 L
.02548 .23848 L
.0253 .24144 L
.02516 .24636 L
.02523 .25179 L
.02557 .25745 L
.02612 .26276 L
.02702 .26867 L
.02827 .27487 L
.0313 .2859 L
.03568 .29764 L
.04179 .31032 L
.05681 .33332 L
.07784 .35671 L
Mistroke
.10218 .37743 L
.12781 .39493 L
.15665 .41108 L
.19028 .42653 L
.25748 .44968 L
.29804 .45989 L
.33762 .46767 L
.38249 .47421 L
.40818 .47695 L
.4319 .47887 L
.44334 .47959 L
.45414 .48015 L
.46386 .48055 L
.47437 .48088 L
.48589 .48112 L
.49169 .48119 L
.49805 .48123 L
.50931 .48121 L
.51981 .48107 L
.53042 .48082 L
.54043 .48048 L
.54942 .4801 L
.55915 .47959 L
.58089 .4781 L
.60084 .4763 L
.64224 .47119 L
.68659 .46349 L
.73101 .45315 L
.77046 .44138 L
.83847 .41354 L
.86836 .39707 L
.89729 .37736 L
.91874 .35917 L
.93797 .33863 L
.95246 .31835 L
.96243 .29936 L
.96656 .2888 L
.97002 .27709 L
.97133 .27116 L
.97193 .26789 L
.97241 .26478 L
.97313 .25874 L
.97352 .25323 L
.97365 .24806 L
.97356 .24256 L
.97329 .23788 L
.97277 .23271 L
.97198 .22718 L
.97084 .22124 L
.96805 .21054 L
Mistroke
.96394 .19904 L
.95819 .18662 L
.94266 .16226 L
.92377 .14074 L
.90246 .1218 L
.87649 .10323 L
.84444 .08477 L
.81314 .07009 L
.77719 .05626 L
.74264 .04538 L
.70257 .0352 L
.66457 .0276 L
.6279 .02195 L
.60707 .01942 L
.58465 .01721 L
.57165 .01617 L
.55983 .01537 L
.54777 .01471 L
.53665 .01422 L
.52606 .01387 L
.51486 .01362 L
.50362 .01349 L
.49723 .01348 L
.49128 .0135 L
.48048 .01362 L
.47065 .01384 L
.45931 .0142 L
.4486 .01467 L
.42877 .01583 L
.40784 .01749 L
.37072 .02159 L
.33165 .02759 L
.28996 .03609 L
.25117 .04625 L
.2126 .05889 L
.15062 .08623 L
.12056 .10394 L
.09588 .12182 L
.07271 .14284 L
.05279 .16665 L
.04536 .17802 L
.03873 .19026 L
.03405 .201 L
.0301 .21265 L
.02839 .21924 L
.02714 .22528 L
.02618 .23136 L
.02556 .23714 L
.02533 .2404 L
.02518 .24386 L
Mistroke
.02513 .24713 L
.02516 .25009 L
.02529 .25359 L
.02554 .25736 L
.02588 .26092 L
.02629 .26418 L
.02716 .2696 L
.02836 .27538 L
.03122 .28575 L
.03579 .29795 L
.04102 .30891 L
.05589 .33215 L
.0742 .35315 L
.09444 .3714 L
.12034 .39022 L
.14896 .4071 L
.18314 .42354 L
.21789 .43715 L
.25182 .44808 L
.28855 .45774 L
.32324 .4651 L
.36346 .47174 L
.38448 .47447 L
.40749 .47691 L
.42905 .47869 L
.43856 .47932 L
.44902 .47992 L
.45827 .48035 L
.4682 .48072 L
.4787 .48101 L
.48851 .48117 L
.4945 .48123 L
.50087 .48125 L
.51231 .48119 L
.51865 .4811 L
.52461 .48098 L
.53113 .48081 L
.53817 .48058 L
.55008 .48008 L
.5626 .47939 L
.58487 .47778 L
.60628 .47574 L
.62602 .47342 L
.66996 .46666 L
.71141 .45806 L
.75426 .44653 L
.78986 .43452 L
.82498 .41998 L
.85405 .40535 L
.88292 .38769 L
Mistroke
.92492 .35309 L
.94379 .33114 L
.95145 .31994 L
.95757 .30937 L
.96262 .29888 L
.96638 .28927 L
.96965 .27849 L
.97103 .27255 L
.97207 .26694 L
.97284 .2613 L
.97317 .2581 L
.97339 .25511 L
.97363 .24908 L
.97363 .2457 L
.97355 .24262 L
.97321 .23711 L
.97256 .23114 L
.97167 .22551 L
.97062 .22032 L
.96749 .20882 L
.96276 .19628 L
.95642 .18337 L
.9492 .17148 L
.93374 .15138 L
.91281 .1305 L
.88859 .11141 L
.85887 .09261 L
.82758 .07654 L
.79663 .0634 L
.73017 .04197 L
.69116 .03274 L
.64822 .0249 L
.61048 .01982 L
.58871 .01758 L
.56819 .01593 L
.55678 .0152 L
.54431 .01455 L
.53251 .01408 L
.52157 .01376 L
.51173 .01358 L
.50085 .01349 L
.48948 .01352 L
.47881 .01366 L
.46708 .01395 L
.46118 .01414 L
.45473 .01439 L
.43273 .01557 L
.42037 .01645 L
.40721 .01755 L
.38368 .01999 L
Mistroke
.33815 .02646 L
.29748 .03438 L
.25476 .0452 L
.21217 .05904 L
.14825 .08749 L
.1169 .10635 L
.09126 .1256 L
.07005 .14561 L
.05136 .16867 L
.04443 .17956 L
.03818 .19138 L
.03342 .2026 L
.02998 .21303 L
.02859 .21831 L
.02734 .22413 L
.02636 .22999 L
.02594 .23319 L
.02563 .23619 L
.02525 .24172 L
.02512 .24677 L
.02523 .25259 L
.02559 .2581 L
.02612 .26304 L
.02691 .26827 L
.02889 .27762 L
.03183 .28762 L
.03603 .29856 L
.04771 .32044 L
.06436 .34261 L
.08198 .36066 L
.10463 .37932 L
.13285 .39803 L
.16693 .41619 L
.23721 .44364 L
.27839 .45529 L
.31827 .46416 L
.36376 .4718 L
.38722 .4748 L
.41335 .47745 L
.42521 .47841 L
.4365 .4792 L
.44679 .47981 L
.45777 .48034 L
.46402 .48058 L
.46969 .48077 L
.48076 .48106 L
.48698 .48116 L
.4937 .48123 L
.50004 .48126 L
.50587 .48125 L
Mistroke
.51632 .48115 L
.52606 .48095 L
.53673 .48064 L
.54813 .48017 L
.56007 .47955 L
.57133 .47882 L
.59231 .47713 L
.63235 .47259 L
.67538 .46566 L
.71866 .4563 L
.75732 .44559 L
.82066 .42193 L
.85245 .40622 L
.87879 .39044 L
.90319 .3727 L
.92554 .35245 L
.94292 .33228 L
.95544 .31324 L
.96154 .30128 L
.96607 .29012 L
.96983 .27774 L
.97124 .27147 L
.97189 .26792 L
.97242 .26456 L
.97312 .25846 L
.9735 .2529 L
.97363 .24691 L
.97357 .24352 L
.97343 .24039 L
.97302 .23519 L
.97231 .22946 L
.97128 .22349 L
.97005 .2179 L
.9668 .20677 L
.96285 .1965 L
.95063 .17368 L
.9345 .15227 L
.91286 .13055 L
.8888 .11157 L
.86288 .09493 L
.80684 .06749 L
.77398 .05519 L
.73548 .04341 L
.69302 .03314 L
.65158 .02544 L
.63125 .02243 L
.61171 .01996 L
.59378 .01807 L
.57453 .0164 L
.56354 .01563 L
Mistroke
.55356 .01503 L
.54338 .01452 L
.534 .01414 L
.523 .0138 L
.51721 .01368 L
.5111 .01358 L
.5008 .01349 L
.48951 .01352 L
.47784 .01368 L
.46706 .01395 L
.46144 .01413 L
.45525 .01437 L
.44274 .01498 L
.42005 .01647 L
.39893 .01834 L
.3601 .02304 L
.31934 .02986 L
.27609 .03945 L
.23293 .05186 L
.19513 .06558 L
.16335 .07972 L
.10798 .11257 L
.08296 .13287 L
.06321 .15325 L
.04844 .17303 L
.03794 .19186 L
.03368 .20189 L
.02997 .21303 L
.0285 .21867 L
.02721 .22475 L
.02628 .2305 L
.02566 .23576 L
.02523 .24179 L
.02511 .24745 L
.02522 .25254 L
.02557 .25803 L
.02625 .26403 L
.0267 .26705 L
.02728 .27035 L
.02994 .28158 L
.03339 .29205 L
.03809 .30312 L
.04915 .32267 L
.06776 .34643 L
.08988 .36765 L
.11309 .38537 L
.1422 .40344 L
.20556 .43265 L
.24448 .44591 L
.2832 .45648 L
Mistroke
.32028 .46456 L
.35672 .47078 L
.3772 .4736 L
.39983 .47617 L
.42069 .47807 L
.44002 .47942 L
.45103 .48003 L
.46269 .48054 L
.47442 .48091 L
.48108 .48106 L
.4873 .48117 L
.49858 .48126 L
.50887 .48123 L
.51456 .48117 L
.52074 .48107 L
.53197 .48079 L
.54195 .48044 L
.55294 .47994 L
.5751 .47855 L
.59549 .47683 L
.61449 .47483 L
.6596 .46846 L
.69967 .46073 L
.74181 .45018 L
.78363 .43679 L
.84774 .40875 L
.87881 .39042 L
.90367 .3723 L
.92374 .35426 L
.94188 .33364 L
.95538 .31334 L
.96458 .29406 L
.96842 .28289 L
.97101 .2726 L
.97206 .26689 L
.9725 .26387 L
.9729 .26066 L
.9734 .25476 L
.97361 .24929 L
.97357 .2438 L
.97325 .23788 L
.97269 .2323 L
.97194 .22718 L
.97109 .22256 L
.96994 .2175 L
.96699 .20735 L
.96223 .1951 L
.9568 .18409 L
.94091 .16004 L
.92175 .1388 L
Mistroke
.89991 .11983 L
.84631 .08579 L
.81476 .07082 L
.77692 .0562 L
.74251 .04538 L
.70351 .03544 L
.66513 .02773 L
.62889 .02211 L
.60772 .01951 L
.58755 .01749 L
.56411 .01567 L
.55371 .01504 L
.5427 .01449 L
.53302 .0141 L
.52236 .01379 L
.51267 .0136 L
.5036 .01351 L
.49291 .0135 L
.48315 .01359 L
.4719 .01382 L
.46124 .01414 L
.45069 .01458 L
.43906 .01518 L
.41562 .01683 L
.39407 .01884 L
.37401 .02117 L
.32979 .02791 L
.28382 .03754 L
.24515 .04803 L
.21106 .05943 L
.17334 .07498 L
.14203 .0909 L
.1144 .10804 L
.0882 .1282 L
.06512 .15104 L
.04793 .17382 L
.04179 .18424 L
.03624 .19561 L
.03234 .20556 L
.02903 .21651 L
.02751 .22318 L
.02643 .2294 L
.0257 .23535 L
.02541 .23868 L
.02523 .2417 L
.0251 .24742 L
.02515 .25064 L
.02526 .2536 L
.02566 .25905 L
.02635 .26479 L
Mistroke
.02737 .27085 L
.02857 .27636 L
.03217 .28867 L
.03663 .29994 L
.04183 .31049 L
.05686 .33347 L
.07833 .35726 L
.10047 .37619 L
.12433 .39282 L
.15632 .41097 L
.18877 .42596 L
.26285 .45122 L
.30526 .46151 L
.3519 .47005 L
.37396 .47318 L
.39503 .47567 L
.41437 .47754 L
.43499 .47911 L
.44574 .47976 L
.4576 .48033 L
.4684 .48074 L
.47852 .48101 L
.48464 .48113 L
.49045 .48121 L
.50136 .48126 L
.5131 .48119 L
.51973 .48109 L
.52588 .48096 L
.5362 .48066 L
.54732 .48021 L
.5674 .47909 L
.58685 .47761 L
.60458 .47592 L
.64438 .47087 L
.68524 .46375 L
.72553 .45457 L
.76055 .44457 L
.79616 .43212 L
.832 .41667 L
.86223 .40069 L
.88736 .3846 L
.92825 .34961 L
.94468 .32989 L
.95222 .31867 L
.95836 .30782 L
.96313 .29762 L
.96734 .28636 L
.96885 .28138 L
.97024 .27604 L
.97125 .27136 L
Mistroke
.97213 .2664 L
.97258 .26332 L
.97297 .25993 L
.97344 .25398 L
.97358 .25062 L
.97362 .24702 L
.97356 .24362 L
.97343 .24052 L
.97294 .23452 L
.97254 .23114 L
.97208 .22802 L
.97103 .22229 L
.96962 .21623 L
.96625 .20523 L
.96218 .19499 L
.94963 .17215 L
.93434 .15211 L
.91361 .13123 L
.88773 .11083 L
.86003 .09329 L
.80256 .06576 L
.76656 .05272 L
.73182 .04243 L
.69303 .03315 L
.65026 .02524 L
.61266 .02008 L
.59094 .0178 L
.57043 .0161 L
.55907 .01535 L
.54664 .01467 L
.53487 .01417 L
.52393 .01383 L
.51308 .01361 L
.50325 .01351 L
.49189 .01351 L
.48121 .01362 L
.4695 .01388 L
.46361 .01406 L
.45716 .0143 L
.43515 .01542 L
.42279 .01626 L
.40961 .01734 L
.38602 .01972 L
.34058 .02605 L
.29991 .03384 L
.25715 .04451 L
.21442 .05821 L
.15024 .0864 L
.11868 .10515 L
.09278 .12432 L
Mistroke
.07077 .14483 L
.054 .16493 L
.04046 .18675 L
.03499 .19856 L
.03046 .21133 L
.02767 .22238 L
.02654 .22865 L
.02579 .23443 L
.02535 .2395 L
.02512 .24507 L
.02515 .25089 L
.02543 .25633 L
.02593 .26162 L
.02663 .26664 L
.02742 .27112 L
.02848 .276 L
.03156 .28687 L
.03528 .29684 L
.04583 .31745 L
.06123 .33894 L
.07944 .35831 L
.09914 .37517 L
.15496 .41028 L
.18783 .42557 L
.227 .44032 L
.26707 .45237 L
.30699 .46188 L
.34423 .46883 L
.38583 .47465 L
.40777 .47695 L
.43216 .47892 L
.44451 .47969 L
.45782 .48034 L
.46428 .4806 L
.47042 .4808 L
.48197 .48108 L
.49274 .48123 L
.50422 .48126 L
.51505 .48117 L
.52487 .48098 L
.53643 .48065 L
.54892 .48014 L
.56068 .47951 L
.57147 .47881 L
.61269 .47503 L
.63546 .47216 L
.65594 .46906 L
.73034 .45331 L
.76922 .44177 L
.80874 .42706 L
Mistroke
.84279 .41132 L
.87176 .39494 L
.91849 .35936 L
.93789 .33867 L
.94631 .32762 L
.95426 .31527 L
.96039 .30372 L
.96566 .29121 L
.96801 .28422 L
.96979 .27784 L
.97126 .27133 L
.9723 .26531 L
.97299 .25971 L
.97345 .25378 L
.97362 .24782 L
.97358 .24444 L
.97346 .24127 L
.97304 .23556 L
.97243 .23035 L
.97143 .22435 L
.97022 .21867 L
.96678 .20675 L
.96246 .19564 L
.95166 .17531 L
.93612 .15418 L
.91498 .13247 L
.89289 .11454 L
.86624 .09692 L
.81082 .06915 L
.77566 .05577 L
.74157 .04511 L
.70296 .03532 L
.65916 .0267 L
.63897 .02352 L
.61727 .02063 L
.59693 .01838 L
.5777 .01666 L
.55965 .01538 L
.54012 .01438 L
.52952 .01399 L
.51837 .0137 L
.50883 .01355 L
.49841 .01349 L
.49266 .0135 L
.48657 .01355 L
.47568 .01373 L
.46396 .01405 L
.45732 .01429 L
.45112 .01456 L
.42973 .01577 L
Mistroke
.40693 .01758 L
.38501 .01983 L
.36446 .02243 L
.32664 .02848 L
.28394 .03751 L
.24618 .04771 L
.20739 .0608 L
.16872 .07713 L
.13766 .09338 L
.11202 .10968 L
.07053 .14508 L
.05367 .16538 L
.03956 .18852 L
.03422 .20048 L
.0318 .20712 L
.02985 .21342 L
.02834 .21932 L
.02702 .22575 L
.02612 .2316 L
.02554 .23701 L
.02518 .24282 L
.0251 .24834 L
.02524 .2533 L
.02563 .2587 L
.02631 .26455 L
.02682 .26781 L
.02735 .27076 L
.03002 .28187 L
.03341 .29212 L
.03806 .30308 L
.04905 .32254 L
.0663 .34483 L
.08921 .36709 L
.11479 .38655 L
.14133 .40296 L
.2031 .43172 L
.2412 .44491 L
.27953 .45559 L
.31407 .46334 L
.35198 .47006 L
.37218 .47295 L
.39474 .47564 L
.41556 .47765 L
.43507 .47912 L
.45594 .48026 L
.46701 .48069 L
.47317 .48088 L
.47885 .48102 L
.48484 .48113 L
.49132 .48122 L
Mistroke
.50309 .48126 L
.51379 .48118 L
.52511 .48098 L
.53491 .4807 L
.54541 .4803 L
.56433 .47929 L
.58669 .47763 L
.60696 .47567 L
.65108 .46984 L
.69762 .46117 L
.73964 .45078 L
.77654 .43929 L
.80576 .42829 L
Mfstroke
.92117 .35711 m
.93895 .33789 L
.95237 .31918 L
.96348 .29794 L
.968 .28578 L
.97104 .27461 L
.97218 .26888 L
.97311 .26279 L
.97365 .25758 L
.974 .25183 L
.97407 .24566 L
.97397 .24219 L
.97379 .23902 L
.97322 .23287 L
.97239 .22703 L
.97137 .22165 L
.97002 .21592 L
.96693 .20568 L
.96212 .19361 L
.95672 .1828 L
.94084 .15891 L
.92195 .13792 L
.89675 .11623 L
.86537 .09509 L
.8028 .06432 L
.76256 .04978 L
.72243 .03825 L
.68155 .02902 L
.65932 .02493 L
.63529 .02119 L
.61405 .01844 L
.59033 .01596 L
.56856 .0142 L
.55875 .01357 L
.54799 .013 L
.53817 .01257 L
.52765 .01223 L
.51653 .01198 L
.50618 .01186 L
.49583 .01185 L
.48605 .01193 L
.47728 .01209 L
.46779 .01235 L
.4574 .01274 L
.446 .01329 L
.42304 .0148 L
.40194 .01668 L
.38237 .01884 L
.33948 .02511 L
.29432 .03416 L
Mistroke
.25359 .0448 L
.21786 .05644 L
.15676 .08282 L
.12685 .09988 L
.10271 .11662 L
.08007 .13587 L
.0602 .15738 L
.04667 .17653 L
.04048 .18758 L
.03559 .19817 L
.03112 .2106 L
.02817 .22202 L
.027 .22843 L
.02622 .23436 L
.02592 .23747 L
.02569 .24089 L
.02555 .24446 L
.02552 .24781 L
.02567 .25351 L
.02612 .25949 L
.02674 .26459 L
.02767 .27015 L
.02895 .27614 L
.03065 .28251 L
.03457 .29388 L
.03976 .3055 L
.04649 .31758 L
.06167 .33859 L
.08232 .36009 L
.10985 .38214 L
.13743 .39969 L
.17061 .41681 L
.23866 .44286 L
.2792 .4542 L
.3186 .46291 L
.36351 .47044 L
.38673 .47344 L
.41271 .4761 L
.43552 .47787 L
.45658 .47904 L
.46766 .47948 L
.47402 .47968 L
.4798 .47983 L
.48594 .47995 L
.4925 .48004 L
.49858 .48008 L
.50433 .48009 L
.51482 .48003 L
.52592 .47984 L
.53539 .47959 L
Mistroke
.5458 .4792 L
.55696 .47868 L
.56892 .47797 L
.59044 .47634 L
.61254 .47416 L
.63583 .47128 L
.67687 .46469 L
.72382 .45449 L
.76419 .44305 L
.80017 .43033 L
.83615 .4146 L
.86677 .39808 L
.89235 .38123 L
.91599 .36203 L
.93425 .34345 L
.95067 .32179 L
.9579 .30949 L
.96354 .29764 L
.96785 .28602 L
.96974 .2796 L
.9712 .27354 L
.97227 .26796 L
.97303 .26282 L
.97362 .25711 L
.97395 .25095 L
.974 .24796 L
.97398 .24477 L
.97372 .23902 L
.97343 .2355 L
.97306 .23219 L
.97213 .226 L
.97081 .21948 L
.96928 .21349 L
.96475 .20005 L
.95981 .18896 L
.9544 .17897 L
.93916 .15708 L
.92137 .13768 L
.90138 .12021 L
.8466 .08509 L
.81011 .06795 L
.77323 .054 L
.73439 .04215 L
.6901 .03155 L
.64644 .02367 L
.62519 .02066 L
.60514 .01828 L
.58525 .01635 L
.56701 .01494 L
.54664 .01377 L
Mistroke
.5354 .01331 L
.52475 .01298 L
.51439 .01277 L
.50341 .01267 L
.49403 .01267 L
.48369 .01278 L
.47261 .01301 L
.46639 .01319 L
.46071 .0134 L
.43924 .01445 L
.42783 .0152 L
.41711 .01602 L
.39718 .01788 L
.3532 .02352 L
.31622 .03002 L
.27757 .03874 L
.23691 .05037 L
.19671 .06485 L
.16202 .08039 L
.13322 .09611 L
.08477 .13153 L
.06382 .15296 L
.048 .17427 L
.04224 .18406 L
.03704 .19461 L
.0333 .20382 L
.03008 .21384 L
.02865 .21946 L
.02756 .22463 L
.02673 .22958 L
.02608 .2348 L
.02562 .24054 L
.02544 .24589 L
.02551 .25176 L
.02567 .25505 L
.0259 .25803 L
.02651 .26354 L
.0273 .26868 L
.02843 .27431 L
.02993 .28033 L
.03393 .29253 L
.03867 .30354 L
.05067 .32428 L
.06546 .34326 L
.08643 .36407 L
.10943 .38219 L
.13811 .40048 L
.173 .41837 L
.21069 .43387 L
.24803 .44627 L
Mistroke
.28505 .45621 L
.32754 .46521 L
.36711 .47157 L
.40491 .476 L
.42609 .47782 L
.4455 .4791 L
.45629 .47964 L
.46803 .4801 L
.47914 .48042 L
.48941 .4806 L
.49994 .48068 L
.511 .48065 L
.52045 .48052 L
.53077 .48029 L
.54191 .47992 L
.55378 .47939 L
.57507 .47808 L
.59649 .4763 L
.61652 .47419 L
.6534 .46914 L
.69627 .46121 L
.73421 .45211 L
.77349 .44026 L
.8128 .42536 L
.84584 .40983 L
.87322 .39418 L
.91829 .35984 L
.93806 .33884 L
.94683 .32733 L
.95484 .3148 L
.9607 .3037 L
.96594 .29125 L
.96782 .28576 L
.96957 .2798 L
.97094 .27423 L
.97199 .26895 L
.97288 .26314 L
.97345 .25784 L
.97381 .25212 L
.97389 .2489 L
.97389 .24592 L
.97373 .24096 L
.97332 .23549 L
.97263 .2298 L
.97175 .22448 L
.9704 .21823 L
.96883 .21232 L
.9651 .20129 L
.95996 .18956 L
.95304 .17696 L
Mistroke
.93647 .15408 L
.91386 .13096 L
.8881 .11059 L
.86129 .09351 L
.83115 .07772 L
.79628 .06276 L
.72718 .04067 L
.68569 .0311 L
.64543 .02397 L
.62223 .02074 L
.59996 .01819 L
.57403 .0159 L
.56257 .0151 L
.55019 .01439 L
.53919 .01389 L
.52908 .01354 L
.51941 .0133 L
.50922 .01314 L
.498 .01308 L
.48757 .01314 L
.47613 .01333 L
.46973 .0135 L
.46392 .01368 L
.45218 .01415 L
.44137 .01471 L
.41707 .01639 L
.39582 .01837 L
.37355 .02097 L
.33485 .02682 L
.29968 .03375 L
.22461 .0546 L
.18919 .06806 L
.15371 .08468 L
.12543 .10092 L
.09875 .11972 L
.07604 .13971 L
.0589 .15881 L
.04511 .17881 L
.03539 .1982 L
.03135 .20922 L
.02851 .21958 L
.02729 .22556 L
.02643 .23102 L
.02606 .23404 L
.02574 .23732 L
.0254 .2433 L
.02534 .24905 L
.02543 .25232 L
.02559 .25539 L
.02585 .25861 L
Mistroke
.02616 .26156 L
.02711 .26818 L
.02821 .27378 L
.0297 .27987 L
.03321 .2909 L
.03776 .30187 L
.04277 .3117 L
.05696 .33318 L
.07365 .35225 L
.09237 .36936 L
.14447 .40431 L
.17537 .41974 L
.21247 .43483 L
.24646 .44612 L
.28496 .45652 L
.32014 .46415 L
.35877 .47072 L
.3803 .47362 L
.40436 .47628 L
.42647 .47818 L
.44739 .47952 L
.45938 .48009 L
.46593 .48035 L
.47204 .48054 L
.48287 .4808 L
.4886 .48089 L
.49473 .48096 L
.50134 .48098 L
.50852 .48096 L
.51529 .48089 L
.52154 .48079 L
.52717 .48067 L
.53336 .4805 L
.54586 .48003 L
.55776 .47945 L
.56904 .47876 L
.59009 .47713 L
.61257 .47487 L
.6368 .47182 L
.6794 .46479 L
.71754 .45651 L
.75712 .44563 L
.7973 .4317 L
.83013 .41764 L
.8618 .40106 L
.88751 .38466 L
.91224 .36525 L
.93007 .3479 L
.94615 .32814 L
.95394 .31617 L
Mistroke
.96002 .30489 L
.96473 .29418 L
.9688 .28223 L
.97018 .27706 L
.97142 .27147 L
.97228 .26662 L
.97301 .26131 L
.97352 .25563 L
.97378 .24966 L
.97376 .24412 L
.97351 .23898 L
.97294 .23288 L
.97248 .22945 L
.97198 .22629 L
.97086 .22062 L
.96932 .2144 L
.96589 .20367 L
.96123 .19245 L
.94687 .16775 L
.92878 .14565 L
.90749 .12565 L
.8801 .10533 L
.85259 .08884 L
.82016 .07289 L
.78511 .05881 L
.75119 .04762 L
.71798 .03858 L
.68004 .03022 L
.63874 .02322 L
.61724 .02037 L
.59397 .01784 L
.57192 .01598 L
.55173 .0147 L
.54196 .01424 L
.53133 .01383 L
.52129 .01356 L
.512 .01339 L
.5013 .0133 L
.48979 .01333 L
.47893 .01348 L
.469 .01372 L
.45741 .01412 L
.44479 .01471 L
.42191 .01619 L
.39825 .01829 L
.3733 .02115 L
.32933 .02793 L
.28536 .03714 L
.24676 .04754 L
.2076 .06076 L
Mistroke
.16794 .07758 L
.11042 .11095 L
.08459 .13155 L
.0644 .15206 L
.04823 .1736 L
.04094 .18614 L
.03541 .19793 L
.03155 .20833 L
.02836 .21991 L
.02717 .22576 L
.02666 .22884 L
.02621 .23208 L
.0256 .23806 L
.02531 .24355 L
.02526 .24895 L
.02542 .25385 L
.02585 .25951 L
.0265 .26484 L
.02731 .26977 L
.02824 .2743 L
.03096 .2845 L
.03457 .2947 L
.03955 .30579 L
.05277 .32768 L
.07095 .34961 L
.09214 .36933 L
.14145 .4028 L
.17388 .41923 L
.20671 .43288 L
.24515 .4459 L
.28936 .45775 L
.33472 .46702 L
.35517 .47036 L
.37792 .47351 L
.39825 .47584 L
.42022 .47786 L
.43244 .47878 L
.44361 .47948 L
.45424 .48003 L
.46554 .48049 L
.47564 .4808 L
.48678 .48102 L
.49692 .48112 L
.50643 .48112 L
.51761 .48101 L
.52783 .48079 L
.53904 .48044 L
.55081 .47994 L
.57067 .47877 L
.58903 .47734 L
Mistroke
.63014 .47282 L
.65268 .46954 L
.67311 .46605 L
.71793 .45647 L
.7556 .44613 L
.79317 .4333 L
.85173 .40668 L
.8807 .38927 L
.90462 .37165 L
.92643 .35167 L
.94571 .32864 L
.95292 .31774 L
.95944 .30593 L
.9641 .29558 L
.96811 .28429 L
.96962 .27898 L
.97096 .27336 L
.97196 .26814 L
.9727 .26328 L
.97321 .2587 L
.97356 .25379 L
.97373 .24835 L
.97367 .2434 L
.97334 .23759 L
.97279 .23224 L
.97192 .22637 L
.97069 .22017 L
.9679 .20982 L
.96381 .19852 L
.95864 .18732 L
.95179 .1753 L
.93617 .15404 L
.91719 .13431 L
.89643 .11699 L
.83914 .08196 L
.8016 .06522 L
.76465 .05194 L
.7272 .04105 L
.68563 .03147 L
.64879 .02487 L
.60725 .01934 L
.58344 .01701 L
.56155 .01539 L
.54939 .0147 L
.53612 .01412 L
.53004 .01391 L
.52357 .01372 L
.51195 .0135 L
.50135 .01341 L
.48993 .01343 L
Mistroke
.47915 .01358 L
.46928 .01381 L
.45834 .01418 L
.4464 .01472 L
.42246 .01623 L
.40014 .01817 L
.3762 .02085 L
.33359 .02722 L
.29346 .03528 L
.25794 .04431 L
.18382 .07035 L
.15067 .08624 L
.11801 .10568 L
.09171 .12531 L
.07049 .14524 L
.05474 .16405 L
.04129 .18535 L
.03541 .19777 L
.03123 .20916 L
.02937 .21552 L
.02775 .22243 L
.02658 .22896 L
.02582 .23498 L
.02538 .2406 L
.0252 .24583 L
.02526 .25157 L
.02563 .25771 L
.02593 .2608 L
.02635 .26415 L
.02734 .27022 L
.0286 .27611 L
.03001 .28154 L
.0337 .29262 L
.03797 .30266 L
.05066 .32477 L
.06613 .34449 L
.08402 .3624 L
.13433 .3988 L
.16855 .41685 L
.2036 .43179 L
.24057 .4446 L
.28317 .45637 L
.32545 .46544 L
.36578 .47199 L
.40313 .47642 L
.42463 .4783 L
.44485 .47963 L
.45584 .48018 L
.46628 .4806 L
.47567 .48088 L
Mistroke
.4859 .48109 L
.49702 .48119 L
.50263 .4812 L
.50883 .48118 L
.51978 .48104 L
.53005 .4808 L
.5405 .48045 L
.55166 .47996 L
.57169 .47876 L
.59535 .47681 L
.61666 .47455 L
.66219 .46801 L
.70377 .45982 L
.77268 .44064 L
.80837 .42725 L
.83889 .41335 L
.86711 .39785 L
.89422 .37971 L
.91476 .36289 L
.93388 .3435 L
.94374 .33128 L
.95168 .31967 L
.95864 .30741 L
.96382 .29613 L
.96787 .2849 L
.97072 .27423 L
.97188 .26834 L
.9727 .26291 L
.97331 .25694 L
.97351 .25393 L
.97364 .25063 L
.97365 .24454 L
.97339 .23892 L
.97315 .23598 L
.97281 .23275 L
.97185 .22622 L
.97071 .22051 L
.96919 .21439 L
.96566 .20338 L
.96119 .19266 L
.95545 .18153 L
.9426 .16213 L
.92358 .14051 L
.90216 .12151 L
.875 .10223 L
.84141 .08318 L
.80526 .06676 L
.76909 .05347 L
.73302 .04267 L
.69131 .03271 L
Mistroke
.65236 .02551 L
.61491 .02028 L
.59391 .01802 L
.57457 .01636 L
.56383 .0156 L
.55209 .0149 L
.54093 .01436 L
.53066 .01398 L
.52057 .01371 L
.50993 .01352 L
.49923 .01345 L
.48752 .0135 L
.47738 .01366 L
.46654 .01393 L
.45632 .0143 L
.44704 .01472 L
.42441 .01612 L
.40004 .01822 L
.37725 .02075 L
.35646 .02356 L
.31564 .03058 L
.27239 .04041 L
.2296 .05298 L
.19217 .06682 L
.15934 .08175 L
.12692 .09989 L
.10159 .11737 L
.07824 .13736 L
.05908 .15834 L
.04527 .17821 L
.03986 .18804 L
.03494 .19882 L
.03119 .20915 L
.02855 .21864 L
.02735 .22428 L
.02645 .22962 L
.02575 .23528 L
.02548 .23848 L
.0253 .24144 L
.02516 .24636 L
.02523 .25179 L
.02557 .25745 L
.02612 .26276 L
.02702 .26867 L
.02827 .27487 L
.0313 .2859 L
.03568 .29765 L
.04179 .31032 L
.05681 .33332 L
.07785 .35671 L
Mistroke
.10218 .37743 L
.12781 .39493 L
.15665 .41108 L
.19028 .42653 L
.25749 .44968 L
.29804 .45989 L
.33762 .46767 L
.38249 .47421 L
.40818 .47695 L
.4319 .47887 L
.44334 .47959 L
.45414 .48015 L
.46386 .48055 L
.47437 .48088 L
.48589 .48112 L
.49169 .48119 L
.49805 .48123 L
.50931 .48121 L
.51981 .48107 L
.53042 .48082 L
.54043 .48048 L
.54941 .4801 L
.55915 .47958 L
.58089 .4781 L
.60084 .4763 L
.64224 .47119 L
.68659 .46349 L
.731 .45315 L
.77046 .44138 L
.83847 .41354 L
.86836 .39707 L
.89729 .37737 L
.91874 .35917 L
.93797 .33863 L
.95246 .31835 L
.96242 .29936 L
.96656 .2888 L
.97002 .27709 L
.97133 .27116 L
.97193 .26789 L
.97241 .26478 L
.97313 .25874 L
.97352 .25323 L
.97365 .24806 L
.97356 .24257 L
.97329 .23788 L
.97277 .23271 L
.97198 .22719 L
.97084 .22124 L
.96805 .21054 L
Mistroke
.96394 .19904 L
.95819 .18662 L
.94267 .16227 L
.92377 .14074 L
.90247 .1218 L
.87649 .10323 L
.84444 .08477 L
.81314 .07009 L
.77719 .05625 L
.74264 .04538 L
.70257 .03519 L
.66457 .0276 L
.6279 .02195 L
.60707 .01942 L
.58465 .01721 L
.57165 .01617 L
.55983 .01537 L
.54777 .0147 L
.53665 .01422 L
.52606 .01387 L
.51486 .01362 L
.50362 .01349 L
.49723 .01347 L
.49128 .0135 L
.48048 .01362 L
.47065 .01384 L
.45931 .0142 L
.4486 .01466 L
.42877 .01583 L
.40784 .01749 L
.37072 .02159 L
.33165 .02759 L
.28996 .03609 L
.25116 .04625 L
.2126 .05889 L
.15062 .08623 L
.12056 .10394 L
.09588 .12182 L
.07271 .14284 L
.05279 .16665 L
.04536 .17802 L
.03873 .19026 L
.03405 .201 L
.0301 .21266 L
.02839 .21924 L
.02714 .22528 L
.02618 .23136 L
.02556 .23715 L
.02533 .2404 L
.02518 .24387 L
Mistroke
.02513 .24713 L
.02516 .25009 L
.02529 .25359 L
.02554 .25736 L
.02588 .26092 L
.02629 .26418 L
.02716 .2696 L
.02836 .27538 L
.03123 .28575 L
.03579 .29795 L
.04102 .30892 L
.05589 .33215 L
.0742 .35315 L
.09444 .3714 L
.12034 .39022 L
.14896 .4071 L
.18314 .42354 L
.21789 .43715 L
.25182 .44808 L
.28855 .45774 L
.32324 .4651 L
.36346 .47174 L
.38448 .47447 L
.40749 .47691 L
.42905 .47869 L
.43856 .47932 L
.44902 .47991 L
.45827 .48035 L
.4682 .48072 L
.4787 .481 L
.48851 .48117 L
.4945 .48123 L
.50087 .48125 L
.51231 .48119 L
.51865 .4811 L
.5246 .48098 L
.53113 .48081 L
.53817 .48058 L
.55008 .48008 L
.5626 .47939 L
.58487 .47778 L
.60628 .47574 L
.62602 .47342 L
.66996 .46666 L
.71141 .45806 L
.75426 .44653 L
.78986 .43452 L
.82498 .41998 L
.85405 .40535 L
.88292 .38769 L
Mistroke
.92492 .35309 L
.94379 .33114 L
.95145 .31994 L
.95757 .30937 L
.96262 .29888 L
.96638 .28927 L
.96965 .27849 L
.97103 .27255 L
.97207 .26694 L
.97284 .26131 L
.97317 .2581 L
.97339 .25512 L
.97363 .24908 L
.97363 .2457 L
.97355 .24262 L
.97321 .23711 L
.97256 .23114 L
.97167 .22551 L
.97062 .22032 L
.96749 .20882 L
.96276 .19628 L
.95643 .18337 L
.9492 .17148 L
.93374 .15138 L
.91281 .1305 L
.88859 .11141 L
.85887 .09261 L
.82758 .07654 L
.79663 .0634 L
.73017 .04197 L
.69116 .03273 L
.64822 .0249 L
.61048 .01981 L
.58871 .01758 L
.56819 .01593 L
.55678 .0152 L
.54431 .01455 L
.53251 .01408 L
.52157 .01376 L
.51173 .01358 L
.50085 .01349 L
.48948 .01352 L
.47881 .01366 L
.46708 .01395 L
.46118 .01414 L
.45473 .01439 L
.43273 .01557 L
.42037 .01645 L
.40721 .01755 L
.38368 .01999 L
Mistroke
.33815 .02646 L
.29748 .03438 L
.25476 .0452 L
.21217 .05904 L
.14825 .08749 L
.1169 .10635 L
.09126 .1256 L
.07005 .14561 L
.05136 .16867 L
.04443 .17956 L
.03818 .19138 L
.03342 .2026 L
.02998 .21303 L
.02859 .21831 L
.02734 .22413 L
.02636 .22999 L
.02594 .23319 L
.02563 .23619 L
.02525 .24172 L
.02512 .24677 L
.02523 .25259 L
.02559 .25811 L
.02612 .26304 L
.02691 .26827 L
.02889 .27763 L
.03183 .28763 L
.03603 .29856 L
.04771 .32044 L
.06437 .34261 L
.08198 .36066 L
.10463 .37932 L
.13285 .39803 L
.16693 .41619 L
.23721 .44364 L
.27839 .45529 L
.31827 .46416 L
.36376 .47179 L
.38722 .4748 L
.41335 .47745 L
.42521 .47841 L
.4365 .4792 L
.44679 .47981 L
.45777 .48033 L
.46402 .48058 L
.46969 .48077 L
.48076 .48106 L
.48698 .48116 L
.4937 .48123 L
.50004 .48126 L
.50587 .48125 L
Mistroke
.51632 .48115 L
.52606 .48095 L
.53673 .48064 L
.54813 .48017 L
.56007 .47955 L
.57133 .47882 L
.59231 .47713 L
.63235 .47259 L
.67538 .46566 L
.71866 .4563 L
.75732 .44559 L
.82066 .42193 L
.85245 .40622 L
.87879 .39045 L
.90319 .3727 L
.92554 .35245 L
.94292 .33228 L
.95544 .31324 L
.96154 .30128 L
.96607 .29012 L
.96983 .27774 L
.97124 .27147 L
.97189 .26792 L
.97242 .26456 L
.97312 .25846 L
.9735 .2529 L
.97363 .24691 L
.97357 .24352 L
.97343 .24039 L
.97302 .23519 L
.97231 .22946 L
.97128 .22349 L
.97005 .2179 L
.9668 .20677 L
.96285 .1965 L
.95063 .17368 L
.9345 .15227 L
.91286 .13055 L
.8888 .11157 L
.86288 .09493 L
.80684 .06749 L
.77398 .05519 L
.73548 .04341 L
.69302 .03314 L
.65158 .02544 L
.63125 .02243 L
.61171 .01996 L
.59378 .01807 L
.57453 .0164 L
.56354 .01563 L
Mistroke
.55356 .01503 L
.54338 .01452 L
.534 .01414 L
.523 .0138 L
.51721 .01368 L
.5111 .01358 L
.5008 .01349 L
.48951 .01352 L
.47784 .01368 L
.46706 .01395 L
.46144 .01413 L
.45525 .01437 L
.44274 .01498 L
.42005 .01647 L
.39893 .01834 L
.3601 .02304 L
.31934 .02986 L
.27609 .03945 L
.23293 .05186 L
.19513 .06558 L
.16335 .07972 L
.10798 .11257 L
.08296 .13287 L
.06321 .15325 L
.04844 .17303 L
.03794 .19186 L
.03368 .20189 L
.02997 .21303 L
.0285 .21867 L
.02721 .22475 L
.02628 .2305 L
.02566 .23576 L
.02523 .24179 L
.02511 .24745 L
.02522 .25254 L
.02557 .25803 L
.02625 .26403 L
.0267 .26705 L
.02728 .27035 L
.02994 .28158 L
.03339 .29205 L
.03809 .30312 L
.04915 .32267 L
.06776 .34643 L
.08988 .36765 L
.11309 .38537 L
.1422 .40344 L
.20556 .43265 L
.24448 .44591 L
.2832 .45648 L
Mistroke
.32028 .46456 L
.35672 .47078 L
.3772 .4736 L
.39983 .47617 L
.42069 .47807 L
.44002 .47942 L
.45103 .48003 L
.46269 .48054 L
.47442 .48091 L
.48108 .48106 L
.4873 .48117 L
.49858 .48126 L
.50887 .48123 L
.51456 .48117 L
.52074 .48107 L
.53197 .48079 L
.54195 .48044 L
.55294 .47994 L
.5751 .47855 L
.59549 .47683 L
.61449 .47483 L
.6596 .46846 L
.69967 .46073 L
.74181 .45018 L
.78363 .43679 L
.84774 .40875 L
.87881 .39042 L
.90367 .3723 L
.92374 .35426 L
.94188 .33364 L
.95538 .31334 L
.96458 .29407 L
.96842 .28289 L
.97101 .2726 L
.97206 .26689 L
.9725 .26387 L
.9729 .26066 L
.9734 .25476 L
.97361 .24929 L
.97357 .2438 L
.97325 .23788 L
.97269 .2323 L
.97195 .22718 L
.97109 .22256 L
.96994 .2175 L
.96699 .20735 L
.96223 .1951 L
.9568 .18409 L
.94091 .16004 L
.92175 .1388 L
Mistroke
.89991 .11983 L
.84631 .08579 L
.81476 .07082 L
.77692 .0562 L
.74251 .04538 L
.70351 .03544 L
.66513 .02773 L
.62889 .02211 L
.60772 .01951 L
.58755 .01749 L
.56411 .01567 L
.55371 .01504 L
.5427 .01449 L
.53302 .0141 L
.52236 .01379 L
.51267 .0136 L
.5036 .01351 L
.49291 .0135 L
.48315 .01359 L
.4719 .01382 L
.46124 .01414 L
.45069 .01458 L
.43906 .01518 L
.41562 .01683 L
.39407 .01884 L
.37401 .02117 L
.32979 .02791 L
.28382 .03754 L
.24515 .04803 L
.21106 .05943 L
.17334 .07498 L
.14203 .0909 L
.1144 .10804 L
.0882 .1282 L
.06512 .15104 L
.04793 .17382 L
.04179 .18424 L
.03624 .19561 L
.03234 .20556 L
.02903 .21651 L
.02751 .22318 L
.02643 .2294 L
.0257 .23535 L
.02541 .23868 L
.02523 .2417 L
.0251 .24742 L
.02515 .25064 L
.02526 .2536 L
.02566 .25905 L
.02635 .26479 L
Mistroke
.02737 .27085 L
.02857 .27636 L
.03217 .28867 L
.03663 .29994 L
.04183 .31049 L
.05686 .33347 L
.07833 .35726 L
.10047 .37619 L
.12433 .39281 L
.15632 .41097 L
.18877 .42596 L
.26285 .45122 L
.30526 .46151 L
.3519 .47005 L
.37396 .47318 L
.39503 .47567 L
.41437 .47754 L
.43499 .47911 L
.44574 .47975 L
.4576 .48033 L
.4684 .48074 L
.47852 .48101 L
.48464 .48113 L
.49045 .48121 L
.50136 .48126 L
.5131 .48119 L
.51973 .48109 L
.52588 .48096 L
.5362 .48066 L
.54732 .48021 L
.5674 .47909 L
.58684 .47761 L
.60458 .47592 L
.64438 .47087 L
.68524 .46375 L
.72553 .45457 L
.76055 .44457 L
.79616 .43212 L
.832 .41667 L
.86223 .40069 L
.88736 .3846 L
.92825 .34961 L
.94468 .32989 L
.95222 .31867 L
.95836 .30782 L
.96313 .29762 L
.96734 .28636 L
.96885 .28138 L
.97024 .27604 L
.97125 .27136 L
Mistroke
.97213 .2664 L
.97258 .26332 L
.97297 .25993 L
.97344 .25398 L
.97358 .25062 L
.97362 .24702 L
.97356 .24362 L
.97343 .24052 L
.97294 .23452 L
.97254 .23114 L
.97208 .22802 L
.97103 .22229 L
.96962 .21623 L
.96625 .20523 L
.96218 .19499 L
.94963 .17215 L
.93434 .15211 L
.91361 .13123 L
.88773 .11083 L
.86003 .09329 L
.80256 .06576 L
.76656 .05272 L
.73182 .04243 L
.69303 .03315 L
.65026 .02524 L
.61266 .02008 L
.59094 .0178 L
.57043 .0161 L
.55907 .01535 L
.54664 .01467 L
.53487 .01417 L
.52393 .01383 L
.51308 .01361 L
.50325 .01351 L
.49189 .01351 L
.48121 .01362 L
.4695 .01388 L
.46361 .01406 L
.45716 .0143 L
.43515 .01542 L
.42279 .01626 L
.40961 .01734 L
.38602 .01972 L
.34058 .02605 L
.29991 .03384 L
.25715 .04451 L
.21442 .05821 L
.15024 .0864 L
.11868 .10515 L
.09278 .12432 L
Mistroke
.07077 .14483 L
.054 .16493 L
.04046 .18675 L
.03499 .19856 L
.03046 .21133 L
.02767 .22238 L
.02654 .22865 L
.02579 .23443 L
.02535 .2395 L
.02512 .24507 L
.02515 .25089 L
.02543 .25633 L
.02593 .26162 L
.02663 .26664 L
.02742 .27112 L
.02848 .276 L
.03156 .28687 L
.03528 .29684 L
.04583 .31745 L
.06123 .33894 L
.07944 .35831 L
.09914 .37517 L
.15496 .41028 L
.18783 .42557 L
.227 .44032 L
.26707 .45237 L
.30699 .46188 L
.34423 .46883 L
.38583 .47465 L
.40777 .47695 L
.43216 .47892 L
.44451 .47969 L
.45782 .48034 L
.46428 .4806 L
.47042 .4808 L
.48197 .48108 L
.49274 .48123 L
.50422 .48126 L
.51505 .48117 L
.52487 .48098 L
.53643 .48065 L
.54892 .48014 L
.56068 .47951 L
.57147 .47881 L
.61269 .47503 L
.63546 .47216 L
.65594 .46906 L
.73034 .45331 L
.76922 .44177 L
.80874 .42706 L
Mistroke
.84279 .41132 L
.87176 .39494 L
.91849 .35936 L
.93789 .33867 L
.94631 .32762 L
.95426 .31527 L
.96039 .30372 L
.96566 .29121 L
.96801 .28422 L
.96979 .27784 L
.97126 .27133 L
.9723 .26531 L
.97299 .25971 L
.97345 .25378 L
.97362 .24782 L
.97358 .24444 L
.97346 .24127 L
.97304 .23556 L
.97243 .23035 L
.97143 .22435 L
.97022 .21867 L
.96678 .20675 L
.96246 .19564 L
.95166 .17531 L
.93612 .15418 L
.91498 .13247 L
.89289 .11454 L
.86624 .09692 L
.81082 .06915 L
.77566 .05577 L
.74157 .04511 L
.70296 .03532 L
.65916 .0267 L
.63897 .02352 L
.61727 .02063 L
.59693 .01838 L
.5777 .01666 L
.55965 .01538 L
.54012 .01438 L
.52952 .01399 L
.51837 .0137 L
.50883 .01355 L
.49842 .01349 L
.49266 .0135 L
.48657 .01355 L
.47568 .01373 L
.46396 .01405 L
.45732 .01429 L
.45112 .01456 L
.42973 .01577 L
Mistroke
.40693 .01758 L
.38501 .01983 L
.36446 .02243 L
.32664 .02848 L
.28394 .03751 L
.24618 .04771 L
.20739 .0608 L
.16872 .07713 L
.13766 .09338 L
.11202 .10968 L
.07053 .14508 L
.05367 .16538 L
.03956 .18852 L
.03422 .20048 L
.0318 .20712 L
.02985 .21342 L
.02834 .21932 L
.02702 .22575 L
.02612 .2316 L
.02554 .23701 L
.02518 .24282 L
.0251 .24834 L
.02524 .2533 L
.02563 .2587 L
.02631 .26455 L
.02682 .26781 L
.02735 .27076 L
.03002 .28187 L
.03341 .29212 L
.03806 .30308 L
.04905 .32254 L
.0663 .34483 L
.08921 .36709 L
.11479 .38655 L
.14133 .40296 L
.2031 .43172 L
.2412 .44491 L
.27953 .45559 L
.31407 .46334 L
.35198 .47006 L
.37218 .47295 L
.39474 .47564 L
.41556 .47765 L
.43507 .47912 L
.45594 .48026 L
.46701 .48069 L
.47317 .48088 L
.47885 .48102 L
.48484 .48113 L
.49132 .48122 L
Mistroke
.50309 .48126 L
.51379 .48118 L
.52511 .48098 L
.53491 .4807 L
.54541 .4803 L
.56433 .47929 L
.58669 .47763 L
.60696 .47567 L
.65108 .46984 L
.69762 .46117 L
.73964 .45078 L
.77654 .43929 L
.80576 .42829 L
Mfstroke
.92133 .35735 m
.93915 .3381 L
.95261 .31935 L
.96374 .29805 L
.96827 .28587 L
.97131 .27467 L
.97246 .26893 L
.97338 .26282 L
.97393 .2576 L
.97428 .25184 L
.97435 .24565 L
.97425 .24217 L
.97407 .23899 L
.9735 .23283 L
.97266 .22698 L
.97164 .22158 L
.97029 .21584 L
.96719 .20557 L
.96237 .19348 L
.95695 .18265 L
.94104 .15872 L
.92211 .1377 L
.89685 .11598 L
.86542 .09483 L
.80275 .06406 L
.76246 .04955 L
.72229 .03805 L
.68137 .02885 L
.65913 .02478 L
.63509 .02106 L
.61383 .01834 L
.5901 .01588 L
.56833 .01414 L
.55851 .01352 L
.54775 .01296 L
.53722 .01252 L
.52741 .01221 L
.51703 .01198 L
.50593 .01186 L
.49558 .01186 L
.48581 .01196 L
.47704 .01213 L
.46755 .0124 L
.45716 .01279 L
.44576 .01335 L
.42282 .01489 L
.40172 .01678 L
.38216 .01897 L
.3393 .02526 L
.29417 .03435 L
Mistroke
.25348 .04501 L
.21779 .05666 L
.15677 .08304 L
.12691 .10009 L
.1028 .11682 L
.08019 .13605 L
.06036 .15752 L
.04684 .17664 L
.04066 .18767 L
.03578 .19825 L
.03132 .21066 L
.02838 .22205 L
.0272 .22845 L
.02642 .23437 L
.02613 .23747 L
.0259 .24088 L
.02576 .24445 L
.02572 .24779 L
.02588 .25348 L
.02633 .25946 L
.02694 .26455 L
.02786 .2701 L
.02915 .27608 L
.03084 .28244 L
.03475 .29379 L
.03993 .30539 L
.04665 .31745 L
.06181 .33843 L
.08242 .35992 L
.10991 .38196 L
.13746 .3995 L
.17059 .41662 L
.23857 .44269 L
.27908 .45406 L
.31846 .46279 L
.36335 .47036 L
.38656 .47337 L
.41253 .47606 L
.43534 .47784 L
.4564 .47903 L
.46748 .47948 L
.47384 .47969 L
.47963 .47984 L
.48576 .47996 L
.49232 .48006 L
.49841 .48011 L
.50415 .48012 L
.51464 .48006 L
.52575 .47988 L
.53522 .47963 L
Mistroke
.54563 .47926 L
.55679 .47874 L
.56876 .47804 L
.59028 .47642 L
.61239 .47426 L
.6357 .4714 L
.67675 .46483 L
.72374 .45464 L
.76415 .44321 L
.80015 .4305 L
.83616 .41476 L
.86682 .39823 L
.89242 .38137 L
.91608 .36215 L
.93437 .34355 L
.9508 .32187 L
.95804 .30955 L
.96368 .29769 L
.968 .28604 L
.96989 .27961 L
.97135 .27355 L
.97242 .26796 L
.97318 .26282 L
.97377 .2571 L
.9741 .25093 L
.97415 .24794 L
.97413 .24474 L
.97387 .23898 L
.97357 .23547 L
.97321 .23215 L
.97228 .22595 L
.97095 .21942 L
.96942 .21342 L
.96487 .19997 L
.95993 .18887 L
.95451 .17887 L
.93925 .15696 L
.92144 .13755 L
.90142 .12007 L
.84659 .08495 L
.81007 .06782 L
.77317 .05388 L
.73431 .04205 L
.68999 .03147 L
.64632 .02361 L
.62506 .02061 L
.60502 .01825 L
.58512 .01633 L
.56688 .01493 L
.54651 .01377 L
Mistroke
.53527 .01331 L
.52462 .01299 L
.51426 .01279 L
.50328 .01269 L
.4939 .0127 L
.48356 .01281 L
.47249 .01305 L
.46627 .01324 L
.46058 .01344 L
.43913 .0145 L
.42771 .01526 L
.417 .01609 L
.39708 .01796 L
.35311 .02361 L
.31614 .03013 L
.27752 .03886 L
.23688 .05049 L
.1967 .06498 L
.16204 .08051 L
.13326 .09622 L
.08485 .13161 L
.06391 .15302 L
.0481 .17432 L
.04235 .1841 L
.03714 .19463 L
.03341 .20384 L
.03019 .21385 L
.02876 .21946 L
.02767 .22462 L
.02684 .22957 L
.02619 .23479 L
.02573 .24053 L
.02555 .24587 L
.02561 .25173 L
.02578 .25502 L
.026 .25799 L
.02661 .2635 L
.02741 .26864 L
.02853 .27426 L
.03003 .28028 L
.03402 .29246 L
.03876 .30347 L
.05074 .32419 L
.06552 .34317 L
.08646 .36397 L
.10944 .38209 L
.1381 .40037 L
.17298 .41827 L
.21065 .43379 L
.24797 .44619 L
Mistroke
.28498 .45615 L
.32745 .46516 L
.36702 .47154 L
.40482 .47599 L
.42599 .47782 L
.44541 .4791 L
.45619 .47965 L
.46793 .48012 L
.47904 .48043 L
.48932 .48062 L
.49984 .4807 L
.51091 .48068 L
.52036 .48056 L
.53068 .48033 L
.54183 .47996 L
.5537 .47943 L
.57499 .47813 L
.59641 .47636 L
.61645 .47426 L
.65334 .46922 L
.69623 .4613 L
.73419 .4522 L
.77348 .44035 L
.81281 .42545 L
.84586 .40992 L
.87326 .39425 L
.91835 .3599 L
.93814 .33888 L
.9469 .32736 L
.95492 .31482 L
.96078 .30371 L
.96602 .29126 L
.96791 .28576 L
.96965 .2798 L
.97102 .27422 L
.97207 .26894 L
.97296 .26312 L
.97353 .25782 L
.97388 .2521 L
.97397 .24887 L
.97397 .24589 L
.9738 .24093 L
.97339 .23546 L
.9727 .22977 L
.97182 .22444 L
.97047 .21819 L
.9689 .21227 L
.96517 .20124 L
.96002 .1895 L
.95309 .1769 L
Mistroke
.93651 .15401 L
.91388 .13089 L
.8881 .11052 L
.86128 .09344 L
.83113 .07765 L
.79624 .0627 L
.72713 .04062 L
.68563 .03106 L
.64537 .02395 L
.62216 .02072 L
.59989 .01819 L
.57396 .0159 L
.5625 .01511 L
.55012 .0144 L
.53912 .0139 L
.52901 .01355 L
.51934 .01331 L
.50915 .01316 L
.49794 .01311 L
.48751 .01317 L
.47607 .01336 L
.46967 .01353 L
.46386 .01371 L
.45212 .01419 L
.44131 .01475 L
.41702 .01644 L
.39577 .01842 L
.37351 .02102 L
.33481 .02688 L
.29966 .03381 L
.2246 .05467 L
.1892 .06812 L
.15373 .08474 L
.12546 .10098 L
.09879 .11976 L
.07609 .13974 L
.05896 .15883 L
.04517 .17883 L
.03544 .1982 L
.03141 .20922 L
.02857 .21957 L
.02735 .22555 L
.02649 .231 L
.02612 .23402 L
.0258 .23731 L
.02545 .24328 L
.02539 .24903 L
.02548 .2523 L
.02564 .25536 L
.0259 .25858 L
Mistroke
.02621 .26153 L
.02716 .26815 L
.02826 .27375 L
.02975 .27984 L
.03326 .29086 L
.0378 .30183 L
.0428 .31165 L
.05698 .33312 L
.07367 .3522 L
.09238 .36931 L
.14446 .40426 L
.17535 .41969 L
.21244 .43479 L
.24642 .44608 L
.28492 .45649 L
.32009 .46413 L
.35872 .47071 L
.38025 .47362 L
.40431 .47628 L
.42642 .47819 L
.44734 .47953 L
.45933 .48011 L
.46588 .48036 L
.47199 .48056 L
.48282 .48082 L
.48855 .48091 L
.49468 .48098 L
.5013 .481 L
.50847 .48098 L
.51525 .48092 L
.52149 .48082 L
.52712 .4807 L
.53332 .48052 L
.54582 .48006 L
.55772 .47948 L
.569 .47879 L
.59006 .47716 L
.61254 .47491 L
.63678 .47186 L
.67938 .46484 L
.71753 .45656 L
.75712 .44568 L
.79731 .43175 L
.83015 .41768 L
.86182 .4011 L
.88754 .38469 L
.91228 .36528 L
.93011 .34792 L
.94619 .32815 L
.95398 .31617 L
Mistroke
.96007 .30489 L
.96477 .29418 L
.96884 .28223 L
.97022 .27705 L
.97146 .27146 L
.97232 .26661 L
.97305 .2613 L
.97356 .25562 L
.97382 .24964 L
.9738 .2441 L
.97355 .23895 L
.97298 .23286 L
.97252 .22943 L
.97201 .22627 L
.97089 .22059 L
.96935 .21437 L
.96592 .20364 L
.96126 .19242 L
.94689 .16771 L
.92879 .14561 L
.90749 .12561 L
.88009 .10529 L
.85258 .0888 L
.82014 .07286 L
.78508 .05878 L
.75116 .0476 L
.71794 .03856 L
.68001 .03021 L
.6387 .02322 L
.6172 .02036 L
.59393 .01784 L
.57189 .01598 L
.55169 .01471 L
.54192 .01425 L
.5313 .01385 L
.52125 .01357 L
.51196 .0134 L
.50127 .01332 L
.48976 .01335 L
.4789 .0135 L
.46897 .01374 L
.45738 .01414 L
.44477 .01473 L
.42188 .01622 L
.39823 .01832 L
.37328 .02118 L
.32932 .02796 L
.28535 .03717 L
.24676 .04758 L
.2076 .06079 L
Mistroke
.16795 .07761 L
.11044 .11097 L
.08461 .13157 L
.06443 .15207 L
.04826 .1736 L
.04097 .18614 L
.03544 .19792 L
.03159 .20832 L
.02839 .2199 L
.0272 .22575 L
.02669 .22882 L
.02624 .23207 L
.02563 .23804 L
.02533 .24353 L
.02528 .24893 L
.02544 .25384 L
.02588 .25949 L
.02653 .26482 L
.02734 .26975 L
.02826 .27428 L
.03098 .28448 L
.03459 .29467 L
.03957 .30576 L
.05278 .32765 L
.07095 .34958 L
.09214 .3693 L
.14144 .40278 L
.17387 .41921 L
.2067 .43285 L
.24512 .44589 L
.28934 .45774 L
.33469 .46702 L
.35514 .47036 L
.37789 .47351 L
.39822 .47584 L
.42019 .47787 L
.43242 .47878 L
.44358 .47949 L
.45421 .48004 L
.46552 .4805 L
.47561 .48081 L
.48676 .48104 L
.4969 .48113 L
.50641 .48113 L
.51758 .48102 L
.52781 .48081 L
.53902 .48046 L
.55079 .47996 L
.57065 .47879 L
.58901 .47736 L
Mistroke
.63013 .47285 L
.65267 .46957 L
.67311 .46607 L
.71793 .4565 L
.7556 .44615 L
.79318 .43332 L
.85175 .4067 L
.88072 .38929 L
.90464 .37166 L
.92645 .35167 L
.94574 .32865 L
.95294 .31774 L
.95946 .30593 L
.96412 .29558 L
.96813 .28428 L
.96964 .27897 L
.97098 .27335 L
.97198 .26813 L
.97272 .26327 L
.97323 .25868 L
.97358 .25378 L
.97375 .24834 L
.97369 .24339 L
.97336 .23758 L
.97281 .23222 L
.97194 .22636 L
.9707 .22016 L
.96792 .2098 L
.96382 .1985 L
.95865 .1873 L
.9518 .17528 L
.93617 .15402 L
.91719 .13428 L
.89642 .11697 L
.83913 .08195 L
.80159 .0652 L
.76463 .05193 L
.72718 .04105 L
.68561 .03146 L
.64877 .02487 L
.60723 .01934 L
.58342 .01702 L
.56153 .0154 L
.54937 .01471 L
.53611 .01412 L
.53002 .01392 L
.52356 .01373 L
.51193 .01351 L
.50134 .01342 L
.48991 .01345 L
Mistroke
.47913 .01359 L
.46926 .01382 L
.45832 .01419 L
.44639 .01473 L
.42244 .01625 L
.40013 .01819 L
.37619 .02087 L
.33359 .02724 L
.29346 .0353 L
.25794 .04432 L
.18383 .07037 L
.15068 .08626 L
.11802 .10569 L
.09172 .12532 L
.07051 .14524 L
.05476 .16405 L
.04131 .18534 L
.03543 .19777 L
.03124 .20915 L
.02939 .21552 L
.02777 .22242 L
.0266 .22896 L
.02583 .23497 L
.02539 .24059 L
.02521 .24582 L
.02527 .25156 L
.02564 .2577 L
.02594 .26079 L
.02636 .26414 L
.02735 .27021 L
.02861 .2761 L
.03003 .28152 L
.03371 .29261 L
.03797 .30264 L
.05067 .32475 L
.06613 .34448 L
.08402 .36239 L
.13432 .39879 L
.16854 .41684 L
.20359 .43178 L
.24056 .44459 L
.28315 .45637 L
.32543 .46544 L
.36576 .472 L
.40312 .47643 L
.42461 .4783 L
.44483 .47964 L
.45583 .48019 L
.46627 .48061 L
.47566 .48089 L
Mistroke
.48589 .48109 L
.49701 .4812 L
.50262 .48121 L
.50882 .48119 L
.51977 .48105 L
.53004 .48081 L
.54049 .48046 L
.55165 .47997 L
.57168 .47877 L
.59534 .47683 L
.61665 .47456 L
.66218 .46803 L
.70377 .45983 L
.77268 .44065 L
.80838 .42727 L
.8389 .41336 L
.86712 .39786 L
.89424 .37971 L
.91477 .36289 L
.93389 .3435 L
.94375 .33128 L
.95169 .31967 L
.95865 .30741 L
.96384 .29613 L
.96789 .28489 L
.97073 .27423 L
.97189 .26833 L
.97271 .2629 L
.97332 .25693 L
.97352 .25392 L
.97365 .25062 L
.97366 .24453 L
.9734 .23891 L
.97316 .23597 L
.97282 .23274 L
.97185 .22621 L
.97072 .2205 L
.9692 .21437 L
.96566 .20337 L
.9612 .19264 L
.95546 .18152 L
.9426 .16212 L
.92358 .1405 L
.90216 .1215 L
.875 .10222 L
.84141 .08317 L
.80525 .06676 L
.76908 .05347 L
.73301 .04267 L
.6913 .03271 L
Mistroke
.65235 .02551 L
.6149 .02028 L
.5939 .01803 L
.57456 .01636 L
.56382 .0156 L
.55208 .0149 L
.54092 .01437 L
.53065 .01399 L
.52056 .01371 L
.50992 .01353 L
.49923 .01346 L
.48751 .01351 L
.47737 .01367 L
.46653 .01394 L
.45631 .01431 L
.44703 .01473 L
.42441 .01613 L
.40003 .01823 L
.37725 .02076 L
.35646 .02357 L
.31564 .03059 L
.27239 .04042 L
.22961 .05298 L
.19217 .06683 L
.15934 .08175 L
.12693 .0999 L
.1016 .11737 L
.07825 .13736 L
.05909 .15834 L
.04528 .17821 L
.03986 .18804 L
.03495 .19882 L
.0312 .20915 L
.02856 .21864 L
.02735 .22427 L
.02645 .22962 L
.02576 .23527 L
.02548 .23847 L
.0253 .24143 L
.02516 .24635 L
.02524 .25178 L
.02557 .25745 L
.02613 .26276 L
.02702 .26867 L
.02827 .27487 L
.0313 .28589 L
.03568 .29764 L
.0418 .31031 L
.05681 .33331 L
.07784 .3567 L
Mistroke
.10218 .37742 L
.12781 .39492 L
.15665 .41107 L
.19028 .42653 L
.25748 .44967 L
.29803 .45989 L
.33761 .46767 L
.38248 .47421 L
.40817 .47695 L
.43189 .47887 L
.44334 .47959 L
.45414 .48015 L
.46385 .48056 L
.47437 .48089 L
.48588 .48113 L
.49169 .4812 L
.49804 .48124 L
.50931 .48121 L
.51981 .48107 L
.53041 .48083 L
.54043 .48049 L
.54941 .4801 L
.55915 .47959 L
.58089 .4781 L
.60084 .4763 L
.64224 .4712 L
.68659 .46349 L
.73101 .45316 L
.77046 .44138 L
.83847 .41355 L
.86837 .39707 L
.89729 .37737 L
.91875 .35917 L
.93797 .33863 L
.95247 .31835 L
.96243 .29936 L
.96657 .2888 L
.97003 .27709 L
.97134 .27116 L
.97193 .26788 L
.97242 .26477 L
.97313 .25874 L
.97352 .25322 L
.97366 .24806 L
.97357 .24256 L
.97329 .23787 L
.97278 .2327 L
.97198 .22718 L
.97085 .22124 L
.96805 .21054 L
Mistroke
.96394 .19904 L
.95819 .18662 L
.94267 .16226 L
.92377 .14074 L
.90246 .12179 L
.87649 .10322 L
.84444 .08477 L
.81313 .07008 L
.77719 .05625 L
.74264 .04538 L
.70257 .03519 L
.66457 .0276 L
.6279 .02195 L
.60707 .01942 L
.58464 .01721 L
.57165 .01617 L
.55982 .01538 L
.54776 .01471 L
.53664 .01422 L
.52606 .01387 L
.51486 .01362 L
.50361 .0135 L
.49723 .01348 L
.49127 .0135 L
.48048 .01363 L
.47064 .01384 L
.45931 .01421 L
.4486 .01467 L
.42877 .01583 L
.40784 .0175 L
.37072 .02159 L
.33165 .02759 L
.28996 .0361 L
.25117 .04625 L
.2126 .05889 L
.15062 .08623 L
.12057 .10394 L
.09589 .12182 L
.07272 .14284 L
.05279 .16665 L
.04536 .17802 L
.03874 .19026 L
.03405 .201 L
.03011 .21265 L
.02839 .21924 L
.02714 .22528 L
.02618 .23136 L
.02556 .23714 L
.02533 .2404 L
.02518 .24386 L
Mistroke
.02513 .24713 L
.02516 .25009 L
.02529 .25358 L
.02554 .25736 L
.02588 .26091 L
.02629 .26417 L
.02716 .26959 L
.02836 .27538 L
.03123 .28574 L
.03579 .29795 L
.04102 .30891 L
.05589 .33215 L
.0742 .35315 L
.09444 .3714 L
.12034 .39021 L
.14896 .4071 L
.18314 .42354 L
.21789 .43715 L
.25182 .44808 L
.28855 .45774 L
.32323 .4651 L
.36345 .47174 L
.38448 .47447 L
.40749 .47691 L
.42905 .47869 L
.43855 .47932 L
.44902 .47992 L
.45826 .48035 L
.46819 .48072 L
.47869 .48101 L
.48851 .48118 L
.4945 .48123 L
.50087 .48126 L
.5123 .4812 L
.51865 .48111 L
.5246 .48099 L
.53113 .48082 L
.53816 .48058 L
.55008 .48008 L
.5626 .47939 L
.58487 .47778 L
.60628 .47574 L
.62602 .47343 L
.66996 .46667 L
.71141 .45806 L
.75426 .44653 L
.78987 .43452 L
.82498 .41998 L
.85405 .40535 L
.88292 .3877 L
Mistroke
.92493 .35309 L
.94379 .33114 L
.95145 .31994 L
.95757 .30937 L
.96262 .29888 L
.96638 .28926 L
.96965 .27849 L
.97103 .27255 L
.97207 .26694 L
.97284 .2613 L
.97317 .2581 L
.9734 .25511 L
.97363 .24908 L
.97363 .24569 L
.97355 .24261 L
.97321 .23711 L
.97256 .23114 L
.97167 .22551 L
.97062 .22032 L
.96749 .20882 L
.96276 .19627 L
.95643 .18336 L
.9492 .17147 L
.93374 .15138 L
.91281 .1305 L
.88859 .11141 L
.85887 .09261 L
.82758 .07654 L
.79663 .0634 L
.73017 .04197 L
.69115 .03274 L
.64822 .02491 L
.61048 .01982 L
.58871 .01759 L
.56819 .01594 L
.55678 .0152 L
.54431 .01455 L
.53251 .01408 L
.52156 .01377 L
.51172 .01358 L
.50084 .01349 L
.48948 .01352 L
.4788 .01366 L
.46708 .01395 L
.46118 .01414 L
.45473 .0144 L
.43273 .01557 L
.42037 .01645 L
.40721 .01756 L
.38368 .01999 L
Mistroke
.33815 .02647 L
.29748 .03439 L
.25476 .0452 L
.21217 .05904 L
.14825 .08749 L
.1169 .10635 L
.09127 .1256 L
.07005 .14561 L
.05136 .16867 L
.04443 .17956 L
.03819 .19137 L
.03342 .2026 L
.02998 .21303 L
.0286 .21831 L
.02734 .22412 L
.02636 .22998 L
.02594 .23319 L
.02563 .23619 L
.02525 .24172 L
.02512 .24677 L
.02523 .25259 L
.02559 .2581 L
.02612 .26304 L
.02691 .26827 L
.02889 .27762 L
.03183 .28762 L
.03603 .29855 L
.04771 .32044 L
.06436 .34261 L
.08198 .36066 L
.10463 .37932 L
.13285 .39803 L
.16693 .41619 L
.23721 .44364 L
.27839 .45529 L
.31827 .46416 L
.36376 .4718 L
.38722 .4748 L
.41335 .47745 L
.4252 .47842 L
.4365 .4792 L
.44679 .47981 L
.45777 .48034 L
.46402 .48058 L
.46969 .48078 L
.48076 .48106 L
.48698 .48116 L
.4937 .48123 L
.50004 .48126 L
.50587 .48125 L
Mistroke
.51632 .48115 L
.52606 .48096 L
.53673 .48064 L
.54813 .48017 L
.56007 .47955 L
.57133 .47883 L
.59231 .47713 L
.63235 .47259 L
.67538 .46567 L
.71866 .45631 L
.75732 .44559 L
.82067 .42193 L
.85245 .40622 L
.87879 .39045 L
.90319 .3727 L
.92554 .35245 L
.94292 .33228 L
.95544 .31324 L
.96154 .30128 L
.96607 .29012 L
.96983 .27774 L
.97124 .27147 L
.97189 .26792 L
.97242 .26455 L
.97313 .25846 L
.9735 .2529 L
.97363 .24691 L
.97357 .24352 L
.97343 .24039 L
.97302 .23519 L
.97231 .22946 L
.97128 .22349 L
.97005 .2179 L
.9668 .20677 L
.96285 .1965 L
.95063 .17368 L
.9345 .15227 L
.91285 .13055 L
.8888 .11157 L
.86288 .09492 L
.80684 .06749 L
.77398 .05519 L
.73547 .04341 L
.69302 .03314 L
.65158 .02544 L
.63125 .02243 L
.61171 .01996 L
.59378 .01807 L
.57453 .01641 L
.56354 .01563 L
Mistroke
.55355 .01503 L
.54338 .01452 L
.534 .01414 L
.523 .01381 L
.51721 .01368 L
.5111 .01358 L
.5008 .0135 L
.48951 .01352 L
.47784 .01368 L
.46706 .01395 L
.46144 .01414 L
.45525 .01438 L
.44274 .01498 L
.42005 .01647 L
.39893 .01835 L
.3601 .02304 L
.31934 .02986 L
.27609 .03945 L
.23293 .05187 L
.19513 .06559 L
.16335 .07972 L
.10798 .11257 L
.08296 .13287 L
.06321 .15325 L
.04844 .17303 L
.03795 .19186 L
.03368 .20189 L
.02997 .21303 L
.0285 .21867 L
.02721 .22475 L
.02628 .2305 L
.02566 .23576 L
.02524 .24178 L
.02511 .24745 L
.02522 .25254 L
.02557 .25803 L
.02625 .26403 L
.0267 .26705 L
.02728 .27034 L
.02994 .28158 L
.03339 .29204 L
.03809 .30312 L
.04915 .32267 L
.06776 .34643 L
.08988 .36765 L
.11309 .38537 L
.1422 .40344 L
.20556 .43265 L
.24448 .44591 L
.2832 .45648 L
Mistroke
.32028 .46456 L
.35671 .47078 L
.3772 .4736 L
.39983 .47617 L
.42069 .47807 L
.44002 .47943 L
.45103 .48003 L
.46269 .48054 L
.47442 .48091 L
.48108 .48107 L
.4873 .48117 L
.49858 .48126 L
.50887 .48123 L
.51456 .48117 L
.52074 .48107 L
.53197 .48079 L
.54195 .48044 L
.55294 .47994 L
.5751 .47855 L
.59549 .47683 L
.61449 .47483 L
.65961 .46846 L
.69967 .46073 L
.74181 .45018 L
.78363 .43679 L
.84774 .40875 L
.87882 .39042 L
.90367 .3723 L
.92374 .35426 L
.94188 .33364 L
.95538 .31334 L
.96459 .29406 L
.96842 .28289 L
.97101 .2726 L
.97206 .26689 L
.97251 .26387 L
.9729 .26066 L
.9734 .25476 L
.97361 .24929 L
.97357 .2438 L
.97325 .23788 L
.97269 .2323 L
.97195 .22718 L
.97109 .22256 L
.96994 .2175 L
.96699 .20735 L
.96223 .1951 L
.9568 .18409 L
.94091 .16004 L
.92175 .1388 L
Mistroke
.89991 .11983 L
.84631 .08579 L
.81476 .07082 L
.77692 .0562 L
.74251 .04538 L
.70351 .03544 L
.66512 .02773 L
.62889 .02211 L
.60772 .01951 L
.58755 .01749 L
.56411 .01567 L
.55371 .01504 L
.5427 .01449 L
.53302 .01411 L
.52236 .01379 L
.51267 .0136 L
.5036 .01351 L
.49291 .0135 L
.48315 .01359 L
.4719 .01382 L
.46124 .01414 L
.45069 .01458 L
.43906 .01518 L
.41562 .01683 L
.39407 .01884 L
.37401 .02117 L
.32979 .02791 L
.28382 .03754 L
.24515 .04803 L
.21106 .05944 L
.17334 .07498 L
.14203 .0909 L
.1144 .10804 L
.0882 .1282 L
.06512 .15104 L
.04793 .17382 L
.04179 .18424 L
.03624 .19561 L
.03234 .20556 L
.02903 .21651 L
.02751 .22318 L
.02643 .2294 L
.0257 .23535 L
.02541 .23868 L
.02523 .2417 L
.0251 .24742 L
.02515 .25064 L
.02526 .2536 L
.02566 .25905 L
.02635 .26479 L
Mistroke
.02737 .27085 L
.02857 .27636 L
.03217 .28867 L
.03663 .29994 L
.04183 .31048 L
.05686 .33347 L
.07833 .35726 L
.10047 .37619 L
.12433 .39281 L
.15632 .41097 L
.18877 .42596 L
.26285 .45122 L
.30526 .46151 L
.3519 .47005 L
.37396 .47318 L
.39503 .47568 L
.41437 .47754 L
.43499 .47911 L
.44574 .47976 L
.4576 .48033 L
.4684 .48074 L
.47852 .48101 L
.48464 .48113 L
.49045 .48121 L
.50136 .48126 L
.5131 .48119 L
.51973 .48109 L
.52588 .48096 L
.5362 .48066 L
.54732 .48021 L
.5674 .47909 L
.58684 .47761 L
.60458 .47592 L
.64438 .47087 L
.68524 .46375 L
.72553 .45457 L
.76055 .44457 L
.79616 .43212 L
.832 .41667 L
.86223 .40069 L
.88736 .3846 L
.92825 .34961 L
.94468 .32989 L
.95222 .31867 L
.95836 .30781 L
.96313 .29762 L
.96734 .28636 L
.96885 .28138 L
.97024 .27604 L
.97125 .27136 L
Mistroke
.97213 .2664 L
.97258 .26332 L
.97297 .25993 L
.97344 .25397 L
.97358 .25062 L
.97362 .24701 L
.97356 .24362 L
.97343 .24052 L
.97294 .23452 L
.97254 .23114 L
.97208 .22802 L
.97103 .22229 L
.96962 .21623 L
.96625 .20522 L
.96218 .19499 L
.94963 .17215 L
.93434 .15211 L
.91361 .13123 L
.88773 .11083 L
.86003 .09329 L
.80256 .06576 L
.76656 .05272 L
.73182 .04243 L
.69303 .03315 L
.65026 .02524 L
.61266 .02008 L
.59094 .0178 L
.57043 .0161 L
.55907 .01535 L
.54664 .01467 L
.53487 .01417 L
.52393 .01383 L
.51308 .01361 L
.50325 .01351 L
.49189 .01351 L
.48121 .01362 L
.4695 .01388 L
.46361 .01406 L
.45716 .0143 L
.43515 .01542 L
.42279 .01626 L
.40961 .01734 L
.38602 .01972 L
.34058 .02605 L
.29991 .03384 L
.25715 .04451 L
.21442 .05821 L
.15024 .0864 L
.11868 .10515 L
.09278 .12432 L
Mistroke
.07077 .14483 L
.054 .16492 L
.04046 .18675 L
.03499 .19856 L
.03046 .21133 L
.02767 .22238 L
.02654 .22864 L
.02579 .23442 L
.02535 .23949 L
.02512 .24507 L
.02515 .25089 L
.02543 .25633 L
.02593 .26162 L
.02663 .26663 L
.02742 .27112 L
.02848 .276 L
.03156 .28686 L
.03528 .29684 L
.04583 .31745 L
.06123 .33894 L
.07944 .35831 L
.09914 .37517 L
.15496 .41028 L
.18783 .42557 L
.227 .44032 L
.26706 .45237 L
.30698 .46188 L
.34423 .46883 L
.38583 .47465 L
.40777 .47695 L
.43216 .47892 L
.44451 .47969 L
.45782 .48034 L
.46428 .4806 L
.47042 .4808 L
.48197 .48108 L
.49274 .48123 L
.50422 .48126 L
.51505 .48117 L
.52487 .48099 L
.53643 .48065 L
.54892 .48014 L
.56068 .47951 L
.57147 .47881 L
.61269 .47503 L
.63546 .47216 L
.65594 .46906 L
.73034 .45331 L
.76922 .44177 L
.80874 .42706 L
Mistroke
.84279 .41132 L
.87176 .39494 L
.91849 .35936 L
.93789 .33867 L
.94631 .32762 L
.95426 .31527 L
.96039 .30372 L
.96566 .29121 L
.96801 .28422 L
.96979 .27784 L
.97126 .27133 L
.9723 .26531 L
.97299 .25971 L
.97345 .25378 L
.97362 .24782 L
.97358 .24444 L
.97346 .24127 L
.97304 .23556 L
.97243 .23035 L
.97143 .22435 L
.97022 .21867 L
.96678 .20675 L
.96246 .19564 L
.95166 .17531 L
.93612 .15418 L
.91498 .13247 L
.89289 .11454 L
.86624 .09692 L
.81082 .06915 L
.77566 .05577 L
.74157 .04511 L
.70296 .03532 L
.65916 .0267 L
.63897 .02352 L
.61727 .02063 L
.59693 .01838 L
.5777 .01666 L
.55965 .01538 L
.54012 .01438 L
.52952 .01399 L
.51837 .0137 L
.50883 .01355 L
.49842 .01349 L
.49266 .0135 L
.48657 .01355 L
.47568 .01373 L
.46396 .01405 L
.45732 .01429 L
.45112 .01456 L
.42973 .01577 L
Mistroke
.40693 .01758 L
.38501 .01984 L
.36446 .02243 L
.32664 .02848 L
.28394 .03751 L
.24618 .04771 L
.20739 .0608 L
.16872 .07713 L
.13766 .09338 L
.11202 .10968 L
.07053 .14508 L
.05367 .16538 L
.03956 .18852 L
.03422 .20048 L
.0318 .20712 L
.02985 .21342 L
.02834 .21932 L
.02702 .22575 L
.02612 .2316 L
.02554 .23701 L
.02518 .24282 L
.0251 .24834 L
.02524 .2533 L
.02563 .2587 L
.02631 .26455 L
.02682 .26781 L
.02735 .27076 L
.03002 .28187 L
.03341 .29212 L
.03806 .30308 L
.04905 .32254 L
.0663 .34483 L
.08921 .36709 L
.11479 .38655 L
.14133 .40296 L
.2031 .43172 L
.2412 .44491 L
.27953 .45559 L
.31407 .46334 L
.35198 .47006 L
.37218 .47295 L
.39474 .47565 L
.41556 .47765 L
.43507 .47912 L
.45594 .48026 L
.46701 .48069 L
.47317 .48088 L
.47885 .48102 L
.48484 .48113 L
.49132 .48122 L
Mistroke
.50309 .48126 L
.51379 .48118 L
.52511 .48098 L
.53491 .4807 L
.54541 .4803 L
.56433 .47929 L
.58669 .47763 L
.60696 .47567 L
.65108 .46984 L
.69762 .46117 L
.73964 .45078 L
.77654 .43929 L
.80576 .42829 L
Mfstroke
.92183 .35774 m
.93971 .33838 L
.9532 .31952 L
.96435 .29811 L
.96889 .28586 L
.97193 .2746 L
.97307 .26883 L
.97399 .26269 L
.97453 .25744 L
.97487 .25165 L
.97493 .24544 L
.97482 .24194 L
.97464 .23875 L
.97405 .23256 L
.9732 .22668 L
.97217 .22126 L
.97081 .2155 L
.96767 .20518 L
.96281 .19304 L
.95735 .18218 L
.94133 .15819 L
.9223 .13712 L
.89692 .11539 L
.86536 .09426 L
.80249 .06357 L
.7621 .04913 L
.72186 .03772 L
.68088 .02861 L
.65862 .0246 L
.63456 .02094 L
.6133 .01826 L
.58957 .01586 L
.56779 .01418 L
.55798 .01358 L
.54722 .01304 L
.53669 .01262 L
.52688 .01233 L
.51651 .01213 L
.50542 .01203 L
.49508 .01205 L
.48532 .01217 L
.47656 .01236 L
.46707 .01264 L
.4567 .01306 L
.44531 .01364 L
.4224 .01522 L
.40133 .01714 L
.3818 .01936 L
.33902 .02571 L
.29399 .03483 L
Mistroke
.2534 .04551 L
.21779 .05716 L
.15694 .08349 L
.12716 .10049 L
.10311 .11716 L
.08057 .13632 L
.06077 .1577 L
.04728 .17675 L
.03624 .19827 L
.03177 .21062 L
.02882 .22197 L
.02766 .22828 L
.02714 .23184 L
.02676 .23514 L
.0263 .24119 L
.02618 .24425 L
.02614 .24762 L
.0263 .25363 L
.02671 .25912 L
.02745 .26513 L
.02794 .26815 L
.02855 .27144 L
.03142 .28291 L
.03508 .29347 L
.04031 .30521 L
.04617 .31586 L
.06297 .3392 L
.08175 .35878 L
.10541 .37827 L
.15499 .40868 L
.18747 .4238 L
.2203 .43643 L
.25751 .44817 L
.30037 .45894 L
.34269 .46714 L
.38316 .47299 L
.42028 .47679 L
.44167 .47834 L
.46188 .47939 L
.47223 .47977 L
.48315 .48006 L
.49249 .48021 L
.50271 .48029 L
.51375 .48025 L
.51993 .48018 L
.52555 .48008 L
.53647 .4798 L
.54678 .47943 L
.55695 .47896 L
.56787 .47833 L
Mistroke
.58751 .47691 L
.61068 .47472 L
.63166 .47222 L
.67626 .46524 L
.71715 .4566 L
.78444 .43675 L
.81925 .42297 L
.84905 .40861 L
.87868 .39124 L
.90674 .37069 L
.92912 .3498 L
.94595 .32951 L
.95792 .31041 L
.9633 .29933 L
.96738 .28886 L
.96921 .28314 L
.97069 .27769 L
.97182 .27273 L
.97281 .26745 L
.97362 .26169 L
.97412 .25636 L
.97441 .25062 L
.97445 .24736 L
.97441 .24429 L
.97415 .23877 L
.97359 .23288 L
.97281 .22733 L
.97188 .2223 L
.96873 .21003 L
.96462 .19857 L
.95922 .18683 L
.95323 .17617 L
.93616 .15281 L
.91923 .13507 L
.89736 .11661 L
.84361 .08317 L
.80927 .06731 L
.77393 .054 L
.73978 .04346 L
.70159 .03391 L
.65842 .02554 L
.61711 .01965 L
.59132 .01694 L
.57857 .01585 L
.56682 .015 L
.55627 .01436 L
.54467 .01379 L
.533 .01334 L
.52661 .01316 L
.52066 .01302 L
Mistroke
.5093 .01286 L
.50357 .01282 L
.49725 .01282 L
.48609 .01292 L
.47564 .01312 L
.46935 .0133 L
.46337 .0135 L
.45215 .01397 L
.44011 .01462 L
.42701 .0155 L
.40506 .01736 L
.38187 .01988 L
.3409 .02581 L
.29923 .03394 L
.26155 .04337 L
.1963 .06542 L
.16519 .07924 L
.13402 .09605 L
.10695 .11396 L
.08186 .13467 L
.06231 .15527 L
.04799 .1749 L
.04232 .18459 L
.03709 .19528 L
.03303 .20554 L
.03009 .21502 L
.02882 .22013 L
.02768 .22573 L
.0268 .23138 L
.02616 .23733 L
.02584 .2426 L
.02575 .24823 L
.0259 .25354 L
.02625 .25836 L
.02655 .26134 L
.02696 .2645 L
.0279 .27015 L
.0292 .2762 L
.03098 .28284 L
.03509 .29462 L
.03999 .30552 L
.05408 .3286 L
.07096 .34882 L
.09495 .37088 L
.12194 .39035 L
.18025 .42142 L
.21746 .43616 L
.25362 .44779 L
.28931 .45715 L
.32955 .46555 L
Mistroke
.36885 .47182 L
.40583 .47614 L
.42745 .478 L
.44728 .47929 L
.45829 .47983 L
.46411 .48007 L
.47028 .48029 L
.48163 .48059 L
.49212 .48076 L
.5017 .48082 L
.51202 .48079 L
.52176 .48066 L
.53068 .48045 L
.54056 .48014 L
.55134 .47969 L
.57298 .47842 L
.59685 .47647 L
.61832 .4742 L
.66555 .46738 L
.70781 .45893 L
.74598 .44912 L
.81656 .42404 L
.84828 .40885 L
.87966 .39035 L
.9033 .37317 L
.92518 .35347 L
.94234 .33384 L
.95488 .31519 L
.96076 .3041 L
.96532 .29354 L
.96908 .28241 L
.97067 .27638 L
.97202 .27001 L
.97286 .2649 L
.97354 .2593 L
.97393 .2542 L
.9741 .24945 L
.97407 .24382 L
.97381 .23871 L
.97325 .23282 L
.97246 .22726 L
.97142 .2217 L
.96997 .21561 L
.96612 .20337 L
.96145 .19216 L
.95612 .18179 L
.94082 .15908 L
.91945 .13583 L
.89505 .11542 L
.86888 .09782 L
Mistroke
.8337 .07879 L
.79837 .06346 L
.72554 .04019 L
.68227 .0304 L
.63989 .02316 L
.59956 .0182 L
.57632 .01614 L
.55447 .0147 L
.54257 .01412 L
.53127 .0137 L
.52112 .01343 L
.51006 .01325 L
.50435 .01321 L
.49804 .0132 L
.49146 .01323 L
.48528 .01329 L
.47425 .0135 L
.46805 .01368 L
.46238 .01387 L
.44256 .01478 L
.4242 .01599 L
.40419 .0177 L
.383 .01997 L
.34044 .02605 L
.30293 .03323 L
.26411 .0427 L
.22512 .05464 L
.16181 .08078 L
.13088 .09776 L
.1051 .11509 L
.08077 .13538 L
.059 .15895 L
.05073 .17024 L
.04318 .1825 L
.03771 .19328 L
.03292 .20506 L
.03084 .21143 L
.02922 .2173 L
.02797 .22282 L
.02689 .2289 L
.02618 .23437 L
.02574 .23947 L
.02551 .24487 L
.02553 .25065 L
.02582 .2564 L
.02633 .26171 L
.02716 .26753 L
.02835 .27369 L
.03104 .28396 L
.03503 .29519 L
Mistroke
.04513 .31551 L
.05777 .33398 L
.07611 .35451 L
.10046 .37565 L
.12543 .39299 L
.1554 .41001 L
.18815 .42523 L
.22026 .43755 L
.28856 .45736 L
.32838 .46571 L
.37198 .47259 L
.41013 .47688 L
.43207 .47865 L
.45271 .47987 L
.46418 .48036 L
.47024 .48057 L
.47669 .48075 L
.48231 .48088 L
.48852 .48098 L
.49948 .48107 L
.51008 .48105 L
.52151 .4809 L
.5323 .48064 L
.54218 .4803 L
.5537 .47978 L
.5644 .47918 L
.58857 .47739 L
.61192 .47507 L
.63658 .47199 L
.68149 .46453 L
.7214 .45571 L
.76308 .44391 L
.80434 .42907 L
.86556 .39901 L
.89511 .37931 L
.91889 .35936 L
.93821 .33873 L
.9468 .32742 L
.9547 .3151 L
.96103 .30305 L
.96569 .29198 L
.96934 .28073 L
.97063 .27565 L
.9718 .27006 L
.97269 .26464 L
.9733 .25956 L
.97372 .2542 L
.97391 .24845 L
.97384 .24311 L
.97356 .23805 L
Mistroke
.97312 .23351 L
.97246 .22859 L
.97152 .22323 L
.9702 .21735 L
.96667 .20551 L
.96236 .19467 L
.95742 .18462 L
.94429 .16399 L
.92578 .14238 L
.90206 .12112 L
.87622 .10272 L
.82163 .07349 L
.787 .05946 L
.75337 .04826 L
.71547 .03796 L
.67346 .02898 L
.63635 .02291 L
.59454 .01794 L
.57068 .01594 L
.54875 .01461 L
.53658 .01408 L
.53015 .01386 L
.5233 .01367 L
.51671 .01353 L
.51074 .01344 L
.4991 .01337 L
.4875 .01343 L
.47685 .0136 L
.46517 .01392 L
.4593 .01413 L
.45287 .0144 L
.4305 .01566 L
.40978 .01729 L
.38691 .0196 L
.36602 .02222 L
.31982 .02981 L
.28058 .03841 L
.24089 .04945 L
.17793 .07307 L
.14597 .08892 L
.11892 .10522 L
.09373 .1238 L
.0704 .14554 L
.05261 .16724 L
.04562 .17795 L
.03997 .18821 L
.0353 .19839 L
.03125 .20953 L
.02979 .21448 L
.02847 .21973 L
Mistroke
.02745 .22467 L
.02669 .22918 L
.02601 .23444 L
.02554 .2401 L
.02534 .24535 L
.02536 .25032 L
.02563 .25609 L
.02613 .26142 L
.02695 .26727 L
.02813 .27346 L
.031 .28438 L
.03509 .29577 L
.04509 .31577 L
.05961 .33659 L
.07979 .35833 L
.10076 .37612 L
.12648 .39389 L
.18067 .42224 L
.21776 .4369 L
.25444 .44865 L
.29704 .45952 L
.34433 .46867 L
.36466 .47177 L
.3868 .47461 L
.40615 .47666 L
.42741 .47846 L
.44039 .47934 L
.45246 .47999 L
.46403 .48049 L
.46996 .48069 L
.47637 .48087 L
.4827 .48101 L
.48853 .4811 L
.49997 .48119 L
.51038 .48115 L
.52135 .481 L
.53227 .48073 L
.53843 .48053 L
.54411 .48031 L
.56557 .47918 L
.58495 .47776 L
.60538 .47584 L
.64712 .47049 L
.69178 .46247 L
.7285 .45388 L
.7662 .44287 L
.82849 .41848 L
.85948 .40244 L
.88542 .38614 L
.91237 .36516 L
Mistroke
.93287 .3448 L
.95018 .3222 L
.96225 .30007 L
.96709 .28765 L
.97039 .27609 L
.97168 .27001 L
.97274 .26332 L
.97314 .25994 L
.97346 .25631 L
.97366 .25289 L
.97376 .24976 L
.97375 .24429 L
.97351 .23915 L
.973 .23352 L
.97215 .22745 L
.97102 .22146 L
.96951 .21517 L
.96598 .20399 L
.96179 .19372 L
.95709 .18427 L
.94362 .16331 L
.92454 .14133 L
.90346 .12242 L
.87668 .10319 L
.84432 .08456 L
.81351 .07011 L
.77673 .05597 L
.70582 .03583 L
.66316 .02726 L
.63897 .02341 L
.61563 .02033 L
.59375 .01798 L
.56964 .01597 L
.55897 .01527 L
.54757 .01465 L
.53694 .01419 L
.527 .01386 L
.5159 .0136 L
.51002 .01352 L
.50372 .01346 L
.49711 .01345 L
.49085 .01347 L
.47913 .01363 L
.46818 .01389 L
.45807 .01424 L
.44699 .01474 L
.43525 .0154 L
.41116 .0172 L
.38875 .01943 L
.33866 .02641 L
Mistroke
.29668 .03461 L
.25975 .04386 L
.22155 .05577 L
.18351 .07055 L
.15033 .08648 L
.12305 .10243 L
.07848 .13723 L
.05904 .1585 L
.0505 .17012 L
.04278 .18268 L
.03716 .19385 L
.03221 .20631 L
.03045 .21181 L
.02884 .21775 L
.02761 .22329 L
.02669 .22852 L
.02626 .2315 L
.02588 .23472 L
.02543 .24035 L
.02528 .24354 L
.02522 .24692 L
.02535 .25295 L
.02574 .25854 L
.02633 .26374 L
.02723 .26944 L
.02849 .27552 L
.03246 .28913 L
.03763 .30185 L
.05093 .3251 L
.06785 .34634 L
.087 .36501 L
.1115 .38412 L
.14183 .40309 L
.17338 .41909 L
.20483 .43225 L
.27261 .45373 L
.31335 .4631 L
.33556 .46728 L
.35969 .47115 L
.3832 .47427 L
.40479 .47661 L
.42669 .47848 L
.44747 .47981 L
.45778 .4803 L
.46885 .48072 L
.47932 .481 L
.48888 .48116 L
.50009 .48124 L
.50642 .48123 L
.51228 .48118 L
Mistroke
.52303 .48101 L
.53444 .48071 L
.54526 .4803 L
.55691 .47972 L
.5779 .47835 L
.60268 .47613 L
.62516 .47355 L
.66182 .46812 L
.70078 .46053 L
.73983 .45079 L
.77439 .4401 L
.81023 .42652 L
.84594 .40979 L
.87435 .39341 L
.90102 .37453 L
.92178 .35633 L
.94082 .33516 L
.9545 .31505 L
.96405 .29565 L
.96822 .28385 L
.97105 .2728 L
.97222 .26642 L
.97299 .26061 L
.9733 .25739 L
.97354 .25391 L
.97367 .25062 L
.97371 .24759 L
.97359 .24207 L
.97326 .23693 L
.97265 .23129 L
.9717 .22527 L
.97039 .21897 L
.96884 .21303 L
.96516 .20198 L
.96085 .19186 L
.95533 .18126 L
.94303 .16266 L
.92649 .14343 L
.90444 .12332 L
.87935 .10503 L
.8494 .08732 L
.7878 .06 L
.74956 .04735 L
.71193 .03733 L
.66872 .02832 L
.64565 .02447 L
.62084 .02102 L
.59873 .01852 L
.57417 .01635 L
.56334 .01559 L
Mistroke
.55167 .0149 L
.5407 .01438 L
.53053 .014 L
.52436 .01382 L
.5178 .01367 L
.51121 .01357 L
.50392 .0135 L
.49766 .01348 L
.49091 .0135 L
.48453 .01357 L
.47867 .01366 L
.46768 .01393 L
.46146 .01413 L
.45567 .01436 L
.44407 .01491 L
.43151 .01566 L
.4084 .01746 L
.38674 .01966 L
.34685 .02506 L
.3017 .03349 L
.26176 .04328 L
.22639 .05408 L
.19066 .06747 L
.13323 .09606 L
.1034 .11603 L
.0791 .13655 L
.06091 .1561 L
.04516 .17842 L
.039 .18981 L
.03359 .20231 L
.03154 .20811 L
.02969 .21426 L
.02835 .21959 L
.02717 .22533 L
.02628 .23092 L
.0257 .23603 L
.02532 .24117 L
.02517 .24604 L
.02524 .2517 L
.02554 .25694 L
.02613 .26267 L
.02705 .26876 L
.02825 .27472 L
.02961 .28016 L
.03357 .29234 L
.03809 .30296 L
.04386 .31399 L
.05953 .33675 L
.08177 .3604 L
.10665 .38074 L
Mistroke
.13378 .39853 L
.19303 .42766 L
.23044 .44141 L
.2672 .45236 L
.30968 .4624 L
.35663 .47074 L
.37835 .47372 L
.39922 .47609 L
.41836 .47786 L
.43887 .47934 L
.45059 .47999 L
.46122 .48047 L
.47194 .48084 L
.48202 .48108 L
.48778 .48117 L
.49385 .48123 L
.50472 .48125 L
.51641 .48115 L
.52304 .48103 L
.52922 .48088 L
.53938 .48054 L
.5504 .48007 L
.57035 .4789 L
.58966 .47738 L
.60737 .47564 L
.64699 .4705 L
.68787 .46325 L
.72747 .4541 L
.76209 .44413 L
.79729 .43172 L
.83293 .41627 L
.88543 .38601 L
.90946 .36753 L
.92862 .34929 L
.94627 .32776 L
.95386 .31605 L
.96057 .30344 L
.96533 .29225 L
.96742 .28626 L
.96933 .27981 L
.97078 .27386 L
.97185 .26841 L
.97267 .26292 L
.97323 .25771 L
.97355 .25276 L
.97367 .24728 L
.97353 .24156 L
.97315 .2362 L
.97259 .23121 L
.9719 .22664 L
Mistroke
.9697 .21639 L
.96659 .20606 L
.96217 .19486 L
.95009 .17278 L
.93278 .15026 L
.91236 .13006 L
.86431 .09572 L
.83234 .07876 L
.79998 .06469 L
.76196 .0512 L
.71831 .03892 L
.67717 .02992 L
.63818 .02339 L
.61906 .02083 L
.59797 .01847 L
.57802 .01667 L
.5591 .01534 L
.54751 .01471 L
.53495 .01417 L
.52351 .01382 L
.51299 .0136 L
.50155 .0135 L
.49507 .01349 L
.48901 .01353 L
.48262 .0136 L
.47679 .01371 L
.47008 .01387 L
.46372 .01406 L
.45305 .01447 L
.44174 .01504 L
.42152 .01637 L
.39991 .01826 L
.37631 .02089 L
.33429 .02714 L
.29154 .03574 L
.25654 .04472 L
.22015 .0562 L
.18339 .07053 L
.14751 .08791 L
.09307 .12413 L
.07011 .14557 L
.05294 .16645 L
.03871 .19032 L
.03342 .20265 L
.03101 .20967 L
.0291 .21637 L
.02775 .22217 L
.0266 .22851 L
.02584 .23429 L
.02538 .23965 L
Mistroke
.02522 .24294 L
.02514 .24603 L
.02521 .2518 L
.02538 .25504 L
.0256 .25801 L
.02593 .26127 L
.02637 .26471 L
.02726 .27009 L
.02847 .27582 L
.03135 .28611 L
.03591 .29823 L
.04113 .3091 L
.05447 .33024 L
.07279 .35172 L
.11574 .38716 L
.14473 .40481 L
.17488 .41988 L
.21067 .43454 L
.25284 .44838 L
.29529 .45931 L
.33653 .46752 L
.37724 .47359 L
.40043 .47623 L
.42168 .47814 L
.43192 .4789 L
.44277 .47958 L
.45217 .48008 L
.46227 .48052 L
.47315 .48088 L
.48333 .48111 L
.48955 .4812 L
.49544 .48125 L
.50649 .48125 L
.51616 .48115 L
.52644 .48095 L
.5352 .4807 L
.54486 .48033 L
.56629 .47917 L
.5863 .47767 L
.60758 .47561 L
.62719 .47328 L
.67085 .46651 L
.71192 .45795 L
.75379 .44669 L
.79057 .43426 L
.82299 .4209 L
.87662 .39188 L
.90065 .37475 L
.92346 .35457 L
.94297 .33224 L
Mistroke
.9507 .32113 L
.95703 .31039 L
.96195 .3004 L
.96635 .28937 L
.96946 .27925 L
.97158 .2698 L
.97251 .264 L
.97313 .25853 L
.97348 .25361 L
.97364 .2483 L
.97354 .24248 L
.97314 .23635 L
.97256 .23113 L
.97166 .22541 L
.97041 .21936 L
.96899 .2138 L
.96482 .2013 L
.96008 .19041 L
.95395 .17903 L
.94076 .15982 L
.92252 .13953 L
.89907 .11915 L
.86945 .09883 L
.83791 .0815 L
.80564 .06699 L
.73504 .04328 L
.69454 .03346 L
.64945 .0251 L
.62606 .02173 L
.60038 .01872 L
.57585 .01651 L
.56409 .01566 L
.55307 .015 L
.54227 .01447 L
.53239 .01408 L
.5214 .01377 L
.51534 .01365 L
.50959 .01356 L
.49814 .01349 L
.48753 .01354 L
.47589 .01373 L
.47001 .01387 L
.46352 .01407 L
.45274 .01449 L
.44271 .01498 L
.42004 .01648 L
.39811 .01843 L
.37489 .02106 L
.3336 .02725 L
.29718 .03446 L
Mistroke
.25637 .04475 L
.21461 .05816 L
.17825 .07277 L
.14701 .08816 L
.09555 .12207 L
.07347 .14205 L
.05412 .16479 L
.04623 .17656 L
.03901 .18966 L
.03356 .20224 L
.03143 .2083 L
.0297 .21404 L
.02827 .2197 L
.02703 .22583 L
.02616 .23141 L
.0256 .23656 L
.02523 .24215 L
.02512 .24828 L
.02518 .25138 L
.02534 .25469 L
.02584 .26066 L
.02659 .26631 L
.02772 .27253 L
.02925 .279 L
.03099 .28505 L
.03486 .29576 L
.0401 .30717 L
.05609 .33244 L
.07554 .35451 L
.09636 .37296 L
.12279 .39181 L
.15391 .40972 L
.18645 .42497 L
.22119 .43832 L
.26148 .45084 L
.2968 .45966 L
.33722 .46765 L
.38247 .47425 L
.40772 .47694 L
.43157 .47888 L
.44308 .47961 L
.45403 .48017 L
.46387 .48058 L
.47462 .48092 L
.4863 .48116 L
.49282 .48123 L
.49873 .48126 L
.51025 .48123 L
.52108 .48107 L
.5315 .48081 L
Mistroke
.54264 .48042 L
.55313 .47993 L
.56266 .4794 L
.58589 .4777 L
.60769 .4756 L
.65034 .46997 L
.69525 .46169 L
.73263 .45271 L
.77038 .4414 L
.8321 .41664 L
.86234 .40064 L
.88728 .38467 L
.91095 .3662 L
.93276 .34469 L
.94891 .32385 L
.95535 .3134 L
.96037 .30378 L
.96446 .2944 L
.96805 .28414 L
.96965 .27846 L
.97088 .27321 L
.97184 .26826 L
.97265 .26286 L
.97325 .25701 L
.97356 .25145 L
.97362 .24604 L
.97347 .24104 L
.97307 .23565 L
.97235 .22971 L
.97129 .22353 L
.97 .21773 L
.96697 .20728 L
.96339 .19777 L
.95256 .17674 L
.93769 .15604 L
.91718 .13445 L
.89127 .11334 L
.86333 .09519 L
.83243 .07884 L
.79555 .063 L
.76046 .05075 L
.721 .03961 L
.68373 .03123 L
.64119 .02385 L
.62213 .02123 L
.60142 .01884 L
.5816 .01697 L
.56351 .01563 L
.55269 .01498 L
.54096 .01441 L
Mistroke
.53449 .01416 L
.52854 .01396 L
.51683 .01367 L
.50674 .01353 L
.49568 .0135 L
.48412 .01358 L
.47335 .01378 L
.46723 .01395 L
.46059 .01417 L
.44852 .01468 L
.42601 .01603 L
.39993 .01825 L
.37607 .02091 L
.33648 .02675 L
.2942 .03512 L
.25199 .046 L
.21461 .05815 L
.14873 .08722 L
.12005 .10425 L
.09255 .12452 L
.07241 .14312 L
.05466 .16403 L
.04161 .18459 L
.03298 .20377 L
.0296 .21438 L
.02809 .22045 L
.02696 .22613 L
.02606 .23214 L
.0255 .23764 L
.02529 .24068 L
.02515 .24399 L
.02514 .25002 L
.02539 .25567 L
.02585 .26078 L
.02664 .26667 L
.02764 .27219 L
.03006 .28199 L
.03356 .29249 L
.03845 .30387 L
.04505 .31614 L
.06224 .34014 L
.0826 .36124 L
.10519 .37974 L
.13238 .39776 L
.16564 .41558 L
.19789 .42967 L
.23474 .44286 L
.26996 .45313 L
.31069 .46265 L
.34916 .46962 L
Mistroke
.3862 .47469 L
.40866 .47703 L
.42969 .47875 L
.44163 .47952 L
.45292 .48012 L
.45918 .4804 L
.46596 .48066 L
.47209 .48085 L
.47781 .481 L
.48844 .48119 L
.50012 .48126 L
.51149 .48121 L
.51787 .48113 L
.52369 .48102 L
.53405 .48073 L
.54531 .4803 L
.56573 .4792 L
.5853 .47775 L
.60673 .4757 L
.64944 .4701 L
.68791 .46322 L
.7228 .45527 L
.79668 .43192 L
.83018 .41754 L
.86353 .39994 L
.88908 .38339 L
.91302 .36438 L
.93092 .34673 L
.94662 .32718 L
.95381 .31604 L
.96047 .30356 L
.96541 .29192 L
.96891 .28116 L
.97057 .27462 L
.97181 .26839 L
.97277 .26179 L
.97316 .25806 L
.97341 .25459 L
.97356 .25132 L
.97362 .24824 L
.97353 .2425 L
.97335 .23927 L
.97312 .23631 L
.97278 .23307 L
.97233 .22965 L
.97134 .22383 L
.97019 .21854 L
.96678 .20675 L
.96259 .19593 L
.95773 .18581 L
Mistroke
.94371 .16371 L
.92376 .14078 L
.90216 .12161 L
.87878 .10476 L
.84731 .08631 L
.8153 .07106 L
.74193 .04521 L
.69981 .03462 L
.65345 .02575 L
.63143 .02246 L
.6104 .01982 L
.59108 .01782 L
.5705 .01611 L
.55974 .01539 L
.54789 .01473 L
.53696 .01425 L
.52697 .01391 L
.52091 .01376 L
.51517 .01364 L
.5091 .01356 L
.50249 .0135 L
.49673 .01349 L
.4906 .01352 L
.4796 .01365 L
.46952 .01388 L
.46029 .01418 L
.45017 .0146 L
.43953 .01516 L
.42167 .01635 L
.40223 .01802 L
.35895 .02321 L
.3197 .02979 L
.27867 .0388 L
.23635 .05076 L
.20128 .06314 L
.16679 .07806 L
.13834 .09299 L
.11021 .11097 L
.08931 .12724 L
.06962 .14605 L
.05168 .16819 L
.04492 .1787 L
.03879 .19009 L
.03382 .20152 L
.03027 .212 L
.02888 .21708 L
.02763 .2226 L
.02673 .22745 L
.02599 .23264 L
.02541 .23871 L
Mistroke
.02514 .24437 L
.0251 .24784 L
.02516 .25111 L
.0255 .25725 L
.0258 .26038 L
.0262 .2637 L
.02715 .26966 L
.02849 .27604 L
.03037 .28306 L
.03429 .29439 L
.03971 .30644 L
.05262 .32774 L
.06985 .34869 L
.08935 .36721 L
.11666 .38781 L
.14505 .40502 L
.2126 .43528 L
.25432 .44883 L
.29613 .45952 L
.33437 .46716 L
.3778 .47368 L
.4001 .4762 L
.42429 .47835 L
.43608 .47918 L
.4473 .47984 L
.45838 .48037 L
.46843 .48074 L
.47863 .48102 L
.48824 .48118 L
.49839 .48126 L
.50934 .48123 L
.51896 .48111 L
.5291 .48088 L
.53775 .4806 L
.54721 .48022 L
.56856 .47902 L
.59125 .47723 L
.61248 .47506 L
.63162 .47269 L
.67258 .46618 L
.71452 .45731 L
.78469 .43641 L
.82016 .42214 L
.85073 .40715 L
.88073 .38915 L
.90922 .36768 L
.9317 .34586 L
.94846 .32449 L
.96059 .30329 L
.96568 .29117 L
Mistroke
.96921 .28007 L
.97054 .27472 L
.97169 .26905 L
.97246 .2642 L
.97308 .25886 L
.97348 .25311 L
.97359 .24988 L
.97362 .24694 L
.97346 .24123 L
.97307 .23582 L
.97249 .23079 L
.97164 .22546 L
.96953 .21592 L
.96643 .20573 L
.962 .19458 L
.95004 .17278 L
.93311 .1507 L
.91527 .13273 L
.89238 .11416 L
.86394 .09556 L
.82965 .07753 L
.75901 .05031 L
.71774 .03881 L
.67779 .03007 L
.63225 .02257 L
.60876 .01963 L
.5826 .01706 L
.57075 .01613 L
.55946 .01537 L
.54917 .0148 L
.53819 .0143 L
.53194 .01407 L
.52627 .01389 L
.5152 .01364 L
.50899 .01356 L
.50227 .0135 L
.49592 .01349 L
.49009 .01352 L
.47965 .01365 L
.46992 .01387 L
.45926 .01422 L
.44786 .01471 L
.42467 .01613 L
.4037 .01788 L
.3619 .02279 L
.31871 .02998 L
.2831 .03771 L
.24547 .04793 L
.20741 .06079 L
.16947 .07678 L
Mistroke
.13718 .09366 L
.11033 .11088 L
.08596 .13015 L
.06715 .14875 L
.05014 .17043 L
.04253 .18287 L
.03672 .19452 L
.03216 .20606 L
.02856 .21838 L
.02719 .22481 L
.02622 .23084 L
.0258 .2343 L
.0255 .23747 L
.02526 .24112 L
.02513 .24459 L
.02514 .25033 L
.02544 .25643 L
.02593 .26163 L
.02674 .26737 L
.02791 .27349 L
.02951 .28007 L
.03333 .2919 L
.03788 .30269 L
.04384 .31408 L
.05734 .33409 L
.07786 .35681 L
.10055 .37626 L
.12803 .39513 L
.1619 .41377 L
.19712 .42938 L
.23281 .44224 L
.27056 .4533 L
.30679 .46184 L
.34858 .46953 L
.37248 .47299 L
.39496 .47567 L
.41682 .47775 L
.44031 .47944 L
.4538 .48016 L
.46043 .48045 L
.46653 .48068 L
.47799 .481 L
.48402 .48112 L
.4904 .48121 L
.50129 .48126 L
.51297 .48119 L
.52398 .48101 L
.53401 .48073 L
.54575 .48028 L
.55849 .47964 L
Mistroke
.58155 .47806 L
.60203 .47619 L
.62389 .47369 L
.66275 .46793 L
.70745 .45897 L
.74661 .44879 L
.82035 .42206 L
.85311 .40585 L
.88508 .38619 L
.9111 .36605 L
.9318 .34575 L
.947 .32662 L
.95971 .30511 L
.96472 .29369 L
.96896 .28099 L
.97058 .27454 L
.97194 .2676 L
.97245 .26423 L
.97285 .26103 L
.97338 .25502 L
.9736 .24939 L
.97355 .24341 L
.97324 .23776 L
.97273 .23266 L
.97185 .22664 L
.97057 .22017 L
.96736 .2085 L
.96333 .19766 L
.95793 .18621 L
.9454 .16603 L
.926 .14306 L
.90427 .1233 L
.87774 .10408 L
.84479 .085 L
.81035 .06896 L
.77529 .05564 L
.7024 .03519 L
.66105 .02702 L
.63921 .02356 L
.61501 .02035 L
.59244 .01794 L
.56814 .01594 L
.55461 .01509 L
.54229 .01447 L
.53633 .01423 L
.52988 .014 L
.51815 .0137 L
.50734 .01354 L
.50119 .0135 L
.49545 .01349 L
Mistroke
.48387 .01358 L
.47738 .01369 L
.47146 .01383 L
.46091 .01415 L
.44944 .01463 L
.42866 .01584 L
.40815 .01747 L
.3862 .0197 L
.34712 .02499 L
.30203 .03338 L
.26238 .04306 L
.18738 .06878 L
.15382 .08452 L
.12084 .10373 L
.09385 .12343 L
.07214 .14339 L
.05597 .16225 L
.04216 .18355 L
.03656 .19487 L
.03167 .20749 L
.02972 .2139 L
.028 .22081 L
.02674 .22737 L
.0259 .23337 L
.02536 .23932 L
.02512 .24483 L
.02515 .25089 L
.02529 .25427 L
.02551 .25734 L
.0261 .26296 L
.02703 .26903 L
.02819 .27474 L
.02949 .27998 L
.03308 .29124 L
.03728 .30139 L
.04984 .32372 L
.06525 .34364 L
.08304 .36165 L
.13336 .39836 L
.16758 .41652 L
.20249 .43148 L
.23619 .44333 L
.27467 .45436 L
.3095 .4624 L
.34895 .46959 L
.39405 .47557 L
.41908 .47794 L
.43114 .47885 L
.44255 .47958 L
.4532 .48014 L
Mistroke
.46475 .48061 L
.47527 .48094 L
.48498 .48114 L
.49549 .48125 L
.50705 .48125 L
.51287 .48119 L
.51912 .4811 L
.5304 .48084 L
.54011 .48051 L
.54889 .48014 L
.56849 .47902 L
.58654 .47764 L
.60341 .47604 L
.64083 .47139 L
.68022 .46474 L
.71413 .4574 L
.74852 .44824 L
.80576 .42829 L
Mfstroke
.92277 .35798 m
.94068 .33844 L
.95417 .31942 L
.96529 .29783 L
.96979 .28548 L
.97279 .27414 L
.97391 .26833 L
.9748 .26215 L
.97532 .25687 L
.97563 .25105 L
.97566 .24479 L
.97553 .24128 L
.97533 .23807 L
.97471 .23184 L
.97383 .22594 L
.97276 .22049 L
.97136 .2147 L
.96815 .20435 L
.96321 .19217 L
.95767 .18129 L
.94146 .15726 L
.92225 .13621 L
.89669 .11452 L
.86494 .09348 L
.80182 .06303 L
.76134 .04875 L
.72104 .0375 L
.68004 .02856 L
.65778 .02464 L
.63373 .02107 L
.61248 .01846 L
.58877 .01614 L
.56702 .01453 L
.55723 .01396 L
.54649 .01345 L
.53598 .01307 L
.52619 .01281 L
.51584 .01263 L
.50478 .01257 L
.49446 .01261 L
.48472 .01275 L
.47598 .01296 L
.46652 .01326 L
.45617 .0137 L
.44482 .01431 L
.42197 .01592 L
.40097 .01787 L
.3815 .02011 L
.33887 .02649 L
.294 .03561 L
Mistroke
.25356 .04626 L
.21809 .05785 L
.15745 .08402 L
.12775 .1009 L
.10377 .11745 L
.08126 .13647 L
.06149 .15771 L
.04799 .17663 L
.03691 .19802 L
.03241 .21031 L
.02943 .2216 L
.02825 .22787 L
.02775 .23119 L
.02733 .2347 L
.02705 .23777 L
.02682 .24116 L
.02666 .24713 L
.0268 .25311 L
.02719 .25858 L
.0279 .26458 L
.02837 .26758 L
.02897 .27086 L
.03178 .2823 L
.03538 .29284 L
.04055 .30456 L
.04634 .31519 L
.063 .33852 L
.08165 .35811 L
.1052 .37766 L
.15458 .40819 L
.18698 .42341 L
.21975 .43614 L
.25692 .448 L
.29975 .4589 L
.34208 .46722 L
.38257 .47317 L
.41973 .47707 L
.44115 .47867 L
.46138 .47976 L
.47175 .48016 L
.48269 .48046 L
.49205 .48064 L
.50229 .48072 L
.51335 .48071 L
.51954 .48064 L
.52517 .48055 L
.53612 .48029 L
.54644 .47993 L
.55664 .47947 L
.56758 .47886 L
Mistroke
.58727 .47746 L
.6105 .47527 L
.63153 .47279 L
.67625 .46581 L
.71724 .45716 L
.7847 .43722 L
.8196 .42337 L
.84947 .40895 L
.87915 .39147 L
.90725 .37081 L
.92965 .34982 L
.94647 .32943 L
.95842 .31025 L
.96378 .29912 L
.96784 .28861 L
.96966 .28286 L
.97112 .2774 L
.97225 .27242 L
.97321 .26712 L
.97401 .26135 L
.9745 .256 L
.97477 .25024 L
.9748 .24697 L
.97475 .24389 L
.97447 .23836 L
.97389 .23245 L
.97309 .22689 L
.97215 .22186 L
.96895 .20957 L
.9648 .19808 L
.9533 .17567 L
.94497 .16338 L
.93614 .15231 L
.89718 .11617 L
.87302 .09961 L
.84328 .08285 L
.80889 .06706 L
.77351 .05384 L
.73933 .04337 L
.70114 .03391 L
.65797 .02563 L
.61669 .01981 L
.59092 .01714 L
.57818 .01608 L
.56644 .01525 L
.5559 .01462 L
.54432 .01407 L
.53266 .01364 L
.52628 .01346 L
.52034 .01333 L
Mistroke
.50899 .01318 L
.50327 .01315 L
.49696 .01316 L
.48582 .01327 L
.47538 .01348 L
.4691 .01366 L
.46313 .01387 L
.45193 .01435 L
.43991 .01501 L
.42683 .01589 L
.40492 .01777 L
.38177 .0203 L
.34088 .02623 L
.29929 .03435 L
.26168 .04375 L
.19655 .06572 L
.16549 .07949 L
.13436 .09624 L
.10732 .11408 L
.08224 .1347 L
.06269 .15522 L
.04835 .17479 L
.04268 .18445 L
.03743 .19511 L
.03335 .20533 L
.0304 .21479 L
.02912 .21989 L
.02797 .22548 L
.02708 .23111 L
.02643 .23706 L
.02609 .24231 L
.02599 .24793 L
.02613 .25323 L
.02646 .25805 L
.02676 .26102 L
.02715 .26417 L
.02807 .26981 L
.02936 .27586 L
.03112 .28249 L
.0352 .29427 L
.04007 .30515 L
.05408 .32824 L
.07089 .34847 L
.09481 .37056 L
.12174 .39007 L
.17996 .42124 L
.21715 .43605 L
.25329 .44774 L
.28898 .45716 L
.32923 .46562 L
Mistroke
.36854 .47194 L
.40554 .47631 L
.42718 .47819 L
.44703 .4795 L
.45805 .48006 L
.47006 .48053 L
.48141 .48084 L
.49192 .48102 L
.50158 .48108 L
.51065 .48106 L
.52059 .48095 L
.53129 .48071 L
.5419 .48037 L
.55304 .47989 L
.57287 .47872 L
.59467 .47697 L
.61773 .47457 L
.65852 .46887 L
.70544 .45978 L
.74611 .44938 L
.78254 .4377 L
.81853 .42347 L
.87535 .39341 L
.90209 .3744 L
.92359 .35534 L
.94305 .3332 L
.95138 .32125 L
.95886 .30828 L
.96414 .29692 L
.96871 .28422 L
.97028 .27862 L
.97169 .27255 L
.97274 .26681 L
.97346 .26152 L
.97377 .25852 L
.97402 .2553 L
.97426 .24951 L
.97427 .24596 L
.97419 .24262 L
.97403 .23961 L
.97378 .23635 L
.97345 .23317 L
.973 .22967 L
.97177 .22261 L
.97026 .21609 L
.96854 .21001 L
.96424 .19813 L
.95908 .18698 L
.94659 .16654 L
.92918 .14541 L
Mistroke
.90572 .12362 L
.87857 .10384 L
.84948 .08673 L
.78698 .05917 L
.74795 .0464 L
.70996 .03644 L
.66634 .02753 L
.64198 .0236 L
.61855 .02046 L
.59786 .01818 L
.57514 .01621 L
.56507 .01551 L
.55435 .01487 L
.54427 .01438 L
.53502 .01401 L
.52433 .01369 L
.51279 .01348 L
.50261 .0134 L
.49189 .01342 L
.48011 .01358 L
.46916 .01385 L
.46288 .01406 L
.45717 .01428 L
.44438 .0149 L
.42353 .01626 L
.40444 .01789 L
.3619 .02295 L
.32531 .02896 L
.2878 .03688 L
.21557 .0582 L
.17876 .07299 L
.14791 .08817 L
.12189 .10361 L
.09667 .12178 L
.07748 .13871 L
.05995 .15795 L
.05109 .1699 L
.04409 .18111 L
.03852 .19178 L
.03354 .20364 L
.03009 .21442 L
.02774 .22453 L
.02681 .23015 L
.02619 .23526 L
.02575 .24118 L
.02559 .24678 L
.02569 .25237 L
.02586 .25555 L
.0261 .25853 L
.0268 .26452 L
Mistroke
.02733 .26788 L
.02789 .27095 L
.03065 .2823 L
.03427 .293 L
.03962 .30516 L
.04571 .31629 L
.0634 .34076 L
.08349 .3614 L
.10959 .38234 L
.13612 .39943 L
.16744 .41595 L
.19835 .42941 L
.23489 .44251 L
.2675 .45212 L
.30464 .46107 L
.34818 .46921 L
.36869 .47226 L
.39077 .47502 L
.41081 .47706 L
.43312 .47885 L
.44294 .47948 L
.45355 .48005 L
.46286 .48045 L
.47282 .48079 L
.48453 .48107 L
.49544 .4812 L
.50211 .48123 L
.50842 .48121 L
.52021 .48107 L
.52626 .48095 L
.53266 .48078 L
.54413 .48038 L
.55644 .47979 L
.56995 .47898 L
.59189 .47726 L
.61527 .47486 L
.65678 .4691 L
.70042 .46079 L
.73923 .45117 L
.77956 .43855 L
.81945 .42281 L
.85409 .40571 L
.88328 .38786 L
.90805 .36915 L
.92786 .35055 L
.94448 .33077 L
.95241 .31905 L
.95858 .30818 L
.96363 .29738 L
.968 .28549 L
Mistroke
.96989 .27892 L
.97132 .27281 L
.97241 .26696 L
.97286 .26393 L
.97325 .26074 L
.97371 .25543 L
.97394 .25056 L
.97396 .24532 L
.97373 .23959 L
.97331 .23462 L
.97264 .22933 L
.9718 .22434 L
.97086 .21982 L
.96784 .2088 L
.96343 .19697 L
.95248 .17594 L
.93713 .15481 L
.91928 .13594 L
.89389 .11483 L
.867 .09698 L
.80236 .06536 L
.76192 .05094 L
.72091 .03936 L
.67987 .03027 L
.64137 .02372 L
.61955 .02077 L
.5957 .01815 L
.57296 .01621 L
.56282 .01551 L
.55193 .01488 L
.54163 .01439 L
.53224 .01404 L
.52279 .01377 L
.51385 .0136 L
.50342 .0135 L
.4938 .0135 L
.48323 .0136 L
.47204 .01383 L
.46207 .01414 L
.45137 .01459 L
.43209 .01567 L
.4093 .01745 L
.38862 .01953 L
.34765 .02505 L
.30526 .03287 L
.26682 .04206 L
.23355 .05189 L
.19657 .06526 L
.15973 .08179 L
.12856 .09914 L
Mistroke
.1027 .11681 L
.07974 .13623 L
.06211 .15496 L
.04643 .17671 L
.0396 .18904 L
.03434 .20089 L
.0304 .2125 L
.02883 .21839 L
.02744 .22493 L
.02654 .23049 L
.02585 .23651 L
.02547 .24219 L
.02536 .2474 L
.02552 .25354 L
.02594 .25924 L
.02631 .26252 L
.02672 .26549 L
.0279 .27215 L
.02938 .27854 L
.03137 .28543 L
.03599 .29784 L
.04745 .31956 L
.06178 .33919 L
.08136 .35976 L
.10666 .38052 L
.13752 .40051 L
.17061 .4177 L
.20645 .43278 L
.24137 .44477 L
.27709 .45481 L
.31751 .46389 L
.36189 .47144 L
.38226 .47415 L
.40485 .47661 L
.42606 .47844 L
.44598 .47974 L
.45703 .48029 L
.46712 .48068 L
.47878 .48101 L
.48982 .4812 L
.49933 .48127 L
.50942 .48125 L
.51804 .48115 L
.52752 .48095 L
.53769 .48064 L
.54861 .4802 L
.5683 .47909 L
.58952 .47746 L
.61196 .47521 L
.65171 .46986 L
Mistroke
.69754 .46133 L
.73738 .45158 L
.77688 .43936 L
.81665 .42389 L
.85071 .40737 L
.87936 .3903 L
.90469 .37172 L
.92463 .35364 L
.94302 .33246 L
.95147 .32024 L
.95812 .3087 L
.96335 .2976 L
.96792 .28518 L
.96966 .27913 L
.9712 .27258 L
.9719 .26896 L
.97244 .26563 L
.97288 .26247 L
.97325 .25909 L
.97366 .25334 L
.97381 .24799 L
.97378 .24472 L
.97368 .24163 L
.97327 .23585 L
.97254 .22975 L
.97159 .22414 L
.97026 .218 L
.9685 .21153 L
.9645 .20001 L
.95966 .18919 L
.94795 .16933 L
.9316 .14874 L
.90953 .12744 L
.88694 .11006 L
.85964 .09287 L
.80296 .06576 L
.76432 .05186 L
.72645 .0409 L
.6827 .03094 L
.65967 .02672 L
.63453 .02283 L
.61207 .01997 L
.59136 .01781 L
.57038 .01608 L
.55037 .01485 L
.53905 .01433 L
.53284 .0141 L
.527 .01392 L
.5167 .01368 L
.50532 .01354 L
Mistroke
.49932 .01351 L
.49299 .01352 L
.48169 .01364 L
.4754 .01377 L
.46954 .01391 L
.45628 .01437 L
.44492 .01491 L
.43294 .01561 L
.41156 .01723 L
.38875 .01949 L
.36395 .02259 L
.32054 .02973 L
.28139 .03825 L
.21315 .05881 L
.17825 .0729 L
.14888 .08729 L
.12111 .10372 L
.095 .12269 L
.0755 .14018 L
.05783 .16007 L
.04879 .17274 L
.04174 .18462 L
.03625 .19594 L
.03149 .2085 L
.02984 .214 L
.02835 .21992 L
.02729 .22504 L
.02639 .23062 L
.02598 .2339 L
.02569 .23693 L
.02532 .24291 L
.02524 .24835 L
.02542 .25411 L
.02586 .25969 L
.02663 .26578 L
.02764 .27151 L
.02882 .27682 L
.03168 .28678 L
.03563 .29731 L
.04815 .3209 L
.06357 .34151 L
.08144 .36001 L
.10428 .37892 L
.15423 .40978 L
.1861 .42473 L
.21828 .43722 L
.25919 .45014 L
.29868 .46002 L
.34191 .4684 L
.38423 .47444 L
Mistroke
.40787 .47695 L
.42994 .47876 L
.44251 .47957 L
.45435 .48019 L
.46672 .48069 L
.47331 .4809 L
.48042 .48107 L
.49161 .48124 L
.50179 .48129 L
.51354 .48122 L
.52464 .48102 L
.53489 .48074 L
.54434 .48038 L
.56563 .47925 L
.58698 .47766 L
.61028 .47537 L
.65653 .46905 L
.70018 .4607 L
.74498 .44937 L
.78453 .43657 L
.81872 .42289 L
.88033 .38954 L
.90732 .36943 L
.93137 .34638 L
.94951 .3231 L
.95662 .31131 L
.96208 .30029 L
.96609 .29032 L
.96952 .27929 L
.97091 .27352 L
.97195 .26812 L
.97279 .26241 L
.97339 .25628 L
.97368 .25059 L
.97372 .24736 L
.97368 .24432 L
.97337 .23821 L
.97307 .23478 L
.9727 .23164 L
.9719 .22636 L
.97076 .2206 L
.96765 .20906 L
.96291 .19643 L
.95639 .18315 L
.94093 .15992 L
.92044 .13741 L
.89697 .11746 L
.84318 .08409 L
.81299 .06999 L
.77708 .0562 L
Mistroke
.73968 .04453 L
.69727 .03402 L
.65585 .02612 L
.61688 .02057 L
.59781 .01846 L
.57686 .01659 L
.55694 .01523 L
.5384 .01432 L
.52796 .01396 L
.51694 .01369 L
.50752 .01356 L
.49721 .01351 L
.48607 .01358 L
.47984 .01367 L
.47417 .01379 L
.46316 .01411 L
.45276 .01452 L
.4328 .01561 L
.41446 .01697 L
.39448 .01885 L
.37349 .02128 L
.33043 .02786 L
.2914 .03582 L
.25044 .04652 L
.20898 .06028 L
.14244 .09075 L
.1104 .11092 L
.08478 .13131 L
.06419 .15221 L
.04913 .17208 L
.04231 .18342 L
.0362 .19588 L
.03164 .20781 L
.02851 .21889 L
.02728 .22473 L
.02637 .23027 L
.02577 .23525 L
.02535 .24068 L
.02517 .24657 L
.02519 .24955 L
.02529 .25284 L
.02569 .25864 L
.02632 .26407 L
.02714 .26922 L
.02823 .27462 L
.03079 .28423 L
.0344 .29449 L
.03936 .30558 L
.05312 .32833 L
.07269 .35157 L
Mistroke
.09553 .37224 L
.11974 .38978 L
.14766 .40638 L
.18042 .42233 L
.24631 .44644 L
.28629 .45721 L
.32543 .46552 L
.36992 .47265 L
.39546 .47572 L
.41906 .47794 L
.43047 .47881 L
.44124 .47951 L
.45105 .48004 L
.46142 .4805 L
.47279 .48089 L
.48324 .48112 L
.4945 .48126 L
.50089 .48128 L
.50684 .48127 L
.51746 .48116 L
.5275 .48095 L
.5365 .48067 L
.54626 .48029 L
.56808 .47908 L
.58812 .47754 L
.60974 .47541 L
.6298 .47297 L
.67456 .46586 L
.7166 .45686 L
.75965 .44491 L
.82747 .41887 L
.86127 .40132 L
.88924 .38334 L
.91452 .36309 L
.93452 .34275 L
.9439 .33104 L
.95265 .31806 L
.95887 .30692 L
.96435 .29478 L
.96842 .28304 L
.97113 .27223 L
.97208 .26701 L
.97287 .26132 L
.97337 .25593 L
.97362 .25094 L
.97365 .24518 L
.97343 .23977 L
.97292 .23384 L
.9725 .23051 L
.97204 .22746 L
Mistroke
.96944 .21538 L
.96768 .20934 L
.96541 .20277 L
.95405 .17914 L
.94563 .16626 L
.93673 .15483 L
.91739 .13461 L
.89287 .11447 L
.86724 .09747 L
.83561 .08035 L
.77227 .05459 L
.73297 .04272 L
.68834 .03216 L
.64437 .02432 L
.62277 .02131 L
.60297 .019 L
.58289 .01709 L
.56101 .01548 L
.54891 .01479 L
.53776 .01429 L
.52708 .01393 L
.51578 .01367 L
.50606 .01354 L
.49564 .01351 L
.48581 .01358 L
.47685 .01372 L
.46635 .01399 L
.45495 .01441 L
.44421 .01492 L
.4343 .0155 L
.41254 .01711 L
.39228 .01906 L
.34687 .02507 L
.304 .033 L
.25978 .04382 L
.18951 .06793 L
.154 .08447 L
.12423 .10158 L
.09692 .12101 L
.07485 .14068 L
.05418 .16473 L
.04632 .17644 L
.04006 .1876 L
.03504 .19854 L
.03134 .20864 L
.02823 .21995 L
.02698 .22621 L
.02608 .23217 L
.0255 .23793 L
.02518 .24406 L
Mistroke
.02516 .24985 L
.02538 .25508 L
.02562 .2583 L
.02593 .26126 L
.02687 .26792 L
.02801 .27377 L
.02951 .27991 L
.03267 .28999 L
.03699 .30067 L
.04717 .31955 L
.0632 .34123 L
.08134 .36005 L
.10386 .37872 L
.13136 .39713 L
.18915 .4261 L
.22534 .43974 L
.26151 .45085 L
.30334 .4611 L
.35039 .46982 L
.37207 .47294 L
.39549 .47573 L
.41595 .47769 L
.43826 .47933 L
.45201 .48009 L
.46471 .48062 L
.47099 .48083 L
.47686 .48099 L
.48299 .48112 L
.48973 .48121 L
.4958 .48126 L
.50155 .48128 L
.51233 .48122 L
.52393 .48102 L
.53048 .48086 L
.53653 .48066 L
.54675 .48026 L
.55775 .4797 L
.57758 .47839 L
.601 .47631 L
.62226 .47392 L
.66527 .46752 L
.70903 .45864 L
.74839 .44831 L
.7823 .4373 L
.81653 .42377 L
.85061 .40724 L
.87904 .3903 L
.90232 .37341 L
.92312 .35491 L
.93917 .33712 L
Mistroke
.95338 .31681 L
.95925 .3061 L
.96453 .29426 L
.96834 .28321 L
.96983 .2778 L
.97096 .27289 L
.97187 .26813 L
.97264 .26297 L
.97322 .25752 L
.97354 .25239 L
.97364 .24638 L
.97346 .24077 L
.97298 .23463 L
.97257 .2312 L
.97211 .22807 L
.97094 .22178 L
.96931 .21498 L
.96536 .2027 L
.96057 .19144 L
.95433 .17967 L
.94018 .15909 L
.92174 .13877 L
.9016 .12114 L
.87664 .10335 L
.84578 .0855 L
.78609 .05945 L
.7501 .04758 L
.71481 .03809 L
.67346 .02925 L
.65107 .02537 L
.62699 .02186 L
.60563 .01929 L
.5819 .01701 L
.56014 .01542 L
.5397 .01437 L
.52944 .014 L
.51825 .01371 L
.50767 .01355 L
.49787 .0135 L
.48907 .01354 L
.47935 .01367 L
.4692 .0139 L
.45968 .01421 L
.44922 .01466 L
.43823 .01525 L
.41864 .0166 L
.39771 .01848 L
.37501 .02106 L
.33011 .02788 L
.28913 .0363 L
Mistroke
.21748 .05713 L
.18095 .07158 L
.14996 .08658 L
.1195 .10463 L
.09098 .12584 L
.06948 .14622 L
.05335 .16584 L
.04685 .17555 L
.0407 .18632 L
.03584 .19657 L
.03209 .20632 L
.03019 .21231 L
.02848 .21881 L
.02732 .22424 L
.02633 .23021 L
.0259 .23357 L
.02558 .23671 L
.02534 .24002 L
.02517 .24357 L
.02512 .24688 L
.02514 .25001 L
.02541 .25587 L
.02593 .26144 L
.02675 .26733 L
.02769 .27236 L
.02896 .27788 L
.03269 .2901 L
.03732 .30144 L
.0489 .32227 L
.06576 .34419 L
.08783 .36589 L
.11223 .38477 L
.16448 .41502 L
.19797 .42971 L
.2307 .44155 L
.26771 .45254 L
.30892 .46228 L
.34548 .46904 L
.38685 .47477 L
.41049 .47721 L
.43228 .47894 L
.44438 .47969 L
.45761 .48034 L
.46368 .48058 L
.47013 .4808 L
.48176 .48109 L
.49343 .48124 L
.5 .48127 L
.50604 .48126 L
.51715 .48115 L
Mistroke
.52886 .4809 L
.53937 .48055 L
.54915 .48014 L
.57129 .47884 L
.59429 .47696 L
.61534 .47474 L
.66207 .46806 L
.70193 .46024 L
.74245 .45001 L
.8072 .42772 L
.84038 .41256 L
.8687 .39685 L
.8953 .37884 L
.92031 .35765 L
.93977 .33635 L
.95404 .31566 L
.95985 .30486 L
.96441 .29454 L
.96776 .28506 L
.97049 .27497 L
.97158 .2697 L
.97251 .2639 L
.97311 .25862 L
.97347 .25368 L
.97363 .24784 L
.97353 .24252 L
.97313 .23639 L
.97247 .23058 L
.97163 .22532 L
.97046 .21966 L
.96768 .20946 L
.96325 .19746 L
.95813 .18658 L
.94445 .1647 L
.92562 .14265 L
.88465 .10869 L
.85659 .09134 L
.82762 .07657 L
.79332 .06215 L
.75318 .04851 L
.7156 .03828 L
.67392 .02933 L
.63503 .02296 L
.61398 .02024 L
.5911 .01782 L
.56993 .01607 L
.55045 .01487 L
.54105 .01442 L
.53079 .01404 L
.52107 .01377 L
Mistroke
.51205 .0136 L
.50055 .0135 L
.49475 .0135 L
.48839 .01354 L
.47714 .01371 L
.46666 .01397 L
.4603 .01418 L
.45429 .01442 L
.44305 .01497 L
.41791 .01665 L
.39615 .01863 L
.37621 .0209 L
.33197 .02754 L
.29649 .03461 L
.25884 .04405 L
.18866 .06826 L
.15635 .08323 L
.12557 .1007 L
.07978 .13583 L
.05987 .15728 L
.04525 .17815 L
.0386 .19049 L
.0337 .20185 L
.03145 .2082 L
.0294 .21512 L
.02782 .22171 L
.02669 .22774 L
.02591 .23337 L
.02541 .23872 L
.02514 .24436 L
.02515 .25052 L
.0254 .25587 L
.02593 .26156 L
.02668 .26692 L
.02755 .27176 L
.03055 .28364 L
.03508 .29634 L
.0406 .30817 L
.0467 .31886 L
.06203 .33989 L
.08321 .36181 L
.10996 .38319 L
.13883 .40154 L
.17003 .41767 L
.20721 .43328 L
.24253 .44532 L
.28221 .45625 L
.3196 .46443 L
.36228 .4716 L
.38138 .47412 L
Mistroke
.40214 .47641 L
.422 .47818 L
.44013 .47944 L
.45094 .48003 L
.46266 .48054 L
.46912 .48077 L
.47506 .48094 L
.48676 .48117 L
.49683 .48126 L
.50788 .48125 L
.51942 .4811 L
.53019 .48085 L
.53629 .48066 L
.54292 .48041 L
.55496 .47984 L
.57742 .47838 L
.60344 .47605 L
.62724 .47327 L
.66667 .46725 L
.70877 .45867 L
.75074 .44759 L
.7879 .43524 L
.85311 .40586 L
.88142 .38869 L
.90852 .36828 L
.92827 .34959 L
.94563 .32858 L
.9526 .31806 L
.95829 .30796 L
.96266 .29873 L
.96655 .28872 L
.96839 .28299 L
.96983 .27773 L
.97105 .27236 L
.97198 .26738 L
.97279 .26158 L
.97311 .25851 L
.97337 .25525 L
.97361 .24919 L
.97357 .24371 L
.97344 .2407 L
.97322 .23753 L
.97263 .23187 L
.9717 .22578 L
.97033 .21913 L
.96696 .20729 L
.96278 .19635 L
.95183 .17558 L
.9387 .15728 L
.91992 .13704 L
Mistroke
.89876 .11894 L
.84486 .08504 L
.81317 .07015 L
.77521 .05561 L
.74071 .04487 L
.70162 .03502 L
.66316 .02739 L
.62688 .02185 L
.60568 .0193 L
.5855 .01731 L
.57426 .01639 L
.56204 .01554 L
.55185 .01494 L
.54062 .0144 L
.52998 .01401 L
.52003 .01374 L
.50951 .01356 L
.49822 .0135 L
.48773 .01354 L
.47778 .01369 L
.46886 .0139 L
.45916 .01422 L
.44781 .01472 L
.43716 .0153 L
.41301 .01705 L
.38967 .01932 L
.36479 .02239 L
.32085 .02957 L
.28196 .03799 L
.24503 .04807 L
.20774 .06067 L
.14736 .08796 L
.11547 .10731 L
.08929 .12726 L
.06932 .14637 L
.05167 .1682 L
.04502 .17853 L
.03892 .18982 L
.03453 .1997 L
.03068 .2106 L
.02884 .21725 L
.02746 .22345 L
.02643 .22939 L
.02602 .23244 L
.02566 .23573 L
.02539 .23898 L
.02522 .24198 L
.0251 .24786 L
.02524 .2532 L
.02564 .25884 L
Mistroke
.02637 .26492 L
.02729 .27044 L
.02867 .2768 L
.03029 .2828 L
.0339 .29338 L
.03888 .30476 L
.05416 .32988 L
.07308 .35206 L
.09326 .37048 L
.11855 .38907 L
.17277 .41894 L
.20861 .43381 L
.24932 .44737 L
.28984 .45807 L
.32832 .46607 L
.37001 .47267 L
.41033 .47719 L
.43278 .47897 L
.4536 .48016 L
.46452 .48061 L
.47081 .48082 L
.47655 .48097 L
.48262 .4811 L
.48913 .4812 L
.5009 .48127 L
.51103 .48122 L
.52181 .48106 L
.53196 .4808 L
.54114 .48048 L
.55197 .47999 L
.56364 .47933 L
.58467 .4778 L
.60456 .47593 L
.62534 .47351 L
.66189 .46808 L
.70311 .45996 L
.73914 .45093 L
.77603 .43947 L
.81347 .42507 L
.84535 .41 L
.87216 .39469 L
.91672 .36101 L
.93522 .34185 L
.95124 .32024 L
.95748 .30949 L
.96249 .29912 L
.96653 .28879 L
.96941 .27933 L
.97073 .27385 L
.97189 .2679 L
Mistroke
.9724 .26462 L
.97279 .2616 L
.97334 .25565 L
.97358 .25053 L
.97359 .24491 L
.97333 .23905 L
.97284 .23358 L
.97245 .23048 L
.97193 .22712 L
.97075 .22101 L
.96772 .20962 L
.96282 .19647 L
.957 .18447 L
.94409 .16423 L
.92623 .14329 L
.88419 .10838 L
.85457 .09023 L
.81966 .07297 L
.78384 .05865 L
.74898 .04726 L
.71316 .0377 L
.67259 .02909 L
.64965 .02515 L
.62816 .02202 L
.60602 .01933 L
.58508 .01727 L
.56704 .01587 L
.54755 .01472 L
.53642 .01423 L
.52582 .01388 L
.5163 .01366 L
.50591 .01353 L
.49479 .0135 L
.48472 .01357 L
.47311 .01379 L
.46218 .01411 L
.45206 .01452 L
.44276 .01498 L
.42187 .01633 L
.40022 .01822 L
.38066 .02035 L
.3375 .02657 L
.29874 .0341 L
.26343 .04277 L
.19048 .06748 L
.15383 .08451 L
.12338 .10208 L
.09912 .11922 L
.07651 .13897 L
.05873 .15869 L
Mistroke
.04563 .1775 L
.0399 .18785 L
.03479 .19905 L
.03042 .21148 L
.02877 .21753 L
.02752 .22313 L
.02642 .22947 L
.02597 .23282 L
.0256 .23636 L
.0252 .24231 L
.02511 .2457 L
.02511 .24886 L
.02532 .25476 L
.02577 .26013 L
.02612 .2631 L
.02658 .26633 L
.02763 .27219 L
.03031 .28288 L
.03426 .29433 L
.04418 .31468 L
.05152 .32618 L
.06049 .33805 L
.07962 .35848 L
.12948 .39602 L
.1638 .4147 L
.19921 .4302 L
.23563 .44315 L
.27776 .45514 L
.31964 .46444 L
.35976 .47123 L
.39684 .47587 L
.41823 .47787 L
.43842 .47933 L
.44935 .47995 L
.45977 .48043 L
.46914 .48076 L
.47938 .48103 L
.49048 .48121 L
.49668 .48125 L
.50231 .48126 L
.51328 .48119 L
.5236 .48102 L
.53396 .48073 L
.54505 .48031 L
.565 .47925 L
.58858 .47746 L
.6099 .47535 L
.65542 .46915 L
.69719 .46126 L
.73397 .45234 L
Mistroke
.76649 .44267 L
.83354 .41593 L
.86205 .40079 L
.88963 .38299 L
.91064 .36645 L
.9304 .3473 L
.94816 .32494 L
.95546 .31319 L
.96192 .30041 L
.96671 .28823 L
.96999 .27706 L
.97119 .27164 L
.97223 .26576 L
.97294 .26018 L
.97338 .25504 L
.9736 .24921 L
.97356 .24368 L
.97331 .23871 L
.9728 .23331 L
.97198 .22746 L
.9708 .22125 L
.96788 .21014 L
.96387 .19897 L
.95915 .18858 L
.9479 .16959 L
.93036 .14766 L
.91051 .12853 L
.88507 .10898 L
.85372 .08976 L
.82137 .07373 L
.78933 .06066 L
.72059 .03952 L
.67924 .03035 L
.65678 .0263 L
.63254 .02261 L
.61107 .0199 L
.58715 .01746 L
.56519 .01574 L
.54448 .01457 L
.53396 .01414 L
.52272 .0138 L
.5121 .01359 L
.50246 .0135 L
.4911 .01351 L
.4847 .01357 L
.4788 .01367 L
.46797 .01392 L
.45654 .01432 L
.44559 .01483 L
.43387 .0155 L
Mistroke
.41281 .01706 L
.38799 .0195 L
.36559 .02227 L
.32698 .02842 L
.28634 .03694 L
.21724 .0572 L
.1833 .07053 L
.15379 .08453 L
.12204 .10294 L
.09641 .12136 L
.07495 .14053 L
.05562 .16272 L
.04082 .18605 L
.03476 .19912 L
.0325 .20509 L
.03043 .21145 L
.02885 .21719 L
.02743 .22354 L
.02644 .22933 L
.02575 .23476 L
.02546 .23804 L
.02526 .24116 L
.0251 .24702 L
.02513 .25029 L
.02524 .25332 L
.02545 .25665 L
.02577 .26019 L
.02655 .26616 L
.02772 .27261 L
.03072 .28422 L
.0347 .29542 L
.03929 .30561 L
.05045 .32462 L
.06622 .34474 L
.08647 .36472 L
.10867 .38228 L
.13622 .40004 L
.16985 .41759 L
.20238 .43144 L
.23952 .44439 L
.27492 .45443 L
.31584 .46369 L
.35446 .47044 L
.39165 .47531 L
.41296 .47742 L
.43293 .47897 L
.44426 .47967 L
.45498 .48022 L
.46092 .48047 L
.46737 .4807 L
Mistroke
.47863 .48102 L
.48976 .4812 L
.49609 .48125 L
.50201 .48126 L
.50825 .48124 L
.51395 .48118 L
.52052 .48108 L
.52675 .48094 L
.53775 .4806 L
.54792 .48018 L
.57088 .47886 L
.59225 .47713 L
.61218 .47509 L
.64884 .47019 L
.6873 .46333 L
.72731 .45411 L
.76679 .44257 L
.80576 .42829 L
Mfstroke
.92408 .35765 m
.94191 .33788 L
.95529 .31867 L
.96142 .30755 L
.96626 .29689 L
.97066 .28446 L
.97217 .27904 L
.97356 .27305 L
.97463 .26718 L
.97539 .26167 L
.97592 .25585 L
.97619 .24958 L
.97616 .24377 L
.97588 .23825 L
.97541 .2333 L
.97468 .22791 L
.97351 .22149 L
.97215 .21569 L
.96813 .20279 L
.9632 .19099 L
.9575 .18004 L
.94209 .1574 L
.92112 .13469 L
.8996 .11646 L
.8724 .09788 L
.83928 .0797 L
.7998 .06249 L
.75954 .04861 L
.71991 .03778 L
.67959 .02915 L
.63518 .02206 L
.61168 .01923 L
.58939 .01709 L
.56472 .01533 L
.55078 .01461 L
.54406 .01433 L
.53796 .01411 L
.52751 .01383 L
.51633 .01365 L
.50598 .01359 L
.4962 .01363 L
.48479 .01379 L
.47428 .01406 L
.46277 .01447 L
.4506 .01505 L
.42815 .0165 L
.40729 .01831 L
.36056 .02404 L
.31876 .03129 L
.27498 .0413 L
Mistroke
.23827 .05191 L
.20149 .06499 L
.16773 .07969 L
.13973 .09442 L
.09301 .12667 L
.07227 .14608 L
.05442 .16764 L
.04261 .18677 L
.03735 .19785 L
.03341 .2083 L
.03162 .21416 L
.03 .22055 L
.02879 .22661 L
.02795 .23222 L
.02742 .23728 L
.02708 .24286 L
.027 .24869 L
.02718 .25415 L
.02768 .26019 L
.02804 .26322 L
.02852 .26652 L
.03087 .27779 L
.03267 .28412 L
.03495 .29084 L
.04003 .30282 L
.05374 .32609 L
.07049 .34667 L
.09321 .36811 L
.12188 .38921 L
.17982 .4205 L
.21751 .43565 L
.25539 .44797 L
.29466 .45825 L
.33943 .46736 L
.36051 .47079 L
.38325 .47392 L
.40315 .4762 L
.42481 .47821 L
.44576 .47969 L
.45498 .4802 L
.46509 .48067 L
.47469 .48101 L
.48364 .48125 L
.49309 .48142 L
.50321 .4815 L
.51445 .48148 L
.52079 .48141 L
.52664 .48131 L
.53738 .48104 L
.54874 .48062 L
Mistroke
.55888 .48014 L
.56836 .4796 L
.58983 .47803 L
.61243 .47585 L
.63318 .47335 L
.67923 .46599 L
.71839 .45758 L
.75823 .44664 L
.79514 .43397 L
.82752 .42034 L
.88087 .39079 L
.90484 .3732 L
.92741 .35255 L
.94654 .32971 L
.95403 .31838 L
.9601 .30746 L
.96479 .29724 L
.9689 .28601 L
.97038 .28102 L
.97173 .27571 L
.97278 .27072 L
.97356 .26614 L
.97426 .26084 L
.97475 .25512 L
.97496 .25007 L
.97496 .24476 L
.9747 .23893 L
.97421 .23351 L
.9734 .22757 L
.97221 .22125 L
.96903 .20921 L
.96437 .1966 L
.95935 .18598 L
.95275 .17449 L
.93404 .14974 L
.91176 .1279 L
.86065 .09231 L
.8265 .0749 L
.79233 .06078 L
.75711 .04887 L
.71741 .03806 L
.6782 .02965 L
.64151 .02355 L
.61999 .02071 L
.59703 .01823 L
.58492 .01715 L
.57159 .01614 L
.55929 .01536 L
.54806 .01479 L
.53657 .01433 L
Mistroke
.5257 .01401 L
.5142 .0138 L
.50771 .01374 L
.50171 .01373 L
.49172 .01377 L
.48072 .01394 L
.46924 .01423 L
.45851 .01463 L
.44746 .01516 L
.43571 .01585 L
.41467 .01744 L
.38987 .01991 L
.36764 .02269 L
.32472 .02965 L
.28567 .03801 L
.2178 .05807 L
.18286 .07186 L
.15317 .08605 L
.12565 .10189 L
.09944 .12031 L
.07972 .13731 L
.06157 .1568 L
.05228 .1691 L
.0449 .18072 L
.03907 .19181 L
.03387 .20422 L
.03034 .21542 L
.02907 .22058 L
.02798 .22602 L
.02709 .23188 L
.02651 .23726 L
.02617 .24306 L
.0261 .24635 L
.02611 .24941 L
.02635 .25529 L
.02658 .25825 L
.02692 .26151 L
.02773 .26726 L
.02874 .27263 L
.03189 .28466 L
.03662 .29746 L
.04231 .30931 L
.04882 .32039 L
.06389 .34061 L
.08198 .35942 L
.10164 .37597 L
.15567 .40978 L
.18875 .42522 L
.22768 .43995 L
.26439 .45117 L
Mistroke
.30521 .46116 L
.34365 .46851 L
.36449 .47175 L
.38712 .47471 L
.40819 .47697 L
.42754 .47863 L
.44711 .47992 L
.45682 .48042 L
.46573 .48079 L
.47592 .48113 L
.48691 .48137 L
.49661 .48148 L
.50681 .48151 L
.51804 .48141 L
.52847 .48121 L
.53991 .48087 L
.55208 .48036 L
.5639 .47972 L
.57665 .47887 L
.59964 .47691 L
.64201 .4718 L
.68139 .46516 L
.72159 .45629 L
.78877 .43572 L
.82303 .42171 L
.85185 .40743 L
.88 .39057 L
.90693 .3706 L
.92808 .35087 L
.94431 .33164 L
.95664 .31255 L
.96169 .30265 L
.96626 .29167 L
.96978 .28072 L
.97128 .2747 L
.9724 .26909 L
.97323 .2638 L
.97378 .25899 L
.97418 .25343 L
.97433 .24817 L
.97423 .24245 L
.97384 .2364 L
.97327 .23124 L
.97239 .22558 L
.97115 .21951 L
.96948 .21301 L
.96558 .20136 L
.961 .19075 L
.95492 .17934 L
.94103 .1591 L
Mistroke
.92413 .14022 L
.9056 .12356 L
.87973 .10467 L
.84781 .08597 L
.81657 .07109 L
.78075 .05712 L
.74618 .0461 L
.70618 .03581 L
.66823 .02814 L
.63171 .02243 L
.61073 .01984 L
.5882 .01758 L
.57637 .01661 L
.56326 .0157 L
.55117 .01501 L
.54005 .01451 L
.52939 .01414 L
.51816 .01388 L
.50687 .01373 L
.50047 .01371 L
.49452 .01372 L
.48369 .01383 L
.47385 .01403 L
.46251 .01438 L
.45182 .01483 L
.43188 .01596 L
.41089 .0176 L
.37373 .02163 L
.3346 .02755 L
.29294 .03593 L
.25186 .0466 L
.21502 .05859 L
.15272 .08575 L
.12242 .10337 L
.09758 .12114 L
.07423 .14202 L
.05413 .16563 L
.04653 .17702 L
.03976 .18926 L
.03496 .2 L
.03091 .21163 L
.02912 .21823 L
.02781 .22427 L
.0268 .23035 L
.02613 .23611 L
.02587 .23938 L
.02569 .24284 L
.02562 .24579 L
.02562 .24905 L
.02572 .25254 L
Mistroke
.02594 .2563 L
.02625 .25984 L
.02663 .26308 L
.02751 .26881 L
.02874 .27489 L
.03174 .28579 L
.03659 .29861 L
.04217 .31008 L
.05645 .33213 L
.07373 .35205 L
.09395 .37047 L
.11981 .38941 L
.14842 .40643 L
.18253 .42296 L
.21734 .43671 L
.25125 .44773 L
.28441 .45663 L
.32257 .46491 L
.36308 .47169 L
.38424 .47448 L
.40732 .47696 L
.42902 .47879 L
.43857 .47944 L
.44906 .48005 L
.45835 .4805 L
.4683 .48088 L
.47883 .48118 L
.48863 .48136 L
.49468 .48143 L
.5011 .48145 L
.5126 .4814 L
.51898 .48132 L
.52496 .48121 L
.53152 .48104 L
.53856 .48081 L
.55115 .48028 L
.56309 .47964 L
.58538 .47803 L
.60688 .47599 L
.62664 .47368 L
.67057 .46692 L
.71238 .45823 L
.75545 .44659 L
.79122 .43445 L
.82636 .41979 L
.85552 .405 L
.88435 .38719 L
.92614 .35237 L
.94497 .33012 L
.95257 .3188 L
Mistroke
.9586 .30814 L
.96313 .29855 L
.96723 .28785 L
.97038 .277 L
.97169 .27102 L
.97265 .2654 L
.97336 .2597 L
.97364 .25647 L
.97383 .25346 L
.97398 .24738 L
.97393 .24398 L
.97381 .24089 L
.97339 .23535 L
.97265 .22935 L
.97168 .22371 L
.97055 .21852 L
.96723 .20697 L
.96231 .19442 L
.95577 .18151 L
.94838 .16967 L
.93155 .14846 L
.90873 .12659 L
.88497 .10856 L
.85621 .09084 L
.82444 .07488 L
.79318 .06191 L
.72628 .04086 L
.68677 .03179 L
.64347 .02419 L
.60546 .01932 L
.58358 .01721 L
.56303 .01569 L
.55152 .01503 L
.53899 .01445 L
.53324 .01424 L
.52713 .01405 L
.51617 .0138 L
.50566 .01368 L
.4958 .01366 L
.485 .01374 L
.47338 .01396 L
.46701 .01414 L
.4611 .01434 L
.44772 .01492 L
.43596 .01558 L
.42347 .01644 L
.39977 .0185 L
.37848 .02087 L
.33688 .02696 L
.29434 .03538 L
Mistroke
.25948 .04418 L
.22305 .05549 L
.18635 .06956 L
.15032 .08671 L
.09534 .12259 L
.07227 .14365 L
.05482 .16425 L
.04019 .18784 L
.03466 .20005 L
.03222 .20669 L
.03004 .21371 L
.02858 .21943 L
.02729 .22572 L
.0264 .23144 L
.02582 .23678 L
.02557 .24003 L
.02543 .24311 L
.02536 .24886 L
.02544 .25208 L
.0256 .25505 L
.02585 .25831 L
.0262 .26176 L
.02696 .2671 L
.02803 .27283 L
.03065 .28313 L
.03491 .29526 L
.03987 .30621 L
.05254 .32721 L
.07015 .34868 L
.09051 .36791 L
.1119 .38432 L
.14054 .40231 L
.17526 .41993 L
.21102 .43458 L
.24683 .44655 L
.28578 .45707 L
.32286 .46505 L
.36549 .47208 L
.38947 .47512 L
.41242 .47744 L
.43489 .47919 L
.44628 .47988 L
.45888 .48049 L
.46962 .48089 L
.48121 .48119 L
.49215 .48135 L
.50218 .4814 L
.50791 .48138 L
.51402 .48132 L
.52501 .48113 L
Mistroke
.53174 .48095 L
.53807 .48075 L
.5499 .48025 L
.56238 .47958 L
.57385 .47882 L
.59957 .47662 L
.64019 .47169 L
.68261 .46449 L
.72121 .45589 L
.75496 .44655 L
.79235 .43381 L
.83004 .41785 L
.86213 .401 L
.8891 .38362 L
.91281 .36481 L
.93139 .3465 L
.94824 .32515 L
.95586 .31284 L
.96177 .30118 L
.96613 .29045 L
.96972 .27885 L
.97127 .27219 L
.97239 .26588 L
.97312 .26021 L
.97342 .257 L
.97361 .25404 L
.97379 .24805 L
.9737 .24244 L
.97329 .23629 L
.97293 .23285 L
.97251 .2297 L
.97143 .2234 L
.96988 .21655 L
.96606 .20417 L
.96128 .1926 L
.95485 .18027 L
.93993 .15855 L
.9215 .13835 L
.90131 .12076 L
.8448 .08489 L
.81137 .0693 L
.77139 .05426 L
.73148 .04231 L
.69166 .03286 L
.65453 .02595 L
.61297 .02016 L
.59112 .01788 L
.56678 .01592 L
.55448 .01516 L
.54118 .01451 L
Mistroke
.53505 .01427 L
.5286 .01405 L
.51705 .01377 L
.50631 .01363 L
.49485 .0136 L
.48403 .01369 L
.47421 .01388 L
.46266 .01421 L
.45016 .01473 L
.4384 .01535 L
.42758 .01605 L
.38658 .01981 L
.3639 .02266 L
.34346 .02574 L
.26921 .04139 L
.23043 .05285 L
.19091 .06748 L
.12779 .09948 L
.09963 .11901 L
.07691 .13878 L
.05983 .15753 L
.04509 .17866 L
.03897 .18999 L
.03354 .2026 L
.03131 .20901 L
.02931 .21591 L
.02789 .2219 L
.0267 .22843 L
.02625 .23159 L
.02586 .23495 L
.02539 .24098 L
.02522 .24663 L
.02525 .24985 L
.02535 .25286 L
.02573 .25845 L
.0263 .26356 L
.02723 .26945 L
.02838 .27503 L
.03169 .28689 L
.03589 .29795 L
.04646 .31825 L
.06172 .33936 L
.08259 .36111 L
.10441 .37906 L
.13083 .39674 L
.18592 .42471 L
.22075 .43815 L
.2546 .44889 L
.29296 .4588 L
.33661 .46757 L
Mistroke
.35668 .47081 L
.3783 .47378 L
.39858 .4761 L
.41779 .47789 L
.43579 .47923 L
.45531 .4803 L
.46589 .48073 L
.47706 .48106 L
.4866 .48124 L
.49705 .48134 L
.50882 .48132 L
.51967 .48118 L
.52534 .48107 L
.53157 .4809 L
.54416 .48045 L
.5552 .47992 L
.56702 .47922 L
.58829 .4776 L
.61017 .47543 L
.63074 .47292 L
.66864 .46701 L
.71139 .45818 L
.7493 .44813 L
.78829 .43522 L
.82728 .41902 L
.86159 .40119 L
.88964 .38311 L
.91263 .36484 L
.9339 .34352 L
.94931 .32338 L
.96038 .30393 L
.96509 .29298 L
.9685 .28289 L
.97002 .27728 L
.97138 .27117 L
.97237 .26537 L
.97305 .26001 L
.97349 .25451 L
.97369 .24873 L
.97365 .24379 L
.97337 .2384 L
.9728 .23257 L
.97236 .22932 L
.97189 .22637 L
.96944 .21525 L
.96627 .20502 L
.96184 .19405 L
.95126 .17453 L
.93452 .1522 L
.9121 .12981 L
Mistroke
.88695 .11021 L
.86073 .09364 L
.79983 .06465 L
.76214 .05128 L
.7241 .04041 L
.68986 .0325 L
.65215 .02557 L
.63207 .02258 L
.60958 .01976 L
.58882 .01765 L
.56932 .01607 L
.5486 .01482 L
.53759 .01433 L
.5258 .01394 L
.51985 .0138 L
.5134 .01368 L
.50166 .01357 L
.49024 .01359 L
.47969 .01372 L
.46986 .01394 L
.46066 .01424 L
.45059 .01466 L
.43977 .01522 L
.41782 .01673 L
.39789 .01853 L
.35375 .02406 L
.32931 .02809 L
.30705 .03241 L
.22756 .05372 L
.1913 .06724 L
.15524 .08388 L
.1265 .10019 L
.09957 .11896 L
.0785 .13713 L
.05918 .15823 L
.04523 .17828 L
.03546 .19758 L
.0311 .20945 L
.02813 .22053 L
.02698 .22633 L
.02603 .23276 L
.02569 .23599 L
.02541 .23948 L
.02524 .24277 L
.02517 .24579 L
.02522 .25134 L
.0255 .2565 L
.02605 .26216 L
.02694 .26818 L
.02819 .2745 L
Mistroke
.02968 .28045 L
.03324 .2915 L
.03747 .30168 L
.04289 .31231 L
.05501 .33095 L
.07139 .35025 L
.09321 .37038 L
.11965 .38976 L
.14818 .40669 L
.20972 .43421 L
.24802 .44698 L
.28562 .45708 L
.32884 .46619 L
.35189 .47008 L
.37661 .47356 L
.39889 .47612 L
.42356 .47834 L
.43446 .47912 L
.44617 .47982 L
.45718 .48036 L
.46737 .48075 L
.47358 .48094 L
.48018 .4811 L
.4868 .48121 L
.49411 .48129 L
.5004 .48131 L
.50717 .4813 L
.51357 .48124 L
.51942 .48115 L
.53046 .4809 L
.5367 .4807 L
.5425 .48048 L
.55411 .47994 L
.56665 .4792 L
.5899 .47741 L
.61162 .47522 L
.65158 .46983 L
.69681 .46141 L
.73673 .45166 L
.77236 .44078 L
.80825 .42733 L
.86583 .39862 L
.89576 .37855 L
.92004 .35795 L
.9382 .33834 L
.94629 .32772 L
.95387 .31601 L
.95994 .30473 L
.96455 .29425 L
.96808 .28412 L
Mistroke
.97088 .27336 L
.97197 .26762 L
.97246 .26446 L
.97284 .26148 L
.97337 .25567 L
.97362 .25038 L
.97366 .24732 L
.97361 .24409 L
.97332 .23829 L
.97303 .23507 L
.97269 .23206 L
.97163 .22521 L
.97039 .21923 L
.96869 .21272 L
.96471 .20096 L
.95972 .18966 L
.95413 .17931 L
.93814 .15655 L
.91618 .13352 L
.89073 .11293 L
.86373 .09542 L
.83116 .07823 L
.79165 .06152 L
.75693 .04967 L
.71753 .03877 L
.67383 .02933 L
.63151 .02249 L
.60933 .01972 L
.58551 .01734 L
.565 .01576 L
.55393 .01508 L
.54224 .0145 L
.53614 .01426 L
.52947 .01403 L
.51774 .01373 L
.51112 .01362 L
.50404 .01355 L
.49736 .01353 L
.4913 .01355 L
.48515 .01361 L
.47948 .01369 L
.47327 .01382 L
.46669 .014 L
.45566 .0144 L
.44355 .01498 L
.42036 .01649 L
.39934 .01835 L
.3528 .02416 L
.31094 .03156 L
.2727 .04036 L
Mistroke
.20066 .06343 L
.1645 .0792 L
.13472 .09515 L
.10961 .11143 L
.0858 .13034 L
.06798 .14787 L
.05218 .16751 L
.04485 .17886 L
.03917 .18937 L
.03436 .20019 L
.0308 .21029 L
.02774 .22216 L
.0266 .22845 L
.02614 .23167 L
.02574 .23513 L
.02529 .24093 L
.02513 .24637 L
.02515 .24969 L
.02525 .25284 L
.02566 .25875 L
.02599 .26192 L
.02639 .2649 L
.02732 .27047 L
.02861 .27644 L
.03034 .28288 L
.03432 .29441 L
.03896 .30489 L
.05313 .32843 L
.07322 .35218 L
.09492 .37181 L
.11785 .3886 L
.14566 .40535 L
.17929 .42188 L
.21316 .43548 L
.24663 .44657 L
.28291 .45643 L
.31761 .46406 L
.35653 .47077 L
.377 .4736 L
.39966 .47618 L
.41832 .4779 L
.43839 .47935 L
.44955 .47998 L
.45971 .48045 L
.46994 .48082 L
.47962 .48107 L
.49023 .48123 L
.50191 .48129 L
.5078 .48127 L
.51411 .48121 L
Mistroke
.52552 .481 L
.53685 .48067 L
.54759 .48023 L
.56767 .47911 L
.59112 .47727 L
.61267 .47507 L
.66059 .46833 L
.70276 .46007 L
.7463 .44892 L
.78255 .43721 L
.81828 .423 L
.84806 .4086 L
.87764 .39122 L
.92091 .35707 L
.94074 .33513 L
.95535 .31341 L
.9649 .29329 L
.96876 .28174 L
.97134 .27099 L
.9723 .26543 L
.97304 .25943 L
.97347 .25375 L
.97363 .24856 L
.97355 .24279 L
.97338 .23952 L
.97315 .23649 L
.97244 .23036 L
.97192 .22694 L
.97135 .22384 L
.96834 .21159 L
.96609 .20473 L
.96367 .19845 L
.95157 .17514 L
.93683 .155 L
.91709 .13438 L
.8719 .10036 L
.83881 .08196 L
.80402 .06635 L
.77054 .05404 L
.73116 .04226 L
.69406 .03338 L
.65244 .0256 L
.62893 .02213 L
.60706 .01946 L
.58459 .01725 L
.56348 .01565 L
.54514 .01462 L
.53485 .01419 L
.52546 .01389 L
.51516 .01366 L
Mistroke
.50397 .01353 L
.4934 .01352 L
.48365 .01361 L
.47359 .0138 L
.46418 .01406 L
.45387 .01446 L
.44281 .015 L
.42035 .01647 L
.39996 .01827 L
.35867 .02327 L
.31586 .03056 L
.27693 .03926 L
.24315 .04866 L
.20547 .06155 L
.16778 .0776 L
.13573 .09453 L
.10899 .11185 L
.08504 .13099 L
.06648 .14951 L
.04972 .17109 L
.04221 .18348 L
.03645 .19514 L
.03199 .20659 L
.02846 .21886 L
.02712 .22525 L
.02617 .23127 L
.02577 .23472 L
.02548 .23788 L
.02526 .24136 L
.02513 .24502 L
.02515 .25072 L
.02547 .25681 L
.02605 .26255 L
.02682 .26775 L
.028 .27385 L
.02963 .28045 L
.0335 .29232 L
.03803 .30298 L
.04396 .31427 L
.05739 .33415 L
.07779 .35673 L
.10042 .37615 L
.1277 .39492 L
.16146 .41355 L
.2323 .44208 L
.2732 .45399 L
.31369 .46327 L
.35142 .46999 L
.39331 .47551 L
.41555 .47766 L
Mistroke
.44012 .47945 L
.45258 .48012 L
.45945 .48043 L
.46595 .48067 L
.47201 .48086 L
.4786 .48103 L
.49012 .48122 L
.50089 .48128 L
.50701 .48126 L
.51276 .48121 L
.52431 .48102 L
.5308 .48085 L
.53674 .48066 L
.54726 .48023 L
.55872 .47964 L
.57952 .47823 L
.60189 .47622 L
.62584 .47346 L
.66842 .46695 L
.70851 .45875 L
.74391 .44959 L
.81773 .42323 L
.85066 .40719 L
.883 .38763 L
.90907 .36781 L
.93 .34774 L
.94547 .32881 L
.95857 .30741 L
.96376 .29612 L
.96824 .28349 L
.96998 .2771 L
.97148 .27018 L
.97204 .26699 L
.97254 .26363 L
.97319 .2576 L
.97353 .25202 L
.97362 .24604 L
.97342 .24041 L
.97302 .23529 L
.97228 .22928 L
.97113 .22278 L
.96973 .21666 L
.96816 .21104 L
.9598 .18988 L
.95346 .17824 L
.94665 .16778 L
.91251 .13026 L
.888 .11102 L
.85719 .09168 L
.79141 .06144 L
Mistroke
.75225 .04824 L
.71311 .03769 L
.67639 .02981 L
.63534 .02301 L
.61347 .02018 L
.5892 .01765 L
.57688 .0166 L
.56361 .01565 L
.55211 .01496 L
.53957 .01437 L
.53351 .01414 L
.52707 .01393 L
.5155 .01366 L
.50464 .01353 L
.49846 .0135 L
.49267 .01352 L
.48192 .01362 L
.47208 .01382 L
.46129 .01415 L
.44996 .01462 L
.42711 .01596 L
.4057 .0177 L
.36617 .02221 L
.32465 .02886 L
.28128 .03817 L
.24502 .04808 L
.20873 .06031 L
.15005 .08651 L
.12128 .10344 L
.09791 .12017 L
.07609 .13939 L
.0565 .16156 L
.04922 .17183 L
.04249 .18295 L
.03755 .1927 L
.03312 .20336 L
.02958 .21443 L
.0283 .21952 L
.02718 .22491 L
.02637 .22979 L
.02571 .23516 L
.02532 .24004 L
.02513 .24459 L
.02514 .25049 L
.02525 .25347 L
.02546 .25675 L
.02605 .26254 L
.02684 .26796 L
.02809 .27431 L
.02952 .28009 L
Mistroke
.03376 .29303 L
.03851 .30401 L
.04485 .31581 L
.05943 .33673 L
.07706 .35603 L
.09955 .37549 L
.14882 .40707 L
.1832 .4236 L
.21766 .4371 L
.25739 .44971 L
.30369 .46119 L
.3459 .46911 L
.38653 .47474 L
.40936 .47711 L
.43036 .47881 L
.44203 .47956 L
.45477 .48022 L
.46682 .4807 L
.478 .48101 L
.4885 .48119 L
.49957 .48127 L
.50902 .48124 L
.51935 .48111 L
.53051 .48085 L
.53675 .48065 L
.54241 .48043 L
.56378 .47933 L
.58348 .47791 L
.60467 .47592 L
.64259 .47115 L
.68635 .46353 L
.7308 .4532 L
.76685 .44255 L
.80412 .42897 L
.83874 .41338 L
.86857 .39691 L
.91555 .36208 L
.93617 .34073 L
.95142 .31995 L
.95833 .30787 L
.96368 .29632 L
.96615 .28986 L
.96843 .28284 L
.97015 .2764 L
.97142 .27051 L
.97237 .26484 L
.97302 .25946 L
.97345 .25378 L
.97358 .25057 L
.97362 .2476 L
Mistroke
.97353 .24267 L
.9732 .23723 L
.97259 .23156 L
.97178 .22625 L
.97061 .22034 L
.96906 .21415 L
.9655 .20316 L
.96055 .19146 L
.95383 .17888 L
.93769 .15605 L
.91551 .13294 L
.89016 .11256 L
.8637 .09542 L
.83398 .0796 L
.79953 .06456 L
.73111 .04224 L
.68997 .03251 L
.64998 .0252 L
.60476 .0192 L
.57893 .01676 L
.56669 .01585 L
.55515 .01513 L
.5446 .01458 L
.5349 .01418 L
.52411 .01384 L
.51245 .01361 L
.50187 .01351 L
.49028 .01352 L
.48443 .01358 L
.47818 .01368 L
.46693 .01396 L
.45639 .01433 L
.44498 .01486 L
.42433 .01616 L
.40436 .01782 L
.38608 .01972 L
.34488 .02535 L
.30092 .03363 L
.25703 .04455 L
.21823 .05685 L
.18336 .07051 L
.14846 .08736 L
.12074 .10379 L
.09464 .12279 L
.07258 .14294 L
.05602 .16219 L
.04284 .18232 L
.0337 .20182 L
.03001 .21286 L
.02749 .22324 L
Mistroke
.02645 .22922 L
.02576 .23469 L
.02548 .23771 L
.02527 .241 L
.0251 .24699 L
.02522 .25274 L
.0254 .25601 L
.02566 .25907 L
.02601 .26229 L
.02641 .26524 L
.02757 .27187 L
.02877 .27719 L
.03034 .28298 L
.03436 .29458 L
.04455 .3153 L
.0594 .3367 L
.07705 .35602 L
.09599 .37269 L
.12089 .39061 L
.15073 .40808 L
.21214 .43511 L
.2501 .4476 L
.28764 .45756 L
.33073 .46651 L
.3538 .47035 L
.37875 .4738 L
.40278 .47648 L
.42475 .47839 L
.43542 .47914 L
.44699 .47983 L
.45786 .48035 L
.46801 .48073 L
.47426 .48091 L
.47994 .48105 L
.48626 .48116 L
.49302 .48124 L
.49953 .48127 L
.50659 .48125 L
.51326 .48119 L
.51942 .4811 L
.53031 .48085 L
.5365 .48065 L
.5423 .48043 L
.55386 .47989 L
.56646 .47916 L
.58932 .4774 L
.61086 .47524 L
.65068 .46991 L
.69577 .46157 L
.73591 .45182 L
Mistroke
.77439 .44003 L
.81324 .42516 L
.84474 .41032 L
.87488 .39297 L
.89907 .37595 L
.92204 .35594 L
.93947 .33671 L
.95263 .318 L
.95867 .3072 L
.96398 .29556 L
.9663 .28943 L
.96849 .28263 L
.97016 .27634 L
.97141 .27056 L
.97234 .26501 L
.97305 .25916 L
.97347 .25328 L
.97359 .24995 L
.97362 .24685 L
.97346 .2412 L
.97309 .23607 L
.9724 .23017 L
.97148 .2246 L
.96908 .21424 L
.96557 .20335 L
.95682 .18413 L
.94395 .16405 L
.9258 .14285 L
.90294 .12223 L
.87756 .10397 L
.8212 .07366 L
.78535 .0592 L
.7497 .04748 L
.70829 .03655 L
.66201 .02719 L
.63987 .02366 L
.61615 .02049 L
.59539 .01823 L
.57297 .01629 L
.56025 .01542 L
.54863 .01477 L
.53692 .01425 L
.52582 .01388 L
.51954 .01373 L
.51288 .01361 L
.50719 .01354 L
.50091 .0135 L
.49418 .0135 L
.48693 .01355 L
.48009 .01364 L
Mistroke
.47383 .01377 L
.46333 .01407 L
.45214 .01451 L
.43206 .01562 L
.40832 .01746 L
.38697 .01961 L
.34128 .02594 L
.29956 .03392 L
.26252 .04302 L
.22386 .05489 L
.18858 .06828 L
.15373 .08457 L
.12431 .10149 L
.10038 .11824 L
.08082 .13484 L
.06241 .15418 L
.04724 .17489 L
.04097 .18577 L
.03534 .1977 L
.0312 .20894 L
.02972 .2139 L
.02833 .21935 L
.02731 .22418 L
.02643 .22935 L
.02574 .23483 L
.02532 .23993 L
.02517 .24308 L
.0251 .24641 L
.0252 .25239 L
.02538 .25571 L
.02564 .25882 L
.026 .26223 L
.02651 .26589 L
.02768 .27243 L
.02913 .27862 L
.03269 .29016 L
.03722 .30126 L
.04234 .31143 L
.05718 .33389 L
.07602 .35502 L
.10087 .37651 L
.12639 .39412 L
.15675 .4112 L
.1869 .42518 L
.22269 .43886 L
.29137 .45843 L
.33453 .46719 L
.35636 .47073 L
.37684 .47356 L
.41571 .47766 L
Mistroke
.43645 .47921 L
.448 .47988 L
.45861 .48038 L
.46932 .48077 L
.48061 .48106 L
.49195 .48122 L
.49838 .48126 L
.50436 .48126 L
.51525 .48117 L
.52514 .48098 L
.53654 .48065 L
.54728 .48021 L
.5591 .4796 L
.57157 .47881 L
.59381 .47699 L
.61751 .47447 L
.64325 .47104 L
.68706 .46339 L
.72704 .45418 L
.79661 .43194 L
.83171 .41681 L
.86141 .40117 L
.89032 .38249 L
.91718 .36058 L
.93866 .33771 L
.94653 .32729 L
.95404 .31564 L
.95968 .30517 L
.96467 .29382 L
.96697 .28748 L
.96876 .28169 L
.9702 .27616 L
.97146 .27029 L
.97234 .26503 L
.97304 .25922 L
.97344 .25394 L
.97361 .24898 L
.97354 .24315 L
.97324 .23782 L
.97264 .23198 L
.97223 .22905 L
.97171 .22585 L
.96939 .21538 L
.96592 .20429 L
.9617 .19394 L
.9571 .18466 L
.94346 .1634 L
.92484 .14188 L
.88135 .10647 L
.85201 .08883 L
Mistroke
.82161 .07384 L
.78557 .05928 L
.74327 .0456 L
.70035 .03474 L
.65881 .02664 L
.61782 .02069 L
.59674 .01836 L
.57323 .01631 L
.5629 .01559 L
.55199 .01495 L
.54254 .01448 L
.53242 .01409 L
.52148 .01377 L
.51128 .01358 L
.50504 .01352 L
.49915 .01349 L
.48812 .01354 L
.4784 .01367 L
.46812 .01392 L
.45935 .01421 L
.44971 .01462 L
.4283 .01587 L
.40838 .01745 L
.38586 .01974 L
.36518 .02233 L
.31932 .02986 L
.28037 .03838 L
.24077 .04937 L
.20409 .06205 L
.17193 .07563 L
.11896 .10496 L
.09514 .12238 L
.07271 .1428 L
.05367 .16537 L
.0462 .17657 L
.04015 .18735 L
.03545 .19744 L
.03133 .20854 L
.02848 .21871 L
.02749 .22326 L
.02661 .22817 L
.02589 .23344 L
.02543 .2384 L
.02514 .24431 L
.02512 .24971 L
.02534 .25504 L
.02584 .26086 L
.02667 .26692 L
.02771 .27254 L
.03084 .28465 L
Mistroke
.03481 .29569 L
.04033 .30766 L
.04749 .32012 L
.06249 .34045 L
.08312 .36173 L
.10495 .37957 L
.13178 .39741 L
.18826 .42575 L
.22557 .43984 L
.2625 .45113 L
.30525 .46151 L
.32789 .46599 L
.35281 .47019 L
.37713 .47359 L
.39976 .47617 L
.42161 .47814 L
.43281 .47897 L
.44482 .47971 L
.4558 .48026 L
.4658 .48065 L
.47588 .48095 L
.48541 .48114 L
.49652 .48125 L
.50679 .48125 L
.51805 .48112 L
.52373 .48101 L
.52998 .48085 L
.53957 .48053 L
.54847 .48016 L
.56857 .47901 L
.58619 .47767 L
.60485 .47589 L
.64 .47151 L
.67121 .46643 L
.70673 .45914 L
.74367 .44964 L
.80576 .42829 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 142.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000eB000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00h03oool00`3ooml0W4P0000000020000000307Bo
o`3oool0oooo0<P0oooo003R0?ooo`030?noM00007@0_ooo0</0oooo003R0?ooo`030?oo_`1d0000
M;oo0</0oooo003R0?ooo`030?oog`2LB000B9cO0</0oooo003S0?ooo`030=nLB000000000000080
000000<0M;oo0?ooo`3oool00P3oool01@3o_g@000000000000004P0W=oo0080oooo00<0oono07@0
000000000P0000003@18W=l0oooo0?ooo`3oool0_g@00000000004P0W=oo0?ooo`3o_g@000000000
B02Lgol00P3oool0102oM00000000000B02Lgol20?ooo`050?noM000000000000000B02Lgol00`3o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000000007Bo0980oooo003S0?ooo`070?noM00004P0
W=oo0?ooo`3ooml0W4P0001d_`020?ooo`0?0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`3oool0
oooO09a8001d_ol0oooo0?oOW0180000M;oo0080oooo01L0gia80018W03Ooml0W7BL0=ooo`3o_g@0
001809cOg`2LM9`0gooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0
B000001d_`020?ooo`030?noM00007@0_ooo0080oooo00@0gia80018W03O_g@0M;ooT@3oool00><0
oooo00<0oono07@0001d_ol00P3oool01`3ooml0W4P004RLg`3oool0gia80018W03Oool00P3oool0
2P3ogi`0B00004RLg`3oool0_gAd0;ooo`3oool0oono07@0001d_ol20?ooo`030?noM00004P0W=oo
0080oooo00<0oono07@0001d_ol00`3oool00`3o_g@0001809cOo`020?ooo`030=nLB000B9`0gooo
0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol0TP3o
ool00><0oooo00<0oooO09a80018W=l00`3oool01P3ogi`0B01809cOo`3o_g@0001d0;ooo`<0oooo
00<0gia80000M02oool00`3oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo
00<0_g@0001d_`3oool00P3oool00`3ookl0M00004RLg`020?ooo`030?noM00007@0_ooo00<0oooo
00/0gia80000M02oool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`2B0?ooo`00i03oool0
0`3OW4P0001d0;ooo`020?ooo`060?oog`2LB000B9cO0?oo_`1d0000M;oo0`3oool00`3ogi`0B018
09cOo`020?ooo`030?noM00004P0W=oo00@0oooo00<0_g@00018W03Oool00P3oool00`3OW4P004RL
0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3ookl0M00007Boo`030?ooo`070?oOW01804P0W=oo
0?ooo`3OW4P004Q804Qd_`020?ooo`030;md0000M;l0oooo0940oooo003T0?ooo`040?noM0000000
04RL0=ooo`80oooo00H0gia8001d_`3oool0gia80000M02oool20?ooo`0:0?oo_`1d0000M;oo0?oo
o`3ogi`0B01809cOo`3oool0giad09cOo`80oooo00<0gia80000B02Lgol00P3oool00`3ogi`0B018
09cOo`030?ooo`030=nLB00004P0W=oo0080oooo00<0gia80000M02oool00P3oool0303ookl0M000
07Boo`3oool0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;oooi40oooo003T0?ooo`080?oo_`1d
0000M9bL04P0M02oool0oooO09a80000M;l20?ooo`0>0;md000007@0_ooo0?ooo`3o_g@0001d0;oo
o`3oool0omnL04P0B02Lgol0oooO09a8001d_ol20?ooo`030?oOW0180000B9cO0080oooo00<0oooO
09a80018W=l00`3oool00`3ogi`0B00004RLg`030?ooo`0@0;md000007@0_ooo0?ooo`3o_g@0001d
0;ooo`3oool0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOoi40oooo003S0?ooo`090?oOW018
0000000004RLg`3ookl0M0000000000007@0_ooo00<0oooo00D0okmd000000000000000007Boo`03
0?ooo`070;md00000000000000000018W=l0oooo0?noM002000000040018W03Oool0oono07@000<0
000000H0M;oo0?noM000000000000018W03Oool30?ooo`0?0?noM000000000000000001d_ol0oooo
0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo0940oooo003o0?ooo`D0oooo00<0okmd
0000M02oool0Z@3oool00?l0oooo1P3oool00`3OW7@0W=oo0?ooo`2X0?ooo`00o`3oool0103ookl0
M0000018W03Oool70?ooo`040?oo_`1d000004RL0=oooj80oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo002I0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol0
0P3oool00`3ookl0M000000000020000000304RLg`3oool0oooo01T0oooo00@0_g@0000000000000
M;oo0`3oool00`3ogi`0B00007Boo`040?ooo`040;md00000000000007Boo`<0oooo00H0omnL04P0
0000000000000018W03OoolK0?ooo`040;md00000000000007Boob80oooo00@0_g@0000000000000
M;oo0`3oool00`3ogi`0B00007Boo`040?ooo`040;md00000000000007Boo`<0oooo00H0omnL04P0
0000000000000018W03OoolK0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol0
0P3oool00`3ookl0M000000000020000000304RLg`3oool0oooo04@0oooo002H0?ooo`060=nLB000
M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`040?ooo`030?noM0000000M;oo01/0
oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo00<0oooo00H0gia8
001d_`3oool0omnL04P00018W=l20?ooo`060?noM0000000M;oo0?ooo`3ogi`0B7Bo6P3oool01P3O
W4P007Bo0?ooo`3ogi`0B00004RLgb00oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`03
0?oOW0180000M;oo00<0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`060?noM0000000
M;oo0?ooo`3ogi`0B7Bo6P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0
001d_ol0103oool00`3o_g@0000007Boo`170?ooo`00U`3oool00`3ooml0W4P004RLg`020?ooo`03
0?noM00004P0W=oo00P0oooo00<0oooO09a80000M;l06P3oool00`3ooml0W4P004RLg`020?ooo`03
0?noM00004P0W=oo00H0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`060?ooo`03
0?noM018W=l0oooo01L0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`0N0?ooo`03
0?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol01P3oool00`3ooml0W4P004RLg`020?ooo`03
0?noM00004P0W=oo00H0oooo00<0okmd04RLg`3oool05`3oool00`3ooml0W4P004RLg`020?ooo`03
0?noM00004P0W=oo00P0oooo00<0oooO09a80000M;l0A`3oool009L0oooo00<0oooO09a80018W=l0
0P3oool0103ooml0W4P00018W03Oool80?ooo`030=nLB000B9`0gooo01T0oooo00<0oooO09a80018
W=l00P3oool0103ooml0W4P00018W03Oool50?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a8
0000B9`0gooo1@3oool00`3ookl0M01d0;ooo`0G0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO
09a80000B9`0gooo7@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`D0oooo
00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool50?ooo`030?oo_`1d07@0_ooo01L0
oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool80?ooo`030=nLB000B9`0gooo
04H0oooo002:0?ooo`030?oog`2LB000000000L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l3
0?ooo`030=nLB00004P0W=oo00P0oooo00<0omnL04P0B02Lgol0303oool00`3ooml0W4P000000007
0000000604RLg`3oool0oooo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`050?ooo`030?oo
g`2LB00007Bo00<0oooo00<0gia80000B02Lgol01@3oool00`3ooml0W4P007Boo`0G0?ooo`030?oo
g`2LB00007Bo00<0oooo00<0gia80000B02Lgol07@3oool00`3ooml0W4P0001d_`030?ooo`030=nL
B00004P0W=oo00D0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`050?ooo`030?oo
g`2LB000M;oo01L0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`080?ooo`030?oO
W01804P0W=oo04H0oooo002H0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0203o
ool00`3ookl0M00007Boo`0J0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01P3o
ool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00D0oooo00<0oono07@00018W=l0603o
ool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO01h0oooo00<0_g@00018W03Oool00P3o
ool00`3ogi`0B00004RLg`060?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01@3o
ool00`3ookl0M00004RLg`0H0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0203o
ool00`3ookl0M00007Boo`160?ooo`00V03oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB000
07Bo00T0oooo00<0_g@0001d_`3oool06@3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB000
07Bo00H0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`050?ooo`030?noM0000000
M;oo01P0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0N0?ooo`030=nLB00004P0
W=oo0080oooo00<0oooO09a80000M;l01P3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB000
07Bo00D0oooo00<0okmd0000001d_ol0603oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB000
07Bo00T0oooo00<0_g@0001d_`3oool0A@3oool009P0oooo00<0omnL04P00018W=l00`3oool00`2o
M00004RL0=ooo`080?ooo`030=nLB000B9`0gooo01T0oooo00<0omnL04P00018W=l00`3oool00`2o
M00004RL0=ooo`050?ooo`030?oOW0180000B9cO00<0oooo00X0_g@00018W03Oool0oooo0?oOg`3O
ool0okmd0000000007@0_ooo603oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo01d0
oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`050?ooo`030?oOW0180000B9cO00<0
oooo00X0_g@00018W03Oool0oooo0?oOg`3Oool0okmd0000000007@0_ooo603oool00`3ogi`0B000
04RLg`030?ooo`030;md0000B9`0gooo00P0oooo00<0gia80018W03Oool0A@3oool009P0oooo00@0
oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`080?ooo`030?oOW01804P0W=oo01T0oooo
00@0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`050?ooo`040?oog`2LB00004RL0=oo
o`80oooo00T0gia80018W03Oool0oooo0?oo_`1d000000000000B02Lgol06@3oool0103ooml0W4P0
0018W03Oool20?ooo`030=nLB000B9`0gooo01d0oooo00@0oooO09a80000B9`0gooo0P3oool00`3O
W4P004RL0=ooo`050?ooo`040?oog`2LB00004RL0=ooo`80oooo00T0gia80018W03Oool0oooo0?oo
_`1d000000000000B02Lgol06@3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo
00P0oooo00<0omnL04P0B02Lgol0A@3oool009T0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P0
07Bo0?ooo`080?ooo`030?oo_`1d0000M;oo01X0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P0
07Bo0?ooo`060?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool00P3oool00`3OW9`0
_ooo0?ooo`0K0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool07P3oool00`3ogi`0
B00007Boo`020?ooo`030=nLB000M;l0oooo00H0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P0
07Bo0?ooo`020?ooo`030=nLW02oool0oooo01/0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P0
07Bo0?ooo`080?ooo`030?oo_`1d0000M;oo04D0oooo002J0?ooo`060=nLB00007@0_ooo0?oog`2L
B000B9cO2P3oool00`2oM00007Bo0?ooo`0J0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO203o
ool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`<0oooo00<0omnL07BLg`3oool0703oool01P3OW4P0
001d0;ooo`3ooml0W4P004RLgb00oooo00H0gia80000M02oool0oooO09a80018W=l80?ooo`060=nL
B00007@0_ooo0?oog`2LB000B9cO0`3oool00`3ogi`0M9cO0?ooo`0L0?ooo`060=nLB00007@0_ooo
0?oog`2LB000B9cO2P3oool00`2oM00007Bo0?ooo`140?ooo`00V`3oool0103OW4P0000000000000
M;l90?ooo`050?oo_`1d000000000000M02oool06`3oool0103OW4P0000000000000M;l:0?ooo`04
0=nLB00000000000001d_`D0oooo00D0_g@0000000000000000004RLg`0J0?ooo`040=nLB0000000
0000001d_b80oooo00@0gia800000000000007Bo2P3oool0103OW4P0000000000000M;l50?ooo`05
0;md00000000000000000018W=l06P3oool0103OW4P0000000000000M;l90?ooo`050?oo_`1d0000
00000000M02oool0A03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool007H0oooo
o`00000C000002P0oooo001f0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool09P3o
ool007H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`250?ooo`030000003oool0
oooo02H0oooo001B0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol0103oool0
102oM00000000000001d_ol40?ooo`050?oog`2LB000000000000000M;l02@3oool2000007D0oooo
9000001e0?ooo`800000:03oool00540oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`03
0?oOW0180000M;oo00<0oooo00H0gia8001d_`3oool0omnL04P00018W=l30?ooo`070=nLB000M;l0
oooo0?oo_`1d000004RL0=ooo`070?ooo`030000003oool0oooo06T0oooo>P00001[0?ooo`030000
003oool0oooo02H0oooo001@0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol01P3o
ool00`3ooml0W4P004RLg`020?ooo`070?noM00004P0W=oo0?ooo`3ooml0W4P007Boo`020?ooo`03
0?oOW0180000B9cO00L0oooo00<000000?ooo`3oool0H03ooolA000001D0oooo00<000000?ooo`3o
ool04@3ooolD00000600oooo00<000000?ooo`3oool09P3oool00500oooo00<0oooO09a80018W=l0
0P3oool0103ooml0W4P00018W03Oool50?ooo`030?oog`2LB000B9cO0080oooo00L0oooO09a80000
B9`0gooo0?oo_`1d0000M;oo00<0oooo00<0_g@00000M02oool01P3oool00`000000oooo0?ooo`1I
0?oooa0000007@3oool00`000000oooo0?ooo`0I0?oooa400000F`3oool00`000000oooo0?ooo`0V
0?ooo`00@`3oool00`3ooml0W4P0000000070000000604RLg`3oool0oooo0?oog`2LB00007Bo0`3o
ool00`3OW4P0001809cOo`050?ooo`030?oog`2LB00007Bo00<0oooo00H0gia80000B02Lgol0oooO
09a80000M;l30?ooo`030=nLB00004P0W=oo00H0oooo00<000000?ooo`3oool0E03oool<000002H0
oooo00<000000?ooo`3oool08@3oool=000005L0oooo00<000000?ooo`3oool09P3oool00540oooo
00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`060?ooo`030;md0000B9`0gooo0080oooo
00L0omnL04P00018W=l0oooo0;md000007@0_ooo0080oooo00<0gia80000B02Lgol01P3oool30000
04l0oooo2`00000/0?ooo`030000003oool0oooo02P0oooo2`00001A0?ooo`800000:03oool00540
oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`060?ooo`030=nLB00004P0W=oo0080
oooo00`0oooO09a80000M;l0oooo0?noM0000000B9cO0?ooo`3ooml0W4P00018W03Oool60?ooo`03
0000003oool0oooo04/0oooo2@00000b0?ooo`030000003oool0oooo02h0oooo2@00001>0?ooo`03
0000003oool0oooo02H0oooo001A0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool0
1@3oool00`3ogi`0B00004RLg`030?ooo`050;md0000B9`0gooo0?oog`2LB0000`0000000`0007@0
_ooo0?ooo`060?ooo`030000003oool0oooo04L0oooo2@00000f0?ooo`030000003oool0oooo03<0
oooo2@0000190?ooo`030000003oool0oooo02H0oooo001A0?ooo`040?oog`2LB00004RL0=ooo`80
oooo00<0gia80018W03Oool01@3oool0103ooml0W4P00018W03Oool20?ooo`070=nLB000B9`0gooo
0?ooo`3ookl0M000001d_`0:0?ooo`030000003oool0oooo04<0oooo2@00000j0?ooo`030000003o
ool0oooo03L0oooo200000160?ooo`030000003oool0oooo02H0oooo001B0?ooo`030?oOW0180000
M;oo0080oooo00<0gia8001d_`3oool01P3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0
oooo0080oooo00<0omnL04P00018W=l02@3oool00`000000oooo0?ooo`100?ooo`P00000?P3oool0
0`000000oooo0?ooo`0k0?ooo`P00000@P3oool00`000000oooo0?ooo`0V0?ooo`00D`3oool01P3O
W4P0001d0;ooo`3ooml0W4P004RLg`P0oooo00H0gia80000M02oool0oooO09a80018W=l40?ooo`04
0?oog`2LB000001d0;ooo`L0oooo0P00000n0?ooo`L00000@P3oool00`000000oooo0?ooo`0n0?oo
o`P00000?P3oool2000002P0oooo001D0?ooo`040=nLB00000000000001d_`X0oooo00@0gia80000
0000000007Bo1`3oool0103ookl0M00000000018W=l50?ooo`030000003oool0oooo03X0oooo1`00
00150?ooo`030000003oool0oooo0480oooo1`00000l0?ooo`030000003oool0oooo02H0oooo001f
0?ooo`030000003oool0oooo03L0oooo1`0000180?ooo`030000003oool0oooo04D0oooo1`00000i
0?ooo`030000003oool0oooo02H0oooo001f0?ooo`030000003oool0oooo03@0oooo1`00001;0?oo
o`030000003oool0oooo04P0oooo1`00000f0?ooo`030000003oool0oooo02H0oooo001f0?ooo`03
0000003oool0oooo0380oooo1P00001>0?ooo`030000003oool0oooo04/0oooo1P00000d0?ooo`03
0000003oool0oooo02H0oooo001f0?ooo`800000<@3oool600000500oooo00<000000?ooo`3oool0
C@3oool600000340oooo0P00000X0?ooo`00MP3oool00`000000oooo0?ooo`0^0?ooo`D00000D`3o
ool00`000000oooo0?ooo`1@0?ooo`H00000;`3oool00`000000oooo0?ooo`0V0?ooo`00MP3oool0
0`000000oooo0?ooo`0[0?ooo`H00000E@3oool00`000000oooo0?ooo`1B0?ooo`H00000;@3oool0
0`000000oooo0?ooo`0V0?ooo`00MP3oool00`000000oooo0?ooo`0Y0?ooo`H00000E`3oool00`00
0000oooo0?ooo`1D0?ooo`H00000:`3oool00`000000oooo0?ooo`0V0?ooo`00MP3oool00`000000
oooo0?ooo`0W0?ooo`D00000FP3oool00`000000oooo0?ooo`1F0?ooo`H00000:@3oool00`000000
oooo0?ooo`0V0?ooo`00DP3oool0102oM00000000000001d_ol30?ooo`030?oOW0180000M;oo00@0
oooo00@0_g@0000000000000M;oo1P3oool00`3ooml0W4P004RLg`090?ooo`8000009P3oool50000
05`0oooo00<000000?ooo`3oool0F03oool6000002H0oooo0P00000X0?ooo`00D@3oool01P3OW4P0
07Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00`3oool01P3OW4P007Bo0?ooo`3o
gi`0B00004RLg`H0oooo00<0gia80018W03Oool0203oool00`000000oooo0?ooo`0S0?ooo`D00000
GP3oool00`000000oooo0?ooo`1J0?ooo`H000009@3oool00`000000oooo0?ooo`0V0?ooo`00D03o
ool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00H0oooo00<0oooO09a80018W=l00P3o
ool00`3o_g@0001809cOo`050?ooo`030?oOW01804P0W=oo00P0oooo00<000000?ooo`3oool08P3o
ool400000600oooo00<000000?ooo`3oool0G03oool6000002<0oooo00<000000?ooo`3oool09P3o
ool00500oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool50?ooo`030?oog`2L
B000B9cO0080oooo00D0oooO09a80000B9`0gooo0?noM006000000030018W03Oool0oooo00D0oooo
00<000000?ooo`3oool0803oool400000680oooo00<000000?ooo`3oool0GP3oool500000280oooo
00<000000?ooo`3oool09P3oool004<0oooo00<0oooO09a8000000001`0000001P18W=l0oooo0?oo
o`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol01@3oool00`3ooml0W4P0001d_`030?ooo`06
0=nLB00004P0W=oo0?oog`2LB4P0W=oo0P3oool00`2oM00007Bo0?ooo`070?ooo`030000003oool0
oooo01h0oooo1@00001S0?ooo`030000003oool0oooo0600oooo1000000Q0?ooo`030000003oool0
oooo02H0oooo001A0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l01P3oool00`2o
M00004RL0=ooo`020?ooo`0;0?oOW0180000B9cO0?ooo`3ookl0M01d0;ooo`3oool0okmd0018W03O
ool01`3oool3000001d0oooo1000001U0?ooo`030000003oool0oooo0680oooo1000000N0?ooo`80
0000:03oool00540oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`060?ooo`030=nL
B00004P0W=oo0080oooo00<0oooO09a80000M;l00P3oool01P3ogi`0B4RL0=ooo`3ogi`0B01809cO
o`L0oooo00<000000?ooo`3oool0703oool4000006H0oooo00<000000?ooo`3oool0H`3oool40000
01h0oooo00<000000?ooo`3oool09P3oool00540oooo00<0omnL04P00018W=l00`3oool00`2oM000
04RL0=ooo`050?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool00P3oool01@3o_g@0
07Bo0?oog`2LB000B9cO00L0oooo00<000000?ooo`3oool06P3oool4000006P0oooo00<000000?oo
o`3oool0I@3oool4000001`0oooo00<000000?ooo`3oool09P3oool00540oooo00@0oooO09a80000
B9`0gooo0P3oool00`3OW4P004RL0=ooo`050?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia8
0018W03Oool00`3oool0103OW4P0B9cO0;md0000M;l70?ooo`030000003oool0oooo01T0oooo1000
001Y0?ooo`030000003oool0oooo06H0oooo1000000K0?ooo`030000003oool0oooo02H0oooo001B
0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01P3oool00`3ogi`0B00007Boo`02
0?ooo`030=nLB000M;l0oooo00@0oooo00@0gia807AdM00007@0_ooo1P3oool00`000000oooo0?oo
o`0H0?ooo`<00000J`3oool00`000000oooo0?ooo`1W0?ooo`@000006P3oool00`000000oooo0?oo
o`0V0?ooo`00D`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`P0oooo00H0gia80000M02oool0
oooO09a80018W=l60?ooo`030;md000004P0W=oo00H0oooo0P00000G0?ooo`@00000K03oool00`00
0000oooo0?ooo`1Y0?ooo`<00000603oool2000002P0oooo001D0?ooo`040=nLB00000000000001d
_`X0oooo00@0gia800000000000007Bo1`3oool00`3ooml0W4P004RLg`060?ooo`030000003oool0
oooo01D0oooo0`00001^0?ooo`030000003oool0oooo06X0oooo1000000G0?ooo`030000003oool0
oooo02H0oooo001f0?ooo`030000003oool0oooo01@0oooo0`00001_0?ooo`030000003oool0oooo
06`0oooo0`00000F0?ooo`030000003oool0oooo02H0oooo001f0?ooo`030000003oool0oooo01<0
oooo0`00001`0?ooo`030000003oool0oooo06d0oooo0`00000E0?ooo`030000003oool0oooo02H0
oooo001f0?ooo`030000003oool0oooo0180oooo0`00001a0?ooo`030000003oool0oooo06h0oooo
0`00000D0?ooo`030000003oool0oooo02H0oooo001f0?ooo`8000004P3oool300000780oooo00<0
00000?ooo`3oool0K`3oool300000180oooo0P00000X0?ooo`00MP3oool00`000000oooo0?ooo`0@
0?ooo`<00000L`3oool00`000000oooo0?ooo`1`0?ooo`<000004P3oool00`000000oooo0?ooo`0V
0?ooo`00;`3oool00`3ookl0M7Bo0?ooo`140?ooo`030000003oool0oooo00l0oooo0`00001d0?oo
o`030000003oool0oooo0740oooo0`00000A0?ooo`030000003oool0oooo02H0oooo000_0?ooo`04
0?oOW0180000001809cOod<0oooo00<000000?ooo`3oool03P3oool3000007D0oooo00<000000?oo
o`3oool0LP3oool300000100oooo00<000000?ooo`3oool09P3oool00340oooo00<0_g@000000000
00000`0000000`0007@0_ooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo0`00001f0?ooo`03
0000003oool0oooo07<0oooo0`00000?0?ooo`030000003oool0oooo02H0oooo000e0?ooo`030?oO
W0180000M;oo01X0oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`040?ooo`04
0;md00000000000007Boo`<0oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`060?oo
o`8000003@3oool3000007L0oooo00<000000?ooo`3oool0M03oool2000000h0oooo0P00000X0?oo
o`00=03oool00`3OW4P0001d0;ooo`0J0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool0
0`3ogi`0B00007Boo`030?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0`3oool00`3o_g@007Bo
0?ooo`020?ooo`030;mdM02oool0oooo00H0oooo00<000000?ooo`3oool0303oool3000007L0oooo
00<000000?ooo`3oool0M03oool3000000h0oooo00<000000?ooo`3oool09P3oool002l0oooo00H0
omnL04P0B02Lgol0okmd00000018W=lK0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02L
gol01P3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00<0oooo00<0okmd001d_`3o
ool02P3oool00`000000oooo0?ooo`0;0?ooo`<00000N03oool00`000000oooo0?ooo`1e0?ooo`<0
00003@3oool00`000000oooo0?ooo`0V0?ooo`00;`3oool0103ogi`0B00000000000M;lM0?ooo`03
0?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo1@3oool00`3ooml0W4P004RLg`020?oo
o`040?oog`2LB00004RL0=ooo`<0oooo00<0okmd001d_`3oool02@3oool00`000000oooo0?ooo`0:
0?ooo`<00000N@3oool00`000000oooo0?ooo`1f0?ooo`8000003@3oool00`000000oooo0?ooo`0V
0?ooo`00@`3oool00`3ooml0W4P0000000070000000604RLg`3oool0oooo0?oog`2LB00007Bo0`3o
ool00`3OW4P0001809cOo`050?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol0103o
ool00`3o_g@0B9cO0?ooo`080?ooo`030000003oool0oooo00X0oooo0P00001j0?ooo`030000003o
ool0oooo07L0oooo0P00000<0?ooo`030000003oool0oooo02H0oooo001A0?ooo`030;md0000B9`0
gooo0080oooo00<0omnL04P00018W=l01P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000
B9cO00D0oooo00<0gia804RLg`3oool01`3oool3000000T0oooo0`00001j0?ooo`030000003oool0
oooo07L0oooo0`00000:0?ooo`800000:03oool00380oooo00H0gia800000000000000000000B02L
golI0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l01P3oool00`3OW4P0001809cO
o`020?ooo`030?oog`2LB00007Bo00H0oooo00<0_g@007Boo`3oool01P3oool00`000000oooo0?oo
o`090?ooo`800000N`3oool00`000000oooo0?ooo`1h0?ooo`<000002P3oool00`000000oooo0?oo
o`0V0?ooo`00<03oool02@3ookl0M00004RLg`3ogi`0W;oo0?ooo`3OW4P004RL0=ooo`0H0?ooo`03
0?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01@3oool00`3ogi`0B00004RLg`030?ooo`03
0;md0000B9`0gooo00D0oooo00<0omnL04P0M02oool01P3oool00`000000oooo0?ooo`080?ooo`<0
0000N`3oool00`000000oooo0?ooo`1i0?ooo`8000002P3oool00`000000oooo0?ooo`0V0?ooo`00
<03oool02@2oM7@0_ooo0?ooo`3o_i`0W=oo0?ooo`3ookl0M01d0;ooo`0H0?ooo`040?oog`2LB000
04RL0=ooo`80oooo00<0gia80018W03Oool01@3oool0103ooml0W4P00018W03Oool20?ooo`030=nL
B000B9`0gooo00D0oooo00<0oooO09a8001d_ol01P3oool00`000000oooo0?ooo`070?ooo`<00000
O03oool00`000000oooo0?ooo`1i0?ooo`<000002@3oool00`000000oooo0?ooo`0V0?ooo`00;`3o
ool02@3ogi`0W;oo0?ooo`3ooml0W7BL0=ooo`3oool0omnL04Qd_`0J0?ooo`030?oOW0180000M;oo
0080oooo00<0gia8001d_`3oool01P3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo
00D0oooo00<0oono07@00018W=l01P3oool2000000P0oooo0P00001m0?ooo`030000003oool0oooo
07X0oooo0P0000080?ooo`800000:03oool002l0oooo00T0oknL09cOo`3oool0_g@007Boo`3oool0
gia80000M02oool06`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`P0oooo00H0gia80000M02o
ool0oooO09a80018W=l20?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cOo`060?ooo`030000
003oool0oooo00L0oooo0P00001m0?ooo`030000003oool0oooo07X0oooo0`0000080?ooo`030000
003oool0oooo02H0oooo000_0?ooo`040?oo_`1d0000000007Boob40oooo00@0gia8000000000000
07Bo2P3oool0103OW4P0000000000000M;l40?ooo`050?oOW018000000000000001d_ol01`3oool0
0`000000oooo0?ooo`060?ooo`800000OP3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool0
0`000000oooo0?ooo`0V0?ooo`00MP3oool00`000000oooo0?ooo`050?ooo`<00000OP3oool00`00
0000oooo0?ooo`1k0?ooo`<000001`3oool00`000000oooo0?ooo`0V0?ooo`00MP3oool00`000000
oooo0?ooo`050?ooo`800000O`3oool00`000000oooo0?ooo`1k0?ooo`<000001`3oool00`000000
oooo0?ooo`0V0?ooo`00<`3oool01P3o_g@00000000000000000001d0;ooocd0oooo0P0000060?oo
o`800000O`3oool00`000000oooo0?ooo`1k0?ooo`<000001P3oool2000002P0oooo000[0?ooo`06
0;nLW03Oool0oooo0?ooo`3ogi`0B0000`0000001000B9`0gooo0?oo_`1dM;ln0?ooo`030000003o
ool0oooo00D0oooo0P00001o0?ooo`030000003oool0oooo07`0oooo0`0000060?ooo`030000003o
ool0oooo02H0oooo000Z0?ooo`030?oog`2LB000000000<0000000<007Bo0?ooo`3oool00P3oool0
0`3o_g@0001d0;ooo`0n0?ooo`030000003oool0oooo00@0oooo0P0000200?ooo`030000003oool0
oooo07`0oooo0`0000060?ooo`030000003oool0oooo02H0oooo000Z0?ooo`030?oo_`1d0000B9cO
04T0oooo00<000000?ooo`3oool0103oool200000800oooo00<000000?ooo`3oool0O@3oool20000
00H0oooo00<000000?ooo`3oool09P3oool007H0oooo00<000000?ooo`3oool0103oool200000800
oooo00<000000?ooo`3oool0O@3oool2000000H0oooo00<000000?ooo`3oool09P3oool00380oooo
00H0omnL04P00000000000000000B02Lgola0?ooo`040;md00000000000007Boo`T0oooo0P000005
0?ooo`800000P03oool00`000000oooo0?ooo`1m0?ooo`8000001@3oool2000002P0oooo000a0?oo
o`030;md00000000M;oo0080oooo00<0oooO09adW03Oool0;`3oool01P3OW4P007Bo0?ooo`3ogi`0
B00004RLg`P0oooo00<000000?ooo`3oool0103oool200000800oooo00<000000?ooo`3oool0O@3o
ool3000000D0oooo00<000000?ooo`3oool09P3oool00300oooo00<0gia804RLg`3oool0103oool0
0`3OW9`0_ooo0?ooo`0]0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol01`3oool0
0`000000oooo0?ooo`040?ooo`800000P03oool00`000000oooo0?ooo`1m0?ooo`<000001@3oool0
0`000000oooo0?ooo`0V0?ooo`00;`3oool00`3ogi`0M9cO0?ooo`040?ooo`030?oog`2LM9`0gooo
02h0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oool60?ooo`030000003oool0
oooo00@0oooo0P0000200?ooo`030000003oool0oooo07d0oooo0`0000050?ooo`030000003oool0
oooo02H0oooo000_0?ooo`030?noW02Lgol0oooo00<0oooo00<0oooO09a8001d_ol0;`3oool00`3o
oml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00H0oooo00<000000?ooo`3oool0103oool20000
0800oooo00<000000?ooo`3oool0O@3oool3000000D0oooo00<000000?ooo`3oool09P3oool002l0
oooo00<0omnL04Qd_`3oool00P3oool00`3OW4P0000004RLg`0a0?ooo`030;md0000B9`0gooo0080
oooo00<0omnL04P00018W=l01P3ooooo000001<00000:03oool00300oooo00H0okmd000000000000
00000018W03Ooolb0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l01P3oool00`00
0000oooo0?ooo`040?ooo`800000P03oool00`000000oooo0?ooo`1n0?ooo`8000001@3oool00`00
0000oooo0?ooo`0V0?ooo`00J03oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00D0
oooo00<000000?ooo`3oool0103oool200000800oooo00<000000?ooo`3oool0O@3oool3000000D0
oooo00<000000?ooo`3oool09P3oool006P0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P0
04RL0=ooo`050?ooo`030000003oool0oooo00@0oooo0P0000200?ooo`030000003oool0oooo07d0
oooo0`0000050?ooo`030000003oool0oooo02H0oooo000b0?ooo`060?oOW0180000000000000000
04P0W=oo<@3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00D0oooo00<000000?oo
o`3oool0103oool200000800oooo00<000000?ooo`3oool0O@3oool2000000H0oooo00<000000?oo
o`3oool09P3oool00300oooo00@0oooO09a80000B9`0gooo0P3oool00`3o_g@004RL0=ooo`0a0?oo
o`060=nLB00007@0_ooo0?oog`2LB000B9cO1P3oool2000000D0oooo0P0000200?ooo`030000003o
ool0oooo07d0oooo0P0000050?ooo`800000:03oool00300oooo00<0_gA809cOo`3oool00`3oool0
0`3ooml0W4Qd0;ooo`0b0?ooo`040=nLB00000000000001d_`L0oooo00<000000?ooo`3oool0103o
ool200000800oooo00<000000?ooo`3oool0O@3oool2000000H0oooo00<000000?ooo`3oool09P3o
ool002l0oooo00<0omnL09boo`3oool0103oool00`3ogi`0B7Bo0?ooo`0m0?ooo`030000003oool0
oooo00@0oooo0P0000200?ooo`030000003oool0oooo07d0oooo0P0000060?ooo`030000003oool0
oooo02H0oooo000_0?ooo`030?noW02Lgol0oooo00<0oooo00<0omnL04Q8W03Oool0?P3oool00`00
0000oooo0?ooo`040?ooo`<00000O`3oool00`000000oooo0?ooo`1l0?ooo`<000001P3oool00`00
0000oooo0?ooo`0V0?ooo`00;`3oool0103ookl0M0000000001d_om30?ooo`030000003oool0oooo
00@0oooo0`00001o0?ooo`030000003oool0oooo07`0oooo0`0000060?ooo`030000003oool0oooo
02H0oooo001f0?ooo`8000001P3oool2000007l0oooo00<000000?ooo`3oool0O03oool2000000H0
oooo0P00000X0?ooo`00MP3oool00`000000oooo0?ooo`050?ooo`800000O`3oool00`000000oooo
0?ooo`1l0?ooo`8000001`3oool00`000000oooo0?ooo`0V0?ooo`00;`3oool00`3ookl0W9cO0?oo
o`030?ooo`040?noM0000000001d0;ooocd0oooo00<000000?ooo`3oool01@3oool3000007h0oooo
00<000000?ooo`3oool0N`3oool3000000L0oooo00<000000?ooo`3oool09P3oool002l0oooo00@0
oono09bLg`3ookl0M000100000000`00B9`0gooo0?ooo`0l0?ooo`030000003oool0oooo00H0oooo
0P00001n0?ooo`030000003oool0oooo07/0oooo0P0000080?ooo`030000003oool0oooo02H0oooo
000_0?ooo`090?oOW018000000000000B02Lgol0oooo0?oog`2LB7@0_ooo03h0oooo00<000000?oo
o`3oool01P3oool3000007d0oooo00<000000?ooo`3oool0NP3oool3000000P0oooo00<000000?oo
o`3oool09P3oool002/0oooo00@0oooO09a8000007@0_ooo8`3oool0102oM00000000000001d_ol3
0?ooo`030?oOW0180000M;oo00@0oooo00@0_g@0000000000000M;oo0`3oool00`3OW4P000000000
00030000000304RLg`3oool0oooo00H0oooo0P0000080?ooo`800000O@3oool00`000000oooo0?oo
o`1j0?ooo`<000001`3oool2000002P0oooo001A0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO
0P3oool00`3ogi`0B00007Boo`030?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0`3oool00`3o
_g@007Bo0?ooo`020?ooo`030;mdM02oool0oooo00H0oooo00<000000?ooo`3oool01`3oool30000
07`0oooo00<000000?ooo`3oool0N@3oool3000000T0oooo00<000000?ooo`3oool09P3oool002l0
oooo00D0omno0;oOo`3oool0oooo0;md0003000000030000M02oool0oooo01H0oooo00<0oooO09a8
0018W=l00P3oool00`3o_g@0001809cOo`060?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000
B02Lgol00`3oool00`3o_g@007Bo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo0P00001l0?oo
o`030000003oool0oooo07T0oooo0`0000090?ooo`030000003oool0oooo02H0oooo000_0?ooo`03
0;md0000000000000080000000D0001d0;ooo`3oool0_ibL0=ooo`0G0?ooo`030?oog`2LB000B9cO
0080oooo00@0oooO09a80000B9`0gooo1@3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB000
04RL0=ooo`<0oooo00<0okmd001d_`3oool02@3oool00`000000oooo0?ooo`080?ooo`<00000N`3o
ool00`000000oooo0?ooo`1h0?ooo`<000002P3oool00`000000oooo0?ooo`0V0?ooo`00;@3oool0
1@2oM000000000000000B9`0gooo00<0oooo00<0oooO09a8001d_ol00P3oool00`2oM00004RL0=oo
o`0C0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol01@3oool00`3ooml0W4P0001d
_`030?ooo`030=nLB00004P0W=oo00@0oooo00<0okmd04RLg`3oool0203oool00`000000oooo0?oo
o`090?ooo`800000N`3oool00`000000oooo0?ooo`1h0?ooo`<000002P3oool00`000000oooo0?oo
o`0V0?ooo`00;`3oool00`3o_i`0W=oo0?ooo`080?ooo`030?oOW018M;l0oooo01@0oooo00<0_g@0
0018W03Oool00P3oool00`3ogi`0B00004RLg`060?ooo`030;md0000B9`0gooo0080oooo00<0omnL
04P00018W=l01@3oool00`3OW4P0B9cO0?ooo`070?ooo`<000002@3oool3000007X0oooo00<00000
0?ooo`3oool0M`3oool3000000X0oooo0P00000X0?ooo`00;`3oool00`3ookl0M7Bo0?ooo`070?oo
o`030?noM000B9`0gooo01D0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`060?oo
o`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l01P3oool00`2oM000M;oo0?ooo`060?oo
o`030000003oool0oooo00X0oooo0`00001i0?ooo`030000003oool0oooo07H0oooo0`00000<0?oo
o`030000003oool0oooo02H0oooo000_0?ooo`040?oOW0180000001d0;ooo`D0oooo00<0gia8001d
_`3oool05P3oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00D0oooo00<0omnL04P0
0018W=l00`3oool00`2oM00004RL0=ooo`050?ooo`030?oOW01807@0_ooo00H0oooo00<000000?oo
o`3oool02P3oool3000007T0oooo00<000000?ooo`3oool0MP3oool3000000`0oooo00<000000?oo
o`3oool09P3oool00300oooo00<0omnL04P0000000001@0000000`18W=l0oooo0?ooo`0F0?ooo`04
0?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool01@3oool0103ooml0W4P00018W03Oool2
0?ooo`030=nLB000B9`0gooo00D0oooo00<0oooO09a8001d_ol01P3oool00`000000oooo0?ooo`0;
0?ooo`<00000N03oool00`000000oooo0?ooo`1e0?ooo`<000003@3oool00`000000oooo0?ooo`0V
0?ooo`00=@3oool00`3o_g@0001809cOo`0J0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d
_`3oool01P3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00D0oooo00<0oono07@0
0018W=l01P3oool00`000000oooo0?ooo`0<0?ooo`<00000M`3oool00`000000oooo0?ooo`1d0?oo
o`<000003P3oool00`000000oooo0?ooo`0V0?ooo`00=03oool00`2oM00007Bo0?ooo`0L0?ooo`06
0=nLB00007@0_ooo0?oog`2LB000B9cO203oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`80oooo
00L0okmd0018W03Oool0oooo0=nLB00004P0W=oo00H0oooo0P00000>0?ooo`800000M`3oool00`00
0000oooo0?ooo`1c0?ooo`<000003P3oool2000002P0oooo000_0?ooo`060?oOW0180000M;oo0?no
M0000000M;oo7`3oool0103OW4P0000000000000M;l:0?ooo`040=nLB00000000000001d_`@0oooo
00D0omnL04P000000000000007Boo`070?ooo`030000003oool0oooo00d0oooo0`00001f0?ooo`03
0000003oool0oooo0780oooo0`00000@0?ooo`030000003oool0oooo02H0oooo000_0?ooo`040?oO
W01800000000001d_d<0oooo00<000000?ooo`3oool03P3oool3000007D0oooo00<000000?ooo`3o
ool0LP3oool200000140oooo00<000000?ooo`3oool09P3oool007H0oooo00<000000?ooo`3oool0
3`3oool3000007@0oooo00<000000?ooo`3oool0L@3oool300000140oooo00<000000?ooo`3oool0
9P3oool007H0oooo00<000000?ooo`3oool0403oool3000007<0oooo00<000000?ooo`3oool0L03o
ool300000180oooo00<000000?ooo`3oool09P3oool007H0oooo0P00000B0?ooo`@00000L@3oool0
0`000000oooo0?ooo`1_0?ooo`<000004P3oool2000002P0oooo001f0?ooo`030000003oool0oooo
0180oooo1000001`0?ooo`030000003oool0oooo06h0oooo0`00000D0?ooo`030000003oool0oooo
02H0oooo001f0?ooo`030000003oool0oooo01<0oooo1000001_0?ooo`030000003oool0oooo06d0
oooo0`00000E0?ooo`030000003oool0oooo02H0oooo001f0?ooo`030000003oool0oooo01D0oooo
0`00001^0?ooo`030000003oool0oooo06/0oooo0`00000G0?ooo`030000003oool0oooo02H0oooo
001f0?ooo`030000003oool0oooo01H0oooo0`00001]0?ooo`030000003oool0oooo06X0oooo0`00
000H0?ooo`030000003oool0oooo02H0oooo001B0?ooo`040;md00000000000007Boo`<0oooo00<0
omnL04P0001d_ol0103oool0102oM00000000000001d_ol60?ooo`030?oog`2LB000B9cO00T0oooo
0P00000H0?ooo`<00000K03oool00`000000oooo0?ooo`1Y0?ooo`<00000603oool2000002P0oooo
001A0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Boo`030?ooo`06
0=nLB000M;l0oooo0?oOW0180000B9cO1P3oool00`3OW4P004RL0=ooo`080?ooo`030000003oool0
oooo01P0oooo1000001Z0?ooo`030000003oool0oooo06L0oooo1000000J0?ooo`030000003oool0
oooo02H0oooo001@0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol01P3oool00`3o
oml0W4P004RLg`020?ooo`030?noM00004P0W=oo00D0oooo00<0omnL04P0B02Lgol0203oool00`00
0000oooo0?ooo`0J0?ooo`<00000J@3oool00`000000oooo0?ooo`1V0?ooo`<00000703oool00`00
0000oooo0?ooo`0V0?ooo`00D03oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=oo
o`D0oooo00<0oooO09a80018W=l00P3oool01@3ooml0W4P00018W03Oool0okmd00H0000000<004RL
0=ooo`3oool01@3oool00`000000oooo0?ooo`0K0?ooo`@00000I`3oool00`000000oooo0?ooo`1U
0?ooo`<000007@3oool00`000000oooo0?ooo`0V0?ooo`00D03oool00`3ooml0W4P0001d_`030?oo
o`030=nLB00004P0W=oo00D0oooo00<0oooO09a80000M;l00`3oool01P3OW4P0001809cOo`3ooml0
W4Q809cOo`80oooo00<0_g@0001d_`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`@00000IP3o
ool00`000000oooo0?ooo`1S0?ooo`@000007P3oool00`000000oooo0?ooo`0V0?ooo`00D@3oool0
0`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00H0oooo00<0_g@00018W03Oool00P3oool0
2`3ogi`0B00004RLg`3oool0oono07@0M02oool0oooo0?noM000B9`0gooo00L0oooo0`00000N0?oo
o`@00000I03oool00`000000oooo0?ooo`1Q0?ooo`@000007`3oool2000002P0oooo001A0?ooo`03
0=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l01P3oool00`3OW4P0001809cOo`020?ooo`03
0?oog`2LB00007Bo0080oooo00H0omnL04Q8W03Oool0omnL04P0B02Lgol70?ooo`030000003oool0
oooo01l0oooo1000001S0?ooo`030000003oool0oooo0600oooo1000000Q0?ooo`030000003oool0
oooo02H0oooo001A0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01@3oool00`3o
gi`0B00004RLg`030?ooo`030;md0000B9`0gooo0080oooo00D0okmd001d_`3ooml0W4P004RLg`07
0?ooo`030000003oool0oooo0240oooo1000001Q0?ooo`030000003oool0oooo05h0oooo1000000S
0?ooo`030000003oool0oooo02H0oooo001A0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia8
0018W03Oool01@3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00<0oooo00@0
gia804RLg`2oM00007Bo1`3oool00`000000oooo0?ooo`0S0?ooo`@00000G`3oool00`000000oooo
0?ooo`1L0?ooo`D00000903oool00`000000oooo0?ooo`0V0?ooo`00DP3oool00`3ogi`0B00007Bo
o`020?ooo`030=nLB000M;l0oooo00H0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?oo
o`040?ooo`040=nLB01dM7@0001d0;ooo`H0oooo00<000000?ooo`3oool0903oool5000005d0oooo
00<000000?ooo`3oool0FP3oool5000002H0oooo00<000000?ooo`3oool09P3oool005<0oooo00H0
gia80000M02oool0oooO09a80018W=l80?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO1P3oool0
0`2oM000001809cOo`060?ooo`8000009`3oool5000005/0oooo00<000000?ooo`3oool0F03oool5
000002L0oooo0P00000X0?ooo`00E03oool0103OW4P0000000000000M;l:0?ooo`040=nLB0000000
0000001d_`L0oooo00<0oooO09a80018W=l01P3oool00`000000oooo0?ooo`0X0?ooo`H00000F03o
ool00`000000oooo0?ooo`1F0?ooo`D00000:P3oool00`000000oooo0?ooo`0V0?ooo`00MP3oool0
0`000000oooo0?ooo`0Z0?ooo`H00000EP3oool00`000000oooo0?ooo`1D0?ooo`D00000;03oool0
0`000000oooo0?ooo`0V0?ooo`00MP3oool00`000000oooo0?ooo`0/0?ooo`H00000E03oool00`00
0000oooo0?ooo`1A0?ooo`H00000;P3oool00`000000oooo0?ooo`0V0?ooo`00MP3oool00`000000
oooo0?ooo`0^0?ooo`H00000DP3oool00`000000oooo0?ooo`1?0?ooo`H00000<03oool00`000000
oooo0?ooo`0V0?ooo`00MP3oool200000380oooo1P00001?0?ooo`030000003oool0oooo04`0oooo
1`00000a0?ooo`800000:03oool007H0oooo00<000000?ooo`3oool0<`3oool6000004d0oooo00<0
00000?ooo`3oool0BP3oool6000003D0oooo00<000000?ooo`3oool09P3oool007H0oooo00<00000
0?ooo`3oool0=P3oool6000004X0oooo00<000000?ooo`3oool0A`3oool7000003L0oooo00<00000
0?ooo`3oool09P3oool007H0oooo00<000000?ooo`3oool0>@3oool6000004L0oooo00<000000?oo
o`3oool0A03oool7000003X0oooo00<000000?ooo`3oool09P3oool007H0oooo00<000000?ooo`3o
ool0>`3oool8000004<0oooo00<000000?ooo`3oool0@@3oool7000003d0oooo00<000000?ooo`3o
ool09P3oool00580oooo00@0_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`040?ooo`04
0;md00000000000007Boo`@0oooo00D0oooO09a8000000000000001d_`090?ooo`800000?`3oool8
00000400oooo00<000000?ooo`3oool0?@3oool8000003l0oooo0P00000X0?ooo`00D@3oool01P3O
W4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0omnL04P0001d_ol00`3oool01P3OW4P007Bo0?oo
o`3ogi`0B00004RLg`<0oooo00L0gia8001d_`3oool0oono07@00000B9`0gooo00L0oooo00<00000
0?ooo`3oool0@P3oool8000003`0oooo00<000000?ooo`3oool0>@3oool9000004<0oooo00<00000
0?ooo`3oool09P3oool00500oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`060?oo
o`030?oog`2LB000B9cO0080oooo00L0okmd0000B02Lgol0oooo0?oog`2LB000M;oo0080oooo00<0
omnL04P00018W=l01`3oool00`000000oooo0?ooo`160?ooo`P00000>03oool00`000000oooo0?oo
o`0e0?ooo`T00000A`3oool00`000000oooo0?ooo`0V0?ooo`00D03oool00`3ooml0W4P004RLg`02
0?ooo`040?oog`2LB00004RL0=ooo`D0oooo00<0oooO09a80018W=l00P3oool01`3ooml0W4P00018
W03Oool0oono07@0001d_ol00`3oool00`2oM000001d0;ooo`060?ooo`030000003oool0oooo04X0
oooo2@00000c0?ooo`030000003oool0oooo0340oooo2@00001;0?ooo`030000003oool0oooo02H0
oooo001@0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol01@3oool00`3ooml0W4P0
001d_`030?ooo`060=nLB00004P0W=oo0?oog`2LB00007Bo0`3oool00`3OW4P0001809cOo`060?oo
o`<00000CP3oool:000002h0oooo00<000000?ooo`3oool0:`3oool;000004h0oooo0P00000X0?oo
o`00D@3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00H0oooo00<0_g@00018W03O
ool00P3oool01`3ogi`0B00004RLg`3oool0_g@00000M02oool00P3oool00`3OW4P0001809cOo`06
0?ooo`030000003oool0oooo0580oooo3000000X0?ooo`030000003oool0oooo02D0oooo3000001D
0?ooo`030000003oool0oooo02H0oooo001A0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a8
0000M;l01P3oool00`3OW4P0001809cOo`020?ooo`0<0?oog`2LB00007Bo0?ooo`3o_g@0000004RL
g`3oool0oooO09a80000B9`0gooo1P3oool00`000000oooo0?ooo`1H0?ooo``000008P3oool00`00
0000oooo0?ooo`0O0?ooo`h00000F03oool00`000000oooo0?ooo`0V0?ooo`00D@3oool00`3ogi`0
B00004RLg`030?ooo`030;md0000B9`0gooo00D0oooo00<0omnL04P00018W=l00`3oool01@2oM000
04RL0=ooo`3ooml0W4P000<0000000<0001d0;ooo`3oool01P3oool00`000000oooo0?ooo`1M0?oo
o`l000006P3oool00`000000oooo0?ooo`0F0?oooa400000GP3oool00`000000oooo0?ooo`0V0?oo
o`00D@3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00D0oooo00@0oooO09a8
0000B9`0gooo0P3oool01`3OW4P004RL0=ooo`3oool0oono07@00000M;l02P3oool00`000000oooo
0?ooo`1T0?oooaD000003@3oool00`000000oooo0?ooo`0;0?oooa@00000IP3oool00`000000oooo
0?ooo`0V0?ooo`00DP3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00H0oooo00<0
omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`020?ooo`030?oOW0180000B9cO00T0oooo0P00
001`0?ooobl00000K`3oool2000002P0oooo001C0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO
203oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`@0oooo00@0oooO09a8000007@0_ooo1`3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool09P3oool0
05@0oooo00@0gia800000000000007Bo2P3oool0103OW4P0000000000000M;l70?ooo`040?oo_`1d
0000000004RLg`D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool09P3oool007H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0V0?ooo`00MP3ooooo000001<00000:03oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00=80oooo00T0oono07@0
00000000B9cO0?ooo`3ookl0M00000000018W=l0503oool00`3o_g@0000000000002000000030018
W03Oool0oooo0180oooo00D0_g@0000000000000000004RLg`2R0?ooo`00dP3oool02P3ookl0M018
09cOo`2oM00007Bo0?oo_`1d04P0W=oo0;md0000M;lB0?ooo`030?noM0000000B9cO00<0oooo00<0
omnL04P0B02Lgol04`3oool00`3ooml0W4P004RLg`2S0?ooo`00e@3oool00`3ookl0M00007Boo`02
0?ooo`030?oo_`1d0000M;oo0140oooo00<0okmd0000M02oool0103oool00`3OW4P007Bo0?ooo`0C
0?ooo`030=nLB000B9`0gooo0:80oooo003F0?ooo`030=nLB000B9`0gooo0080oooo00<0gia80018
W03Oool04@3oool0202oM000001d0;ooo`3oool0oooO09a800000000B9cO503oool00`3ogi`0B01d
0;ooo`2R0?ooo`00_`3oool00`2oM000000000000005000000030018W03Oool0oooo00<0oooo00`0
omnL04P00000000004RL0=ooo`2oM0000000001d_`3oool0okmd0000B02Lgol20?ooo`030?noM000
04P0W=oo00<0oooo00P0_g@00000000004P0W=oo0?ooo`3OW4P004RL0=ooo`80oooo00<0_g@00000
0000M;l00P3oool01P3ookl0M000000000000000001d0;ooo`D0oooo00<0okmd0000000000001`00
00002@1d_ol0oooo0?oOW018000000000000M02ookl0M00007Boo`020?ooo`0;0?oOW01800000000
0018W03Oool0_g@000000000M;l0oooo0?oOW01800000P0000002@1d_ol0gia800000000B9`0gooo
0?noM0000000001809cOo`020?ooo`040;md00000000001809cOo`80oooo00D0okmd000000000000
001809cOo`030?ooo`030=nLB000B9`0gooo0080oooo00<0_g@000000000M;l0LP3oool00<00oooo
00@0oono07@00000B9`0gooo0`3oool00`2oM0000000001d_`030?ooo`0<0?oOW01804P0W=oo0?oO
W018M;l0_g@0001d_`3o_i`0W=oo0?oo_`1d0000B9cO0P3oool00`3ookl0M00004RLg`030?ooo`08
0=nLB000B9`0gooO09adW03Oool0okmd0000M02oool20?ooo`080=nLB000B9`0gkmd07Boo`3oool0
okmd0000M02oool90?ooo`040?oog`2LB00004RL0=ooo`<0oooo00/0oooO09a80000B9`0gooo0;md
0000B9`0gooo0?oo_`1d07@0M7@004RLg`020?ooo`0T0?oOW01804P0W=oo0?oOW018M;l0_g@0001d
_`3o_i`0W=oo0;md0000B9`0gooo0?ooo`2oM000M7Ad0000M02ogi`0W;oo0?noM00004P0W=oO09ad
W03Oool0oooo0=nLB000B9`0gooO09adW03Oool0omnL04P0B02Lgol0oooo0?oOW018000007Bo0P3o
ool00`3o_g@0001d0;ooo`020?ooo`040=nLB000B9`0gkmd07Boog40oooo00310?ooo`030=nLB000
04P0W=oo00@0oooo00d0oono07@00000B9`0gooo0?ooo`3ooml0W4P004RLg`3oool0okmd07AdM000
B9`0gooo0080oooo00<0_g@00018W03Oool00P3oool00`2oM00004RL0=ooo`020?ooo`030?noM000
04P0W=oo0080oooo00<0oono07@00018W=l00P3oool00`3ogi`0B01809cOo`030?ooo`030;md001d
_ol0oooo00T0oooo00<0okmd0000B02Lgol01@3oool0103OW7@0W=oo0;md0000M;l20?ooo`0@0?oo
_`1d000004RL0=ooo`3oool0oooO09a80018W=l0oooo0?noM01dM7@004RL0=ooo`3oool0_g@0001d
_`<0oooo00L0_g@00000001d_ol0oooo0?oo_`1d0000M;oo00<0oooo00<0okmd0000B02Lgol00P3o
ool00`3OW4P004RL0=ooo`020?ooo`070?oOW0180000B9cO0?ooo`3ookl0M00004RLg`020?ooo`03
0?oOW01804P0W=oo0780oooo00310?ooo`030?oOW0180000M;oo00D0oooo00<0omnL04P00000M;l0
0P3oool01`2oM00004RL0=ooo`3oool0_g@00000B02Lgol00P3oool00`3OW4P0001d0;ooo`020?oo
o`030=nLB00007@0_ooo0080oooo00<0oono07@00018W=l00P3oool0203ooml0W4P00000M02oool0
oooo0?oog`2LB000B9cO0P3oool00`3ookl0M000000000020000000307Boo`3oool0oooo00D0oooo
00<0oono07@00018W=l01`3oool00`3OW4P004RL0=ooo`020?ooo`030?noM00007@0_ooo0080oooo
00/0_g@00018W03Oool0oooo0;md000004P0W=oo0?ooo`3o_g@0001d0;ooo`020?ooo`030?oo_`1d
0000B9cO0080oooo00<0_g@0001d_`3oool00P3oool00`3ookl0M00004RLg`020?ooo`030?noM000
07@0_ooo00<0oooo00/0gia80000M02oool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`1b
0?ooo`00`@3oool00`3ookl0M000001d_`060?ooo`0;0;md000004P0W=oo0?ooo`3o_g@0001d0;oo
o`3oool0oono07@0001d_ol00P3oool00`3ogi`0B00007Boo`020?ooo`030?oOW0180000M;oo00<0
oooo00<0_g@00018W03Oool00P3oool00`3OW4P004Q804Qd_`020?ooo`0;0;md0000M;l0oooo0?oo
o`2oM00004RL0=ooo`3oool0omnL04P00018W=l01P3oool00`3ooml0W4P0001d_`020?ooo`030?oo
_`2LW=l0oooo0080oooo00<0omnL04P0001d_ol00P3oool00`3ookl0M00007Boo`020?ooo`0;0?no
M00007@0_ooo0?ooo`3ookl0M00007Boo`3oool0oono07@0001d_ol00`3oool01`2oM00004RL0=oo
o`3oool0gia80018W03Oool00`3oool01`2oM00004RL0=ooo`3oool0oono07@0001d_ol00`3oool0
1`3ogi`0B01809cOo`3oool0gia80018B018M;l00P3oool00`2oM00007Bo0?ooo`1a0?ooo`00`P3o
ool00`2oM00004RL0=ooo`050?ooo`070?noM0000000B9cO0?oOg`3Ookl0M00007Boo`020?ooo`07
0;md0000M;l0oooo0?ooo`3ooml0W4P004RLg`020?ooo`030?oog`2LB000B9cO00<0oooo00<0gia8
0000B02Lgol00P3oool02`3o_g@0001d0;noM018W=l0oooo0?noM00007@0_ooo0?ooo`2oM00007Bo
00<0oooo00<0gia80000M02oool01P3oool01P3OW4P0001d0;ooo`3oool0omnL04Qd_`@0oooo00`0
_g@00000M02oool0oooo0?oog`2LB000B9cO0?ooo`3ogml0gono07@0001d_ol20?ooo`070;md0000
M;l0oooo0?ooo`3o_g@0001d0;ooo`020?ooo`070=nLB00007@0_ooo0?ooo`3ogi`0B01809cOo`03
0?ooo`030=nLB00004P0W=oo0080oooo00<0gia80000M02oool00P3oool0303ookl0M00007Boo`3o
ool0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;ooog40oooo00320?ooo`030?noM00004P0W=oo
00D0oooo00L0omnL04P00000M;l0omnL04Qd_`2oM00007Bo0080oooo00<0okmd0018W03Oool00P3o
ool00`2oM00004RL0=ooo`020?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l00P3o
ool0303ooml0W4P007Boo`3OW4P007Bo0?oOW01804P0W=oo0?ooo`3ogi`0B00004RLg`80oooo00<0
gia80000M02oool01P3oool00`3o_g@0000000000002000000030000M02oool0oooo0080oooo00`0
oooO09a80000B9`0gooo0?oo_`2LB4P004RL0=ooo`3ogi`0B7Bo0;md0000M;l20?ooo`030?noM000
B9`0gooo0080oooo00/0gia80000M02oool0oooo0;md000004P0W=oo0?ooo`3ooml0W4P004RLg`03
0?ooo`030?oOW0180000B9cO00<0oooo0100_g@00000M02oool0oooo0?noM00007@0_ooo0?ooo`3o
oml0W4P007Boo`3OW4P007Bo0?oOW01804P0W=ooL@3oool00<80oooo00<0omnL04P0001d_ol01@3o
ool01`3ogi`0B000001d_`3oool0okmd00000000M;l00P3oool01@3ogi`0B01809cOo`3ookl0M000
00<0000000<0M;no07@0000000000P0000003`1d_ol0okmd00000000000004RL0=ooo`3ookl0M000
00000018W=l0oooo0?noM0000000001809cOo`020?ooo`030?oo_`1d0000000000@0000000<0B9cO
0?ooo`3oool00`3oool00`3ookl0M00007Boo`020?ooo`030;mdB02Lgol0oooo00@0oooo00X0gia8
0000000007@0_kmd0000M02oool0oooo0?noM000000007Bo0P3oool00`3ogi`0B01809cOo`030?oo
o`080?oOW0180000000004RLW01d0000B9cO0?oo_`1d00030000000607Boo`3o_g@0000000000000
B9`0gooo0`3oool03`3o_g@00000000000000000M;oo0?ooo`3ookl0M00000000018W=l0oooo0?no
M0000000001809cOo`1a0?ooo`00`P3oool00`3ooml0W4P0001d_`050?ooo`030?noM0000000B9cO
00/0oooo00<0okmd0000B02Lgol00P3oool00`3o_g@0001809cOo`0O0?ooo`060;md0000M;l0oooo
0?ooo`3ogi`0M9cO7`3oool00`3o_g@0001d0;ooo`290?ooo`00``3oool00`2oM00004RL0=ooo`03
0?ooo`040?oog`2LB000001d0;ooo`/0oooo00<0oooO09a80000M;l00P3oool00`3ooml0W4P0001d
_`0O0?ooo`030=nLB00007@0_ooo00@0oooo00<0gibL0;ooo`3oool0703oool00`3OW7@0W=oo0?oo
o`280?ooo`00``3oool00`3OW4P0001809cOo`020?ooo`040?oo_`1d0000000007Boo`d0oooo00<0
okmd0000M02oool00P3oool00`3o_g@0001d0;ooo`020?ooo`040?oo_`1d000004RL0=oooaP0oooo
00<0okmd0000B02Lgol00`3oool00`3ookl0M01809cOo`0R0?ooo`040?oo_`1d000004RL0=oooh80
oooo00320?ooo`030;md00000000000000@0000000<004RL0=ooo`3oool03P3oool02P3OW4P004RL
0=oog`2LB000B9cO0=nLB000B9`0gooO09a80018W=lJ0?ooo`030;md00000000000000H0000000<0
M;oo0?ooo`3oool0YP3oool00=/0oooo00T0gia80000000004P0W=oo0?ooo`3OW4P000000000B02L
gol0c03oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 431}, {212.25, 0}} -> {-0.25846, -0.119622, \
0.0015203, 0.0015203}}]
}, Closed]],

Cell["\<\
The period is determined by the driving force, so the Poincar\[EAcute] map \
quickly settles upon a single point as transients decay.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[sol];\)\), "\[IndentingNewLine]", 
    \(\(sol[
          t_] = \(duffingSol[1, 1, 0.05, 0.1, 0.5, 0, 1, 3000, 
            MaxSteps \[Rule] 10\^5]\)[t];\)\), "\[IndentingNewLine]", 
    \(pts = poincare[sol[t], 0.1, 0, 3000]\)}], "Input"],

Cell[BoxData[
    \({{\(-5.26748614073768`*^-21\), 
        1.`}, {0.12679041708361405`, \(-0.03621602584258875`\)}, \
{0.1297161190023087`, 0.003179471399778104`}, {0.13090082530776487`, 
        0.004329884640091198`}, {0.13097295716564494`, 
        0.004331010276423537`}, {0.13097542290646846`, 
        0.004328924326043276`}, {0.1309754571033617`, 
        0.004328784839345631`}, {0.13097543156489916`, 
        0.004328783862542216`}, {0.13097541840367988`, 
        0.004328781594350715`}, {0.13097547078938693`, 
        0.004328769465646462`}, {0.13097544887878815`, 
        0.004328773697943415`}, {0.1309754364281724`, 
        0.004328796568104957`}, {0.13097544295972485`, 
        0.0043287987262272225`}, {0.13097543121229596`, 
        0.0043287774748128945`}, {0.1309754196201361`, 
        0.004328796511815453`}, {0.1309754035433469`, 
        0.00432878998587297`}, {0.13097542015867228`, 
        0.004328794728549822`}, {0.13097542356928085`, 
        0.004328789631018558`}, {0.13097544742106834`, 
        0.004328783103114058`}, {0.13097545523816628`, 
        0.004328785454090669`}, {0.13097545714403197`, 
        0.004328787128169318`}, {0.13097548040420617`, 
        0.00432878554092621`}, {0.1309754348112679`, 
        0.004328779303527894`}, {0.13097542786417335`, 
        0.0043287970588963874`}, {0.1309754591669077`, 
        0.004328780521330667`}, {0.13097543803881032`, 
        0.004328789457429353`}, {0.1309754286827854`, 
        0.004328789522732502`}, {0.13097541295588244`, 
        0.004328786834234597`}, {0.13097542378173838`, 
        0.004328784670485316`}, {0.13097543228270506`, 
        0.0043287836698536536`}, {0.13097544283382723`, 
        0.004328807581287435`}, {0.13097541080327663`, 
        0.004328789692590968`}, {0.13097546343661173`, 
        0.004328785499546264`}, {0.13097540001675875`, 
        0.004328791352984113`}, {0.13097547357444222`, 
        0.004328784149000762`}, {0.13097547565599035`, 
        0.0043287679528260905`}, {0.13097542462028122`, 
        0.004328796337974665`}, {0.13097543715976523`, 
        0.004328793626041213`}, {0.13097543801239914`, 
        0.00432879142256834`}, {0.1309754624474589`, 
        0.004328779432177364`}, {0.1309754329119502`, 
        0.0043287938130391265`}, {0.1309754044751117`, 
        0.004328793415651499`}, {0.13097542412637783`, 
        0.004328797824648261`}, {0.13097543847646664`, 
        0.004328776255519055`}, {0.13097546891942266`, 
        0.004328776944574183`}, {0.13097547585760516`, 
        0.004328770941351824`}, {0.13097542520203875`, 
        0.004328788194672137`}, {0.1309754115319235`, 
        0.004328786491595596`}}\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Strong driving, modest damping", "Subsubsection"],

Cell["\<\
In the example below, the driving frequency is just above the natural \
frequency, but its amplitude is quite large.  Nevertheless, after some rather \
chaotic transients, the system appears to settle upon a stable attractor.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(duffingPlot[1, 1, 0.05, 10, 1.25, 0, 0, 0, 100, 
        MaxSteps \[Rule] 4000, PlotPoints \[Rule] 100];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.507893 0.137959 0.524516 0.067587 [
[.09402 -0.0125 -9.34375 -15.6875 ]
[.09402 -0.0125 9.34375 0 ]
[.23198 -0.0125 -9.34375 -15.6875 ]
[.23198 -0.0125 9.34375 0 ]
[.36993 -0.0125 -9.34375 -15.6875 ]
[.36993 -0.0125 9.34375 0 ]
[.50789 -0.0125 -5 -15.6875 ]
[.50789 -0.0125 5 0 ]
[.64585 -0.0125 -5 -15.6875 ]
[.64585 -0.0125 5 0 ]
[.78381 -0.0125 -5 -15.6875 ]
[.78381 -0.0125 5 0 ]
[.92177 -0.0125 -5 -15.6875 ]
[.92177 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.9688 -31.375 ]
[.5 -0.0125 21.9688 -15.6875 ]
[-0.0125 .11899 -18.9375 -7.84375 ]
[-0.0125 .11899 0 7.84375 ]
[-0.0125 .25417 -18.6875 -7.84375 ]
[-0.0125 .25417 0 7.84375 ]
[-0.0125 .38934 -18.6875 -7.84375 ]
[-0.0125 .38934 0 7.84375 ]
[-0.0125 .52452 -10 -7.84375 ]
[-0.0125 .52452 0 7.84375 ]
[-0.0125 .65969 -10 -7.84375 ]
[-0.0125 .65969 0 7.84375 ]
[-0.0125 .79486 -10 -7.84375 ]
[-0.0125 .79486 0 7.84375 ]
[-0.0125 .93004 -10.25 -7.84375 ]
[-0.0125 .93004 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -34.625 -20.4688 ]
[-0.01875 .5 -18.9375 20.4688 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -43.9375 0 ]
[.5 1.0125 43.9375 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09402 0 m
.09402 .00625 L
s
gsave
.09402 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.23198 0 m
.23198 .00625 L
s
gsave
.23198 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.36993 0 m
.36993 .00625 L
s
gsave
.36993 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.50789 0 m
.50789 .00625 L
s
gsave
.50789 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.64585 0 m
.64585 .00625 L
s
gsave
.64585 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.78381 0 m
.78381 .00625 L
s
gsave
.78381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.92177 0 m
.92177 .00625 L
s
gsave
.92177 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.12161 0 m
.12161 .00375 L
s
.1492 0 m
.1492 .00375 L
s
.17679 0 m
.17679 .00375 L
s
.20438 0 m
.20438 .00375 L
s
.25957 0 m
.25957 .00375 L
s
.28716 0 m
.28716 .00375 L
s
.31475 0 m
.31475 .00375 L
s
.34234 0 m
.34234 .00375 L
s
.39753 0 m
.39753 .00375 L
s
.42512 0 m
.42512 .00375 L
s
.45271 0 m
.45271 .00375 L
s
.4803 0 m
.4803 .00375 L
s
.53549 0 m
.53549 .00375 L
s
.56308 0 m
.56308 .00375 L
s
.59067 0 m
.59067 .00375 L
s
.61826 0 m
.61826 .00375 L
s
.67344 0 m
.67344 .00375 L
s
.70104 0 m
.70104 .00375 L
s
.72863 0 m
.72863 .00375 L
s
.75622 0 m
.75622 .00375 L
s
.8114 0 m
.8114 .00375 L
s
.83899 0 m
.83899 .00375 L
s
.86659 0 m
.86659 .00375 L
s
.89418 0 m
.89418 .00375 L
s
.06643 0 m
.06643 .00375 L
s
.03883 0 m
.03883 .00375 L
s
.01124 0 m
.01124 .00375 L
s
.94936 0 m
.94936 .00375 L
s
.97695 0 m
.97695 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.9688 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
102.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11899 m
.00625 .11899 L
s
gsave
-0.0125 .11899 -79.9375 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
0 .25417 m
.00625 .25417 L
s
gsave
-0.0125 .25417 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .38934 m
.00625 .38934 L
s
gsave
-0.0125 .38934 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .52452 m
.00625 .52452 L
s
gsave
-0.0125 .52452 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .65969 m
.00625 .65969 L
s
gsave
-0.0125 .65969 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .79486 m
.00625 .79486 L
s
gsave
-0.0125 .79486 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .93004 m
.00625 .93004 L
s
gsave
-0.0125 .93004 -71.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .15279 m
.00375 .15279 L
s
0 .18658 m
.00375 .18658 L
s
0 .22037 m
.00375 .22037 L
s
0 .28796 m
.00375 .28796 L
s
0 .32175 m
.00375 .32175 L
s
0 .35555 m
.00375 .35555 L
s
0 .42314 m
.00375 .42314 L
s
0 .45693 m
.00375 .45693 L
s
0 .49072 m
.00375 .49072 L
s
0 .55831 m
.00375 .55831 L
s
0 .5921 m
.00375 .5921 L
s
0 .6259 m
.00375 .6259 L
s
0 .69348 m
.00375 .69348 L
s
0 .72728 m
.00375 .72728 L
s
0 .76107 m
.00375 .76107 L
s
0 .82866 m
.00375 .82866 L
s
0 .86245 m
.00375 .86245 L
s
0 .89624 m
.00375 .89624 L
s
0 .0852 m
.00375 .0852 L
s
0 .05141 m
.00375 .05141 L
s
0 .01761 m
.00375 .01761 L
s
0 .96383 m
.00375 .96383 L
s
0 .99762 m
.00375 .99762 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -108.25 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
81.4688 11.8438 translate
90 rotate
-81.4688 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(velocity) show
99.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.09402 .99375 m
.09402 1 L
s
.23198 .99375 m
.23198 1 L
s
.36993 .99375 m
.36993 1 L
s
.50789 .99375 m
.50789 1 L
s
.64585 .99375 m
.64585 1 L
s
.78381 .99375 m
.78381 1 L
s
.92177 .99375 m
.92177 1 L
s
.125 Mabswid
.12161 .99625 m
.12161 1 L
s
.1492 .99625 m
.1492 1 L
s
.17679 .99625 m
.17679 1 L
s
.20438 .99625 m
.20438 1 L
s
.25957 .99625 m
.25957 1 L
s
.28716 .99625 m
.28716 1 L
s
.31475 .99625 m
.31475 1 L
s
.34234 .99625 m
.34234 1 L
s
.39753 .99625 m
.39753 1 L
s
.42512 .99625 m
.42512 1 L
s
.45271 .99625 m
.45271 1 L
s
.4803 .99625 m
.4803 1 L
s
.53549 .99625 m
.53549 1 L
s
.56308 .99625 m
.56308 1 L
s
.59067 .99625 m
.59067 1 L
s
.61826 .99625 m
.61826 1 L
s
.67344 .99625 m
.67344 1 L
s
.70104 .99625 m
.70104 1 L
s
.72863 .99625 m
.72863 1 L
s
.75622 .99625 m
.75622 1 L
s
.8114 .99625 m
.8114 1 L
s
.83899 .99625 m
.83899 1 L
s
.86659 .99625 m
.86659 1 L
s
.89418 .99625 m
.89418 1 L
s
.06643 .99625 m
.06643 1 L
s
.03883 .99625 m
.03883 1 L
s
.01124 .99625 m
.01124 1 L
s
.94936 .99625 m
.94936 1 L
s
.97695 .99625 m
.97695 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .11899 m
1 .11899 L
s
.99375 .25417 m
1 .25417 L
s
.99375 .38934 m
1 .38934 L
s
.99375 .52452 m
1 .52452 L
s
.99375 .65969 m
1 .65969 L
s
.99375 .79486 m
1 .79486 L
s
.99375 .93004 m
1 .93004 L
s
.125 Mabswid
.99625 .15279 m
1 .15279 L
s
.99625 .18658 m
1 .18658 L
s
.99625 .22037 m
1 .22037 L
s
.99625 .28796 m
1 .28796 L
s
.99625 .32175 m
1 .32175 L
s
.99625 .35555 m
1 .35555 L
s
.99625 .42314 m
1 .42314 L
s
.99625 .45693 m
1 .45693 L
s
.99625 .49072 m
1 .49072 L
s
.99625 .55831 m
1 .55831 L
s
.99625 .5921 m
1 .5921 L
s
.99625 .6259 m
1 .6259 L
s
.99625 .69348 m
1 .69348 L
s
.99625 .72728 m
1 .72728 L
s
.99625 .76107 m
1 .76107 L
s
.99625 .82866 m
1 .82866 L
s
.99625 .86245 m
1 .86245 L
s
.99625 .89624 m
1 .89624 L
s
.99625 .0852 m
1 .0852 L
s
.99625 .05141 m
1 .05141 L
s
.99625 .01761 m
1 .01761 L
s
.99625 .96383 m
1 .96383 L
s
.99625 .99762 m
1 .99762 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .52452 m
1 .52452 L
s
.50789 0 m
.50789 1 L
s
gsave
.5 1.0125 -104.938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Duffing) show
102.938 15.813 moveto
(Equation) show
146.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.50789 .52452 m
.50851 .5447 L
.51014 .56298 L
.51328 .58392 L
.51748 .60352 L
.52785 .63775 L
.54323 .67375 L
.56493 .71155 L
.59308 .74878 L
.62095 .77739 L
.65524 .80416 L
.67483 .81574 L
.69412 .82454 L
.71186 .83029 L
.73153 .83384 L
.74277 .83443 L
.75296 .83398 L
.76469 .83223 L
.77565 .82927 L
.79482 .82064 L
.80534 .81376 L
.81477 .80608 L
.8311 .7888 L
.8453 .76862 L
.85944 .74199 L
.87263 .70839 L
.87838 .68967 L
.88392 .66802 L
.8919 .62563 L
.89693 .58135 L
.89901 .5386 L
.89835 .49007 L
.89495 .44572 L
.8882 .39832 L
.88365 .37533 L
.87781 .35103 L
.86599 .31226 L
.85086 .2746 L
.83445 .24295 L
.81794 .21756 L
.79496 .18973 L
.77215 .16832 L
.74564 .149 L
.71621 .13253 L
.66431 .11161 L
.60453 .0941 L
.47914 .06157 L
.40599 .04246 L
.3689 .03397 L
.35063 .03044 L
Mistroke
.33399 .02774 L
.30107 .02432 L
.28294 .02381 L
.26589 .02444 L
.24732 .02656 L
.23035 .03003 L
.21188 .03574 L
.19268 .04421 L
.16241 .06397 L
.13557 .08995 L
.10819 .12768 L
.09403 .15322 L
.08201 .17924 L
.0624 .23362 L
.04727 .29181 L
.03474 .36234 L
.02645 .44383 L
.02381 .52742 L
.02462 .56936 L
.02713 .61445 L
.0356 .69096 L
.04782 .75608 L
.06411 .81468 L
.08258 .86174 L
.10131 .8968 L
.12347 .92702 L
.14936 .95115 L
.17806 .96737 L
.2032 .9745 L
.2311 .97619 L
.2467 .97472 L
.2636 .97141 L
.2939 .96156 L
.32262 .94821 L
.34834 .93341 L
.45462 .84915 L
.52681 .77158 L
.55658 .73259 L
.58249 .69266 L
.60077 .65869 L
.61615 .62284 L
.62143 .60761 L
.62611 .59175 L
.6296 .57731 L
.6321 .56439 L
.63426 .54876 L
.63499 .54082 L
.63545 .53265 L
.63554 .51952 L
.63523 .51241 L
Mistroke
.63471 .50599 L
.63319 .4947 L
.6312 .48514 L
.62824 .47506 L
.62485 .46646 L
.62116 .45921 L
.61746 .45342 L
.61314 .448 L
.60816 .44313 L
.60328 .43952 L
.59862 .43697 L
.59406 .43521 L
.58916 .43409 L
.58381 .43369 L
.57809 .43421 L
.57274 .43558 L
.56795 .43755 L
.5625 .44074 L
.55684 .44524 L
.55182 .45046 L
.5475 .45609 L
.5435 .46258 L
.53975 .47021 L
.53696 .47738 L
.53437 .48587 L
.53217 .4958 L
.53124 .50168 L
.53057 .50722 L
.52982 .51853 L
.52979 .52981 L
.53041 .54092 L
.53177 .55318 L
.53352 .56404 L
.53611 .57638 L
.54446 .60523 L
.55565 .63364 L
.57315 .66825 L
.59423 .70177 L
.64557 .76307 L
.68056 .79338 L
.69867 .80585 L
.71639 .81592 L
.72677 .8208 L
.73817 .82525 L
.75838 .83066 L
.76999 .83222 L
.78227 .83253 L
.79274 .83161 L
.80416 .82925 L
.82468 .821 L
Mistroke
.84297 .80845 L
.85217 .79989 L
.86195 .78883 L
.88035 .76114 L
.89463 .73104 L
.90163 .71223 L
.90764 .69298 L
.91734 .65231 L
.92378 .61184 L
.92766 .57037 L
.92909 .52487 L
.92785 .48175 L
.92456 .44333 L
.91811 .39986 L
.90818 .35617 L
.89622 .31902 L
.88324 .28888 L
.86752 .26128 L
.84892 .23713 L
.83004 .2194 L
.81195 .20728 L
.79001 .19755 L
.77736 .19398 L
.76556 .19178 L
.74377 .19018 L
.73275 .19043 L
.7206 .19139 L
.70889 .19294 L
.69663 .19512 L
.67494 .20018 L
.6275 .21486 L
.54757 .24296 L
.51076 .25435 L
.47726 .26289 L
.44799 .26878 L
.4169 .27363 L
.35341 .28171 L
.32224 .28709 L
.30489 .2913 L
.28897 .29634 L
.27452 .30218 L
.26118 .30895 L
.23744 .3253 L
.22508 .33674 L
.21432 .34891 L
.20273 .36502 L
.19291 .38203 L
.18538 .39799 L
.17829 .41649 L
.17326 .43272 L
Mistroke
.16871 .45123 L
.16494 .47194 L
.16232 .49414 L
.16115 .5147 L
.16113 .53359 L
.16245 .5556 L
.16366 .56629 L
.1654 .57766 L
.16945 .59649 L
.17431 .61249 L
.18118 .62894 L
.18841 .64162 L
.19722 .65276 L
.20191 .65725 L
.20722 .66131 L
.21666 .66626 L
.22545 .6686 L
.23036 .66905 L
.23569 .66889 L
.24529 .66698 L
.25413 .66342 L
.26317 .658 L
.27058 .65217 L
.2783 .64466 L
.2923 .62658 L
.30294 .60758 L
.30786 .5964 L
.31239 .58388 L
.31561 .57288 L
.3184 .56068 L
.32024 .54955 L
.32137 .53923 L
.32193 .52854 L
.32183 .51737 L
.32115 .50793 L
.31987 .49844 L
.31834 .49076 L
.31622 .48288 L
.31307 .47408 L
.30966 .46684 L
.30543 .45996 L
.30046 .454 L
.29585 .45003 L
.29133 .4474 L
.28623 .44577 L
.28333 .44545 L
.28067 .44555 L
.27584 .44673 L
.27145 .44898 L
.26682 .45275 L
Mistroke
.2622 .45828 L
.25818 .46497 L
.25482 .4725 L
.25222 .48025 L
.24991 .4896 L
.24794 .50169 L
.24688 .51401 L
.24663 .52149 L
.24664 .52852 L
.24696 .53689 L
.24755 .54502 L
.24841 .55305 L
.24964 .56173 L
.25266 .5776 L
.25711 .59491 L
.26348 .61405 L
.27705 .64464 L
.29602 .67613 L
.31785 .70404 L
.34098 .72809 L
.46893 .823 L
.54757 .87175 L
.63294 .91852 L
.65834 .93011 L
.68599 .94088 L
.7007 .94565 L
.71706 .95005 L
.74619 .9551 L
.77279 .95595 L
.80127 .95192 L
.82773 .94246 L
.85123 .92825 L
.86488 .91691 L
.87894 .90239 L
.9027 .8696 L
.91609 .84518 L
.92774 .81924 L
.93743 .79323 L
.94664 .7634 L
.96078 .70176 L
.96991 .63967 L
.97527 .56906 L
.97619 .5282 L
.97565 .49013 L
.97108 .42082 L
.96708 .38719 L
.96139 .35161 L
.94829 .29356 L
.93279 .24579 L
.92214 .22047 L
Mistroke
.91119 .1989 L
.88878 .16514 L
.87541 .15006 L
.86254 .1384 L
.848 .12808 L
.83213 .11976 L
.80478 .11148 L
.7892 .10963 L
.77482 .10952 L
.74846 .11275 L
.72096 .12015 L
.69681 .12946 L
.67481 .13987 L
.6272 .16745 L
.48706 .27324 L
.3852 .36667 L
.34699 .41008 L
.32186 .44533 L
.29539 .49569 L
.29245 .50243 L
.2912 .50519 L
.29003 .50752 L
.28912 .50906 L
.28821 .51022 L
.28742 .51079 L
.28671 .51093 L
.28589 .51063 L
.28512 .50995 L
.28417 .50871 L
.28319 .50711 L
.27734 .49608 L
.26892 .48252 L
.26264 .47472 L
.25585 .46817 L
.25186 .46516 L
.24788 .46275 L
.2442 .46104 L
.24008 .45971 L
.2377 .45924 L
.23554 .459 L
.23304 .45896 L
.23069 .45916 L
.22653 .46011 L
.22422 .46099 L
.22213 .46204 L
.21872 .46429 L
.21523 .4674 L
.21212 .47102 L
.20948 .47487 L
.20665 .48006 L
Mistroke
.20395 .48647 L
.20181 .49322 L
.20022 .5 L
.199 .50745 L
.19827 .51482 L
.19793 .52324 L
.19815 .5326 L
.19898 .54208 L
.20051 .55211 L
.20236 .56062 L
.20493 .56977 L
.21212 .58792 L
.2172 .59736 L
.22248 .60545 L
.23354 .61861 L
.24688 .63001 L
.25999 .63808 L
.27302 .64398 L
.28798 .64897 L
.30464 .65305 L
.34077 .65973 L
.36137 .66377 L
.38136 .66865 L
.42279 .68303 L
.4646 .70345 L
.57575 .77283 L
.61364 .79628 L
.65725 .82007 L
.67626 .82882 L
.69717 .83697 L
.70942 .84091 L
.72069 .84391 L
.73211 .84629 L
.74297 .84787 L
.76267 .84882 L
.78353 .84674 L
.80114 .84203 L
.82015 .8333 L
.8398 .81938 L
.8504 .80934 L
.85975 .79871 L
.87676 .77408 L
.8913 .74577 L
.90459 .71097 L
.91088 .6899 L
.91609 .6689 L
.92414 .62535 L
.92889 .58356 L
.9305 .55871 L
.93126 .53221 L
Mistroke
.93022 .48493 L
.92831 .45911 L
.9257 .4356 L
.92193 .41064 L
.91688 .38512 L
.90686 .34771 L
.89322 .31161 L
.88546 .29573 L
.87651 .28037 L
.85897 .2573 L
.84117 .24106 L
.82148 .22942 L
.80418 .22359 L
.78498 .22109 L
.77321 .22135 L
.76212 .2227 L
.74159 .22779 L
.73027 .23189 L
.71999 .23635 L
.69739 .24844 L
.66185 .27319 L
.6281 .30253 L
.54301 .40116 L
.51455 .44309 L
.49674 .47026 L
.49063 .47829 L
.48764 .48148 L
.48499 .48368 L
.48354 .4846 L
.482 .48531 L
.47936 .48584 L
.47806 .48578 L
.47669 .48547 L
.47418 .48434 L
.47182 .48265 L
.46917 .48015 L
.46392 .4739 L
.44857 .45173 L
.42211 .41409 L
.38569 .37039 L
.34243 .3302 L
.32888 .32015 L
.3138 .31043 L
.30033 .30311 L
.28514 .2965 L
.2703 .29185 L
.2563 .28925 L
.24141 .28859 L
.22555 .29059 L
.21096 .29527 L
Mistroke
.19755 .30241 L
.18594 .31122 L
.17397 .32341 L
.16174 .34002 L
.14964 .36211 L
.1388 .3892 L
.13057 .41783 L
.1247 .447 L
.12102 .47513 L
.11883 .50871 L
.11885 .54091 L
.12049 .56822 L
.124 .5975 L
.1295 .62651 L
.13627 .65179 L
.14385 .67325 L
.1518 .69099 L
.16149 .70816 L
.17265 .72354 L
.18481 .7363 L
.19856 .74681 L
.21206 .75388 L
.22464 .75808 L
.23965 .76053 L
.24816 .76083 L
.25601 .76048 L
.27037 .75841 L
.28539 .75448 L
.29964 .74926 L
.31478 .74231 L
.341 .72731 L
.38474 .69577 L
.42415 .66358 L
.44254 .64893 L
.45815 .63772 L
.4717 .6297 L
.47895 .62635 L
.48543 .62403 L
.4908 .62263 L
.49662 .62172 L
.50267 .62144 L
.50831 .62181 L
.51411 .62281 L
.51968 .62433 L
.52476 .62617 L
.53041 .62867 L
.55685 .64516 L
.5909 .67203 L
.6363 .70782 L
.66057 .72469 L
Mistroke
.68833 .74101 L
.71362 .7524 L
.72847 .75725 L
.74251 .76041 L
.75854 .76209 L
.77371 .76153 L
.78723 .759 L
.80165 .75385 L
.81692 .7451 L
.82436 .73939 L
.83229 .73205 L
.84558 .71634 L
.85696 .69848 L
.86893 .67335 L
.87845 .64594 L
.88526 .61881 L
.88834 .60261 L
.89067 .58713 L
.89274 .56852 L
.89402 .55071 L
.89467 .51716 L
.89403 .49842 L
.89281 .48144 L
.89079 .46319 L
.88791 .44454 L
.88192 .41698 L
.87779 .40245 L
.87352 .38979 L
.86464 .36859 L
.8539 .34923 L
.84333 .33478 L
.83274 .3237 L
.8205 .31424 L
.8068 .3071 L
.79193 .30275 L
.78341 .30163 L
.77548 .30139 L
.76098 .30279 L
.75293 .30451 L
.7457 .30658 L
.73223 .31171 L
.71807 .31876 L
.69378 .33451 L
.65227 .37129 L
.61824 .41039 L
.57924 .46299 L
.57174 .47206 L
.56845 .47538 L
.56556 .47777 L
.56306 .47935 L
Mistroke
.56048 .48042 L
.55793 .48087 L
.55513 .48062 L
.5521 .47951 L
.54923 .47772 L
.54592 .47491 L
.54219 .47102 L
.52605 .44977 L
.47237 .37801 L
.43611 .337 L
.38632 .28993 L
.35353 .26478 L
.33812 .25468 L
.3205 .24459 L
.30451 .23689 L
.28688 .23016 L
.26789 .22517 L
.24989 .22291 L
.22943 .22365 L
.21791 .22585 L
.20733 .22915 L
.18833 .2386 L
.17804 .24593 L
.16896 .2539 L
.15258 .27257 L
.13636 .2981 L
.1228 .3272 L
.1121 .35796 L
.10376 .39005 L
.09688 .42722 L
.09247 .4643 L
.09029 .49915 L
.09001 .54053 L
.0925 .585 L
.09746 .62545 L
.10419 .66067 L
.11312 .69404 L
.12318 .72224 L
.13588 .74934 L
.15123 .77378 L
.16787 .7931 L
.18654 .80826 L
.20317 .81726 L
.22181 .82328 L
.23183 .825 L
.24247 .82582 L
.26154 .82495 L
.28191 .82116 L
.29334 .8179 L
.30389 .81424 L
Mistroke
.3392 .79813 L
.37459 .77719 L
.47829 .70192 L
.5019 .68517 L
.5252 .67046 L
.54411 .66066 L
.55397 .65655 L
.563 .65348 L
.57088 .65139 L
.57927 .64979 L
.58376 .6492 L
.58847 .64879 L
.59689 .64855 L
.60455 .64888 L
.61173 .64961 L
.61966 .65086 L
.62825 .65267 L
.66504 .66368 L
.68376 .66978 L
.70199 .67503 L
.71254 .67747 L
.72233 .67922 L
.72795 .67995 L
.7333 .68045 L
.73897 .68073 L
.74517 .68073 L
.75126 .68039 L
.75677 .67976 L
.76309 .67863 L
.76899 .67714 L
.77934 .67339 L
.78504 .67061 L
.79018 .66763 L
.79867 .66153 L
.80731 .65356 L
.82141 .63541 L
.82887 .62204 L
.83501 .60791 L
.83967 .59417 L
.84376 .5783 L
.8467 .56215 L
.84791 .55274 L
.84873 .54383 L
.84926 .53444 L
.84944 .52584 L
.84932 .51645 L
.84882 .50669 L
.84717 .49082 L
.84475 .47673 L
.84115 .46227 L
Mistroke
.83631 .44819 L
.83105 .43669 L
.82446 .42576 L
.81684 .41639 L
.81295 .41265 L
.80915 .40955 L
.80159 .40482 L
.79447 .40187 L
.78664 .40007 L
.78218 .39966 L
.77804 .39965 L
.77351 .40002 L
.76864 .40085 L
.76407 .40201 L
.75993 .40339 L
.7522 .40673 L
.74432 .41115 L
.72901 .42262 L
.71429 .43735 L
.68073 .48615 L
.67638 .49341 L
.67435 .49644 L
.67261 .49864 L
.67123 .49999 L
.66981 .5009 L
.66827 .50124 L
.66687 .50093 L
.66547 .50004 L
.66386 .49841 L
.66205 .49599 L
.6602 .49307 L
.64919 .47299 L
.60948 .41011 L
.52508 .31349 L
.45414 .24905 L
.41694 .2198 L
.37182 .18905 L
.3497 .17622 L
.32509 .164 L
.30115 .15452 L
.27883 .14816 L
.25331 .14433 L
.23882 .14404 L
.22541 .14516 L
.20103 .15111 L
.18891 .15624 L
.17575 .16372 L
.16279 .17329 L
.14955 .18568 L
.12725 .21405 L
Mistroke
.11575 .23338 L
.10574 .25363 L
.09503 .27995 L
.08596 .30735 L
.07901 .33292 L
.07249 .3624 L
.0638 .41755 L
.06049 .45038 L
.05831 .48596 L
.05754 .51669 L
.05787 .55056 L
.05926 .58144 L
.06194 .61453 L
.06985 .67219 L
.08108 .72372 L
.09433 .76636 L
.11314 .80958 L
.13259 .84132 L
.1442 .85587 L
.15728 .86919 L
.16998 .87949 L
.18213 .88727 L
.20467 .89717 L
.2299 .90251 L
.25468 .90299 L
.26854 .90153 L
.28111 .89928 L
.30332 .89339 L
.32701 .88483 L
.36843 .86541 L
.62807 .70556 L
.67114 .68019 L
.70963 .65445 L
.72699 .64035 L
.74362 .6241 L
.75664 .60836 L
.7665 .59358 L
.77405 .57944 L
.78029 .56434 L
.78289 .55631 L
.78478 .54918 L
.78614 .54267 L
.78715 .53616 L
.78767 .53096 L
.78791 .52578 L
.78785 .52133 L
.78758 .51766 L
.78703 .51385 L
.78617 .51033 L
.78517 .50762 L
Mistroke
.78409 .50565 L
.78292 .50418 L
.78157 .50317 L
.78025 .50272 L
.77902 .50273 L
.77793 .50307 L
.77675 .50376 L
.77557 .50483 L
.77454 .5061 L
.77342 .5079 L
.77248 .50985 L
.77173 .51179 L
.77106 .51398 L
.77047 .51646 L
.77007 .51879 L
.76979 .5213 L
.7697 .52269 L
.76966 .52397 L
.7697 .52634 L
.76979 .52758 L
.76991 .52864 L
.77023 .53051 L
.77064 .53199 L
.77091 .53269 L
.77121 .53332 L
.77181 .53412 L
.77216 .53438 L
.7725 .53448 L
.77287 .53445 L
.77325 .53423 L
.77387 .53342 L
.77419 .53273 L
.77446 .53192 L
.77487 .53004 L
.77516 .52746 L
.77526 .52467 L
.77518 .52163 L
.77489 .51784 L
.77429 .51326 L
.77348 .50868 L
.77246 .50407 L
.76913 .49259 L
.76439 .48028 L
.75759 .4663 L
.74039 .44004 L
.71926 .41632 L
.68868 .38982 L
.64904 .36169 L
.55786 .30317 L
.42286 .21724 L
Mistroke
.37776 .19213 L
.35144 .1795 L
.32559 .16907 L
.30101 .16143 L
.2869 .15823 L
.27371 .15614 L
.25035 .15488 L
.22551 .15759 L
.20195 .16488 L
.18885 .17133 L
.17687 .17899 L
.15364 .19964 L
.14132 .21439 L
.13063 .22987 L
.11302 .26243 L
.09645 .30466 L
.08366 .35051 L
.07461 .3972 L
.07084 .42446 L
.0678 .45465 L
.06509 .51056 L
.06518 .54318 L
.06658 .57718 L
.06884 .60568 L
.07238 .63597 L
.07735 .66697 L
.0829 .69371 L
.0899 .72077 L
.0986 .74784 L
.10763 .77069 L
.11669 .78972 L
.13631 .82131 L
.15495 .84248 L
.17617 .85894 L
.19702 .86897 L
.21645 .87389 L
.23942 .87516 L
.2524 .874 L
.26436 .87187 L
.28604 .86567 L
.30857 .85639 L
.35086 .83246 L
.38745 .80606 L
.45816 .74315 L
.65788 .61008 L
.68224 .63184 L
.71047 .65271 L
.72809 .66231 L
.73854 .66656 L
.74362 .6682 L
Mistroke
.74843 .66948 L
.75689 .67106 L
.76627 .67174 L
.77542 .6712 L
.78517 .66915 L
.79069 .66725 L
.79573 .66497 L
.80161 .66162 L
.80681 .65796 L
.81602 .64957 L
.8251 .63832 L
.83247 .62623 L
.83944 .61117 L
.84494 .59527 L
.84897 .57942 L
.85198 .56254 L
.85378 .54618 L
.85461 .52788 L
.85454 .51758 L
.85415 .50823 L
.85241 .48972 L
.85087 .47955 L
.84911 .4704 L
.84506 .4544 L
.83965 .43875 L
.83396 .42617 L
.82718 .41446 L
.82084 .40576 L
.81338 .39768 L
.80483 .39062 L
.79995 .38748 L
.79525 .38497 L
.7859 .38133 L
.77724 .37938 L
.76888 .37861 L
.76001 .37887 L
.75248 .37987 L
.74427 .3817 L
.73559 .38441 L
.72648 .38803 L
.7107 .39596 L
.67864 .41691 L
.65059 .43684 L
.6388 .44378 L
.63333 .44632 L
.62845 .4481 L
.62408 .44924 L
.61952 .44992 L
.61497 .45006 L
.60997 .44956 L
Mistroke
.60731 .44902 L
.60477 .44832 L
.59993 .44655 L
.59458 .44395 L
.58855 .44031 L
.56493 .42116 L
.48527 .34258 L
.43097 .2934 L
.39559 .26525 L
.35881 .24009 L
.32501 .22147 L
.30516 .21294 L
.28655 .20682 L
.26593 .20245 L
.25416 .20124 L
.2432 .20104 L
.22319 .2033 L
.20213 .20989 L
.1822 .221 L
.17125 .22954 L
.16133 .23904 L
.14244 .26287 L
.12426 .29539 L
.10974 .33185 L
.09846 .3714 L
.09063 .41039 L
.0848 .45565 L
.08281 .48188 L
.0818 .50683 L
.08166 .53431 L
.08263 .56381 L
.08474 .59261 L
.08817 .62212 L
.09205 .6464 L
.09725 .6718 L
.10898 .71373 L
.11676 .73481 L
.12452 .75234 L
.14126 .7818 L
.15874 .80388 L
.17612 .81948 L
.19617 .83147 L
.20652 .83559 L
.21777 .8387 L
.2383 .84115 L
.25874 .84004 L
.278 .83624 L
.29504 .83095 L
.31324 .82355 L
.35279 .80223 L
Mistroke
.3914 .77592 L
.45101 .72812 L
.49852 .68736 L
.53861 .6554 L
.55653 .64361 L
.56541 .63875 L
.57454 .63458 L
.58269 .63169 L
.58994 .62982 L
.59713 .62865 L
.60389 .62818 L
.61013 .62828 L
.61704 .62895 L
.62053 .6295 L
.62432 .63024 L
.63125 .63196 L
.64506 .63653 L
.65828 .64186 L
.69112 .65603 L
.71074 .66326 L
.72073 .66619 L
.7301 .66832 L
.73912 .66972 L
.74873 .67042 L
.75839 .67015 L
.76385 .66952 L
.76894 .6686 L
.77769 .66614 L
.78552 .66291 L
.79429 .65793 L
.80227 .65191 L
.80936 .64513 L
.81643 .63669 L
.82772 .61841 L
.83357 .60539 L
.83824 .59206 L
.8417 .57931 L
.84461 .56491 L
.84678 .54843 L
.84779 .53281 L
.84793 .52383 L
.84777 .51569 L
.84726 .5064 L
.84646 .49776 L
.84538 .48954 L
.84393 .48106 L
.84057 .46659 L
.83592 .45229 L
.82968 .43832 L
.82357 .42808 L
Mistroke
.81741 .4201 L
.80976 .41261 L
.80205 .40718 L
.79469 .40361 L
.78769 .40147 L
.7799 .40033 L
.77157 .40042 L
.7636 .40164 L
.75912 .40278 L
.75498 .40412 L
.74678 .40751 L
.73829 .41204 L
.72387 .42195 L
.71196 .43215 L
.68966 .45553 L
.68039 .46626 L
.6721 .47539 L
.66596 .48087 L
.66439 .48195 L
.66274 .48291 L
.66121 .48361 L
.65983 .48407 L
.65741 .48445 L
.65477 .48424 L
.65198 .4833 L
.6493 .48175 L
.64638 .47947 L
.64347 .47667 L
.63748 .46981 L
.62028 .44694 L
.56481 .37709 L
.51723 .32609 L
.45902 .27165 L
.39243 .21933 L
.35947 .19804 L
.32118 .17814 L
.29856 .16932 L
.27715 .16334 L
.25642 .16011 L
.23424 .15988 L
.22193 .1614 L
.20872 .16453 L
.1852 .1745 L
.16312 .19012 L
.14389 .21005 L
.12409 .23882 L
.1073 .27246 L
.09417 .30777 L
.08228 .35111 L
.07251 .4032 L
Mistroke
.06893 .43103 L
.06607 .46256 L
.06389 .51954 L
.06522 .57307 L
.06948 .62269 L
.07698 .67217 L
.08569 .71135 L
.09744 .75018 L
.11247 .78686 L
.13078 .81947 L
.14983 .84393 L
.16827 .86095 L
.19139 .87525 L
.20335 .88015 L
.21665 .88389 L
.24042 .88674 L
.26267 .88564 L
.27607 .88348 L
.28869 .88055 L
.31201 .8731 L
.33649 .86287 L
.36224 .84994 L
.50686 .75582 L
.6803 .65483 L
.71216 .6391 L
.74124 .62164 L
.75446 .61142 L
.76717 .59915 L
.77698 .58707 L
.78452 .5752 L
.7906 .56268 L
.79295 .55652 L
.79477 .5509 L
.79609 .54598 L
.79723 .54069 L
.79806 .53554 L
.7986 .53033 L
.79876 .52753 L
.79882 .52497 L
.7987 .5204 L
.79851 .51801 L
.79826 .51589 L
.7979 .51369 L
.79743 .51148 L
.79637 .50786 L
.79516 .50492 L
.79392 .50266 L
.79243 .50064 L
.79091 .4991 L
.78941 .49799 L
Mistroke
.78771 .49712 L
.78583 .49656 L
.78488 .49642 L
.78384 .49635 L
.78194 .49647 L
.78012 .49683 L
.77846 .49734 L
.77556 .49858 L
.77253 .50019 L
.76957 .50185 L
.76698 .50308 L
.76573 .5035 L
.76441 .50377 L
.76367 .50382 L
.76297 .5038 L
.76164 .50357 L
.76022 .50302 L
.75886 .50221 L
.75731 .50098 L
.75555 .49927 L
.73875 .47673 L
.63607 .37332 L
.54573 .30415 L
.47983 .25626 L
.40462 .20636 L
.36667 .18492 L
.32375 .1655 L
.31059 .16085 L
.29807 .15711 L
.2744 .1521 L
.25199 .15022 L
.22778 .15196 L
.20741 .15705 L
.18554 .16703 L
.16352 .18291 L
.14406 .20316 L
.12702 .22718 L
.11277 .25332 L
.09809 .28844 L
.0862 .32621 L
.07573 .37181 L
.06763 .425 L
.0632 .47785 L
.06198 .52725 L
.06402 .58461 L
.0668 .61628 L
.07041 .64483 L
.07945 .69419 L
.09232 .74157 L
.10057 .76465 L
Mistroke
.10886 .78411 L
.11847 .80307 L
.12976 .82148 L
.15025 .84679 L
.16208 .85767 L
.17345 .86601 L
.19573 .87735 L
.21653 .88296 L
.24079 .88455 L
.26375 .88197 L
.28324 .87714 L
.3044 .86955 L
.34554 .8489 L
.41212 .80304 L
.52527 .70346 L
.5953 .63764 L
.60913 .62606 L
.62243 .6163 L
.6337 .60959 L
.63896 .6071 L
.64369 .60526 L
.64911 .60364 L
.65192 .60302 L
.65488 .60252 L
.65964 .60207 L
.66485 .60205 L
.66783 .60226 L
.67057 .60257 L
.67374 .60307 L
.67678 .60369 L
.68829 .60696 L
.71189 .61596 L
.72392 .6204 L
.73545 .6239 L
.74147 .6253 L
.7479 .62641 L
.75441 .62706 L
.75812 .62719 L
.76158 .62714 L
.76784 .6266 L
.7735 .62555 L
.77994 .62361 L
.78589 .62103 L
.79198 .61746 L
.79816 .6127 L
.8083 .6016 L
.81328 .59406 L
.81747 .58615 L
.82145 .57663 L
.82495 .56551 L
Mistroke
.82714 .55609 L
.82866 .54702 L
.82973 .53682 L
.83017 .5258 L
.83012 .52022 L
.82986 .51422 L
.82884 .50349 L
.82718 .49336 L
.8251 .48443 L
.82269 .47648 L
.82006 .46949 L
.81647 .46179 L
.81281 .45539 L
.80433 .44433 L
.79917 .43943 L
.79401 .43557 L
.78868 .43248 L
.78274 .42995 L
.77701 .42829 L
.77167 .42735 L
.76573 .42691 L
.7592 .42707 L
.75592 .42738 L
.75243 .42787 L
.74618 .4291 L
.73968 .43081 L
.73278 .43304 L
.7207 .43767 L
.6998 .44627 L
.69515 .44796 L
.69026 .44952 L
.68581 .45071 L
.68163 .45156 L
.67701 .45216 L
.67281 .45238 L
.66818 .45221 L
.66555 .45192 L
.6631 .45151 L
.65869 .45047 L
.65446 .44911 L
.64632 .44552 L
.63703 .4401 L
.62619 .4324 L
.46933 .2918 L
.4044 .24139 L
.36327 .21473 L
.32112 .19326 L
.29617 .18409 L
.28181 .18024 L
.2684 .1777 L
Mistroke
.24457 .17608 L
.23253 .17685 L
.21929 .1791 L
.19583 .18724 L
.18295 .19436 L
.1714 .20263 L
.15102 .22247 L
.13119 .25006 L
.11458 .28212 L
.09912 .32343 L
.08735 .36805 L
.07923 .41314 L
.07431 .45623 L
.07167 .50517 L
.07208 .55669 L
.07536 .60398 L
.08262 .65651 L
.09272 .70234 L
.1042 .73923 L
.11899 .77417 L
.13733 .80542 L
.14844 .81981 L
.15894 .83097 L
.1804 .84777 L
.20144 .85801 L
.2201 .86294 L
.24077 .86464 L
.26234 .86287 L
.28226 .8585 L
.30065 .85245 L
.31706 .84562 L
.35251 .82699 L
.47888 .73276 L
.56158 .66501 L
.59305 .64415 L
.60903 .63611 L
.62315 .63092 L
.6304 .62903 L
.6343 .62824 L
.6379 .62766 L
.64424 .62694 L
.65113 .6266 L
.65501 .6266 L
.65867 .62672 L
.66553 .62722 L
.66939 .62764 L
.67296 .62811 L
.68109 .6294 L
.70797 .63469 L
.71596 .63614 L
Mistroke
.72362 .6373 L
.73056 .63809 L
.73815 .6386 L
.74505 .63866 L
.75265 .6382 L
.75646 .63773 L
.76054 .63703 L
.76785 .63522 L
.77461 .63282 L
.78154 .62949 L
.78727 .62597 L
.7933 .62137 L
.80411 .61019 L
.80953 .60264 L
.814 .59504 L
.81775 .58734 L
.8213 .5784 L
.82395 .57014 L
.8263 .56089 L
.82836 .54976 L
.8296 .53912 L
.83003 .53259 L
.83021 .52639 L
.82995 .51487 L
.82951 .50911 L
.82884 .50309 L
.82707 .49264 L
.82566 .48652 L
.8241 .481 L
.82065 .47136 L
.81708 .4637 L
.81281 .45652 L
.80876 .4511 L
.8041 .44615 L
.79878 .44179 L
.79358 .43863 L
.79032 .43712 L
.78719 .43598 L
.78123 .43454 L
.77587 .434 L
.77009 .43413 L
.76465 .43486 L
.75973 .43599 L
.75435 .43769 L
.7486 .43999 L
.73756 .44569 L
.71882 .45805 L
.70986 .46429 L
.70214 .46908 L
.69883 .47078 L
Mistroke
.69543 .47221 L
.69369 .47279 L
.69179 .4733 L
.68849 .47382 L
.68551 .47388 L
.6823 .47349 L
.67924 .47267 L
.67639 .47153 L
.67322 .46988 L
.6702 .46796 L
.66288 .46219 L
.64727 .44673 L
.5885 .38324 L
.49306 .29263 L
.43523 .24532 L
.36257 .19623 L
.32016 .17507 L
.30812 .17038 L
.29506 .16605 L
.27118 .16041 L
.24753 .1582 L
.22514 .15976 L
.20522 .16472 L
.18403 .17445 L
.16222 .19037 L
.1433 .21035 L
.12314 .24014 L
.10604 .27518 L
.09246 .31291 L
.08197 .35222 L
.07304 .39935 L
.06674 .45306 L
.06471 .48476 L
.06387 .51426 L
.06409 .5467 L
.06562 .58069 L
.07113 .63615 L
.07584 .66614 L
.08123 .69286 L
.09366 .73878 L
.10744 .77547 L
.12583 .81109 L
.14526 .83795 L
.16554 .85768 L
.17758 .86628 L
.18914 .87271 L
.21291 .88118 L
.22648 .88357 L
.23897 .88441 L
.26 .88324 L
Mistroke
.28284 .87881 L
.30627 .87137 L
.32757 .86247 L
.41383 .8115 L
.48983 .75553 L
.58652 .68422 L
.62675 .65906 L
.65909 .64251 L
.69004 .63005 L
.72067 .61974 L
.73297 .61545 L
.7457 .61037 L
.75713 .6048 L
.76677 .59892 L
.77609 .5917 L
.78489 .5828 L
.79185 .57348 L
.79725 .5639 L
.79941 .55911 L
.80137 .55394 L
.80282 .54941 L
.8041 .54452 L
.80516 .53925 L
.80586 .53436 L
.80634 .52863 L
.80643 .52354 L
.80619 .51823 L
.80593 .51564 L
.80555 .51286 L
.80463 .50817 L
.80349 .50405 L
.80185 .49958 L
.80007 .49588 L
.79786 .49226 L
.79526 .48895 L
.79295 .48662 L
.79035 .48452 L
.78799 .483 L
.78535 .48164 L
.78214 .48041 L
.78064 .47997 L
.77905 .47957 L
.77599 .47902 L
.77314 .4787 L
.77024 .47853 L
.7686 .47849 L
.76708 .47848 L
.76429 .47851 L
.76133 .47859 L
.75887 .47865 L
Mistroke
.75622 .47871 L
.75331 .47871 L
.75058 .47862 L
.74764 .47841 L
.74596 .47823 L
.7444 .47801 L
.74121 .47741 L
.73774 .4765 L
.73444 .47538 L
.73125 .47406 L
.725 .47084 L
.71122 .46142 L
.69609 .44892 L
.64904 .40709 L
.58113 .34911 L
.47192 .26255 L
.43091 .23304 L
.38788 .20516 L
.34235 .18066 L
.31906 .17075 L
.29742 .16355 L
.27494 .15845 L
.25356 .15626 L
.23095 .15728 L
.20671 .16295 L
.1823 .17458 L
.17036 .1829 L
.15763 .19406 L
.13629 .21928 L
.1181 .24926 L
.10126 .28731 L
.09315 .31089 L
.08635 .33463 L
.07638 .3799 L
.06864 .43389 L
.06602 .46359 L
.06437 .49538 L
.06434 .5526 L
.06594 .58417 L
.06844 .61297 L
.07229 .64366 L
.07764 .67505 L
.08932 .72381 L
.09727 .74871 L
.1054 .76982 L
.12212 .80377 L
.14193 .83262 L
.16113 .85234 L
.18001 .86581 L
.20144 .87546 L
Mistroke
.22495 .8805 L
.24784 .88084 L
.26898 .87783 L
.29187 .87151 L
.30444 .86686 L
.31567 .86207 L
.39313 .81604 L
.50559 .7242 L
.58477 .65513 L
.61622 .63174 L
.62962 .62379 L
.64102 .61839 L
.64681 .61623 L
.65295 .61437 L
.65628 .61356 L
.65933 .61295 L
.66528 .61208 L
.67123 .61164 L
.6746 .61157 L
.67776 .61162 L
.68109 .61177 L
.68415 .612 L
.68768 .61236 L
.69106 .61279 L
.71563 .61732 L
.72769 .61955 L
.73307 .62036 L
.73902 .62105 L
.7448 .62146 L
.75094 .62156 L
.75416 .62146 L
.75761 .62121 L
.7638 .62037 L
.76997 .61896 L
.77572 .61705 L
.78076 .61483 L
.7861 .61184 L
.79152 .60799 L
.7972 .60291 L
.80237 .59713 L
.80746 .58999 L
.8117 .58254 L
.81512 .57509 L
.81792 .56754 L
.8204 .55901 L
.82222 .55063 L
.82344 .54281 L
.82423 .53481 L
.82457 .52722 L
.82446 .51839 L
Mistroke
.82389 .51037 L
.82276 .50178 L
.82099 .49304 L
.81895 .48564 L
.81629 .47818 L
.81037 .46622 L
.80614 .45999 L
.80175 .45487 L
.79716 .45062 L
.79273 .44738 L
.78763 .44452 L
.78494 .44333 L
.78194 .44225 L
.77682 .4409 L
.77134 .44011 L
.76633 .43988 L
.76097 .44012 L
.75593 .44073 L
.75138 .44157 L
.74578 .44292 L
.7407 .44441 L
.72958 .44825 L
.71966 .45196 L
.71078 .45505 L
.70352 .45708 L
.69952 .45791 L
.6959 .45843 L
.69217 .45871 L
.6881 .4587 L
.68383 .4583 L
.67984 .45756 L
.6755 .45635 L
.67133 .4548 L
.66322 .45081 L
.65388 .44488 L
.64283 .4365 L
.4921 .30011 L
.42947 .24994 L
.38951 .22196 L
.34813 .19756 L
.32347 .18581 L
.31012 .1805 L
.29572 .17569 L
.28351 .17243 L
.2699 .16979 L
.24571 .16795 L
.22132 .17048 L
.20772 .17414 L
.19538 .17908 L
.17324 .19249 L
Mistroke
.16248 .20148 L
.15107 .21316 L
.13072 .2407 L
.1138 .27245 L
.09777 .31404 L
.09083 .33749 L
.08417 .36503 L
.07548 .41458 L
.07203 .44388 L
.06981 .47133 L
.06813 .5255 L
.06977 .57688 L
.0742 .62445 L
.0819 .67236 L
.09178 .71391 L
.10274 .74783 L
.11783 .78269 L
.13638 .81374 L
.15562 .83662 L
.17445 .85233 L
.19547 .86385 L
.21863 .87069 L
.24076 .87259 L
.26094 .87103 L
.28438 .86591 L
.29744 .86172 L
.30936 .85714 L
.35275 .8354 L
.42992 .78243 L
.49624 .72882 L
.57837 .66336 L
.59606 .65146 L
.61316 .64155 L
.62695 .63503 L
.63423 .63221 L
.64094 .63 L
.64712 .62832 L
.65372 .6269 L
.65965 .62593 L
.66507 .6253 L
.67016 .62492 L
.67574 .6247 L
.68155 .62468 L
.687 .62482 L
.69344 .62514 L
.69958 .62556 L
.71117 .62647 L
.71726 .62692 L
.72376 .6273 L
.72751 .62745 L
Mistroke
.73092 .62753 L
.73756 .6275 L
.74401 .62719 L
.75 .62657 L
.75652 .62549 L
.7634 .62379 L
.77048 .62133 L
.77698 .61831 L
.78263 .61498 L
.78851 .61068 L
.79837 .60097 L
.80287 .59516 L
.80739 .58809 L
.81084 .58155 L
.81413 .57404 L
.81662 .5671 L
.81885 .55939 L
.82091 .54994 L
.82224 .54095 L
.82277 .5354 L
.82307 .53017 L
.82312 .52044 L
.82289 .51551 L
.82246 .51037 L
.82122 .50144 L
.82027 .49666 L
.81923 .49233 L
.81633 .48308 L
.81331 .47593 L
.81002 .46983 L
.80292 .46031 L
.7985 .45612 L
.79418 .45296 L
.78925 .45028 L
.78669 .44923 L
.78383 .4483 L
.77899 .44724 L
.77444 .44679 L
.76943 .44684 L
.76664 .44708 L
.7641 .44743 L
.75903 .44847 L
.75361 .45003 L
.74412 .45365 L
.72875 .46101 L
.72127 .46462 L
.71367 .46774 L
.71154 .46845 L
.70953 .46902 L
.70582 .46982 L
Mistroke
.70237 .47021 L
.70043 .47026 L
.69863 .4702 L
.69657 .47 L
.69461 .46968 L
.69093 .46872 L
.68883 .46797 L
.68687 .46715 L
.68232 .4648 L
.67484 .4598 L
.66581 .45241 L
.64394 .43145 L
.58021 .36813 L
.48266 .28116 L
.40871 .22481 L
.36357 .19634 L
.33719 .18256 L
.31152 .17166 L
.28954 .16466 L
.26547 .1599 L
.25236 .15878 L
.23853 .15887 L
.21394 .16275 L
.19187 .17104 L
.17195 .18333 L
.15106 .2024 L
.1303 .22958 L
.11239 .26227 L
.09537 .30557 L
.08802 .33007 L
.08114 .35819 L
.07608 .38384 L
.07154 .41298 L
.06588 .47117 L
.06425 .52801 L
.06623 .58313 L
.07113 .63259 L
.07559 .66193 L
.08159 .6921 L
.08783 .71719 L
.09532 .74192 L
.11186 .78349 L
.12937 .81507 L
.13995 .82989 L
.15182 .84352 L
.17436 .86252 L
.18869 .87077 L
.20252 .87642 L
.21509 .87982 L
.22884 .88187 L
Mistroke
.25206 .88191 L
.27371 .87861 L
.29714 .87201 L
.32175 .86222 L
.36936 .83667 L
.4094 .81017 L
.52874 .71788 L
.60611 .66061 L
.63965 .64114 L
.66639 .62973 L
.68059 .62531 L
.69537 .6218 L
.72107 .61728 L
.73311 .61517 L
.74551 .61244 L
.75574 .60936 L
.7665 .60489 L
.7766 .59898 L
.7866 .59075 L
.79485 .58118 L
.80125 .5709 L
.80585 .56065 L
.80795 .55449 L
.80956 .54855 L
.81086 .5422 L
.81171 .53633 L
.81225 .52989 L
.81238 .52319 L
.81206 .51646 L
.81138 .51054 L
.81084 .50737 L
.81014 .50402 L
.80857 .49824 L
.80674 .49319 L
.80448 .48828 L
.79966 .48069 L
.79659 .47715 L
.79304 .47393 L
.7895 .47142 L
.78613 .46958 L
.78206 .46793 L
.77971 .46723 L
.7775 .46671 L
.77537 .46632 L
.77342 .46607 L
.77117 .46588 L
.76904 .46578 L
.76548 .4658 L
.76168 .46603 L
.75811 .46638 L
Mistroke
.75488 .4668 L
.74698 .46799 L
.73983 .46898 L
.73628 .46933 L
.73254 .46954 L
.72879 .46953 L
.72665 .46942 L
.72464 .46924 L
.721 .4687 L
.71763 .46795 L
.71386 .46683 L
.70981 .46529 L
.70281 .46186 L
.69483 .45695 L
.67863 .44471 L
.62846 .40036 L
.54386 .3265 L
.48133 .27556 L
.39862 .21599 L
.35845 .19228 L
.33511 .18075 L
.31229 .17144 L
.29917 .1671 L
.28471 .16328 L
.27146 .16075 L
.25911 .15933 L
.23469 .1595 L
.22239 .1613 L
.2089 .16479 L
.18584 .17501 L
.16542 .1895 L
.14419 .21153 L
.1341 .22514 L
.12361 .24202 L
.10739 .27517 L
.09248 .31678 L
.08106 .36129 L
.07315 .40542 L
.06738 .45713 L
.06493 .5072 L
.06559 .56244 L
.07017 .62039 L
.07391 .64818 L
.07906 .67728 L
.0911 .7262 L
.10581 .76783 L
.12174 .80056 L
.13987 .82782 L
.15833 .84785 L
.17578 .86136 L
Mistroke
.19533 .87153 L
.21722 .87784 L
.2406 .87974 L
.26056 .87807 L
.28227 .87333 L
.29431 .86956 L
.30725 .86469 L
.33023 .85418 L
.37114 .83054 L
.45107 .77155 L
.55529 .68332 L
.58928 .65606 L
.6198 .63525 L
.63524 .62706 L
.64166 .62426 L
.6485 .62171 L
.65442 .61989 L
.66063 .61837 L
.66403 .61771 L
.6671 .61721 L
.67306 .6165 L
.67931 .6161 L
.68245 .61602 L
.68591 .61602 L
.69202 .61621 L
.69776 .61658 L
.70456 .61719 L
.71081 .61784 L
.71817 .61863 L
.72504 .6193 L
.73103 .61977 L
.73743 .62008 L
.7411 .62014 L
.74455 .6201 L
.75098 .61976 L
.75712 .61903 L
.76271 .61796 L
.76875 .61631 L
.77499 .61395 L
.7806 .61116 L
.78647 .60744 L
.79141 .60354 L
.79637 .59876 L
.80056 .59389 L
.80482 .58793 L
.81133 .576 L
.81459 .56797 L
.81708 .56019 L
.81824 .55575 L
.81932 .5508 L
Mistroke
.82019 .54599 L
.82082 .54159 L
.82164 .53288 L
.82189 .52358 L
.82156 .51506 L
.82076 .50721 L
.81961 .50019 L
.81791 .49281 L
.81567 .48554 L
.81317 .47923 L
.80783 .46921 L
.8044 .46438 L
.80104 .46048 L
.79714 .4568 L
.79279 .45353 L
.7878 .45069 L
.78303 .44873 L
.77851 .44746 L
.77421 .4467 L
.76946 .44633 L
.76432 .4464 L
.75925 .4469 L
.75468 .44767 L
.74946 .44885 L
.74462 .45019 L
.72751 .45599 L
.71901 .45883 L
.71451 .46013 L
.71036 .46111 L
.70805 .46154 L
.70595 .46186 L
.70363 .46212 L
.70114 .46228 L
.69907 .46232 L
.69681 .46225 L
.69268 .46181 L
.69043 .46141 L
.68798 .46083 L
.68348 .4594 L
.67898 .45753 L
.67471 .45537 L
.65234 .43952 L
.595 .38688 L
.51347 .31299 L
.45197 .26235 L
.38121 .21243 L
.33595 .18752 L
.30897 .17626 L
.29581 .17195 L
.28334 .16866 L
Mistroke
.26147 .16501 L
.23721 .16461 L
.21368 .16861 L
.20062 .17304 L
.18882 .17861 L
.16761 .19303 L
.14885 .21155 L
.12968 .23785 L
.11131 .2729 L
.103 .29327 L
.09482 .31724 L
.0824 .36533 L
.0736 .41687 L
.06858 .46725 L
.06666 .52303 L
.06821 .57589 L
.07236 .62205 L
.07972 .66972 L
.09084 .71711 L
.09835 .74119 L
.10588 .76135 L
.12237 .79592 L
.13973 .8225 L
.15747 .84235 L
.17725 .85793 L
.19478 .86717 L
.21442 .87337 L
.23588 .87599 L
.25888 .87478 L
.28042 .87047 L
.29971 .86439 L
.32209 .85508 L
.34508 .84337 L
.38406 .81945 L
.46048 .76238 L
.5614 .6801 L
.59699 .65435 L
.62579 .6377 L
.64022 .63146 L
.64755 .62893 L
.65519 .62676 L
.66212 .62521 L
.66833 .62414 L
.67451 .62337 L
.6803 .62288 L
.68558 .62261 L
.69132 .62248 L
.69673 .62248 L
.70174 .62256 L
.70758 .62271 L
Mistroke
.71379 .6229 L
.71902 .62304 L
.72481 .62314 L
.73111 .62311 L
.73465 .62302 L
.73789 .62287 L
.74385 .62242 L
.75008 .62164 L
.75582 .62058 L
.7611 .61927 L
.7668 .61743 L
.77274 .61496 L
.77858 .61189 L
.78465 .60788 L
.78975 .60372 L
.79484 .59869 L
.79913 .5936 L
.80347 .58741 L
.81007 .57515 L
.81332 .56703 L
.81578 .55922 L
.81692 .55478 L
.81799 .54986 L
.81883 .54509 L
.81944 .54073 L
.82022 .53214 L
.82041 .52743 L
.82043 .52303 L
.82011 .51528 L
.81924 .50713 L
.81798 .49987 L
.81642 .49342 L
.8143 .48676 L
.81159 .48019 L
.80831 .47397 L
.80484 .46877 L
.8014 .46464 L
.79751 .4609 L
.79397 .45819 L
.78991 .45575 L
.78611 .45403 L
.78247 .45282 L
.77812 .45186 L
.7741 .45141 L
.76968 .45132 L
.76503 .45165 L
.76036 .45237 L
.75775 .45291 L
.75537 .45349 L
.74655 .45622 L
Mistroke
.7311 .46221 L
.723 .46521 L
.71918 .46639 L
.71575 .46726 L
.71219 .46792 L
.7084 .46831 L
.70643 .46837 L
.70428 .46831 L
.70225 .46814 L
.70036 .46787 L
.69726 .46721 L
.69386 .46616 L
.69058 .46486 L
.6875 .46337 L
.67146 .45249 L
.62685 .41095 L
.55863 .3465 L
.4452 .25143 L
.40195 .22052 L
.35691 .19315 L
.33612 .18263 L
.31343 .17303 L
.30135 .16882 L
.2879 .16496 L
.26393 .1605 L
.23935 .15968 L
.21695 .16291 L
.20471 .16656 L
.19153 .17221 L
.16819 .18734 L
.14757 .20751 L
.12722 .23583 L
.10996 .2691 L
.09631 .30454 L
.0839 .34842 L
.07492 .39356 L
.06822 .4466 L
.0649 .50588 L
.06477 .53598 L
.06581 .56855 L
.07079 .62622 L
.07931 .67896 L
.09017 .72343 L
.10259 .76025 L
.11603 .79038 L
.13248 .81825 L
.15185 .84215 L
.17237 .85977 L
.19496 .8722 L
.21476 .87832 L
Mistroke
.23668 .88086 L
.24918 .8806 L
.26269 .87909 L
.27537 .87662 L
.28697 .87356 L
.30863 .86598 L
.33096 .85597 L
.41915 .80049 L
.53724 .70667 L
.61175 .65153 L
.62896 .64145 L
.64412 .63398 L
.65712 .62877 L
.67036 .62469 L
.67672 .62315 L
.68261 .62196 L
.68829 .62101 L
.69346 .62029 L
.70348 .61921 L
.7142 .61834 L
.72588 .61745 L
.73665 .61637 L
.74202 .61563 L
.74771 .61464 L
.75395 .61324 L
.75953 .61164 L
.76971 .60766 L
.77525 .60475 L
.78026 .60156 L
.78965 .59373 L
.79445 .58848 L
.79849 .58316 L
.80474 .57258 L
.80771 .56602 L
.81007 .55962 L
.81192 .55336 L
.81333 .54732 L
.81455 .54023 L
.81526 .53375 L
.81562 .52666 L
.8155 .51898 L
.81524 .51518 L
.81482 .51118 L
.81369 .50418 L
.81211 .49758 L
.81022 .49171 L
.80573 .48191 L
.80269 .47709 L
.79911 .47263 L
.79578 .46932 L
Mistroke
.79198 .46633 L
.78771 .46377 L
.78356 .46195 L
.78111 .46113 L
.77849 .46046 L
.77624 .46002 L
.77375 .45968 L
.7693 .4594 L
.76519 .45947 L
.76305 .45962 L
.7607 .45986 L
.75825 .46019 L
.75597 .46055 L
.73984 .46408 L
.73269 .46564 L
.72923 .46625 L
.72605 .46669 L
.72244 .467 L
.7185 .46709 L
.71516 .46692 L
.71159 .46648 L
.7095 .46609 L
.70728 .46556 L
.70325 .46432 L
.6988 .46254 L
.69375 .46003 L
.67421 .44662 L
.62335 .40134 L
.54127 .32808 L
.42176 .23356 L
.38152 .20716 L
.33516 .18229 L
.30971 .17192 L
.29492 .1672 L
.28088 .16372 L
.25602 .16031 L
.24199 .16016 L
.22915 .16129 L
.20657 .16666 L
.18602 .17599 L
.16425 .19159 L
.14234 .21497 L
.13193 .22954 L
.12127 .24743 L
.10378 .28541 L
.08944 .32883 L
.07892 .37376 L
.07078 .42636 L
.06632 .47897 L
.06512 .52724 L
Mistroke
.06688 .57958 L
.07232 .63451 L
.07641 .66101 L
.08194 .689 L
.09409 .73444 L
.10803 .77183 L
.12316 .802 L
.14083 .82813 L
.15704 .84585 L
.17571 .86059 L
.19665 .87139 L
.21961 .87767 L
.24151 .87922 L
.26143 .87749 L
.28483 .87222 L
.29648 .86847 L
.30915 .86362 L
.35094 .84281 L
.43421 .78542 L
.54489 .69385 L
.58283 .66352 L
.61696 .6401 L
.63073 .63252 L
.64451 .62641 L
.65095 .62412 L
.65689 .62234 L
.6621 .62105 L
.66775 .61993 L
.67429 .61898 L
.67784 .61861 L
.68115 .61835 L
.68704 .61809 L
.69335 .61804 L
.6969 .6181 L
.70076 .61822 L
.70441 .61837 L
.70779 .61855 L
.71461 .61894 L
.72104 .6193 L
.7265 .61954 L
.73239 .6197 L
.73558 .61971 L
.73894 .61967 L
.74493 .61939 L
.75118 .61879 L
.75695 .61788 L
.7632 .61644 L
.76975 .61432 L
.77543 .61188 L
.78147 .60856 L
Mistroke
.78751 .60433 L
.79284 .59965 L
.80149 .58954 L
.80576 .58293 L
.80924 .57635 L
.81254 .56867 L
.81545 .55998 L
.81683 .55479 L
.81789 .54998 L
.81878 .54502 L
.81943 .54042 L
.81989 .536 L
.82022 .53133 L
.82038 .52665 L
.82036 .52154 L
.82019 .51716 L
.81984 .51253 L
.81878 .50439 L
.81802 .5003 L
.81707 .49609 L
.81499 .48887 L
.81225 .48168 L
.80868 .47453 L
.80518 .46909 L
.80105 .46399 L
.79683 .45993 L
.79276 .45685 L
.7886 .45442 L
.78462 .45265 L
.78016 .45123 L
.77532 .45027 L
.77286 .44999 L
.77018 .44983 L
.76532 .44989 L
.76061 .45034 L
.7563 .45103 L
.73904 .45574 L
.72386 .46078 L
.71999 .4619 L
.71594 .46288 L
.71385 .4633 L
.71156 .46368 L
.70754 .46412 L
.70393 .46423 L
.70004 .46401 L
.69633 .46348 L
.6929 .46268 L
.68873 .46133 L
.68475 .45968 L
.67525 .45442 L
Mistroke
.65307 .43732 L
.59521 .38361 L
.49559 .295 L
.42688 .24111 L
.39207 .21719 L
.35059 .19285 L
.33177 .18366 L
.311 .17513 L
.29096 .16874 L
.27237 .16467 L
.25127 .16256 L
.22822 .1638 L
.20664 .16899 L
.18701 .17778 L
.1647 .1936 L
.14484 .21434 L
.12824 .23803 L
.11194 .26907 L
.09645 .30923 L
.08916 .33372 L
.08318 .35802 L
.07466 .40399 L
.06857 .45773 L
.06603 .51403 L
.06615 .54265 L
.06739 .57399 L
.07234 .62786 L
.08006 .67549 L
.08574 .70103 L
.09264 .7263 L
.10715 .7669 L
.12548 .80346 L
.13692 .82075 L
.14813 .83461 L
.16965 .85444 L
.19098 .86719 L
.21069 .87415 L
.23235 .87745 L
.25607 .87672 L
.26797 .8749 L
.28097 .87192 L
.30362 .86453 L
.3243 .85566 L
.39953 .8105 L
.45805 .7661 L
.55706 .68516 L
.59257 .65864 L
.60961 .64751 L
.62442 .6391 L
.63744 .63291 L
Mistroke
.65078 .62791 L
.6565 .62621 L
.66244 .62473 L
.66783 .62362 L
.67288 .62279 L
.67929 .62199 L
.68509 .6215 L
.69131 .62118 L
.69481 .62108 L
.69804 .62103 L
.70342 .62102 L
.70935 .62107 L
.7155 .62115 L
.72135 .6212 L
.72464 .6212 L
.72824 .62117 L
.73453 .62099 L
.73808 .62079 L
.74185 .6205 L
.7454 .62013 L
.74861 .61971 L
.75482 .61861 L
.76144 .61696 L
.76757 .6149 L
.77307 .61253 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00e@3oool00`3ooml0W4P0000000020000000307Bo
o`3oool0oooo0=<0oooo003G0?ooo`030?noM00007@0_ooo0=H0oooo003G0?ooo`030?oo_`1d0000
M;oo0=H0oooo003G0?ooo`030?oog`2LB000B9cO0=H0oooo003H0?ooo`030=nLB000000000000080
000000<0M;oo0?ooo`3oool00P3oool01@3o_g@000000000000004P0W=oo0080oooo00<0oono07@0
000000000P0000003@18W=l0oooo0?ooo`3oool0_g@00000000004P0W=oo0?ooo`3o_g@000000000
B02Lgol00P3oool0102oM00000000000B02Lgol20?ooo`050?noM000000000000000B02Lgol00`3o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000000007Bo09d0oooo003H0?ooo`070?noM00004P0
W=oo0?ooo`3ooml0W4P0001d_`020?ooo`0?0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`3oool0
oooO09a8001d_ol0oooo0?oOW0180000M;oo0080oooo01L0gia80018W03Ooml0W7BL0=ooo`3o_g@0
001809cOg`2LM9`0gooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0
B000001d_`020?ooo`030?noM00007@0_ooo0080oooo00@0gia80018W03O_g@0M;ooW03oool00=P0
oooo00<0oono07@0001d_ol00P3oool01`3ooml0W4P004RLg`3oool0gia80018W03Oool00P3oool0
2P3ogi`0B00004RLg`3oool0_gAd0;ooo`3oool0oono07@0001d_ol20?ooo`030?noM00004P0W=oo
0080oooo00<0oono07@0001d_ol00`3oool00`3o_g@0001809cOo`020?ooo`030=nLB000B9`0gooo
0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol0W@3o
ool00=P0oooo00<0oooO09a80018W=l00`3oool01P3ogi`0B01809cOo`3o_g@0001d0;ooo`<0oooo
00<0gia80000M02oool00`3oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo
00<0_g@0001d_`3oool00P3oool00`3ookl0M00004RLg`020?ooo`030?noM00007@0_ooo00<0oooo
00/0gia80000M02oool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`2M0?ooo`00f@3oool0
0`3OW4P0001d0;ooo`020?ooo`060?oog`2LB000B9cO0?oo_`1d0000M;oo0`3oool00`3ogi`0B018
09cOo`020?ooo`030?noM00004P0W=oo00@0oooo00<0_g@00018W03Oool00P3oool00`3OW4P004RL
0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3ookl0M00007Boo`030?ooo`070?oOW01804P0W=oo
0?ooo`3OW4P004Q804Qd_`020?ooo`030;md0000M;l0oooo09`0oooo003I0?ooo`040?noM0000000
04RL0=ooo`80oooo00H0gia8001d_`3oool0gia80000M02oool20?ooo`0:0?oo_`1d0000M;oo0?oo
o`3ogi`0B01809cOo`3oool0giad09cOo`80oooo00<0gia80000B02Lgol00P3oool00`3ogi`0B018
09cOo`030?ooo`030=nLB00004P0W=oo0080oooo00<0gia80000M02oool00P3oool0303ookl0M000
07Boo`3oool0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;oooi`0oooo003I0?ooo`080?oo_`1d
0000M9bL04P0M02oool0oooO09a80000M;l20?ooo`0>0;md000007@0_ooo0?ooo`3o_g@0001d0;oo
o`3oool0omnL04P0B02Lgol0oooO09a8001d_ol20?ooo`030?oOW0180000B9cO0080oooo00<0oooO
09a80018W=l00`3oool00`3ogi`0B00004RLg`030?ooo`0@0;md000007@0_ooo0?ooo`3o_g@0001d
0;ooo`3oool0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOoi`0oooo003H0?ooo`090?oOW018
0000000004RLg`3ookl0M0000000000007@0_ooo00<0oooo00D0okmd000000000000000007Boo`03
0?ooo`070;md00000000000000000018W=l0oooo0?noM002000000040018W03Oool0oono07@000<0
000000H0M;oo0?noM000000000000018W03Oool30?ooo`0?0?noM000000000000000001d_ol0oooo
0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo09`0oooo003i0?ooo`030?noM00007@0
_ooo0;@0oooo003j0?ooo`030=nLM02Lgol0oooo0;<0oooo003d0?ooo`040?oo_`1d000004RL0=oo
o`L0oooo00@0oono07@00000B9`0gooo[@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool006L0oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`0Y0?ooo`030=nLB000
0000000000<0000000<0B9cO0?ooo`3oool09`3oool00`3ookl0M000000000020000000304RLg`3o
ool0oooo02@0oooo00@0_g@0000000000000M;oo:`3oool00`3ookl0M000000000020000000304RL
g`3oool0oooo02P0oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`0X0?ooo`030?oo
_`1d000000000080000000<0M;oo0?ooo`3oool0903oool006L0oooo00<0okmd00000000M;l00P3o
ool00`2oM4P0W=oo0?ooo`0Z0?ooo`030?noM000M;l0oooo0080oooo00<0_gAd0;ooo`3oool0:@3o
ool00`3o_g@0000007Boo`0V0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO;03oool00`3o_g@0
000007Boo`0/0?ooo`030?noM000M;l0oooo0080oooo00<0_gAd0;ooo`3oool0:03oool00`3o_g@0
0000001d_`020?ooo`030;mdB02Lgol0oooo02@0oooo001/0?ooo`030?oOW018B9`0gooo02/0oooo
00<0okmd001d_`3oool0;@3oool00`3ooml0W4P0001d_`0U0?ooo`030?oog`2LB000B9cO0080oooo
00<0okmd0000B02Lgol0:`3oool00`3ooml0W4P0001d_`0]0?ooo`030?noM000M;l0oooo0340oooo
00<0omnL04Q8W03Oool0903oool006`0oooo00<0oono07@0001d_ol0;03oool00`3o_g@007Bo0?oo
o`0]0?ooo`030=nLB000B9`0gooo02@0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018
W03Oool[0?ooo`030=nLB000B9`0gooo02d0oooo00<0okmd001d_`3oool0<03oool00`3ookl0M000
07Boo`0T0?ooo`00FP3oool00`3ooml0W4P0000000070000000304RLg`3oool0oooo00D0oooo00<0
omnL04P0001d_ol0703oool00`3ooml0W4P0000000070000000304RLg`3oool0oooo00@0oooo00<0
okmd04RLg`3oool0703oool00`3ooml0W4P0000000070000000304RLg`3oool0oooo00<0oooo00<0
omnL04P0B02Lgol0903oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo02/0oooo00<0
omnL04P0B02Lgol0;P3oool00`3o_g@0B9cO0?ooo`0_0?ooo`030?oOW0180000M;oo02@0oooo001[
0?ooo`040?oOW0180000001809cOobh0oooo00<0gia804RLg`3oool0:`3oool00`3ookl0M00007Bo
o`0U0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0:`3oool00`3ookl0M00007Bo
o`0_0?ooo`030=nLB018W=l0oooo02d0oooo00@0omnL04P0000004P0W=oo903oool006T0oooo00D0
omnL04P000000000000007Boo`0`0?ooo`030;md001d_ol0oooo02/0oooo00<0_g@0001d_`3oool0
903oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo02`0oooo00<0_g@0001d_`3oool0
;`3oool00`2oM000M;oo0?ooo`0Z0?ooo`050?oOW018000000000000001d_ol09@3oool006/0oooo
00<0oono07@00000M;l0<03oool00`3ogi`0B01d0;ooo`0[0?ooo`030=nLB000B9`0gooo02@0oooo
00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`0[0?ooo`030=nLB000B9`0gooo02l0oooo
00<0omnL04P0M02oool0;03oool00`3ookl0M000001d_`0U0?ooo`00K@3oool00`3OW4P007Bo0?oo
o`0^0?ooo`030?oog`2LB000M;oo02/0oooo00<0omnL04P0B02Lgol0903oool0103ooml0W4P00018
W03Oool20?ooo`030=nLB000B9`0gooo02/0oooo00<0omnL04P0B02Lgol0;`3oool00`3ooml0W4P0
07Boo`0^0?ooo`030=nLB000M;l0oooo02<0oooo001]0?ooo`030?oOW01804P0W=oo02h0oooo00<0
oono07@00018W=l0:`3oool00`3ookl0M00007Boo`0U0?ooo`030?oOW0180000M;oo0080oooo00<0
gia8001d_`3oool0:`3oool00`3ookl0M00007Boo`0_0?ooo`030?oo_`1d0000B9cO02h0oooo00<0
omnL04P0B02Lgol08`3oool006X0oooo00H0_g@007Boo`3oool0gia80000B02LgolZ0?ooo`070?no
M000B9`0gooo0?ooo`3OW4P0001809cOo`0/0?ooo`030;md0000M;l0oooo02D0oooo00H0gia80000
M02oool0oooO09a80018W=l]0?ooo`030;md0000M;l0oooo02X0oooo00L0okmd0018W03Oool0oooo
0=nLB00004P0W=oo02/0oooo00H0_g@007Boo`3oool0gia80000B02LgolS0?ooo`00J`3oool0102o
M000000000000018W=l/0?ooo`050?oOW018000000000000001d_ol0:`3oool01@3ookl0M0000000
000007@0_ooo02H0oooo00@0gia800000000000007Bo;03oool01@3ookl0M0000000000007@0_ooo
02/0oooo00D0omnL04P000000000000007Boo`0]0?ooo`040;md00000000000004RLgb@0oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo00140?ooool00000HP00
000;0?ooo`00A03oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`00
0000oooo0?ooo`2`0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool02@3oool004@0
oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00T0
oooo00140?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0ZP3oool00`000000oooo
0?ooo`090?ooo`00A03oool300000;00oooo00<000000?ooo`3oool0Z@3oool2000000/0oooo0014
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`09
0?ooo`00A03oool00`000000oooo0?ooo`1O0?ooo`D00000C03oool00`000000oooo0?ooo`2Z0?oo
o`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo05<0oooo300000050?ooo`T0
0000@`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000
003oool0oooo0500oooo0`00000J0?ooo`T00000>P3oool00`000000oooo0?ooo`2Z0?ooo`030000
003oool0oooo00T0oooo00140?ooo`030000003oool0oooo04d0oooo0`00000V0?ooo`H00000=03o
ool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0
oooo04X0oooo0`00000_0?ooo`H00000;P3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0
oooo00T0oooo00140?ooo`030000003oool0oooo04L0oooo0`00000h0?ooo`@00000:P3oool00`00
0000oooo0?ooo`2Z0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo04D0
oooo0P00000o0?ooo`@000009P3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00T0
oooo00140?ooo`030000003oool0oooo04<0oooo0P0000150?ooo`@000008P3oool00`000000oooo
0?ooo`2Z0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo0440oooo0P00
001;0?ooo`@000007P3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00T0oooo0014
0?ooo`030000003oool0oooo03l0oooo0P00001A0?ooo`@000006P3oool00`000000oooo0?ooo`2Z
0?ooo`030000003oool0oooo00T0oooo00140?ooo`<00000?@3oool2000005L0oooo0`00000G0?oo
o`030000003oool0oooo0:T0oooo0P00000;0?ooo`00A03oool00`000000oooo0?ooo`0k0?ooo`80
0000G03oool4000001<0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`090?ooo`00
A03oool00`000000oooo0?ooo`0i0?ooo`800000HP3oool4000000l0oooo00<000000?ooo`3oool0
ZP3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0g0?ooo`800000J03o
ool4000000/0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo06`0oooo0`0000080?ooo`030000003oool0
oooo0:X0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`1`0?ooo`@00000103oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo
00T0oooo00140?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0M@3oool500000:`0
oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`1j0?ooo`@00000Z@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo07/0oooo00@000000?ooo`3oool0oooo1000002U0?ooo`030000
003oool0oooo00T0oooo00140?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0O03o
ool00`000000oooo0?ooo`050?ooo`@00000X@3oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool02@3oool4
000009d0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`1m0?ooo`030000003oool0oooo00d0oooo1000002I0?ooo`030000003oool0oooo
00T0oooo00140?ooo`<00000;`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0140
oooo1000002D0?ooo`8000002`3oool004@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`1o0?ooo`030000003oool0oooo01D0oooo1000002A0?ooo`030000003oool0oooo00T0oooo
00140?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?oo
o`0I0?ooo`@00000S@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool07@3oool4000008T0oooo00<00000
0?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`220?oo
o`030000003oool0oooo0240oooo100000250?ooo`030000003oool0oooo00T0oooo00140?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`0U0?ooo`<0
0000PP3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo08<0oooo00<000000?ooo`3oool0:03oool4000007h0oooo00<000000?ooo`3oool0
2@3oool003D0oooo00D0oooO09a8000000000000001d_`0:0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0/0?ooo`<00000N`3oool00`000000oooo
0?ooo`090?ooo`00=@3oool01`3OW4P007Bo0?ooo`3ookl0M0000018W03Oool0203oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0;`3oool4000002H0
oooo1@00001<0?ooo`030000003oool0oooo00T0oooo000d0?ooo`030?oog`2LB000M;oo0080oooo
00<0omnL04P00018W=l0203oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo08D0oooo
00<000000?ooo`3oool0<`3oool3000001l0oooo100000050?ooo`T00000@`3oool00`000000oooo
0?ooo`090?ooo`00=03oool00`3ookl0M00007Boo`030?ooo`030;md000007@0_ooo00L0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo03H0oooo0P00
000H0?ooo`D000004P3oool300000400oooo00<000000?ooo`3oool02@3oool002L0oooo00<0oooO
09a8000000001`0000001P18W=l0oooo0?ooo`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol0
1`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0
>03oool200000140oooo1@00000J0?ooo`@00000?03oool00`000000oooo0?ooo`090?ooo`00=@3o
ool00`2oM000001d0;ooo`020?ooo`030=nLB00004P0W=oo00L0oooo1000000T0?ooo`030000003o
ool0oooo08P0oooo00<000000?ooo`3oool0>P3oool2000000/0oooo1000000S0?ooo`800000>03o
ool3000000/0oooo000e0?ooo`080?noM0000000B9cO0?ooo`3ooml0W4P00018W03Oool70?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0l0?ooo`<0
00001@3oool3000002T0oooo0P00000h0?ooo`030000003oool0oooo00T0oooo000e0?ooo`030?oo
g`2LB00000000080000000<0001d0;ooo`3oool01`3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo08T0oooo00<000000?ooo`3oool0?`3oool5000002h0oooo0P00000f0?ooo`030000
003oool0oooo00T0oooo000f0?ooo`030?oo_`1d000007Bo00/0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo03l0oooo1000000a0?ooo`800000=03o
ool00`000000oooo0?ooo`090?ooo`00=`3oool00`3ogi`0B00004RLg`0:0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`800000103oool2
00000340oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`090?ooo`00>03oool0103o
oml0W4P00000M02oool80?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0R`3oool0
0`000000oooo0?ooo`0k0?ooo`800000203oool3000002l0oooo0P00000a0?ooo`030000003oool0
oooo00T0oooo000j0?ooo`040?oo_`1d0000000004RLg`H0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03T0oooo0P00000=0?ooo`800000;`3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
00l0oooo0P00000^0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool004@0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03H0
oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0
oooo00140?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0:03oool@000005D0oooo
00<000000?ooo`3oool0=03oool2000001P0oooo0P00000/0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0U0?ooo`@00000403oool6000004l0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`0J0?ooo`800000:`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo0014
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool08P3oool3000000D0oooo50000000
0`3oool0000000000002000004/0oooo00<000000?ooo`3oool0<@3oool2000001l0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo00140?oo
o`<000007P3oool00`000000oooo0?ooo`0Q0?ooo`800000103oool4000000H0oooo200000060?oo
o`@0000000<0oooo0000000000000P0000170?ooo`030000003oool0oooo02l0oooo0P00000R0?oo
o`800000:P3oool00`000000oooo0?ooo`0W0?ooo`8000002`3oool004@0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0O0?ooo`800000103oool2000000@0oooo500000040?ooo`@0
000000<0oooo000000000000A@3oool00`000000oooo0?ooo`0]0?ooo`8000009P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool004@0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`800000103oool2000000<0oooo
700000030?ooo`80000000<0oooo000000000000@`3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703o
ool2000000@0oooo0P0000000`3oool000000000000:00000080oooo700000110?ooo`030000003o
ool0oooo02X0oooo0P00000[0?ooo`800000:@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00T0oooo00140?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`020?ooo`80000000<0oooo0000000000008P0000000`3oool0000000000007
000003l0oooo00<000000?ooo`3oool0:03oool2000002l0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00/000000`3oool8000000D0oooo300000001@3oool00000000000000000oooo00D00000?@3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06P3oool2000000<0oooo20000000103oool000000000003oool7
000000P0oooo1`0000040?ooo`d000000P3oool3000003/0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool00P3oool7000000030?ooo`000000000000<000005P3oool40000
00@0oooo200000000`3oool00000000000020?ooo`<00000>@3oool00`000000oooo0?ooo`0T0?oo
o`800000=P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool02@3oool004@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`04
0000003oool0oooo0?ooo`L0000000<0oooo0000000000000P0000070?oooa4000001@3oool50000
00030?ooo`000000000000H0000000D0oooo00000000000000000?ooo`03000003L0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo01L0oooo0P0000020?ooo`L0000000<0oooo0000000000000P0000050?oo
o`@000004@3oool4000000H0oooo1`000000103oool000000000000000020?ooo`80000000@0oooo
0000000000000000=@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00T0oooo0014
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool05P3oool01P000000oooo0?ooo`3o
ool000000?ooo`T000001@3oool2000001T0oooo0`0000070?ooo`D0000000@0oooo000000000000
00000P3oool2000000040?ooo`0000000000000003<0oooo00<000000?ooo`3oool0803oool20000
03d0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
00T0oooo00140?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool05P3oool01P000000
oooo0?ooo`3oool000000?ooo`@0000000@0oooo0000003oool00000103oool3000001h0oooo0`00
00060?ooo`T000000P3oool2000000040?ooo`000000000000000340oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`090?ooo`00A03oool3000001T0oooo00<000000?ooo`3oool05@3o
ool01P000000oooo0?ooo`3oool000000?ooo`P000000`3oool2000002@0oooo0P0000070?ooo`P0
00000P3oool2000000040?ooo`0000000000000002l0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool07P3oool20000
00/0oooo00140?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0503oool01P000000
oooo0?ooo`3oool000000?ooo`L000000`3oool2000002P0oooo0`0000060?ooo`P000000P3oool0
0`000000oooo0?ooo`03000002d0oooo00<000000?ooo`3oool0703oool2000002T0oooo4`000008
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`09
0?ooo`00A03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01D0oooo00D000000?oo
o`3oool000000?ooo`04000000030?ooo`000000oooo0080oooo0P00000]0?ooo`<000001@3oool8
000000030?ooo`00000000000080oooo0`00000[0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0903oool5000001<0oooo100000050?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo01@0oooo00D000000?ooo`3oool000000?ooo`04000000030?ooo`000000
oooo0080oooo00<000000?ooo`3oool0<03oool2000000D0oooo1`0000020?ooo`80000000@0oooo
0000000000000000:P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01l0oooo1P00
000L0?ooo`<000000`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0D
0?ooo`050000003oool0oooo0000003oool01P0000020?ooo`800000=@3oool2000000D0oooo1`00
00020?ooo`80000000@0oooo0000000000000000:03oool00`000000oooo0?ooo`0H0?ooo`800000
7@3oool5000002D0oooo0P0000020?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo01<0oooo00D000000?ooo`3oool000000?ooo`05000000<0oooo00<000000?ooo`3oool0
3P3ooolB000001L0oooo0P0000050?ooo`L000000P3oool2000000040?ooo`0000000000000002H0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0J0?ooo`<00000;03oool200000003
0?ooo`000000oooo02@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`090?ooo`00
A03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0
00000?ooo`05000000<0oooo00<000000?ooo`3oool03@3oool200000180oooo1000000E0?ooo`80
0000103oool800000080oooo00<000000?ooo`0000000`00000T0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0603oool300000340oooo0P00000U0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0C0?ooo`050000003oool0oooo0000003oool0100000030?ooo`030000003oool0oooo00/0
oooo0`00000H0?ooo`<00000503oool2000000@0oooo20000000103oool000000000003oool30000
02<0oooo00<000000?ooo`3oool0503oool2000001T0oooo0P00000f0?ooo`800000903oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`000000oooo00@000000`3oool00`00
0000oooo0?ooo`0:0?ooo`8000007P3oool400000180oooo0P0000030?ooo`T0000000<0oooo0000
003oool01000000Q0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05P3oool30000
03T0oooo0`00000R0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool02@3oool004@0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`050000003oool0oooo0000
003oool0100000020?ooo`8000002`3oool2000002@0oooo0`00000A0?ooo`8000000`3oool;0000
00030?ooo`000000oooo008000007`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
01@0oooo0`00000m0?ooo`030000003oool000000280oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140
oooo00@000000?ooo`3oool0oooo0`0000001@3oool000000?ooo`3oool0000000/0oooo0P00000Y
0?ooo`8000004@3oool2000000<0oooo200000000`3oool000000?ooo`05000001d0oooo00<00000
0?ooo`3oool0403oool2000001@0oooo0`0000110?ooo`040000003oool0000000000200oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`090?ooo`00A03oool3000001D0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`06000000030?ooo`000000oooo00T0oooo0P00000]
0?ooo`8000004@3oool010000000oooo0?ooo`3oool;000000030?ooo`000000oooo00<000006`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo0`0000150?ooo`040000003o
ool0oooo00000200oooo00<000000?ooo`3oool05`3oool2000000/0oooo00140?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`06000000030?ooo`00
0000oooo00T0oooo00<000000?ooo`3oool04P3oool7000001H0oooo0P00000@0?ooo`8000000`3o
ool8000000050?ooo`000000oooo0000003oool00`00000J0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03`3oool300000380oooo3@0000090?ooo`050000003oool0oooo0?ooo`00
00007`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`05000000030?oo
o`000000oooo00T0oooo00<000000?ooo`3oool02`3oool8000000L0oooo1@00000C0?ooo`800000
403oool010000000oooo0?ooo`3oool8000000040?ooo`000000000000000080oooo0`00000H0?oo
o`030000003oool0oooo00`0oooo0P00000?0?ooo`<00000<@3oool4000000d0oooo1@0000050?oo
o`050000003oool0oooo0?ooo`0000007`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00T0oooo00140?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0500000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?oo
o`800000503oool300000180oooo0P00000?0?ooo`8000000`3oool8000000050?ooo`0000000000
0000003oool00`00000G0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool3
00000340oooo0`00000F0?ooo`<000000`3oool010000000oooo0?ooo`3oool2000001d0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0140oooo00@000000?ooo`000000oooo100000000`3oool000000?oo
o`080?ooo`030000003oool0oooo00T0oooo0P00000I0?ooo`<000004@3oool2000000l0oooo00H0
00000?ooo`3oool0oooo0000003oool6000000040?ooo`000000000000000080oooo0`00000E0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool400000340oooo0`00000L0?oo
o`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00D0000000<0oooo0000003oool0203oool00`000000
oooo0?ooo`080?ooo`8000007P3oool300000100oooo0P00000>0?ooo`8000000P3oool800000080
oooo0P0000020?ooo`@000004`3oool00`000000oooo0?ooo`080?ooo`8000002@3oool3000003<0
oooo0P00000Q0?ooo`<000001@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0@0?ooo`040000003oool000000?ooo`<0000000<0oooo0000003oool01`3oool2000000T0
oooo0P00000S0?ooo`800000403oool2000000h0oooo00H000000?ooo`3oool0oooo0000003oool6
000000030?ooo`000000000000<0oooo0`00000B0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01P3oool3000003D0oooo00<000000?ooo`3oool08`3oool2000000D0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo000g0?oo
o`030?oog`2LB000B9cO00X0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00D0000000<0oooo0000003oool01P3oool00`000000oooo0?ooo`070?oo
o`8000009`3oool200000100oooo0P00000=0?ooo`8000000P3oool800000080oooo00<000000?oo
o`3oool00P3oool300000100oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?oo
o`<00000=P3oool2000002L0oooo0`0000040?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`090?ooo`00>03oool00`3OW4P004RL0=ooo`090?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0403oool00`000000oooo0000000400000003
0?ooo`000000oooo00H0oooo00<000000?ooo`3oool01P3oool2000002/0oooo0P00000@0?ooo`03
0000003oool0oooo00`0oooo00@000000?ooo`3oool0oooo200000000`3oool00000000000030?oo
o`<000003`3oool00`000000oooo0?ooo`040?ooo`800000103oool3000003L0oooo0P00000Z0?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00T0oooo000h0?ooo`030?oOW01804P0W=oo00T0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0000000<0oooo0000003o
ool01P3oool00`000000oooo0?ooo`050?ooo`800000;`3oool2000000l0oooo0P00000=0?ooo`06
0000003oool0oooo0?ooo`000000oooo0P0000001@3oool00000000000000000oooo00800000103o
ool3000000d0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool3000003P0oooo
0P00000/0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00T0oooo000d0?ooo`030?noM0000000000000@00000
00<004RL0=ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`000000100000000`3oool000000?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0<@3oool2000000l0oooo00<000000?ooo`3oool02`3oool200000080oooo
200000020?ooo`030000003oool0oooo0080oooo0`00000<0?ooo`030000003oool0oooo0080oooo
1@00000i0?ooo`800000;`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`090?ooo`009`3oool00`3ooml0W4P0
000000070000000604RLg`3oool0oooo0?oog`2LB4P0W=oo0P3oool00`2oM00007Bo0?ooo`080?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040000
00030?ooo`000000oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`3oool8
000000030?ooo`000000000000@0oooo0`00000:0?ooo`030000003oool0oooo00<00000>`3oool2
00000340oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`0I0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool02@3oool003D0oooo00L0oono07@0M02oool0oooo0?no
M000B9`0gooo00P0oooo1000000@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`000000
100000000`3oool000000?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
=P3oool2000000h0oooo0P00000=0?ooo`060000003oool0oooo0?ooo`000000oooo0P0000001@3o
ool00000000000000000oooo00800000103oool3000000T0oooo0`00000m0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000I0?ooo`030000003oool0
oooo0180oooo0`00000;0?ooo`00=P3oool01P3ogi`0B4RL0=ooo`3ogi`0B01809cOo`P0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0000000<0000000<0
oooo0000003oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo0?ooo`/00000
1@3oool3000000<0oooo1P00000l0?ooo`800000=@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0000001P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`00=`3o
ool01@3o_g@007Bo0?oog`2LB000B9cO00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0000000@0000000<0oooo0000003oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo03/0oooo0P00000>0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool;000000@0oooo1@0000030?ooo`800000?03oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo00<0oooo0P00000I0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool02@3oool003P0oooo00@0gia804RLg`2oM00007Bo203oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000000`0000000`3oool00000
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?P3oool2000000d0oooo
0P00000<0?ooo`8000000`3oool00`000000oooo0000000<000000040?ooo`000000000000000080
oooo00<000000?ooo`000000>`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00@0
oooo0P00000H0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02@3oool003T0oooo
00@0gia807AdM00007@0_ooo1`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`000000100000000`3oool000000?ooo`030?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0@03oool2000000d0oooo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`3oool;000000D0oooo00@000000?ooo`00000000000P3oool00`000000oooo0?ooo`0g
0?ooo`800000>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000001L0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`00>P3oool00`2oM000001809cOo`070?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool03P3oool00`000000oooo000000030000
00030?ooo`000000oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo000000080000
00030?ooo`000000000000800000103oool2000000040?ooo`000000oooo000003P0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`040?ooo`800000603oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00T0oooo000j0?ooo`030?oog`2LB000B9cO00L0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000@0000000<0oooo0000
003oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04D0oooo0P00000<0?oo
o`8000001`3oool6000000@0oooo00<000000?ooo`0000001P0000001@3oool000000?ooo`3oool0
00000080oooo00@000000?ooo`0000000000=P3oool2000003l0oooo00<000000?ooo`3oool0103o
ool2000001L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000000`000000
0`3oool000000?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`0;0?ooo`L000001P3oool2000000<0oooo00<000000?ooo`0000001P000000
0`3oool00000000000040?ooo`040000003oool00000000003@0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0100000000`3oool000000?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`040?ooo`P000003@3oool0
10000000oooo0?ooo`3oool7000000040?ooo`0000000000000000D0oooo0P0000000`3oool00000
0000000a0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool2000001L0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000000`0000000`3oool000000?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0B@3oool8000000P0oooo0P00
000<0?ooo`030000003oool0oooo0080oooo200000000`3oool00000000000040?ooo`8000000P3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01@3o
ool2000001H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000000`000000
0`3oool000000?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A03oool6
000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0080oooo2@0000000`3oool000000?ooo`020?ooo`030000003oool000000080oooo0P00000[
0?ooo`800000AP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`000000100000000`3oool000000?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0?`3oool6000000X0oooo0P00000=0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool7000000040?ooo`000000oooo
00000080oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`090?ooo`00A03oool3000000h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo00000003000000030?ooo`000000oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`D00000603oool500000180oooo00<000000?oo
o`3oool02`3oool2000000/0oooo0P0000030?ooo`80000000<0oooo0000000000000P0000001P3o
ool000000?ooo`000000oooo000000@0oooo00<000000?ooo`3oool00P00000V0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00l0oooo0P00000;0?ooo`00A03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`0000000`0000000`3oool000000?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool06P3oool4000000D0oooo1@00000>0?ooo`D00000603oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo0`0000020?ooo`030000003oool0
000000D0000000<0oooo0000000000001@3oool010000000oooo0?ooo`3oool2000002<0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000000`0000000`3oool000000?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool2000000h0oooo1@000006
0?ooo`<000007P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo0P000004
0?ooo`P0000000<0oooo0000000000001@3oool2000000<0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0303oool00`000000oooo00000003000000030?ooo`000000oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`<000005@3oool60000
0280oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo
000000@0oooo0P0000000`3oool0000000000004000000030?ooo`000000oooo00D0oooo00@00000
0?ooo`3oool0oooo0P00000M0?ooo`800000CP3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000000`000000
0`3oool000000?ooo`030?ooo`050000003oool0oooo0?ooo`0000005`3oool2000001T0oooo0P00
00000`3oool000000000000S0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000000`3oool000000000
0004000000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000080000000<0oooo
0000003oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo0P00000I
0?ooo`8000001@3oool200000280oooo0P00000=0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`80000000<0oooo00000000000010000000
0`3oool00000000000050?ooo`8000000`3oool2000001P0oooo00<000000?ooo`3oool0:`3oool>
000001H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0000000<0000000<0oooo0000003oool00`3oool01@00
0000oooo0?ooo`3oool0000001D0oooo00<000000?ooo`3oool05`3oool2000000T0oooo0P00000R
0?ooo`030000003oool0oooo00/0oooo0P0000020?ooo`030000003oool0oooo00H0oooo0P000003
0?ooo`80000000D0oooo00000000000000000?ooo`0200000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0:P3o
ool2000000h0oooo0P00000E0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo00000004000000@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`800000603oool2000000d0oooo0P00000Q
0?ooo`030000003oool0oooo00`0oooo0P00000;0?ooo`040000003oool0oooo0?ooo`80000000<0
oooo0000000000001@0000000`3oool000000?ooo`050?ooo`030000003oool0oooo0080oooo0P00
000C0?ooo`030000003oool0oooo02P0oooo0`00000B0?ooo`<000004P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`090?ooo`00A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`0000000P0000000`3oool000000?ooo`030?ooo`050000003oool0oooo0?ooo`0000004`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00l0oooo0P00000P0?ooo`030000003o
ool0oooo00/0oooo0P00000<0?ooo`040000003oool0oooo0?ooo`80000000<0oooo000000000000
1@0000000`3oool00000000000050?ooo`800000103oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo02L0oooo0P00000H0?ooo`8000004@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`00A03o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`0000000`00
00000`3oool000000?ooo`030?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo
0?ooo`0F0?ooo`800000503oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00T0oooo
00@000000?ooo`3oool00000303oool010000000oooo0?ooo`3oool3000000030?ooo`0000000000
00@000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P00000?0?oo
o`030000003oool0oooo02@0oooo0`00000L0?ooo`8000003`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?oo
o`00A03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`00
0000100000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo0P00000O0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo0?oo
o`<0000000D0oooo00000000000000000?ooo`0200000080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`800000303oool00`000000oooo0?ooo`0S0?ooo`8000008@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo0P00000D0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool000000080000000<0oooo0000003oool00`3oool01@00
0000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool0503oool2000001X0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02P3oool020000000oooo0?ooo`3oool000000?ooo`000000oooo0`0000000`3oool0
0000000000020?ooo`030000003oool0oooo00@0oooo0P0000050?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool08P3oool2000002@0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`090?ooo`00A03oool3000000`0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`04000000D0oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000003oool0oooo01<0
oooo0P00000M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool00P3oool2000000P0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02000000030?ooo`000000oooo00<0
000000D0oooo00000000000000000?ooo`02000000H0oooo00<000000?ooo`3oool00`3oool20000
00L0oooo00<000000?ooo`3oool08@3oool2000002L0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0303oool20000
00/0oooo00140?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000
oooo00000004000000@0oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool07P3oool2000001h0oooo0P0000000`3oool000000?ooo`0:0?oo
o`030000003oool0oooo00X0oooo0`0000001@3oool000000?ooo`000000oooo00L000000P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`030?ooo`050000003oool0oooo
0?ooo`000000403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0240oooo0P00000N
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool01`000000oooo0?ooo`00
0000oooo0000003oool0100000000`3oool00000000000020?ooo`030000003oool0oooo00@0oooo
0P0000050?ooo`8000000P3oool00`000000oooo0?ooo`0P0?ooo`800000;03oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`04000000@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0000000d0oooo0P00000;0?ooo`8000000P3o
ool010000000oooo0000003oool4000000030?ooo`00000000000080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`8000008P3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool200000180oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`000000100000040?ooo`050000003oool0oooo0?ooo`000000
3`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
603oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`3oool0203oool00`000000
oooo000000020?ooo`040000003oool000000?ooo`@0000000<0oooo0000000000000P3oool20000
00H0oooo00<000000?ooo`3oool0103oool2000001l0oooo0P00000a0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool000000080000000<0oooo0000003oool00`3oool01@000000
oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000P3oool010000000oooo0000003o
ool4000000030?ooo`000000000000<0oooo00<000000?ooo`3oool0103oool2000000<0oooo00<0
00000?ooo`3oool00P00000L0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`0000002@0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0100000040?ooo`050000003oool0oooo0?ooo`0000003P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`000000
0`0000000`3oool00000000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool2000001L0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo00000004000000@0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo0P0000001P3oool000000?ooo`3oool000000?ooo`@0000000<0oooo0000
000000000P3oool2000000@0oooo00@000000?ooo`00000000001`3oool2000001@0oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo0P00000A
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool000000080000000<0oooo0000
003oool00`3oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`0000000P3oool00`000000oooo00000003000000030?ooo`000000000000<0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo0014
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo00000002
000000030?ooo`000000oooo0080oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0<@3oool2000000d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo000000020?ooo`030000003oool0000000<0000000<0oooo0000000000000`3o
ool2000000H0oooo00<000000?ooo`3oool01P3oool2000000l0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo00000003000000@0oooo00D00000
0?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`080?ooo`800000403oool00`000000oooo0?ooo`0=0?ooo`050000003o
ool0oooo0?ooo`0000002@3oool2000000<0oooo00<000000?ooo`0000000`0000000`3oool00000
000000030?ooo`030000003oool0oooo00D0oooo0P0000080?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo
00140?ooo`<000002P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000@00000103o
ool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
3@3oool010000000oooo0?ooo`00000:0?ooo`8000000`3oool00`000000oooo0000000300000007
0?ooo`00000000000?ooo`000000oooo000000080?ooo`030000003oool0oooo00H0oooo0P000009
0?ooo`800000@03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`8000002`3oool004@0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool000000080000000<0oooo0000
003oool00P3oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0000000/0oooo0P0000030?ooo`030000003oool0
000000<0000000<0oooo0000000000000`3oool2000000L0oooo00<000000?ooo`3oool01`3oool2
000000H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00T0oooo00140?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo00000002000000030?ooo`000000oooo0080oooo00D000000?ooo`3oool0oooo0000000<
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03P3oool2000000`0oooo0P000003
0?ooo`030000003oool0000000H00000103oool00`000000oooo0?ooo`050?ooo`8000002@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`070?ooo`800000403oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00T0oooo00140?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo00000003000000@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo03/0oooo00@000000?ooo`3oool00000603oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00/0oooo0P0000030?ooo`030000003oool0000000L000000`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo0P0000000`3oool000000?oo
o`140?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`H00000103oool010000000oooo0?ooo`00
000<0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0?@3oool2000001X0oooo00<0
00000?ooo`3oool03@3oool2000000h0oooo00@000000?ooo`3oool0oooo1`0000000`3oool00000
000000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool004@0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`H000000`3oool01@000000oooo0?oo
o`3oool0000000`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0m0?ooo`800000
6`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool0
oooo1`0000000`3oool00000000000030?ooo`030000003oool0oooo00H0oooo0P0000070?ooo`03
0000003oool0000004H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`00
A03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000
0P0000000`3oool000000?ooo`020?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo03d0oooo00@000000?ooo`3oool000006P3oool00`00
0000oooo0?ooo`0<0?ooo`040000003oool0oooo000000h0oooo00D000000?ooo`3oool000000?oo
o`06000000030?ooo`000000000000<0oooo0P0000080?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool0oooo0P0000150?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1`3oool200000100oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`00=03o
ool00`3OW4P00000000000030000000304RLg`3oool0oooo00L0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000<00000103oool010000000oooo0?oo
o`00000<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02`3oool01@000000oooo
0?ooo`3oool0000000h0oooo0P0000030?ooo`H0000000<0oooo000000000000103oool00`000000
oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool200000100oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`00=@3oool00`3o_g@007Bo0?ooo`020?ooo`03
0;mdM02oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0000000<00000103oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo0P0000040?ooo`80000000D0oooo00000000000000000?ooo`02000000@0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo000000080?ooo`800000703oool9000001h0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`800000403oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00T0oooo000f0?ooo`030?noM000M;l0oooo00/0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`H000000`3oool01@000000oooo0?ooo`3oool0
000000/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`0000040?ooo`80000000D0
oooo00000000000000000?ooo`02000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo01<0oooo1P0000090?ooo`<000006`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00P0oooo0P00000@0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool003L0oooo00<0okmd001d_`3oool02P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00X0oooo1P0000030?ooo`050000003oool0oooo0?ooo`000000
2`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo0P0000030?ooo`800000
00D0oooo00000000000000000?ooo`02000000@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0000000;0?ooo`030000003oool0oooo00l0oooo0`00000B0?ooo`8000006P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo0P00000@0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool002L0oooo00<0oooO09a8000000001`0000000`18W=l0oooo
0?ooo`040?ooo`030?noM018W=l0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`H000000`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`80000000D0oooo00000000
000000000?ooo`02000000@0oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000002`3oool2
000000d0oooo0P00000G0?ooo`800000603oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00L0oooo0P00000@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
03T0oooo00<0gia804RLg`3oool0203oool4000000P0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo00000003000000@0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000000`3oool2000000050?ooo`000000
00000000003oool00`0000040?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`080?ooo`8000006`3oool00`000000oooo0?ooo`0F0?ooo`050000003o
ool0oooo0?ooo`0000002@3oool200000100oooo00<000000?ooo`3oool01`3oool3000000/0oooo
000j0?ooo`030;md001d_ol0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0000000<000000`3oool01@000000oooo0?ooo`3oool0000000/0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000<0oooo
0P000000103oool000000000000000020?ooo`800000103oool2000000H0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`050?ooo`8000007P3oool00`000000oooo0?ooo`0E0?ooo`05
0000003oool0oooo0?ooo`0000002@3oool00`000000oooo0000000?0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02@3oool003X0oooo00<0omnL04P0M02oool01`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000000`0000030?ooo`05
0000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00000:0?ooo`030000003oool0
000000<0oooo0P0000000`3oool0000000000002000000030?ooo`000000000000<0oooo0P000007
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool200000240oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo0P00000?
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool003X0oooo00<0oooO09a8
001d_ol01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo1P0000030?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00T0oooo0P00000<0?ooo`030000003oool0000000<0oooo0P000000
1P3oool000000000003oool000000?ooo`80000000D0oooo0000003oool0oooo000000070?ooo`03
0000003oool0oooo00X0oooo00@000000?ooo`0000000000603oool2000000X0oooo00<000000?oo
o`3oool0503oool01@000000oooo0?ooo`3oool0000000T0oooo0P00000@0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool003X0oooo00<0oono07@00018W=l01`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo1P0000030?ooo`040000003oool0oooo
000000/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00T0oooo0P00000<0?ooo`040000003oool0oooo000000<0oooo0P0000001P3oool000000000
003oool000000?ooo`800000103oool2000000H0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0C0?ooo``000001P3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?oo
o`0000002@3oool200000100oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?oo
o`00=P3oool01`3o_g@004RL0=ooo`3oool0gia80000B02Lgol01`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00X0oooo1P0000020?ooo`050000003oool0oooo0?ooo`0000002P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203o
ool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo008000000P3oool200000080oooo
00<000000?ooo`0000000`0000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
203oool010000000oooo00000000000?0?ooo`@000002P3oool4000000D0oooo00<000000?ooo`3o
ool04P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`0000003`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo000g0?ooo`050?oOW018000000000000
001d_ol0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo1@0000030?oo
o`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000`0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`8000000P3oool3000000030?ooo`000000000000D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`800000103oool00`000000oooo
0?ooo`0:0?ooo`@000003P3oool4000000@0oooo00<000000?ooo`3oool04@3oool01@000000oooo
0?ooo`3oool0000000T0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo00000003000000<0oooo00@000000?ooo`3oool000002`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo000000020?oo
o`80000000H0oooo000000000000oooo0000003oool3000000@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3o
ool400000180oooo0`0000040?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo
000000090?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`0000000`0000030?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
603oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P0000020?ooo`<0
000000@0oooo0000003oool00000103oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0000001H0oooo0P000003
0?ooo`030000003oool0oooo0140oooo00D000000?ooo`3oool0oooo000000090?ooo`8000003`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool6000000<0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
0P0000020?ooo`<0000000@0oooo0000003oool00000103oool00`000000oooo0?ooo`040?ooo`<0
00002`3oool00`000000oooo0?ooo`020?ooo`80000000<0oooo0000003oool05`3oool300000080
oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0000000T0oooo0P00000@0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`090?ooo`H000000`3oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool500000080oooo0`000000103o
ool000000?ooo`0000040?ooo`030000003oool0oooo00<0oooo0P00000=0?ooo`050000003oool0
00000000003oool00P00000J0?ooo`8000000`3oool00`000000oooo0?ooo`0?0?ooo`050000003o
ool0oooo0?ooo`0000002@3oool200000100oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo1P00
00020?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0603oool00`000000oooo
000000060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool010000000oooo
0?ooo`3oool2000000030?ooo`00000000000080000000P0oooo00000000000000000?ooo`000000
oooo000000@0oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo00/0oooo00@0
00000?ooo`3oool000007@3oool200000080oooo00<000000?ooo`3oool03`3oool01@000000oooo
0?ooo`3oool0000000T0oooo0P00000@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool02@3oool001<0oooo00<0oono07Ad_`3oool0;P3oool3000000P0oooo00<000000?ooo`3oool0
2@3oool5000000<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0H0?ooo`80
00001P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`00
00000P3oool2000000050?ooo`000000oooo0000003oool00`0000000`3oool00000000000020000
00<0oooo0P0000050?ooo`030000003oool0oooo00T0oooo00@000000?ooo`00000000007`3oool0
1@000000oooo0?ooo`3oool000000140oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0000000?0?ooo`030000003oool0oooo00H0oooo0P00000;0?ooo`004`3oool0103ogi`0B0000000
B02Lgol]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool5000000<0oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000@0
oooo00H000000?ooo`000000oooo0000003oool300000080oooo00<000000?ooo`0000000P3oool2
000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02000000L0oooo2000000A
0?ooo`050000003oool0oooo0?ooo`000000403oool010000000oooo0?ooo`0000090?ooo`030000
003oool0000000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`005@3o
ool00`2oM000000000000003000000030000M02oool0oooo02H0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`D000000`3oool010000000oooo0?ooo`00000:0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo01P0oooo0P0000030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`030?ooo`80000000D0oooo0000003oool000000?ooo`0300000080
oooo00@000000?ooo`00000000000P3oool2000000@0oooo00<000000?ooo`3oool01P3oool01P00
0000oooo0?ooo`000000oooo00000080oooo1@0000080?ooo`@000003@3oool200000080oooo00<0
00000?ooo`3oool03P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0000000l0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`3ogi`0B00007Bo
o`0X0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool5000000<0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0G0?ooo`8000000`3oool00`000000oooo
0?ooo`0@0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo000000050?ooo`800000
00D0oooo0000003oool000000?ooo`0300000080oooo00<000000?ooo`000000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool20000
0140oooo0P00000<0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo00000009
0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`09
0?ooo`00603oool00`3OW4P0001d0;ooo`0Y0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02@3oool00`000000oooo00000003000000<0oooo00@000000?ooo`3oool000002P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0F0?ooo`050000003oool000000?ooo`0000004P3oool4000000060?ooo`00
000000000000003oool000000`3oool00`000000oooo0?ooo`030?ooo`80000000D0oooo0000003o
ool000000?ooo`04000000040?ooo`000000oooo000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo0P0000000`3oool000000?oo
o`060?ooo`/0000000<0oooo0000000000002P3oool200000080oooo00<000000?ooo`3oool03P3o
ool010000000oooo0?ooo`0000090?ooo`8000003`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00T0oooo000C0?ooo`060?oOW01804P0W=oo0?noM0000000B9cO:`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000000`0000030?ooo`04
0000003oool0oooo000000X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool05@3oool010000000oooo0?ooo`00000A
0?ooo`800000103oool010000000oooo0?ooo`3oool3000000<0oooo00<000000?ooo`3oool00P3o
ool020000000oooo0000003oool000000?ooo`000000oooo0`0000020?ooo`040000003oool00000
000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`@00000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo0P0000000`3oool000000?oo
o`090?ooo`8000000P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000T0oooo
0P00000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool001<0oooo00@0
omnL04P00000000007Bo;@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`0000000`0000030?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`02000000h0oooo0P0000070?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000001@3oool010000000oooo0000003oool700000080oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`8000000P3oool2000000P0oooo
00<000000?ooo`3oool0300000040?ooo`<000002@3oool200000080oooo00<000000?ooo`3oool0
3P3oool00`000000oooo000000090?ooo`8000003`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0000000300000080oooo00D000000?ooo`3oool0oooo000000090?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo01@0oooo00D000000?ooo`000000oooo0000000=0?ooo`030000003oool0oooo00P0
oooo0P0000040?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000P0000020?oo
o`@000000P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo0?ooo`D000002@3o
ool4000000/0oooo0P0000040?ooo`8000002@3oool01@000000oooo0?ooo`3oool0000000l0oooo
00<000000?ooo`0000002@3oool2000000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`0000000P0000030?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0R0?ooo`L000002P3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo01<0oooo0P0000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool010000000oooo0000000000030?ooo`80000000<0oooo0000003oool00`3oool200000080
oooo0P0000020?ooo`80000000D0oooo0000003oool0oooo000000020?ooo`040000003oool0oooo
0?ooo`@0000000<0oooo000000000000203oool4000000<0oooo2@0000030?ooo`8000000`3oool2
000000P0oooo0P0000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000002@3oool2
000000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`005P3oool01P3O
W4P00000000000000000001809cOobP0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`090?ooo`030000003oool00000008000000`3oool010000000oooo0?ooo`00000:0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0C0?ooo`800000
103oool00`000000oooo0?ooo`060?ooo`800000303oool010000000oooo0?ooo`3oool;00000003
0?ooo`000000oooo00<0oooo1`0000020?ooo`80000000<0oooo0000000000000`0000030?ooo`80
00001@3oool4000000030?ooo`000000000000/0000000<0oooo0000000000000P0000000`3oool0
0000000000020?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000003`3oool00`00
0000oooo000000090?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`090?ooo`00503oool02@3ookl0M00004RLg`3ogi`0W;oo0?ooo`3OW4P004RL0=oo
o`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool5000000<0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01l0oooo
0P0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00`0000000@0oooo0000003oool000000P3oool:0000
00030?ooo`000000000000d0000000<0oooo0000000000000P0000030?ooo`030000003oool0oooo
00H0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000000T0oooo00<00000
0?ooo`0000003P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo000D0?oo
o`090;mdM02oool0oooo0?noW02Lgol0oooo0?oo_`1d07@0_ooo02L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`090?ooo`D000000`3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0@0?ooo`80
00001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool0oooo100000020?ooo`040000003oool0000000000080oooo0P0000001@3oool000000000
00000000oooo00@0000000<0oooo0000000000001000000;0?ooo`<0000000@0oooo000000000000
00000`3oool00`000000oooo0?ooo`050?ooo`8000000P3oool00`000000oooo0?ooo`0=0?ooo`80
00002P3oool2000000h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`00
4`3oool02@3ogi`0W;oo0?ooo`3ooml0W7BL0=ooo`3oool0omnL04Qd_`0X0?ooo`<000001`3oool0
0`000000oooo0?ooo`090?ooo`D000000`3oool010000000oooo0?ooo`00000:0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool04`3oool4000000P0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0403o
ool2000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo0?ooo`80000000<0oooo0000000000002@0000030?ooo`8000000P3oool5000000<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`D000000P3oool2000000L0oooo
00@000000?ooo`3oool000003`3oool2000000X0oooo0P00000?0?ooo`030000003oool0oooo00D0
oooo0P00000;0?ooo`004`3oool02@3o_i`0W=oo0?ooo`2oM000M;oo0?ooo`3OW4P0001d0;ooo`0X
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool5000000<0oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo0`00
00040?ooo`8000001@3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo00000300oooo
00<000000?ooo`3oool03P3oool00`000000oooo000000080?ooo`050000003oool0oooo0?ooo`00
0000303oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0000000`0000000<0oooo0000
000000000`0000050?ooo`L0000000<0oooo0000000000000`0000030?ooo`D000000P3oool00`00
0000oooo0?ooo`050?ooo`80000000<0oooo0000003oool03P3oool2000000X0oooo0P00000?0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool001<0oooo00@0oono07@00000
0000M;oo;@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo1@0000030?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00L0oooo0P0000020?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`000000<@3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000T0oooo00<0
00000?ooo`000000303oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool0103oool2000000<0oooo4P0000030?ooo`@000000P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0080oooo0`0000030?ooo`030000003oool0oooo00D0oooo
00@000000?ooo`3oool000003P3oool2000000X0oooo0P00000?0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`090?ooo`D000000`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool000000140
oooo0P00000b0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool000002@3oool20000
00`0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool01@3oool010000000oooo0?ooo`3oool3000000030?ooo`000000000000h000001@3o
ool;00000080oooo0P0000020?ooo`@000000P3oool00`000000oooo0?ooo`050?ooo`040000003o
ool0oooo000000h0oooo0P00000:0?ooo`8000003`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0000000300000080oooo00D000000?ooo`3oool0oooo000000090?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0:0?ooo`050000
003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000080?ooo`030000003oool00000
00<0oooo2@0000020?ooo`/000000P3oool00`000000oooo0?ooo`060?ooo`8000000P3oool00`00
0000oooo0?ooo`03000000<0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000>
0?ooo`030000003oool0000000T0oooo0P00000?0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool02@3oool001L0oooo00H0okmd00000000000000000000M02ooolW0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0000000300000080oooo00D0
00000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0<0?ooo`<00000403oool2000003<0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo0P0000090?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000080?ooo`<0
00000`3oool2000000T0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`070?oo
o`040000003oool0oooo00000080oooo0`0000020?ooo`030000003oool0oooo00@0oooo0P000000
0`3oool000000?ooo`0=0?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo000?0?ooo`060;nLW03Oool0oooo
0?ooo`3ogi`0B0000`0000001000B9`0gooo0?oo_`1dM;lX0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0000000300000080oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`000000=03oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool01000
0000oooo0?ooo`0000070?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00@000000?ooo`3oool0oooo0`00000<0?ooo`@00000
203oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo00000080oooo0P0000020?ooo`80
00001P3oool00`000000oooo0000000>0?ooo`030000003oool0000000X0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo000>0?ooo`030?oo
g`2LB000000000<0000000<007Bo0?ooo`3oool00P3oool00`3o_g@0001d0;ooo`0X0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0000000300000080oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool010000000oooo0?ooo`00000d0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000001@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo3P0000060?ooo`050000003o
ool0oooo0000003oool00`0000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0
00003@3oool00`000000oooo0000000:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`090?ooo`003P3oool00`3ookl0M00004RLg`0c0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0000000300000080oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0
oooo00D000000?ooo`3oool0oooo0000000e0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo1@00000F0?oo
o`030000003oool0oooo00@0oooo0P000000103oool000000?ooo`3oool2000000D0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo10000003
0?ooo`80000000<0oooo0000003oool00P0000020?ooo`030000003oool0oooo00@0oooo00@00000
0?ooo`3oool000003@3oool00`000000oooo0000000:0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000000`0000020?ooo`040000003oool0
oooo000000X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0<`3oool200000080oooo0P0000070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`050?ooo`@000001`3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool2000000<0oooo00@000000?ooo`000000oooo0`0000000`3oool000000?ooo`050?ooo`040000
003oool0oooo000000d0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool001H0oooo00H0omnL04P000000000
00000000B02LgolX0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0000000300000080oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0e
0?ooo`<00000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo0?ooo`8000000P3o
ool2000000030?ooo`000000000000H0oooo00<000000?ooo`0000003@3oool00`000000oooo0000
000:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`090?ooo`005@3oool00`2oM000000007Boo`020?ooo`030?oog`2LM9`0gooo02L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000<000000P3oool0
10000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3o
ool01`000000oooo0?ooo`000000oooo0000003oool00P0000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`0000003@3oool00`000000oooo0000000:0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`00503oool00`3OW4P0B9cO
0?ooo`040?ooo`030=nLW02oool0oooo02H0oooo0`0000060?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`0000000`0000020?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080000000H0oooo00000000
000000000?ooo`0000060?ooo`030000003oool0000000h0oooo0P00000:0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool01@3oool2000000/0oooo000C0?ooo`030?oOW01dW=l0oooo
00@0oooo00<0oooO09adW03Oool09`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`0000000`0000020?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000001X0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`0000000000
0?ooo`03000000030?ooo`000000oooo00D0oooo00<000000?ooo`0000003P3oool2000000X0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo
000C0?ooo`030?noW02Lgol0oooo00<0oooo00<0oooO09a8001d_ol0:03oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000000`0000020?ooo`040000003o
ool0oooo000000T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00000K0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`0000001@0000030?ooo`030000003oool0oooo0080
000000<0oooo0000000000000P0000060?ooo`030000003oool0000000h0oooo0P00000:0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`00
4`3oool00`3ogi`0B7Bo0?ooo`020?ooo`030=nLB0000000B9cO02T0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`090?ooo`060000003oool000000000003oool000000P3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000
00090?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo00P0oooo0`00000M0?ooo`8000000`3oool2000000H0oooo00@0
00000?ooo`3oool000000P3oool2000000060?ooo`00000000000000003oool000001@3oool20000
00030?ooo`000000oooo00`0oooo0P00000:0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`090?ooo`00503oool01P3o_g@0000000000000000004RL
0=ooobX0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`@0000000D0oooo
0000003oool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203o
ool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0:03oool4000000030?oo
o`000000000000<000000`3oool01@000000oooo0?ooo`000000oooo0080000000H0oooo00000000
000000000?ooo`0000050?ooo`80000000<0oooo0000003oool0303oool2000000X0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool4000000050?ooo`000000oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00@00000
0?ooo`00000000002@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0]0?ooo`8000000P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`00000000000?ooo`03000000030?ooo`000000oooo00@0
oooo0P0000000`3oool000000?ooo`0<0?ooo`8000002P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool003H0oooo00@0_g@0000000000000
M;oo2P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo100000001@3oool0
00000?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?oo
o`<000002P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`05000000030?ooo`000000oooo00@0oooo0P000000
0`3oool000000?ooo`0<0?ooo`8000002P3oool2000000h0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`090?ooo`005P3oool01P3ogi`0B000000000000000001809cOoaT0oooo00H0
gia8001d_`3oool0omnL04P00018W=l90?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool02@3oool4000000050?ooo`000000oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0]0?oo
o`8000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`00000000000?oo
o`02000000030?ooo`000000oooo00@0oooo0P0000000`3oool000000?ooo`0<0?ooo`8000002P3o
ool2000000l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`00503oool0
103ooml0W4P00018W03Oool20?ooo`030?noM000B9`0gooo01L0oooo00<0oooO09a80018W=l00P3o
ool00`3o_g@0001809cOo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3o
ool4000000050?ooo`000000oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0;03oool00`000000oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo000000000000oooo0080000000<0oooo0000
003oool0103oool2000000030?ooo`000000oooo00`0oooo0P00000:0?ooo`8000003`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo000D0?ooo`030;mdB02Lgol0oooo00<0
oooo00<0oooO09a8M02oool05`3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=oo
o`L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`@0000000D0oooo0000
003oool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool000000000003oool00P0000000`3oool000000?ooo`040?ooo`800000
00<0oooo0000003oool0303oool2000000X0oooo0P00000?0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02@3oool001<0oooo00<0omnL09boo`3oool0103oool00`3ogi`0B7Bo0?oo
o`0G0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00T0oooo100000001@3oool000000?ooo`3oool000000080oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`00
000000000?ooo`02000000030?ooo`000000oooo00D0oooo00<000000?ooo`0000003@3oool20000
00X0oooo0P00000?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool001<0
oooo00<0oknL09cOo`3oool00`3oool00`3ogi`0B4RL0=ooo`0I0?ooo`030;md0000B9`0gooo0080
oooo00<0omnL04P00018W=l01`3ooooo0000068000002`3oool001<0oooo00@0oono07@000000000
M;oo7P3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`090?ooo`@0000000D0oooo0000003oool0oooo000000020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
00000000003oool00P0000000`3oool000000?ooo`050?ooo`030000003oool0000000d0oooo0P00
000:0?ooo`8000003`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo000e
0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00T0oooo100000001@3oool000000?ooo`3oool000000080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000
00000?ooo`02000000030?ooo`000000oooo00@0oooo0P0000000`3oool000000?ooo`0<0?ooo`80
00002P3oool2000000l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`00
=@3oool0103ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`090?ooo`@0000000D0oooo0000003oool0oooo000000020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0/0?oo
o`<000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`00000000000?oo
o`02000000030?ooo`000000oooo00@0oooo0P0000000`3oool000000?ooo`0<0?ooo`8000002P3o
ool2000000l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`004`3oool0
0`3ookl0W9cO0?ooo`030?ooo`040?noM0000000001d0;oooaT0oooo00<0omnL04P0001d_ol00P3o
ool00`3OW4P007Bo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3o
ool4000000050?ooo`000000oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo000000000000oooo0080000000<0oooo0000
003oool0103oool2000000030?ooo`000000oooo00`0oooo0P00000:0?ooo`8000003`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo000C0?ooo`040?oo_`2LW=l0oono07@0
00@0000000<004RL0=ooo`3oool06@3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`@0000000D0oooo0000003oool0oooo
000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0b0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`D0000000<0oooo0000
003oool0103oool2000000030?ooo`000000oooo00`0oooo0P00000:0?ooo`8000003`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo000C0?ooo`090?oOW018000000000000
B02Lgol0oooo0?oog`2LB7@0_ooo01`0oooo00@0gia800000000000007Bo203oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00T0oooo100000001@3oool000000?ooo`3oool000000080
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0380
oooo00X000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo100000000`3oool00000
0?ooo`040?ooo`80000000<0oooo0000003oool0303oool2000000X0oooo0P00000?0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool000l0oooo00@0oooO09a8000007@0_ooo
<@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo100000001@3oool00000
0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo0380oooo00@000000?ooo`3oool000000P3oool01@000000oooo000000000000
oooo00<0000000<0oooo0000003oool0103oool2000000030?ooo`000000oooo00`0oooo0P00000:
0?ooo`8000003`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool4000000050?ooo`000000oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0<P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`0000000000
0?ooo`03000000030?ooo`000000oooo00@0oooo0P0000000`3oool000000?ooo`0<0?ooo`800000
2P3oool2000000l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`004`3o
ool01@3ogkl0_moo0?ooo`3oool0_g@000<0000000<0001d0;ooo`3oool09P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00T0oooo100000001@3oool000000?ooo`3oool000000080
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0380
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool000000000003oool00P000002
0?ooo`030000003oool0oooo00<0oooo0P0000000`3oool000000?ooo`0<0?ooo`8000002P3oool2
000000h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`004`3oool00`2o
M000000000000002000000050000M02oool0oooo0;nLW03Oool09`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00T0oooo100000001@3oool000000?ooo`3oool000000080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0380oooo00`0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000003oool2000000030?ooo`00
0000000000D0oooo0P0000000`3oool000000?ooo`0<0?ooo`8000002P3oool2000000h0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`004@3oool01@2oM000000000000000
B9`0gooo00<0oooo00<0oooO09a8001d_ol00P3oool00`2oM00004RL0=ooo`0S0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool02@3oool600000080oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0400oooo0P0000060?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0<P3oool010000000oooo0?ooo`0000020?ooo`06
0000003oool000000?ooo`000000oooo0P0000000`3oool000000?ooo`050?ooo`<000003P3oool2
000000X0oooo0P00000>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool0
01<0oooo00<0oknL09cOo`3oool0203oool00`3ogi`0B7Bo0?ooo`0S0?ooo`<000001P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0000000<000000P3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0@03oool2000000H0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0b0?ooo`060000003oool0oooo0000003oool00000
0P3oool2000000060?ooo`00000000000000003oool000001@3oool2000000030?ooo`000000oooo
00d0oooo0P00000:0?ooo`8000003P3oool00`000000oooo0?ooo`050?ooo`8000002`3oool001<0
oooo00<0oono07Ad_`3oool01`3oool00`3o_g@004RL0=ooo`0T0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0000000300000080oooo00@000000?ooo`3o
ool000002P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0400oooo0P0000070?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0<@3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo0080000000<0oooo0000000000000`0000050?ooo`80000000<0oooo
0000003oool0303oool00`000000oooo0000000:0?ooo`8000003P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00T0oooo000C0?ooo`040?oOW0180000001d0;ooo`D0oooo00<0gia8
001d_`3oool09@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`0000000`0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`100?ooo`8000001`3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo0340oooo00@000000?ooo`3oool000000P3oool01@000000oooo000000000000oooo00H0
00001@3oool2000000030?ooo`000000oooo00`0oooo00<000000?ooo`0000002P3oool2000000h0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`00503oool00`3ogi`0B000
000000050000000304RLg`3oool0oooo02D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0000000<000000P3oool01@000000oooo0?ooo`3oool0000000T0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`110?ooo`8000001`3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0340oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`02000000060?ooo`00000000000000003oool000001P3oool2000000030?ooo`000000
oooo00`0oooo00<000000?ooo`0000002P3oool2000000h0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`090?ooo`006@3oool00`3o_g@0001809cOo`0X0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0000000300000080oooo00D000000?oo
o`3oool0oooo000000090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0@@3oool2
000000L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0`0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`00000000000P3oool3000000030?ooo`000000oooo00D0oooo
0P0000000`3oool000000?ooo`0<0?ooo`030000003oool0000000X0oooo0P00000>0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool001P0oooo00<0_g@0001d_`3oool0:@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000000`00
00020?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo0440oooo0P0000080?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo000000020?ooo`030000003oool0oooo0080000000D0oooo000000000000
00000?ooo`02000000H0oooo00<000000?ooo`0000003P3oool00`000000oooo0000000:0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`00
4`3oool01P3ogi`0B00007Boo`3o_g@0000007Boob/0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0000000<000000P3oool01@000000oooo0?ooo`3oool0
000000T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`110?ooo`030000003oool0
000000L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
00000080oooo00@000000?ooo`00000000000P3oool3000000030?ooo`000000oooo00D0oooo0P00
00000`3oool000000?ooo`0=0?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo000C0?ooo`040?oOW0180000
0000001d_bd0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0000000<000000P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`120?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
0P0000000`3oool0000000000002000000030?ooo`000000oooo00D0oooo0P0000000`3oool00000
0?ooo`0=0?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo00000003000000<0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0480oooo00<000000?ooo`000000
1`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0300oooo00D000000?ooo`000000
oooo000000020?ooo`8000000P3oool300000080oooo00<000000?ooo`3oool0103oool200000003
0?ooo`000000oooo00d0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`090?ooo`030000003oool000000080000000D0oooo0000003oool0
oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`120?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0_0?ooo`050000003oool000000?ooo`0000000P3oool010000000oooo0000003oool4
000000030?ooo`000000oooo00H0oooo0P0000000`3oool000000?ooo`0=0?ooo`030000003oool0
000000T0oooo0P00000?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool0
04@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool00000
0080000000D0oooo0000003oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`120?ooo`030000003oool0000000P0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0`0?ooo`040000003oool0000000000080oooo00<0
00000?ooo`0000000P3oool300000080oooo00<000000?ooo`3oool0103oool2000000030?ooo`00
0000oooo00h0oooo00<000000?ooo`0000002@3oool2000000l0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`0000000P0000001@3oool000000?ooo`3oool000000080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`000000203oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02l0oooo00@0
00000?ooo`00000000000`3oool010000000oooo0000003oool300000080oooo0P0000060?ooo`80
000000<0oooo0000003oool03P3oool00`000000oooo000000090?ooo`8000003P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00140?ooo`<000001P3oool00`000000oooo
0?ooo`090?ooo`030000003oool000000080000000D0oooo0000003oool0oooo000000020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0000000P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0_0?ooo`<0
00000`3oool010000000oooo0000003oool3000000<0oooo00<000000?ooo`3oool01@3oool30000
0100oooo0P00000:0?ooo`8000003P3oool00`000000oooo0?ooo`060?ooo`8000002`3oool004@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool000000080
000000D0oooo0000003oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`130?ooo`040000003oool0oooo000000P0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0000000<0oooo00@00000
0?ooo`000000oooo100000020?ooo`8000001`3oool3000000l0oooo00<000000?ooo`0000002P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3o
ool004@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
00000080000000D0oooo0000003oool0oooo000000030?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`130?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool000000080oooo
100000020?ooo`<000000P3oool2000000L0oooo00@000000?ooo`00000000003`3oool00`000000
oooo0000000:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo
100000001@3oool000000?ooo`3oool0000000<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo04@0oooo00@000000?ooo`3oool00000203oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`030000003oool0000000<0oooo0P0000070?ooo`80000000<0oooo0000
003oool03P3oool00`000000oooo0000000:0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`0000000`0000020?ooo`050000003oool0oooo0?oo
o`0000002@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04@0oooo00@000000?oo
o`3oool000002@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo2`00000L
0?ooo`80000000D0oooo000000000000oooo000000020?ooo`D000000P3oool2000000L0oooo00@0
00000?ooo`0000000000403oool00`000000oooo000000090?ooo`8000003`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0000000300000080oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0A@3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool4000000/0
oooo1000000G0?ooo`@000000P3oool00`000000oooo0?ooo`0500000080oooo0P0000080?ooo`80
000000<0oooo0000003oool03`3oool00`000000oooo000000090?ooo`8000003`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool02@3oool00`000000oooo00000003000000<0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04D0oooo00D000000?ooo`3o
ool0oooo000000080?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3oool0oooo0P000007
0?ooo`030000003oool0oooo00T0oooo0P00000C0?ooo`@0000000@0oooo00000000000000000P3o
ool3000000070?ooo`000000oooo0?ooo`000000oooo000000070?ooo`050000003oool000000?oo
o`000000403oool00`000000oooo000000090?ooo`8000003`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo00000003000000<0oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo04H0oooo00D000000?ooo`3oool0oooo00000009
0?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3oool000001`3ooolB000000d0oooo2@00
00020?ooo`L000000P3oool00`000000oooo000000080?ooo`050000003oool000000?ooo`000000
3`3oool010000000oooo0?ooo`0000090?ooo`8000003`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo00000003000000<0oooo00@000000?ooo`3oool000002P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo04H0oooo00D000000?ooo`3oool0oooo000000090?oo
o`030000003oool0oooo01H0oooo00@000000?ooo`00000000001`3oool300000080oooo00<00000
0?ooo`3oool02@3oool4000000L0oooo2P0000030?ooo`P000000P3oool00`000000oooo00000008
0?ooo`050000003oool000000?ooo`000000403oool00`000000oooo0000000:0?ooo`8000003`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo00000002000000050?ooo`000000
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool05@3oool2000000H0oooo100000020?oooad000000P3oool2000000030?ooo`00
0000000000P000000`3oool3000000T0oooo00D000000?ooo`000000oooo0000000@0?ooo`030000
003oool0000000X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo00000002000000050?ooo`000000oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0AP3oool00`000000oooo
000000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0503oool2000000D0oooo
0`0000030?ooo`80000000<0oooo000000000000100000020?ooob000000103oool3000000X0oooo
00D000000?ooo`000000oooo0000000A0?ooo`030000003oool0000000X0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00140?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo00000002000000050?oo
o`000000oooo0?ooo`0000000`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool04P3oool2000000P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`100?ooo`H0000000<0oooo0000000000001@0000090?ooo`030000003oool0oooo01<0
oooo0P0000040?ooo`/000000P3ooolO00000080oooo0`0000030?ooo`<0000000<0oooo0000003o
ool02P3oool01@000000oooo0000003oool000000140oooo00<000000?ooo`0000002@3oool20000
00l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`00A03oool3000000L0
oooo00<000000?ooo`3oool02P3oool4000000050?ooo`000000oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0?P3oool30000
00P0oooo00<000000?ooo`3oool00P3oool2000000T0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo000000020?ooo`80000000<0oooo0000000000007@0000050?ooo`l000000`3oool00`00
0000oooo0?ooo`090?ooo`050000003oool000000?ooo`0000004@3oool010000000oooo0?ooo`00
00090?ooo`8000003`3oool00`000000oooo0?ooo`070?ooo`8000002`3oool004@0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`@0000000D0oooo0000003oool0oooo0000
00030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0m0?ooo`8000002`3oool00`000000oooo0?ooo`030?ooo`<000001`3oool00`000000oooo0?oo
o`090?ooo`d0000000<0oooo0000000000005P0000090?ooo`P000003@3oool2000000`0oooo0P00
00000`3oool000000?ooo`0A0?ooo`040000003oool0oooo000000T0oooo0P00000?0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`@0000000<0oooo0000003oool00P3oool010000000oooo0?oo
o`00000:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0503oool2000000H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0k0?ooo`8000003@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo008000001P3oool00`000000oooo0?ooo`050?ooo`<00000
1@3oool200000080oooo0P0000000`3oool000000000000600000080oooo0P0000000`3oool00000
000000060?ooo`80000000<0oooo0000000000000P0000090?ooo`040000003oool0oooo000000`0
oooo0`00000=0?ooo`040000003oool00000000001<0oooo00@000000?ooo`3oool000002@3oool2
000000l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`00A03oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000000`0000030?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0F
0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo0P00000?
0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo00<0oooo0P0000070?ooo`040000003oool0oooo0?oooa4000001P3oool2000000030?oo
o`000000000000@0oooo100000030?ooo`8000000P3oool00`000000oooo0?ooo`090?ooo`800000
403oool2000000030?ooo`000000oooo0140oooo00@000000?ooo`3oool000002P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool004@0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0000000<00000
0`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000?03oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool20000
00<0oooo00@000000?ooo`3oool0oooo0P0000080?ooo`040000003oool0oooo0?ooo`T0000000<0
oooo0000000000000`0000070?ooo`8000001@3oool00`000000oooo0?ooo`050?ooo`X000000`3o
ool600000140oooo0P0000000`3oool000000?ooo`0B0?ooo`040000003oool0oooo000000X0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo
00140?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0000
0003000000<0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0603oool200000080oooo00<000000?ooo`000000?03oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`3oool3000000T0oooo00<000000?ooo`0000000P0000000`3oool000000000000400000004
0?ooo`00000000000?ooo`8000000P3oool2000000<0oooo0P0000080?ooo`030000003oool0oooo
00<0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`00000F0?ooo`040000003oool00000
000001@0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`090?ooo`030000003oool0000000<00000103oool010000000oooo0?ooo`00
000:0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06@3oool5000003X0oooo0P00
000C0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool4000000X0oooo1@00
00000`3oool0000000000006000000030?ooo`000000000000H0oooo0`00000;0?ooo`80000000<0
oooo0000000000001@3oool00`000000oooo0?ooo`0L0?ooo`<00000503oool01@000000oooo0?oo
o`3oool0000000T0oooo0P00000@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool003@0oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02P3oool4000000030?ooo`000000oooo0080oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01/0oooo
0`00000h0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`<0000000<0oooo0000003oool01`3oool2000000030?ooo`000000oooo00P00000
00<0oooo0000000000001`3oool200000080oooo0P00000:0?ooo`8000001P3oool00`000000oooo
0?ooo`0L0?ooo`80000000<0oooo0000003oool04`3oool01@000000oooo0?ooo`3oool0000000T0
oooo0P00000@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool003D0oooo
00<0okmd001d_`3oool00P3oool00`2oM7@0_ooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02P3oool4000000030?ooo`000000oooo0080oooo00@000000?ooo`3oool0
00002`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01T0oooo00@000000?ooo`00
0000oooo0`00000d0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`800000103oool?00000080oooo00<00000
0?ooo`3oool01@3oool2000000H0oooo0P0000060?ooo`8000000P3oool200000080oooo0P00000M
0?ooo`<0000000<0oooo0000003oool0503oool010000000oooo0?ooo`00000:0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`00=P3oool0
0`3o_g@007Bo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool6
000000<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo01L0oooo00@000000?ooo`3oool00000103oool200000340oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo008000001@3oool500000080oooo
00<000000?ooo`000000200000000`3oool0000000000004000000<0oooo0P00000:0?ooo`800000
0P3oool2000000H0oooo0P00000N0?ooo`030000003oool0oooo008000005@3oool01@000000oooo
0?ooo`3oool0000000X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo000g0?ooo`030?noM000M;l0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000<00000103oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool2000000@0
oooo00<000000?ooo`3oool00`3oool5000002/0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0000000H0oooo100000020?ooo`80000000<0oooo0000003o
ool00`0000001@3oool00000000000000000oooo008000001@3oool3000000h0oooo0P0000080?oo
o`<00000703oool00`000000oooo0?ooo`02000001H0oooo00D000000?ooo`3oool0oooo0000000:
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`00>03oool00`3o_g@0B9cO0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo00000003000000@0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`080?ooo`H000008`3oool2000001T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`<000000`3oool300000080oooo200000000`3oool0000000000006
0?ooo`8000000P3oool4000000P0oooo0P0000020?ooo`<000000`3oool2000000<0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`02000001L0oooo00D000000?ooo`3oool0oooo0000
000:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`00>@3oool00`3OW4P0B9cO0?ooo`080?ooo`@00000203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0000000<00000103oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool0oooo01@0oooo0P00000A0?ooo`800000203oool00`000000oooo0?ooo`0=0?ooo`L000006`3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo0P0000020?ooo`8000001P3o
ool:000000040?ooo`0000000000000000L0oooo00<000000?ooo`3oool01P3oool3000000<0oooo
0P0000070?ooo`@000001@3oool2000001H0oooo0P0000020?ooo`8000005`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00L0oooo0P00000@0?ooo`030000003oool0oooo00L0oooo
0`00000;0?ooo`00>P3oool00`2oM000M;oo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool5000000@0oooo00@000000?ooo`3oool000002`3oool00`000000oooo
0?ooo`0F0?ooo`8000003@3oool2000000X0oooo00<000000?ooo`3oool0503oool5000001D0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`040?ooo`80000000@0oooo000000000000
00001`3oool3000000030?ooo`000000000000P000001P3oool2000000`0oooo0`0000090?ooo`80
00000P3oool3000000@0oooo0P00000B0?ooo`8000000`3oool2000001P0oooo00D000000?ooo`3o
ool0oooo0000000:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`00>P3oool00`3ogi`0B01d0;ooo`070?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool6000000@0oooo00<000000?ooo`000000303oool00`000000
oooo0?ooo`0G0?ooo`<000001`3oool3000000d0oooo00<000000?ooo`3oool0603oool400000100
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
00001`3oool2000000030?ooo`000000000000@0000000<0oooo0000003oool00P0000060?ooo`03
0000003oool0oooo00`0oooo0P0000000`3oool0000000000002000000@0oooo00<000000?ooo`3o
ool01@3oool400000080oooo0`00000<0?ooo`<000000`3oool3000001T0oooo00D000000?ooo`3o
ool0oooo0000000:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`00>P3oool00`3ooml0W4P007Boo`070?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool6000000@0oooo00@000000?ooo`3oool000002`3oool00`00
0000oooo0?ooo`0J0?ooo`L00000403oool00`000000oooo0?ooo`0L0?ooo`<00000303oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo00@000000?ooo`00000000000P3oool0
0`000000oooo0?ooo`040?ooo`80000000<0oooo0000000000001P0000000`3oool0000000000005
0?ooo`8000003@3oool2000000L0oooo1000000<0?ooo`T00000103oool400000080oooo1@00000K
0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool003X0oooo00<0oono07@00018W=l01`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`0000000`000004
0?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`0N0?ooo`<000001`3oool2000001l0oooo00L000000?ooo`3oool0oooo0000003oool0000000D0
oooo00@000000?ooo`3oool0oooo0`0000000`3oool0000000000003000000030?ooo`0000000000
0080000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0;0?ooo`8000002@3oool20000
00040?ooo`000000000000000100oooo3@0000000`3oool000000000000L0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool003H0oooo00L0okmd0018W03Oool0oooo0=nLB000
04P0W=oo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0000000<00000103oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool08@3oool3000000<0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`03000000H0oooo00D000000?ooo`3oool000000?ooo`09000000050?ooo`000000oooo0?oo
o`0000000`3oool2000000d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?oo
o`<00000603oool3000001h0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`800000403oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo000g0?ooo`050?oOW01800000000
0000001d_ol0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`000000100000040?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0S0?ooo`<000008P3oool010000000oooo0000000000090?ooo`80000000<0
oooo0000000000001@000000103oool000000000000000020?ooo`030000003oool0000000800000
3@3oool2000000T0oooo0P00000:0?ooo`@000004P3oool200000240oooo00D000000?ooo`3oool0
oooo0000000:0?ooo`800000403oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00140?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool6000000@0oooo
00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`0000000P00000O0?ooo`<000002P3oool010000000oooo0000003oool40000
00030?ooo`0000000000008000000`3oool01@000000oooo0000003oool0000000/0oooo0P00000:
0?ooo`030000003oool0oooo00h0oooo4P00000R0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?oo
o`H00000103oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`030?ooo`<000006`3oool2000000/0oooo0`000000
0`3oool0000000000002000000040?ooo`000000oooo00000080oooo00<000000?ooo`0000000P00
00030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool2000004D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo1P0000040?ooo`040000003oool0oooo000000d0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo0P00
000H0?ooo`030000003oool0000000T0oooo200000001@3oool000000000003oool0000000<0oooo
00<000000?ooo`0000001P3oool00`000000oooo0?ooo`040?ooo`8000002@3oool2000004H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`000000100000040?ooo`030000003o
ool0000000d0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0M0?ooo`800000303o
ool2000001D0oooo00@000000?ooo`3oool00000203oool300000080oooo0`0000000`3oool00000
0?ooo`02000000@0oooo0P0000080?ooo`040000003oool0oooo0?ooo`8000002P3oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool200000140
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00/0oooo1P0000040?ooo`040000003oool0oooo000000d0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00h0
oooo0P00000A0?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`<0000000<0oooo00000000
0000100000000`3oool000000?ooo`040?ooo`040000003oool00000000000P0oooo0`00000:0?oo
o`800000B03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo0P00000A0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool004@0oooo0`00000:0?ooo`03
0000003oool0oooo00/0oooo1P0000040?ooo`040000003oool0oooo000000d0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0140oooo0P00000>0?oo
o`800000103oool00`000000oooo0?ooo`040?ooo`<0000000D0oooo00000000000000000?ooo`02
000000030?ooo`000000oooo00@0oooo00D000000?ooo`000000oooo000000080?ooo`<00000203o
ool2000004X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`800000403o
ool00`000000oooo0?ooo`0:0?ooo`8000002`3oool004@0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0;0?ooo`H00000103oool010000000oooo0?ooo`00000>0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0D0?ooo`8000002`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`000000oooo
0`0000000`3oool000000?ooo`02000000@0oooo0P0000000`3oool000000?ooo`020?ooo`030000
003oool0oooo00<0oooo0P0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo0P00000A0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000@00000103oool010000000oooo0?oo
o`00000=0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool05@3oool2000001T0oooo
0P0000070?ooo`8000001`3oool010000000oooo0?ooo`3oool2000000030?ooo`000000000000<0
000000@0oooo0000003oool000000P3oool010000000oooo0?ooo`0000030?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`800000
C03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo0P00000A0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000@00000103oool010000000oooo0?oo
o`00000>0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0K0?ooo`800000103oool2000000P0oooo00@000000?ooo`3oool000000P3oool700000003
0?ooo`000000oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`04
0000003oool00000000000P0oooo0`00001=0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01`3oool200000180oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?oo
o`00A03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo1P0000040?ooo`05
0000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
0100oooo0P00000P0?ooo`D000002@3oool300000080oooo100000000`3oool000000?ooo`020000
00@0oooo0P0000030?ooo`030000003oool0oooo00@0oooo0P00000:0?ooo`030000003oool00000
04d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`8000004P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool5000000030?ooo`000000oooo0080oooo00D000000?ooo`3o
ool0oooo0000000>0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0Q0?ooo`<000002P3oool200000080oooo10000000103oool000000?ooo`000005
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool200000080oooo00<00000
0?ooo`3oool01@3oool2000000<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00L0oooo0P00000C0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0000000@00000103oool010000000oooo0?ooo`00000?0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0Q0?ooo`80000000<0oooo
0000000000001`3oool300000080oooo1P0000000`3oool000000?ooo`040?ooo`070000003oool0
oooo0?ooo`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool2000000H0oooo0P0000180?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1`3oool200000180oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`00A03o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`0000001000
00040?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo00T0oooo0P00000R0?ooo`<00000103oool2000000@0oooo2P0000000`3oool00000
000000040?ooo`8000001@3oool010000000oooo0?ooo`3oool2000000H0oooo00D000000?ooo`3o
ool0oooo0000000:0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`080?ooo`8000004P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00T0oooo00140?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool500000003
0?ooo`000000oooo0080oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool00000
00L0oooo00<000000?ooo`0000000P0000020?ooo`@0000000@0oooo0000003oool000001@3oool0
0`000000oooo0?ooo`050?ooo`@000002@3oool3000000`0oooo0P0000140?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01`3oool2000001<0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`030?ooo`050000003oool0oooo
0?ooo`0000003`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00@0oooo0P00000R
0?ooo`80000000<0oooo0000003oool0203oool300000080oooo10000000103oool000000?ooo`00
00050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000002`3oool2000000l0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo0P00
000C0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0000000@00000103oool0
1@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0240oooo00@000000?ooo`0000000000203oool2000000040?oo
o`00000000000?ooo`P00000103oool2000000P0oooo0P0000000`3oool000000?ooo`070?ooo`80
00000P3oool00`000000oooo0?ooo`0=0?ooo`800000?`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00P0oooo0P00000B0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool02@3oool004@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0000000@00000103oool01@000000oooo0?ooo`3oool000000140oooo00<000000?ooo`3o
ool0=P3oool010000000oooo00000000000R0?ooo`80000000<0oooo0000003oool0203oool01000
0000oooo0?ooo`0000020?ooo`D0000000<0oooo0000003oool0103oool00`000000oooo0?ooo`06
0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`09
0?ooo`00A03oool3000000`0oooo00<000000?ooo`3oool0303oool00`000000oooo000000020000
00030?ooo`000000oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool08@3oool010000000oooo0?ooo`000008
0?ooo`80000000<0oooo0000000000000P3oool00`000000oooo00000002000000030?ooo`000000
oooo00<0oooo0P0000080?ooo`8000001P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<0
00000?ooo`3oool03P3oool2000003X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`070?ooo`8000004`3oool00`000000oooo0?ooo`0<0?ooo`8000002`3oool004@0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool000000080000000<0oooo
0000003oool00`3oool01@000000oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool0=03o
ool2000000030?ooo`00000000000200oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000030?ooo`<0000000@0oooo0000000000000000103oool00`000000oooo0?ooo`060?oo
o`80000000<0oooo0000003oool01@3oool010000000oooo00000000000:0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo0P00000C0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool0
04@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool00000
00@00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0<@3oool2000000D0oooo00<000000?ooo`3oool06`3oool2000000030?ooo`0000000000
00L0oooo0P0000020?ooo`030000003oool0oooo00P0000000D0oooo0000003oool0oooo00000007
0?ooo`8000000P3oool00`000000oooo0?ooo`050?ooo`800000303oool00`000000oooo0?ooo`0@
0?ooo`800000=@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool5000000030?ooo`000000oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
02h0oooo0P0000080?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool00000203oool0
0`000000oooo0?ooo`0200000080oooo00<000000?ooo`0000000P000000103oool000000?ooo`00
00020?ooo`8000001`3oool01@000000oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3oool0
0000303oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`070?ooo`8000004`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
303oool00`000000oooo00000002000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02/0oooo0P00000;0?ooo`800000
5`3oool200000080oooo00<000000?ooo`3oool01@3oool200000080oooo00H000000?ooo`3oool0
oooo0000003oool3000000070?ooo`000000oooo0?ooo`000000oooo000000020?ooo`8000000`3o
ool2000000<0oooo00<000000?ooo`3oool0103oool2000000@0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0A0?ooo`800000<03oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00P0oooo0P00000C0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3o
ool004@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
00000080000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0140oooo0P00000Y0?ooo`8000003`3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0
oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`000000
oooo0`0000030?ooo`8000001@3oool3000000D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04P3oool2000002d0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`800000503oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03@3oool5000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02@0oooo0P00000B0?ooo`030000
003oool0oooo0100oooo0P0000020?ooo`8000001`3oool00`000000oooo0?ooo`02000000<0oooo
1P0000040?ooo`8000001@3oool4000000@0oooo00<000000?ooo`3oool00P3oool2000000P0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0C0?ooo`800000:P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00P0oooo0P00000C0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool000000080000000<0oooo0000003oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01<0oooo0P00000Q0?ooo`<000005@3oool2000000l0oooo00D0
00000?ooo`3oool0oooo000000080?ooo`040000003oool0oooo000000<0oooo1@0000000`3oool0
00000?ooo`030?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000030?ooo`8000002`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
01@0oooo0P00000V0?ooo`8000003P3oool00`000000oooo0?ooo`070?ooo`800000503oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0303oool00`000000oooo0000000200000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo0P00000M0?ooo`80
00006P3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`000000203oool01000
0000oooo0?ooo`0000030?ooo`D0000000<0oooo0000003oool00`3oool010000000oooo0?ooo`00
00020?ooo`8000001P3oool2000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo01D0oooo0P00000R0?ooo`8000003`3oool00`000000oooo0?oo
o`080?ooo`800000503oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo0014
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool5000000030?ooo`000000
oooo00@0oooo00D000000?ooo`3oool0oooo0000000H0?ooo`800000603oool3000001d0oooo00<0
00000?ooo`3oool0203oool2000000<0oooo00<000000?ooo`3oool01P3oool010000000oooo0000
000000030?ooo`L000000`3oool2000000<0oooo0`0000090?ooo`@00000403oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo01L0oooo1000000K0?ooo`<000004@3oool00`000000oooo
0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo
00140?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000
0002000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0G0?ooo`8000004`3oool300000240oooo0P0000070?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo000000040?ooo`<0000000<0oooo000000000000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo1@00000A0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool06P3oool5000001@0oooo0P00000C0?ooo`030000003o
ool0oooo00P0oooo0P00000D0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02@3o
ool004@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
000000<0000000<0oooo0000003oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01P0oooo4`00000V0?ooo`030000003oool0oooo0080oooo0P0000030?ooo`8000001`3oool2
000000030?ooo`000000oooo00<0oooo1P0000030?ooo`800000103oool3000000T0oooo0P000004
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0N
0?ooo`D000002`3oool4000001D0oooo00<000000?ooo`3oool01`3oool2000001D0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`090?ooo`00A03oool3000000l0oooo00<000000?oo
o`3oool03@3oool00`000000oooo00000002000000030?ooo`000000oooo00@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1B0?ooo`80000000<0oooo0000003oool00`3oool00`00
0000oooo0?ooo`060?ooo`040000003oool00000000000<0oooo1@0000000`3oool000000?ooo`02
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000203oool2000000H0oooo0P00
000@0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08P3oool;000001P0oooo00<0
00000?ooo`3oool0203oool2000001D0oooo00<000000?ooo`3oool03`3oool2000000/0oooo0014
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03@3oool00`000000oooo00000003
000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1B
0?ooo`800000103oool00`000000oooo0?ooo`060?ooo`030000003oool0000000@0oooo1`000003
0?ooo`030000003oool0oooo0080oooo0P0000030?ooo`030000003oool0oooo00D0oooo0P000009
0?ooo`8000003`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool01`3oool2000001H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`09
0?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`0000000`0000000`3oool000000?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0D03oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00H0oooo0`000004
0?ooo`<0000000<0oooo0000000000000`3oool2000000@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`<00000303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
000001D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000000`0000000`3o
ool000000?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`020?ooo`800000203oool2000000D0oooo1P0000030?ooo`030000003oool0oooo
0080oooo0P0000060?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool03@3oool2
000000h0oooo00<000000?ooo`3oool02P3oool200000440oooo00<000000?ooo`3oool0203oool2
000001H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000000`0000000`3o
ool000000?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0C03oool20000
00@0oooo00@000000?ooo`3oool000001P3oool2000000D0oooo1P0000020?ooo`8000000`3oool2
000000P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`0000005P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00T0oooo00140?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`04000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`800000103oool6000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooo`<000000P3oool00`000000oooo0?ooo`0A0?ooo`8000003@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0000000G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02@3oool0
03L0oooo00<0oooO09a80018W=l02P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`0000000`0000000`3oool000000?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0B03oool2000000@0oooo0P0000060?ooo`80000000<0oooo0000
003oool0103oool600000080oooo0P0000030?ooo`8000002P3oool2000000<0oooo00<000000?oo
o`3oool0503oool2000000`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo00L0oooo00@000000?ooo`3oool000005P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00T0oooo000h0?ooo`030=nLB000B9`0gooo00T0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0000000<0oooo0000
003oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo1P0000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo000000020?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0203oool00`000000oooo0000000G0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool02@3oool003P0oooo00<0omnL04P0B02L
gol02@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`00
00000P000000103oool000000?ooo`0000050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0@`3oool2000000@0oooo0P0000090?ooo`80000000@0oooo0000003oool0oooo1`000002
0?ooo`040000003oool0oooo0?ooo`8000002P3oool200000080oooo00<000000?ooo`0000006`3o
ool2000000/0oooo0P00000<0?ooo`800000>03oool00`000000oooo0?ooo`070?ooo`030000003o
ool0000001P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`00=03oool0
0`3o_g@0000000000004000000030018W03Oool0oooo00H0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0000000@0000000<0oooo0000003oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`080?ooo`8000000`3oool700000080oooo0P0000030?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool00P3oool2000001h0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool01`3oool0
10000000oooo0?ooo`00000H0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02@3o
ool003@0oooo00<0oooO09a8B02Lgol00P3oool00`2oM00007Bo0?ooo`080?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`03000000040?ooo`000000
oooo000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0o0?ooo`800000103o
ool2000000X0oooo0P0000030?ooo`@0000000<0oooo0000000000000P3oool010000000oooo0?oo
o`3oool2000000X0oooo0P0000050?ooo`030000003oool0oooo01h0oooo0P00000;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`070?ooo`040000
003oool0oooo000001P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`00
=@3oool01`3ookl0M01d0;ooo`3oool0okmd0018W03Oool0203oool400000140oooo00<000000?oo
o`3oool03P3oool00`000000oooo00000004000000030?ooo`000000oooo00D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0080oooo0P00000:0?oo
o`800000103oool7000000030?ooo`000000000000<0oooo00<000000?ooo`3oool0203oool20000
00L0oooo00<000000?ooo`3oool0803oool2000000X0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000006@3oool0
0`000000oooo0?ooo`0A0?ooo`<000002`3oool003H0oooo00H0omnL04Q8W03Oool0omnL04P0B02L
gol80?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`03000000040?ooo`000000oooo000000H0oooo00<000000?ooo`3oool00`3oool2000003/0oooo
0P0000040?ooo`030000003oool0oooo00T0oooo0P0000030?ooo`P0000000<0oooo0000003oool0
0P3oool2000000X0oooo00<000000?ooo`3oool01P3oool2000002@0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0;0?ooo`800000;`3oool00`000000oooo0?ooo`080?ooo`040000
003oool0oooo000001T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`00
=`3oool01@3o_g@007Bo0?oog`2LB000B9cO00P0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00D000000P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0=P3oool2000000@0oooo0P00000:0?ooo`<0
00000`3oool4000000040?ooo`00000000000?ooo`80000000@0oooo0000003oool000002P3oool2
000000P0oooo00<000000?ooo`0000009@3oool2000000T0oooo0P00000=0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00000I0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool02@3oool003P0oooo00@0gia804RLg`2oM00007Bo203o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`00
0000103oool000000?ooo`0000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
<`3oool2000000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo000000020?ooo`P00000
00<0oooo0000003oool00P3oool3000000P0oooo0P0000090?ooo`040000003oool0oooo000002L0
oooo0P0000090?ooo`030000003oool0oooo00/0oooo0P00000Z0?ooo`030000003oool0oooo00P0
oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00T0oooo000i0?ooo`040=nLB01dM7@0001d0;ooo`L0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0>0?ooo`040000003oool0oooo0?ooo`@000000P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo0P00000`0?ooo`<000001@3oool2000000/0oooo00<00000
0?ooo`0000000P3oool00`000000oooo00000005000000040?ooo`000000oooo0?ooo`8000000`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo
0000000Y0?ooo`800000203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0203oool010000000oooo0?ooo`00000K0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool02@3oool003X0oooo00<0_g@00000B02Lgol01`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@0000020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Z0?ooo`<00000
1P3oool2000000/0oooo0P000000103oool000000?ooo`3oool7000000030?ooo`00000000000080
oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool2000000X0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0Y0?ooo`8000001`3oool2000000d0oooo0P00000U0?oo
o`030000003oool0oooo00P0oooo00@000000?ooo`3oool000006`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00T0oooo000j0?ooo`030?oog`2LB000B9cO00L0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo0?ooo`@000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo0P00000X0?ooo`800000203oool0
0`000000oooo0?ooo`0:0?ooo`050000003oool000000000003oool01P000000103oool000000?oo
o`0000020?ooo`800000203oool3000000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0[0?ooo`8000001`3oool2000000d0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`070?ooo`8000000P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00D000000P3oool00`000000oooo0?ooo`050?ooo`800000203o
ool2000002@0oooo0P0000080?ooo`800000303oool00`000000oooo000000020?ooo`030000003o
ool0000000L000000P3oool00`000000oooo0?ooo`080?ooo`<000002P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo02d0oooo0P0000070?ooo`800000303oool200000200oooo00<0
00000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000001d0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00l0oooo00@000000?ooo`3oool0oooo1@0000020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool3000001l0oooo0P0000090?ooo`030000003oool0oooo00X0oooo
0P0000000`3oool000000?ooo`06000000040?ooo`000000000000000080oooo0P0000090?ooo`80
00000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0;`3oool2000000L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00@0000000D0oooo0000003oool0oooo000000080?oo
o`030000003oool0oooo00T0oooo0`00000I0?ooo`<000002@3oool2000000`0oooo00L000000?oo
o`00000000000?ooo`000000oooo00L000000`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00@0oooo0P0000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0<@3o
ool2000000H0oooo0P00000<0?ooo`8000006P3oool2000000P0oooo0P0000030?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool010000000
1@3oool000000?ooo`3oool0000000P0oooo0P00000<0?ooo`<00000403oool6000000X0oooo0P00
000=0?ooo`040000003oool000000?ooo`H0000000@0oooo00000000000000000P3oool2000000T0
oooo0P0000090?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0c0?oo
o`8000001P3oool2000000`0oooo0`00000E0?ooo`800000203oool2000000<0oooo0P00000N0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo0?ooo`D000000P3oool00`00
0000oooo0?ooo`080?ooo`8000003@3oool@000000h0oooo0P00000=0?ooo`80000000<0oooo0000
003oool01@000000103oool000000000000000030?ooo`030000003oool0oooo00L0oooo0P00000<
0?ooo`<000002P3oool00`000000oooo0?ooo`0e0?ooo`8000001P3oool3000000`0oooo1000000?
0?ooo`800000203oool2000000@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00T0oooo00140?ooo`<000005P3oool00`000000oooo0?ooo`0@0?oo
o`040000003oool0oooo0?ooo`D000000P3oool00`000000oooo0?ooo`090?ooo`8000009@3oool4
000000h0oooo00<000000?ooo`0000002P0000030?ooo`8000002@3oool00`000000oooo0?ooo`0=
0?ooo`<000002@3oool00`000000oooo0?ooo`0g0?ooo`<000001P3oool4000000`0oooo10000009
0?ooo`800000203oool2000000D0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0G
0?ooo`8000002`3oool004@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?oo
o`040000003oool0oooo0?ooo`H000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01l0oooo0`00000@0?ooo`80000000<0oooo0000003oool01@000000103oool0000000000000
00030?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`050000003oool0oooo0?ooo`000000
203oool00`000000oooo0?ooo`0j0?ooo`800000203oool5000000/0oooo0`0000030?ooo`<00000
0`3oool7000000D0oooo0P00000Q0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
2@3oool004@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`040000003o
ool0oooo0?ooo`H000000P3oool00`000000oooo0?ooo`0:0?ooo`800000703oool300000140oooo
0P0000020?ooo`X000000`3oool2000000T0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`020?ooo`8000001P3oool00`000000oooo0?ooo`0l0?ooo`<000002P3ooolG000000X0oooo
0P00000R0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool004@0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo0?ooo`H00000
0P3oool2000000`0oooo0`00000D0?ooo`D000004P3oool200000080oooo1`0000000`3oool00000
000000030?ooo`8000002@3oool200000140oooo00<000000?ooo`3oool01@3oool2000000@0oooo
00<000000?ooo`3oool0?`3oool2000002L0oooo0P00000T0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0080oooo1P0000030?ooo`030000003oool0oooo00`0oooo1P00
00070?ooo`L000005@3oool200000080oooo2`0000030?ooo`030000003oool0oooo00L0oooo0P00
000B0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000130?ooo`800000
8`3oool2000002D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`090?ooo`00A03o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool0oooo
1`0000030?ooo`030000003oool0oooo0140oooo1`00000J0?ooo`8000000P3oool3000000030?oo
o`000000000000D000000`3oool2000000T0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0:0?ooo`80000000<0oooo0000003oool0A03oool3000001d0oooo0`00000W0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo0?ooo`P000000P3oool200000300oooo
0P0000020?ooo`<0000000<0oooo0000000000001@0000040?ooo`030000003oool0oooo00L0oooo
0P00000C0?ooo`030000003oool0oooo00d0oooo0P0000180?ooo`@000005P3oool3000002T0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool0oooo1P0000000`3oool00000
0?ooo`020?ooo`030000003oool0oooo02/0oooo0P0000020?ooo`<000000P3oool7000000<0oooo
0P0000080?ooo`800000503oool00`000000oooo0?ooo`0?0?ooo`800000B`3ooolF000002`0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool8000000<0oooo0P00
000Y0?ooo`8000000P3oool300000080oooo1`0000030?ooo`8000002@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo0100oooo00@000000?ooo`0000000000RP3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`P00000103oool2000002@0oooo0`00
00020?ooo`<000000P3oool5000000030?ooo`000000oooo0080oooo0P0000090?ooo`8000005@3o
ool00`000000oooo0?ooo`0A0?ooo`050000003oool0oooo0?ooo`000000R@3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`030000003oool0000000H00000103o
ool2000001l0oooo0`0000030?ooo`<000000P3oool5000000030?ooo`00000000000080oooo0P00
000:0?ooo`030000003oool0oooo01<0oooo0P00000D0?ooo`030000003oool0oooo0080oooo0P00
00260?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`000000100000000`3oool00000000000040?ooo`@000005P3oool5000000@0oooo0`000002
0?ooo`D0000000<0oooo0000000000000P3oool2000000X0oooo0P00000E0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0103oool2000008@0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`090?ooo`00A03oool3000001X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`020?ooo`<0000000<0oooo0000000000000P0000000`3oool00000000000060?oo
o`L00000203oool7000000H0oooo100000000`3oool0000000000004000000040?ooo`0000000000
0?ooo`<000002P3oool2000001H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool07@3oool2000000/0oooo00140?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?oo
o`/000002`3oool8000000T0oooo100000020?ooo`X0000000<0oooo0000000000002`3oool20000
01H0oooo0P00000H0?ooo`030000003oool0oooo00L0oooo0P0000200?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo0P0000000`3oool0000000000008000001@0
oooo1@0000000`3oool000000000000:000000030?ooo`000000000000/0oooo0P00000G0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool02@3oool2000007d0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool2000000030?ooo`000000000000`00000
203ooolE00000080oooo0P00000;0?ooo`800000603oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`060?ooobT000000P3oool3000000/0oooo0P00000I0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0303oool2000007T0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo01L0oooo0P0000080?ooo`T0000000<0oooo0000000000006@0000020?ooo`800000303oool2
000001T0oooo0P00000M0?ooo`030000003oool0oooo00h0oooo0P00001f0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00L0oooo800000020?ooo`<00000303oool20000
01X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0@0?ooo`800000M03oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0:0?oooaT0000000<0oooo00000000
00000P00000=0?ooo`8000006`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00T0
oooo00140?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool06@3oool2000000`0oooo
6000000>0?ooo`<00000703oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01<0oooo
0P00001_0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02@3oool004@0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0K0?ooo`8000003`3oool9000001H0oooo0P00
000M0?ooo`8000008P3oool00`000000oooo0?ooo`0E0?ooo`800000K03oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0703oool2000002T0oooo0`00000N0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool05`3oool2000006T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`09
0?ooo`00A03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01h0oooo0`00000S0?oo
o`<00000803oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0I@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00T0oooo00140?ooo`<0
00008@3oool00`000000oooo0?ooo`0P0?ooo`@000006`3oool400000240oooo0P00000V0?ooo`03
0000003oool0oooo01X0oooo0P00001U0?ooo`030000003oool0oooo02D0oooo0P00000;0?ooo`00
A03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo1000000C0?ooo`@00000
903oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01`0oooo0P00001R0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0W0?oooa<000009`3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo01h0oooo0P00001O0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3o
ool004@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0803oool2000005`0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
05`0oooo0P00000[0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02<0
oooo0P00001G0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool004@0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool09@3oool2000005@0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`090?ooo`00=@3oool01@3ooml0W4P000000000000007Bo00X0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
9`3oool200000540oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`00=@3o
ool01`3OW4P007Bo0?ooo`3ookl0M0000018W03Oool0203oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo05@0oooo0P00000`0?ooo`030000003oool0oooo02T0oooo0P00001>0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool02@3oool003@0oooo00<0oooO09a8001d_ol0
0P3oool00`3ogi`0B00004RLg`080?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02/0oooo0P00001;0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool02@3oool003@0oooo00<0oono07@0001d_ol00`3o
ool00`2oM000001d0;ooo`070?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0D@3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02d0oooo0P0000180?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool02@3oool003@0oooo00<0oooO09a80000M;l00`3oool0
0`3OW4P0001809cOo`070?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0CP3oool2
000003@0oooo00<000000?ooo`3oool0;`3oool2000004D0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`090?ooo`00=@3oool00`2oM000001d0;ooo`020?ooo`030=nLB00004P0W=oo
00L0oooo1000000Y0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0a0?ooo`<00000@03oool200000380oooo0`00000;0?ooo`00=@3oool0203o_g@0
000004RLg`3oool0oooO09a80000B9`0gooo1`3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo04X0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0d0?ooo`800000?03o
ool2000003H0oooo00<000000?ooo`3oool02@3oool003D0oooo00<0oooO09a8000000000P000000
0`0007@0_ooo0?ooo`070?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0A`3oool2
000003P0oooo00<000000?ooo`3oool0=P3oool3000003L0oooo0P00000h0?ooo`030000003oool0
oooo00T0oooo000f0?ooo`030?oo_`1d000007Bo00/0oooo00<000000?ooo`3oool0;@3oool20000
04D0oooo0P00000j0?ooo`030000003oool0oooo03T0oooo0P00000c0?ooo`800000>P3oool00`00
0000oooo0?ooo`090?ooo`00=`3oool00`3ogi`0B00004RLg`0:0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0@03oool2000003`0oooo00<000000?ooo`3oool0>`3oool4000002d0
oooo0P00000l0?ooo`030000003oool0oooo00T0oooo000h0?ooo`040?oog`2LB000001d0;ooo`P0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0m0?ooo`800000?P3oool00`000000
oooo0?ooo`0o0?ooo`@000009`3oool2000003h0oooo00<000000?ooo`3oool02@3oool003X0oooo
00@0oono07@000000000B9cO1P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`130?ooo`8000008`3oool200000400
oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0h0?ooo`800000@@3oool00`000000oooo0?ooo`150?ooo`@000007@3oool200000480oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0<`3oool2000003H0oooo0P00
00130?ooo`030000003oool0oooo04T0oooo1P00000A0?ooo`H00000A03oool00`000000oooo0?oo
o`090?ooo`00A03oool00`000000oooo0?ooo`0e0?ooo`800000<P3oool2000004D0oooo00<00000
0?ooo`3oool0C`3ooolA000004X0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0]0?ooo`800000A`3oool00`000000oooo0?ooo`2Z0?oo
o`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo03P0oooo0P00000Z0?ooo`<0
0000B@3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00T0oooo00140?ooo`<00000
>P3oool2000002D0oooo0`00001<0?ooo`030000003oool0oooo0:T0oooo0P00000;0?ooo`00A03o
ool00`000000oooo0?ooo`0l0?ooo`8000008@3oool2000004l0oooo00<000000?ooo`3oool0ZP3o
ool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0n0?ooo`<000006`3oool3
00000540oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`090?ooo`00A03oool00`00
0000oooo0?ooo`110?ooo`<00000503oool4000005@0oooo00<000000?ooo`3oool0ZP3oool00`00
0000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`140?oooa@00000F03oool00`000000
oooo0?ooo`2Z0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo0;00oooo
00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?oo
o`2`0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool0/03oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo0;00oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`090?oo
o`00A03oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3o
ool02@3oool004@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00T0oooo00140?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool004@0oooo0`00
00000`3oool000000?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103o
ool2000000/0oooo00140?ooool00000HP00000;0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00a`3oool02@3ookl0
M00000000018W=l0oooo0?oo_`1d0000000004RLg`0D0?ooo`030?noM000000000000080000000<0
04RL0=ooo`3oool04P3oool01@2oM0000000000000000000B9cO0:d0oooo00370?ooo`0:0?oo_`1d
04P0W=oo0;md0000M;l0oono07@0B02Lgol0_g@0001d_a80oooo00<0okmd00000018W=l00`3oool0
0`3ogi`0B01809cOo`0C0?ooo`030?oog`2LB000B9cO0:h0oooo003:0?ooo`030?oo_`1d0000M;oo
0080oooo00<0oono07@0001d_ol04@3oool00`3o_g@0001d0;ooo`040?ooo`030=nLB000M;l0oooo
01<0oooo00<0gia80018W03Oool0[@3oool00</0oooo00<0gia80018W03Oool00P3oool00`3OW4P0
04RL0=ooo`0A0?ooo`080;md000007@0_ooo0?ooo`3ooml0W4P000000018W=lD0?ooo`030?oOW018
07@0_ooo0:d0oooo002d0?ooo`030;md00000000000000D0000000<004RL0=ooo`3oool00`3oool0
303ogi`0B00000000000B9`0gooo0;md0000000007Bo0?ooo`3o_g@0001809cOo`80oooo00<0okmd
0000B02Lgol00`3oool0202oM00000000000B02Lgol0oooo0=nLB000B9`0gooo0P3oool00`2oM000
0000001d_`020?ooo`060?oo_`1d000000000000000007@0_ooo1@3oool00`3o_g@0000000000007
0000000907Boo`3oool0omnL04P000000000001d0;oo_`1d0000M;oo0080oooo00/0omnL04P00000
000004RL0=ooo`2oM0000000001d_`3oool0omnL04P000020000000907Boo`3OW4P000000018W03O
ool0okmd0000000004P0W=oo0080oooo00@0_g@00000000004P0W=oo0P3oool01@3o_g@000000000
000004P0W=oo00<0oooo00<0gia80018W03Oool00P3oool00`2oM0000000001d_`1m0?ooo`00]@3o
ool0103ookl0M0000018W03Oool30?ooo`030;md0000000007Bo00<0oooo00`0omnL04P0B02Lgol0
omnL04Qd_`2oM00007Bo0?noW02Lgol0oono07@00018W=l20?ooo`030?oo_`1d0000B9cO00<0oooo
00P0gia80018W03Ooml0W7BL0=ooo`3o_g@0001d0;ooo`80oooo00P0gia80018W03O_g@0M;oo0?oo
o`3o_g@0001d0;ooo`T0oooo00@0oooO09a80000B9`0gooo0`3oool02`3ooml0W4P00018W03Oool0
_g@00018W03Oool0oono07@0M01dM000B9cO0080oooo02@0omnL04P0B02Lgol0omnL04Qd_`2oM000
07Bo0?noW02Lgol0_g@00018W03Oool0oooo0;md001dM7@0001d0;oOW02L_ol0okmd0000B02Lgml0
W7BL0=ooo`3oool0gia80018W03Ooml0W7BL0=ooo`3ogi`0B01809cOo`3oool0omnL04P00000M;l2
0?ooo`030?noM00007@0_ooo0080oooo00@0gia80018W03O_g@0M;ooO03oool00;H0oooo00<0gia8
0000B02Lgol0103oool03@3ookl0M0000018W03Oool0oooo0?oog`2LB000B9cO0?ooo`3o_g@0M7Ad
0018W03Oool00P3oool00`2oM00004RL0=ooo`020?ooo`030;md0000B9`0gooo0080oooo00<0okmd
0000B02Lgol00P3oool00`3ookl0M00004RLg`020?ooo`030?oOW01804P0W=oo00<0oooo00<0_g@0
07Boo`3oool02@3oool00`3o_g@0001809cOo`050?ooo`040=nLM02Lgol0_g@0001d_`80oooo0100
oono07@00000B9`0gooo0?ooo`3ooml0W4P004RLg`3oool0okmd07AdM000B9`0gooo0?ooo`2oM000
07Bo0`3oool01`2oM000000007Boo`3oool0oono07@0001d_ol00`3oool00`3o_g@0001809cOo`02
0?ooo`030=nLB000B9`0gooo0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000B9cO0080oooo
00<0omnL04P0B02Lgol0O@3oool00;H0oooo00<0omnL04P0001d_ol01@3oool00`3ogi`0B000001d
_`020?ooo`070;md0000B9`0gooo0?ooo`2oM000001809cOo`020?ooo`030=nLB00007@0_ooo0080
oooo00<0gia80000M02oool00P3oool00`3ookl0M00004RLg`020?ooo`080?oog`2LB000001d0;oo
o`3oool0oooO09a80018W=l20?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool01@3o
ool00`3ookl0M00004RLg`070?ooo`030=nLB000B9`0gooo0080oooo00<0okmd0000M02oool00P3o
ool02`2oM00004RL0=ooo`3oool0_g@00000B02Lgol0oooo0?noM00007@0_ooo0080oooo00<0oono
07@00018W=l00P3oool00`2oM00007Bo0?ooo`020?ooo`030?oo_`1d0000B9cO0080oooo00<0okmd
0000M02oool00`3oool02`3OW4P0001d0;ooo`3ooml0W4P00000M02oool0oooo0?oog`2LB000B9cO
07d0oooo002f0?ooo`030?oo_`1d000007Bo00H0oooo00/0_g@00000B02Lgol0oooo0?noM00007@0
_ooo0?ooo`3ookl0M00007Boo`020?ooo`030?oOW0180000M;oo0080oooo00<0omnL04P0001d_ol0
0`3oool00`2oM00004RL0=ooo`020?ooo`030=nLB000B4P0B7Bo0080oooo00/0_g@0001d_`3oool0
oooo0;md0000B9`0gooo0?ooo`3ogi`0B00004RLg`060?ooo`030?oog`2LB00007Bo0080oooo00<0
oono09bLg`3oool00P3oool00`3ogi`0B00007Boo`020?ooo`030?oo_`1d0000M;oo0080oooo00/0
okmd0000M02oool0oooo0?oo_`1d0000M;oo0?ooo`3ookl0M00007Boo`030?ooo`070;md0000B9`0
gooo0?ooo`3OW4P004RL0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3ookl0M00007Boo`030?oo
o`070?oOW01804P0W=oo0?ooo`3OW4P004Q804Qd_`020?ooo`030;md0000M;l0oooo07`0oooo002g
0?ooo`030;md0000B9`0gooo00D0oooo00L0okmd00000018W=l0omoO0=oo_`1d0000M;oo0080oooo
00L0_g@0001d_`3oool0oooo0?oog`2LB000B9cO0080oooo00<0oooO09a80018W=l00`3oool00`3O
W4P0001809cOo`020?ooo`0;0?noM00007@0_kmd04RLg`3oool0okmd0000M02oool0oooo0;md0000
M;l00`3oool00`3OW4P0001d0;ooo`060?ooo`060=nLB00007@0_ooo0?ooo`3ogi`0B7Bo103oool0
302oM000001d0;ooo`3oool0oooO09a80018W=l0oooo0?oOg`3Ookl0M00007Boo`80oooo00L0_g@0
001d_`3oool0oooo0?noM00007@0_ooo0080oooo00L0gia80000M02oool0oooo0?oOW01804P0W=oo
00<0oooo00<0gia80000B02Lgol00P3oool00`3OW4P0001d0;ooo`020?ooo`0<0?oo_`1d0000M;oo
0?ooo`3o_g@0001d0;noM018W=l0oooo0?noM00007@0_oooO03oool00;L0oooo00<0okmd0000B02L
gol01@3oool01`3ogi`0B000001d_`3ogi`0B7Bo0;md0000M;l00P3oool00`3o_g@004RL0=ooo`02
0?ooo`030;md0000B9`0gooo0080oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`02
0?ooo`0<0?oog`2LB000M;oo0=nLB000M;l0omnL04P0B02Lgol0oooo0?oOW0180000B9cO0P3oool0
0`3OW4P0001d0;ooo`060?ooo`030?noM000000000000080000000<0001d0;ooo`3oool00P3oool0
303ooml0W4P00018W03Oool0oono09a8B000B9`0gooo0?oOW018M;l0_g@0001d_`80oooo00<0okmd
0018W03Oool00P3oool02`3OW4P0001d0;ooo`3oool0_g@00000B02Lgol0oooo0?oog`2LB000B9cO
00<0oooo00<0omnL04P00018W=l00`3oool0402oM000001d0;ooo`3oool0okmd0000M02oool0oooo
0?oog`2LB000M;oo0=nLB000M;l0omnL04P0B02Lgoml0?ooo`00]`3oool00`3ogi`0B00007Boo`05
0?ooo`070?oOW018000007Bo0?ooo`3o_g@00000001d_`020?ooo`050?oOW01804P0W=oo0?oo_`1d
00000`0000000`1d_kl0M000000000020000000?07Boo`3o_g@0000000000000B9`0gooo0?oo_`1d
0000000004RLg`3oool0okmd0000000004P0W=oo0080oooo00<0oono07@000000000100000000`18
W=l0oooo0?ooo`030?ooo`030?oo_`1d0000M;oo0080oooo00<0_gA809cOo`3oool0103oool02P3O
W4P000000000M02o_g@0001d0;ooo`3oool0okmd00000000M;l20?ooo`030?oOW01804P0W=oo00<0
oooo00P0omnL04P000000000B9bL07@00018W=l0oono07@000<0000000H0M;oo0?noM00000000000
0018W03Oool30?ooo`0?0?noM000000000000000001d_ol0oooo0?oo_`1d0000000004RLg`3oool0
okmd0000000004P0W=oo07`0oooo002g0?ooo`030?oog`2LB00007Bo00D0oooo00<0okmd00000018
W=l02`3oool00`3o_g@0001809cOo`020?ooo`030?noM00004P0W=oo01l0oooo00H0_g@0001d_`3o
ool0oooo0?oOW01dW=lO0?ooo`030?noM00007@0_ooo09@0oooo002h0?ooo`030;md0000B9`0gooo
00<0oooo00@0oooO09a8000007@0_ooo2`3oool00`3ooml0W4P0001d_`020?ooo`030?oog`2LB000
07Bo01l0oooo00<0gia80000M02oool0103oool00`3OW9`0_ooo0?ooo`0L0?ooo`030=nLM02Lgol0
oooo09<0oooo002h0?ooo`030=nLB00004P0W=oo0080oooo00@0oono07@000000000M;oo3@3oool0
0`3o_g@0001d0;ooo`020?ooo`030?noM00007@0_ooo0080oooo00@0oono07@00000B9`0gooo603o
ool00`3o_g@0001809cOo`030?ooo`030?oo_`1d04P0W=oo0280oooo00@0oono07@00000B9`0gooo
S@3oool00;L0oooo00<0_g@0000000000000100000000`00B9`0gooo0?ooo`0>0?ooo`0:0=nLB000
B9`0gooO09a80018W=l0gia80018W03Ooml0W4P004RLgaX0oooo00<0_g@00000000000001P000000
0`1d_ol0oooo0?ooo`2a0?ooo`00d03oool02@3OW4P000000000B02Lgol0oooo0=nLB00000000018
09cOo`3G0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-5.10114, -9.926, 0.0309227, \
0.0631196}}]
}, Closed]],

Cell[TextData[{
  "The shape of the attractor can be clarified by using ",
  StyleBox["tmin", "InlineInput"],
  " to suppress transients."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(duffingPlot[1, 1, 0.05, 10, 1.25, 0, 0, 100, 200, 
        MaxSteps \[Rule] 8000, PlotPoints \[Rule] 100];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.582789 0.174124 0.506018 0.0894545 [
[.06042 -0.0125 -9.34375 -15.6875 ]
[.06042 -0.0125 9.34375 0 ]
[.23454 -0.0125 -9.34375 -15.6875 ]
[.23454 -0.0125 9.34375 0 ]
[.40867 -0.0125 -9.34375 -15.6875 ]
[.40867 -0.0125 9.34375 0 ]
[.58279 -0.0125 -5 -15.6875 ]
[.58279 -0.0125 5 0 ]
[.75691 -0.0125 -5 -15.6875 ]
[.75691 -0.0125 5 0 ]
[.93104 -0.0125 -5 -15.6875 ]
[.93104 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.9688 -31.375 ]
[.5 -0.0125 21.9688 -15.6875 ]
[-0.0125 .1482 -18.6875 -7.84375 ]
[-0.0125 .1482 0 7.84375 ]
[-0.0125 .32711 -18.6875 -7.84375 ]
[-0.0125 .32711 0 7.84375 ]
[-0.0125 .50602 -10 -7.84375 ]
[-0.0125 .50602 0 7.84375 ]
[-0.0125 .68493 -10 -7.84375 ]
[-0.0125 .68493 0 7.84375 ]
[-0.0125 .86384 -10 -7.84375 ]
[-0.0125 .86384 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -34.375 -20.4688 ]
[-0.01875 .5 -18.6875 20.4688 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -43.9375 0 ]
[.5 1.0125 43.9375 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06042 0 m
.06042 .00625 L
s
gsave
.06042 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.23454 0 m
.23454 .00625 L
s
gsave
.23454 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.40867 0 m
.40867 .00625 L
s
gsave
.40867 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.58279 0 m
.58279 .00625 L
s
gsave
.58279 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.75691 0 m
.75691 .00625 L
s
gsave
.75691 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.93104 0 m
.93104 .00625 L
s
gsave
.93104 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.09524 0 m
.09524 .00375 L
s
.13007 0 m
.13007 .00375 L
s
.16489 0 m
.16489 .00375 L
s
.19972 0 m
.19972 .00375 L
s
.26937 0 m
.26937 .00375 L
s
.30419 0 m
.30419 .00375 L
s
.33902 0 m
.33902 .00375 L
s
.37384 0 m
.37384 .00375 L
s
.44349 0 m
.44349 .00375 L
s
.47831 0 m
.47831 .00375 L
s
.51314 0 m
.51314 .00375 L
s
.54796 0 m
.54796 .00375 L
s
.61761 0 m
.61761 .00375 L
s
.65244 0 m
.65244 .00375 L
s
.68726 0 m
.68726 .00375 L
s
.72209 0 m
.72209 .00375 L
s
.79174 0 m
.79174 .00375 L
s
.82656 0 m
.82656 .00375 L
s
.86139 0 m
.86139 .00375 L
s
.89621 0 m
.89621 .00375 L
s
.02559 0 m
.02559 .00375 L
s
.96586 0 m
.96586 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.9688 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
102.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .1482 m
.00625 .1482 L
s
gsave
-0.0125 .1482 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .32711 m
.00625 .32711 L
s
gsave
-0.0125 .32711 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .50602 m
.00625 .50602 L
s
gsave
-0.0125 .50602 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .68493 m
.00625 .68493 L
s
gsave
-0.0125 .68493 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .86384 m
.00625 .86384 L
s
gsave
-0.0125 .86384 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .19293 m
.00375 .19293 L
s
0 .23765 m
.00375 .23765 L
s
0 .28238 m
.00375 .28238 L
s
0 .37184 m
.00375 .37184 L
s
0 .41656 m
.00375 .41656 L
s
0 .46129 m
.00375 .46129 L
s
0 .55075 m
.00375 .55075 L
s
0 .59547 m
.00375 .59547 L
s
0 .6402 m
.00375 .6402 L
s
0 .72965 m
.00375 .72965 L
s
0 .77438 m
.00375 .77438 L
s
0 .81911 m
.00375 .81911 L
s
0 .10347 m
.00375 .10347 L
s
0 .05875 m
.00375 .05875 L
s
0 .01402 m
.00375 .01402 L
s
0 .90856 m
.00375 .90856 L
s
0 .95329 m
.00375 .95329 L
s
0 .99802 m
.00375 .99802 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -108 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
81.4688 11.8438 translate
90 rotate
-81.4688 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(velocity) show
99.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.06042 .99375 m
.06042 1 L
s
.23454 .99375 m
.23454 1 L
s
.40867 .99375 m
.40867 1 L
s
.58279 .99375 m
.58279 1 L
s
.75691 .99375 m
.75691 1 L
s
.93104 .99375 m
.93104 1 L
s
.125 Mabswid
.09524 .99625 m
.09524 1 L
s
.13007 .99625 m
.13007 1 L
s
.16489 .99625 m
.16489 1 L
s
.19972 .99625 m
.19972 1 L
s
.26937 .99625 m
.26937 1 L
s
.30419 .99625 m
.30419 1 L
s
.33902 .99625 m
.33902 1 L
s
.37384 .99625 m
.37384 1 L
s
.44349 .99625 m
.44349 1 L
s
.47831 .99625 m
.47831 1 L
s
.51314 .99625 m
.51314 1 L
s
.54796 .99625 m
.54796 1 L
s
.61761 .99625 m
.61761 1 L
s
.65244 .99625 m
.65244 1 L
s
.68726 .99625 m
.68726 1 L
s
.72209 .99625 m
.72209 1 L
s
.79174 .99625 m
.79174 1 L
s
.82656 .99625 m
.82656 1 L
s
.86139 .99625 m
.86139 1 L
s
.89621 .99625 m
.89621 1 L
s
.02559 .99625 m
.02559 1 L
s
.96586 .99625 m
.96586 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .1482 m
1 .1482 L
s
.99375 .32711 m
1 .32711 L
s
.99375 .50602 m
1 .50602 L
s
.99375 .68493 m
1 .68493 L
s
.99375 .86384 m
1 .86384 L
s
.125 Mabswid
.99625 .19293 m
1 .19293 L
s
.99625 .23765 m
1 .23765 L
s
.99625 .28238 m
1 .28238 L
s
.99625 .37184 m
1 .37184 L
s
.99625 .41656 m
1 .41656 L
s
.99625 .46129 m
1 .46129 L
s
.99625 .55075 m
1 .55075 L
s
.99625 .59547 m
1 .59547 L
s
.99625 .6402 m
1 .6402 L
s
.99625 .72965 m
1 .72965 L
s
.99625 .77438 m
1 .77438 L
s
.99625 .81911 m
1 .81911 L
s
.99625 .10347 m
1 .10347 L
s
.99625 .05875 m
1 .05875 L
s
.99625 .01402 m
1 .01402 L
s
.99625 .90856 m
1 .90856 L
s
.99625 .95329 m
1 .95329 L
s
.99625 .99802 m
1 .99802 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .50602 m
1 .50602 L
s
.58279 0 m
.58279 1 L
s
gsave
.5 1.0125 -104.938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Duffing) show
102.938 15.813 moveto
(Equation) show
146.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.91748 .62251 m
.92416 .61877 L
.93003 .61479 L
.94235 .60377 L
.95245 .59099 L
.96058 .57676 L
.96449 .5679 L
.96805 .55796 L
.97062 .54898 L
.97283 .53903 L
.97454 .52812 L
.97553 .51779 L
.97584 .51149 L
.97592 .50553 L
.97554 .49448 L
.9745 .48403 L
.97301 .47491 L
.97067 .46492 L
.96789 .45613 L
.9617 .44224 L
.95759 .43551 L
.95346 .43006 L
.94896 .42524 L
.94386 .42092 L
.93798 .41715 L
.9323 .41451 L
.92918 .41343 L
.92575 .41251 L
.92248 .41188 L
.91944 .41148 L
.91367 .4112 L
.90754 .4115 L
.90165 .4123 L
.89871 .41286 L
.89551 .41358 L
.88479 .41668 L
.86217 .42485 L
.85259 .42786 L
.84989 .42854 L
.84737 .42909 L
.84268 .42986 L
.83829 .43024 L
.83425 .43025 L
.82981 .42986 L
.82507 .42897 L
.82237 .42825 L
.81979 .4274 L
.81485 .42539 L
.80317 .41879 L
.79219 .41069 L
Mistroke
.77893 .3993 L
.69694 .31854 L
.57583 .20545 L
.49333 .13693 L
.4024 .07399 L
.34531 .04477 L
.3153 .03379 L
.298 .02911 L
.28174 .02595 L
.26403 .02403 L
.24724 .02381 L
.21589 .02821 L
.19855 .03375 L
.18273 .04104 L
.16571 .05162 L
.14813 .06597 L
.1232 .0936 L
.09842 .13205 L
.07751 .17668 L
.06087 .22433 L
.04564 .28408 L
.03867 .32068 L
.03335 .35617 L
.02611 .43122 L
.0242 .47438 L
.02381 .5138 L
.02639 .58503 L
.03258 .64943 L
.04335 .71585 L
.0592 .7803 L
.06867 .80947 L
.08002 .8386 L
.10312 .88423 L
.12815 .91933 L
.15306 .94379 L
.17726 .95995 L
.20066 .96988 L
.22675 .97551 L
.2551 .97619 L
.28309 .97222 L
.3122 .96398 L
.33657 .95432 L
.36258 .94163 L
.46638 .87276 L
.55707 .79814 L
.67539 .69838 L
.71868 .66752 L
.73956 .65531 L
.75781 .64656 L
.77644 .63975 L
Mistroke
.78599 .6371 L
.79608 .63492 L
.80513 .63345 L
.81365 .63244 L
.82125 .63179 L
.82554 .63152 L
.8295 .6313 L
.84445 .63074 L
.85229 .63048 L
.85656 .63031 L
.86054 .63013 L
.86775 .62968 L
.87563 .62896 L
.88227 .6281 L
.88933 .62688 L
.89803 .62482 L
.90611 .62222 L
.91319 .6193 L
.92066 .61541 L
.92728 .61115 L
.934 .60587 L
.9451 .5944 L
.95473 .58035 L
.95892 .57241 L
.96293 .56314 L
.96588 .55476 L
.9685 .54545 L
.97046 .53641 L
.9718 .52805 L
.97287 .5174 L
.97326 .50759 L
.97301 .49697 L
.97263 .49171 L
.97201 .48604 L
.97052 .47682 L
.96831 .46743 L
.96568 .45915 L
.96286 .45214 L
.95966 .44573 L
.95589 .43959 L
.94826 .43036 L
.94315 .42588 L
.9381 .42247 L
.9334 .42005 L
.9282 .41807 L
.92347 .41685 L
.91823 .41603 L
.91272 .41571 L
.90758 .41585 L
.90277 .4163 L
Mistroke
.89843 .41695 L
.89346 .41793 L
.88881 .41902 L
.86798 .42491 L
.86298 .42624 L
.8583 .42732 L
.85414 .42811 L
.84965 .42872 L
.84498 .42905 L
.84066 .42902 L
.83597 .42862 L
.83093 .4277 L
.82821 .427 L
.82523 .42607 L
.81974 .42391 L
.80897 .41814 L
.78689 .40163 L
.75837 .37556 L
.68721 .30659 L
.56985 .19948 L
.48149 .12773 L
.4311 .09212 L
.38058 .06196 L
.35495 .04935 L
.33029 .03926 L
.30405 .03108 L
.27465 .02553 L
.24474 .02453 L
.2174 .02851 L
.18783 .03918 L
.17326 .04733 L
.15766 .05855 L
.13288 .08264 L
.11172 .11082 L
.08931 .15097 L
.07056 .19625 L
.05564 .24415 L
.04421 .29287 L
.03447 .35056 L
.02757 .41523 L
.02428 .48691 L
.0256 .56544 L
.0315 .63758 L
.04086 .7008 L
.05357 .75846 L
.06776 .80546 L
.08695 .85271 L
.10737 .88991 L
.13189 .92245 L
.15965 .94773 L
Mistroke
.18443 .9624 L
.21234 .97186 L
.24284 .97528 L
.25997 .97452 L
.27552 .97237 L
.30545 .96479 L
.33322 .95423 L
.38105 .92953 L
.42854 .89854 L
.50437 .83978 L
.63391 .72768 L
.6797 .69 L
.71996 .66151 L
.73869 .65079 L
.75783 .64207 L
.76591 .63915 L
.77436 .63661 L
.78163 .63482 L
.78922 .63336 L
.79696 .63226 L
.80405 .63157 L
.81164 .63113 L
.81594 .631 L
.81995 .63095 L
.82722 .63099 L
.83385 .63113 L
.84152 .63138 L
.84881 .63162 L
.85534 .63179 L
.86229 .63188 L
.86822 .63183 L
.87477 .63161 L
.88176 .6311 L
.88926 .6302 L
.89627 .62893 L
.90264 .62736 L
.91022 .6249 L
.91722 .62194 L
.92976 .61458 L
.93638 .60937 L
.94218 .60384 L
.94853 .59652 L
.95399 .58883 L
.9619 .57446 L
.96545 .56608 L
.96875 .55658 L
.97157 .54621 L
.97365 .53602 L
.97499 .5267 L
.97589 .51643 L
Mistroke
.97614 .51051 L
.97619 .50414 L
.97569 .49274 L
.9745 .48196 L
.97281 .47246 L
.97036 .46269 L
.96699 .45275 L
.96276 .44336 L
.95822 .43561 L
.95351 .42924 L
.9487 .42408 L
.94407 .4201 L
.93894 .41663 L
.93316 .4137 L
.92768 .41173 L
.92167 .41036 L
.91822 .40989 L
.91497 .40965 L
.90934 .40965 L
.90336 .41015 L
.89775 .41103 L
.8927 .41212 L
.88062 .41557 L
.86967 .41929 L
.85951 .42273 L
.84916 .42564 L
.84388 .42669 L
.84091 .42711 L
.83814 .42737 L
.8333 .42751 L
.83058 .4274 L
.82809 .42716 L
.8236 .42643 L
.81878 .42518 L
.81414 .42354 L
.80985 .42165 L
.79881 .41535 L
.78756 .40718 L
.73336 .35694 L
.64073 .26702 L
.56904 .20197 L
.48558 .13324 L
.40064 .07507 L
.37399 .06032 L
.34801 .04798 L
.3243 .03875 L
.29769 .03106 L
.27004 .02652 L
.24055 .02623 L
.21335 .03093 L
Mistroke
.18824 .04035 L
.15957 .05841 L
.13452 .0822 L
.12135 .09845 L
.1076 .11882 L
.08454 .16297 L
.06377 .21838 L
.04811 .27709 L
.04138 .31035 L
.03524 .34858 L
.03028 .39005 L
.02702 .42985 L
.02459 .50468 L
.02646 .5729 L
.02915 .60989 L
.0334 .64915 L
.04446 .71676 L
.05768 .77147 L
.0756 .82489 L
.09753 .87193 L
.12062 .90761 L
.14381 .93346 L
.1662 .95119 L
.19165 .96452 L
.2191 .97228 L
.24951 .97435 L
.27713 .97129 L
.29231 .96789 L
.30863 .96302 L
.33773 .95158 L
.39143 .92272 L
.43749 .89175 L
.60706 .75165 L
.69888 .67757 L
.72007 .66365 L
.73871 .65321 L
.75466 .64589 L
.77088 .64015 L
.78001 .6377 L
.78815 .63599 L
.79625 .63469 L
.8038 .63382 L
.80809 .63345 L
.81259 .63316 L
.82064 .63283 L
.82512 .63274 L
.82929 .63271 L
.83387 .6327 L
.83877 .63273 L
.84684 .63279 L
Mistroke
.8514 .63281 L
.85562 .6328 L
.86335 .63268 L
.87154 .63232 L
.87883 .63174 L
.88563 .6309 L
.89302 .6296 L
.90089 .62768 L
.9084 .62521 L
.91508 .62241 L
.92207 .61876 L
.92936 .614 L
.94148 .60337 L
.95162 .5908 L
.95667 .58269 L
.96161 .57297 L
.96576 .5628 L
.96943 .55122 L
.97209 .53992 L
.97385 .52934 L
.97496 .51857 L
.97539 .50835 L
.97537 .50245 L
.97517 .49696 L
.97432 .4869 L
.97275 .47647 L
.97158 .47083 L
.97033 .46582 L
.96464 .44968 L
.96111 .44255 L
.95678 .43559 L
.95151 .42896 L
.94633 .42392 L
.93999 .41926 L
.93698 .41753 L
.93372 .41597 L
.93089 .41485 L
.92774 .41384 L
.92212 .41259 L
.91893 .41217 L
.91549 .41193 L
.91224 .41189 L
.90926 .412 L
.90328 .41261 L
.8977 .41358 L
.89275 .41472 L
.88746 .41618 L
.86577 .4235 L
.85648 .42644 L
.85154 .42772 L
Mistroke
.84699 .42864 L
.84314 .42918 L
.83903 .42948 L
.83449 .42944 L
.83033 .42903 L
.82541 .42808 L
.8229 .4274 L
.82009 .42648 L
.81019 .42198 L
.79775 .41397 L
.78485 .40366 L
.7196 .34079 L
.61669 .24233 L
.53766 .17303 L
.44672 .103 L
.40122 .07371 L
.3555 .04969 L
.32924 .03891 L
.30017 .03008 L
.27335 .02531 L
.24848 .02425 L
.22098 .02753 L
.19555 .03548 L
.16831 .05036 L
.14026 .07428 L
.12685 .08955 L
.11283 .10878 L
.0892 .1508 L
.06899 .20022 L
.05315 .25305 L
.03906 .31978 L
.03364 .35567 L
.02905 .39638 L
.02451 .47081 L
.02451 .54111 L
.0265 .58337 L
.02975 .62258 L
.03929 .69281 L
.0465 .72966 L
.05428 .76182 L
.07551 .82687 L
.0957 .8705 L
.11676 .9042 L
.14177 .93316 L
.17037 .95539 L
.19992 .96902 L
.21504 .973 L
.23167 .97537 L
.26125 .97504 L
.28859 .9703 L
Mistroke
.31521 .96222 L
.34342 .95047 L
.39241 .92368 L
.47496 .86511 L
.61606 .74581 L
.66934 .70147 L
.71615 .6675 L
.73602 .6557 L
.75362 .64704 L
.76864 .64119 L
.78438 .63666 L
.79209 .63502 L
.80051 .63363 L
.80471 .63309 L
.80922 .63261 L
.81736 .63197 L
.82499 .63159 L
.83301 .63137 L
.83985 .63127 L
.84734 .63118 L
.85194 .63112 L
.85629 .63104 L
.86442 .63077 L
.86896 .63053 L
.87315 .63024 L
.87773 .62981 L
.88256 .62923 L
.89049 .62794 L
.89784 .62627 L
.90576 .62386 L
.91407 .62052 L
.9215 .61666 L
.928 .61248 L
.93469 .60723 L
.94152 .60065 L
.94742 .5937 L
.95243 .58662 L
.96096 .5709 L
.9649 .56118 L
.96798 .55162 L
.97068 .5407 L
.97187 .53443 L
.97275 .52866 L
.97345 .52259 L
.97391 .51695 L
.97419 .51077 L
.97425 .50424 L
.97378 .49345 L
.97321 .48745 L
.97247 .48194 L
Mistroke
.9708 .473 L
.9684 .46376 L
.9653 .45481 L
.96189 .44721 L
.9547 .43548 L
.95016 .43005 L
.94575 .42583 L
.94029 .42173 L
.93504 .41875 L
.9291 .41634 L
.92605 .41544 L
.92266 .41469 L
.91693 .41394 L
.9137 .41377 L
.91075 .41377 L
.90502 .41413 L
.89962 .41487 L
.87786 .42042 L
.86774 .42359 L
.85877 .42614 L
.85393 .42726 L
.85139 .42774 L
.84869 .42817 L
.84598 .42849 L
.84347 .42869 L
.8406 .42879 L
.83799 .42875 L
.83339 .42837 L
.82836 .42747 L
.82354 .42613 L
.819 .42445 L
.80991 .41996 L
.80086 .41418 L
.77751 .39524 L
.712 .3321 L
.59664 .22388 L
.51669 .15579 L
.42643 .08955 L
.37937 .06172 L
.33246 .0404 L
.30565 .03181 L
.2762 .02601 L
.24923 .02462 L
.22443 .02724 L
.19716 .03526 L
.17225 .04821 L
.1459 .06916 L
.11928 .10006 L
.10672 .11898 L
.09378 .14218 L
Mistroke
.07249 .19125 L
.05496 .24705 L
.04195 .3049 L
.0321 .36963 L
.02592 .4416 L
.0242 .50457 L
.02609 .57332 L
.0325 .64532 L
.038 .68383 L
.04413 .71735 L
.05897 .77768 L
.07619 .82779 L
.09477 .86806 L
.11662 .90334 L
.13672 .92749 L
.16005 .94789 L
.18614 .96307 L
.21494 .97234 L
.24248 .97521 L
.26768 .97358 L
.29692 .96737 L
.31305 .96222 L
.32749 .95668 L
.38026 .93007 L
.48599 .85508 L
.62756 .73386 L
.71579 .66527 L
.73316 .65489 L
.75062 .6462 L
.76021 .64227 L
.76873 .63931 L
.77667 .63701 L
.78495 .63508 L
.79377 .63352 L
.80185 .63252 L
.8063 .63212 L
.81048 .63184 L
.81504 .63162 L
.81995 .63148 L
.82394 .63143 L
.82829 .63142 L
.83284 .63146 L
.83707 .63153 L
.84461 .63167 L
.85278 .63181 L
.86089 .63185 L
.86855 .6317 L
.87598 .63132 L
.8828 .6307 L
.89014 .62968 L
Mistroke
.89812 .62805 L
.90632 .62569 L
.91381 .62282 L
.92097 .61931 L
.92832 .61477 L
.94067 .60442 L
.94693 .59743 L
.95237 .59008 L
.95785 .58106 L
.96292 .57065 L
.96645 .56164 L
.96969 .55127 L
.97205 .54146 L
.97372 .5321 L
.97504 .52086 L
.97561 .51059 L
.97567 .50494 L
.97552 .49885 L
.97471 .488 L
.97342 .47864 L
.97173 .47023 L
.96938 .46148 L
.96629 .45273 L
.9625 .44439 L
.95842 .4373 L
.95435 .43159 L
.94967 .4263 L
.94498 .42204 L
.94052 .41882 L
.93589 .41618 L
.93142 .4142 L
.92608 .41251 L
.92109 .41149 L
.91558 .41093 L
.90973 .4109 L
.90399 .41136 L
.90077 .41181 L
.8978 .41233 L
.88676 .41502 L
.86708 .42146 L
.85665 .42478 L
.85168 .42609 L
.84719 .42705 L
.84253 .42775 L
.83754 .42812 L
.83507 .42814 L
.83238 .42803 L
.82955 .42776 L
.82692 .42736 L
.82242 .42635 L
Mistroke
.81747 .42477 L
.81269 .42278 L
.80817 .42051 L
.78905 .40753 L
.73159 .35395 L
.646 .2709 L
.50424 .14703 L
.45053 .10678 L
.39438 .07081 L
.36852 .05694 L
.34016 .04412 L
.3235 .03791 L
.30823 .03319 L
.27809 .0269 L
.24743 .0253 L
.21933 .02891 L
.18892 .03948 L
.17394 .04773 L
.15786 .05921 L
.13183 .08471 L
.10593 .12094 L
.08388 .16377 L
.06626 .20984 L
.05049 .26575 L
.03885 .32367 L
.02988 .39197 L
.02496 .46899 L
.02508 .54657 L
.02702 .58512 L
.03055 .62639 L
.04034 .69624 L
.05321 .75583 L
.06969 .80991 L
.08798 .85401 L
.10635 .88755 L
.12796 .9173 L
.15319 .94217 L
.18121 .96033 L
.20587 .96978 L
.23337 .97449 L
.24884 .97482 L
.26566 .97352 L
.29602 .96733 L
.32507 .95741 L
.35131 .94559 L
.40787 .91267 L
.46281 .8733 L
.6125 .74734 L
.70548 .67319 L
.72585 .66026 L
Mistroke
.74575 .64971 L
.76177 .64299 L
.77048 .64005 L
.77855 .63779 L
.786 .63609 L
.79398 .63465 L
.80117 .63369 L
.80777 .63305 L
.81487 .63259 L
.82266 .6323 L
.83078 .6322 L
.83839 .6322 L
.8455 .63225 L
.85226 .63227 L
.85832 .63223 L
.86493 .63208 L
.87209 .63174 L
.87968 .6311 L
.88679 .63018 L
.89319 .62903 L
.90048 .62726 L
.90717 .62513 L
.91436 .62222 L
.92184 .61837 L
.92939 .61346 L
.9362 .60797 L
.94206 .60224 L
.94788 .5954 L
.95726 .58106 L
.96437 .56581 L
.9676 .55665 L
.97013 .5477 L
.97233 .53758 L
.97402 .52643 L
.97497 .51514 L
.97521 .50468 L
.97506 .49873 L
.97475 .49339 L
.97417 .48733 L
.97344 .48173 L
.97253 .47639 L
.97138 .4709 L
.96885 .46154 L
.96549 .45223 L
.96109 .44302 L
.95681 .43609 L
.95254 .43054 L
.94724 .42509 L
.94189 .42085 L
.93675 .41773 L
Mistroke
.93185 .4155 L
.92634 .41373 L
.92038 .41258 L
.91458 .41212 L
.91128 .41211 L
.90821 .41225 L
.90497 .41255 L
.90203 .41294 L
.89548 .41416 L
.88998 .41552 L
.88411 .41723 L
.87374 .42065 L
.86212 .42454 L
.85598 .42634 L
.85033 .4277 L
.8456 .42852 L
.84055 .42902 L
.83769 .4291 L
.83497 .42904 L
.83252 .42886 L
.82984 .42851 L
.82731 .42806 L
.82455 .4274 L
.81949 .42579 L
.81444 .42368 L
.80966 .42124 L
.78481 .4033 L
.72235 .34349 L
.63058 .25528 L
.47983 .12721 L
.42313 .08747 L
.3932 .06931 L
.36443 .05413 L
.33811 .04252 L
.30837 .03247 L
.27793 .02613 L
.26113 .02461 L
.24532 .02464 L
.21633 .02888 L
.18628 .04002 L
.16136 .05568 L
.13527 .07995 L
.10899 .11507 L
.09535 .13887 L
.08375 .16306 L
.0636 .21688 L
.04796 .27522 L
.03651 .33638 L
.02824 .40675 L
.02449 .47584 L
Mistroke
.02458 .53961 L
.02894 .61296 L
.03339 .65305 L
.03875 .6889 L
.05149 .75041 L
.06886 .80869 L
.09068 .86046 L
.10437 .88523 L
.11772 .90516 L
.14389 .93484 L
.1577 .94646 L
.17323 .95676 L
.20093 .96902 L
.23118 .97501 L
.2599 .97484 L
.28592 .97059 L
.31209 .96297 L
.33929 .95201 L
.38621 .92706 L
.4811 .85977 L
.61233 .74832 L
.70595 .6735 L
.72643 .66042 L
.74638 .64973 L
.76242 .64289 L
.77113 .63989 L
.77918 .63757 L
.78665 .6358 L
.79464 .63431 L
.80183 .63328 L
.80841 .63259 L
.8155 .63207 L
.82327 .63172 L
.83136 .63155 L
.83891 .6315 L
.846 .63149 L
.85273 .63146 L
.85876 .63138 L
.86532 .63119 L
.87243 .63081 L
.87995 .63013 L
.88634 .62929 L
.89333 .62801 L
.90061 .62621 L
.90727 .62407 L
.91443 .62114 L
.92186 .61729 L
.92937 .61238 L
.93613 .6069 L
.9477 .59441 L
Mistroke
.957 .58015 L
.96404 .56503 L
.96705 .5565 L
.96982 .54671 L
.97207 .53616 L
.97355 .52606 L
.97448 .51513 L
.9747 .50895 L
.9747 .50325 L
.97422 .49296 L
.97301 .48232 L
.97117 .47233 L
.96886 .46344 L
.96634 .45597 L
.96318 .44849 L
.95922 .44105 L
.95435 .43388 L
.94876 .42756 L
.94317 .42274 L
.93765 .41915 L
.93245 .41663 L
.92951 .41553 L
.92628 .41457 L
.92034 .41338 L
.91473 .41289 L
.90958 .41291 L
.90393 .41337 L
.89804 .41427 L
.89294 .41536 L
.88827 .41655 L
.8779 .41965 L
.8662 .42344 L
.86063 .42511 L
.8556 .42645 L
.85118 .42742 L
.84637 .4282 L
.84157 .42864 L
.83651 .42866 L
.83391 .42849 L
.83143 .42819 L
.82674 .42731 L
.82163 .42583 L
.81592 .42356 L
.80516 .41772 L
.79441 .4102 L
.72839 .34894 L
.62082 .24617 L
.54559 .17993 L
.46061 .11316 L
.41498 .08245 L
Mistroke
.36949 .0568 L
.3436 .04493 L
.31949 .03601 L
.29223 .02877 L
.26272 .02491 L
.2332 .02595 L
.20614 .03206 L
.17704 .04534 L
.16272 .05493 L
.14734 .06789 L
.12273 .09547 L
.0983 .1337 L
.07766 .17791 L
.06123 .22502 L
.04531 .28803 L
.03418 .35346 L
.02763 .41583 L
.02439 .48553 L
.02553 .56205 L
.02794 .59998 L
.03197 .64067 L
.04252 .70904 L
.05606 .76734 L
.07294 .81939 L
.09157 .86184 L
.11015 .89395 L
.13201 .92239 L
.15729 .94581 L
.18542 .96272 L
.21011 .97125 L
.23774 .97508 L
.26806 .97353 L
.28323 .97082 L
.2997 .96658 L
.32846 .95631 L
.35456 .94422 L
.4653 .87155 L
.61414 .74579 L
.66812 .70054 L
.7158 .66581 L
.73493 .65449 L
.75384 .64537 L
.76916 .63969 L
.77756 .63727 L
.78541 .63544 L
.79279 .63409 L
.80075 .633 L
.80794 .63233 L
.81458 .63192 L
.82245 .63167 L
Mistroke
.82958 .63161 L
.8378 .63166 L
.84554 .63176 L
.85236 .63183 L
.85957 .63183 L
.86571 .63172 L
.87244 .63143 L
.87967 .63087 L
.88737 .62992 L
.89457 .62861 L
.90105 .62702 L
.90807 .62478 L
.91453 .62216 L
.92199 .61836 L
.92859 .61416 L
.94115 .60341 L
.94718 .59657 L
.95301 .58851 L
.95731 .58136 L
.96145 .57316 L
.96765 .55711 L
.97059 .54662 L
.97274 .53639 L
.97413 .52702 L
.97507 .51678 L
.9754 .50563 L
.97507 .49536 L
.9746 .48957 L
.974 .48438 L
.97311 .47853 L
.97207 .47312 L
.96947 .46285 L
.96645 .45402 L
.96252 .4452 L
.95771 .43691 L
.95306 .43067 L
.94764 .42497 L
.94218 .42056 L
.93695 .41734 L
.93205 .41507 L
.92657 .41326 L
.92076 .41207 L
.91529 .41155 L
.90934 .41155 L
.90634 .41176 L
.90305 .41212 L
.89728 .41308 L
.89193 .41428 L
.86808 .42175 L
.85805 .42493 L
Mistroke
.85324 .42623 L
.84883 .4272 L
.84385 .428 L
.84123 .42826 L
.83845 .42842 L
.83349 .42834 L
.82898 .42786 L
.82445 .42695 L
.8196 .42551 L
.81537 .42387 L
.81062 .42163 L
.79947 .41488 L
.78815 .40637 L
.73334 .35505 L
.6316 .25693 L
.56019 .19299 L
.47869 .12693 L
.3914 .06882 L
.34292 .04497 L
.31429 .03468 L
.28692 .02804 L
.25881 .02502 L
.22917 .02678 L
.20407 .03301 L
.17715 .04552 L
.1491 .0665 L
.13405 .08188 L
.12088 .09822 L
.09689 .1366 L
.07665 .18077 L
.05948 .23128 L
.04447 .29261 L
.03392 .35602 L
.02759 .41737 L
.02439 .49143 L
.02462 .5336 L
.02614 .57241 L
.03217 .64168 L
.04299 .71102 L
.05069 .74621 L
.0588 .77662 L
.06857 .8071 L
.08042 .83766 L
.10281 .88203 L
.11628 .9026 L
.12913 .91892 L
.15493 .9438 L
.18395 .96187 L
.21166 .97146 L
.23824 .97497 L
Mistroke
.26288 .97405 L
.28988 .96915 L
.31766 .96047 L
.34315 .94973 L
.38695 .92609 L
.43122 .89688 L
.58618 .77034 L
.6455 .71942 L
.69665 .67938 L
.7181 .66496 L
.73679 .65414 L
.75276 .64648 L
.76884 .64043 L
.77677 .6381 L
.78534 .63605 L
.79303 .63461 L
.80015 .6336 L
.80444 .63313 L
.80849 .63277 L
.81605 .6323 L
.82418 .63203 L
.82876 .63197 L
.83301 .63195 L
.83703 .63195 L
.84127 .63197 L
.84593 .632 L
.8502 .63202 L
.85791 .63199 L
.86228 .63191 L
.86635 .63178 L
.87446 .63133 L
.87899 .63094 L
.88309 .63047 L
.88761 .62982 L
.89249 .62894 L
.90124 .62681 L
.90852 .62442 L
.91504 .62169 L
.92186 .61815 L
.92904 .61351 L
.94095 .6032 L
.95101 .59093 L
.95649 .58222 L
.96092 .57364 L
.96507 .56373 L
.9688 .55235 L
.97152 .54131 L
.97336 .53087 L
.97452 .52075 L
.9751 .51004 L
Mistroke
.975 .49889 L
.97428 .48895 L
.97363 .48359 L
.97273 .47789 L
.97059 .46795 L
.96802 .45923 L
.96474 .45068 L
.95757 .43736 L
.95294 .43116 L
.94755 .42549 L
.94213 .42112 L
.93693 .41793 L
.93098 .41526 L
.92753 .41413 L
.92429 .41333 L
.92084 .41271 L
.91768 .41235 L
.91403 .41215 L
.91057 .41217 L
.90521 .41255 L
.89949 .41337 L
.89415 .41446 L
.88933 .41568 L
.86739 .42271 L
.85716 .42588 L
.85191 .42719 L
.84906 .42777 L
.8464 .42822 L
.84387 .42855 L
.84116 .42878 L
.83643 .42888 L
.83162 .42854 L
.82717 .42781 L
.82299 .42675 L
.81844 .42518 L
.80997 .42121 L
.79925 .41448 L
.78867 .40639 L
.73031 .35138 L
.64045 .26455 L
.49281 .13725 L
.44544 .10248 L
.38982 .06754 L
.35599 .05029 L
.32398 .03744 L
.30831 .03259 L
.29104 .02846 L
.27461 .02585 L
.25929 .02468 L
.22823 .02658 L
Mistroke
.19926 .03441 L
.17381 .04719 L
.14725 .06784 L
.11991 .09913 L
.10698 .11848 L
.09356 .14254 L
.0721 .19219 L
.05514 .24626 L
.0409 .31044 L
.03528 .34515 L
.03037 .38488 L
.02514 .45754 L
.02435 .52703 L
.0257 .56652 L
.02851 .60748 L
.03701 .67786 L
.04361 .71489 L
.05087 .7476 L
.05993 .78104 L
.07104 .81449 L
.09235 .86356 L
.1151 .90135 L
.1392 .93013 L
.16273 .94993 L
.18919 .96454 L
.21907 .97328 L
.23426 .97508 L
.25062 .97529 L
.2801 .97168 L
.30835 .96408 L
.33405 .95416 L
.38983 .92467 L
.48033 .86014 L
.61036 .7497 L
.66566 .70326 L
.71422 .66764 L
.73369 .65595 L
.75284 .64651 L
.76834 .64059 L
.7768 .63803 L
.78468 .63609 L
.79215 .63462 L
.80019 .63342 L
.80744 .63264 L
.81411 .63215 L
.82128 .63183 L
.82917 .63166 L
.83314 .63162 L
.83741 .63162 L
.84513 .63164 L
Mistroke
.85193 .63164 L
.85936 .63157 L
.8671 .63135 L
.87428 .63093 L
.881 .63029 L
.88707 .62947 L
.89402 .62818 L
.90049 .62658 L
.90734 .6244 L
.91454 .62147 L
.927 .61447 L
.93417 .60904 L
.94061 .60306 L
.95153 .58965 L
.95643 .58176 L
.96109 .57265 L
.96462 .56424 L
.96788 .55468 L
.9707 .54402 L
.97272 .53369 L
.97359 .52762 L
.97428 .52118 L
.97467 .51568 L
.97491 .50965 L
.9748 .49913 L
.97412 .4894 L
.97303 .48091 L
.97135 .47207 L
.96897 .46295 L
.96585 .45398 L
.96274 .44695 L
.95888 .43993 L
.95103 .42942 L
.94616 .42467 L
.94146 .42106 L
.93695 .41831 L
.93187 .41596 L
.92697 .41432 L
.92235 .41328 L
.91694 .4126 L
.9118 .41243 L
.90587 .41275 L
.9005 .41345 L
.89548 .4144 L
.8909 .41547 L
.88074 .41841 L
.86148 .42463 L
.85643 .42604 L
.85176 .42715 L
.84695 .42801 L
Mistroke
.84442 .42834 L
.84169 .42857 L
.83677 .42867 L
.83397 .42852 L
.83136 .42825 L
.82859 .4278 L
.82605 .42726 L
.82028 .42553 L
.81524 .42348 L
.8096 .42064 L
.7988 .41378 L
.7438 .36447 L
.64018 .26427 L
.57458 .20498 L
.48461 .13103 L
.43718 .09694 L
.38179 .06324 L
.35349 .04926 L
.32587 .03821 L
.30058 .03069 L
.27264 .02575 L
.25584 .02472 L
.24003 .02526 L
.21065 .03069 L
.19437 .03654 L
.17962 .04387 L
.16373 .0542 L
.14741 .06785 L
.12151 .09713 L
.0992 .13207 L
.07727 .17892 L
.06648 .20849 L
.05734 .23845 L
.04294 .29988 L
.03686 .3349 L
.03161 .3741 L
.02776 .41424 L
.02521 .45733 L
.02458 .53515 L
.02849 .60655 L
.0359 .67014 L
.04798 .73508 L
.06504 .79703 L
.07641 .82824 L
.08785 .85429 L
.10111 .87937 L
.11666 .90333 L
.14478 .93532 L
.16097 .94851 L
.17649 .95825 L
Mistroke
.19191 .96548 L
.20673 .97039 L
.23482 .97494 L
.26517 .97392 L
.28224 .97105 L
.29792 .96712 L
.32396 .95816 L
.35139 .94585 L
.39888 .91877 L
.49476 .84822 L
.6372 .72623 L
.68315 .68907 L
.72426 .66085 L
.7452 .64954 L
.76304 .64202 L
.77133 .63926 L
.78016 .63684 L
.78776 .63518 L
.79584 .63381 L
.8041 .63282 L
.81179 .63221 L
.81646 .63197 L
.82089 .63181 L
.82486 .63173 L
.82919 .63169 L
.83382 .63169 L
.83802 .63172 L
.84286 .63176 L
.84742 .6318 L
.85556 .63184 L
.86014 .6318 L
.86435 .63172 L
.87191 .6314 L
.87894 .63086 L
.8866 .62993 L
.89087 .62922 L
.89473 .62845 L
.90244 .62647 L
.91064 .62364 L
.91819 .62022 L
.92495 .61637 L
.93128 .61197 L
.93763 .6066 L
.94808 .59513 L
.95777 .58017 L
.96242 .5706 L
.96615 .5611 L
.9691 .55173 L
.97137 .54258 L
.97297 .53416 L
Mistroke
.97423 .5249 L
.97504 .51473 L
.97525 .50401 L
.9749 .49499 L
.97398 .48531 L
.97322 .48002 L
.97219 .47439 L
.96982 .46461 L
.96693 .45574 L
.96377 .44817 L
.95946 .44004 L
.9551 .43358 L
.9496 .42719 L
.94405 .42225 L
.9389 .41874 L
.93326 .41587 L
.92832 .41406 L
.92282 .41272 L
.91681 .41195 L
.91344 .4118 L
.91036 .41183 L
.90439 .41228 L
.89878 .41312 L
.87645 .41924 L
.85705 .42549 L
.85227 .42671 L
.84778 .42762 L
.84533 .428 L
.84267 .42831 L
.83801 .42858 L
.83529 .42855 L
.83282 .4284 L
.82996 .42807 L
.82726 .42761 L
.82238 .4264 L
.817 .42451 L
.80778 .41998 L
.79696 .41294 L
.77183 .39192 L
.7097 .33143 L
.5987 .22667 L
.52265 .1613 L
.43751 .09734 L
.38397 .06457 L
.35509 .05013 L
.33846 .04304 L
.323 .03735 L
.30711 .0325 L
.29023 .02854 L
.25905 .02491 L
Mistroke
.24141 .02526 L
.22505 .02737 L
.20721 .03185 L
.18839 .03937 L
.15912 .05783 L
.14321 .07201 L
.12904 .08763 L
.10452 .12287 L
.0812 .16949 L
.06312 .21906 L
.04897 .27155 L
.0369 .33492 L
.02829 .40807 L
.02563 .44854 L
.02441 .48707 L
.02543 .55911 L
.03132 .6347 L
.03674 .67545 L
.043 .7113 L
.0561 .76729 L
.07386 .82164 L
.09569 .86961 L
.11857 .90585 L
.13248 .92281 L
.1482 .93831 L
.16248 .94951 L
.178 .959 L
.20808 .97068 L
.23634 .97497 L
.25202 .975 L
.26888 .97339 L
.29912 .96673 L
.31641 .96102 L
.33433 .95381 L
.36556 .93846 L
.46432 .87241 L
.54101 .80954 L
.66819 .70095 L
.71276 .66836 L
.73334 .65596 L
.75355 .64608 L
.77027 .6399 L
.77947 .63731 L
.78792 .63543 L
.79559 .63412 L
.80253 .63322 L
.8105 .63251 L
.81801 .6321 L
.82465 .63191 L
.83199 .63183 L
Mistroke
.83964 .63185 L
.84684 .63189 L
.85354 .6319 L
.85968 .63185 L
.86642 .63167 L
.87351 .6313 L
.88068 .63065 L
.8883 .62961 L
.89542 .62822 L
.90181 .62656 L
.9092 .62407 L
.91702 .62066 L
.9242 .61667 L
.93052 .61234 L
.94231 .60169 L
.94823 .59466 L
.95342 .58725 L
.96143 .57245 L
.96522 .56325 L
.96822 .55426 L
.9711 .54315 L
.97312 .53238 L
.97434 .52254 L
.97503 .51186 L
.97513 .50631 L
.97503 .50028 L
.9747 .49405 L
.97419 .48833 L
.9728 .47837 L
.97175 .47299 L
.97064 .46823 L
.96789 .45892 L
.96435 .44984 L
.96085 .44281 L
.95653 .43589 L
.95145 .42947 L
.94552 .42375 L
.93957 .41946 L
.93388 .41646 L
.92833 .41439 L
.92309 .41309 L
.91726 .41232 L
.91399 .41215 L
.91101 .41215 L
.905 .41256 L
.90162 .413 L
.89853 .41352 L
.88702 .41629 L
.86697 .42278 L
.85655 .42596 L
Mistroke
.85156 .42718 L
.84699 .42804 L
.84275 .42856 L
.83827 .42879 L
.8333 .42861 L
.82878 .42802 L
.82461 .4271 L
.82004 .42569 L
.81151 .42195 L
.80072 .41543 L
.7878 .40564 L
.75672 .37732 L
.6758 .29811 L
.54417 .1789 L
.45564 .10969 L
.41139 .08029 L
.35917 .05183 L
.32913 .03933 L
.30033 .03058 L
.26946 .02538 L
.25202 .02466 L
.23605 .02559 L
.21885 .02849 L
.203 .0331 L
.18582 .04047 L
.16785 .05119 L
.15117 .06433 L
.13595 .07946 L
.10911 .11516 L
.08683 .15654 L
.06625 .20906 L
.05152 .26051 L
.03874 .32302 L
.02932 .39574 L
.02611 .4382 L
.02453 .47752 L
.02516 .55416 L
.03023 .62519 L
.03873 .68824 L
.05174 .75101 L
.06735 .80401 L
.08418 .84653 L
.10523 .88634 L
.13066 .92095 L
.14425 .93492 L
.15923 .94735 L
.18715 .96358 L
.20287 .96938 L
.21753 .97292 L
.23371 .97496 L
Mistroke
.25089 .9752 L
.27967 .97168 L
.29589 .9678 L
.31093 .96312 L
.33845 .95212 L
.36295 .94001 L
.41538 .90809 L
.67518 .69558 L
.71633 .66613 L
.73632 .65439 L
.75391 .64593 L
.76955 .6401 L
.77754 .63776 L
.78583 .63579 L
.79274 .63448 L
.80025 .63339 L
.80703 .63267 L
.81332 .63221 L
.82137 .63185 L
.82591 .63174 L
.83011 .63169 L
.8378 .63168 L
.84597 .63172 L
.85326 .63173 L
.8601 .63166 L
.86759 .63144 L
.87565 .63095 L
.88369 .6301 L
.88821 .62943 L
.89239 .62867 L
.90076 .62666 L
.90951 .62376 L
.91746 .62024 L
.92472 .61615 L
.93101 .61177 L
.93746 .60634 L
.94867 .59388 L
.95766 .57979 L
.96234 .57014 L
.96615 .56035 L
.96902 .55113 L
.97153 .5407 L
.97333 .53032 L
.97407 .52434 L
.97458 .51869 L
.97491 .51277 L
.97504 .50735 L
.97498 .50143 L
.9747 .49527 L
.97374 .48523 L
Mistroke
.97231 .47621 L
.97017 .46679 L
.96725 .45737 L
.96402 .44936 L
.96061 .44261 L
.95654 .4361 L
.95163 .42986 L
.94737 .42553 L
.94253 .4216 L
.93721 .41825 L
.93205 .41583 L
.92697 .41412 L
.92133 .41291 L
.91596 .41234 L
.91096 .41226 L
.90601 .41256 L
.90154 .4131 L
.89643 .41402 L
.89166 .41511 L
.86973 .42188 L
.85965 .42506 L
.85537 .42623 L
.85077 .42729 L
.84604 .4281 L
.8416 .42856 L
.83653 .42867 L
.83184 .42834 L
.82703 .42754 L
.82426 .42686 L
.82164 .42608 L
.81628 .42405 L
.81032 .42116 L
.78903 .4065 L
.76187 .38217 L
.69421 .3159 L
.58078 .21048 L
.49482 .13892 L
.44564 .10274 L
.3963 .07134 L
.34654 .04624 L
.32049 .03641 L
.29129 .02864 L
.26166 .02491 L
.24497 .02494 L
.22975 .02648 L
.20046 .0341 L
.17327 .04768 L
.14984 .06561 L
.12609 .09118 L
.10515 .1217 L
Mistroke
.0877 .15476 L
.06928 .20029 L
.05247 .25683 L
.03992 .3163 L
.0315 .37509 L
.02558 .44903 L
.02432 .52056 L
.0268 .58433 L
.0333 .65136 L
.04465 .71967 L
.05196 .75173 L
.06117 .78487 L
.08012 .8372 L
.1006 .8785 L
.12211 .91057 L
.14641 .9368 L
.16821 .95339 L
.19282 .96584 L
.22003 .97327 L
.24935 .97516 L
.27697 .97211 L
.30179 .96599 L
.33094 .95531 L
.36091 .94099 L
.41189 .91031 L
.51225 .83385 L
.64491 .71986 L
.69168 .68284 L
.72903 .65819 L
.74756 .64855 L
.75689 .6445 L
.76654 .64092 L
.77445 .63846 L
.78304 .63627 L
.79074 .63472 L
.7979 .63361 L
.80464 .63284 L
.81197 .63226 L
.8196 .6319 L
.82669 .63175 L
.83334 .63171 L
.83938 .63174 L
.84598 .6318 L
.85297 .63183 L
.86057 .63178 L
.86758 .63158 L
.87511 .63115 L
.87937 .63077 L
.88335 .63032 L
.89048 .62923 L
Mistroke
.89694 .62787 L
.90429 .62583 L
.91115 .62335 L
.91829 .62007 L
.92576 .61575 L
.93209 .61122 L
.93846 .6057 L
.94948 .59312 L
.95818 .57922 L
.96234 .57059 L
.9662 .56074 L
.96901 .55179 L
.97148 .5417 L
.97269 .53542 L
.97359 .52954 L
.97427 .52389 L
.97479 .51786 L
.97519 .50745 L
.97513 .50157 L
.9749 .49611 L
.97414 .48721 L
.97277 .47779 L
.97076 .46842 L
.9684 .4602 L
.96306 .44689 L
.95951 .44032 L
.95599 .43495 L
.9518 .42971 L
.94708 .42494 L
.94159 .42062 L
.93632 .41746 L
.93125 .41521 L
.92641 .41367 L
.92102 .41257 L
.91519 .41201 L
.91197 .41195 L
.90895 .41204 L
.90332 .41257 L
.89731 .41356 L
.89091 .41502 L
.86969 .42166 L
.85823 .42528 L
.85217 .42684 L
.84926 .42745 L
.84662 .42791 L
.84192 .42846 L
.83691 .42864 L
.8343 .42855 L
.83146 .4283 L
.82876 .42791 L
Mistroke
.82625 .42742 L
.82172 .42619 L
.81676 .42438 L
.80743 .41972 L
.79551 .41178 L
.78354 .40219 L
.71524 .33673 L
.61847 .24449 L
.54527 .17998 L
.46072 .11347 L
.4056 .07689 L
.37472 .0596 L
.34084 .04394 L
.31146 .03367 L
.29453 .02937 L
.2786 .02654 L
.25045 .02479 L
.22032 .02827 L
.19023 .03845 L
.17359 .04753 L
.15852 .05826 L
.13196 .08411 L
.10575 .12075 L
.08462 .16154 L
.06712 .20664 L
.05095 .26309 L
.0375 .33096 L
.0288 .40192 L
.02481 .46914 L
.02496 .54764 L
.02978 .6203 L
.03814 .68436 L
.04898 .73935 L
.06406 .79398 L
.08324 .8443 L
.10538 .88645 L
.11861 .90596 L
.13175 .92205 L
.1585 .94669 L
.18409 .96208 L
.19909 .96808 L
.21524 .97237 L
.24452 .97522 L
.26248 .97423 L
.27932 .97165 L
.29434 .96812 L
.31042 .96318 L
.33995 .95133 L
.36671 .93787 L
.42414 .90197 L
Mistroke
.52393 .82409 L
.65327 .71303 L
.70001 .67699 L
.72146 .66284 L
.74243 .65118 L
.75957 .6436 L
.76833 .64048 L
.77756 .63776 L
.78586 .6358 L
.79337 .63441 L
.80049 .63341 L
.80792 .63266 L
.81523 .63217 L
.82295 .63189 L
.82698 .63182 L
.8314 .63178 L
.83918 .63179 L
.84652 .63184 L
.8544 .63185 L
.86184 .63176 L
.86862 .63153 L
.87561 .63109 L
.88206 .63045 L
.8891 .62943 L
.8965 .62793 L
.90282 .62622 L
.90867 .62424 L
.92157 .6182 L
.92795 .61418 L
.9344 .60923 L
.9451 .59853 L
.95516 .58442 L
.96008 .5753 L
.96409 .56617 L
.96771 .55589 L
.9705 .54573 L
.97246 .53632 L
.97398 .52591 L
.97452 .52047 L
.97491 .51448 L
.97511 .50823 L
.97508 .50242 L
.97456 .49219 L
.97331 .48153 L
.97154 .47204 L
.96939 .46369 L
.96652 .45512 L
.9629 .44676 L
.95896 .4396 L
.95487 .43361 L
Mistroke
.95086 .42883 L
.94636 .42447 L
.94204 .42109 L
.93711 .41805 L
.9325 .41587 L
.9281 .41431 L
.92283 .41304 L
.91797 .41237 L
.91234 .41212 L
.907 .41235 L
.90173 .41297 L
.89609 .41399 L
.88609 .41653 L
.8645 .42354 L
.85405 .42655 L
.84893 .42765 L
.84605 .42812 L
.84339 .42845 L
.83863 .42874 L
.8343 .42864 L
.82929 .42806 L
.82451 .42703 L
.82031 .42574 L
.8156 .42388 L
.80569 .41863 L
.78591 .40407 L
.72517 .34637 L
.62381 .24924 L
.47477 .12366 L
.42461 .08866 L
.36661 .05543 L
.3486 .0471 L
.33137 .04018 L
.31437 .03445 L
.29859 .0302 L
.26735 .02524 L
.25085 .02471 L
.23345 .02593 L
.20531 .03234 L
.17582 .04607 L
.149 .06634 L
.12581 .09148 L
.10058 .12954 L
.07628 .18136 L
.05694 .23982 L
.0427 .30106 L
.03214 .36941 L
.02613 .43814 L
.02422 .50138 L
.02594 .57037 L
Mistroke
.03222 .64286 L
.03766 .68161 L
.04374 .71529 L
.05851 .77602 L
.07565 .8264 L
.09425 .86706 L
.11612 .90265 L
.13626 .927 L
.15959 .94757 L
.18575 .96292 L
.21458 .97231 L
.24214 .97527 L
.26732 .97371 L
.29671 .96753 L
.31138 .96292 L
.32739 .95685 L
.38029 .93025 L
.48619 .8553 L
.62794 .73436 L
.6779 .6934 L
.71675 .6658 L
.75182 .64679 L
.76886 .64029 L
.77809 .63759 L
.78634 .63566 L
.79524 .63407 L
.80337 .63303 L
.8076 .63262 L
.81224 .63228 L
.81707 .63202 L
.82158 .63186 L
.82583 .63176 L
.82987 .63172 L
.83744 .63171 L
.84559 .63175 L
.85021 .63177 L
.85449 .63177 L
.86262 .63166 L
.87026 .63137 L
.8771 .63088 L
.88446 .63006 L
.89243 .62873 L
.89641 .62786 L
.90074 .62675 L
.90829 .6243 L
.91518 .62143 L
.9223 .6177 L
.92957 .61294 L
.94172 .60221 L
.94786 .59504 L
Mistroke
.95317 .58753 L
.95848 .57837 L
.96336 .56787 L
.96674 .55879 L
.96981 .54838 L
.972 .53859 L
.97352 .52929 L
.97466 .51813 L
.97508 .508 L
.97505 .50242 L
.97482 .49645 L
.97387 .48583 L
.97245 .47666 L
.97065 .46846 L
.9682 .45996 L
.96502 .4515 L
.96115 .44347 L
.95702 .43668 L
.95291 .43124 L
.94823 .42624 L
.94352 .42223 L
.93908 .41923 L
.93447 .41678 L
.93004 .41499 L
.92474 .41348 L
.91982 .41261 L
.91438 .41219 L
.90863 .41227 L
.90294 .41282 L
.89974 .41331 L
.89681 .41386 L
.88591 .4166 L
.86652 .42288 L
.85622 .42597 L
.8513 .42715 L
.84686 .42796 L
.84224 .4285 L
.83728 .42869 L
.8347 .4286 L
.83188 .42836 L
.8292 .42798 L
.8267 .42749 L
.82219 .42629 L
.81721 .42449 L
.80784 .41984 L
.79812 .41352 L
.78848 .40613 L
.73002 .35113 L
.64247 .26655 L
.49798 .14141 L
Mistroke
.44326 .10111 L
.38627 .0657 L
.36005 .05231 L
.33139 .04022 L
.31617 .03504 L
.2992 .03038 L
.26894 .02541 L
.23815 .02544 L
.21008 .03087 L
.17985 .04375 L
.16502 .05328 L
.14919 .0662 L
.12363 .09433 L
.09846 .13342 L
.07728 .17891 L
.0606 .22715 L
.04582 .28565 L
.03528 .34558 L
.02765 .41559 L
.02429 .49356 L
.02453 .53284 L
.02624 .57533 L
.03317 .6504 L
.04445 .71872 L
.05859 .77622 L
.0763 .82798 L
.09559 .86952 L
.11474 .90065 L
.13701 .92774 L
.16285 .94985 L
.1913 .96525 L
.21619 .97258 L
.24376 .97524 L
.25933 .97456 L
.27619 .97226 L
.30651 .96451 L
.33541 .95338 L
.36142 .94073 L
.47142 .86693 L
.61824 .74257 L
.7066 .67235 L
.72615 .65993 L
.74524 .64971 L
.76063 .6431 L
.77673 .63788 L
.78579 .63572 L
.7939 .63424 L
.79836 .63359 L
.80316 .63302 L
.8073 .63263 L
Mistroke
.81183 .6323 L
.81993 .63191 L
.82435 .6318 L
.82847 .63174 L
.83586 .63173 L
.84378 .63178 L
.85177 .63182 L
.85628 .63181 L
.86047 .63177 L
.86813 .63154 L
.87625 .63104 L
.88345 .63028 L
.89017 .62925 L
.89746 .62771 L
.90521 .62548 L
.91254 .62272 L
.91904 .61963 L
.92583 .61565 L
.93289 .61053 L
.94452 .59927 L
.95415 .58614 L
.95889 .57777 L
.96347 .56782 L
.9675 .5567 L
.97054 .54575 L
.97269 .53518 L
.97408 .52532 L
.97461 .51984 L
.97498 .51386 L
.97513 .50303 L
.97493 .49722 L
.97449 .49103 L
.97387 .48529 L
.97312 .48012 L
.97126 .47066 L
.96869 .46125 L
.96528 .4519 L
.96154 .44399 L
.95688 .4363 L
.95133 .42926 L
.94619 .42423 L
.94027 .41982 L
.93443 .41662 L
.92886 .41446 L
.92376 .41313 L
.91806 .41228 L
.91208 .41203 L
.90646 .4123 L
.90101 .41297 L
.89524 .41406 L
Mistroke
.88507 .41673 L
.86324 .42384 L
.85784 .42545 L
.8521 .42691 L
.8495 .42745 L
.84676 .42793 L
.84189 .4285 L
.83724 .42867 L
.83289 .42847 L
.82809 .4278 L
.82537 .42721 L
.82287 .42654 L
.81833 .42499 L
.81338 .42285 L
.80411 .41767 L
.78038 .39939 L
.72121 .34255 L
.61305 .23948 L
.53216 .16899 L
.47968 .1274 L
.42527 .08915 L
.37331 .05885 L
.34533 .04577 L
.31412 .03443 L
.29604 .02968 L
.27921 .0266 L
.26304 .02501 L
.24587 .02492 L
.21624 .0292 L
.19957 .03446 L
.18414 .04143 L
.15601 .06027 L
.13055 .08573 L
.10916 .11518 L
.08777 .15463 L
.06744 .20568 L
.0577 .23719 L
.04954 .26894 L
.03675 .3357 L
.0289 .4007 L
.0248 .46906 L
.02481 .54327 L
.02899 .61213 L
.03623 .67233 L
.04865 .73797 L
.05741 .77211 L
.06655 .80154 L
.08566 .84964 L
.10885 .89194 L
.13309 .92355 L
Mistroke
.16107 .94858 L
.18873 .96418 L
.21476 .97229 L
.24395 .97524 L
.26052 .97445 L
.27589 .97231 L
.29207 .96874 L
.30665 .96446 L
.3388 .95187 L
.38962 .9246 L
.43341 .89545 L
.52035 .82712 L
.63893 .72498 L
.68508 .68787 L
.72655 .65977 L
.74446 .65017 L
.76052 .64322 L
.77435 .63862 L
.78143 .63676 L
.78898 .63515 L
.79363 .63434 L
.79789 .63371 L
.8062 .63278 L
.81371 .63223 L
.82161 .6319 L
.82572 .63181 L
.83011 .63176 L
.83802 .63176 L
.84286 .63179 L
.84744 .63182 L
.85155 .63183 L
.85602 .63182 L
.86344 .6317 L
.87161 .63135 L
.8757 .63107 L
.8801 .63066 L
.88801 .6296 L
.8954 .62817 L
.90306 .62613 L
.90949 .62392 L
.91636 .62094 L
.93033 .61245 L
.93768 .60631 L
.94403 .59976 L
.95448 .58553 L
.95906 .57735 L
.96349 .56766 L
.96687 .55851 L
.96957 .54944 L
.97203 .53861 L
Mistroke
.97366 .52849 L
.97464 .51888 L
.97508 .50996 L
.97502 .50026 L
.97437 .49013 L
.97303 .47975 L
.97122 .47064 L
.96864 .46121 L
.96529 .45204 L
.95834 .4386 L
.95377 .4322 L
.94916 .42707 L
.94338 .42206 L
.93762 .41832 L
.93226 .41577 L
.9263 .4138 L
.92317 .41309 L
.91969 .41254 L
.91604 .41221 L
.91262 .41211 L
.90651 .41238 L
.90309 .41276 L
.89997 .41323 L
.87881 .41878 L
.86022 .42485 L
.85544 .42618 L
.85046 .42733 L
.84788 .42781 L
.84507 .42823 L
.84015 .42866 L
.8357 .42868 L
.83091 .42828 L
.82636 .42746 L
.82216 .42633 L
.81667 .42432 L
.81145 .42187 L
.79895 .41418 L
.77255 .3923 L
.70053 .32214 L
.59853 .22629 L
.52598 .16383 L
.4332 .09431 L
.37692 .06068 L
.3432 .04484 L
.32668 .0385 L
.31089 .03344 L
.2805 .02675 L
.25264 .02471 L
.22266 .02772 L
.2059 .03216 L
Mistroke
.19061 .03821 L
.16342 .05442 L
.13903 .07618 L
.11389 .10788 L
.08932 .15131 L
.07816 .17667 L
.06699 .20696 L
.0496 .26866 L
.03673 .33573 L
.02872 .40253 L
.02453 .47882 L
.02427 .51765 L
.02544 .56003 L
.03112 .63333 L
.04045 .69797 L
.04791 .73479 L
.05613 .76759 L
.07433 .823 L
.09749 .87303 L
.11196 .89666 L
.12607 .91552 L
.15094 .94077 L
.17542 .9577 L
.20314 .96941 L
.23355 .97489 L
.26389 .97412 L
.27907 .97174 L
.29555 .96784 L
.32435 .95806 L
.35048 .94637 L
.44673 .88578 L
.52104 .82657 L
.64626 .71886 L
.6929 .68209 L
.71506 .66685 L
.73413 .65548 L
.75065 .64728 L
.76501 .64157 L
.78036 .637 L
.78862 .6352 L
.79636 .6339 L
.80405 .63296 L
.8121 .63229 L
.8163 .63206 L
.82089 .63189 L
.82894 .63174 L
.83655 .63172 L
.8447 .63177 L
.85239 .6318 L
.85938 .63175 L
Mistroke
.8672 .63154 L
.87161 .63132 L
.87567 .63103 L
.88309 .63027 L
.8909 .62906 L
.89495 .62823 L
.89927 .62718 L
.90698 .62481 L
.91591 .62112 L
.9238 .61684 L
.9304 .61237 L
.9371 .60681 L
.94814 .59472 L
.95416 .58601 L
.95923 .57698 L
.96329 .56812 L
.96697 .55818 L
.96969 .54892 L
.97206 .5384 L
.97363 .52862 L
.97459 .5194 L
.97509 .50849 L
.97495 .49866 L
.97463 .49331 L
.97409 .48757 L
.97262 .47746 L
.97076 .46879 L
.96858 .46108 L
.96574 .45318 L
.96219 .44538 L
.95821 .43842 L
.95358 .43199 L
.94926 .42719 L
.94437 .42284 L
.93954 .41947 L
.93501 .41699 L
.93033 .41505 L
.92584 .4137 L
.92053 .41267 L
.9156 .4122 L
.91017 .41216 L
.90444 .4126 L
.89885 .41344 L
.89283 .41472 L
.88212 .41772 L
.8631 .42395 L
.85291 .42678 L
.85004 .4274 L
.84736 .42788 L
.84239 .42849 L
Mistroke
.8377 .42869 L
.83339 .42852 L
.82864 .42789 L
.82357 .42672 L
.81904 .42523 L
.81482 .42348 L
.80497 .41814 L
.78519 .40344 L
.72407 .34529 L
.63075 .25568 L
.47811 .12618 L
.42938 .0918 L
.37242 .05838 L
.33795 .04273 L
.32121 .03665 L
.30548 .03196 L
.28965 .02833 L
.27225 .02573 L
.25685 .02476 L
.24043 .02524 L
.20975 .03097 L
.1927 .03728 L
.17725 .04525 L
.14966 .06577 L
.12215 .09628 L
.09939 .13172 L
.08019 .17176 L
.06183 .22307 L
.04578 .28585 L
.03446 .35145 L
.02982 .39084 L
.02672 .42878 L
.02423 .50664 L
.02505 .55051 L
.02721 .59027 L
.0338 .65518 L
.04507 .72169 L
.061 .78431 L
.07922 .83508 L
.09094 .86057 L
.10458 .88518 L
.11731 .90424 L
.13143 .92174 L
.14464 .9352 L
.15962 .94755 L
.18687 .96338 L
.20384 .96959 L
.21952 .9732 L
.23772 .97511 L
.25503 .9749 L
Mistroke
.28562 .97033 L
.30274 .96571 L
.31844 .96033 L
.37604 .93267 L
.42649 .90034 L
.50958 .83611 L
.64681 .71835 L
.69039 .68388 L
.72925 .65816 L
.74372 .65048 L
.75846 .64396 L
.77396 .63868 L
.78796 .63531 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00e@3oool00`3ooml0W4P0000000020000000307Bo
o`3oool0oooo0=<0oooo003G0?ooo`030?noM00007@0_ooo0=H0oooo003G0?ooo`030?oo_`1d0000
M;oo0=H0oooo003G0?ooo`030?oog`2LB000B9cO0=H0oooo003H0?ooo`030=nLB000000000000080
000000<0M;oo0?ooo`3oool00P3oool01@3o_g@000000000000004P0W=oo0080oooo00<0oono07@0
000000000P0000003@18W=l0oooo0?ooo`3oool0_g@00000000004P0W=oo0?ooo`3o_g@000000000
B02Lgol00P3oool0102oM00000000000B02Lgol20?ooo`050?noM000000000000000B02Lgol00`3o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000000007Bo09d0oooo003H0?ooo`070?noM00004P0
W=oo0?ooo`3ooml0W4P0001d_`020?ooo`0?0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`3oool0
oooO09a8001d_ol0oooo0?oOW0180000M;oo0080oooo01L0gia80018W03Ooml0W7BL0=ooo`3o_g@0
001809cOg`2LM9`0gooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0
B000001d_`020?ooo`030?noM00007@0_ooo0080oooo00@0gia80018W03O_g@0M;ooW03oool00=P0
oooo00<0oono07@0001d_ol00P3oool01`3ooml0W4P004RLg`3oool0gia80018W03Oool00P3oool0
2P3ogi`0B00004RLg`3oool0_gAd0;ooo`3oool0oono07@0001d_ol20?ooo`030?noM00004P0W=oo
0080oooo00<0oono07@0001d_ol00`3oool00`3o_g@0001809cOo`020?ooo`030=nLB000B9`0gooo
0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol0W@3o
ool00=P0oooo00<0oooO09a80018W=l00`3oool01P3ogi`0B01809cOo`3o_g@0001d0;ooo`<0oooo
00<0gia80000M02oool00`3oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo
00<0_g@0001d_`3oool00P3oool00`3ookl0M00004RLg`020?ooo`030?noM00007@0_ooo00<0oooo
00/0gia80000M02oool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`2M0?ooo`00f@3oool0
0`3OW4P0001d0;ooo`020?ooo`060?oog`2LB000B9cO0?oo_`1d0000M;oo0`3oool00`3ogi`0B018
09cOo`020?ooo`030?noM00004P0W=oo00@0oooo00<0_g@00018W03Oool00P3oool00`3OW4P004RL
0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3ookl0M00007Boo`030?ooo`070?oOW01804P0W=oo
0?ooo`3OW4P004Q804Qd_`020?ooo`030;md0000M;l0oooo09`0oooo003I0?ooo`040?noM0000000
04RL0=ooo`80oooo00H0gia8001d_`3oool0gia80000M02oool20?ooo`0:0?oo_`1d0000M;oo0?oo
o`3ogi`0B01809cOo`3oool0giad09cOo`80oooo00<0gia80000B02Lgol00P3oool00`3ogi`0B018
09cOo`030?ooo`030=nLB00004P0W=oo0080oooo00<0gia80000M02oool00P3oool0303ookl0M000
07Boo`3oool0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;oooi`0oooo003I0?ooo`080?oo_`1d
0000M9bL04P0M02oool0oooO09a80000M;l20?ooo`0>0;md000007@0_ooo0?ooo`3o_g@0001d0;oo
o`3oool0omnL04P0B02Lgol0oooO09a8001d_ol20?ooo`030?oOW0180000B9cO0080oooo00<0oooO
09a80018W=l00`3oool00`3ogi`0B00004RLg`030?ooo`0@0;md000007@0_ooo0?ooo`3o_g@0001d
0;ooo`3oool0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOoi`0oooo003H0?ooo`090?oOW018
0000000004RLg`3ookl0M0000000000007@0_ooo00<0oooo00D0okmd000000000000000007Boo`03
0?ooo`070;md00000000000000000018W=l0oooo0?noM002000000040018W03Oool0oono07@000<0
000000H0M;oo0?noM000000000000018W03Oool30?ooo`0?0?noM000000000000000001d_ol0oooo
0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo09`0oooo003i0?ooo`030?noM00007@0
_ooo0;@0oooo003j0?ooo`030=nLM02Lgol0oooo0;<0oooo003d0?ooo`040?oo_`1d000004RL0=oo
o`L0oooo00@0oono07@00000B9`0gooo[@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool005/0oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`0f0?ooo`030=nLB000
0000000000<0000000<0B9cO0?ooo`3oool0=03oool00`3ookl0M000000000020000000304RLg`3o
ool0oooo0340oooo00@0_g@0000000000000M;oo=`3oool00`3ookl0M000000000020000000304RL
g`3oool0oooo03D0oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`0P0?ooo`00F`3o
ool00`3o_g@00000001d_`020?ooo`030;mdB02Lgol0oooo03L0oooo00<0okmd001d_`3oool00P3o
ool00`2oM7@0_ooo0?ooo`0f0?ooo`030?noM0000000M;oo03<0oooo00H0gia8001d_`3oool0omnL
04P00018W=lh0?ooo`030?noM0000000M;oo03T0oooo00<0okmd001d_`3oool00P3oool00`2oM7@0
_ooo0?ooo`0P0?ooo`00H03oool00`3ogi`0B4RL0=ooo`0h0?ooo`030?noM000M;l0oooo03X0oooo
00<0oooO09a80000M;l0<P3oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo03L0oooo
00<0oooO09a80000M;l0>P3oool00`3o_g@007Bo0?ooo`0T0?ooo`00H03oool00`3ookl0M00007Bo
o`0i0?ooo`030?noM000M;l0oooo03X0oooo00<0gia80018W03Oool0<@3oool00`3ooml0W4P004RL
g`020?ooo`040?oog`2LB00004RL0=ooocL0oooo00<0gia80018W03Oool0>P3oool00`3o_g@007Bo
0?ooo`0S0?ooo`00CP3oool00`3ooml0W4P0000000070000000304RLg`3oool0oooo00D0oooo00<0
omnL04P0001d_ol0:@3oool00`3ooml0W4P0000000070000000304RLg`3oool0oooo00@0oooo00<0
okmd04RLg`3oool0:@3oool00`3ooml0W4P0000000070000000304RLg`3oool0oooo00<0oooo00<0
omnL04P0B02Lgol0<@3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo03L0oooo00<0
omnL04P0B02Lgol0>`3oool00`3o_g@0B9cO0?ooo`0R0?ooo`00G`3oool0103ogi`0B0000000B02L
golk0?ooo`030=nLB018W=l0oooo03P0oooo00<0oono07@0001d_ol0<P3oool00`2oM00004RL0=oo
o`020?ooo`030?oOW0180000B9cO03L0oooo00<0oono07@0001d_ol0?03oool00`3OW4P0B9cO0?oo
o`0Q0?ooo`00G@3oool01@3ogi`0B000000000000000M;oo03d0oooo00<0_g@007Boo`3oool0>03o
ool00`2oM00007Bo0?ooo`0a0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0>03o
ool00`2oM00007Bo0?ooo`0l0?ooo`030;md001d_ol0oooo0200oooo001O0?ooo`030?oo_`1d0000
07Bo03d0oooo00<0omnL04P0M02oool0>03oool00`3OW4P004RL0=ooo`0a0?ooo`030?oOW0180000
B9cO00<0oooo00<0_g@00018W03Oool0=`3oool00`3OW4P004RL0=ooo`0l0?ooo`030?oOW01807@0
_ooo0200oooo001Q0?ooo`030=nLB000M;l0oooo03/0oooo00<0oooO09a8001d_ol0>03oool00`3o
gi`0B01809cOo`0a0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0=`3oool0
0`3ogi`0B01809cOo`0l0?ooo`030?oog`2LB000M;oo0200oooo001Q0?ooo`030?oOW01804P0W=oo
03/0oooo00<0oono07@00018W=l0>03oool00`3ookl0M00007Boo`0b0?ooo`030?oOW0180000M;oo
0080oooo00<0gia8001d_`3oool0=`3oool00`3ookl0M00007Boo`0l0?ooo`030?oo_`1d0000B9cO
0200oooo001N0?ooo`060;md001d_ol0oooo0=nLB00004P0W=oo=`3oool01`3o_g@004RL0=ooo`3o
ool0gia80000B02Lgol0>@3oool00`2oM00007Bo0?ooo`0b0?ooo`060=nLB00007@0_ooo0?oog`2L
B000B9cO>@3oool00`2oM00007Bo0?ooo`0g0?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cO
o`0P0?ooo`00G`3oool0102oM000000000000018W=li0?ooo`050?oOW018000000000000001d_ol0
>03oool01@3ookl0M0000000000007@0_ooo03<0oooo00@0gia800000000000007Bo>03oool01@3o
okl0M0000000000007@0_ooo03P0oooo00D0omnL04P000000000000007Boo`0Q0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00A03ooooo0000068000002`3o
ool004@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00140?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02@3oool004@0
oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00T0
oooo00140?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool0T03oool00`000000oooo
0?ooo`090?ooo`00A03oool200000</0oooo00<000000?ooo`3oool0SP3oool3000000/0oooo0014
0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`09
0?ooo`00A03oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool02@3oool004@0oooo00<000000?ooo`3oool0DP3oool;000006d0oooo00<000000?ooo`3o
ool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`1<0?oooaL00000
I`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003o
ool0oooo04P0oooo2@00000<0?ooo`/00000HP3oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo00T0oooo00140?ooo`030000003oool0oooo04D0oooo1P00000I0?ooo`P00000GP3oool0
0`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
0480oooo1@00000Q0?ooo`H00000G03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo
00T0oooo00140?ooo`030000003oool0oooo03l0oooo1@00000W0?ooo`L00000F03oool00`000000
oooo0?ooo`2@0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo03d0oooo
1@00000/0?ooo`H00000EP3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00T0oooo
00140?ooo`030000003oool0oooo03/0oooo1@00000a0?ooo`D00000E03oool00`000000oooo0?oo
o`2@0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo03X0oooo1000000f
0?ooo`D00000D@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo03P0oooo1000000k0?ooo`@00000C`3oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo03L0oooo0`00000o0?ooo`@0
0000C@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000
003oool0oooo03H0oooo0`0000120?ooo`@00000B`3oool00`000000oooo0?ooo`2@0?ooo`030000
003oool0oooo00T0oooo00140?ooo`030000003oool0oooo03D0oooo0`0000150?ooo`@00000B@3o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00T0oooo00140?ooo`800000=03oool3
000004T0oooo100000170?ooo`030000003oool0oooo08h0oooo0`00000;0?ooo`00A03oool00`00
0000oooo0?ooo`0b0?ooo`<00000C03oool4000004D0oooo00<000000?ooo`3oool0T03oool00`00
0000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0a0?ooo`<00000C`3oool3000004@0
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo
0?ooo`0`0?ooo`<00000DP3oool300000480oooo00<000000?ooo`3oool0T03oool00`000000oooo
0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0_0?ooo`<00000E@3oool300000400oooo00<0
00000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0^
0?ooo`<00000F03oool3000003h0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`09
0?ooo`00A03oool00`000000oooo0?ooo`0]0?ooo`<00000F`3oool3000003`0oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0/0?ooo`<0
0000G@3oool3000003/0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00
A03oool00`000000oooo0?ooo`0/0?ooo`800000H03oool3000003T0oooo00<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0[0?ooo`800000HP3o
ool4000003L0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`0Z0?ooo`800000I@3oool4000003D0oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0Y0?ooo`800000I`3oool40000
03@0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000
oooo0?ooo`0X0?ooo`800000JP3oool3000003<0oooo00<000000?ooo`3oool0T03oool00`000000
oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0W0?ooo`<00000J`3oool400000340oooo
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?oo
o`0W0?ooo`800000K@3oool400000300oooo00<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`090?ooo`00A03oool2000002L0oooo0P00001`0?ooo`<00000;`3oool00`000000oooo0?ooo`2>
0?ooo`<000002`3oool004@0oooo00<000000?ooo`3oool09P3oool200000740oooo1000000]0?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3o
ool09@3oool2000007@0oooo0`00000/0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3o
ool02@3oool004@0oooo00<000000?ooo`3oool0903oool2000007H0oooo0`00000[0?ooo`030000
003oool0oooo0900oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool08`3o
ool2000007T0oooo0`00000Y0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02@3o
ool004@0oooo00<000000?ooo`3oool08`3oool2000007X0oooo0`00000X0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool08P3oool20000
07`0oooo1000000V0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02@3oool004@0
oooo00<000000?ooo`3oool08P3oool2000007h0oooo0`00000U0?ooo`030000003oool0oooo0900
oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool08@3oool200000800oooo
0`00000T0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02@3oool004@0oooo00<0
00000?ooo`3oool08@3oool200000880oooo0`00000R0?ooo`030000003oool0oooo0900oooo00<0
00000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0803oool2000008@0oooo0`00000Q
0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02@3oool003L0oooo00<0oooO09a8
0018W=l02P3oool00`000000oooo0?ooo`0O0?ooo`800000QP3oool4000001l0oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`090?ooo`00>03oool00`3OW4P004RL0=ooo`090?ooo`03
0000003oool0oooo01l0oooo0P0000280?ooo`<000007P3oool00`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo00T0oooo000h0?ooo`030?oOW01804P0W=oo00T0oooo00<000000?ooo`3oool0
7P3oool2000008X0oooo0`00000M0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0
2@3oool003@0oooo00<0okmd000000000000100000000`00B9`0gooo0?ooo`060?ooo`030000003o
ool0oooo01h0oooo0P00002;0?ooo`@000006`3oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo00T0oooo000W0?ooo`030?oog`2LB000000000L0000000H0B9cO0?ooo`3oool0oooO09a8
B02Lgol20?ooo`030;md0000M;l0oooo00P0oooo00<000000?ooo`3oool07@3oool2000008d0oooo
1000000J0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02@3oool003D0oooo00L0
oono07@0M02oool0oooo0?noM000B9`0gooo00P0oooo0`00000M0?ooo`800000S`3oool3000001T0
oooo00<000000?ooo`3oool0SP3oool3000000/0oooo000f0?ooo`060?oOW018B9`0gooo0?oOW018
04P0W=oo203oool00`000000oooo0?ooo`0L0?ooo`800000T@3oool3000001P0oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`090?ooo`00=`3oool01@3o_g@007Bo0?oog`2LB000B9cO
00P0oooo00<000000?ooo`3oool0703oool200000980oooo0`00000G0?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool02@3oool003P0oooo00@0gia804RLg`2oM00007Bo203oool00`00
0000oooo0?ooo`0K0?ooo`800000U03oool4000001D0oooo00<000000?ooo`3oool0T03oool00`00
0000oooo0?ooo`090?ooo`00>@3oool0103OW4P0M7Ad0000M02oool70?ooo`030000003oool0oooo
01/0oooo0P00002F0?ooo`<00000503oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo
00T0oooo000j0?ooo`030;md000004P0W=oo00L0oooo00<000000?ooo`3oool06P3oool2000009P0
oooo0`00000C0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02@3oool003X0oooo
00<0oooO09a80018W=l01`3oool00`000000oooo0?ooo`0J0?ooo`800000V@3oool300000180oooo
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?oo
o`0I0?ooo`<00000VP3oool300000140oooo00<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`090?ooo`00A03oool00`000000oooo0?ooo`0I0?ooo`800000W03oool4000000l0oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0H0?oo
o`<00000W@3oool4000000h0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?oo
o`00A03oool00`000000oooo0?ooo`0H0?ooo`800000X03oool3000000d0oooo00<000000?ooo`3o
ool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0H0?ooo`800000
X@3oool3000000`0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03o
ool00`000000oooo0?ooo`0G0?ooo`<00000XP3oool3000000/0oooo00<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0G0?ooo`800000Y03oool4
000000T0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool00`00
0000oooo0?ooo`0G0?ooo`800000Y@3oool4000000P0oooo00<000000?ooo`3oool0T03oool00`00
0000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0F0?ooo`800000Y`3oool4000000L0
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool2000001L0oooo
0P00002Y0?ooo`@000001@3oool00`000000oooo0?ooo`2>0?ooo`<000002`3oool004@0oooo00<0
00000?ooo`3oool05@3oool300000:X0oooo100000040?ooo`030000003oool0oooo0900oooo00<0
00000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool05@3oool200000:`0oooo10000003
0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?oo
o`3oool05@3oool200000:d0oooo100000020?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool02@3oool004@0oooo00<000000?ooo`3oool0503oool300000:h0oooo100000000`3oool0
00000?ooo`2A0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01@0oooo
0P00002`0?ooo`D00000TP3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?oo
o`0D0?ooo`800000/@3oool400000980oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool04`3oool300000;<0oooo0`00002A0?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo01<0oooo0P00002e0?ooo`@00000S`3oool00`000000oooo0?ooo`090?oo
o`00A03oool00`000000oooo0?ooo`0C0?ooo`800000]@3oool5000008h0oooo00<000000?ooo`3o
ool02@3oool004@0oooo00<000000?ooo`3oool04`3oool200000;D0oooo00<000000?ooo`000000
0`00002=0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo0180oooo0`00
002e0?ooo`030000003oool0oooo00@00000S03oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`0B0?ooo`800000]P3oool010000000oooo0?ooo`3oool4000008/0oooo00<0
00000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool04P3oool200000;H0oooo00<00000
0?ooo`3oool00`3oool3000008X0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?oo
o`3oool04@3oool300000;H0oooo00<000000?ooo`3oool0103oool3000008T0oooo00<000000?oo
o`3oool02@3oool004@0oooo00<000000?ooo`3oool04@3oool200000;L0oooo00<000000?ooo`3o
ool01@3oool3000008P0oooo00<000000?ooo`3oool02@3oool004@0oooo0P00000B0?ooo`800000
]`3oool00`000000oooo0?ooo`060?ooo`<00000Q@3oool3000000/0oooo00140?ooo`030000003o
ool0oooo0140oooo0P00002g0?ooo`030000003oool0oooo00L0oooo0`0000260?ooo`030000003o
ool0oooo00T0oooo00140?ooo`030000003oool0oooo0100oooo0P00002h0?ooo`030000003oool0
oooo00P0oooo0`0000250?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
0100oooo0P00002h0?ooo`030000003oool0oooo00T0oooo0`0000240?ooo`030000003oool0oooo
00T0oooo00140?ooo`030000003oool0oooo0100oooo0P00002h0?ooo`030000003oool0oooo00X0
oooo0`0000230?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo0100oooo
0P00002h0?ooo`030000003oool0oooo00`0oooo0`0000210?ooo`030000003oool0oooo00T0oooo
00140?ooo`030000003oool0oooo00l0oooo0P00002i0?ooo`030000003oool0oooo00d0oooo0`00
00200?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00l0oooo0P00002i
0?ooo`030000003oool0oooo00h0oooo0`00001o0?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo00l0oooo0P00002i0?ooo`030000003oool0oooo00l0oooo0`00001n0?oo
o`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00l0oooo0P00002i0?ooo`03
0000003oool0oooo0100oooo0`00001m0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000
003oool0oooo00h0oooo0P00002j0?ooo`030000003oool0oooo0140oooo0`00001l0?ooo`030000
003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00h0oooo0P00002j0?ooo`030000003o
ool0oooo0180oooo0`00001k0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0
oooo00h0oooo0P00002j0?ooo`030000003oool0oooo01<0oooo0`00001j0?ooo`030000003oool0
oooo00T0oooo00140?ooo`030000003oool0oooo00h0oooo0P00002j0?ooo`030000003oool0oooo
01@0oooo0`00001i0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00d0
oooo0P00002k0?ooo`030000003oool0oooo01D0oooo0`00001h0?ooo`030000003oool0oooo00T0
oooo00140?ooo`8000003P3oool200000;/0oooo00<000000?ooo`3oool05P3oool3000007D0oooo
0`00000;0?ooo`00A03oool00`000000oooo0?ooo`0=0?ooo`800000^`3oool00`000000oooo0?oo
o`0G0?ooo`<00000MP3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0=
0?ooo`800000^`3oool00`000000oooo0?ooo`0H0?ooo`<00000M@3oool00`000000oooo0?ooo`09
0?ooo`00A03oool00`000000oooo0?ooo`0=0?ooo`800000^`3oool00`000000oooo0?ooo`0I0?oo
o`@00000L`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0<0?ooo`80
0000_03oool00`000000oooo0?ooo`0K0?ooo`<00000LP3oool00`000000oooo0?ooo`090?ooo`00
A03oool00`000000oooo0?ooo`0<0?ooo`800000_03oool00`000000oooo0?ooo`0L0?ooo`<00000
L@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0<0?ooo`800000_03o
ool00`000000oooo0?ooo`0M0?ooo`<00000L03oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`0<0?ooo`800000_03oool00`000000oooo0?ooo`0N0?ooo`<00000K`3oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0;/0oooo00<000000?ooo`3oool07`3oool3000006h0oooo00<000000?ooo`3oool02@3oool004@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo0200
oooo0`00001]0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00/0oooo
0P00002m0?ooo`030000003oool0oooo0240oooo0`00001/0?ooo`030000003oool0oooo00T0oooo
000d0?ooo`030=nLB0000000000000<0000000<0B9cO0?ooo`3oool01`3oool00`000000oooo0?oo
o`0;0?ooo`800000_@3oool00`000000oooo0?ooo`0R0?ooo`<00000J`3oool00`000000oooo0?oo
o`090?ooo`00=@3oool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02oool0oooo00L0oooo00<00000
0?ooo`3oool02`3oool200000;d0oooo00<000000?ooo`3oool08`3oool3000006X0oooo00<00000
0?ooo`3oool02@3oool003H0oooo00<0okmd001d_`3oool02`3oool00`000000oooo0?ooo`0;0?oo
o`800000_@3oool00`000000oooo0?ooo`0T0?ooo`<00000J@3oool00`000000oooo0?ooo`090?oo
o`00=`3oool00`3o_g@007Bo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0_03oool00`000000oooo0?ooo`0U0?ooo`<00000J03oool00`000000oooo0?ooo`090?ooo`00
9`3oool00`3ooml0W4P0000000070000000304RLg`3oool0oooo00@0oooo00<0okmd04RLg`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`800000_P3oool00`000000oooo0?ooo`0V0?ooo`<00000
I`3oool00`000000oooo0?ooo`090?ooo`00>@3oool00`3OW4P0B9cO0?ooo`080?ooo`<000002P3o
ool200000;h0oooo00<000000?ooo`3oool09`3oool3000006@0oooo0`00000;0?ooo`00>P3oool0
0`2oM000M;oo0?ooo`070?ooo`030000003oool0oooo00X0oooo0P00002n0?ooo`030000003oool0
oooo02P0oooo0`00001U0?ooo`030000003oool0oooo00T0oooo000j0?ooo`030?oOW01807@0_ooo
00L0oooo00<000000?ooo`3oool02P3oool200000;h0oooo00<000000?ooo`3oool0:@3oool30000
06@0oooo00<000000?ooo`3oool02@3oool003X0oooo00<0oooO09a8001d_ol01`3oool00`000000
oooo0?ooo`0:0?ooo`800000_P3oool00`000000oooo0?ooo`0[0?ooo`800000H`3oool00`000000
oooo0?ooo`090?ooo`00>P3oool00`3ookl0M00004RLg`070?ooo`030000003oool0oooo00X0oooo
0P00002n0?ooo`030000003oool0oooo02`0oooo0P00001R0?ooo`030000003oool0oooo00T0oooo
000f0?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cOo`070?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0]0?ooo`<00000H03oool00`000000
oooo0?ooo`090?ooo`00=`3oool01@3ogi`0B000000000000000M;oo00P0oooo00<000000?ooo`3o
ool02@3oool200000;l0oooo00<000000?ooo`3oool0;P3oool3000005l0oooo00<000000?ooo`3o
ool02@3oool004@0oooo00<000000?ooo`3oool02@3oool200000;l0oooo00<000000?ooo`3oool0
;`3oool3000005h0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool02@3o
ool200000;l0oooo00<000000?ooo`3oool0<03oool3000005d0oooo00<000000?ooo`3oool02@3o
ool004@0oooo00<000000?ooo`3oool02@3oool200000;l0oooo00<000000?ooo`3oool0<@3oool3
000005`0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool02@3oool20000
0;l0oooo00<000000?ooo`3oool0<P3oool3000005/0oooo00<000000?ooo`3oool02@3oool004@0
oooo00<000000?ooo`3oool02@3oool200000;l0oooo00<000000?ooo`3oool0<`3oool3000005X0
oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0203oool200000<00oooo
00<000000?ooo`3oool0=03oool3000005T0oooo00<000000?ooo`3oool02@3oool004@0oooo00<0
00000?ooo`3oool0203oool200000<00oooo00<000000?ooo`3oool0=@3oool3000005P0oooo00<0
00000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0203oool200000<00oooo00<00000
0?ooo`3oool0=P3oool3000005L0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?oo
o`3oool0203oool200000<00oooo00<000000?ooo`3oool0=`3oool3000005H0oooo00<000000?oo
o`3oool02@3oool004@0oooo0P0000090?ooo`800000`03oool00`000000oooo0?ooo`0h0?ooo`<0
0000D`3oool3000000/0oooo00140?ooo`030000003oool0oooo00P0oooo0P0000300?ooo`030000
003oool0oooo03T0oooo0`00001D0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003o
ool0oooo00P0oooo0P0000300?ooo`030000003oool0oooo03X0oooo0`00001C0?ooo`030000003o
ool0oooo00T0oooo00140?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0_`3oool0
0`000000oooo0?ooo`0k0?ooo`<00000DP3oool00`000000oooo0?ooo`090?ooo`00A03oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0?03oool30000
0540oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool01`3oool200000<40
oooo00<000000?ooo`3oool0?@3oool300000500oooo00<000000?ooo`3oool02@3oool004@0oooo
00<000000?ooo`3oool01`3oool200000<40oooo00<000000?ooo`3oool0?P3oool4000004h0oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool01`3oool200000<40oooo00<0
00000?ooo`3oool0?`3oool4000004d0oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool01`3oool200000<40oooo00<000000?ooo`3oool0@@3oool3000004`0oooo00<00000
0?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool01`3oool200000<40oooo00<000000?oo
o`3oool0@P3oool3000004/0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3o
ool01`3oool200000<40oooo00<000000?ooo`3oool0@`3oool3000004X0oooo00<000000?ooo`3o
ool02@3oool004@0oooo00<000000?ooo`3oool01`3oool200000<40oooo00<000000?ooo`3oool0
A03oool3000004T0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool01`3o
ool200000<40oooo00<000000?ooo`3oool0A@3oool4000004L0oooo00<000000?ooo`3oool02@3o
ool004@0oooo00<000000?ooo`3oool01`3oool200000<40oooo00<000000?ooo`3oool0AP3oool4
00000280oooo2@00000K0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`170?ooo`@000007P3oool@0000
01L0oooo00<000000?ooo`3oool02@3oool004@0oooo0P0000080?ooo`030000003oool0oooo0<00
oooo00<000000?ooo`3oool0B@3oool4000001P0oooo5P00000C0?ooo`<000002`3oool004@0oooo
00<000000?ooo`3oool01P3oool200000<80oooo00<000000?ooo`3oool0BP3oool4000001@0oooo
300000060?ooo`P00000503oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?oo
o`060?ooo`800000`P3oool00`000000oooo0?ooo`1<0?ooo`@00000403oool800000100oooo00<0
00000?ooo`0000000P00000C0?ooo`030000003oool0oooo00T0oooo000C0?ooo`030?oo_`1dM;l0
oooo02h0oooo00<000000?ooo`3oool01P3oool200000<80oooo00<000000?ooo`3oool0C@3oool4
000000`0oooo1`00000E0?ooo`80000000@0oooo00000000000000004@3oool00`000000oooo0?oo
o`090?ooo`004`3oool0103ogi`0B0000000B02Lgol]0?ooo`030000003oool0oooo00H0oooo0P00
00320?ooo`030000003oool0oooo04l0oooo4P00000J0?ooo`@000004@3oool00`000000oooo0?oo
o`090?ooo`005@3oool00`2oM000000000000003000000030000M02oool0oooo02H0oooo00<00000
0?ooo`3oool01P3oool200000<80oooo00<000000?ooo`3oool0D@3oool<00000200oooo0`00000@
0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030?oOW0180000M;oo02P0oooo00<000000?oo
o`3oool01P3oool200000<80oooo00<000000?ooo`3oool0OP3oool3000000l0oooo00<000000?oo
o`3oool02@3oool001P0oooo00<0gia80000M02oool0:@3oool00`000000oooo0?ooo`060?ooo`80
0000`P3oool00`000000oooo0?ooo`1o0?ooo`<000003P3oool00`000000oooo0?ooo`090?ooo`00
4`3oool01P3ogi`0B01809cOo`3o_g@0000004RLgb/0oooo00<000000?ooo`3oool01P3oool20000
0<80oooo00<000000?ooo`3oool0O`3oool4000000d0oooo00<000000?ooo`3oool02@3oool001<0
oooo00@0omnL04P00000000007Bo;@3oool00`000000oooo0?ooo`060?ooo`800000`P3oool00`00
0000oooo0?ooo`200?ooo`<000003@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000
oooo0?ooo`060?ooo`800000`P3oool00`000000oooo0?ooo`210?ooo`<00000303oool00`000000
oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`060?ooo`800000`P3oool00`000000oooo
0?ooo`220?ooo`800000303oool00`000000oooo0?ooo`090?ooo`005P3oool01P3OW4P000000000
00000000001809cOobP0oooo00<000000?ooo`3oool01P3oool200000<80oooo00<000000?ooo`3o
ool0PP3oool3000000/0oooo00<000000?ooo`3oool02@3oool001@0oooo00T0oono07@00018W=l0
omnL09boo`3oool0gia80018W03Oool09`3oool00`000000oooo0?ooo`060?ooo`800000`P3oool0
0`000000oooo0?ooo`230?ooo`8000002`3oool00`000000oooo0?ooo`090?ooo`00503oool02@2o
M7@0_ooo0?ooo`3o_i`0W=oo0?ooo`3ookl0M01d0;ooo`0W0?ooo`030000003oool0oooo00H0oooo
0P0000320?ooo`030000003oool0oooo08<0oooo0`00000:0?ooo`030000003oool0oooo00T0oooo
000C0?ooo`090?oOW02L_ol0oooo0?oog`2LM9`0gooo0?ooo`3ogi`0B7Bo02P0oooo00<000000?oo
o`3oool01P3oool200000<80oooo00<000000?ooo`3oool0Q03oool2000000X0oooo00<000000?oo
o`3oool02@3oool001<0oooo00T0oknL09cOo`3oool0_g@007Boo`3oool0gia80000M02oool0:03o
ool2000000L0oooo0P0000320?ooo`030000003oool0oooo08@0oooo0P0000080?ooo`<000002`3o
ool001<0oooo00@0oono07@000000000M;oo;@3oool00`000000oooo0?ooo`060?ooo`800000`P3o
ool00`000000oooo0?ooo`250?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool004@0oooo00<000000?ooo`3oool01P3oool200000<80oooo00<000000?ooo`3oool0Q@3oool2
000000T0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`310?ooo`030000003oool0oooo08D0oooo0P0000090?ooo`030000003oool0oooo
00T0oooo000G0?ooo`060?noM000000000000000000007@0_ooo9`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool0Q@3oool2000000T0oooo00<00000
0?ooo`3oool02@3oool000l0oooo00H0_ibL0=ooo`3oool0oooo0?oOW0180003000000040018W03O
ool0oono07Ad_bP0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`310?ooo`030000
003oool0oooo08D0oooo0P0000090?ooo`030000003oool0oooo00T0oooo000>0?ooo`030?oog`2L
B000000000<0000000<007Bo0?ooo`3oool00P3oool00`3o_g@0001d0;ooo`0X0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`250?ooo`<00000203o
ool00`000000oooo0?ooo`090?ooo`003P3oool00`3ookl0M00004RLg`0c0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`250?ooo`<00000203oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0QP3oool2000000P0oooo00<000000?ooo`3oool02@3oool001H0
oooo00H0omnL04P00000000000000000B02LgolX0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0`@3oool00`000000oooo0?ooo`260?ooo`800000203oool00`000000oooo0?ooo`09
0?ooo`005@3oool00`2oM000000007Boo`020?ooo`030?oog`2LM9`0gooo02L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo08H0oooo0P0000080?oo
o`030000003oool0oooo00T0oooo000D0?ooo`030=nLB018W=l0oooo00@0oooo00<0gibL0;ooo`3o
ool0603oool0102oM00000000000001d_ol:0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0`@3oool00`000000oooo0?ooo`260?ooo`800000203oool00`000000oooo0?ooo`090?oo
o`004`3oool00`3ogi`0M9cO0?ooo`040?ooo`030?oog`2LM9`0gooo01P0oooo00H0gia8001d_`3o
ool0omnL04P00018W=l90?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0`@3oool0
0`000000oooo0?ooo`260?ooo`800000203oool00`000000oooo0?ooo`090?ooo`004`3oool00`3o
_i`0W=oo0?ooo`030?ooo`030?oog`2LB000M;oo01P0oooo00<0oooO09a80018W=l00P3oool00`3o
_g@0001809cOo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0`@3oool00`00
0000oooo0?ooo`260?ooo`800000203oool00`000000oooo0?ooo`090?ooo`004`3oool00`3ogi`0
B7Bo0?ooo`020?ooo`030=nLB0000000B9cO01T0oooo00<0oooO09a80018W=l00P3oool0103ooml0
W4P00018W03Oool70?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0`@3oool00`00
0000oooo0?ooo`260?ooo`800000203oool00`000000oooo0?ooo`090?ooo`00503oool01P3o_g@0
000000000000000004RL0=oooaX0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`26
0?ooo`800000203oool00`000000oooo0?ooo`090?ooo`00=@3oool00`2oM00004RL0=ooo`020?oo
o`030?oOW0180000B9cO00L0ooooo`00001R000000/0oooo000e0?ooo`030=nLB00004P0W=oo0080
oooo00<0oooO09a80000M;l01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0<40
oooo00<000000?ooo`3oool0QP3oool2000000P0oooo00<000000?ooo`3oool02@3oool001H0oooo
00H0omnL04P00000000000000000B02LgolI0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018
W03Oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0<40oooo00<000000?oo
o`3oool0QP3oool2000000P0oooo00<000000?ooo`3oool02@3oool001@0oooo00@0oooO09a80000
B9`0gooo0P3oool00`3o_g@004RL0=ooo`0H0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia8
0018W03Oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0<40oooo00<00000
0?ooo`3oool0QP3oool2000000P0oooo00<000000?ooo`3oool02@3oool001@0oooo00<0_gA809cO
o`3oool00`3oool00`3ooml0W4Qd0;ooo`0I0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d
_`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0<40oooo00<000000?oo
o`3oool0QP3oool2000000P0oooo00<000000?ooo`3oool02@3oool001<0oooo00<0omnL09boo`3o
ool0103oool00`3ogi`0B7Bo0?ooo`0J0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO1`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool0QP3oool2
000000P0oooo00<000000?ooo`3oool02@3oool001<0oooo00<0oknL09cOo`3oool00`3oool00`3o
gi`0B4RL0=ooo`0L0?ooo`040=nLB00000000000001d_`P0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`310?ooo`030000003oool0oooo08H0oooo0P0000080?ooo`030000003oool0
oooo00T0oooo000C0?ooo`040?oo_`1d0000000007Boobd0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`310?ooo`030000003oool0oooo08H0oooo0P0000080?ooo`030000003oool0
oooo00T0oooo00140?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0`@3oool00`00
0000oooo0?ooo`260?ooo`800000203oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool0QP3oool2000000P0
oooo00<000000?ooo`3oool02@3oool001<0oooo00<0oono09bLg`3oool00`3oool0103o_g@00000
0000M02ooolW0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0`@3oool00`000000
oooo0?ooo`250?ooo`<00000203oool00`000000oooo0?ooo`090?ooo`004`3oool0103ookl0W9cO
0?oo_`1d0004000000030018W03Oool0oooo02H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`310?ooo`030000003oool0oooo08D0oooo0`0000080?ooo`030000003oool0oooo00T0
oooo000C0?ooo`090?oOW018000000000000B02Lgol0oooo0?oog`2LB7@0_ooo02P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo08D0oooo0P000009
0?ooo`030000003oool0oooo00T0oooo000?0?ooo`040?oog`2LB000001d0;oooc40oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo08D0oooo0P000009
0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0`@3oool00`000000oooo0?ooo`250?ooo`8000002@3oool00`000000oooo0?ooo`090?oo
o`004`3oool01@3ogkl0_moo0?ooo`3oool0_g@000<0000000<0001d0;ooo`3oool09P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool0Q03oool30000
00T0oooo00<000000?ooo`3oool02@3oool001<0oooo00<0_g@00000000000000P0000001@0007@0
_ooo0?ooo`2oW9`0gooo02L0oooo0P0000070?ooo`030000003oool0oooo0<40oooo00<000000?oo
o`3oool0Q03oool2000000P0oooo0`00000;0?ooo`004@3oool01@2oM000000000000000B9`0gooo
00<0oooo00<0oooO09a8001d_ol00P3oool00`2oM00004RL0=ooo`0S0?ooo`030000003oool0oooo
00H0oooo0P0000320?ooo`030000003oool0oooo08@0oooo0P00000:0?ooo`030000003oool0oooo
00T0oooo000C0?ooo`030?noW02Lgol0oooo00P0oooo00<0omnL04Qd_`3oool08`3oool00`000000
oooo0?ooo`060?ooo`800000`P3oool00`000000oooo0?ooo`240?ooo`8000002P3oool00`000000
oooo0?ooo`090?ooo`004`3oool00`3ookl0M7Bo0?ooo`070?ooo`030?noM000B9`0gooo02@0oooo
00<000000?ooo`3oool01P3oool200000<80oooo00<000000?ooo`3oool0P`3oool3000000X0oooo
00<000000?ooo`3oool02@3oool001<0oooo00@0omnL04P0000007@0_ooo1@3oool00`3OW4P007Bo
0?ooo`0U0?ooo`030000003oool0oooo00H0oooo0P0000320?ooo`030000003oool0oooo08<0oooo
0P00000;0?ooo`030000003oool0oooo00T0oooo000D0?ooo`030?oOW0180000000000D0000000<0
B9cO0?ooo`3oool09@3oool00`000000oooo0?ooo`060?ooo`800000`P3oool00`000000oooo0?oo
o`220?ooo`<000002`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`3o_g@0001809cOo`0X
0?ooo`030000003oool0oooo00H0oooo0P0000320?ooo`030000003oool0oooo0880oooo0P00000<
0?ooo`030000003oool0oooo00T0oooo000H0?ooo`030;md0000M;l0oooo02T0oooo00<000000?oo
o`3oool01P3oool200000<80oooo00<000000?ooo`3oool0P@3oool3000000`0oooo00<000000?oo
o`3oool02@3oool001<0oooo00H0omnL04P0001d_ol0okmd0000001d_ol[0?ooo`030000003oool0
oooo00H0oooo0P0000320?ooo`030000003oool0oooo0840oooo0P00000=0?ooo`030000003oool0
oooo00T0oooo000C0?ooo`040?oOW01800000000001d_bd0oooo00<000000?ooo`3oool01P3oool2
00000<80oooo00<000000?ooo`3oool0P03oool3000000d0oooo00<000000?ooo`3oool02@3oool0
04@0oooo00<000000?ooo`3oool01P3oool200000<80oooo00<000000?ooo`3oool0P03oool20000
00h0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool01P3oool200000<80
oooo00<000000?ooo`3oool0O`3oool3000000h0oooo00<000000?ooo`3oool02@3oool004@0oooo
00<000000?ooo`3oool01P3oool200000<80oooo00<000000?ooo`3oool0OP3oool3000000l0oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool01P3oool200000<80oooo00<0
00000?ooo`3oool0OP3oool3000000l0oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool01P3oool200000<80oooo00<000000?ooo`3oool0O@3oool300000100oooo00<00000
0?ooo`3oool02@3oool004@0oooo0P0000070?ooo`800000`P3oool00`000000oooo0?ooo`1l0?oo
o`@000003P3oool3000000/0oooo00140?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0`03oool00`000000oooo0?ooo`1k0?ooo`@000004@3oool00`000000oooo0?ooo`090?ooo`00
A03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0
NP3oool400000180oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool01`3o
ool200000<40oooo00<000000?ooo`3oool0NP3oool3000001<0oooo00<000000?ooo`3oool02@3o
ool004@0oooo00<000000?ooo`3oool01`3oool200000<40oooo00<000000?ooo`3oool0N@3oool3
000001@0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool01`3oool20000
0<40oooo00<000000?ooo`3oool0M`3oool4000001D0oooo00<000000?ooo`3oool02@3oool004@0
oooo00<000000?ooo`3oool01`3oool200000<40oooo00<000000?ooo`3oool0MP3oool3000001L0
oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool01`3oool200000<40oooo
00<000000?ooo`3oool0M03oool4000001P0oooo00<000000?ooo`3oool02@3oool004@0oooo00<0
00000?ooo`3oool01`3oool200000<40oooo00<000000?ooo`3oool0LP3oool5000001T0oooo00<0
00000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool01`3oool200000<40oooo00<00000
0?ooo`3oool0L@3oool5000001X0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?oo
o`3oool01`3oool200000<40oooo00<000000?ooo`3oool0KP3oool7000001/0oooo00<000000?oo
o`3oool02@3oool004@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2o0?ooo`03
0000003oool0oooo06P0oooo2P00000N0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`1Q0?ooo`l00000
803oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`080?ooo`800000`03o
ool00`000000oooo0?ooo`180?ooob<000009@3oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`080?ooo`800000`03oool00`000000oooo0?ooo`120?ooo`h00000@03oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`080?ooo`800000`03oool00`00
0000oooo0?ooo`0o0?ooo`P00000B@3oool00`000000oooo0?ooo`090?ooo`00A03oool2000000T0
oooo0P0000300?ooo`030000003oool0oooo03d0oooo1`00001:0?ooo`<000002`3oool004@0oooo
00<000000?ooo`3oool0203oool200000<00oooo00<000000?ooo`3oool0>P3oool600000500oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0203oool200000<00oooo00<0
00000?ooo`3oool0>03oool5000005<0oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool0203oool200000<00oooo00<000000?ooo`3oool0=P3oool4000005H0oooo00<00000
0?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0203oool200000<00oooo00<000000?oo
o`3oool0=03oool4000005P0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3o
ool02@3oool200000;l0oooo00<000000?ooo`3oool0<P3oool4000005X0oooo00<000000?ooo`3o
ool02@3oool004@0oooo00<000000?ooo`3oool02@3oool200000;l0oooo00<000000?ooo`3oool0
<03oool4000005`0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool02@3o
ool200000;l0oooo00<000000?ooo`3oool0;P3oool5000005d0oooo00<000000?ooo`3oool02@3o
ool004@0oooo00<000000?ooo`3oool02@3oool200000;l0oooo00<000000?ooo`3oool0;@3oool4
000005l0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool02@3oool20000
0;l0oooo00<000000?ooo`3oool0:`3oool500000600oooo00<000000?ooo`3oool02@3oool004@0
oooo00<000000?ooo`3oool02@3oool200000;l0oooo00<000000?ooo`3oool0:P3oool400000680
oooo00<000000?ooo`3oool02@3oool003@0oooo00<0gia80000000000000`0000000`18W=l0oooo
0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0_@3oool00`000000oooo
0?ooo`0Y0?ooo`@00000H`3oool00`000000oooo0?ooo`090?ooo`00=@3oool00`3o_g@007Bo0?oo
o`020?ooo`030;mdM02oool0oooo00L0oooo00<000000?ooo`3oool02P3oool200000;h0oooo00<0
00000?ooo`3oool09`3oool4000006D0oooo00<000000?ooo`3oool02@3oool003H0oooo00<0okmd
001d_`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`800000_P3oool00`000000oooo0?ooo`0V
0?ooo`@00000IP3oool00`000000oooo0?ooo`090?ooo`00=`3oool00`3o_g@007Bo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo0P00002n0?ooo`030000003oool0oooo02@0oooo1@00001W0?oo
o`030000003oool0oooo00T0oooo000h0?ooo`030?noM018W=l0oooo00T0oooo00<000000?ooo`3o
ool02P3oool200000;h0oooo00<000000?ooo`3oool08`3oool4000006T0oooo00<000000?ooo`3o
ool02@3oool003T0oooo00<0gia804RLg`3oool0203oool3000000X0oooo0P00002n0?ooo`030000
003oool0oooo0240oooo1@00001X0?ooo`<000002`3oool003X0oooo00<0_g@007Boo`3oool01`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0803o
ool5000006/0oooo00<000000?ooo`3oool02@3oool003X0oooo00<0omnL04P0M02oool01`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool07`3oool4
000006d0oooo00<000000?ooo`3oool02@3oool003X0oooo00<0oooO09a8001d_ol01`3oool00`00
0000oooo0?ooo`0;0?ooo`800000_@3oool00`000000oooo0?ooo`0M0?ooo`D00000KP3oool00`00
0000oooo0?ooo`090?ooo`00>P3oool00`3ookl0M00004RLg`070?ooo`030000003oool0oooo00/0
oooo0P00002m0?ooo`030000003oool0oooo01`0oooo1@00001_0?ooo`030000003oool0oooo00T0
oooo000f0?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cOo`070?ooo`030000003oool0oooo
00/0oooo0P00002m0?ooo`030000003oool0oooo01/0oooo1000001a0?ooo`030000003oool0oooo
00T0oooo000g0?ooo`050?oOW018000000000000001d_ol0203oool00`000000oooo0?ooo`0;0?oo
o`800000_@3oool00`000000oooo0?ooo`0J0?ooo`@00000LP3oool00`000000oooo0?ooo`090?oo
o`00A03oool00`000000oooo0?ooo`0;0?ooo`800000_@3oool00`000000oooo0?ooo`0I0?ooo`@0
0000L`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0<0?ooo`800000
_03oool00`000000oooo0?ooo`0G0?ooo`D00000M03oool00`000000oooo0?ooo`090?ooo`00A03o
ool00`000000oooo0?ooo`0<0?ooo`800000_03oool00`000000oooo0?ooo`0F0?ooo`@00000MP3o
ool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0<0?ooo`800000_03oool0
0`000000oooo0?ooo`0E0?ooo`@00000M`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`00
0000oooo0?ooo`0<0?ooo`800000_03oool00`000000oooo0?ooo`0D0?ooo`@00000N03oool00`00
0000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0<0?ooo`800000_03oool00`000000
oooo0?ooo`0B0?ooo`D00000N@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo
0?ooo`0=0?ooo`800000^`3oool00`000000oooo0?ooo`0A0?ooo`D00000NP3oool00`000000oooo
0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0=0?ooo`800000^`3oool00`000000oooo0?oo
o`0@0?ooo`@00000O03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0=
0?ooo`800000^`3oool00`000000oooo0?ooo`0?0?ooo`@00000O@3oool00`000000oooo0?ooo`09
0?ooo`00A03oool2000000h0oooo0P00002k0?ooo`030000003oool0oooo00h0oooo1000001l0?oo
o`<000002`3oool004@0oooo00<000000?ooo`3oool03P3oool200000;X0oooo00<000000?ooo`3o
ool0303oool3000000030?ooo`000000oooo07h0oooo00<000000?ooo`3oool02@3oool004@0oooo
00<000000?ooo`3oool03P3oool200000;X0oooo00<000000?ooo`3oool02`3oool500000800oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool03P3oool200000;X0oooo00<0
00000?ooo`3oool02P3oool400000880oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool03P3oool200000;X0oooo00<000000?ooo`3oool02@3oool4000008<0oooo00<00000
0?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2h0?oo
o`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`230?ooo`030000003oool0oooo
00T0oooo00140?ooo`030000003oool0oooo00l0oooo0P00002i0?ooo`030000003oool0oooo00L0
oooo0P0000000`3oool000000?ooo`240?ooo`030000003oool0oooo00T0oooo00140?ooo`030000
003oool0oooo00l0oooo0P00002i0?ooo`030000003oool0oooo00D0oooo1@0000260?ooo`030000
003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00l0oooo0P00002i0?ooo`030000003o
ool0oooo00@0oooo100000280?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`030?ooo`@00000R@3oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0@0?ooo`800000^03oool00`00
0000oooo0?ooo`020?ooo`80000000<0oooo0000003oool0R@3oool00`000000oooo0?ooo`090?oo
o`00A03oool00`000000oooo0?ooo`0@0?ooo`800000^03oool010000000oooo0?ooo`3oool20000
00030?ooo`000000oooo08X0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3o
ool0403oool200000;P0oooo00<000000?ooo`3oool01000002<0?ooo`030000003oool0oooo00T0
oooo00140?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0]P3oool5000008h0oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool04@3oool200000;L0oooo1000
002?0?ooo`030000003oool0oooo00T0oooo00140?ooo`8000004P3oool200000;H0oooo0P000000
0`3oool000000?ooo`2=0?ooo`<000002`3oool004@0oooo00<000000?ooo`3oool04@3oool20000
0;D0oooo1000002A0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo0180
oooo0P00002c0?ooo`@00000TP3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo
0?ooo`0B0?ooo`800000/P3oool3000000030?ooo`000000oooo0940oooo00<000000?ooo`3oool0
2@3oool004@0oooo00<000000?ooo`3oool04P3oool200000;00oooo100000020?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`2]0?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01<0oooo0P00002]0?oo
o`80000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo
00T0oooo00140?ooo`030000003oool0oooo01<0oooo0P00002/0?ooo`@000001@3oool00`000000
oooo0?ooo`2@0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0Z03oool4000000L0oooo00<000000?ooo`3oool0T03oool00`000000oooo
0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0D0?ooo`800000Z03oool4000000P0oooo00<0
00000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0D
0?ooo`800000Y`3oool4000000T0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`09
0?ooo`00A03oool00`000000oooo0?ooo`0D0?ooo`800000YP3oool4000000X0oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0E0?ooo`80
0000X`3oool4000000`0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00
A03oool00`000000oooo0?ooo`0E0?ooo`800000XP3oool4000000d0oooo00<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0E0?ooo`<00000X03o
ool4000000h0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`0F0?ooo`800000W`3oool4000000l0oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`090?ooo`00A03oool2000001L0oooo0P00002M0?ooo`D00000403oool00`00
0000oooo0?ooo`2>0?ooo`<000002`3oool004@0oooo00<000000?ooo`3oool05`3oool2000009/0
oooo1000000B0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02@3oool004@0oooo
00<000000?ooo`3oool05`3oool2000009X0oooo1000000C0?ooo`030000003oool0oooo0900oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool05`3oool2000009T0oooo1000
000D0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool0603oool2000009H0oooo1@00000E0?ooo`030000003oool0oooo0900oooo00<00000
0?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0603oool2000009D0oooo1000000G0?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3o
ool06@3oool2000009<0oooo1000000H0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3o
ool02@3oool004@0oooo00<000000?ooo`3oool06@3oool200000980oooo1000000I0?ooo`030000
003oool0oooo0900oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool06@3o
ool200000900oooo1@00000J0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02@3o
ool004@0oooo00<000000?ooo`3oool06P3oool2000008h0oooo1000000L0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool06P3oool20000
08d0oooo1000000M0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02@3oool003L0
oooo00<0oooO09a80018W=l02P3oool00`000000oooo0?ooo`0K0?ooo`800000R`3oool4000001h0
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00>03oool00`3OW4P004RL
0=ooo`090?ooo`030000003oool0oooo01/0oooo0P00002:0?ooo`@000007`3oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo00T0oooo000h0?ooo`030?oOW01804P0W=oo00T0oooo00<0
00000?ooo`3oool0703oool2000008L0oooo1@00000P0?ooo`030000003oool0oooo0900oooo00<0
00000?ooo`3oool02@3oool003@0oooo00<0okmd000000000000100000000`00B9`0gooo0?ooo`06
0?ooo`030000003oool0oooo01`0oooo0P0000260?ooo`@000008P3oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo00T0oooo000d0?ooo`030?oog`2LB4P0W=oo0080oooo00<0_g@0001d
_`3oool0203oool00`000000oooo0?ooo`0M0?ooo`800000Q03oool4000002<0oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`090?ooo`00=@3oool01`3ookl0M01d0;ooo`3oool0okmd
0018W03Oool0203oool3000001d0oooo0P0000230?ooo`@00000903oool00`000000oooo0?ooo`2>
0?ooo`<000002`3oool003H0oooo00H0omnL04Q8W03Oool0omnL04P0B02Lgol80?ooo`030000003o
ool0oooo01h0oooo0P0000200?ooo`D000009@3oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo00T0oooo000g0?ooo`050?noM000M;l0oooO09a80018W=l0203oool00`000000oooo0?oo
o`0N0?ooo`<00000OP3oool4000002L0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`090?ooo`00>03oool0103OW4P0B9cO0;md0000M;l80?ooo`030000003oool0oooo01l0oooo0P00
001m0?ooo`@00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00T0oooo000i
0?ooo`040=nLB01dM7@0001d0;ooo`L0oooo00<000000?ooo`3oool07`3oool3000007/0oooo1000
000Y0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02@3oool003X0oooo00<0_g@0
0000B02Lgol01`3oool00`000000oooo0?ooo`0P0?ooo`800000N@3oool4000002/0oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00>P3oool00`3ooml0W4P004RLg`070?oo
o`030000003oool0oooo0200oooo0`00001g0?ooo`@00000;03oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo0240oooo0P00001f0?ooo`<0
0000;P3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000
003oool0oooo0280oooo0P00001d0?ooo`<00000;`3oool00`000000oooo0?ooo`2@0?ooo`030000
003oool0oooo00T0oooo00140?ooo`030000003oool0oooo0280oooo0`00001a0?ooo`@00000<03o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0
oooo02<0oooo0P00001`0?ooo`<00000<P3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo00T0oooo00140?ooo`030000003oool0oooo02@0oooo0P00001]0?ooo`@00000<`3oool00`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo02D0
oooo0P00001[0?ooo`@00000=03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00T0
oooo00140?ooo`030000003oool0oooo02D0oooo0P00001Y0?ooo`@00000=P3oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo02H0oooo0P00
001W0?ooo`@00000=`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00T0oooo0014
0?ooo`800000:03oool2000006@0oooo1000000i0?ooo`030000003oool0oooo08h0oooo0`00000;
0?ooo`00A03oool00`000000oooo0?ooo`0X0?ooo`800000HP3oool4000003X0oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0X0?ooo`<0
0000G`3oool4000003`0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00
A03oool00`000000oooo0?ooo`0Y0?ooo`<00000G@3oool4000003d0oooo00<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0Z0?ooo`<00000FP3o
ool4000003l0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`0[0?ooo`800000F@3oool400000400oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0/0?ooo`800000EP3oool40000
0480oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000
oooo0?ooo`0]0?ooo`800000E03oool4000004<0oooo00<000000?ooo`3oool0T03oool00`000000
oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0^0?ooo`800000D@3oool4000004D0oooo
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?oo
o`0_0?ooo`800000CP3oool4000004L0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`090?ooo`00A03oool00`000000oooo0?ooo`0`0?ooo`800000C03oool3000004T0oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0a0?oo
o`<00000B03oool4000004X0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?oo
o`00A03oool00`000000oooo0?ooo`0b0?ooo`<00000A@3oool4000004`0oooo00<000000?ooo`3o
ool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0c0?ooo`<00000
@P3oool5000004d0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03o
ool00`000000oooo0?ooo`0d0?ooo`@00000?P3oool5000004l0oooo00<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0e0?ooo`@00000>`3oool5
00000540oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool20000
03P0oooo1000000f0?ooo`H00000D`3oool00`000000oooo0?ooo`2>0?ooo`<000002`3oool004@0
oooo00<000000?ooo`3oool0>@3oool400000380oooo1P00001E0?ooo`030000003oool0oooo0900
oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0>P3oool5000002h0oooo
1P00001G0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02@3oool004@0oooo00<0
00000?ooo`3oool0?03oool5000002T0oooo1P00001J0?ooo`030000003oool0oooo0900oooo00<0
00000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0?P3oool5000002@0oooo1P00001M
0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?oo
o`3oool0@03oool6000001`0oooo2000001P0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool02@3oool004@0oooo00<000000?ooo`3oool0@P3oool8000001<0oooo2P00001S0?ooo`03
0000003oool0oooo0900oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0
AP3oool:000000D0oooo3P00001W0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0
2@3oool004@0oooo00<000000?ooo`3oool0B`3ooolB000006d0oooo00<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`3:0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0bP3oool00`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo0<X0
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo
0?ooo`3:0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02@3oool004@0oooo00<0
00000?ooo`3oool0bP3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00T0oooo0014
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00140?ooo`80
00001`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`070?ooo`<000002`3oool004@0ooooo`00001R000000/0oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo00370?ooo`090?oo_`1d0000000004RLg`3oool0oono07@000000000B9cO01@0
oooo00<0okmd0000000000000P0000000`00B9`0gooo0?ooo`0B0?ooo`050;md0000000000000000
0018W=l0[@3oool00<L0oooo00X0oono07@0B02Lgol0_g@0001d_`3ookl0M01809cOo`2oM00007Bo
4P3oool00`3o_g@0000004RLg`030?ooo`030?oOW01804P0W=oo01<0oooo00<0oooO09a80018W=l0
[P3oool00<X0oooo00<0oono07@0001d_ol00P3oool00`3ookl0M00007Boo`0A0?ooo`030?noM000
07@0_ooo00@0oooo00<0gia8001d_`3oool04`3oool00`3OW4P004RL0=ooo`2]0?ooo`00b`3oool0
0`3OW4P004RL0=ooo`020?ooo`030=nLB000B9`0gooo0140oooo00P0_g@00000M02oool0oooo0?oo
g`2LB000000004RLga@0oooo00<0omnL04P0M02oool0[@3oool00;@0oooo00<0_g@0000000000000
1@0000000`00B9`0gooo0?ooo`030?ooo`0<0?oOW018000000000018W03Oool0_g@000000000M;l0
oooo0?noM00004P0W=oo0P3oool00`3o_g@0001809cOo`030?ooo`080;md00000000001809cOo`3o
ool0gia80018W03Oool20?ooo`030;md0000000007Bo0080oooo00H0oono07@00000000000000000
M02oool50?ooo`030?noM0000000000000L0000000T0M;oo0?ooo`3ogi`0B0000000000007@0_ono
07@0001d_ol00P3oool02`3ogi`0B00000000000B9`0gooo0;md0000000007Bo0?ooo`3ogi`0B000
0080000000T0M;oo0=nLB000000004RL0=ooo`3o_g@000000000B02Lgol00P3oool0102oM0000000
0000B02Lgol20?ooo`050?noM000000000000000B02Lgol00`3oool00`3OW4P004RL0=ooo`020?oo
o`030;md0000000007Bo07d0oooo002e0?ooo`040?oo_`1d000004RL0=ooo`<0oooo00<0_g@00000
0000M;l00`3oool0303ogi`0B01809cOo`3ogi`0B7Bo0;md0000M;l0oknL09cOo`3ookl0M00004RL
g`80oooo00<0oono07@00018W=l00`3oool0203OW4P004RL0=oog`2LM9`0gooo0?noM00007@0_ooo
0P3oool0203OW4P004RL0=noM01d_ol0oooo0?noM00007@0_ooo2@3oool0103ooml0W4P00018W03O
ool30?ooo`0;0?oog`2LB00004RL0=ooo`2oM00004RL0=ooo`3ookl0M01d07Ad0018W=l00P3oool0
903ogi`0B01809cOo`3ogi`0B7Bo0;md0000M;l0oknL09cOo`2oM00004RL0=ooo`3oool0_g@007Ad
M00007@0_mnL09boo`3o_g@0001809cOg`2LM9`0gooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo0?oO
W01804P0W=oo0?ooo`3ogi`0B000001d_`80oooo00<0okmd0000M02oool00P3oool0103OW4P004RL
0=noM01d_oml0?ooo`00]P3oool00`3OW4P0001809cOo`040?ooo`0=0?oo_`1d000004RL0=ooo`3o
ool0oooO09a80018W=l0oooo0?noM01dM7@004RL0=ooo`020?ooo`030;md0000B9`0gooo0080oooo
00<0_g@00018W03Oool00P3oool00`3o_g@0001809cOo`020?ooo`030?oo_`1d0000B9cO0080oooo
00<0omnL04P0B02Lgol00`3oool00`2oM000M;oo0?ooo`090?ooo`030?noM00004P0W=oo00D0oooo
00@0giad09cOo`2oM00007Bo0P3oool0403ookl0M0000018W03Oool0oooo0?oog`2LB000B9cO0?oo
o`3o_g@0M7Ad0018W03Oool0oooo0;md0000M;l30?ooo`070;md00000000M;oo0?ooo`3ookl0M000
07Boo`030?ooo`030?noM00004P0W=oo0080oooo00<0gia80018W03Oool00P3oool01`3ogi`0B000
04RLg`3oool0oono07@00018W=l00P3oool00`3ogi`0B01809cOo`1m0?ooo`00]P3oool00`3ogi`0
B00007Boo`050?ooo`030?oOW018000007Bo0080oooo00L0_g@00018W03Oool0oooo0;md000004P0
W=oo0080oooo00<0gia80000M02oool00P3oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000
B9cO0080oooo00P0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`80oooo00<0oono07@00000
00000P0000000`1d_ol0oooo0?ooo`050?ooo`030?oo_`1d0000B9cO00L0oooo00<0gia80018W03O
ool00P3oool00`3o_g@0001d0;ooo`020?ooo`0;0;md0000B9`0gooo0?ooo`2oM000001809cOo`3o
ool0okmd0000M02oool00P3oool00`3ookl0M00004RLg`020?ooo`030;md0000M;l0oooo0080oooo
00<0oono07@00018W=l00P3oool00`3o_g@0001d0;ooo`030?ooo`0;0=nLB00007@0_ooo0?oog`2L
B000001d0;ooo`3oool0oooO09a80018W=l0O@3oool00;H0oooo00<0oono07@00000M;l01P3oool0
2`2oM000001809cOo`3oool0okmd0000M02oool0oooo0?oo_`1d0000M;oo0080oooo00<0omnL04P0
001d_ol00P3oool00`3ogi`0B00007Boo`030?ooo`030;md0000B9`0gooo0080oooo00<0gia80018
B018M;l00P3oool02`2oM00007Bo0?ooo`3oool0_g@00018W03Oool0oooo0?oOW0180000B9cO00H0
oooo00<0oooO09a80000M;l00P3oool00`3ookl0W9cO0?ooo`020?ooo`030?oOW0180000M;oo0080
oooo00<0oono07@0001d_ol00P3oool02`3o_g@0001d0;ooo`3oool0oono07@0001d_ol0oooo0?oo
_`1d0000M;oo00<0oooo00L0_g@00018W03Oool0oooo0=nLB000B9`0gooo00<0oooo00L0_g@00018
W03Oool0oooo0?oo_`1d0000M;oo00<0oooo00L0omnL04P0B02Lgol0oooo0=nLB000B4P0B7Bo0080
oooo00<0_g@0001d_`3oool0O03oool00;L0oooo00<0_g@00018W03Oool01@3oool01`3o_g@00000
04RLg`3ogml0gono07@0001d_ol00P3oool01`2oM00007Bo0?ooo`3oool0oooO09a80018W=l00P3o
ool00`3ooml0W4P004RLg`030?ooo`030=nLB00004P0W=oo0080oooo00/0okmd0000M02o_g@0B9cO
0?ooo`3o_g@0001d0;ooo`3oool0_g@0001d_`030?ooo`030=nLB00007@0_ooo00H0oooo00H0gia8
0000M02oool0oooo0?oOW018M;l40?ooo`0<0;md000007@0_ooo0?ooo`3ooml0W4P004RLg`3oool0
omoO0=oo_`1d0000M;oo0P3oool01`2oM00007Bo0?ooo`3oool0okmd0000M02oool00P3oool01`3O
W4P0001d0;ooo`3oool0omnL04P0B02Lgol00`3oool00`3OW4P0001809cOo`020?ooo`030=nLB000
07@0_ooo0080oooo00`0oono07@0001d_ol0oooo0?noM00007@0_kmd04RLg`3oool0okmd0000M02o
ooml0?ooo`00]`3oool00`3o_g@0001809cOo`050?ooo`070?oOW018000007Bo0?oOW018M;l0_g@0
001d_`020?ooo`030?noM000B9`0gooo0080oooo00<0_g@00018W03Oool00P3oool00`2oM00004RL
0=ooo`020?ooo`030?oOW0180000B9cO0080oooo00`0oooO09a8001d_ol0gia8001d_`3ogi`0B018
09cOo`3oool0omnL04P00018W=l20?ooo`030=nLB00007@0_ooo00H0oooo00<0okmd000000000000
0P0000000`0007@0_ooo0?ooo`020?ooo`0<0?oog`2LB00004RL0=ooo`3ookl0W4Q80018W03Oool0
omnL04Qd_`2oM00007Bo0P3oool00`3o_g@004RL0=ooo`020?ooo`0;0=nLB00007@0_ooo0?ooo`2o
M000001809cOo`3oool0oooO09a80018W=l00`3oool00`3ogi`0B00004RLg`030?ooo`0@0;md0000
07@0_ooo0?ooo`3o_g@0001d0;ooo`3oool0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOog`0
oooo002g0?ooo`030?oOW0180000M;oo00D0oooo00L0omnL04P00000M;l0oooo0?noM000000007Bo
0080oooo00D0omnL04P0B02Lgol0oono07@000030000000307Bo_`1d000000000080000000l0M;oo
0?noM000000000000018W03Oool0oono07@000000000B9cO0?ooo`3o_g@000000000B02Lgol00P3o
ool00`3ookl0M000000000040000000304RLg`3oool0oooo00<0oooo00<0oono07@0001d_ol00P3o
ool00`2oM4P0W=oo0?ooo`040?ooo`0:0=nLB0000000001d0;noM00007@0_ooo0?ooo`3o_g@00000
001d_`80oooo00<0omnL04P0B02Lgol00`3oool0203ogi`0B00000000018W9`0M00004RLg`3ookl0
M0000`0000001P1d_ol0okmd00000000000004RL0=ooo`<0oooo00l0okmd000000000000000007Bo
o`3oool0oono07@000000000B9cO0?ooo`3o_g@000000000B02Lgol0O03oool00;L0oooo00<0oooO
09a80000M;l01@3oool00`3o_g@0000004RLg`0;0?ooo`030?noM00004P0W=oo0080oooo00<0okmd
0000B02Lgol07`3oool01P2oM00007Bo0?ooo`3oool0omnL07BLgal0oooo00<0okmd0000M02oool0
U03oool00;P0oooo00<0_g@00018W03Oool00`3oool0103ooml0W4P00000M02oool;0?ooo`030?oo
g`2LB00007Bo0080oooo00<0oooO09a80000M;l07`3oool00`3OW4P0001d0;ooo`040?ooo`030=nL
W02oool0oooo01`0oooo00<0giad09cOo`3oool0T`3oool00;P0oooo00<0gia80000B02Lgol00P3o
ool0103ookl0M0000000001d_ol=0?ooo`030?noM00007@0_ooo0080oooo00<0okmd0000M02oool0
0P3oool0103ookl0M0000018W03OoolH0?ooo`030?noM00004P0W=oo00<0oooo00<0oono07@0B02L
gol08P3oool0103ookl0M0000018W03Ooon=0?ooo`00]`3oool00`2oM00000000000000400000003
0018W03Oool0oooo00h0oooo00X0gia80018W03Ooml0W4P004RLg`3OW4P004RL0=oog`2LB000B9cO
6P3oool00`2oM0000000000000060000000307Boo`3oool0oooo0;40oooo003@0?ooo`090=nLB000
0000001809cOo`3oool0gia80000000004P0W=oo0=L0oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-4.46872, -7.29277, 0.0245001, \
0.0476897}}]
}, Closed]],

Cell["\<\
The figure below illustrates the dependence of the limiting orbit upon \
\[Alpha].\
\>", "Text"],

Cell[BoxData[
    \(\(stuff = 
        Table[{duffingPlot[1, \[Alpha], 0.05, 10, 1.25, 0, 0, 100, 200, 
              MaxSteps \[Rule] 8000, PlotPoints \[Rule] 100, 
              PlotStyle \[Rule] Hue[\[Alpha]], 
              PlotRange \[Rule] {{\(-22\), 22}, {\(-22\), 22}}, 
              DisplayFunction \[Rule] Identity], 
            Graphics[
              Text[ToString[\[Alpha]], {10, 6 - 12  \[Alpha]}, 
                TextStyle \[Rule] {FontColor \[Rule] 
                      Hue[\[Alpha]]}]]}, {\[Alpha], 0, 1, 0.2}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[stuff, DisplayFunction \[Rule] $DisplayFunction, 
        PlotRange \[Rule] {{\(-22\), 22}, {\(-22\), 22}}, 
        AspectRatio \[Rule] Automatic];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.0227273 0.5 0.0227273 [
[.04545 -0.0125 -12.3438 -15.6875 ]
[.04545 -0.0125 12.3438 0 ]
[.27273 -0.0125 -12.3438 -15.6875 ]
[.27273 -0.0125 12.3438 0 ]
[.5 -0.0125 -5 -15.6875 ]
[.5 -0.0125 5 0 ]
[.72727 -0.0125 -8 -15.6875 ]
[.72727 -0.0125 8 0 ]
[.95455 -0.0125 -8 -15.6875 ]
[.95455 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.9688 -31.375 ]
[.5 -0.0125 21.9688 -15.6875 ]
[-0.0125 .04545 -24.6875 -7.84375 ]
[-0.0125 .04545 0 7.84375 ]
[-0.0125 .27273 -24.6875 -7.84375 ]
[-0.0125 .27273 0 7.84375 ]
[-0.0125 .5 -10 -7.84375 ]
[-0.0125 .5 0 7.84375 ]
[-0.0125 .72727 -16 -7.84375 ]
[-0.0125 .72727 0 7.84375 ]
[-0.0125 .95455 -16 -7.84375 ]
[-0.0125 .95455 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -40.375 -20.4688 ]
[-0.01875 .5 -24.6875 20.4688 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -43.9375 0 ]
[.5 1.0125 43.9375 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04545 0 m
.04545 .00625 L
s
gsave
.04545 -0.0125 -73.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.27273 0 m
.27273 .00625 L
s
gsave
.27273 -0.0125 -73.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.72727 0 m
.72727 .00625 L
s
gsave
.72727 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.95455 0 m
.95455 .00625 L
s
gsave
.95455 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
.09091 0 m
.09091 .00375 L
s
.13636 0 m
.13636 .00375 L
s
.18182 0 m
.18182 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.31818 0 m
.31818 .00375 L
s
.36364 0 m
.36364 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.54545 0 m
.54545 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.77273 0 m
.77273 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.90909 0 m
.90909 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.9688 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
102.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .04545 m
.00625 .04545 L
s
gsave
-0.0125 .04545 -85.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .27273 m
.00625 .27273 L
s
gsave
-0.0125 .27273 -85.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .72727 m
.00625 .72727 L
s
gsave
-0.0125 .72727 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .95455 m
.00625 .95455 L
s
gsave
-0.0125 .95455 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .09091 m
.00375 .09091 L
s
0 .13636 m
.00375 .13636 L
s
0 .18182 m
.00375 .18182 L
s
0 .22727 m
.00375 .22727 L
s
0 .31818 m
.00375 .31818 L
s
0 .36364 m
.00375 .36364 L
s
0 .40909 m
.00375 .40909 L
s
0 .45455 m
.00375 .45455 L
s
0 .54545 m
.00375 .54545 L
s
0 .59091 m
.00375 .59091 L
s
0 .63636 m
.00375 .63636 L
s
0 .68182 m
.00375 .68182 L
s
0 .77273 m
.00375 .77273 L
s
0 .81818 m
.00375 .81818 L
s
0 .86364 m
.00375 .86364 L
s
0 .90909 m
.00375 .90909 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -114 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
81.4688 11.8438 translate
90 rotate
-81.4688 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(velocity) show
99.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.04545 .99375 m
.04545 1 L
s
.27273 .99375 m
.27273 1 L
s
.5 .99375 m
.5 1 L
s
.72727 .99375 m
.72727 1 L
s
.95455 .99375 m
.95455 1 L
s
.125 Mabswid
.09091 .99625 m
.09091 1 L
s
.13636 .99625 m
.13636 1 L
s
.18182 .99625 m
.18182 1 L
s
.22727 .99625 m
.22727 1 L
s
.31818 .99625 m
.31818 1 L
s
.36364 .99625 m
.36364 1 L
s
.40909 .99625 m
.40909 1 L
s
.45455 .99625 m
.45455 1 L
s
.54545 .99625 m
.54545 1 L
s
.59091 .99625 m
.59091 1 L
s
.63636 .99625 m
.63636 1 L
s
.68182 .99625 m
.68182 1 L
s
.77273 .99625 m
.77273 1 L
s
.81818 .99625 m
.81818 1 L
s
.86364 .99625 m
.86364 1 L
s
.90909 .99625 m
.90909 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .04545 m
1 .04545 L
s
.99375 .27273 m
1 .27273 L
s
.99375 .5 m
1 .5 L
s
.99375 .72727 m
1 .72727 L
s
.99375 .95455 m
1 .95455 L
s
.125 Mabswid
.99625 .09091 m
1 .09091 L
s
.99625 .13636 m
1 .13636 L
s
.99625 .18182 m
1 .18182 L
s
.99625 .22727 m
1 .22727 L
s
.99625 .31818 m
1 .31818 L
s
.99625 .36364 m
1 .36364 L
s
.99625 .40909 m
1 .40909 L
s
.99625 .45455 m
1 .45455 L
s
.99625 .54545 m
1 .54545 L
s
.99625 .59091 m
1 .59091 L
s
.99625 .63636 m
1 .63636 L
s
.99625 .68182 m
1 .68182 L
s
.99625 .77273 m
1 .77273 L
s
.99625 .81818 m
1 .81818 L
s
.99625 .86364 m
1 .86364 L
s
.99625 .90909 m
1 .90909 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .5 m
1 .5 L
s
.5 0 m
.5 1 L
s
gsave
.5 1.0125 -104.938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Duffing) show
102.938 15.813 moveto
(Equation) show
146.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.14642 .28875 m
.13526 .32091 L
.12539 .35632 L
.11808 .39052 L
.11316 .42213 L
.11097 .44162 L
.10951 .4597 L
.10853 .47961 L
.10827 .48966 L
.10819 .50074 L
.10849 .5193 L
.10944 .53924 L
.11094 .55799 L
.11281 .57508 L
.11543 .59385 L
.11887 .6137 L
.12669 .64891 L
.13869 .68969 L
.15202 .72538 L
.18481 .79132 L
.22295 .84679 L
.27169 .8986 L
.29862 .92075 L
.32975 .94179 L
.35746 .95693 L
.38809 .97014 L
.40323 .97539 L
.41772 .97966 L
.43184 .98314 L
.44517 .98581 L
.46074 .98819 L
.46904 .98913 L
.47799 .9899 L
.48689 .99042 L
.49627 .99068 L
.50427 .99069 L
.51303 .99046 L
.52877 .98943 L
.53757 .98851 L
.54554 .98746 L
.561 .98484 L
.57552 .98165 L
.61008 .97117 L
.64115 .95807 L
.67412 .94001 L
.70742 .91686 L
.75698 .87124 L
.79678 .82152 L
.81619 .79117 L
.83509 .756 L
Mistroke
.85082 .72061 L
.863 .68726 L
.87264 .65485 L
.88097 .61898 L
.88462 .59892 L
.88738 .58034 L
.88948 .56246 L
.89113 .5435 L
.89207 .52712 L
.89259 .50955 L
.89263 .49295 L
.89227 .47784 L
.89137 .46013 L
.88982 .44094 L
.8878 .42291 L
.88547 .40634 L
.87854 .36939 L
.87021 .33624 L
.85918 .30147 L
.84475 .2648 L
.81502 .20669 L
.77708 .15183 L
.72772 .09964 L
.69732 .07509 L
.66828 .05591 L
.64005 .04078 L
.60853 .02755 L
.59378 .02261 L
.57804 .01816 L
.56328 .01475 L
.54952 .01222 L
.53439 .01016 L
.52638 .00936 L
.51786 .00874 L
.50354 .00822 L
.48772 .0084 L
.47372 .00923 L
.45866 .01082 L
.44449 .01298 L
.43155 .01554 L
.40266 .02325 L
.37168 .03479 L
.34025 .05018 L
.31203 .0675 L
.26319 .10666 L
.22321 .14973 L
.18328 .20724 L
.1525 .26806 L
.13943 .30164 L
.12907 .33414 L
Mistroke
.11986 .37075 L
.11254 .41098 L
.10989 .43135 L
.10877 .44216 L
.10779 .45371 L
.10705 .46483 L
.10656 .47493 L
.10607 .49465 L
.1062 .5137 L
.107 .53427 L
.10839 .55364 L
.1102 .57138 L
.11237 .58791 L
.11519 .6055 L
.12156 .63687 L
.13126 .6734 L
.14207 .70577 L
.17174 .77237 L
.20709 .82946 L
.24862 .87937 L
.30062 .92501 L
.32882 .94386 L
.36045 .9609 L
.3913 .97377 L
.40523 .97844 L
.42023 .98273 L
.43459 .98612 L
.44772 .98863 L
.46097 .99059 L
.47352 .99192 L
.4882 .99284 L
.50174 .99309 L
.51661 .99269 L
.53231 .9915 L
.54632 .98978 L
.56129 .98724 L
.5881 .98083 L
.61941 .97023 L
.64732 .95776 L
.70118 .92465 L
.72933 .90182 L
.75338 .87864 L
.79585 .82712 L
.82974 .77193 L
.84617 .73795 L
.86107 .70046 L
.87186 .66687 L
.88118 .62994 L
.88541 .60873 L
.88861 .58924 L
Mistroke
.89118 .56951 L
.89303 .55074 L
.89381 .54009 L
.89445 .52878 L
.89506 .50845 L
.89511 .49714 L
.89497 .48655 L
.89461 .47494 L
.89398 .46246 L
.89323 .45176 L
.89235 .4417 L
.89028 .42295 L
.8874 .4029 L
.88355 .38138 L
.87466 .3432 L
.86434 .30895 L
.83311 .23444 L
.81365 .1997 L
.78963 .1641 L
.74328 .11086 L
.71504 .08568 L
.68675 .06475 L
.6593 .04801 L
.62835 .03285 L
.59943 .02193 L
.57214 .01432 L
.55755 .01127 L
.5421 .0088 L
.52886 .00729 L
.51433 .00628 L
.49862 .00594 L
.48982 .00609 L
.48183 .00644 L
.4663 .00769 L
.45168 .00958 L
.43804 .01196 L
.42368 .01513 L
.39819 .02246 L
.37127 .03268 L
.3424 .04666 L
.28557 .08458 L
.25606 .11078 L
.23087 .13759 L
.18749 .19668 L
.1539 .26022 L
.13925 .29668 L
.1277 .33227 L
.11925 .36509 L
.11219 .40129 L
.10939 .42042 L
Mistroke
.107 .44153 L
.10608 .45221 L
.10529 .46368 L
.10442 .48442 L
.10424 .50512 L
.10472 .52471 L
.10567 .54226 L
.10728 .56127 L
.10931 .57898 L
.11168 .5955 L
.11875 .6327 L
.12783 .66818 L
.13997 .70532 L
.16785 .76884 L
.19966 .822 L
.24188 .87481 L
.26764 .90025 L
.29341 .92173 L
.3186 .93944 L
.34697 .95598 L
.3734 .96846 L
.39869 .97797 L
.42935 .98651 L
.44579 .98979 L
.455 .99124 L
.46355 .99235 L
.47247 .99325 L
.48221 .99395 L
.49081 .99432 L
.49996 .99445 L
.51576 .99406 L
.52476 .99349 L
.5332 .99271 L
.54838 .99075 L
.5643 .98789 L
.59249 .98077 L
.62228 .97027 L
.65404 .95548 L
.68282 .93856 L
.71271 .917 L
.7627 .86986 L
.80505 .81506 L
.83775 .75781 L
.86538 .69012 L
.87728 .64952 L
.88581 .61044 L
.88934 .58904 L
.89199 .56854 L
.89378 .55003 L
.89509 .52975 L
Mistroke
.89554 .5182 L
.89576 .50773 L
.89579 .49563 L
.89561 .48424 L
.89476 .46397 L
.89398 .45258 L
.89309 .44212 L
.89091 .42245 L
.88827 .40394 L
.8818 .36964 L
.87268 .33346 L
.86027 .29523 L
.83169 .23022 L
.7986 .17546 L
.75597 .12291 L
.70218 .07499 L
.67291 .05531 L
.64001 .03762 L
.6079 .0244 L
.57776 .01533 L
.56193 .01179 L
.54689 .00919 L
.53333 .00748 L
.5186 .00628 L
.50249 .00576 L
.49437 .0058 L
.48545 .0061 L
.46968 .00723 L
.45498 .009 L
.44028 .01147 L
.4264 .01444 L
.40063 .02168 L
.37339 .03186 L
.34445 .04571 L
.28668 .08399 L
.25685 .1104 L
.23163 .13719 L
.18801 .19655 L
.16972 .22846 L
.15454 .25976 L
.12989 .32635 L
.12011 .36324 L
.11225 .40365 L
.10933 .42426 L
.10808 .43518 L
.10696 .4468 L
.10616 .45697 L
.10548 .46819 L
.10478 .488 L
.1047 .50723 L
Mistroke
.10529 .52791 L
.10648 .54739 L
.10811 .56516 L
.11025 .58281 L
.1131 .60151 L
.11966 .63477 L
.12984 .67346 L
.14125 .70754 L
.16957 .77117 L
.20284 .82576 L
.24447 .87685 L
.29658 .92345 L
.32494 .94277 L
.35666 .9602 L
.38761 .9734 L
.40156 .97821 L
.41652 .98262 L
.43033 .98601 L
.44569 .98904 L
.45973 .99114 L
.47296 .99253 L
.48852 .99346 L
.50281 .99364 L
.51849 .99309 L
.53498 .99167 L
.5484 .98988 L
.56268 .98732 L
.58818 .98109 L
.618 .97096 L
.64449 .95925 L
.69914 .92604 L
.72499 .90542 L
.75186 .87989 L
.79475 .82811 L
.82882 .77284 L
.84624 .73676 L
.86045 .7009 L
.87131 .66715 L
.88066 .63021 L
.88492 .60886 L
.88813 .58933 L
.89071 .56954 L
.89255 .55081 L
.89335 .54012 L
.89398 .52881 L
.89459 .50852 L
.89465 .49722 L
.89451 .48667 L
.89415 .47511 L
.89352 .46274 L
Mistroke
.89207 .44367 L
.89098 .43285 L
.88978 .42273 L
.88658 .40077 L
.88296 .38082 L
.87475 .34532 L
.86354 .30805 L
.83196 .23326 L
.81233 .19851 L
.78822 .1631 L
.74145 .1099 L
.71303 .08487 L
.6847 .06421 L
.65711 .04765 L
.62616 .03278 L
.59725 .02214 L
.57012 .0148 L
.55456 .0117 L
.53971 .00949 L
.52634 .0081 L
.51174 .00723 L
.49588 .00706 L
.48702 .00731 L
.47902 .00775 L
.46343 .00919 L
.44882 .01125 L
.43508 .01383 L
.42068 .0172 L
.3952 .02488 L
.3683 .03549 L
.33961 .04984 L
.28287 .08877 L
.25355 .1155 L
.22869 .14265 L
.18592 .20244 L
.16801 .2346 L
.15313 .26624 L
.12952 .33221 L
.1202 .36877 L
.11275 .40899 L
.11004 .42933 L
.10889 .44013 L
.10787 .45168 L
.10709 .46279 L
.10656 .47288 L
.10601 .49261 L
.10608 .51165 L
.10681 .53223 L
.10813 .55161 L
.10989 .56937 L
Mistroke
.112 .58589 L
.11476 .60348 L
.12102 .63487 L
.13059 .67142 L
.14128 .70385 L
.17071 .77055 L
.20587 .82779 L
.24714 .87777 L
.2989 .92358 L
.32697 .94251 L
.35849 .95968 L
.38925 .97266 L
.40314 .9774 L
.41812 .98175 L
.43243 .9852 L
.44551 .98776 L
.45873 .98977 L
.47125 .99116 L
.4859 .99215 L
.49942 .99246 L
.51426 .99213 L
.52996 .99101 L
.54394 .98936 L
.55889 .98688 L
.58568 .98061 L
.60182 .97565 L
.61699 .97016 L
.64491 .95782 L
.67465 .94127 L
.70156 .92294 L
.74842 .88195 L
.79301 .82883 L
.81325 .79822 L
.83309 .76244 L
.86047 .69792 L
.87211 .66076 L
.88076 .62515 L
.88415 .60773 L
.88689 .59111 L
.88898 .57592 L
.89078 .55971 L
.89225 .54203 L
.89315 .52563 L
.89364 .50796 L
.89358 .48847 L
.89292 .46935 L
.89178 .45162 L
.88994 .43224 L
.8873 .41168 L
.87975 .37016 L
Mistroke
.87043 .33331 L
.85974 .30003 L
.84602 .26519 L
.8157 .20588 L
.7719 .144 L
.74464 .11431 L
.71729 .0895 L
.66517 .05316 L
.63593 .03801 L
.60358 .02508 L
.57239 .01613 L
.55643 .01282 L
.54719 .01129 L
.53869 .01012 L
.52357 .00862 L
.50721 .00782 L
.49278 .00783 L
.47759 .00854 L
.46109 .01015 L
.45188 .01143 L
.44353 .01283 L
.41219 .02015 L
.39488 .02562 L
.37634 .03266 L
.34348 .04832 L
.28739 .0857 L
.26112 .10873 L
.23403 .13708 L
.19151 .19418 L
.1587 .25465 L
.14378 .29043 L
.13207 .3249 L
.12167 .36389 L
.11736 .38424 L
.11349 .40648 L
.11056 .42793 L
.10854 .44779 L
.10721 .46685 L
.10646 .48704 L
.10634 .50517 L
.10672 .52209 L
.10766 .54062 L
.1093 .56042 L
.11151 .57963 L
.11409 .5973 L
.12182 .63676 L
.13077 .67078 L
.14242 .70592 L
.16756 .76369 L
.20216 .82193 L
Mistroke
.24598 .8761 L
.29878 .92314 L
.34824 .95427 L
.37767 .96796 L
.40573 .97801 L
.42169 .9825 L
.43913 .98643 L
.44718 .9879 L
.45572 .98923 L
.47108 .99103 L
.48587 .99205 L
.49972 .99237 L
.51491 .99203 L
.5312 .99084 L
.54015 .98983 L
.54844 .98866 L
.56711 .9852 L
.58345 .98123 L
.60067 .97606 L
.63297 .96352 L
.66136 .94922 L
.71516 .9125 L
.74034 .89018 L
.76623 .86297 L
.80716 .80834 L
.83894 .75097 L
.85496 .71357 L
.86769 .67674 L
.87704 .64266 L
.88491 .6048 L
.88804 .58491 L
.89071 .56284 L
.89176 .55168 L
.89266 .53965 L
.89328 .52827 L
.89368 .51783 L
.89393 .49797 L
.89379 .48673 L
.89348 .47629 L
.89245 .45722 L
.89069 .43694 L
.8884 .41772 L
.88518 .39676 L
.87649 .35506 L
.86587 .31743 L
.85378 .28335 L
.81918 .21131 L
.79563 .17446 L
.77178 .14344 L
.72359 .09445 L
Mistroke
.69381 .07114 L
.66487 .05261 L
.63646 .03788 L
.60902 .02661 L
.57977 .01756 L
.56404 .0139 L
.55526 .01221 L
.54695 .01085 L
.5313 .00888 L
.51703 .00778 L
.50164 .00731 L
.49296 .00738 L
.48495 .00766 L
.4716 .00857 L
.45695 .01022 L
.44172 .01268 L
.42754 .01566 L
.39534 .02492 L
.36655 .03632 L
.3343 .05285 L
.30486 .07179 L
.25076 .11813 L
.20672 .17059 L
.16645 .23716 L
.14806 .27777 L
.13411 .3163 L
.12423 .35067 L
.11577 .38931 L
.11246 .40908 L
.10964 .43043 L
.10767 .4507 L
.10646 .46924 L
.10582 .48774 L
.10571 .50486 L
.10615 .52364 L
.10724 .54354 L
.1087 .56071 L
.11051 .57676 L
.11619 .61298 L
.12478 .6515 L
.13649 .69095 L
.16392 .7578 L
.18267 .79258 L
.20216 .82302 L
.25307 .88432 L
.30556 .92886 L
.33746 .94915 L
.36804 .96457 L
.39559 .97541 L
.42651 .98438 L
Mistroke
.44228 .98772 L
.451 .98921 L
.4593 .9904 L
.47545 .99209 L
.49022 .9929 L
.50357 .99304 L
.51832 .99254 L
.53369 .99128 L
.5481 .98941 L
.56144 .98708 L
.57362 .98444 L
.60081 .97675 L
.62787 .96652 L
.65674 .95257 L
.71186 .91606 L
.7379 .89347 L
.76443 .86608 L
.80734 .80936 L
.84172 .74669 L
.86627 .68359 L
.87678 .64668 L
.88446 .61127 L
.8879 .59068 L
.89044 .57171 L
.89158 .56119 L
.89263 .54967 L
.89336 .53958 L
.89397 .52863 L
.89439 .51719 L
.8946 .50639 L
.89448 .48622 L
.89412 .47477 L
.8935 .46269 L
.89279 .4524 L
.89181 .44112 L
.88954 .421 L
.88637 .39959 L
.87875 .36148 L
.86846 .32338 L
.85486 .2842 L
.82382 .21808 L
.78172 .15458 L
.75415 .12264 L
.72616 .09577 L
.70017 .07489 L
.67149 .05572 L
.64575 .04158 L
.61744 .02905 L
.60111 .02316 L
.58612 .01858 L
Mistroke
.57073 .01468 L
.55645 .01176 L
.53968 .00918 L
.53081 .00818 L
.52141 .0074 L
.50559 .00672 L
.49659 .00669 L
.48817 .00689 L
.47248 .00786 L
.46372 .00874 L
.45581 .00975 L
.44044 .0123 L
.42607 .01537 L
.39417 .02469 L
.36054 .03844 L
.33157 .05378 L
.30217 .07303 L
.25318 .11491 L
.21109 .16373 L
.17733 .21568 L
.14714 .27865 L
.13361 .31618 L
.1235 .35147 L
.11584 .38618 L
.11235 .40644 L
.10976 .42513 L
.10766 .44492 L
.10681 .45534 L
.10611 .46632 L
.10537 .48487 L
.10521 .50516 L
.10566 .52411 L
.10657 .54127 L
.10822 .56102 L
.11035 .57955 L
.11554 .61225 L
.12313 .64706 L
.1337 .68409 L
.14798 .72342 L
.16449 .7601 L
.18492 .79733 L
.22793 .85756 L
.27472 .90522 L
.3018 .92675 L
.33203 .94655 L
.35918 .96098 L
.38935 .97366 L
.40649 .97939 L
.42238 .9838 L
.43868 .98745 L
Mistroke
.45395 .99007 L
.46209 .99115 L
.47082 .99208 L
.48051 .99283 L
.48934 .99325 L
.49857 .99343 L
.50857 .99332 L
.51802 .99292 L
.52672 .9923 L
.5412 .99074 L
.5567 .98832 L
.57126 .98533 L
.58448 .98201 L
.61634 .97152 L
.64587 .95852 L
.70159 .92426 L
.731 .90017 L
.75664 .87496 L
.8016 .81842 L
.82215 .78525 L
.84132 .748 L
.85587 .71368 L
.86929 .67453 L
.87911 .63778 L
.88616 .60273 L
.88892 .5849 L
.89133 .56539 L
.89303 .54686 L
.8941 .52967 L
.89465 .51418 L
.89481 .49707 L
.89446 .47921 L
.89367 .46247 L
.89227 .44406 L
.8902 .42477 L
.88499 .39061 L
.87725 .35445 L
.8663 .31589 L
.85321 .27953 L
.83643 .24178 L
.79951 .17852 L
.75631 .1247 L
.71106 .08302 L
.65728 .04744 L
.62498 .03198 L
.5939 .02077 L
.57681 .01604 L
.56046 .01244 L
.54569 .00994 L
.52953 .00801 L
Mistroke
.5203 .00728 L
.51193 .00685 L
.50227 .00664 L
.49319 .00671 L
.477 .00748 L
.46791 .00827 L
.45957 .00924 L
.44373 .01168 L
.42885 .01473 L
.40127 .02234 L
.37214 .03326 L
.34139 .04826 L
.28895 .08313 L
.24474 .12374 L
.20212 .17638 L
.16314 .24296 L
.14703 .27929 L
.1325 .32012 L
.12155 .36003 L
.11395 .39745 L
.11092 .41727 L
.10865 .43608 L
.10712 .45304 L
.10599 .47146 L
.10538 .49162 L
.10533 .50179 L
.10546 .51294 L
.10619 .53267 L
.10744 .55105 L
.10926 .56949 L
.1115 .58688 L
.11701 .61915 L
.12487 .6533 L
.13562 .68954 L
.16569 .76218 L
.18443 .79624 L
.20768 .83142 L
.25471 .88643 L
.28004 .90954 L
.30485 .92873 L
.35804 .96022 L
.38753 .97278 L
.41981 .98293 L
.43632 .98675 L
.44506 .98841 L
.45435 .9899 L
.4625 .99098 L
.47147 .99192 L
.48731 .99295 L
.50271 .99318 L
Mistroke
.51925 .9926 L
.53484 .99126 L
.54904 .98935 L
.56321 .9868 L
.57821 .98338 L
.60488 .97541 L
.63592 .96296 L
.66324 .94894 L
.71433 .914 L
.75815 .87287 L
.79945 .82101 L
.83712 .75607 L
.85278 .72065 L
.86692 .68108 L
.87766 .64244 L
.88158 .62504 L
.88518 .60639 L
.88798 .58909 L
.89049 .56989 L
.89225 .55233 L
.89343 .53579 L
.89426 .51632 L
.89447 .49847 L
.89411 .47887 L
.89306 .45829 L
.89169 .44148 L
.88972 .42363 L
.88485 .39176 L
.87691 .35448 L
.86769 .32141 L
.84129 .25274 L
.82485 .22027 L
.80452 .18657 L
.76318 .13271 L
.71907 .08997 L
.69019 .06805 L
.66151 .05018 L
.63452 .03652 L
.60501 .02476 L
.58955 .01985 L
.57229 .01533 L
.55646 .01206 L
.54151 .00972 L
.53294 .00871 L
.5239 .0079 L
.50769 .00709 L
.49865 .007 L
.49024 .00715 L
.48101 .00758 L
.47115 .00833 L
Mistroke
.4558 .01012 L
.4471 .01147 L
.43898 .01296 L
.42134 .01693 L
.40535 .02144 L
.37685 .03169 L
.34698 .04567 L
.31614 .06391 L
.28407 .08754 L
.23079 .13983 L
.18811 .19842 L
.16804 .23399 L
.15151 .26939 L
.13824 .30393 L
.12634 .3426 L
.11782 .37872 L
.11195 .41257 L
.10945 .43214 L
.10767 .45077 L
.10655 .46756 L
.10586 .48586 L
.10573 .50577 L
.1059 .51582 L
.10629 .5269 L
.10745 .54644 L
.10911 .5647 L
.11119 .58195 L
.1139 .6 L
.12008 .63189 L
.12861 .66556 L
.14012 .70141 L
.17141 .77246 L
.19288 .80911 L
.21464 .84015 L
.26259 .89353 L
.28834 .91585 L
.31364 .93435 L
.36669 .96385 L
.39607 .97544 L
.42832 .98466 L
.44467 .98799 L
.45335 .9894 L
.46261 .99064 L
.47153 .99157 L
.47962 .9922 L
.49542 .99282 L
.51069 .99267 L
.52717 .99168 L
.54268 .98995 L
.55687 .98769 L
Mistroke
.57014 .98498 L
.58424 .98146 L
.60938 .97349 L
.63864 .96135 L
.66455 .94785 L
.71786 .91073 L
.7635 .86656 L
.8035 .8145 L
.84002 .74936 L
.85509 .71403 L
.86869 .67443 L
.87894 .63582 L
.88266 .61841 L
.88606 .59966 L
.88888 .58074 L
.89093 .56346 L
.89249 .54601 L
.8935 .52951 L
.89412 .51019 L
.89416 .49238 L
.89361 .47285 L
.89235 .45226 L
.89083 .43561 L
.88869 .41784 L
.88353 .38606 L
.87522 .34892 L
.86565 .31584 L
.83897 .24843 L
.82246 .21652 L
.80199 .18324 L
.76061 .13025 L
.71636 .08806 L
.68909 .06759 L
.65904 .04908 L
.63213 .0357 L
.60259 .02418 L
.5856 .01895 L
.57 .01503 L
.55421 .01188 L
.53922 .00964 L
.5307 .00869 L
.52165 .00794 L
.50542 .00724 L
.49638 .00722 L
.48793 .00743 L
.47867 .00792 L
.46872 .00875 L
.46014 .00972 L
.45207 .01085 L
.43707 .01352 L
Mistroke
.42101 .01719 L
.40381 .02209 L
.37329 .03335 L
.34596 .04638 L
.2865 .08573 L
.25882 .11019 L
.23051 .14033 L
.18818 .19849 L
.16821 .23388 L
.15167 .26927 L
.13844 .30363 L
.12652 .3423 L
.11798 .37842 L
.11206 .41246 L
.1097 .43073 L
.10782 .45006 L
.1067 .46663 L
.10598 .48478 L
.10581 .50443 L
.10598 .51543 L
.10631 .5254 L
.10742 .54479 L
.10903 .56301 L
.11103 .58005 L
.11366 .59797 L
.11969 .62973 L
.12805 .66326 L
.13942 .69916 L
.17015 .76987 L
.19132 .80651 L
.21291 .83772 L
.26044 .89138 L
.31139 .93275 L
.3407 .95079 L
.36925 .96493 L
.39558 .97522 L
.42456 .98372 L
.43989 .98707 L
.45679 .98987 L
.46534 .99093 L
.47451 .99181 L
.49108 .99271 L
.50763 .99275 L
.52326 .99199 L
.53727 .99064 L
.55242 .98847 L
.56657 .98577 L
.57975 .98266 L
.6094 .9735 L
.63766 .96184 L
Mistroke
.66718 .94636 L
.71762 .91099 L
.7597 .87086 L
.80152 .81758 L
.8216 .78515 L
.83848 .75279 L
.85237 .72114 L
.86527 .68557 L
.87495 .65246 L
.88225 .62085 L
.88594 .60085 L
.88873 .58247 L
.89116 .56191 L
.89221 .55054 L
.893 .53975 L
.89359 .52928 L
.89402 .51815 L
.89428 .49814 L
.89415 .48703 L
.89384 .47661 L
.8933 .46519 L
.89248 .4529 L
.89075 .43413 L
.88819 .4137 L
.88098 .37303 L
.87187 .33617 L
.86134 .30277 L
.83145 .23305 L
.81077 .19665 L
.78943 .16529 L
.74508 .11389 L
.72015 .09108 L
.69186 .06938 L
.66514 .05241 L
.63989 .03915 L
.61352 .02795 L
.58856 .01967 L
.57316 .01564 L
.55911 .01265 L
.54342 .01007 L
.53478 .00899 L
.52663 .0082 L
.51175 .00729 L
.49805 .00707 L
.48302 .00752 L
.46719 .00877 L
.4519 .01074 L
.43538 .01372 L
.41988 .01733 L
.40567 .02136 L
Mistroke
.37915 .03076 L
.35166 .04324 L
.29737 .07707 L
.26855 .10085 L
.24313 .12593 L
.20214 .17689 L
.17019 .22967 L
.14199 .2932 L
.13072 .32691 L
.12073 .36482 L
.11322 .40362 L
.1101 .42578 L
.10795 .44633 L
.10664 .46442 L
.10581 .48434 L
.10563 .49439 L
.10563 .50517 L
.1061 .52462 L
.10714 .54342 L
.10893 .56381 L
.11123 .58296 L
.11391 .60059 L
.12035 .63352 L
.12917 .66784 L
.14085 .70371 L
.15595 .74101 L
.18948 .80394 L
.21229 .83721 L
.23879 .86937 L
.26518 .8961 L
.29172 .91866 L
.3178 .93725 L
.34729 .95456 L
.37263 .9666 L
.40121 .97731 L
.41634 .98181 L
.43276 .98581 L
.45023 .98909 L
.46668 .99127 L
.48308 .99258 L
.49869 .99304 L
.5127 .99279 L
.52798 .9918 L
.54354 .99003 L
.55814 .98766 L
.57118 .98496 L
.58518 .98142 L
.61622 .97117 L
.6441 .95899 L
.69281 .93016 L
Mistroke
.74032 .89101 L
.78653 .83891 L
.82245 .78404 L
.8395 .7511 L
.85559 .71349 L
.86736 .67968 L
.87796 .64123 L
.88183 .62389 L
.88543 .60503 L
.88806 .58859 L
.89043 .5705 L
.89236 .55108 L
.89373 .53056 L
.89438 .5115 L
.89445 .49377 L
.89401 .47575 L
.8931 .45878 L
.89189 .44359 L
.89016 .42719 L
.88777 .40939 L
.88467 .39069 L
.87767 .3576 L
.86728 .32005 L
.8552 .2855 L
.82702 .22423 L
.78919 .16463 L
.74017 .10883 L
.6919 .06918 L
.66308 .051 L
.63604 .03715 L
.61001 .02646 L
.59611 .02175 L
.58131 .01748 L
.56823 .01432 L
.5538 .0115 L
.54061 .00951 L
.52828 .00816 L
.51238 .00713 L
.50435 .00692 L
.4955 .00692 L
.47986 .00753 L
.46524 .0088 L
.45645 .0099 L
.44811 .01117 L
.43251 .01415 L
.41585 .01823 L
.39784 .0237 L
.36802 .03529 L
.33713 .05085 L
.28462 .08684 L
Mistroke
.23484 .13484 L
.19408 .1886 L
.16334 .24289 L
.13698 .30687 L
.12637 .3416 L
.11736 .37984 L
.11389 .39867 L
.11114 .41666 L
.10915 .43278 L
.10745 .45067 L
.10618 .47034 L
.10576 .48114 L
.10553 .49129 L
.10554 .50941 L
.10615 .52894 L
.10672 .53926 L
.10754 .55053 L
.10983 .57316 L
.1127 .59398 L
.116 .61321 L
.12536 .65461 L
.13681 .69264 L
.1648 .76009 L
.18401 .79527 L
.20381 .82577 L
.25529 .88682 L
.30379 .92783 L
.33299 .94678 L
.3607 .96138 L
.38715 .97254 L
.40135 .97748 L
.41663 .98201 L
.43144 .98564 L
.44494 .98831 L
.45857 .99042 L
.47146 .99185 L
.48649 .99285 L
.50299 .99313 L
.51131 .99294 L
.52022 .99249 L
.53625 .99106 L
.55218 .98881 L
.56717 .98594 L
.59498 .97864 L
.62712 .96684 L
.65602 .95294 L
.68889 .93295 L
.71758 .91137 L
.76366 .86685 L
.80684 .80999 L
Mistroke
.8385 .75332 L
.86461 .68837 L
.87532 .65202 L
.88021 .63164 L
.88418 .61219 L
.88732 .59388 L
.89008 .57389 L
.89201 .55561 L
.89331 .5387 L
.89425 .51853 L
.89453 .49964 L
.89417 .47892 L
.89366 .46731 L
.89301 .45673 L
.89213 .44571 L
.89114 .43553 L
.88828 .41258 L
.88504 .39251 L
.88087 .37137 L
.87203 .33583 L
.86041 .29939 L
.834 .23751 L
.79804 .17688 L
.75068 .11921 L
.7039 .07783 L
.67627 .05882 L
.64912 .04345 L
.62306 .03148 L
.5941 .0211 L
.58113 .01741 L
.56729 .0141 L
.55433 .01157 L
.54225 .00971 L
.52718 .00805 L
.51069 .00706 L
.49614 .0069 L
.48063 .00748 L
.46542 .00878 L
.45114 .01068 L
.43837 .01294 L
.42464 .01597 L
.39332 .02526 L
.36102 .0385 L
.33425 .05253 L
.30591 .0707 L
.25821 .11038 L
.21276 .162 L
.17624 .21826 L
.14902 .27489 L
.13686 .30736 L
Mistroke
.12567 .34438 L
.12096 .36338 L
.11656 .3841 L
.11335 .40219 L
.11046 .42213 L
.10835 .4409 L
.10691 .45844 L
.10594 .47701 L
.10552 .49689 L
.1057 .51544 L
.10639 .53293 L
.10743 .5486 L
.10901 .56553 L
.11149 .58555 L
.11441 .60414 L
.12316 .64584 L
.13446 .6854 L
.14955 .72639 L
.18419 .7955 L
.22343 .85161 L
.26926 .89995 L
.29674 .9226 L
.32389 .94122 L
.35028 .95619 L
.37969 .96959 L
.40707 .9792 L
.43266 .98584 L
.44759 .9887 L
.46366 .99098 L
.47888 .99236 L
.49276 .99299 L
.50908 .99294 L
.51828 .99254 L
.52678 .99193 L
.54234 .99022 L
.55878 .98756 L
.57435 .98422 L
.59098 .97977 L
.6206 .96945 L
.65485 .95347 L
.68506 .93542 L
.73546 .89556 L
.78328 .84309 L
.82166 .78536 L
.85005 .72723 L
.86419 .68933 L
.8749 .65324 L
.88402 .61255 L
.88755 .59172 L
.89059 .56864 L
Mistroke
.89254 .54822 L
.89373 .52951 L
.89413 .51915 L
.89438 .50786 L
.8943 .48733 L
.89361 .46818 L
.89222 .44788 L
.89051 .43061 L
.88805 .41164 L
.8817 .37575 L
.87233 .33727 L
.8599 .29825 L
.84598 .26324 L
.81564 .20433 L
.77617 .14799 L
.75106 .11974 L
.72173 .09225 L
.69428 .07093 L
.66378 .05149 L
.63524 .03686 L
.60288 .02404 L
.58844 .01953 L
.57278 .01545 L
.5581 .01236 L
.5442 .01009 L
.5362 .00906 L
.52754 .00819 L
.5124 .00723 L
.50379 .00701 L
.4947 .00703 L
.47844 .00772 L
.4634 .00912 L
.44943 .01106 L
.43416 .01391 L
.41792 .01779 L
.38193 .02961 L
.34882 .04466 L
.32012 .06127 L
.29023 .08252 L
.23936 .13 L
.19277 .19088 L
.16005 .25007 L
.14463 .28622 L
.13238 .32148 L
.12242 .35762 L
.1152 .39199 L
.11195 .41202 L
.10957 .43035 L
.1085 .44054 L
.10752 .45162 L
Mistroke
.10626 .47177 L
.10568 .49133 L
.10562 .50245 L
.10575 .51284 L
.10608 .52379 L
.10654 .53378 L
.10728 .54529 L
.10819 .55619 L
.11025 .57538 L
.1127 .59305 L
.12015 .63258 L
.12946 .66881 L
.14023 .70196 L
.16537 .76089 L
.19929 .81896 L
.24307 .87401 L
.29307 .91967 L
.34428 .95293 L
.37528 .96768 L
.40427 .97823 L
.42056 .98287 L
.43841 .98693 L
.44663 .98844 L
.45538 .98981 L
.47113 .99165 L
.48746 .99273 L
.50242 .99297 L
.51067 .99279 L
.51968 .99236 L
.53605 .99091 L
.55124 .98879 L
.56735 .98573 L
.59602 .97813 L
.61336 .97216 L
.63186 .9646 L
.66454 .94801 L
.7219 .90752 L
.76996 .85935 L
.80891 .80644 L
.84405 .74092 L
.85996 .70137 L
.87193 .66388 L
.88178 .62352 L
.8884 .58537 L
.89089 .56524 L
.89202 .5536 L
.89286 .54289 L
.89355 .53162 L
.89405 .51946 L
.8943 .50872 L
Mistroke
.89435 .49741 L
.89397 .47819 L
.8929 .4577 L
.89127 .43843 L
.88926 .42099 L
.88626 .40061 L
.88224 .37871 L
.87291 .33964 L
.86225 .30518 L
.84854 .26937 L
.8181 .20863 L
.77321 .14451 L
.72501 .09516 L
.66901 .0546 L
.63521 .03692 L
.60282 .02409 L
.58647 .01904 L
.57095 .01508 L
.55674 .01217 L
.54166 .0098 L
.53378 .00885 L
.52511 .00804 L
.50986 .00719 L
.50126 .00704 L
.49204 .00714 L
.48335 .00748 L
.47544 .008 L
.46064 .0095 L
.44682 .01154 L
.43173 .01448 L
.41559 .01846 L
.38321 .02915 L
.35428 .04193 L
.30375 .07241 L
.25491 .1138 L
.20783 .1689 L
.17107 .22807 L
.13949 .30019 L
.12615 .34308 L
.11687 .38321 L
.11103 .4188 L
.10865 .43923 L
.10705 .45841 L
.10601 .47871 L
.10565 .49727 L
.10569 .50753 L
.10592 .51869 L
.10687 .53898 L
.10821 .55617 L
.11024 .57509 L
Mistroke
.11299 .59472 L
.11615 .61304 L
.12316 .64528 L
.13266 .67933 L
.16184 .75363 L
.18019 .78843 L
.20289 .82416 L
.24924 .88047 L
.29848 .92375 L
.32741 .94325 L
.35516 .95852 L
.38661 .97215 L
.403 .97782 L
.42082 .98293 L
.43654 .98655 L
.45101 .98915 L
.46563 .9911 L
.47956 .99231 L
.49574 .99294 L
.51076 .99279 L
.52723 .9918 L
.53641 .99087 L
.54472 .98979 L
.55921 .98739 L
.57442 .98412 L
.60135 .97642 L
.62978 .96552 L
.66012 .95052 L
.71162 .916 L
.75551 .87553 L
.79996 .82006 L
.8204 .78745 L
.83963 .75059 L
.85419 .71683 L
.86776 .67805 L
.87775 .64164 L
.88504 .60667 L
.88796 .58858 L
.89019 .57165 L
.89202 .55388 L
.89342 .53438 L
.89414 .51743 L
.89438 .502 L
.89418 .4842 L
.89352 .46742 L
.89228 .44917 L
.89038 .42992 L
.88828 .41358 L
.88546 .39572 L
.87729 .35646 L
Mistroke
.86734 .32061 L
.84007 .25035 L
.82082 .21328 L
.80067 .18098 L
.75846 .12763 L
.73448 .1036 L
.70698 .08036 L
.67838 .06032 L
.65101 .04458 L
.62456 .03224 L
.59485 .02147 L
.58174 .01771 L
.5676 .0143 L
.55531 .01188 L
.54191 .00979 L
.5267 .00813 L
.51228 .00724 L
.49823 .00701 L
.48525 .00734 L
.46965 .00846 L
.45486 .01024 L
.44164 .01242 L
.42728 .01545 L
.39555 .0246 L
.36671 .036 L
.31643 .06365 L
.26675 .10244 L
.21436 .16003 L
.17315 .22407 L
.14385 .28817 L
.13082 .32648 L
.12116 .36284 L
.11707 .38193 L
.11375 .4002 L
.11123 .41693 L
.10905 .43481 L
.10728 .45432 L
.1062 .47245 L
.10564 .49199 L
.1056 .50312 L
.10574 .51358 L
.10637 .53097 L
.10756 .54926 L
.10901 .56481 L
.11105 .58176 L
.1173 .61925 L
.12519 .65349 L
.13706 .69298 L
.15071 .72899 L
.18231 .79218 L
Mistroke
.22442 .85271 L
.24942 .88073 L
.27831 .90777 L
.30549 .9289 L
.33147 .94575 L
.35883 .96036 L
.38494 .97158 L
.41593 .9817 L
.43253 .98576 L
.44108 .98749 L
.45035 .98911 L
.45925 .99039 L
.46745 .99135 L
.4836 .9926 L
.49831 .99302 L
.51383 .99273 L
.53027 .99158 L
.54519 .98978 L
.55342 .98849 L
.56234 .98684 L
.57846 .98318 L
.60912 .97379 L
.63685 .96241 L
.66625 .9471 L
.69741 .92684 L
.75545 .87568 L
.79924 .82122 L
.83736 .75546 L
.8627 .69376 L
.8739 .65702 L
.88218 .62197 L
.8859 .60201 L
.88919 .58019 L
.89156 .55944 L
.89312 .54023 L
.89402 .52282 L
.89443 .50366 L
.89422 .48365 L
.89344 .46496 L
.89276 .45453 L
.89181 .44319 L
.88955 .42264 L
.88669 .40277 L
.88346 .38451 L
.87411 .34377 L
.86113 .30171 L
.83231 .23439 L
.79881 .17815 L
.7551 .12395 L
.70232 .07676 L
Mistroke
.67836 .06024 L
.65178 .04492 L
.62813 .03369 L
.60186 .02368 L
.58557 .01869 L
.57039 .01487 L
.55578 .01191 L
.54021 .00952 L
.52623 .00804 L
.51311 .00722 L
.4987 .00695 L
.48319 .0074 L
.47461 .00797 L
.46653 .00873 L
.45148 .01069 L
.43535 .01362 L
.41802 .01771 L
.38722 .02753 L
.35952 .03928 L
.33003 .05507 L
.29896 .07579 L
.24137 .12773 L
.19733 .18382 L
.17631 .21822 L
.15869 .25282 L
.14444 .28652 L
.13135 .32461 L
.12171 .36032 L
.11476 .39409 L
.11185 .4122 L
.10938 .4314 L
.10776 .44788 L
.10649 .46597 L
.10572 .48557 L
.10556 .49655 L
.10558 .50653 L
.10609 .52594 L
.10714 .54423 L
.10861 .56133 L
.11069 .57935 L
.11574 .61136 L
.12306 .64526 L
.13331 .68169 L
.16181 .75378 L
.18181 .79141 L
.20243 .82366 L
.24825 .87958 L
.29792 .92344 L
.32659 .94286 L
.35465 .95836 L
Mistroke
.38093 .97006 L
.40929 .97984 L
.4243 .98389 L
.44087 .98749 L
.45604 .98999 L
.47024 .99165 L
.47889 .99235 L
.48708 .99279 L
.50243 .99305 L
.51895 .99249 L
.52826 .99179 L
.53686 .9909 L
.55002 .98908 L
.56413 .9865 L
.58943 .98022 L
.619 .97009 L
.64545 .95831 L
.69755 .92676 L
.74773 .88369 L
.79338 .82958 L
.82837 .77319 L
.84484 .73938 L
.86017 .70106 L
.87122 .6667 L
.88095 .62788 L
.88447 .61022 L
.88766 .5911 L
.88993 .57447 L
.89187 .55626 L
.89342 .53565 L
.89424 .51604 L
.89444 .49693 L
.8941 .47924 L
.89333 .46286 L
.89221 .4475 L
.89054 .43072 L
.88822 .4127 L
.88186 .37643 L
.87412 .34375 L
.85115 .2754 L
.83478 .23925 L
.81782 .20798 L
.77959 .1522 L
.73776 .10658 L
.71193 .08416 L
.6831 .06328 L
.65712 .04775 L
.62826 .03374 L
.59643 .02191 L
.58194 .0177 L
Mistroke
.566 .0139 L
.55628 .01199 L
.54723 .0105 L
.53783 .00922 L
.52929 .00831 L
.51294 .00721 L
.50396 .00697 L
.4955 .00698 L
.4809 .00753 L
.46528 .00886 L
.4506 .01083 L
.43727 .01322 L
.42174 .01675 L
.40499 .02147 L
.37503 .03235 L
.34453 .04687 L
.31332 .06567 L
.26105 .10772 L
.21843 .15472 L
.18374 .20536 L
.15235 .26707 L
.13803 .30411 L
.12711 .33925 L
.11811 .3766 L
.11201 .4112 L
.10949 .43058 L
.10841 .44082 L
.10746 .45169 L
.10621 .47172 L
.10564 .49021 L
.1056 .5072 L
.10609 .52544 L
.10704 .54262 L
.10833 .55826 L
.11034 .5765 L
.11315 .59625 L
.1199 .63175 L
.1305 .67252 L
.14249 .7083 L
.15788 .74538 L
.17725 .78344 L
.21842 .84526 L
.26398 .89503 L
.28862 .91627 L
.31634 .93633 L
.34128 .95136 L
.36924 .96516 L
.38668 .97226 L
.40302 .9779 L
.41849 .9824 L
Mistroke
.43568 .98644 L
.45118 .98925 L
.46577 .99118 L
.48123 .99248 L
.48993 .99288 L
.4979 .99303 L
.51416 .99272 L
.52325 .99218 L
.53148 .99146 L
.54747 .98945 L
.56247 .98681 L
.57988 .98282 L
.59577 .97828 L
.63099 .96505 L
.65878 .95132 L
.68823 .93326 L
.74354 .88782 L
.79162 .83196 L
.82975 .77051 L
.85702 .70956 L
.86929 .67318 L
.87854 .63852 L
.88248 .62042 L
.8861 .60072 L
.88872 .58354 L
.89102 .56464 L
.89201 .55446 L
.89288 .54356 L
.89359 .53203 L
.89405 .52129 L
.89433 .51054 L
.89442 .50038 L
.89414 .48137 L
.89318 .46092 L
.89244 .45064 L
.89143 .43934 L
.88912 .41946 L
.88638 .40096 L
.87815 .35986 L
.8662 .31686 L
.85316 .28045 L
.83672 .24326 L
.80097 .18135 L
.77544 .14711 L
.74915 .11779 L
.72352 .09378 L
.69487 .07135 L
.66813 .05401 L
.63769 .03799 L
.60916 .02624 L
Mistroke
.58198 .01775 L
.56527 .01378 L
.54935 .01085 L
.53498 .00892 L
.51932 .00757 L
.5112 .00718 L
.50225 .00699 L
.49289 .00706 L
.48412 .00738 L
.46848 .00856 L
.45972 .00956 L
.4517 .01069 L
.43578 .01356 L
.42086 .01701 L
.39329 .02537 L
.36422 .03712 L
.33367 .05297 L
.28169 .08939 L
.2382 .13126 L
.19641 .18528 L
.15864 .25303 L
.14319 .28991 L
.12945 .33114 L
.11926 .37134 L
.11543 .39059 L
.11239 .40886 L
.10991 .42722 L
.10813 .44417 L
.1067 .46307 L
.10581 .48353 L
.1056 .50211 L
.106 .52245 L
.10646 .5327 L
.10714 .54365 L
.10886 .56332 L
.11104 .58167 L
.11403 .60146 L
.12111 .63693 L
.13 .67074 L
.13992 .70117 L
.16855 .76722 L
.18832 .8021 L
.20895 .83272 L
.25621 .88755 L
.28571 .91389 L
.31427 .93493 L
.342 .95172 L
.36899 .96502 L
.40097 .97722 L
.41531 .98151 L
Mistroke
.43059 .98531 L
.4441 .98803 L
.45901 .99034 L
.47261 .99182 L
.48534 .99267 L
.50039 .99301 L
.51411 .99269 L
.52992 .99159 L
.54485 .98981 L
.55964 .98734 L
.57586 .9838 L
.60827 .97407 L
.6376 .96203 L
.66437 .94815 L
.72114 .90822 L
.7505 .88079 L
.77553 .85275 L
.81482 .79697 L
.83341 .76336 L
.84886 .72997 L
.86135 .69756 L
.87271 .66125 L
.88101 .62736 L
.88692 .59554 L
.88955 .57712 L
.89174 .5572 L
.89321 .53831 L
.89404 .52101 L
.8944 .50073 L
.89431 .48926 L
.89403 .47863 L
.89305 .45918 L
.89133 .43855 L
.88878 .41707 L
.88519 .39405 L
.87646 .35301 L
.86529 .3141 L
.85275 .2795 L
.82241 .21605 L
.78193 .15524 L
.73704 .10597 L
.69141 .06895 L
.66171 .05034 L
.63325 .03598 L
.60109 .02346 L
.58456 .01846 L
.56617 .01398 L
.54998 .01097 L
.53508 .00895 L
.52684 .00814 L
Mistroke
.51782 .0075 L
.50137 .007 L
.48607 .0073 L
.46976 .00845 L
.45442 .0103 L
.44057 .01262 L
.42588 .01578 L
.41048 .01986 L
.38325 .02909 L
.35463 .04171 L
.32418 .05869 L
Mfstroke
0 g
gsave
.72727 .63636 -66.5938 -11.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 14.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(0) show
70.188 14.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 1 0 r
.56489 .60917 m
.56816 .60887 L
.57111 .6082 L
.57449 .60687 L
.57764 .60504 L
.5805 .60281 L
.58307 .60025 L
.58862 .59262 L
.59131 .58759 L
.59368 .58222 L
.5963 .57501 L
.59847 .56765 L
.60036 .55981 L
.60215 .55058 L
.60371 .54015 L
.60485 .52972 L
.60529 .5243 L
.60567 .51834 L
.60608 .50739 L
.60615 .49665 L
.60591 .48682 L
.60533 .47635 L
.60486 .47054 L
.60433 .46522 L
.60299 .4549 L
.60118 .44454 L
.59931 .43621 L
.597 .42797 L
.59474 .42146 L
.59214 .41534 L
.58965 .41055 L
.58675 .40603 L
.58399 .4026 L
.58134 .39998 L
.57806 .39751 L
.5763 .39649 L
.57441 .39561 L
.5724 .39491 L
.57049 .39443 L
.56877 .39416 L
.5669 .39401 L
.56349 .3941 L
.56177 .39431 L
.55989 .39465 L
.55658 .3955 L
.55351 .39656 L
.54614 .39985 L
.53964 .40337 L
.52587 .41114 L
.52047 .41376 L
Mistroke
.51488 .41592 L
.51171 .41682 L
.50887 .4174 L
.50751 .4176 L
.50603 .41776 L
.50337 .41787 L
.50086 .41779 L
.4981 .41749 L
.4967 .41725 L
.4952 .41693 L
.49247 .4162 L
.4871 .41422 L
.48209 .41182 L
.45975 .39854 L
.45383 .39534 L
.44728 .39248 L
.44541 .39184 L
.44345 .39125 L
.43991 .39048 L
.43657 .39013 L
.43293 .39022 L
.43089 .39051 L
.42897 .39096 L
.42542 .3923 L
.42344 .39335 L
.42165 .39452 L
.41768 .39794 L
.4146 .40149 L
.41136 .40627 L
.40817 .41226 L
.40539 .41879 L
.40284 .42622 L
.40066 .43405 L
.3989 .44178 L
.39727 .4506 L
.39583 .46077 L
.39479 .47063 L
.39401 .48161 L
.39373 .48798 L
.39357 .494 L
.39355 .50436 L
.39386 .51535 L
.39448 .52553 L
.3953 .53451 L
.39657 .54463 L
.39832 .55494 L
.40028 .56393 L
.40234 .57152 L
.4071 .58446 L
.41013 .59045 L
Mistroke
.41314 .59516 L
.41646 .59921 L
.4196 .60214 L
.42137 .60345 L
.42332 .60465 L
.42505 .6055 L
.42693 .60624 L
.43034 .60711 L
.43356 .60743 L
.43671 .60734 L
.43959 .60695 L
.44271 .60624 L
.4461 .60517 L
.45282 .60235 L
.47466 .59056 L
.48037 .58788 L
.48331 .58672 L
.4864 .58568 L
.48907 .58497 L
.49047 .58467 L
.49198 .5844 L
.49462 .58408 L
.49709 .58395 L
.49951 .584 L
.50216 .58423 L
.50493 .58469 L
.50753 .5853 L
.51224 .58683 L
.51738 .58902 L
.5298 .59575 L
.537 .59994 L
.54402 .60373 L
.54743 .60536 L
.55071 .60674 L
.55395 .60788 L
.55697 .60871 L
.56034 .60934 L
.56402 .6096 L
.56769 .60935 L
.56974 .60896 L
.57158 .60844 L
.57336 .60777 L
.57521 .60689 L
.57849 .60481 L
.58194 .60181 L
.58558 .59756 L
.5886 .59302 L
.59165 .58726 L
.5966 .5745 L
.59916 .56546 L
Mistroke
.60154 .55457 L
.60337 .54337 L
.60409 .53776 L
.60468 .53238 L
.60553 .52209 L
.60585 .51651 L
.60609 .51045 L
.60622 .50409 L
.60624 .49803 L
.60599 .4867 L
.60538 .47588 L
.60454 .46636 L
.60322 .45585 L
.60166 .44652 L
.5982 .4316 L
.59589 .42426 L
.59357 .41823 L
.58816 .40785 L
.58483 .40334 L
.58159 .4 L
.5798 .39853 L
.57807 .39734 L
.57479 .39562 L
.57294 .39493 L
.57121 .39445 L
.56931 .3941 L
.56728 .39391 L
.56421 .39395 L
.56086 .39439 L
.55739 .39522 L
.55418 .39628 L
.54853 .39871 L
.54265 .40177 L
.53015 .40901 L
.52435 .41218 L
.51916 .41464 L
.51437 .41644 L
.51199 .41714 L
.50939 .41772 L
.50679 .41812 L
.50534 .41825 L
.50402 .41832 L
.50145 .4183 L
.49901 .4181 L
.49683 .41777 L
.49449 .41726 L
.49024 .41597 L
.48508 .41382 L
.48028 .41136 L
.45754 .3977 L
Mistroke
.45151 .39462 L
.44812 .39317 L
.44488 .39203 L
.44302 .3915 L
.441 .39103 L
.43745 .39052 L
.43383 .39048 L
.43049 .39091 L
.42692 .39197 L
.42361 .39357 L
.42174 .39477 L
.42005 .39607 L
.41632 .39971 L
.41307 .40392 L
.40969 .40955 L
.4064 .41659 L
.4036 .4242 L
.40122 .43228 L
.39923 .44065 L
.39766 .44884 L
.39626 .45803 L
.39506 .46857 L
.39426 .47864 L
.39375 .48974 L
.39362 .49611 L
.3936 .50208 L
.39384 .51309 L
.3941 .51858 L
.39448 .52458 L
.39542 .53488 L
.39659 .54416 L
.3983 .5544 L
.40018 .56311 L
.40254 .57181 L
.40534 .57994 L
.40783 .58575 L
.41068 .59113 L
.41327 .59509 L
.41619 .5987 L
.41975 .60205 L
.42321 .60439 L
.42664 .60596 L
.42984 .60685 L
.43274 .60723 L
.43587 .60725 L
.43883 .60694 L
.44151 .60642 L
.44464 .60556 L
.44801 .60436 L
.45404 .60169 L
Mistroke
.46555 .59552 L
.47721 .58938 L
.48341 .5868 L
.48608 .58592 L
.48898 .58515 L
.4917 .58462 L
.49423 .58431 L
.49689 .58417 L
.49838 .58417 L
.49974 .58424 L
.50231 .58449 L
.50469 .58489 L
.50732 .58551 L
.51014 .58635 L
.51495 .5882 L
.52038 .59079 L
.53287 .59784 L
.53982 .6018 L
.54742 .60563 L
.55073 .60702 L
.55431 .60826 L
.55639 .60884 L
.55828 .60927 L
.56019 .60959 L
.562 .60978 L
.56539 .60984 L
.56852 .60948 L
.57192 .60859 L
.57549 .607 L
.57876 .60488 L
.58223 .60178 L
.5854 .59807 L
.58823 .59392 L
.59319 .58413 L
.5957 .57755 L
.59779 .57093 L
.59987 .5629 L
.60179 .55369 L
.60353 .54282 L
.60477 .53225 L
.60561 .52199 L
.6061 .5122 L
.60631 .50134 L
.60628 .49524 L
.60616 .48972 L
.60572 .4799 L
.60495 .46974 L
.60404 .46137 L
.6028 .45255 L
.60119 .44365 L
Mistroke
.59916 .43479 L
.59479 .42094 L
.59241 .41534 L
.58965 .41001 L
.58708 .406 L
.58423 .4024 L
.58131 .39952 L
.5786 .39745 L
.57582 .39586 L
.57317 .39479 L
.57005 .39401 L
.56669 .39369 L
.56352 .39381 L
.56063 .39424 L
.55726 .39507 L
.55364 .39631 L
.54717 .3992 L
.53478 .40617 L
.52258 .41297 L
.51778 .41513 L
.51273 .41689 L
.51134 .41726 L
.50988 .41759 L
.50729 .41804 L
.50486 .41828 L
.50221 .41834 L
.49979 .41821 L
.49759 .41794 L
.49503 .41744 L
.49259 .41681 L
.48821 .41527 L
.48334 .41308 L
.47202 .40663 L
.45885 .39861 L
.45209 .39506 L
.44868 .39357 L
.44548 .3924 L
.44256 .39156 L
.43943 .39094 L
.43594 .39063 L
.43277 .39075 L
.42919 .39142 L
.42592 .39258 L
.42239 .39453 L
.42064 .3958 L
.41874 .39743 L
.41563 .40075 L
.41241 .40514 L
.40704 .41533 L
.40412 .42294 L
Mistroke
.40127 .4324 L
.39895 .44239 L
.39714 .45244 L
.39582 .46205 L
.39472 .47316 L
.39431 .4789 L
.39398 .48516 L
.39367 .49662 L
.39374 .50767 L
.39411 .5176 L
.39489 .5288 L
.39596 .53897 L
.39724 .54794 L
.39865 .55576 L
.40255 .57154 L
.40495 .57864 L
.40738 .58452 L
.41049 .59056 L
.4135 .59518 L
.4168 .59912 L
.42004 .60205 L
.42355 .60436 L
.42556 .60532 L
.42744 .60601 L
.42932 .60652 L
.43105 .60684 L
.43295 .60703 L
.43496 .60707 L
.43834 .6068 L
.44025 .60647 L
.44203 .60608 L
.44533 .60511 L
.44831 .60402 L
.45486 .60106 L
.46797 .59395 L
.47475 .59035 L
.48088 .58756 L
.48591 .58577 L
.4887 .58503 L
.49123 .58452 L
.49397 .58416 L
.49552 .58405 L
.49696 .58401 L
.49959 .58408 L
.5024 .58437 L
.50497 .58483 L
.50776 .58552 L
.5129 .58728 L
.52286 .59208 L
.53568 .5995 L
Mistroke
.54312 .60361 L
.55032 .60693 L
.55354 .6081 L
.55662 .60899 L
.5602 .60969 L
.56347 .60997 L
.5671 .60981 L
.57044 .60917 L
.57408 .60785 L
.5759 .60691 L
.57789 .60565 L
.58112 .60303 L
.58404 .59994 L
.58714 .5958 L
.59028 .59048 L
.59338 .58387 L
.59607 .57667 L
.5983 .56935 L
.6004 .56084 L
.60199 .55287 L
.60348 .54354 L
.60458 .53463 L
.60537 .526 L
.60601 .51556 L
.60632 .50587 L
.60632 .49464 L
.60599 .48407 L
.60527 .47286 L
.6043 .46306 L
.60282 .45231 L
.60109 .44286 L
.59728 .42791 L
.59477 .42067 L
.59227 .41482 L
.58954 .40963 L
.58646 .40494 L
.58292 .40082 L
.57949 .39787 L
.57761 .39663 L
.57554 .39553 L
.57357 .39472 L
.57173 .39417 L
.56824 .39357 L
.56648 .39347 L
.56453 .39352 L
.56122 .39391 L
.55817 .39459 L
.55484 .39563 L
.55133 .39701 L
.53817 .4039 L
Mistroke
.52765 .41001 L
.52237 .41278 L
.51695 .41516 L
.51395 .41622 L
.51238 .41669 L
.5107 .41712 L
.50916 .41744 L
.50777 .41768 L
.50504 .41799 L
.50232 .41807 L
.50078 .41802 L
.49935 .41791 L
.49673 .41755 L
.4954 .41729 L
.49393 .41695 L
.48867 .41526 L
.48286 .41267 L
.4718 .40639 L
.46039 .39946 L
.45378 .39588 L
.44733 .39307 L
.44361 .39187 L
.44149 .39135 L
.43953 .391 L
.43605 .39069 L
.43429 .3907 L
.43235 .39086 L
.42888 .39158 L
.42694 .39224 L
.42518 .39301 L
.4218 .39503 L
.41866 .39761 L
.41526 .40131 L
.4123 .40544 L
.40926 .41075 L
.40619 .41751 L
.40358 .42473 L
.40139 .43214 L
.39954 .43981 L
.39781 .44867 L
.39625 .45892 L
.39512 .46899 L
.39459 .47533 L
.3942 .48144 L
.39394 .48699 L
.39376 .49306 L
.39369 .499 L
.39374 .50554 L
.39392 .51234 L
.3942 .51866 L
Mistroke
.39501 .5297 L
.39562 .53573 L
.39628 .54111 L
.39778 .55088 L
.39948 .5595 L
.40332 .5738 L
.40581 .58067 L
.40829 .58626 L
.41138 .59186 L
.41443 .59622 L
.41718 .59933 L
.41976 .60165 L
.42268 .60368 L
.42588 .60526 L
.42898 .60625 L
.43239 .60678 L
.43561 .60684 L
.4386 .60654 L
.44212 .60582 L
.4441 .60527 L
.4459 .60468 L
.45261 .60189 L
.46459 .59552 L
.47669 .58907 L
.48313 .58634 L
.48612 .58535 L
.48885 .58463 L
.49136 .58414 L
.494 .5838 L
.49665 .58366 L
.49816 .58367 L
.49957 .58374 L
.50212 .58401 L
.50446 .58441 L
.50719 .58506 L
.50979 .58586 L
.51952 .59008 L
.53079 .59647 L
.54404 .60399 L
.54803 .6059 L
.55185 .60746 L
.55533 .60861 L
.55729 .60912 L
.55913 .60949 L
.56248 .60991 L
.56618 .6099 L
.56976 .60935 L
.57177 .60878 L
.57358 .60809 L
.57679 .60641 L
Mistroke
.58021 .60388 L
.58335 .60078 L
.58617 .59726 L
.58901 .59285 L
.59186 .58739 L
.59646 .5756 L
.59872 .56792 L
.60059 .56011 L
.60248 .55026 L
.60394 .54031 L
.60494 .53129 L
.60573 .52118 L
.60619 .51178 L
.60638 .50302 L
.60633 .49354 L
.60598 .4832 L
.60528 .47263 L
.60433 .46308 L
.60297 .45309 L
.60113 .44291 L
.59908 .43408 L
.59692 .42664 L
.59227 .41469 L
.58939 .40924 L
.58664 .40506 L
.58324 .40102 L
.58001 .39812 L
.57636 .39579 L
.5745 .39493 L
.57244 .3942 L
.56895 .39348 L
.56698 .39331 L
.56519 .39331 L
.56171 .39364 L
.55843 .39432 L
.55537 .39523 L
.55211 .39645 L
.54631 .39913 L
.53374 .40619 L
.52222 .41249 L
.51669 .41489 L
.51359 .41595 L
.51081 .41671 L
.50819 .41723 L
.50573 .41755 L
.50314 .41769 L
.50168 .41768 L
.50033 .41762 L
.49808 .41739 L
.4956 .41697 L
Mistroke
.49299 .41635 L
.49053 .4156 L
.4857 .41371 L
.48119 .41154 L
.47058 .40544 L
.45861 .3983 L
.45169 .39477 L
.44822 .39331 L
.44499 .39219 L
.44218 .39144 L
.43921 .3909 L
.43621 .39065 L
.43292 .39077 L
.42959 .39136 L
.42605 .3926 L
.42275 .39439 L
.41981 .39659 L
.41647 .3999 L
.41305 .40432 L
.40738 .41475 L
.40454 .42193 L
.40213 .42954 L
.39978 .43882 L
.39764 .44978 L
.39615 .45986 L
.3955 .4654 L
.39492 .47145 L
.39446 .47736 L
.39414 .4828 L
.39377 .49356 L
.39373 .504 L
.39405 .51521 L
.39468 .52559 L
.39554 .53484 L
.39682 .54483 L
.39833 .55376 L
.40183 .56881 L
.40415 .57615 L
.40649 .58221 L
.40943 .58839 L
.41237 .59329 L
.41752 .59956 L
.42038 .60202 L
.42353 .60404 L
.4267 .60544 L
.43008 .60634 L
.43298 .60668 L
.43616 .60665 L
.43797 .60646 L
.43993 .60614 L
Mistroke
.44348 .60526 L
.4469 .60411 L
.45001 .60285 L
.46399 .59557 L
.47528 .58941 L
.48121 .58671 L
.48407 .58564 L
.48669 .58481 L
.48921 .58417 L
.49188 .58367 L
.4934 .58348 L
.49483 .58336 L
.49749 .58328 L
.49995 .58339 L
.50221 .58365 L
.50471 .58409 L
.50736 .58475 L
.51224 .58641 L
.51688 .58846 L
.52791 .59452 L
.54073 .60206 L
.54738 .60547 L
.55371 .608 L
.5573 .60902 L
.55912 .6094 L
.56114 .6097 L
.56316 .60986 L
.56533 .60987 L
.56739 .60971 L
.56926 .6094 L
.57255 .60845 L
.5761 .60678 L
.57787 .60566 L
.57973 .60426 L
.58301 .60113 L
.58614 .59728 L
.58943 .59212 L
.59264 .58566 L
.59542 .57866 L
.59974 .56385 L
.60175 .55437 L
.60329 .54508 L
.60403 .5396 L
.60471 .5336 L
.60565 .5225 L
.60601 .5162 L
.60624 .51022 L
.60637 .50362 L
.60638 .49649 L
.60627 .49074 L
Mistroke
.60604 .48449 L
.60568 .47804 L
.60524 .47214 L
.60419 .46187 L
.60271 .45145 L
.60087 .44162 L
.59887 .43328 L
.59645 .42516 L
.59348 .41732 L
.59086 .41183 L
.58788 .40678 L
.58457 .4024 L
.58134 .39915 L
.57814 .39674 L
.57631 .39568 L
.57458 .39487 L
.5714 .39383 L
.56798 .39327 L
.56461 .39321 L
.56145 .39355 L
.55861 .39413 L
.55557 .39501 L
.54929 .39751 L
.54275 .40081 L
.53153 .40721 L
.52012 .41315 L
.51711 .4144 L
.51396 .4155 L
.5113 .41624 L
.50988 .41656 L
.50839 .41685 L
.50684 .41707 L
.50542 .41722 L
.5039 .41731 L
.50223 .41733 L
.50079 .41729 L
.49924 .41717 L
.49645 .41679 L
.49498 .4165 L
.49338 .41611 L
.49045 .41524 L
.48488 .41303 L
.4729 .40659 L
.46101 .39948 L
.45476 .39609 L
.44865 .39334 L
.44522 .39214 L
.44339 .39162 L
.44144 .39117 L
.43798 .39066 L
Mistroke
.43477 .39056 L
.43148 .39089 L
.42795 .39178 L
.42466 .39321 L
.42168 .39506 L
.41903 .39723 L
.4162 .40015 L
.41079 .40794 L
.40764 .41415 L
.40488 .42098 L
.40039 .43616 L
.39832 .4459 L
.39672 .45559 L
.39534 .46686 L
.3948 .47275 L
.39433 .47936 L
.39383 .49057 L
.39371 .50094 L
.39377 .50665 L
.39395 .51286 L
.39456 .52398 L
.39545 .53402 L
.39674 .54425 L
.39825 .55336 L
.39986 .56108 L
.4039 .57544 L
.40656 .58236 L
.40923 .58799 L
.41217 .59297 L
.41509 .5969 L
.41859 .60052 L
.42189 .60302 L
.42483 .60463 L
.42799 .60579 L
.43072 .60637 L
.43374 .60662 L
.43697 .60648 L
.44045 .60593 L
.44371 .60508 L
.44667 .60407 L
.46007 .59758 L
.47337 .59014 L
.47946 .58717 L
.48239 .58596 L
.48506 .58501 L
.48741 .58431 L
.48997 .5837 L
.49254 .58327 L
.49524 .58301 L
.49791 .58297 L
Mistroke
.50044 .58312 L
.50272 .58341 L
.50522 .5839 L
.50795 .58462 L
.51088 .5856 L
.51626 .58788 L
.53809 .60038 L
.5451 .60421 L
.54888 .60599 L
.55294 .6076 L
.55654 .60871 L
.5586 .60918 L
.56053 .60951 L
.56393 .60979 L
.56757 .60959 L
.57109 .60886 L
.57307 .60817 L
.57489 .60736 L
.57818 .60538 L
.58159 .60253 L
.58455 .5993 L
.58723 .59566 L
.59005 .59092 L
.5929 .58503 L
.59556 .57822 L
.59777 .5713 L
.60145 .55588 L
.60311 .54626 L
.60385 .54096 L
.60453 .53521 L
.60552 .52428 L
.6061 .51393 L
.60637 .50314 L
.60628 .49153 L
.60584 .48071 L
.60514 .47107 L
.60458 .46536 L
.60397 .4602 L
.60229 .44904 L
.60048 .4399 L
.59824 .43102 L
.59406 .41874 L
.59143 .41294 L
.58887 .40833 L
.58384 .40158 L
.58119 .399 L
.57822 .39677 L
.57484 .39495 L
.57172 .39387 L
.56999 .39349 L
Mistroke
.5681 .39323 L
.56466 .39316 L
.56145 .39348 L
.55806 .3942 L
.55519 .39505 L
.55206 .39621 L
.53983 .40229 L
.52738 .40933 L
.52199 .41207 L
.5164 .41443 L
.51374 .41532 L
.51125 .416 L
.50903 .41647 L
.50664 .41683 L
.50386 .41705 L
.50228 .41707 L
.50081 .41702 L
.49925 .41691 L
.49783 .41674 L
.49618 .41647 L
.49462 .41615 L
.49183 .41542 L
.48923 .41456 L
.48323 .41202 L
.47212 .40592 L
.45923 .39831 L
.45278 .39499 L
.44919 .39343 L
.4458 .3922 L
.44287 .39138 L
.43972 .39076 L
.4362 .39046 L
.43301 .39058 L
.42978 .39115 L
.42683 .39212 L
.42363 .39371 L
.4203 .39606 L
.41747 .39869 L
.4149 .40167 L
.40939 .41044 L
.40658 .41652 L
.40376 .42413 L
.40151 .43166 L
.39939 .44048 L
.39759 .44995 L
.39623 .45908 L
.39515 .4687 L
.3944 .47805 L
.39386 .48932 L
.39373 .49505 L
Mistroke
.3937 .50134 L
.39392 .51244 L
.39445 .52261 L
.39492 .52866 L
.39546 .53427 L
.39674 .54439 L
.39847 .55461 L
.40074 .56481 L
.40504 .57863 L
.40778 .58513 L
.41048 .59027 L
.41311 .59435 L
.4161 .59807 L
.41902 .6009 L
.4218 .60297 L
.42352 .60398 L
.42539 .60487 L
.42883 .60599 L
.4322 .60652 L
.43531 .60657 L
.43867 .60622 L
.44058 .60586 L
.44235 .60542 L
.4459 .6043 L
.44966 .60279 L
.46305 .59579 L
.47623 .58853 L
.48136 .58619 L
.48677 .5843 L
.48825 .58389 L
.48981 .58354 L
.49259 .58306 L
.49517 .58281 L
.49664 .58276 L
.498 .58276 L
.49934 .58282 L
.50079 .58294 L
.50344 .58332 L
.50603 .58388 L
.50843 .58455 L
.51398 .58664 L
.52004 .5896 L
.53363 .59758 L
.54071 .60174 L
.54744 .60522 L
.5505 .60656 L
.55387 .60781 L
.55708 .60874 L
.56008 .60935 L
.5636 .60968 L
Mistroke
.56679 .60959 L
.57045 .60895 L
.57388 .60776 L
.57737 .60585 L
.5791 .60461 L
.58098 .60303 L
.58425 .59959 L
.58713 .59573 L
.59037 .59026 L
.59361 .58328 L
.59637 .57576 L
.59871 .56783 L
.6022 .5517 L
.60366 .54226 L
.60489 .53156 L
.60575 .52051 L
.60605 .51485 L
.60626 .50861 L
.60636 .49748 L
.60613 .48718 L
.60558 .47687 L
.60478 .46742 L
.60383 .45924 L
.60257 .45077 L
.60094 .44208 L
.59893 .43359 L
.59469 .42037 L
.59197 .41408 L
.58932 .40912 L
.58632 .4046 L
.58289 .40061 L
.57962 .39776 L
.57652 .39578 L
.57351 .39444 L
.57027 .39355 L
.56827 .39325 L
.56643 .39313 L
.56441 .39316 L
.56227 .39336 L
.5587 .39402 L
.55669 .39456 L
.55482 .39515 L
.54824 .39785 L
.54141 .40136 L
.5294 .40814 L
.52317 .4114 L
.51752 .41388 L
.5144 .41498 L
.51157 .41579 L
.51008 .41613 L
Mistroke
.50847 .41643 L
.50676 .41667 L
.50514 .41683 L
.50366 .4169 L
.50232 .41692 L
.50077 .41687 L
.4993 .41676 L
.49669 .41641 L
.49521 .41612 L
.49385 .41581 L
.48863 .41418 L
.48364 .41207 L
.47177 .40558 L
.45831 .39769 L
.45206 .39455 L
.44842 .39303 L
.44496 .39185 L
.44174 .39103 L
.43823 .3905 L
.43641 .39038 L
.43448 .39039 L
.43105 .3908 L
.42924 .39122 L
.42732 .39185 L
.42389 .39348 L
.42183 .39481 L
.4199 .39632 L
.41638 .39981 L
.41338 .40367 L
.41034 .40859 L
.40534 .41958 L
.40287 .42687 L
.40077 .43444 L
.39876 .44342 L
.39692 .45401 L
.39562 .46397 L
.39471 .47359 L
.3941 .48305 L
.39374 .49328 L
.39369 .50341 L
.39392 .51289 L
.39435 .52128 L
.39504 .53015 L
.39607 .53958 L
.39751 .5494 L
.39935 .55897 L
.40134 .56717 L
.40552 .57993 L
.40815 .58595 L
.4107 .5907 L
Mistroke
.41331 .59467 L
.41623 .59825 L
.41955 .60137 L
.42274 .60358 L
.4262 .60522 L
.42796 .60579 L
.42989 .60624 L
.43332 .6066 L
.43652 .60651 L
.43976 .60604 L
.4428 .6053 L
.44551 .60443 L
.44842 .60331 L
.46053 .5972 L
.47305 .59011 L
.47952 .58691 L
.4826 .58563 L
.48538 .58464 L
.48773 .58395 L
.49027 .58336 L
.49294 .58292 L
.49546 .5827 L
.49822 .58267 L
.49961 .58274 L
.50116 .58288 L
.50389 .5833 L
.50647 .58389 L
.50899 .58463 L
.5117 .5856 L
.51669 .58778 L
.52856 .59441 L
.54187 .6023 L
.5488 .60575 L
.5519 .60703 L
.55537 .6082 L
.55859 .60901 L
.56162 .60948 L
.56484 .60963 L
.56829 .60934 L
.57008 .60898 L
.57203 .60841 L
.57555 .60687 L
.57891 .6047 L
.58196 .60203 L
.58491 .59872 L
.58759 .59497 L
.59227 .5863 L
.59469 .58046 L
.59675 .57449 L
.60078 .55901 L
Mistroke
.60253 .54968 L
.6039 .54029 L
.60488 .53148 L
.60567 .52157 L
.60619 .51055 L
.60632 .50493 L
.60635 .49871 L
.60614 .48778 L
.60562 .47768 L
.60486 .46835 L
.60377 .4589 L
.60263 .45119 L
.60116 .44322 L
.59933 .4352 L
.59712 .42737 L
.59255 .41537 L
.58945 .40938 L
.58641 .40477 L
.58292 .40069 L
.58109 .39898 L
.57909 .39742 L
.57567 .39539 L
.57243 .39412 L
.57043 .39361 L
.56853 .39331 L
.56496 .39317 L
.56174 .39345 L
.55834 .39413 L
.55515 .39506 L
.55229 .3961 L
.53913 .40263 L
.52741 .40921 L
.52134 .41224 L
.51585 .41447 L
.51348 .41523 L
.51126 .41583 L
.50871 .41635 L
.5064 .41667 L
.50385 .41685 L
.5015 .41685 L
.49891 .41666 L
.49616 .41626 L
.49341 .41565 L
.49087 .41491 L
.48505 .41265 L
.47405 .40686 L
.461 .39913 L
.4534 .39512 L
.44957 .39342 L
.44599 .39212 L
Mistroke
.44266 .39118 L
.43913 .39054 L
.43556 .39032 L
.43354 .3904 L
.43165 .39064 L
.42837 .39143 L
.42541 .39263 L
.42204 .39461 L
.41892 .39714 L
.41607 .40011 L
.41315 .40395 L
.40823 .41267 L
.40572 .41852 L
.40353 .42468 L
.39925 .44098 L
.39757 .44988 L
.39605 .46025 L
.39542 .4657 L
.39485 .47166 L
.3941 .48266 L
.39372 .49387 L
.39369 .50451 L
.39395 .51401 L
.39452 .52414 L
.3955 .53487 L
.3962 .54075 L
.39697 .5461 L
.39877 .55631 L
.4011 .56634 L
.40359 .57468 L
.4062 .58168 L
.41167 .59233 L
.41468 .5965 L
.41805 .60012 L
.42134 .60274 L
.42443 .60451 L
.42726 .60562 L
.4304 .60636 L
.43369 .60665 L
.43676 .60652 L
.43848 .6063 L
.44035 .60595 L
.44373 .60506 L
.44698 .60392 L
.44996 .60268 L
.46332 .59563 L
.47417 .58954 L
.47923 .58705 L
.48376 .58521 L
.48842 .58377 L
Mistroke
.49084 .58325 L
.49337 .58287 L
.49596 .58267 L
.49837 .58267 L
.50101 .58285 L
.50249 .58305 L
.50384 .58328 L
.50639 .58385 L
.50878 .58454 L
.51432 .58666 L
.52605 .59287 L
.53764 .59985 L
.54366 .60322 L
.5494 .60598 L
.55264 .60727 L
.55626 .60842 L
.55815 .60888 L
.55993 .60922 L
.56182 .60946 L
.56386 .60959 L
.56725 .60944 L
.57081 .60875 L
.57382 .60768 L
.57708 .60593 L
.57903 .60457 L
.58084 .60306 L
.58415 .5996 L
.58758 .59494 L
.59109 .58874 L
.59394 .58233 L
.59672 .57454 L
.60095 .55813 L
.6026 .5492 L
.60407 .53883 L
.60514 .52856 L
.60583 .51871 L
.60623 .50876 L
.60634 .49968 L
.60617 .48922 L
.60573 .4795 L
.60492 .46913 L
.60372 .45862 L
.60243 .4501 L
.60074 .44132 L
.59863 .43262 L
.59606 .42424 L
.5934 .41732 L
.59074 .41175 L
.58816 .40735 L
.58518 .40324 L
Mistroke
.58207 .3999 L
.57866 .39716 L
.57561 .3954 L
.57227 .39411 L
.56908 .39342 L
.56615 .3932 L
.56329 .39331 L
.56064 .39368 L
.55774 .39433 L
.55467 .39527 L
.54849 .39779 L
.54302 .40054 L
.53123 .40715 L
.5209 .41248 L
.51592 .41448 L
.51339 .41529 L
.51067 .416 L
.50913 .41631 L
.50772 .41654 L
.50493 .41683 L
.5024 .41689 L
.49971 .41676 L
.49815 .4166 L
.49672 .41638 L
.49514 .41607 L
.49347 .41568 L
.4875 .4137 L
.48203 .41123 L
.47585 .4079 L
.46422 .40099 L
.45775 .39732 L
.45064 .39385 L
.4471 .39247 L
.44521 .39185 L
.44316 .39128 L
.43954 .39057 L
.43613 .3903 L
.4326 .39048 L
.43082 .39076 L
.4289 .39124 L
.4255 .39255 L
.42239 .39434 L
.41916 .39689 L
.41619 .39994 L
.41092 .40747 L
.40817 .41276 L
.40579 .41831 L
.40105 .43322 L
.39912 .44153 L
.39734 .45114 L
Mistroke
.39597 .4608 L
.39499 .47001 L
.39417 .48117 L
.39388 .4876 L
.39371 .49359 L
.39369 .50462 L
.3938 .51017 L
.39404 .51625 L
.39437 .52206 L
.39483 .52808 L
.39591 .53852 L
.39744 .54916 L
.39954 .55995 L
.40167 .56847 L
.40425 .57664 L
.40955 .58877 L
.41241 .59348 L
.41571 .59776 L
.41929 .60124 L
.42105 .60258 L
.42274 .60366 L
.42603 .60523 L
.42907 .60615 L
.43237 .60663 L
.43423 .60669 L
.43597 .60663 L
.43786 .60643 L
.4399 .60609 L
.44182 .60565 L
.44358 .60515 L
.45033 .60256 L
.46473 .59487 L
.47654 .58838 L
.48203 .58592 L
.48691 .58423 L
.48952 .58357 L
.49198 .58311 L
.49456 .58281 L
.49601 .58272 L
.49736 .5827 L
.49999 .5828 L
.50148 .58295 L
.50289 .58315 L
.50574 .58373 L
.50884 .5846 L
.51407 .58659 L
.51981 .58937 L
.53067 .59567 L
.54339 .60308 L
.54704 .60491 L
Mistroke
.55097 .60663 L
.55441 .60787 L
.55632 .60843 L
.55814 .60887 L
.56017 .60925 L
.56203 .60947 L
.56569 .60955 L
.56775 .60937 L
.56966 .60903 L
.57174 .60845 L
.57395 .60761 L
.57585 .60665 L
.57789 .60538 L
.5815 .60242 L
.58491 .59865 L
.58791 .5944 L
.59322 .58405 L
.59594 .57689 L
.59823 .5694 L
.60036 .56084 L
.6021 .55206 L
.60376 .54124 L
.60492 .53084 L
.60568 .52111 L
.60618 .5104 L
.60634 .50019 L
.60621 .49085 L
.60575 .48008 L
.60534 .4741 L
.60486 .46864 L
.60376 .45897 L
.60226 .4492 L
.60038 .43971 L
.59799 .43037 L
.59562 .423 L
.59286 .41613 L
.59019 .41076 L
.58707 .40577 L
.58411 .40203 L
.58125 .39919 L
.57828 .39694 L
.57498 .39514 L
.57182 .39402 L
.56888 .39343 L
.56622 .39324 L
.56329 .39335 L
.56023 .39379 L
.55738 .39447 L
.55426 .39545 L
.55101 .39672 L
Mistroke
.54531 .39939 L
.53306 .40618 L
.52753 .40925 L
.52173 .41217 L
.51676 .41424 L
.51409 .41515 L
.51161 .41584 L
.50878 .41643 L
.50729 .41666 L
.5057 .41683 L
.50424 .41693 L
.50286 .41696 L
.50028 .41687 L
.49772 .4166 L
.49535 .41618 L
.49272 .41553 L
.4899 .41465 L
.48465 .41253 L
.47882 .4096 L
.46769 .40309 L
.45696 .39691 L
.45078 .39393 L
.44769 .39269 L
.44479 .39173 L
.44137 .39089 L
.43956 .39058 L
.43763 .39037 L
.43451 .39032 L
.43107 .39071 L
.42791 .39156 L
.42453 .39304 L
.4214 .39503 L
.41859 .39741 L
.41535 .40094 L
.41245 .40495 L
.40918 .41067 L
.4064 .41677 L
.40139 .43188 L
.3991 .44159 L
.39727 .45156 L
.39592 .4612 L
.39478 .47231 L
.39435 .47806 L
.39401 .48432 L
.39368 .49576 L
.39372 .50718 L
.39412 .5179 L
.39476 .52732 L
.39575 .53723 L
.39716 .54748 L
Mistroke
.39911 .55802 L
.40154 .56802 L
.40415 .5764 L
.40949 .58869 L
.41281 .5941 L
.41602 .59813 L
.41925 .60124 L
.42239 .60348 L
.42525 .60495 L
.4284 .60602 L
.43186 .60662 L
.4336 .60672 L
.43553 .60669 L
.43893 .60631 L
.44209 .60561 L
.44524 .60465 L
.4482 .60353 L
.45366 .60102 L
.46542 .59453 L
.47656 .58844 L
.48239 .58585 L
.48519 .58484 L
.48774 .58408 L
.49074 .58339 L
.49232 .58313 L
.49397 .58293 L
.49665 .58278 L
.49817 .58278 L
.49959 .58285 L
.50236 .58314 L
.5049 .5836 L
.50785 .58436 L
.51067 .58529 L
.52089 .59001 L
.53295 .59709 L
.54561 .60424 L
.54923 .60593 L
.5531 .60744 L
.55644 .60847 L
.55834 .60892 L
.56012 .60925 L
.56357 .60958 L
.56683 .60948 L
.56975 .60901 L
.5729 .60804 L
.57629 .6064 L
.5798 .60393 L
.58273 .60117 L
.58585 .59741 L
.59113 .58863 L
Mistroke
.59384 .58254 L
.59615 .57625 L
.59812 .56981 L
.60006 .56216 L
.60158 .55488 L
.60297 .54674 L
.60438 .53606 L
.60535 .52581 L
.60603 .51443 L
.60624 .50789 L
.60633 .50176 L
.60621 .49065 L
.60578 .48065 L
.60542 .47522 L
.60493 .46942 L
.60379 .45922 L
.6025 .45057 L
.60079 .44163 L
.59887 .43358 L
.59655 .42572 L
.59415 .41917 L
.59179 .41386 L
.58677 .40536 L
.5836 .40149 L
.58009 .39826 L
.57668 .39601 L
.57354 .39459 L
.5716 .39399 L
.5698 .3936 L
.56782 .39335 L
.56572 .39327 L
.5622 .39351 L
.5602 .39383 L
.55834 .39425 L
.55479 .39531 L
.55146 .39657 L
.54534 .39942 L
.53228 .40668 L
.52669 .40976 L
.52086 .41263 L
.51551 .41476 L
.51301 .41554 L
.5107 .41613 L
.50829 .41659 L
.50566 .41691 L
.50311 .41703 L
.50039 .41695 L
.49891 .41682 L
.49732 .41661 L
.4958 .41634 L
Mistroke
.4944 .41603 L
.48888 .41435 L
.48403 .4123 L
.47937 .40995 L
.46826 .40347 L
.4623 .39992 L
.45573 .3963 L
.44944 .39339 L
.4463 .39223 L
.44338 .39136 L
.4399 .39065 L
.43806 .39042 L
.43612 .39031 L
.43297 .39044 L
.42953 .39107 L
.42757 .39168 L
.4258 .39242 L
.4239 .3934 L
.42186 .3947 L
.41831 .39768 L
.41505 .40132 L
.41213 .40545 L
.40908 .41087 L
.40629 .41703 L
.40353 .42464 L
.4012 .43259 L
.39931 .44057 L
.39775 .4487 L
.39634 .45791 L
.39522 .46747 L
.39446 .47645 L
.39395 .48569 L
.39369 .49452 L
.39368 .50486 L
.39395 .51433 L
.39454 .52454 L
.39549 .535 L
.39663 .54397 L
.39813 .55308 L
.4015 .56792 L
.40395 .57583 L
.4065 .58247 L
.40898 .58772 L
.41181 .59261 L
.41477 .5967 L
.41759 .59977 L
.42037 .60213 L
.42335 .60405 L
.42669 .60552 L
.42982 .60636 L
Mistroke
.43329 .60674 L
.43523 .60673 L
.437 .6066 L
.44055 .60602 L
.44381 .60515 L
.44735 .6039 L
.45105 .60232 L
.4636 .59563 L
.47357 .59003 L
.47882 .58743 L
.48368 .58542 L
.48637 .58453 L
.48928 .58376 L
.4919 .58326 L
.49433 .58297 L
.49683 .58284 L
.49909 .58289 L
.50171 .58312 L
.50419 .58352 L
.50667 .5841 L
.50935 .58489 L
.51425 .58678 L
.52591 .59291 L
.53896 .60069 L
.54577 .60435 L
.54883 .60578 L
.55226 .60717 L
.55522 .60816 L
.55844 .60897 L
.56186 .60948 L
.56508 .6096 L
.56864 .60925 L
.57043 .60886 L
.57237 .60825 L
.57579 .6067 L
.57891 .60465 L
.58193 .602 L
.58471 .59891 L
.58963 .59149 L
.5922 .58637 L
.59444 .58104 L
.59891 .56688 L
.6009 .55828 L
.60254 .54949 L
.60377 .54113 L
.60485 .53162 L
.60569 .52092 L
.60601 .51482 L
.60621 .50925 L
.60633 .49834 L
Mistroke
.60613 .4881 L
.60566 .47858 L
.60487 .46878 L
.60398 .46071 L
.60277 .45224 L
.60121 .44362 L
.59926 .43507 L
.5951 .42162 L
.59222 .41476 L
.58936 .40933 L
.58603 .40437 L
.58232 .40021 L
.579 .39746 L
.57582 .39557 L
.57397 .39476 L
.57226 .39418 L
.57039 .39372 L
.5684 .39342 L
.5652 .39329 L
.56179 .39358 L
.55858 .39421 L
.55569 .39503 L
.54872 .3978 L
.54233 .40104 L
.53009 .40796 L
.5194 .41332 L
.51423 .41524 L
.51138 .41603 L
.50879 .41657 L
.50733 .41679 L
.50598 .41694 L
.5045 .41705 L
.50293 .4171 L
.5003 .41701 L
.4988 .41687 L
.49738 .41668 L
.4951 .41625 L
.49257 .41562 L
.48742 .41384 L
.47786 .40917 L
.46686 .40267 L
.45404 .39548 L
.45047 .39384 L
.44663 .39236 L
.44331 .39137 L
.44141 .39093 L
.43963 .39063 L
.43613 .39033 L
.43293 .39046 L
.43117 .39072 L
Mistroke
.42925 .39116 L
.42578 .39244 L
.42244 .39432 L
.41948 .39661 L
.41615 .4 L
.41313 .40395 L
.40809 .41293 L
.40549 .41908 L
.40327 .42543 L
.40109 .43305 L
.39902 .44199 L
.39748 .45031 L
.39608 .45989 L
.39538 .46597 L
.39483 .47171 L
.39441 .4772 L
.39405 .48333 L
.3937 .4941 L
.39369 .50558 L
.39384 .51152 L
.39411 .5177 L
.39486 .52854 L
.39543 .53441 L
.39606 .53974 L
.3978 .55127 L
.39968 .56064 L
.40165 .56845 L
.40422 .5766 L
.40687 .58331 L
.41207 .59302 L
.41504 .59702 L
.41835 .60048 L
.42005 .60189 L
.42193 .60321 L
.42539 .60503 L
.42881 .60615 L
.43201 .60667 L
.43529 .60674 L
.43837 .60644 L
.44112 .6059 L
.44408 .60508 L
.45062 .60254 L
.45647 .59964 L
.46928 .59242 L
.4804 .58677 L
.48577 .58477 L
.48873 .58394 L
.4914 .58339 L
.49292 .58317 L
.49432 .58302 L
Mistroke
.49585 .58292 L
.49747 .58289 L
.50019 .58301 L
.50175 .58318 L
.5032 .5834 L
.50585 .58394 L
.5087 .58474 L
.51391 .58668 L
.52628 .59316 L
.5388 .60063 L
.54529 .60414 L
.54821 .60553 L
.55146 .60689 L
.55445 .60794 L
.55769 .60883 L
.56113 .60943 L
.56436 .60963 L
.56617 .60957 L
.56814 .60935 L
.5717 .6085 L
.57514 .60706 L
.57826 .60514 L
.58104 .60287 L
.58358 .60026 L
.58651 .59652 L
.58909 .59246 L
.59396 .58228 L
.59627 .57591 L
.59849 .56848 L
.60051 .56016 L
.60239 .55037 L
.60385 .5405 L
.60491 .53095 L
.60562 .52205 L
.60612 .51205 L
.60633 .50147 L
.60623 .49157 L
.60576 .48018 L
.60496 .46964 L
.60396 .46053 L
.60258 .45107 L
.60076 .44148 L
.59849 .43215 L
.59607 .4243 L
.59362 .41789 L
.58831 .40762 L
.58529 .40343 L
.58197 .39987 L
.579 .39746 L
.57617 .39575 L
Mistroke
.57301 .39442 L
.5696 .39359 L
.56655 .3933 L
.56323 .39342 L
.56011 .39388 L
.55723 .39458 L
.55467 .39538 L
.55186 .39644 L
.54628 .39899 L
.52354 .41146 L
.51843 .41376 L
.51312 .41561 L
.51156 .41602 L
.5101 .41636 L
.50739 .41682 L
.50485 .41707 L
.50211 .41713 L
.49934 .41697 L
.49776 .41678 L
.49628 .41654 L
.49329 .41586 L
.49004 .41486 L
.48404 .4124 L
.4784 .40951 L
.46685 .4027 L
.46015 .39875 L
.45362 .3953 L
.44752 .3927 L
.44403 .39158 L
.4408 .39084 L
.43744 .39041 L
.43375 .39041 L
.43189 .39062 L
.42991 .39101 L
.42636 .39219 L
.42314 .39388 L
.41971 .39642 L
.41656 .39954 L
.41375 .40307 L
.40874 .41158 L
.4064 .41678 L
.40401 .42322 L
.40145 .43169 L
.39931 .4406 L
.39766 .44925 L
.39616 .4593 L
.39492 .47077 L
.3944 .47738 L
.39405 .48348 L
.39382 .48924 L
Mistroke
.39368 .49551 L
.39372 .50688 L
.3941 .51741 L
.39445 .52329 L
.39488 .52869 L
.396 .53926 L
.39758 .54998 L
.39938 .55925 L
.40135 .56733 L
.40568 .58046 L
.40809 .58595 L
.41086 .59109 L
.41338 .59489 L
.41623 .59838 L
.41951 .60147 L
.42122 .60274 L
.42306 .60389 L
.4264 .60543 L
.42955 .60631 L
.43142 .60661 L
.43315 .60674 L
.43505 .60675 L
.43706 .60661 L
.44042 .60606 L
.44233 .6056 L
.4441 .60508 L
.45033 .60268 L
.45684 .59945 L
.46818 .59305 L
.47409 .58982 L
.47947 .5872 L
.48438 .58525 L
.48691 .58445 L
.48957 .58378 L
.4918 .58336 L
.49423 .58306 L
.49643 .58293 L
.49848 .58294 L
.50127 .58315 L
.50391 .58355 L
.50629 .58408 L
.5089 .58483 L
.51486 .58713 L
.52053 .58994 L
.53303 .59724 L
.54008 .60139 L
.54799 .60545 L
.55163 .60698 L
.55514 .60817 L
.55832 .60898 L
Mistroke
.56182 .60952 L
.56512 .60963 L
.56864 .60928 L
.57195 .60843 L
.57491 .60719 L
.57667 .60621 L
.57851 .60497 L
.58175 .60221 L
.58512 .59841 L
.58866 .5932 L
.59155 .5878 L
.59444 .58106 L
.59901 .56652 L
.60094 .55815 L
.60276 .54817 L
.60428 .53704 L
.60534 .52607 L
.60599 .51553 L
.60629 .5057 L
.6063 .49487 L
.60594 .48356 L
.6052 .47232 L
.60462 .4662 L
.60399 .46077 L
.60252 .45066 L
.60082 .44173 L
.5985 .43219 L
.59607 .4243 L
.59311 .4167 L
.58969 .4099 L
.58676 .40535 L
.58397 .40189 L
.58063 .3987 L
.57738 .39641 L
.57432 .3949 L
.57146 .39396 L
.56829 .39341 L
.56491 .3933 L
.56297 .39344 L
.5612 .39368 L
.55925 .39406 L
.55721 .39458 L
.55379 .3957 L
.5501 .3972 L
.5374 .40383 L
.52502 .41072 L
.51924 .41344 L
.51676 .41443 L
.51404 .41535 L
.51181 .41598 L
Mistroke
.50941 .41651 L
.5069 .4169 L
.50455 .41711 L
.50195 .41715 L
.49921 .41698 L
.49687 .41666 L
.49429 .41613 L
.49126 .41529 L
.48836 .41427 L
.48285 .41185 L
.46978 .40449 L
.45767 .3974 L
.45092 .39407 L
.44711 .39257 L
.44521 .39194 L
.44345 .39144 L
.43996 .39071 L
.43811 .39048 L
.43613 .39036 L
.43262 .39053 L
.42945 .39114 L
.42623 .39226 L
.42281 .3941 L
.41964 .39649 L
.4168 .39928 L
.41368 .40318 L
.4109 .40753 L
.40778 .41363 L
.40513 .42006 L
.40043 .43572 L
.3983 .44567 L
.39664 .45581 L
.39556 .46437 L
.39464 .47416 L
.394 .48468 L
.3937 .49469 L
.39368 .50408 L
.39389 .51262 L
.39439 .52233 L
.39512 .53133 L
.39618 .54065 L
.3976 .55009 L
.40087 .56549 L
.40327 .57377 L
.40578 .5807 L
.41102 .59134 L
.41378 .59542 L
.41686 .59903 L
.41987 .60174 L
.42267 .60366 L
Mistroke
.42601 .60527 L
.42792 .60591 L
.42969 .60633 L
.43296 .60673 L
.43644 .60666 L
.43974 .6062 L
.44327 .60533 L
.44657 .60422 L
.44957 .60301 L
.46328 .59586 L
.47428 .58972 L
.4794 .58724 L
.48393 .58542 L
.4862 .58467 L
.48864 .584 L
.49121 .58347 L
.49361 .58313 L
.49626 .58295 L
.49759 .58293 L
.49905 .58298 L
.50165 .58321 L
.50408 .5836 L
.50675 .58421 L
.50962 .58508 L
.51487 .58715 L
.52734 .59384 L
.53999 .60134 L
.54654 .60478 L
.54947 .60612 L
.55273 .60739 L
.55597 .60842 L
.55901 .60913 L
.56223 .60956 L
.5657 .60962 L
.56751 .60946 L
.56948 .60912 L
.57304 .60804 L
.57645 .60635 L
.57955 .60418 L
.5823 .60167 L
.58481 .59881 L
.5877 .59477 L
.59022 .59043 L
.59496 .57968 L
.59719 .57302 L
.59932 .56531 L
.60124 .55667 L
.60301 .54658 L
.60435 .53646 L
.60529 .52673 L
Mistroke
.60588 .51769 L
.60626 .50759 L
.60633 .49697 L
.6061 .4871 L
.60547 .47576 L
.60453 .46536 L
.60341 .4564 L
.60191 .44717 L
.59996 .43787 L
.59756 .42889 L
.59503 .4214 L
.5925 .41534 L
.58758 .4065 L
.58482 .40285 L
.5818 .3997 L
.5791 .39752 L
.57654 .39593 L
.5737 .39465 L
.57062 .39376 L
.56724 .39332 L
.56533 .39328 L
.56357 .39338 L
.56034 .39383 L
.55694 .39465 L
.55393 .39564 L
.55113 .39674 L
.54489 .3997 L
.53264 .40655 L
.52651 .40994 L
.52021 .41302 L
.51717 .41427 L
.51435 .41525 L
.51163 .41603 L
.50914 .41657 L
.50679 .41692 L
.50431 .41712 L
.50183 .41715 L
.49911 .41697 L
.49647 .41659 L
.49397 .41606 L
.4917 .41543 L
.48921 .4146 L
.47813 .40939 L
.46788 .40334 L
.45606 .39655 L
.44929 .3934 L
.44626 .39228 L
.44292 .39131 L
.43973 .39068 L
.43675 .39039 L
Mistroke
.4336 .39044 L
.43024 .39095 L
.42831 .39148 L
.42653 .39214 L
.4246 .39306 L
.42258 .39426 L
.41923 .39686 L
.41566 .40061 L
.41261 .40476 L
.40949 .41011 L
.40438 .42215 L
.40176 .4306 L
.39961 .43928 L
.39759 .44968 L
.39671 .45531 L
.39588 .46159 L
.3952 .46779 L
.39468 .47361 L
.39429 .47927 L
.39397 .48531 L
.39368 .49592 L
.39366 .50195 L
.39374 .50757 L
.39418 .51887 L
.39494 .5293 L
.39589 .53833 L
.39721 .54769 L
.39896 .55724 L
.40114 .56654 L
.40583 .58082 L
.4084 .58655 L
.41138 .59192 L
.41415 .5959 L
.41722 .59939 L
.42036 .60211 L
.42327 .60399 L
.42624 .60535 L
.42906 .60619 L
.4324 .60669 L
.43593 .60669 L
.43894 .60634 L
.44223 .60561 L
.44574 .60452 L
.44946 .60305 L
.45602 .59988 L
.46736 .59352 L
.47326 .59025 L
.47863 .58758 L
.48343 .58559 L
.48775 .58422 L
Mistroke
.49006 .58368 L
.49248 .58326 L
.4949 .58301 L
.49754 .58293 L
.49899 .58297 L
.50036 .58307 L
.50292 .58339 L
.5057 .58395 L
.50874 .58479 L
.51431 .5869 L
.51958 .58945 L
.53204 .59666 L
.53906 .60082 L
.54693 .60497 L
.55057 .60657 L
.55407 .60786 L
.55725 .60876 L
.56074 .60941 L
.56405 .60965 L
.56758 .60946 L
.57089 .60878 L
.57387 .6077 L
.57564 .60682 L
.5775 .6057 L
.58076 .60315 L
.58417 .5996 L
.58776 .59468 L
.5907 .58953 L
.59365 .58307 L
.59835 .56902 L
.60037 .56082 L
.60229 .55101 L
.60392 .54001 L
.60509 .52914 L
.60584 .51864 L
.60623 .50882 L
.60634 .49797 L
.60608 .4866 L
.60579 .4806 L
.60544 .47523 L
.60492 .46914 L
.60433 .46352 L
.60304 .4539 L
.60132 .44411 L
.59905 .4342 L
.59627 .42486 L
.59362 .41786 L
.59046 .41125 L
.58733 .40613 L
.58421 .40214 L
Mistroke
.58131 .39926 L
.57807 .39682 L
.57637 .39583 L
.57448 .39494 L
.57248 .39423 L
.5706 .39375 L
.56722 .39331 L
.56532 .39328 L
.56357 .39337 L
.5604 .39381 L
.55746 .3945 L
.55427 .39551 L
.55089 .39684 L
.53818 .40337 L
.52641 .40999 L
.52029 .41297 L
.51473 .41512 L
.51189 .41595 L
.51044 .41629 L
.50886 .41661 L
.50715 .41687 L
.50552 .41704 L
.50394 .41713 L
.50247 .41715 L
.50101 .41711 L
.49962 .41701 L
.49703 .41668 L
.49422 .41611 L
.49116 .41525 L
.48585 .41324 L
.47986 .41032 L
.46707 .40285 L
.45523 .39613 L
.45186 .3945 L
.44822 .39298 L
.44504 .3919 L
.44157 .39101 L
.438 .39048 L
.43463 .39038 L
.43268 .39053 L
.43063 .39087 L
.427 .39196 L
.42364 .3936 L
.42058 .39573 L
.41729 .39876 L
.41391 .40288 L
.411 .40737 L
.40802 .41312 L
.40556 .41894 L
.40315 .42587 L
Mistroke
.40117 .43277 L
.39923 .44102 L
.3978 .44846 L
.39647 .45704 L
.39573 .46287 L
.39514 .46842 L
.39463 .47428 L
.39426 .47967 L
.3938 .49013 L
.39366 .50139 L
.39375 .50772 L
.39392 .5135 L
.39423 .51978 L
.39468 .5263 L
.39573 .53696 L
.39726 .54804 L
.39905 .55767 L
.40094 .56575 L
.40324 .57367 L
.40602 .58129 L
.40882 .58739 L
.41158 .59222 L
.41429 .59607 L
.41738 .59953 L
.42042 .60214 L
.42368 .6042 L
.42676 .60553 L
.42965 .60631 L
.43309 .60672 L
.43622 .60666 L
.43795 .60648 L
.43982 .60617 L
.4432 .60533 L
.44611 .60438 L
.44928 .60312 L
.45555 .60011 L
.46627 .59412 L
.47816 .58778 L
.48144 .58635 L
.48451 .5852 L
.48726 .58434 L
.48876 .58395 L
.49016 .58364 L
.49266 .58323 L
.4954 .58297 L
.49773 .58292 L
.50024 .58304 L
.50303 .5834 L
.50444 .58366 L
.50599 .58401 L
Mistroke
.51135 .58569 L
.51695 .58811 L
.52322 .59143 L
.53526 .59859 L
.54677 .6049 L
.55004 .60636 L
.55361 .6077 L
.55701 .6087 L
.56014 .60932 L
.56376 .60965 L
.56581 .60962 L
.56771 .60944 L
.57117 .6087 L
.5731 .60803 L
.57483 .60725 L
.57857 .60495 L
.58065 .60326 L
.58252 .60145 L
.58607 .59716 L
.58924 .59223 L
.5944 .58119 L
.59684 .57417 L
.5992 .56579 L
.60135 .55612 L
.60307 .54621 L
.60431 .53679 L
.60534 .5261 L
.60599 .51561 L
.60629 .50584 L
.60631 .49507 L
.60596 .48383 L
.60536 .47421 L
.60455 .46552 L
.60341 .45636 L
.6019 .44711 L
.59993 .43772 L
.59744 .4285 L
.59499 .42127 L
.59215 .41457 L
.5894 .40937 L
.58621 .40458 L
.58318 .40102 L
.58025 .39837 L
.57685 .39609 L
.57489 .39512 L
.57307 .39441 L
.5697 .39358 L
.5678 .39334 L
.56609 .39327 L
.56283 .39343 L
Mistroke
.55933 .39402 L
.55605 .39491 L
.55306 .39595 L
.53946 .40263 L
.52616 .4101 L
.5204 .41291 L
.5151 .41499 L
.51283 .41568 L
.51043 .41628 L
.50783 .41676 L
.50543 .41703 L
.50289 .41714 L
.50016 .41704 L
.49757 .41675 L
.49519 .41632 L
.49239 .41562 L
.48931 .41461 L
.48358 .41219 L
.47312 .40649 L
.46098 .39924 L
.45511 .39606 L
.44871 .39317 L
.44603 .39221 L
.44313 .39137 L
.43993 .39071 L
.43693 .3904 L
.435 .39037 L
.43322 .39047 L
.43128 .39074 L
.42921 .39121 L
.42578 .39248 L
.42384 .39348 L
.42204 .39463 L
.41877 .39729 L
.41585 .40038 L
.41276 .40453 L
.40967 .40978 L
.40717 .415 L
.40468 .42131 L
.40072 .43455 L
.39868 .44374 L
.39704 .45309 L
.39584 .46196 L
.39482 .472 L
.39407 .48316 L
.39372 .49381 L
.39366 .49994 L
.3937 .50555 L
.39387 .51198 L
.39414 .51804 L
Mistroke
.3945 .5238 L
.39499 .52982 L
.39614 .5403 L
.39795 .55202 L
.39997 .5618 L
.40438 .57701 L
.40726 .58416 L
.41012 .58979 L
.413 .59434 L
.4158 .59787 L
.41883 .60087 L
.42223 .60337 L
.42559 .60509 L
.42731 .60571 L
.42921 .60621 L
.43258 .60669 L
.43575 .60669 L
.43756 .60652 L
.43947 .60623 L
.44285 .60543 L
.44646 .60424 L
.45034 .60264 L
.46249 .59628 L
.47458 .58953 L
.4804 .58677 L
.4832 .58565 L
.48575 .58477 L
.488 .58413 L
.49045 .58357 L
.49291 .58318 L
.4955 .58295 L
.49796 .58291 L
.5002 .58303 L
.5028 .58334 L
.50528 .58382 L
.50758 .58442 L
.50973 .58509 L
.51466 .58703 L
.53578 .59889 L
.54804 .60548 L
.55113 .60679 L
.55448 .60798 L
.55642 .60854 L
.55819 .60896 L
.56167 .60951 L
.56365 .60964 L
.56547 .60963 L
.56748 .60947 L
.5696 .6091 L
.57314 .60801 L
Mistroke
.57513 .6071 L
.57698 .60604 L
.58039 .60348 L
.58343 .60047 L
.58681 .59612 L
.58987 .5911 L
.59256 .58562 L
.59524 .57894 L
.59945 .56478 L
.60159 .55488 L
.60328 .5448 L
.60449 .53523 L
.60547 .52444 L
.60607 .51372 L
.60632 .50381 L
.60626 .49234 L
.60585 .48161 L
.60517 .47192 L
.6043 .46324 L
.60308 .45412 L
.60149 .44498 L
.59963 .4365 L
.59734 .42817 L
.59255 .41542 L
.58944 .40944 L
.58596 .40425 L
.58286 .4007 L
.57935 .39768 L
.57756 .39649 L
.5756 .39543 L
.57373 .39464 L
.572 .39408 L
.56869 .39343 L
.56519 .39327 L
.56337 .39337 L
.56142 .39362 L
.55792 .39436 L
.5558 .39498 L
.5538 .39567 L
.55008 .39717 L
.5366 .40425 L
.52524 .41057 L
.5199 .41312 L
.51714 .41424 L
.51428 .41524 L
.51179 .41595 L
.50908 .41654 L
.50663 .4169 L
.50436 .41708 L
.50301 .41712 L
Mistroke
.50155 .4171 L
.49889 .41691 L
.4963 .41653 L
.49389 .41601 L
.49126 .41526 L
.48834 .41424 L
.48231 .41156 L
.47184 .40571 L
.45956 .39843 L
.45366 .39533 L
.45034 .39383 L
.44717 .39259 L
.44419 .39164 L
.44093 .39088 L
.43795 .39047 L
.4352 .39036 L
.43182 .39065 L
.42867 .39137 L
.42526 .39272 L
.42336 .39377 L
.42165 .39491 L
.41827 .39776 L
.41472 .40179 L
.41151 .40651 L
.40869 .41171 L
.40418 .42273 L
.4019 .43008 L
.39998 .43764 L
.39831 .44563 L
.39682 .4546 L
.39549 .46499 L
.39458 .47493 L
.39394 .48619 L
.39368 .49659 L
.39367 .50237 L
.39377 .50861 L
.39424 .51982 L
.39501 .53006 L
.39616 .54048 L
.39741 .54894 L
.39906 .5577 L
.40131 .56715 L
.40366 .57493 L
.40667 .58281 L
.40978 .58919 L
.41263 .59381 L
.41581 .59788 L
.41943 .60137 L
.42121 .6027 L
.42289 .60376 L
Mistroke
.4262 .60532 L
.42798 .6059 L
.42988 .60635 L
.43189 .60663 L
.4338 .60673 L
.43737 .60654 L
.44069 .60597 L
.44374 .60516 L
.44706 .60401 L
.45054 .60255 L
.46499 .59484 L
.47751 .58807 L
.4825 .5859 L
.48762 .58422 L
.49027 .5836 L
.49176 .58333 L
.49315 .58314 L
.49558 .58293 L
.49817 .5829 L
.49968 .58297 L
.50106 .5831 L
.50259 .5833 L
.50421 .58358 L
.50695 .58423 L
.50999 .58517 L
.51571 .5875 L
.52121 .59029 L
.53311 .59728 L
.53976 .6012 L
.54712 .60505 L
.55086 .60668 L
.55443 .60796 L
.55766 .60884 L
.56118 .60946 L
.56455 .60965 L
.56809 .60938 L
.57111 .60871 L
.57439 .60746 L
.57777 .60551 L
.58091 .60302 L
.58365 .60021 L
.58653 .59652 L
.58953 .59171 L
.59253 .58569 L
.59495 .57973 L
.59734 .57254 L
.59936 .56516 L
.601 .55788 L
.60247 .54998 L
.60363 .54226 L
Mistroke
.60473 .5329 L
.60561 .52231 L
.60611 .51274 L
.60634 .50241 L
.60624 .49152 L
.60603 .48539 L
.60574 .47973 L
.60533 .47383 L
.60486 .46856 L
.60352 .45712 L
.60205 .44794 L
.60014 .43865 L
.59593 .42387 L
.59323 .41695 L
.59 .41041 L
.58638 .4048 L
.58281 .40065 L
.57936 .39769 L
.57613 .39569 L
.57441 .3949 L
.57251 .39423 L
.57052 .39372 L
.56866 .39342 L
.56524 .39326 L
.56331 .39338 L
.56153 .3936 L
.55827 .39427 L
.55486 .39529 L
.54903 .39764 L
.54279 .40078 L
.52979 .40812 L
.52374 .41132 L
.51831 .41378 L
.5132 .41556 L
.51038 .41627 L
.50785 .41673 L
.50508 .41703 L
.50352 .4171 L
.50208 .41711 L
.49944 .41696 L
.49665 .41658 L
.49429 .41609 L
.49175 .4154 L
.48711 .41374 L
.47613 .40823 L
.46243 .40007 L
.45526 .39612 L
.45202 .39456 L
.4484 .39304 L
.44535 .39198 L
Mistroke
.44203 .3911 L
.43851 .39052 L
.43519 .39036 L
.43152 .39069 L
.42967 .39108 L
.42767 .3917 L
.42415 .3933 L
.42094 .39543 L
.41758 .39846 L
.41414 .40255 L
.41133 .4068 L
.4084 .4123 L
.40547 .41918 L
.4026 .42765 L
.40022 .43659 L
.39831 .44563 L
.3967 .45538 L
.39599 .46065 L
.39532 .46663 L
.39444 .47697 L
.39386 .48826 L
.39366 .49858 L
.3938 .50971 L
.39425 .52007 L
.39494 .52936 L
.39588 .53819 L
.39713 .54722 L
.40004 .56214 L
.40219 .57028 L
.40446 .57722 L
.40921 .58814 L
.41188 .59268 L
.41483 .59674 L
.41748 .59962 L
.4204 .60213 L
.42361 .60416 L
.42666 .60549 L
.42853 .60605 L
.43033 .60642 L
.4337 .60673 L
.43666 .60662 L
.43986 .60615 L
.44286 .60542 L
.4456 .60455 L
.45601 .59985 L
.46654 .59395 L
.47739 .58812 L
.48173 .5862 L
.48408 .58531 L
.48628 .58459 L
Mistroke
.48832 .58403 L
.49051 .58354 L
.4925 .58321 L
.49434 .58301 L
.49641 .58289 L
.49836 .5829 L
.5005 .58303 L
.50281 .58333 L
.50512 .58377 L
.50756 .58439 L
.51197 .58589 L
Mfstroke
0 g
gsave
.72727 .58182 -73.7813 -11.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 14.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 1.000 0.000 setrgbcolor
(0.2) show
84.563 14.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 .4 r
.5673 .45377 m
.56587 .45051 L
.56449 .4481 L
.56282 .44599 L
.5612 .44464 L
.55966 .44392 L
.55824 .44369 L
.55667 .4439 L
.55502 .44462 L
.5534 .44583 L
.5517 .44761 L
.55016 .44972 L
.5488 .45198 L
.54579 .45861 L
.54338 .46607 L
.54156 .47386 L
.54075 .47841 L
.54015 .48262 L
.53971 .48659 L
.53936 .4909 L
.53915 .49495 L
.53906 .49865 L
.53909 .50289 L
.53923 .50677 L
.53952 .51089 L
.53973 .51312 L
.53997 .51511 L
.54053 .51895 L
.54129 .52285 L
.54213 .52622 L
.54301 .52904 L
.54391 .53142 L
.54493 .53359 L
.54613 .53555 L
.54728 .53694 L
.54839 .53786 L
.54944 .53837 L
.5506 .53852 L
.55184 .5382 L
.55254 .53779 L
.55317 .53726 L
.55386 .53652 L
.55457 .53554 L
.55571 .53345 L
.55687 .53051 L
.55781 .52734 L
.55869 .52337 L
.55939 .51913 L
.5599 .51485 L
.56014 .51213 L
Mistroke
.56032 .50956 L
.56047 .50648 L
.56056 .50349 L
.56058 .49793 L
.56052 .4947 L
.5604 .49167 L
.56023 .4883 L
.56001 .48511 L
.55931 .47776 L
.55836 .47052 L
.55705 .46276 L
.55385 .44873 L
.5499 .43607 L
.54564 .42538 L
.54029 .41452 L
.52854 .39604 L
.51552 .37964 L
.49754 .35971 L
.47863 .3411 L
.46799 .33239 L
.46262 .32875 L
.45765 .32597 L
.4523 .32373 L
.44653 .32238 L
.4435 .32219 L
.44022 .32244 L
.4343 .32429 L
.42849 .32821 L
.42525 .33148 L
.42229 .33527 L
.41656 .34525 L
.41352 .35229 L
.41088 .35963 L
.40654 .37494 L
.40243 .39474 L
.39925 .41619 L
.39697 .43805 L
.39545 .46045 L
.39459 .485 L
.39448 .50627 L
.395 .52938 L
.39632 .55353 L
.39739 .56648 L
.39856 .5778 L
.40134 .59832 L
.40452 .61565 L
.40795 .62985 L
.41197 .6427 L
.41568 .65186 L
.42001 .66006 L
Mistroke
.42488 .6668 L
.43031 .67186 L
.43555 .67478 L
.4404 .67609 L
.44609 .67622 L
.44926 .67574 L
.45213 .67501 L
.45768 .67291 L
.46283 .6703 L
.48562 .65413 L
.52122 .62583 L
.53659 .61277 L
.54929 .59811 L
.55495 .58896 L
.56035 .57748 L
.56308 .57013 L
.5654 .56263 L
.56724 .55555 L
.56901 .54735 L
.57022 .54059 L
.5713 .53312 L
.57221 .5251 L
.57283 .51752 L
.57321 .51041 L
.57341 .50303 L
.57341 .49687 L
.57323 .49034 L
.5728 .48294 L
.57221 .47663 L
.57181 .47333 L
.57131 .46992 L
.57026 .46422 L
.56912 .45948 L
.56777 .45513 L
.56651 .45198 L
.56505 .44912 L
.56332 .44668 L
.56167 .4451 L
.55981 .44411 L
.55876 .44388 L
.5578 .44387 L
.55606 .44429 L
.55508 .44478 L
.55419 .44537 L
.55259 .44682 L
.55095 .44881 L
.54809 .45359 L
.54571 .45912 L
.54348 .46609 L
.54157 .47429 L
Mistroke
.54074 .47908 L
.54012 .48359 L
.53962 .48858 L
.53943 .4911 L
.53928 .49387 L
.53915 .49846 L
.53915 .501 L
.53919 .50331 L
.53937 .50767 L
.53968 .51168 L
.54009 .51534 L
.54065 .51904 L
.54194 .52508 L
.54289 .52833 L
.54389 .53103 L
.54487 .53314 L
.54598 .53502 L
.54713 .53647 L
.54821 .53742 L
.54931 .538 L
.55037 .53818 L
.55161 .53794 L
.55273 .53726 L
.55394 .536 L
.55453 .53516 L
.55516 .53406 L
.55628 .53159 L
.55722 .52881 L
.55814 .52521 L
.55898 .52084 L
.55956 .51656 L
.55999 .51221 L
.5603 .50708 L
.5604 .50407 L
.56044 .50124 L
.5604 .49599 L
.56019 .49023 L
.55986 .48518 L
.55935 .47952 L
.55861 .47338 L
.5576 .46675 L
.55522 .45487 L
.5521 .44329 L
.5485 .43281 L
.54016 .41469 L
.52797 .39557 L
.51488 .37913 L
.49863 .36104 L
.47848 .3411 L
.46851 .33288 L
Mistroke
.46286 .329 L
.45748 .32598 L
.45282 .324 L
.44779 .32265 L
.44217 .32231 L
.43706 .32326 L
.43196 .32567 L
.42732 .32936 L
.42238 .33522 L
.41735 .34372 L
.41324 .35309 L
.40964 .36365 L
.40602 .37719 L
.40258 .394 L
.3995 .41431 L
.39729 .43457 L
.39551 .45963 L
.39462 .48431 L
.3945 .50755 L
.39499 .52879 L
.39619 .55144 L
.39816 .57409 L
.40085 .59509 L
.40443 .61514 L
.4084 .63142 L
.41244 .64392 L
.41759 .65571 L
.42066 .66106 L
.42359 .66521 L
.42914 .67094 L
.432 .67298 L
.4352 .67463 L
.43803 .67559 L
.44113 .67618 L
.44439 .67632 L
.44742 .67606 L
.45282 .6748 L
.45855 .67253 L
.46516 .66897 L
.47127 .66501 L
.4823 .65683 L
.51917 .62762 L
.53463 .61484 L
.54754 .60081 L
.55334 .59214 L
.55894 .58121 L
.56179 .57418 L
.56426 .56695 L
.56643 .55935 L
.56817 .55207 L
Mistroke
.57071 .53815 L
.57177 .53022 L
.57254 .52265 L
.57306 .5156 L
.57337 .50916 L
.57352 .50219 L
.57348 .49501 L
.57323 .48802 L
.57275 .48092 L
.57209 .47466 L
.57134 .46937 L
.57028 .46373 L
.56894 .45834 L
.56752 .45401 L
.56609 .45068 L
.56457 .44799 L
.56289 .44586 L
.56141 .4446 L
.55977 .44379 L
.55797 .44355 L
.55697 .4437 L
.55606 .44399 L
.55431 .44499 L
.55269 .44641 L
.55122 .44813 L
.54971 .45033 L
.54721 .45511 L
.54482 .46125 L
.54262 .46889 L
.54161 .47345 L
.54081 .47791 L
.5402 .48204 L
.53969 .48649 L
.53947 .48902 L
.53931 .49131 L
.5391 .49576 L
.53904 .49824 L
.53904 .50088 L
.53907 .50335 L
.53915 .50558 L
.53938 .50949 L
.5397 .51301 L
.54016 .51671 L
.54078 .52044 L
.54156 .52407 L
.54241 .52721 L
.54327 .52976 L
.54426 .53218 L
.54531 .53421 L
.54632 .53573 L
Mistroke
.54738 .53692 L
.54841 .53773 L
.54963 .53823 L
.55077 .53828 L
.55201 .53784 L
.5527 .53736 L
.55331 .53679 L
.55453 .53519 L
.55559 .53322 L
.55667 .53049 L
.55771 .52698 L
.5585 .52343 L
.55913 .51971 L
.55969 .51521 L
.55994 .51251 L
.56012 .50994 L
.56034 .50516 L
.56042 .4998 L
.56035 .49503 L
.56013 .48959 L
.55971 .48362 L
.55905 .47706 L
.55823 .47081 L
.55729 .46506 L
.55516 .45469 L
.55221 .44366 L
.54437 .42303 L
.53908 .41268 L
.5326 .40212 L
.51902 .38397 L
.4874 .34938 L
.47657 .33928 L
.46583 .33082 L
.46023 .32729 L
.45731 .32575 L
.4541 .32433 L
.45057 .32314 L
.4472 .32241 L
.44391 .32212 L
.44085 .32228 L
.43493 .32392 L
.42943 .32733 L
.4246 .33214 L
.41958 .33943 L
.41437 .35006 L
.40933 .36447 L
.40546 .37939 L
.40178 .3984 L
.39875 .42008 L
.39663 .44201 L
Mistroke
.39579 .45403 L
.3951 .46763 L
.39463 .4821 L
.39444 .49582 L
.39471 .52093 L
.39565 .54345 L
.39742 .56702 L
.40006 .58996 L
.40287 .60744 L
.40638 .62396 L
.41012 .63738 L
.41383 .6477 L
.4185 .6576 L
.42386 .66573 L
.42913 .67111 L
.43411 .67432 L
.4395 .67611 L
.44532 .67646 L
.4508 .67557 L
.45577 .67393 L
.46152 .67124 L
.46766 .66763 L
.47847 .66001 L
.51787 .62894 L
.53447 .61531 L
.54191 .60793 L
.54828 .60017 L
.55365 .59198 L
.55878 .58196 L
.56329 .57038 L
.56739 .55599 L
.56925 .54734 L
.57072 .53881 L
.57178 .53095 L
.57266 .5223 L
.57301 .5178 L
.5733 .51285 L
.5735 .50773 L
.5736 .50298 L
.57356 .4947 L
.57342 .49019 L
.57322 .48618 L
.57264 .47882 L
.5719 .47248 L
.57088 .46614 L
.56956 .46017 L
.56813 .45529 L
.56664 .45145 L
.5652 .44864 L
.56357 .44627 L
Mistroke
.56184 .44457 L
.56023 .44362 L
.55835 .44321 L
.55656 .44346 L
.55493 .44421 L
.55344 .44532 L
.55185 .44696 L
.55022 .44913 L
.54709 .45491 L
.54453 .46157 L
.54223 .46987 L
.54119 .47485 L
.5404 .47955 L
.53983 .48387 L
.53937 .48851 L
.53907 .49289 L
.53893 .49684 L
.53889 .49923 L
.5389 .50142 L
.53894 .50379 L
.53904 .50626 L
.5393 .51031 L
.53951 .51254 L
.53973 .51458 L
.54032 .51872 L
.54102 .52238 L
.54263 .52846 L
.54369 .53134 L
.54476 .53362 L
.54601 .53567 L
.54673 .5366 L
.54741 .53729 L
.54857 .53814 L
.54966 .53855 L
.55088 .53856 L
.55217 .53804 L
.55281 .53756 L
.55349 .53688 L
.5547 .53521 L
.55581 .53304 L
.55677 .53055 L
.55759 .52783 L
.55828 .52494 L
.55895 .52139 L
.55955 .51717 L
.56 .51259 L
.56033 .50739 L
.56047 .50268 L
.56047 .49728 L
.56039 .49411 L
Mistroke
.56025 .49061 L
.56006 .48724 L
.55982 .4841 L
.55924 .47808 L
.55843 .47165 L
.55606 .45829 L
.55431 .45084 L
.55243 .44404 L
.54416 .42228 L
.5384 .41121 L
.5325 .4017 L
.5032 .36562 L
.48597 .34778 L
.46785 .33208 L
.46302 .32879 L
.45784 .32584 L
.45206 .32343 L
.44671 .32217 L
.4408 .32212 L
.43532 .32359 L
.43219 .3252 L
.42938 .32719 L
.42619 .33018 L
.42322 .33372 L
.41787 .34233 L
.4153 .34771 L
.41257 .35448 L
.40808 .36861 L
.40433 .38434 L
.40058 .40578 L
.39787 .42783 L
.39668 .44083 L
.39566 .45555 L
.39497 .46986 L
.39457 .48338 L
.39445 .50935 L
.39471 .52236 L
.39524 .53644 L
.3968 .5605 L
.39893 .58154 L
.40052 .59345 L
.40222 .60406 L
.40586 .62203 L
.41038 .6384 L
.41588 .65261 L
.42065 .66141 L
.42619 .66855 L
.42905 .6712 L
.43218 .67342 L
.43792 .6759 L
Mistroke
.44338 .67666 L
.44913 .67611 L
.45401 .67474 L
.4593 .67252 L
.46985 .66635 L
.47906 .65971 L
.49833 .64442 L
.5285 .62061 L
.5426 .60727 L
.54904 .59923 L
.55548 .58879 L
.56037 .57833 L
.56489 .56543 L
.56836 .55178 L
.5708 .53833 L
.57192 .52988 L
.57241 .5252 L
.5728 .52078 L
.57334 .51218 L
.57359 .50449 L
.57363 .50009 L
.57359 .49553 L
.57331 .48766 L
.57305 .48345 L
.57274 .47967 L
.57232 .47572 L
.5718 .47164 L
.57074 .46535 L
.56956 .46007 L
.56825 .4556 L
.56694 .45208 L
.56541 .44893 L
.56363 .44627 L
.56271 .44525 L
.56169 .44437 L
.55983 .44338 L
.55884 .44316 L
.55791 .44312 L
.55617 .4435 L
.55432 .44451 L
.55329 .44534 L
.55236 .44626 L
.54925 .45055 L
.54779 .45327 L
.54629 .45661 L
.54353 .46464 L
.54224 .4696 L
.54123 .47434 L
.54045 .47886 L
.53978 .48388 L
Mistroke
.53953 .48619 L
.53931 .48865 L
.53902 .49307 L
.53887 .49741 L
.53885 .50134 L
.53896 .50556 L
.53922 .50987 L
.53956 .51349 L
.53997 .51673 L
.54051 .5201 L
.54121 .52349 L
.54208 .52687 L
.54316 .53015 L
.54427 .53283 L
.54538 .53489 L
.54644 .53641 L
.54764 .53766 L
.54826 .53812 L
.54894 .53848 L
.55017 .53878 L
.55084 .53873 L
.55148 .53856 L
.55266 .53787 L
.55389 .5366 L
.55457 .53564 L
.55517 .5346 L
.55614 .53252 L
.55712 .52975 L
.55805 .52634 L
.5588 .52269 L
.55918 .52043 L
.55954 .51781 L
.55982 .51538 L
.56007 .51268 L
.5604 .50726 L
.56055 .50193 L
.56056 .49886 L
.5605 .49548 L
.56025 .48917 L
.56 .48544 L
.55966 .48145 L
.55886 .47425 L
.55793 .46787 L
.55691 .46209 L
.55401 .44935 L
.55059 .43802 L
.54676 .4279 L
.53616 .40724 L
.52186 .38709 L
.49043 .35212 L
Mistroke
.48033 .34238 L
.46879 .33272 L
.46297 .3287 L
.45733 .32554 L
.45219 .32342 L
.44654 .3221 L
.44066 .32209 L
.43516 .32361 L
.43205 .32525 L
.42922 .32729 L
.42615 .33017 L
.42299 .33399 L
.42018 .33819 L
.41726 .34348 L
.41228 .35522 L
.40693 .37293 L
.40274 .39252 L
.39953 .41338 L
.3972 .43462 L
.39543 .45964 L
.39486 .47273 L
.39449 .48738 L
.39448 .51208 L
.39532 .53825 L
.39691 .56191 L
.399 .5822 L
.40204 .60312 L
.4055 .62052 L
.40903 .63408 L
.41324 .64646 L
.41823 .65731 L
.42086 .66175 L
.42383 .66588 L
.42924 .67138 L
.43442 .67463 L
.43971 .67632 L
.44476 .67665 L
.44928 .67608 L
.45418 .67469 L
.45944 .67245 L
.46495 .66945 L
.47457 .66303 L
.51211 .63349 L
.52901 .6201 L
.53747 .61251 L
.54482 .60459 L
.55083 .59649 L
.55667 .58635 L
.56232 .57306 L
.56658 .55911 L
Mistroke
.56963 .54508 L
.57098 .53674 L
.57198 .52887 L
.57266 .52191 L
.57319 .51424 L
.5735 .5063 L
.57358 .49903 L
.57345 .49194 L
.57308 .48455 L
.57252 .47797 L
.57184 .47229 L
.57101 .46709 L
.57015 .46278 L
.56909 .45855 L
.56786 .45464 L
.56639 .45101 L
.56495 .4483 L
.56332 .44605 L
.56237 .44507 L
.56147 .44435 L
.55981 .44351 L
.55829 .44325 L
.55653 .44351 L
.55488 .44427 L
.55327 .44549 L
.55159 .44729 L
.54872 .45164 L
.54718 .45472 L
.54567 .45834 L
.54332 .46558 L
.5423 .46955 L
.54136 .47395 L
.54066 .47786 L
.54004 .48216 L
.53972 .48482 L
.53947 .48728 L
.53928 .48958 L
.53912 .49211 L
.53894 .49648 L
.53889 .50103 L
.53899 .50522 L
.53921 .50908 L
.53949 .51244 L
.53991 .51595 L
.54047 .51958 L
.54119 .52318 L
.5419 .52606 L
.54277 .52889 L
.54364 .53124 L
.54449 .53315 L
Mistroke
.54541 .53483 L
.5463 .53615 L
.54732 .53729 L
.54846 .53818 L
.5496 .53864 L
.55082 .5387 L
.55202 .53827 L
.5527 .53782 L
.55333 .53724 L
.55455 .53566 L
.55521 .53452 L
.5558 .53332 L
.55678 .53081 L
.55776 .52754 L
.55857 .52396 L
.55922 .52022 L
.55956 .51778 L
.55987 .51498 L
.56012 .51222 L
.5603 .50956 L
.56052 .50427 L
.56057 .49836 L
.56051 .49518 L
.56039 .4917 L
.56 .48528 L
.55966 .48128 L
.55926 .47746 L
.55831 .47025 L
.55609 .45801 L
.55291 .44536 L
.54955 .43505 L
.54519 .4243 L
.53324 .40267 L
.51945 .38415 L
.48591 .3477 L
.47636 .3389 L
.4656 .33049 L
.45919 .32655 L
.45611 .32502 L
.45325 .32385 L
.45035 .32293 L
.4472 .32226 L
.44147 .32207 L
.43665 .32311 L
.43152 .32565 L
.42677 .3296 L
.42254 .33467 L
.41779 .34253 L
.41291 .35362 L
.40866 .36658 L
Mistroke
.40511 .38076 L
.40161 .3992 L
.39889 .41865 L
.39696 .43761 L
.39546 .45931 L
.39456 .48403 L
.39447 .5105 L
.39509 .53286 L
.39649 .55651 L
.39878 .58021 L
.40157 .60016 L
.40529 .61951 L
.40991 .63685 L
.41436 .64913 L
.41885 .65836 L
.42405 .66607 L
.42707 .66938 L
.42987 .67179 L
.4351 .67486 L
.44002 .67629 L
.44545 .67653 L
.45122 .67553 L
.45667 .67363 L
.46174 .67118 L
.47101 .66545 L
.50987 .6351 L
.52797 .62081 L
.53608 .61368 L
.54303 .60651 L
.54882 .59923 L
.55463 .59003 L
.56009 .57864 L
.56454 .56615 L
.56848 .5507 L
.57006 .54232 L
.57147 .53275 L
.57239 .52447 L
.57278 .51978 L
.57307 .51549 L
.57342 .50762 L
.57354 .49951 L
.57341 .49226 L
.57312 .48593 L
.57258 .47901 L
.57188 .47293 L
.57107 .46774 L
.57022 .46335 L
.56916 .45904 L
.56791 .45499 L
.56653 .45152 L
Mistroke
.56516 .44885 L
.56345 .44637 L
.56183 .44478 L
.5601 .44378 L
.55911 .4435 L
.55819 .44341 L
.5565 .44368 L
.55473 .44453 L
.55299 .44594 L
.55114 .44804 L
.5493 .45081 L
.54769 .45385 L
.54508 .46022 L
.54274 .46807 L
.54166 .47281 L
.54069 .47815 L
.53996 .4833 L
.53969 .48578 L
.53947 .48811 L
.53917 .49244 L
.53906 .49473 L
.53899 .49718 L
.53896 .49959 L
.53897 .5021 L
.53912 .5065 L
.53939 .51062 L
.53976 .51422 L
.54031 .51818 L
.54094 .52168 L
.54234 .52729 L
.54326 .53004 L
.54417 .53227 L
.54517 .53424 L
.5463 .53597 L
.54697 .53677 L
.5476 .53739 L
.54884 .53823 L
.54952 .53848 L
.55015 .53859 L
.55084 .53856 L
.55157 .53835 L
.55278 .53762 L
.55346 .53697 L
.55408 .53621 L
.55514 .53453 L
.5562 .53222 L
.55714 .52958 L
.55791 .52679 L
.55871 .52305 L
.55908 .52089 L
Mistroke
.55944 .51846 L
.55997 .51365 L
.56031 .50885 L
.56051 .50361 L
.56053 .49766 L
.56036 .4918 L
.56005 .48628 L
.55978 .48288 L
.55947 .47969 L
.55859 .4724 L
.55758 .46595 L
.55628 .45912 L
.55342 .44733 L
.54954 .43516 L
.54054 .415 L
.52959 .39747 L
.51778 .38224 L
.50266 .36509 L
.48414 .34609 L
.47429 .33723 L
.46448 .32982 L
.46009 .32713 L
.45534 .32477 L
.45008 .32294 L
.44518 .32211 L
.43942 .32244 L
.43417 .32422 L
.42849 .32806 L
.4257 .33082 L
.4227 .33455 L
.41779 .34261 L
.41287 .35381 L
.40859 .36692 L
.40509 .38098 L
.40123 .40174 L
.39836 .42339 L
.39716 .43552 L
.39608 .4494 L
.39523 .46437 L
.39471 .47868 L
.39446 .49236 L
.39444 .50539 L
.39498 .52964 L
.39639 .55487 L
.39754 .56849 L
.39884 .58057 L
.40185 .60172 L
.40573 .62129 L
.40954 .63556 L
.41416 .64855 L
Mistroke
.41956 .6595 L
.42274 .66431 L
.42571 .66791 L
.42853 .67063 L
.43164 .67295 L
.43737 .6756 L
.44273 .6765 L
.44865 .67605 L
.45162 .67535 L
.4548 .6743 L
.46048 .67176 L
.47121 .66523 L
.48064 .6583 L
.51382 .63194 L
.52964 .61934 L
.54307 .60641 L
.54952 .59818 L
.55587 .58767 L
.56097 .57641 L
.565 .56458 L
.56815 .55221 L
.57081 .53755 L
.57181 .52989 L
.57264 .52156 L
.57317 .51369 L
.57345 .50657 L
.57353 .49831 L
.57346 .49425 L
.57332 .48986 L
.57287 .48244 L
.57224 .47592 L
.5718 .47241 L
.57126 .4689 L
.57016 .46314 L
.56877 .45773 L
.56706 .45279 L
.56541 .44932 L
.56382 .44688 L
.56291 .44581 L
.56191 .44489 L
.56005 .44381 L
.55828 .44346 L
.55642 .44376 L
.55484 .44452 L
.55313 .44586 L
.55138 .4478 L
.54982 .45003 L
.54658 .4564 L
.54412 .46322 L
.54303 .46704 L
Mistroke
.542 .47137 L
.54112 .47579 L
.54044 .47994 L
.53992 .48389 L
.53948 .48825 L
.53921 .49217 L
.53905 .49581 L
.53898 .49961 L
.53903 .50361 L
.53911 .50588 L
.53924 .50825 L
.53958 .51238 L
.53983 .5146 L
.5401 .51662 L
.54083 .52099 L
.54161 .5245 L
.54242 .52744 L
.54347 .53051 L
.54454 .53297 L
.54551 .53472 L
.54659 .53626 L
.54723 .53696 L
.54784 .53751 L
.54901 .53822 L
.55025 .53851 L
.5514 .53833 L
.55265 .53763 L
.55327 .53707 L
.55394 .5363 L
.55511 .53447 L
.55613 .53228 L
.55717 .52933 L
.55815 .52559 L
.55895 .52146 L
.55957 .5171 L
.56 .51283 L
.56033 .50787 L
.56048 .50302 L
.56049 .49744 L
.56031 .49137 L
.55996 .48554 L
.55946 .47996 L
.55887 .47482 L
.55706 .46325 L
.55574 .45676 L
.5541 .44999 L
.55058 .43825 L
.54599 .42635 L
.54004 .41417 L
.52723 .39429 L
Mistroke
.5129 .37658 L
.49616 .35821 L
.48637 .34828 L
.47521 .33803 L
.46943 .33337 L
.46384 .32943 L
.45828 .32619 L
.45309 .3239 L
.44809 .32252 L
.44279 .32209 L
.43747 .32295 L
.43169 .32565 L
.42624 .33026 L
.42125 .33668 L
.41696 .34429 L
.41255 .35469 L
.40815 .36856 L
.404 .38619 L
.40096 .40349 L
.39822 .42472 L
.39632 .44604 L
.39513 .46663 L
.39449 .48992 L
.39456 .51466 L
.39525 .53594 L
.39641 .55511 L
.39822 .57507 L
.40075 .5948 L
.40403 .61346 L
.40826 .63116 L
.41327 .64632 L
.4184 .65744 L
.42349 .66527 L
.42832 .67044 L
.43405 .67429 L
.43959 .67613 L
.44273 .67649 L
.44558 .67644 L
.44887 .676 L
.45195 .67525 L
.4574 .67323 L
.4632 .67029 L
.48709 .65323 L
.52115 .62625 L
.53667 .6131 L
.54445 .60486 L
.55122 .59572 L
.55719 .58511 L
.56282 .57146 L
.56498 .56474 L
Mistroke
.56702 .55716 L
.56858 .55028 L
.57003 .54258 L
.57125 .5346 L
.57214 .52714 L
.57278 .51996 L
.57325 .51241 L
.57352 .5042 L
.57353 .49675 L
.5733 .48888 L
.57306 .48466 L
.57277 .48095 L
.57201 .47384 L
.57154 .47049 L
.57096 .46701 L
.56978 .4614 L
.56852 .45681 L
.56688 .45227 L
.56524 .44895 L
.56429 .44746 L
.56324 .4461 L
.56221 .44508 L
.56125 .44436 L
.55952 .44358 L
.55788 .44341 L
.55608 .44383 L
.55508 .44432 L
.55417 .44493 L
.55247 .44647 L
.55068 .44868 L
.5489 .45152 L
.54734 .4546 L
.54454 .46181 L
.54242 .46939 L
.54151 .4736 L
.54066 .47838 L
.53995 .48346 L
.5397 .48575 L
.53946 .48826 L
.53915 .49279 L
.539 .49706 L
.53897 .50115 L
.53905 .50488 L
.53929 .50918 L
.53962 .51294 L
.53985 .51495 L
.54014 .51707 L
.54076 .52074 L
.54212 .5265 L
.54302 .52936 L
Mistroke
.54395 .53173 L
.54498 .53385 L
.54601 .53552 L
.5466 .5363 L
.54725 .53701 L
.54842 .53795 L
.54946 .5384 L
.55061 .53851 L
.55181 .53817 L
.55292 .53741 L
.55393 .53631 L
.55483 .53497 L
.55576 .53313 L
.55669 .53078 L
.55761 .52775 L
.55849 .52393 L
.5592 .51983 L
.55973 .51566 L
.56009 .51159 L
.56037 .50683 L
.56049 .50155 L
.56047 .49638 L
.56024 .49012 L
.55983 .48399 L
.55929 .4784 L
.55852 .47224 L
.5561 .45847 L
.55301 .44604 L
.54936 .43479 L
.54531 .42481 L
.53628 .40766 L
.52458 .39077 L
.5098 .37302 L
.49391 .35584 L
.47465 .33753 L
.46854 .33267 L
.4626 .32861 L
.45716 .3256 L
.45431 .32434 L
.45116 .32324 L
.44541 .32213 L
.44226 .32209 L
.43931 .32246 L
.43406 .32426 L
.4285 .32804 L
.42556 .33096 L
.42249 .33482 L
.41717 .34382 L
.41408 .3507 L
.4113 .35818 L
Mistroke
.40653 .37474 L
.40257 .39369 L
.39953 .41359 L
.3982 .42484 L
.39696 .43775 L
.39592 .45176 L
.39519 .46524 L
.39446 .49132 L
.39458 .51625 L
.39536 .53826 L
.39689 .56127 L
.39933 .58458 L
.40085 .59551 L
.40274 .60683 L
.40656 .62475 L
.41064 .63904 L
.41497 .65047 L
.41994 .66014 L
.42488 .667 L
.42952 .67147 L
.43511 .67481 L
.4383 .67588 L
.44125 .67641 L
.44669 .67637 L
.45243 .67514 L
.45787 .67306 L
.46363 .6701 L
.47375 .6635 L
.49515 .6468 L
.52777 .62102 L
.54143 .60835 L
.55236 .594 L
.55807 .58336 L
.56277 .57172 L
.56691 .55773 L
.56884 .54917 L
.57033 .54097 L
.57156 .53234 L
.57245 .52415 L
.57285 .51942 L
.57313 .51512 L
.57337 .51017 L
.57351 .50554 L
.57357 .5011 L
.57355 .49648 L
.5733 .48844 L
.57304 .48416 L
.57274 .48029 L
.57232 .47622 L
.57179 .47205 L
Mistroke
.57079 .46598 L
.5697 .46093 L
.56833 .4561 L
.56671 .4518 L
.56584 .44997 L
.56486 .44824 L
.56398 .44693 L
.56302 .44578 L
.56213 .44494 L
.56115 .44422 L
.55939 .44347 L
.55759 .44336 L
.55595 .4438 L
.55407 .44492 L
.55234 .44652 L
.5508 .44842 L
.54943 .45052 L
.54655 .45629 L
.54408 .46317 L
.5422 .47021 L
.54061 .47846 L
.54001 .48273 L
.53973 .48516 L
.5395 .48746 L
.53918 .49164 L
.53901 .49543 L
.53893 .49946 L
.53898 .50376 L
.53914 .50742 L
.53942 .51119 L
.53974 .51429 L
.54018 .51757 L
.54087 .52144 L
.54163 .52484 L
.54336 .53039 L
.54446 .53295 L
.54556 .53493 L
.54683 .53664 L
.54756 .53738 L
.54824 .5379 L
.54949 .53848 L
.55065 .53857 L
.55191 .53818 L
.55254 .53778 L
.55323 .53718 L
.55435 .53579 L
.55549 .53377 L
.55651 .53136 L
.55736 .52874 L
.55817 .52553 L
Mistroke
.55885 .52214 L
.55947 .51801 L
.55999 .51311 L
.56033 .50784 L
.56044 .50505 L
.5605 .50191 L
.56047 .49612 L
.56027 .49052 L
.5599 .48468 L
.55938 .47906 L
.55877 .47397 L
.55797 .46843 L
.5556 .45607 L
.55273 .445 L
.54889 .43347 L
.54466 .42331 L
.5329 .4023 L
.51886 .38356 L
.50106 .36334 L
.48283 .34482 L
.47186 .3352 L
.46098 .3276 L
.45788 .32591 L
.45457 .32441 L
.45092 .32313 L
.44754 .32236 L
.44166 .32209 L
.43833 .32264 L
.43523 .32368 L
.43215 .32529 L
.42926 .32736 L
.42397 .33282 L
.4185 .34123 L
.41555 .34723 L
.41293 .35359 L
.40881 .36611 L
.40482 .38212 L
.40156 .39956 L
.39906 .41731 L
.39687 .43874 L
.39525 .46372 L
.39475 .47676 L
.39446 .49085 L
.39458 .5163 L
.39499 .53021 L
.39559 .5428 L
.39648 .55626 L
.39768 .56998 L
.40026 .59157 L
.40385 .61271 L
Mistroke
.40764 .629 L
.41222 .64363 L
.41695 .65474 L
.42153 .66266 L
.4265 .66879 L
.4313 .67279 L
.43668 .67544 L
.44254 .67655 L
.44836 .67617 L
.45127 .67551 L
.45445 .6745 L
.46003 .67207 L
.46514 .66924 L
.50145 .64179 L
.53424 .61547 L
.54244 .60728 L
.54958 .59826 L
.55542 .58871 L
.56102 .57649 L
.56523 .564 L
.56722 .5565 L
.56888 .549 L
.5702 .54179 L
.57139 .5337 L
.57226 .52622 L
.57286 .51922 L
.57315 .51487 L
.57337 .51018 L
.57357 .50181 L
.5735 .4939 L
.57322 .48693 L
.57269 .47976 L
.57229 .47592 L
.57186 .47249 L
.57082 .46607 L
.56947 .46002 L
.56795 .45494 L
.56639 .45106 L
.56454 .44772 L
.56357 .44639 L
.56247 .44521 L
.5615 .44442 L
.5606 .44388 L
.55959 .4435 L
.55854 .44331 L
.55675 .4435 L
.55575 .44386 L
.55482 .44437 L
.55299 .44582 L
.55132 .4477 L
Mistroke
.54837 .45236 L
.54685 .45553 L
.54555 .45876 L
.543 .46689 L
.54201 .47099 L
.54119 .47501 L
.54055 .47875 L
.53999 .48279 L
.53951 .4872 L
.53919 .4913 L
.53906 .4938 L
.53897 .49614 L
.53892 .50046 L
.53899 .50424 L
.53917 .50811 L
.53942 .51133 L
.53978 .51473 L
.54027 .51823 L
.54092 .52176 L
.54234 .52746 L
.54337 .53045 L
.5444 .53285 L
.54561 .53506 L
.54626 .53599 L
.54698 .53685 L
.5482 .53792 L
.54938 .53849 L
.55011 .53862 L
.55079 .5386 L
.55208 .53813 L
.55321 .53724 L
.55439 .53579 L
.55544 .53394 L
.55634 .53186 L
.55733 .52892 L
.55827 .52516 L
.55904 .5211 L
.55962 .51693 L
.56008 .51211 L
.56038 .5072 L
.56051 .50254 L
.56051 .49723 L
.56032 .49123 L
.56016 .48812 L
.55991 .48465 L
.55932 .47843 L
.55859 .47253 L
.55666 .46103 L
.55431 .45068 L
.55111 .43971 L
Mistroke
.54705 .42875 L
.53639 .40774 L
.52414 .39011 L
.50842 .37139 L
.48855 .35034 L
.47808 .34045 L
.4663 .33101 L
.46127 .32775 L
.45577 .3249 L
.45257 .32364 L
.44964 .32277 L
.44386 .322 L
.43813 .32268 L
.43287 .32485 L
.4272 .3292 L
.4241 .33264 L
.42135 .33643 L
.41649 .34516 L
.41158 .3573 L
.40736 .3714 L
.40389 .38659 L
.401 .40308 L
.39844 .42259 L
.39656 .44248 L
.39535 .46157 L
.39455 .48474 L
.39447 .51026 L
.39515 .53408 L
.39641 .55536 L
.39831 .57607 L
.40062 .59407 L
.40369 .61193 L
.40756 .62871 L
.41188 .64272 L
.41686 .65459 L
.4214 .66247 L
.42657 .66888 L
.42936 .67139 L
.43235 .67346 L
.43778 .67579 L
.44367 .67659 L
.44702 .67637 L
.45015 .6758 L
.45576 .674 L
.46082 .67167 L
.47191 .66483 L
.50774 .63681 L
.52479 .62346 L
.53309 .61649 L
.54137 .60842 L
Mistroke
.54807 .60035 L
.55481 .58981 L
.56023 .57842 L
.56461 .56606 L
.56648 .5594 L
.56826 .55192 L
.57084 .53764 L
.572 .52857 L
.57281 .51989 L
.57328 .51211 L
.57354 .50377 L
.57353 .49583 L
.57342 .49144 L
.57324 .48744 L
.57298 .48336 L
.57268 .47976 L
.5718 .47214 L
.57085 .46629 L
.56961 .4606 L
.56827 .45594 L
.56691 .45228 L
.56545 .44925 L
.56379 .44669 L
.56215 .44495 L
.56061 .44391 L
.55919 .44342 L
.55763 .44335 L
.556 .44378 L
.5545 .4446 L
.55278 .44606 L
.55119 .44788 L
.5484 .45234 L
.54571 .45838 L
.54323 .46607 L
.54144 .47375 L
.54064 .47827 L
.54003 .48248 L
.53961 .48622 L
.53927 .49033 L
.53903 .49459 L
.53893 .49853 L
.53893 .50077 L
.53896 .50317 L
.53914 .50744 L
.53944 .51146 L
.53982 .51501 L
.54036 .51868 L
.54107 .52245 L
.54195 .52606 L
.54289 .52911 L
Mistroke
.54389 .53173 L
.54508 .53415 L
.54628 .536 L
.54744 .5373 L
.54862 .53816 L
.54971 .53856 L
.55097 .53856 L
.55215 .53809 L
.55276 .53765 L
.55342 .53703 L
.5541 .5362 L
.55471 .53528 L
.55577 .53325 L
.55682 .53055 L
.55793 .52668 L
.55883 .52237 L
.55949 .51798 L
.5598 .51531 L
.56004 .51272 L
.56036 .50764 L
.56052 .50251 L
.56052 .49768 L
.56037 .49221 L
.56003 .48611 L
.55975 .48263 L
.55944 .47946 L
.55868 .47314 L
.55781 .46731 L
.55562 .45609 L
.55255 .4443 L
.54519 .42443 L
.54011 .4142 L
.53481 .4052 L
.52085 .38596 L
.50494 .36754 L
.48486 .34674 L
.47428 .33718 L
.46822 .3324 L
.46238 .32844 L
.45733 .32564 L
.4518 .32339 L
.44878 .32259 L
.44559 .3221 L
.43989 .32232 L
.43456 .32398 L
.42895 .32762 L
.42379 .33305 L
.41927 .33985 L
.41423 .3503 L
.4092 .36476 L
Mistroke
.40497 .38143 L
.40161 .39929 L
.3991 .41693 L
.39697 .43751 L
.39553 .45815 L
.39472 .47772 L
.39441 .50104 L
.39485 .52638 L
.39601 .54965 L
.3977 .57018 L
.40028 .59166 L
.4033 .60987 L
.40645 .62437 L
.41026 .63793 L
.41484 .65022 L
.42006 .66037 L
.42475 .66688 L
.43007 .67192 L
.43585 .67513 L
.44126 .67644 L
.4441 .67657 L
.44722 .67633 L
.45048 .67571 L
.45352 .67481 L
.45904 .67254 L
.46403 .66988 L
.47495 .66265 L
.51013 .63491 L
.52736 .62134 L
.54172 .60801 L
.54829 .60001 L
.5547 .58996 L
.56094 .57661 L
.56566 .56239 L
.56894 .54857 L
.57043 .54024 L
.57156 .53223 L
.57248 .52365 L
.57308 .51578 L
.5733 .51145 L
.57347 .50676 L
.57355 .4984 L
.57341 .49153 L
.57303 .48427 L
.57241 .47715 L
.57162 .47096 L
.57072 .46571 L
.56978 .46133 L
.56861 .45706 L
.56726 .45317 L
Mistroke
.56565 .44965 L
.56409 .44714 L
.5632 .44603 L
.56222 .44505 L
.56039 .44385 L
.55865 .44338 L
.55681 .44354 L
.55524 .44418 L
.55355 .44538 L
.55255 .44633 L
.55162 .44739 L
.54992 .44974 L
.54806 .45305 L
.54644 .45658 L
.54389 .46382 L
.54273 .46803 L
.54167 .4727 L
.54086 .477 L
.54013 .48182 L
.53962 .48626 L
.53927 .49042 L
.53912 .49293 L
.53902 .4953 L
.53894 .4997 L
.53896 .50213 L
.53901 .50434 L
.53911 .50674 L
.53927 .50923 L
.5396 .51296 L
.54008 .51681 L
.54065 .52024 L
.54125 .5232 L
.54296 .52926 L
.54395 .53182 L
.54513 .5342 L
.54625 .53593 L
.54736 .53718 L
.54838 .53799 L
.5495 .53848 L
.55074 .53857 L
.55136 .53843 L
.55204 .53813 L
.55322 .53721 L
.5543 .53589 L
.55533 .53413 L
.55626 .53205 L
.55782 .52709 L
.55857 .52374 L
.55916 .52027 L
.55971 .51611 L
Mistroke
.56015 .51128 L
.56042 .50609 L
.5605 .503 L
.56053 .50004 L
.5605 .49684 L
.56043 .49385 L
.56028 .49034 L
.56008 .48697 L
.55958 .48088 L
.55894 .47518 L
.55799 .46848 L
.55689 .46222 L
.554 .4495 L
.54987 .43611 L
.54494 .42391 L
.53872 .41172 L
.5259 .39244 L
.50978 .37294 L
.49221 .35406 L
.47416 .33709 L
.46412 .32955 L
.45827 .32613 L
.4528 .32375 L
.44795 .32244 L
.4426 .32205 L
.43702 .32304 L
.43186 .32548 L
.42606 .33039 L
.42076 .33739 L
.41622 .34579 L
.41158 .35735 L
.407 .37282 L
.40277 .39254 L
.39976 .41183 L
.39842 .42282 L
.39716 .43541 L
.39558 .45739 L
.39463 .48153 L
.39443 .5043 L
.39482 .52539 L
.39602 .54969 L
.39775 .57067 L
.40048 .59304 L
.40371 .61195 L
.40698 .62648 L
.41086 .63974 L
.41445 .64929 L
.41866 .65796 L
.42341 .66522 L
.42871 .67082 L
Mistroke
.43386 .67424 L
.43863 .67597 L
.44442 .67654 L
.44986 .67583 L
.45472 .67437 L
.45992 .67209 L
.4713 .66522 L
.48132 .65782 L
.51485 .63121 L
.53139 .61793 L
.54517 .60402 L
.5514 .59547 L
.55743 .58465 L
.56052 .57763 L
.5632 .5704 L
.56537 .5634 L
.56746 .55538 L
.56908 .54782 L
.57036 .54064 L
.57144 .53314 L
.57225 .52606 L
.57292 .51821 L
.57337 .50966 L
.57355 .50147 L
.57354 .49699 L
.57345 .493 L
.57309 .48507 L
.57252 .47819 L
.57214 .47479 L
.57166 .47123 L
.5705 .4646 L
.5693 .45947 L
.56784 .45473 L
.56633 .45102 L
.56486 .44828 L
.56333 .44618 L
.56164 .4446 L
.56002 .44371 L
.55853 .44339 L
.55677 .44357 L
.55489 .4444 L
.55315 .44576 L
.55159 .44744 L
.5489 .45147 L
.54624 .45709 L
.54384 .464 L
.54201 .47114 L
.54114 .47542 L
.54038 .48008 L
.53986 .48412 L
Mistroke
.53942 .4886 L
.53924 .4911 L
.53911 .49339 L
.53901 .49602 L
.53896 .4985 L
.53898 .50284 L
.53905 .50525 L
.53916 .50745 L
.53947 .51163 L
.5399 .5154 L
.54037 .51863 L
.54098 .52193 L
.54176 .52527 L
.5427 .52847 L
.54367 .53113 L
.54463 .53325 L
.54555 .53488 L
.5466 .53634 L
.54774 .53751 L
.54885 .53823 L
.54991 .53855 L
.55103 .5385 L
.55198 .53814 L
.55302 .53738 L
.55419 .53602 L
.55523 .53431 L
.5563 .53192 L
.55733 .52885 L
.55814 .52571 L
.5588 .52241 L
.55942 .5184 L
.55994 .51369 L
.5603 .50874 L
.56043 .50578 L
.5605 .50292 L
.5605 .49692 L
.56041 .49344 L
.56026 .49019 L
.55987 .48429 L
.55924 .47774 L
.55844 .4715 L
.55752 .46569 L
.55455 .45165 L
.551 .43944 L
.54595 .4262 L
.54033 .41464 L
.52811 .39543 L
.51477 .3787 L
.49798 .36007 L
.4877 .34954 L
Mistroke
.4773 .33979 L
.46706 .33158 L
.46147 .32791 L
.45836 .32618 L
.45541 .32478 L
.45026 .32297 L
.44453 .32206 L
.43966 .32238 L
.43444 .32406 L
.42953 .32716 L
.42429 .33244 L
.41903 .3403 L
.4144 .34992 L
.41034 .3611 L
.40695 .37306 L
.40344 .38896 L
.40059 .4059 L
.39803 .42642 L
.39597 .45086 L
.39525 .46373 L
.39473 .47783 L
.39442 .50366 L
.39496 .52924 L
.39623 .55273 L
.39796 .57273 L
.40046 .59291 L
.40383 .61256 L
.40824 .63117 L
.4107 .63924 L
.4135 .64697 L
.41604 .65285 L
.41893 .65844 L
.42436 .6664 L
.42743 .66967 L
.43033 .67208 L
.43561 .67502 L
.44133 .67642 L
.44685 .67636 L
.44998 .67581 L
.4529 .675 L
.45873 .67266 L
.4649 .66935 L
.48517 .6548 L
.52431 .6238 L
.53222 .61721 L
.54035 .60947 L
.54702 .6017 L
.55355 .59197 L
.55931 .58055 L
.56382 .56853 L
Mistroke
.56757 .55491 L
.57032 .54092 L
.57142 .53336 L
.57235 .52512 L
.57298 .5173 L
.57336 .51019 L
.57355 .50199 L
.57355 .49745 L
.57347 .49334 L
.57315 .48605 L
.57258 .47875 L
.57182 .47232 L
.57078 .46602 L
.56963 .46073 L
.56843 .45647 L
.56697 .45245 L
.56524 .4489 L
.56432 .44745 L
.56331 .44615 L
.56241 .44522 L
.56145 .44445 L
.55967 .44358 L
.55802 .44337 L
.55625 .44372 L
.55525 .44418 L
.55432 .44477 L
.55268 .4462 L
.55122 .4479 L
.54814 .4529 L
.5457 .45847 L
.54342 .46547 L
.54166 .47272 L
.54042 .4798 L
.53983 .48434 L
.53957 .48684 L
.53937 .48917 L
.53911 .49328 L
.53896 .49775 L
.53895 .50022 L
.53897 .50254 L
.53912 .50679 L
.53926 .50911 L
.53943 .51121 L
.53994 .51579 L
.54047 .51925 L
.54106 .52232 L
.54187 .5257 L
.54271 .52851 L
.5436 .53097 L
.54466 .53331 L
Mistroke
.54585 .53535 L
.54705 .53686 L
.54825 .53789 L
.5494 .53844 L
.55045 .53858 L
.55158 .53833 L
.5528 .53757 L
.5534 .53699 L
.55405 .53621 L
.55517 .53442 L
.55615 .5323 L
.55706 .52972 L
.55786 .52688 L
.55851 .52398 L
.55911 .52056 L
.55965 .51649 L
.56005 .51242 L
.56034 .50773 L
.56051 .50222 L
.56049 .49669 L
.56032 .49134 L
.55995 .4853 L
.55966 .48186 L
.55934 .4787 L
.55855 .47229 L
.55745 .46531 L
.55483 .45279 L
.55168 .44155 L
.54764 .43025 L
.5387 .41171 L
.5259 .39246 L
.51171 .37515 L
.49382 .35572 L
.48332 .34529 L
.47134 .3348 L
.46512 .33023 L
.45913 .32658 L
.45365 .32406 L
.45054 .32304 L
.44766 .32239 L
.4424 .32206 L
.43665 .32316 L
.43377 .32439 L
.43071 .32626 L
.4253 .33124 L
.41995 .3387 L
.41705 .34405 L
.41446 .34976 L
.40999 .3622 L
.40571 .37819 L
Mistroke
.40236 .39483 L
.3997 .41229 L
.39736 .43324 L
.39557 .45748 L
.39465 .48057 L
.39442 .50242 L
.39485 .52631 L
.39611 .55106 L
.39704 .56307 L
.39827 .5756 L
.40104 .59677 L
.40436 .61515 L
.40789 .62992 L
.41156 .64178 L
.41526 .65115 L
.41957 .65954 L
.42441 .66647 L
.42968 .6716 L
.43479 .67468 L
.43944 .67615 L
.44453 .67655 L
.44745 .67629 L
.45053 .67568 L
.456 .67387 L
.45902 .67254 L
.46181 .67111 L
.46806 .6674 L
.48849 .65216 L
.52156 .626 L
.53739 .61247 L
.54449 .60487 L
.55057 .59677 L
.55691 .58576 L
.56284 .57148 L
.56697 .55746 L
.5687 .54981 L
.57031 .54102 L
.57152 .53264 L
.57239 .52472 L
.57307 .51599 L
.57332 .51113 L
.57347 .50675 L
.57356 .49886 L
.57338 .49062 L
.57297 .48322 L
.57238 .47683 L
.57164 .47108 L
.57081 .46614 L
.56976 .46123 L
.56848 .45661 L
Mistroke
.567 .4525 L
.56548 .44932 L
.56405 .44705 L
.56242 .44521 L
.5606 .44393 L
.55886 .44339 L
.55786 .44336 L
.55695 .44349 L
.55595 .44382 L
.55491 .44436 L
.55396 .44502 L
.55297 .44589 L
.55123 .44786 L
.54926 .45082 L
.54758 .45402 L
.54488 .46071 L
.54364 .46464 L
.54248 .46905 L
.54159 .47307 L
.54075 .47761 L
.54016 .48156 L
.53966 .48581 L
.53927 .49039 L
.53904 .49462 L
.53897 .4972 L
.53894 .4996 L
.539 .50401 L
.53919 .50813 L
.53948 .51179 L
.53992 .51564 L
.54051 .51949 L
.5411 .52252 L
.54182 .52555 L
.54335 .53034 L
.5444 .5328 L
.54546 .53476 L
.54647 .5362 L
.5476 .5374 L
.54884 .53824 L
.55003 .53858 L
.55071 .53857 L
.55133 .53843 L
.55201 .53813 L
.55272 .53765 L
.55336 .53705 L
.55403 .53626 L
.55518 .5344 L
.55647 .53148 L
.55753 .52817 L
.55839 .52455 L
Mistroke
.55908 .52077 L
.55969 .51617 L
.55994 .51368 L
.56017 .51082 L
.56043 .50574 L
.56052 .49997 L
.56043 .49426 L
.56019 .48888 L
.55977 .4831 L
.55922 .47759 L
.55844 .47149 L
.55738 .4649 L
.55455 .45167 L
.55119 .43999 L
.54323 .42029 L
.53841 .4112 L
.53256 .40179 L
.50035 .36258 L
.48085 .34298 L
.47147 .3349 L
.46594 .33078 L
.46065 .32742 L
.45543 .32478 L
.44974 .32282 L
.44661 .32223 L
.44362 .32202 L
.43802 .32274 L
.43506 .32377 L
.43194 .32543 L
.42642 .33001 L
.42312 .33393 L
.42009 .33846 L
.41469 .3492 L
.41024 .3614 L
.40598 .377 L
.40278 .39248 L
.39979 .41157 L
.39726 .43428 L
.39618 .44781 L
.39541 .46052 L
.39454 .48594 L
.39448 .51036 L
.39505 .53164 L
.39634 .55438 L
.3984 .57677 L
.40094 .59611 L
.40379 .61238 L
.40678 .62568 L
.41041 .63839 L
.41459 .64962 L
Mistroke
.41914 .65883 L
.42427 .6663 L
.42929 .67131 L
.43396 .6743 L
.43953 .67617 L
.44269 .67654 L
.4456 .6765 L
.45095 .67558 L
.45656 .67365 L
.46188 .67108 L
.46758 .66771 L
.47763 .66066 L
.49526 .64673 L
.51273 .63289 L
.52952 .61956 L
.53713 .61273 L
.54385 .60562 L
.54995 .59769 L
.5551 .58925 L
.55955 .58003 L
.56368 .569 L
.56717 .55663 L
.57018 .54183 L
.57143 .53332 L
.57234 .5253 L
.57274 .52074 L
.57304 .51645 L
.57329 .512 L
.57347 .50713 L
.57356 .49904 L
.57343 .49186 L
.57302 .48397 L
.57239 .47694 L
.57165 .47114 L
.57069 .4655 L
.56963 .46072 L
.56856 .45686 L
.56718 .45294 L
.56556 .44946 L
.56394 .4469 L
.56238 .44517 L
.56067 .44396 L
.55881 .44338 L
.55704 .44346 L
.55544 .44405 L
.5536 .44531 L
.55258 .44628 L
.55165 .44733 L
.5499 .44977 L
.54833 .45248 L
Mistroke
.54553 .45887 L
.54411 .46306 L
.54295 .46715 L
.54102 .47604 L
.54025 .4809 L
.53963 .4861 L
.53926 .49047 L
.53912 .49292 L
.53902 .49518 L
.53894 .49928 L
.53898 .50356 L
.53914 .50728 L
.53938 .51068 L
.53974 .51426 L
.54025 .51794 L
.5409 .52161 L
.54176 .5253 L
.54261 .52825 L
.54362 .53105 L
.54471 .53344 L
.54576 .53524 L
.54687 .53669 L
.54794 .5377 L
.54898 .53831 L
.55012 .53859 L
.55132 .53844 L
.55243 .53788 L
.55345 .53697 L
.55435 .53581 L
.55535 .53409 L
.55625 .53208 L
.55715 .52948 L
.55802 .52626 L
.55868 .52314 L
.5593 .51933 L
.55984 .51485 L
.56008 .51216 L
.56025 .50959 L
.56046 .50462 L
.56052 .49911 L
.5604 .49333 L
.56026 .48998 L
.56007 .48685 L
.55958 .48099 L
.55888 .47472 L
.55718 .46379 L
.55463 .45194 L
.55112 .43976 L
.54649 .42744 L
.5361 .40729 L
Mistroke
.52331 .38907 L
.5091 .37218 L
.49343 .3553 L
.47691 .33944 L
.46691 .33146 L
.46239 .32845 L
.45735 .32566 L
.45206 .32349 L
.44643 .3222 L
.44346 .32202 L
.44028 .32226 L
.43458 .32398 L
.42871 .32783 L
.42547 .33104 L
.42254 .33472 L
.41735 .34343 L
.4122 .35557 L
.408 .36903 L
.40446 .38386 L
.4011 .40248 L
.39959 .41306 L
.39818 .42495 L
.3962 .44752 L
.395 .46962 L
.39458 .48349 L
.39442 .49668 L
.3947 .52129 L
.39568 .54435 L
.39718 .56465 L
.39944 .58551 L
.40249 .6055 L
.4055 .62038 L
.40915 .63432 L
.41292 .6455 L
.4166 .65404 L
.42116 .6621 L
.42635 .66863 L
.43141 .67285 L
.43618 .67525 L
.44146 .67645 L
.44703 .67635 L
.45177 .67536 L
.45691 .67351 L
.46239 .67081 L
.46815 .66735 L
.47819 .66024 L
.51189 .63354 L
.52976 .61935 L
.5378 .61208 L
.54474 .60457 L
Mistroke
.55049 .59689 L
.55627 .58703 L
.5614 .57544 L
.56389 .56833 L
.56598 .56128 L
.5694 .54623 L
.57081 .53781 L
.57199 .5286 L
.57243 .52433 L
.57282 .5197 L
.57331 .51134 L
.57354 .50331 L
.57353 .49612 L
.57332 .48924 L
.57296 .48311 L
.57237 .47676 L
.57155 .47047 L
.57049 .46449 L
.56931 .45948 L
.56813 .45554 L
.56674 .45189 L
.5651 .44865 L
.56348 .44632 L
.56252 .4453 L
.56162 .44456 L
.56063 .44395 L
.55958 .44354 L
.55862 .44336 L
.55759 .44338 L
.55574 .44391 L
.55462 .44454 L
.55358 .44533 L
.55168 .4473 L
.55008 .44949 L
.54846 .45224 L
.54582 .45811 L
.5434 .46548 L
.54224 .47005 L
.54131 .47446 L
.5406 .47856 L
.53996 .48316 L
.53947 .48784 L
.53927 .4904 L
.53912 .4928 L
.53897 .49717 L
.53894 .50112 L
.53904 .50536 L
.5393 .5097 L
.53962 .51322 L
.54008 .51682 L
Mistroke
.5406 .52004 L
.54116 .52281 L
.5419 .52585 L
.54281 .52884 L
.54468 .53338 L
.54582 .53533 L
.54694 .53677 L
.54759 .53741 L
.5482 .53788 L
.54892 .53828 L
.5496 .53851 L
.55026 .5386 L
.55096 .53854 L
.55222 .53802 L
.55298 .53744 L
.55368 .53671 L
.55494 .53485 L
.55599 .5327 L
.55702 .52989 L
.55782 .52706 L
.5586 .52354 L
.55931 .51925 L
.55965 .51664 L
.55991 .51415 L
.56029 .50898 L
.56049 .50375 L
.56052 .49862 L
.56039 .49286 L
.5601 .48724 L
.55968 .48199 L
.55905 .47608 L
.55816 .46957 L
.55571 .45653 L
.55245 .44402 L
.54809 .43136 L
.53812 .41069 L
.52564 .39209 L
.51175 .37518 L
.48025 .34243 L
.47106 .33457 L
.46072 .32746 L
.4576 .32578 L
.45462 .32443 L
.44897 .32264 L
.44363 .32202 L
.43782 .32279 L
.43467 .32394 L
.43173 .32556 L
.42634 .3301 L
.42338 .33359 L
Mistroke
.42072 .33744 L
.41499 .3485 L
.41072 .3599 L
.40646 .375 L
.40257 .39361 L
.39956 .41336 L
.39731 .43371 L
.39558 .45737 L
.39465 .48071 L
.39442 .50266 L
.39473 .52238 L
.39564 .54364 L
.3972 .56491 L
.3992 .58361 L
.40214 .60349 L
.40547 .62025 L
.40887 .63337 L
.41294 .64555 L
.41772 .65623 L
.42047 .66102 L
.42313 .66487 L
.42847 .67062 L
.43344 .67404 L
.43861 .67598 L
.4442 .67656 L
.44948 .67593 L
.45426 .67455 L
.4598 .67216 L
.46573 .66886 L
.47619 .66173 L
.51455 .63147 L
.52941 .61964 L
.53696 .61289 L
.54362 .60588 L
.55422 .59082 L
.55913 .58098 L
.56375 .56877 L
.56753 .55511 L
.56927 .54688 L
.57061 .53911 L
.57163 .53168 L
.5725 .52351 L
.57308 .51575 L
.57341 .50864 L
.57356 .50052 L
.57346 .49314 L
.57311 .4854 L
.57281 .48126 L
.57246 .47761 L
.57159 .47075 L
Mistroke
.57039 .46406 L
.56905 .45854 L
.56765 .45417 L
.56603 .45038 L
.56514 .44872 L
.56416 .44722 L
.56328 .44611 L
.5623 .44511 L
.56054 .44391 L
.5588 .44339 L
.55693 .4435 L
.55517 .44421 L
.5536 .44532 L
.55267 .4462 L
.5517 .44728 L
.55001 .44961 L
.54814 .45287 L
.54651 .4564 L
.54395 .46362 L
.54278 .46785 L
.54169 .47257 L
.54087 .47694 L
.54024 .48098 L
.53974 .48514 L
.53938 .48899 L
.53909 .49348 L
.539 .49583 L
.53895 .4983 L
.53896 .50239 L
.53911 .50678 L
.53925 .50905 L
.53942 .51116 L
.53983 .51499 L
.54041 .5189 L
.54118 .52287 L
.54196 .52605 L
.5429 .52911 L
.54387 .53164 L
.54483 .53366 L
.54574 .53521 L
.54679 .53659 L
.54787 .53763 L
.54904 .53833 L
.55008 .53858 L
.5512 .53847 L
.55225 .53799 L
.55319 .53723 L
.55435 .53581 L
.55537 .53404 L
.55643 .5316 L
Mistroke
.55745 .52845 L
.55825 .52525 L
.5589 .52189 L
.5595 .51781 L
.56001 .513 L
.56021 .51026 L
.56036 .50758 L
.56051 .50235 L
.56049 .49641 L
.56039 .49296 L
.56024 .48972 L
.55987 .48419 L
.55927 .47802 L
.55844 .47151 L
.55747 .46542 L
.55453 .45156 L
.551 .43942 L
.54598 .42626 L
.54036 .41469 L
.52827 .39563 L
.515 .37895 L
.49829 .36039 L
.47758 .34003 L
.46735 .33178 L
.46156 .32795 L
.45608 .32507 L
.45131 .32326 L
.44618 .32218 L
.44047 .32224 L
.43531 .32367 L
.43013 .32668 L
.42547 .33105 L
.42051 .33778 L
.41552 .34731 L
.41146 .3577 L
.40794 .36923 L
.40445 .38389 L
.4012 .40184 L
.39963 .41278 L
.39817 .42508 L
.39612 .4486 L
.39525 .46372 L
.39471 .47827 L
.39446 .4915 L
.39443 .50584 L
.39463 .5186 L
.39508 .53242 L
.39581 .54656 L
.39673 .55936 L
.3989 .58111 L
Mistroke
.40194 .6023 L
.40554 .62053 L
.41007 .63732 L
.41484 .65019 L
.41958 .65957 L
.42407 .66606 L
.4292 .67123 L
.43468 .67464 L
.4399 .67624 L
.44549 .6765 L
.44861 .6761 L
.45143 .67545 L
.45689 .67351 L
.46197 .67103 L
.47306 .664 L
.4845 .65534 L
.51984 .62734 L
.53433 .61534 L
.54162 .60812 L
.54798 .60044 L
.55341 .59223 L
.55793 .58363 L
.5624 .57273 L
.56645 .55948 L
.56951 .54562 L
.57088 .5373 L
.57191 .52929 L
.57273 .52078 L
.57323 .51298 L
.57352 .5045 L
.57356 .50032 L
.57352 .49582 L
.57328 .48843 L
.57287 .48204 L
.57218 .47513 L
.57134 .46913 L
.5704 .46407 L
.56941 .45987 L
.56812 .45551 L
.56682 .4521 L
.56532 .44904 L
.56361 .4465 L
.56196 .44483 L
.56036 .44383 L
.55848 .44336 L
.55673 .44356 L
.55572 .44393 L
.55482 .44442 L
.55379 .44517 L
.55284 .44603 L
Mistroke
.55109 .44806 L
.54932 .45073 L
.54641 .45665 L
.54374 .4643 L
.54247 .46909 L
.54145 .47375 L
.54068 .47809 L
.54001 .48279 L
.53957 .48684 L
.53921 .49131 L
.53908 .4938 L
.539 .49607 L
.53895 .49855 L
.53895 .50113 L
.53905 .5054 L
.53917 .50776 L
.53932 .50992 L
.53971 .51399 L
.54021 .51764 L
.54074 .52075 L
.54141 .52391 L
.54226 .52707 L
.54325 .53008 L
.54427 .53253 L
.54527 .53444 L
.54629 .53597 L
.54729 .53711 L
.54837 .53798 L
.54957 .5385 L
.55063 .53858 L
.55175 .53827 L
.55279 .53759 L
.55371 .53666 L
.55486 .53499 L
.55586 .533 L
.55688 .53031 L
.55785 .52693 L
.5586 .52352 L
.5592 .51998 L
.55974 .51573 L
.56017 .51078 L
.56043 .50565 L
.56051 .50259 L
.56052 .49965 L
.56041 .49351 L
.56025 .48997 L
.56005 .48667 L
.55955 .48072 L
.5588 .47413 L
.55686 .46209 L
Mistroke
.55532 .45482 L
.55368 .44834 L
.54925 .43442 L
.54424 .42239 L
.53877 .41182 L
.5126 .37617 L
.49417 .35607 L
.48415 .34608 L
.47443 .33732 L
.46513 .33023 L
.46007 .3271 L
.45461 .32444 L
.44872 .32259 L
.44322 .32203 L
.43808 .32272 L
.43245 .32512 L
.42954 .32715 L
.42651 .32992 L
.42125 .33662 L
.41842 .3414 L
.41586 .34654 L
.41042 .36082 L
.40613 .37637 L
.40271 .39286 L
.40104 .40291 L
.39941 .41449 L
.39701 .43708 L
.39533 .46212 L
.39453 .48652 L
.39441 .50069 L
.39453 .51362 L
.39493 .52841 L
.39556 .5422 L
.3964 .55516 L
.39754 .56847 L
.40017 .5909 L
.40214 .60349 L
.40422 .61446 L
.40862 .6325 L
.41298 .64566 L
.41799 .65675 L
.42253 .66406 L
.42771 .66994 L
.43345 .67404 L
.43672 .67543 L
.43972 .6762 L
.44556 .67649 L
.45108 .67554 L
.45558 .67404 L
.46038 .67187 L
Mistroke
.46887 .66686 L
.48717 .65322 L
.5195 .6276 L
.53242 .61705 L
.53898 .61089 L
.54474 .60456 L
.55404 .59115 L
.55839 .58263 L
.56254 .57233 L
Mfstroke
0 g
gsave
.72727 .52727 -73.7813 -11.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 14.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.400 setrgbcolor
0.000 0.000 rmoveto
63.000 14.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.400 setrgbcolor
(0.4) show
84.563 14.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.400 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .4 1 r
.52179 .62676 m
.52925 .63394 L
.53351 .6374 L
.53764 .64018 L
.54154 .64222 L
.54584 .64367 L
.54977 .64415 L
.5534 .64375 L
.55767 .64207 L
.5616 .63914 L
.5658 .63422 L
.57011 .62677 L
.57216 .62215 L
.57431 .61642 L
.57793 .60408 L
.58103 .58979 L
.58347 .57464 L
.58556 .55668 L
.58647 .54591 L
.58714 .53566 L
.58793 .51621 L
.58811 .49528 L
.58771 .47663 L
.58686 .45971 L
.58541 .44207 L
.58331 .42463 L
.5805 .40809 L
.57687 .39282 L
.57297 .38113 L
.56904 .37269 L
.56531 .36696 L
.56103 .36254 L
.55645 .35983 L
.55209 .35884 L
.54751 .35917 L
.54327 .3605 L
.53869 .36287 L
.53389 .3662 L
.51655 .38315 L
.49145 .41213 L
.47105 .43372 L
.46241 .44349 L
.45828 .44913 L
.45482 .4548 L
.45185 .46079 L
.44952 .46664 L
.44738 .47348 L
.4464 .47738 L
.44563 .48102 L
.44462 .48725 L
Mistroke
.44424 .49045 L
.44409 .49205 L
.44396 .49374 L
.44386 .49532 L
.4438 .49673 L
.44373 .49939 L
.44375 .50166 L
.44384 .50388 L
.444 .50597 L
.44419 .50767 L
.44448 .5094 L
.4448 .51079 L
.44514 .51187 L
.44547 .51267 L
.44586 .51335 L
.44629 .51385 L
.44674 .51412 L
.44699 .51418 L
.44722 .51417 L
.44764 .51403 L
.44808 .5137 L
.44831 .51345 L
.44855 .51314 L
.44897 .51246 L
.44943 .51148 L
.44981 .51047 L
.45037 .50857 L
.45086 .50634 L
.45105 .50523 L
.45121 .50408 L
.45132 .50313 L
.45141 .50218 L
.45146 .50134 L
.45149 .50067 L
.4515 .50014 L
.4515 .4997 L
.45149 .49943 L
.45147 .49929 L
.45145 .49927 L
.45143 .49941 L
.45142 .49976 L
.45142 .50028 L
.45143 .50066 L
.45144 .50106 L
.45146 .50159 L
.4515 .50215 L
.4516 .50345 L
.45173 .50486 L
.45223 .50874 L
.45284 .51246 L
Mistroke
.45379 .51709 L
.45671 .52779 L
.46117 .53971 L
.4669 .55151 L
.4818 .57514 L
.505 .60636 L
.52139 .62575 L
.53041 .6344 L
.53454 .63764 L
.53918 .64057 L
.54371 .64258 L
.54799 .64357 L
.55252 .64347 L
.55505 .64281 L
.55734 .64179 L
.55982 .64018 L
.56208 .63821 L
.56453 .63546 L
.56706 .63185 L
.57113 .62407 L
.5753 .61288 L
.57862 .60065 L
.58131 .5876 L
.5838 .57138 L
.58584 .55249 L
.5871 .53479 L
.5878 .51766 L
.58804 .49852 L
.58767 .47816 L
.58667 .4583 L
.5852 .44098 L
.58303 .42349 L
.58017 .40707 L
.57726 .39477 L
.57424 .38501 L
.57064 .37624 L
.56652 .36903 L
.5627 .36442 L
.55842 .36115 L
.55431 .35954 L
.55047 .35917 L
.54667 .3597 L
.54325 .36084 L
.53934 .36281 L
.53573 .36516 L
.52047 .37913 L
.50581 .39579 L
.48212 .42228 L
.46548 .4396 L
.45879 .44803 L
Mistroke
.45355 .45673 L
.45108 .46201 L
.44883 .46797 L
.44696 .47424 L
.44538 .4813 L
.44445 .48712 L
.44407 .4903 L
.44382 .49313 L
.44367 .49566 L
.44357 .4983 L
.44356 .50065 L
.4436 .50271 L
.44373 .50506 L
.44384 .50628 L
.44396 .50734 L
.44422 .5091 L
.44456 .5107 L
.4449 .51191 L
.44525 .51283 L
.44566 .51362 L
.44612 .51422 L
.44639 .51444 L
.44663 .51457 L
.4469 .51465 L
.4472 .51465 L
.44768 .51447 L
.44795 .51428 L
.4482 .51404 L
.44866 .51347 L
.44905 .5128 L
.44949 .51189 L
.44986 .51092 L
.45049 .50884 L
.45094 .50684 L
.4513 .50471 L
.45144 .50358 L
.45154 .50262 L
.4516 .50191 L
.45164 .50122 L
.45167 .50058 L
.45168 .50009 L
.45167 .49969 L
.45166 .49945 L
.45164 .49938 L
.45163 .49945 L
.45162 .49957 L
.45161 .49975 L
.45161 .49999 L
.45161 .50026 L
.45163 .50092 L
Mistroke
.45167 .50181 L
.45171 .50236 L
.45176 .503 L
.45187 .50432 L
.45232 .50803 L
.45301 .51226 L
.45395 .51688 L
.45657 .52674 L
.46031 .53724 L
.4659 .54936 L
.48216 .57563 L
.5025 .60328 L
.51643 .62043 L
.524 .62862 L
.53127 .63531 L
.53518 .63828 L
.5395 .64094 L
.54414 .64293 L
.54857 .64384 L
.5509 .64387 L
.55346 .6435 L
.55612 .64261 L
.55858 .64128 L
.56292 .63758 L
.56742 .63152 L
.57129 .62398 L
.57521 .61345 L
.57856 .60124 L
.5813 .58804 L
.58341 .57474 L
.58532 .55863 L
.58681 .54053 L
.5877 .52266 L
.58809 .50246 L
.58803 .49097 L
.58779 .48034 L
.5868 .4594 L
.58594 .44817 L
.58498 .43837 L
.58288 .42198 L
.58006 .40617 L
.57696 .39334 L
.57377 .3834 L
.56978 .37421 L
.5658 .36773 L
.56344 .36489 L
.56124 .36281 L
.55866 .361 L
.55619 .35982 L
.5538 .35914 L
Mistroke
.55124 .35887 L
.54663 .35941 L
.54383 .3603 L
.54121 .36147 L
.53638 .36436 L
.52826 .37095 L
.52108 .37808 L
.50631 .39471 L
.4824 .42134 L
.46658 .43771 L
.45967 .44617 L
.4535 .45626 L
.45082 .46213 L
.44832 .46905 L
.44649 .47564 L
.44518 .48193 L
.44467 .48505 L
.44424 .48828 L
.44395 .49098 L
.44372 .49385 L
.44357 .49682 L
.44353 .49842 L
.44351 .49982 L
.44355 .50241 L
.44366 .50467 L
.44381 .50651 L
.44403 .50834 L
.44432 .51003 L
.44464 .51139 L
.44496 .51246 L
.44529 .51328 L
.44568 .51403 L
.44607 .51455 L
.44651 .51492 L
.44698 .51508 L
.44743 .51503 L
.44783 .51484 L
.4483 .51443 L
.44855 .51413 L
.44878 .5138 L
.44959 .51222 L
.44997 .51123 L
.4503 .51021 L
.45082 .50815 L
.45126 .50587 L
.45144 .50461 L
.45157 .50349 L
.45165 .50265 L
.45171 .5018 L
.45175 .50096 L
Mistroke
.45177 .50027 L
.45177 .49962 L
.45175 .49915 L
.45172 .49885 L
.45168 .49867 L
.45166 .49864 L
.45163 .49867 L
.45159 .49888 L
.45156 .49931 L
.45155 .49989 L
.45156 .50072 L
.45158 .50129 L
.4516 .50189 L
.45169 .50327 L
.45185 .50501 L
.45231 .50884 L
.45302 .51316 L
.45517 .52269 L
.45841 .53306 L
.46345 .54516 L
.47855 .57099 L
.49766 .59741 L
.51082 .61417 L
.52498 .62992 L
.53289 .63689 L
.53748 .64007 L
.54174 .64229 L
.54647 .6438 L
.54916 .64414 L
.55164 .64406 L
.55618 .64284 L
.56092 .63977 L
.56477 .63565 L
.56875 .62947 L
.57231 .62184 L
.57536 .6133 L
.57861 .60138 L
.58171 .5861 L
.58414 .56965 L
.58592 .5529 L
.58734 .5322 L
.58783 .52009 L
.58808 .5088 L
.58803 .48793 L
.58726 .46632 L
.58596 .4478 L
.58426 .43166 L
.5819 .41555 L
.57885 .40043 L
.5751 .38695 L
Mistroke
.57278 .38058 L
.57054 .37549 L
.5662 .36806 L
.56392 .3652 L
.56136 .36271 L
.55686 .3599 L
.5543 .35906 L
.55194 .35872 L
.54759 .35902 L
.54305 .36045 L
.53869 .36271 L
.53405 .3659 L
.52597 .37298 L
.51212 .38789 L
.48695 .41657 L
.46913 .43511 L
.46195 .4434 L
.45628 .45159 L
.45121 .46158 L
.44894 .4676 L
.44715 .47359 L
.44563 .48022 L
.44461 .48633 L
.44419 .48977 L
.44391 .49279 L
.4438 .49441 L
.44371 .49613 L
.44366 .49769 L
.44363 .49909 L
.44364 .50159 L
.44373 .50406 L
.4439 .50619 L
.4441 .50793 L
.4444 .50973 L
.44459 .51062 L
.44478 .51137 L
.44517 .51255 L
.4454 .51309 L
.44561 .51352 L
.44606 .51418 L
.44632 .51443 L
.44657 .5146 L
.44701 .51475 L
.4475 .51468 L
.44778 .51455 L
.44803 .51436 L
.44831 .51408 L
.44857 .51376 L
.44902 .51305 L
.44947 .51212 L
Mistroke
.45015 .51025 L
.45074 .50798 L
.45116 .50575 L
.45142 .50379 L
.45153 .50267 L
.4516 .50173 L
.45163 .50127 L
.45164 .5008 L
.45166 .50035 L
.45166 .49997 L
.45165 .49939 L
.45162 .499 L
.45159 .49873 L
.45156 .49867 L
.45154 .49866 L
.45152 .4987 L
.45149 .49881 L
.45147 .49898 L
.45146 .4992 L
.45144 .49975 L
.45145 .50054 L
.45146 .50103 L
.45148 .50163 L
.45156 .50287 L
.4517 .50463 L
.4519 .50648 L
.45243 .5103 L
.45331 .51516 L
.45585 .52543 L
.46012 .53771 L
.4657 .54978 L
.48036 .57359 L
.50336 .60471 L
.5196 .62419 L
.52852 .6331 L
.53259 .63651 L
.53713 .6397 L
.54157 .64207 L
.54573 .64349 L
.54973 .644 L
.55398 .64346 L
.5584 .64149 L
.56247 .63814 L
.56679 .63261 L
.56913 .62857 L
.5712 .62426 L
.57506 .614 L
.57832 .60235 L
.58145 .58729 L
.5842 .5688 L
Mistroke
.58534 .55863 L
.58635 .54709 L
.58711 .53579 L
.58762 .5251 L
.58809 .50442 L
.58787 .48248 L
.58708 .46382 L
.5859 .44752 L
.58401 .42997 L
.58174 .41488 L
.57928 .4025 L
.57672 .39244 L
.57364 .38302 L
.57011 .37484 L
.56639 .36852 L
.56219 .36363 L
.55811 .36069 L
.55431 .35926 L
.55007 .35891 L
.54544 .35977 L
.54312 .36063 L
.54065 .3618 L
.53628 .3645 L
.5276 .37167 L
.51896 .38048 L
.50504 .39641 L
.48002 .42425 L
.46351 .44183 L
.45956 .44695 L
.45614 .45214 L
.45336 .45721 L
.45074 .46299 L
.44854 .46907 L
.44689 .47481 L
.44558 .48068 L
.44466 .48617 L
.44427 .48923 L
.44397 .49237 L
.44379 .49496 L
.44367 .49767 L
.44364 .49914 L
.44364 .50043 L
.44366 .50186 L
.4437 .50316 L
.44384 .50531 L
.44394 .50644 L
.44405 .50741 L
.44427 .50888 L
.44455 .51028 L
.44484 .51142 L
Mistroke
.44514 .5123 L
.44549 .5131 L
.44589 .51377 L
.44634 .51424 L
.44676 .51448 L
.44721 .51452 L
.44764 .51438 L
.44802 .51411 L
.44842 .51369 L
.44884 .51308 L
.44926 .51228 L
.44994 .51056 L
.45055 .50841 L
.451 .50625 L
.45129 .50436 L
.45141 .50335 L
.45149 .50247 L
.45153 .50201 L
.45156 .50154 L
.4516 .50077 L
.45161 .50015 L
.45161 .49969 L
.45159 .49934 L
.45158 .49921 L
.45157 .49913 L
.45154 .49912 L
.45152 .4992 L
.45151 .49933 L
.45149 .49968 L
.45149 .50024 L
.45151 .50086 L
.45154 .5017 L
.45161 .50278 L
.45173 .50415 L
.45206 .50715 L
.45261 .5108 L
.45334 .51477 L
.45539 .52331 L
.45908 .53458 L
.46371 .54536 L
.47878 .57091 L
.49779 .5972 L
.5109 .61391 L
.52506 .62967 L
.53287 .63656 L
.53741 .63972 L
.54164 .64195 L
.54632 .64348 L
.54899 .64383 L
.55145 .64379 L
Mistroke
.55597 .64263 L
.56069 .63967 L
.5645 .63568 L
.56847 .62965 L
.57202 .62221 L
.57507 .61382 L
.57818 .60276 L
.58118 .58858 L
.58381 .57166 L
.58573 .55422 L
.58719 .53383 L
.58771 .52187 L
.58799 .51067 L
.588 .48995 L
.5873 .46836 L
.58607 .44987 L
.58443 .43366 L
.58213 .41742 L
.57914 .40207 L
.57546 .38842 L
.57318 .38193 L
.57095 .37669 L
.56666 .36903 L
.56416 .36577 L
.56184 .36343 L
.55737 .36042 L
.55482 .35948 L
.55246 .35905 L
.54811 .35921 L
.54355 .36053 L
.53924 .36267 L
.53464 .36575 L
.52659 .37268 L
.51277 .38746 L
.48758 .41622 L
.46973 .43472 L
.46251 .44287 L
.45677 .4509 L
.45165 .46058 L
.44943 .46616 L
.44746 .47232 L
.44587 .47885 L
.44476 .48493 L
.4443 .48837 L
.44398 .49141 L
.44384 .49306 L
.44372 .4948 L
.44365 .4964 L
.4436 .49783 L
.44357 .50038 L
Mistroke
.44363 .50293 L
.44375 .50514 L
.44393 .50697 L
.44419 .50888 L
.44437 .50985 L
.44455 .51067 L
.44491 .51197 L
.44513 .51258 L
.44534 .51307 L
.44578 .51386 L
.44602 .51417 L
.44627 .51443 L
.44671 .51469 L
.4472 .51475 L
.44748 .51468 L
.44773 .51456 L
.44802 .51434 L
.44828 .51408 L
.44875 .51347 L
.44922 .51263 L
.44992 .5109 L
.45056 .50874 L
.45102 .50657 L
.45133 .50462 L
.45147 .5035 L
.45156 .50253 L
.45163 .50156 L
.45166 .50108 L
.45167 .50068 L
.45168 .50004 L
.45168 .49974 L
.45168 .49951 L
.45166 .49921 L
.45163 .49905 L
.4516 .49909 L
.45157 .4993 L
.45156 .49949 L
.45155 .49976 L
.45156 .50043 L
.45158 .50125 L
.45164 .50233 L
.45172 .50342 L
.45185 .5048 L
.45231 .50852 L
.45312 .51341 L
.45564 .52407 L
.45938 .5353 L
.46417 .54629 L
.47996 .57273 L
.50271 .60373 L
Mistroke
.51911 .62357 L
.52721 .63184 L
.53171 .63576 L
.53668 .63937 L
.53913 .64082 L
.54149 .64199 L
.54595 .64351 L
.55016 .64397 L
.55475 .6432 L
.55728 .64212 L
.55954 .64069 L
.56212 .63847 L
.56451 .6358 L
.56863 .62949 L
.57282 .62035 L
.57674 .60841 L
.58051 .59231 L
.58217 .58306 L
.58374 .57238 L
.58492 .56257 L
.58601 .55137 L
.58687 .53974 L
.58747 .52867 L
.58786 .51788 L
.58807 .50629 L
.58796 .4862 L
.58762 .47491 L
.58712 .46453 L
.58578 .4462 L
.5837 .42766 L
.58243 .41902 L
.58092 .41041 L
.57784 .39657 L
.57436 .38498 L
.57076 .37615 L
.56734 .36992 L
.56346 .36487 L
.55906 .36121 L
.55652 .35992 L
.55413 .35918 L
.5516 .35885 L
.54929 .35892 L
.54662 .35939 L
.54411 .36017 L
.53971 .36226 L
.53571 .36483 L
.52696 .37218 L
.47974 .42422 L
.47031 .43389 L
.46172 .44367 L
Mistroke
.45551 .45282 L
.4525 .45857 L
.45006 .46432 L
.44797 .47048 L
.44637 .47651 L
.44524 .48199 L
.44435 .48786 L
.44403 .49082 L
.44377 .49398 L
.44368 .49551 L
.44362 .49712 L
.44357 .4999 L
.44361 .50247 L
.44372 .50472 L
.44388 .50657 L
.44411 .50838 L
.44426 .50932 L
.44444 .51025 L
.44482 .51172 L
.44522 .51288 L
.44563 .5137 L
.44609 .51434 L
.44636 .51459 L
.44661 .51475 L
.44689 .51484 L
.44714 .51486 L
.44742 .51481 L
.4477 .5147 L
.44814 .51436 L
.44861 .51381 L
.44898 .51322 L
.44938 .51244 L
.44977 .51148 L
.45016 .51034 L
.45076 .50808 L
.45118 .50585 L
.45136 .50463 L
.45149 .50357 L
.45158 .50263 L
.45165 .5017 L
.45169 .50091 L
.4517 .50027 L
.4517 .49966 L
.45168 .49922 L
.45165 .49891 L
.45163 .49881 L
.45161 .49878 L
.45157 .49886 L
.45155 .49901 L
.45153 .4992 L
Mistroke
.45152 .49972 L
.45151 .50011 L
.45152 .50051 L
.45153 .50096 L
.45155 .50151 L
.45159 .50215 L
.45163 .50281 L
.4519 .50575 L
.45214 .50775 L
.45243 .50977 L
.45334 .51491 L
.45605 .5258 L
.46003 .53726 L
.46505 .54835 L
.47211 .56092 L
.49162 .58921 L
.50289 .60409 L
.51704 .62136 L
.52466 .62949 L
.53235 .63636 L
.5358 .63888 L
.53955 .64113 L
.54372 .64295 L
.54764 .64389 L
.55218 .64388 L
.55476 .64327 L
.55715 .64225 L
.55965 .64068 L
.5619 .63876 L
.56446 .63593 L
.56683 .6326 L
.57085 .6251 L
.57434 .61624 L
.57784 .60435 L
.58111 .58927 L
.58381 .57202 L
.58506 .56143 L
.58603 .55124 L
.58735 .53151 L
.58804 .50985 L
.58811 .49819 L
.58796 .48577 L
.5876 .47419 L
.5871 .46387 L
.58629 .45207 L
.58517 .43982 L
.58398 .42965 L
.5825 .41939 L
.57969 .40426 L
.57664 .39209 L
Mistroke
.57259 .38024 L
.56856 .37188 L
.56629 .36831 L
.56413 .36556 L
.56172 .36313 L
.5591 .36119 L
.55658 .3599 L
.55419 .35915 L
.5497 .35885 L
.54547 .35967 L
.54106 .3615 L
.53734 .36368 L
.53334 .36658 L
.51724 .38224 L
.4893 .41419 L
.46964 .4347 L
.46264 .44265 L
.45623 .45176 L
.45335 .457 L
.45056 .46321 L
.44857 .46877 L
.44677 .4751 L
.4454 .48139 L
.44486 .48458 L
.44439 .48793 L
.44405 .49101 L
.44383 .49372 L
.44369 .49634 L
.44362 .4987 L
.44362 .5013 L
.44365 .50254 L
.44371 .50385 L
.44387 .50599 L
.44407 .50779 L
.44422 .50879 L
.44437 .50966 L
.4447 .51111 L
.44511 .51239 L
.44535 .51299 L
.44559 .51347 L
.44597 .51404 L
.44639 .51446 L
.44679 .51467 L
.44717 .51471 L
.44759 .5146 L
.44804 .5143 L
.44849 .5138 L
.4489 .51319 L
.44931 .5124 L
.44968 .51155 L
Mistroke
.45028 .50972 L
.45081 .50756 L
.45124 .50516 L
.45138 .5041 L
.4515 .50299 L
.45158 .50203 L
.45162 .50122 L
.45164 .50077 L
.45165 .5004 L
.45166 .50002 L
.45165 .4997 L
.45164 .49926 L
.45161 .49896 L
.45157 .49885 L
.45154 .49891 L
.45152 .49902 L
.4515 .49919 L
.45149 .49965 L
.45148 .5003 L
.4515 .50111 L
.45155 .50198 L
.45162 .50309 L
.45173 .50443 L
.45191 .5061 L
.45246 .5101 L
.45323 .51445 L
.45422 .51899 L
.45755 .53055 L
.46297 .54403 L
.47657 .56784 L
.49856 .59838 L
.51301 .61659 L
.522 .6267 L
.53115 .63532 L
.53549 .63859 L
.54017 .64137 L
.54266 .64248 L
.5454 .64337 L
.54792 .64385 L
.55027 .64396 L
.55473 .6432 L
.55877 .64122 L
.56333 .63719 L
.56751 .63143 L
.57157 .6234 L
.57563 .61218 L
.57906 .59915 L
.58181 .58516 L
.58392 .57095 L
.58578 .55394 L
Mistroke
.58715 .53491 L
.58789 .51638 L
.58807 .50577 L
.58807 .49421 L
.58755 .47344 L
.58642 .45396 L
.58485 .43703 L
.58262 .42028 L
.5796 .40401 L
.57591 .38973 L
.57202 .37897 L
.56842 .37172 L
.56428 .36582 L
.56022 .36202 L
.55637 .3599 L
.55253 .35897 L
.54903 .359 L
.545 .35991 L
.54123 .3615 L
.53718 .36388 L
.53298 .36696 L
.52572 .37345 L
.51077 .38969 L
.48604 .41783 L
.46822 .43635 L
.4618 .4438 L
.45589 .4524 L
.45322 .45732 L
.45061 .46315 L
.44869 .46844 L
.44699 .47424 L
.44554 .48066 L
.44458 .48651 L
.44419 .48969 L
.44391 .49258 L
.44372 .49562 L
.44365 .49726 L
.44362 .4987 L
.44361 .50119 L
.44368 .50333 L
.44382 .50549 L
.44403 .50754 L
.44427 .50912 L
.44454 .51043 L
.44486 .51165 L
.44525 .51274 L
.44547 .51322 L
.44572 .51365 L
.44618 .51424 L
.44646 .51447 L
Mistroke
.44674 .51461 L
.44699 .51466 L
.44726 .51465 L
.4475 .51459 L
.44776 .51445 L
.44803 .51425 L
.44827 .514 L
.4487 .51344 L
.44914 .51268 L
.44954 .5118 L
.44995 .51073 L
.45057 .50855 L
.45104 .5063 L
.45134 .50427 L
.45146 .50328 L
.45155 .50232 L
.4516 .50156 L
.45163 .50083 L
.45165 .50016 L
.45165 .49984 L
.45164 .49959 L
.45163 .49923 L
.4516 .49904 L
.45157 .499 L
.45154 .49912 L
.45152 .49935 L
.45151 .49974 L
.45151 .50034 L
.45153 .50117 L
.45158 .50215 L
.45166 .50319 L
.45178 .50461 L
.45197 .50633 L
.45247 .50994 L
.45339 .51499 L
.45456 .52016 L
.45794 .5315 L
.46254 .54294 L
.47625 .56723 L
.49773 .59721 L
.50906 .61173 L
.52296 .62765 L
.53176 .63576 L
.53609 .63895 L
.54018 .64133 L
.54434 .64303 L
.5489 .6439 L
.55292 .64364 L
.55717 .64214 L
.56148 .63904 L
Mistroke
.56605 .63366 L
.57017 .62644 L
.57376 .61778 L
.57703 .60729 L
.57971 .59614 L
.58242 .58143 L
.58453 .56595 L
.58631 .54747 L
.58754 .52667 L
.58804 .5083 L
.58798 .48797 L
.58722 .46649 L
.58648 .45487 L
.58562 .44465 L
.58347 .42606 L
.58089 .41033 L
.57834 .39859 L
.57518 .38747 L
.57156 .37794 L
.56793 .37092 L
.56438 .36596 L
.56103 .36266 L
.55728 .3603 L
.55327 .35908 L
.54917 .35899 L
.54481 .35998 L
.54074 .36176 L
.53709 .36394 L
.52843 .37087 L
.52072 .37856 L
.47669 .42748 L
.46801 .43649 L
.45995 .44616 L
.45654 .45123 L
.45362 .45641 L
.44909 .46713 L
.44727 .47307 L
.44573 .47955 L
.44514 .48271 L
.44467 .48566 L
.44432 .48825 L
.44402 .49103 L
.44378 .49402 L
.44369 .49561 L
.44363 .49705 L
.44358 .49952 L
.44361 .50201 L
.44365 .50332 L
.44373 .50468 L
.44383 .5059 L
Mistroke
.44393 .50695 L
.44418 .50878 L
.44451 .51045 L
.44488 .51183 L
.44525 .51285 L
.44569 .51372 L
.44593 .51406 L
.44619 .51435 L
.44663 .51466 L
.44712 .51476 L
.44758 .51465 L
.44799 .51438 L
.44824 .51414 L
.4485 .51384 L
.44895 .51315 L
.4494 .51225 L
.44986 .51109 L
.45056 .50873 L
.45106 .50636 L
.45125 .50522 L
.4514 .50405 L
.45151 .50309 L
.45159 .50213 L
.45162 .50163 L
.45165 .50121 L
.45167 .50046 L
.45168 .50012 L
.45168 .49979 L
.45167 .49949 L
.45166 .49928 L
.45163 .49901 L
.4516 .49894 L
.45157 .49902 L
.45154 .49927 L
.45153 .49975 L
.45153 .50007 L
.45153 .50049 L
.45156 .5014 L
.45162 .50243 L
.4517 .50359 L
.45184 .50505 L
.45222 .50816 L
.45278 .51174 L
.45349 .51546 L
.45587 .52504 L
.45974 .53637 L
.46558 .54922 L
.47252 .56144 L
.49416 .59252 L
.50719 .60947 L
Mistroke
.5214 .62606 L
.52997 .63433 L
.53388 .63745 L
.53822 .64032 L
.54072 .64165 L
.54306 .64265 L
.5477 .64383 L
.55007 .64398 L
.55269 .64374 L
.55541 .64298 L
.55794 .64176 L
.56214 .63846 L
.5665 .63305 L
.57041 .62598 L
.57376 .61782 L
.57739 .60603 L
.58084 .59063 L
.58356 .57376 L
.58555 .55648 L
.58703 .5372 L
.58785 .51831 L
.5881 .49714 L
.58794 .48528 L
.5876 .47457 L
.58641 .45374 L
.58543 .44255 L
.58434 .43265 L
.58192 .41591 L
.57878 .40036 L
.5754 .38808 L
.57197 .37883 L
.56794 .37088 L
.56582 .36772 L
.56344 .36486 L
.55934 .36138 L
.55486 .35936 L
.55059 .35885 L
.5467 .35938 L
.54269 .36076 L
.53903 .36267 L
.53097 .36857 L
.51739 .38211 L
.49186 .41138 L
.4712 .43305 L
.4631 .44205 L
.45651 .45124 L
.45162 .4606 L
.44933 .46641 L
.44754 .47206 L
.44604 .4781 L
Mistroke
.44539 .4813 L
.44482 .48467 L
.44441 .48757 L
.44406 .4907 L
.44383 .49345 L
.44368 .49593 L
.4436 .49842 L
.44359 .50065 L
.44363 .50254 L
.44372 .50446 L
.44388 .50639 L
.4441 .50822 L
.44434 .50962 L
.44464 .51097 L
.445 .51219 L
.44542 .51322 L
.4458 .51389 L
.44624 .51441 L
.44672 .51471 L
.447 .51478 L
.44725 .51477 L
.44773 .51459 L
.44818 .51423 L
.44859 .51374 L
.449 .51308 L
.44969 .51159 L
.45032 .50967 L
.45088 .50734 L
.45128 .50506 L
.45143 .50382 L
.45154 .50274 L
.45162 .5018 L
.45166 .50102 L
.45168 .50026 L
.45168 .49967 L
.45166 .49927 L
.45163 .49898 L
.45161 .49887 L
.45157 .49888 L
.45154 .49906 L
.45152 .49946 L
.45151 .50003 L
.45152 .50071 L
.45156 .50172 L
.45159 .5023 L
.45164 .50302 L
.45192 .50594 L
.45216 .5079 L
.45251 .51024 L
.45337 .51503 L
Mistroke
.45612 .526 L
.46002 .53717 L
.4652 .54857 L
.47227 .56112 L
.48928 .58596 L
.50275 .60385 L
.51791 .62229 L
.52529 .63006 L
.53358 .63725 L
.53807 .64025 L
.54048 .64155 L
.5431 .64268 L
.54773 .64385 L
.55208 .64385 L
.5565 .64253 L
.559 .6411 L
.56132 .63926 L
.56587 .63399 L
.56834 .63004 L
.57053 .62574 L
.57404 .61705 L
.57756 .60536 L
.58081 .59079 L
.58336 .57519 L
.5846 .56549 L
.58574 .5544 L
.58662 .54347 L
.58726 .53305 L
.58798 .51275 L
.58804 .49091 L
.58779 .47971 L
.5873 .46786 L
.58588 .4473 L
.58468 .43551 L
.58333 .42494 L
.58026 .40705 L
.57704 .39357 L
.57378 .38336 L
.57185 .37853 L
.56968 .37397 L
.56557 .36737 L
.56154 .36303 L
.55717 .36019 L
.55339 .35904 L
.54922 .35893 L
.5467 .35938 L
.54432 .36011 L
.5399 .36217 L
.53523 .36519 L
.53028 .36917 L
Mistroke
.51444 .38543 L
.47107 .43323 L
.46267 .44263 L
.45878 .44782 L
.4551 .4537 L
.45224 .4593 L
.44955 .46588 L
.44752 .47221 L
.44602 .47828 L
.44486 .48454 L
.44437 .48801 L
.44403 .49114 L
.44382 .49379 L
.44367 .49659 L
.4436 .49936 L
.44362 .50179 L
.44371 .50398 L
.44385 .5059 L
.44402 .50747 L
.44425 .50901 L
.44454 .51048 L
.44489 .5118 L
.44526 .51282 L
.44562 .51355 L
.44607 .51418 L
.44631 .51441 L
.44657 .51458 L
.44703 .51472 L
.44747 .51465 L
.44773 .51453 L
.44797 .51436 L
.44842 .51389 L
.44867 .51356 L
.44889 .51322 L
.44936 .5123 L
.45002 .51057 L
.45063 .50839 L
.45111 .506 L
.45127 .50493 L
.45141 .50383 L
.45152 .50278 L
.45159 .50191 L
.45163 .50111 L
.45166 .50045 L
.45166 .49982 L
.45165 .49937 L
.45162 .49904 L
.4516 .49895 L
.45158 .4989 L
.45156 .49891 L
Mistroke
.45155 .49898 L
.45152 .49924 L
.45151 .49948 L
.4515 .49975 L
.4515 .5001 L
.45151 .50055 L
.45154 .50144 L
.45159 .50246 L
.45169 .50377 L
.45185 .5054 L
.45225 .50855 L
.45291 .51262 L
.45509 .52235 L
.45829 .5326 L
.46238 .54269 L
.47725 .56882 L
.49817 .59784 L
.50975 .61264 L
.52384 .62858 L
.5319 .63592 L
.53667 .63937 L
.54124 .64188 L
.54548 .64339 L
.54939 .64396 L
.5539 .64345 L
.55815 .64161 L
.56259 .63799 L
.56503 .6351 L
.56723 .63188 L
.57111 .62445 L
.57493 .61439 L
.57805 .60341 L
.58066 .59152 L
.58313 .57676 L
.58527 .5592 L
.58692 .53886 L
.58754 .52684 L
.58791 .5155 L
.58807 .49446 L
.5879 .48388 L
.58751 .47235 L
.58636 .45313 L
.58447 .43379 L
.58213 .41724 L
.57956 .40379 L
.57678 .39267 L
.57349 .38264 L
.57015 .37493 L
.56696 .36936 L
.56304 .36446 L
Mistroke
.55865 .36099 L
.55444 .35929 L
.55053 .35888 L
.54648 .35946 L
.54273 .36078 L
.53866 .36293 L
.53437 .36586 L
.51869 .38073 L
.4729 .43138 L
.4641 .44093 L
.45984 .44635 L
.45621 .45181 L
.45319 .45732 L
.45035 .46375 L
.4482 .46992 L
.44656 .47589 L
.44531 .48183 L
.4448 .48487 L
.44436 .48811 L
.44415 .48992 L
.44399 .49157 L
.44386 .49309 L
.44376 .49472 L
.44363 .49746 L
.4436 .5002 L
.44361 .50162 L
.44365 .50291 L
.44378 .50518 L
.44389 .50635 L
.444 .50737 L
.44416 .50849 L
.44432 .50945 L
.44466 .511 L
.44501 .51217 L
.44542 .51317 L
.44567 .51363 L
.4459 .51397 L
.4463 .5144 L
.44674 .51465 L
.44715 .51471 L
.44753 .51462 L
.44797 .51435 L
.44844 .51386 L
.44886 .51325 L
.44924 .51256 L
.44991 .5109 L
.45053 .50877 L
.45104 .5064 L
.45121 .50533 L
.45137 .50422 L
Mistroke
.45149 .50316 L
.45157 .50226 L
.45162 .50143 L
.45165 .50074 L
.45166 .50006 L
.45166 .49956 L
.45164 .49918 L
.45162 .49905 L
.4516 .49897 L
.45158 .49894 L
.45157 .49897 L
.45154 .49917 L
.45152 .49936 L
.45152 .49959 L
.45151 .49991 L
.45151 .50031 L
.45152 .50072 L
.45154 .50122 L
.4516 .5023 L
.45169 .50354 L
.45181 .50486 L
.45217 .50785 L
.45266 .51113 L
.45451 .52002 L
.45743 .53003 L
.4619 .54154 L
.46836 .5544 L
.47591 .56675 L
.49909 .59904 L
.5129 .61644 L
.5279 .63248 L
.53611 .63899 L
.53842 .64042 L
.54088 .6417 L
.54531 .64334 L
.54769 .64381 L
.55024 .64396 L
.55481 .64317 L
.55759 .64193 L
.56019 .64019 L
.56248 .6381 L
.56493 .63524 L
.56908 .62862 L
.57267 .62071 L
.57649 .60926 L
.57973 .59612 L
.58231 .58213 L
.58433 .56771 L
.58607 .55052 L
.58735 .53101 L
Mistroke
.58801 .51078 L
.5881 .49925 L
.588 .48869 L
.58738 .46952 L
.58612 .45014 L
.5852 .44036 L
.58405 .43039 L
.58155 .41386 L
.57794 .39696 L
.57414 .38439 L
.57011 .37485 L
.56798 .37097 L
.56555 .36738 L
.56112 .36271 L
.55687 .36009 L
.55427 .35924 L
.55179 .3589 L
.54714 .3593 L
.54455 .36005 L
.54217 .36103 L
.53683 .36409 L
.52807 .37118 L
.52057 .37869 L
.50544 .39585 L
.48212 .42189 L
.47185 .43242 L
.46355 .44155 L
.45743 .44982 L
.45197 .45985 L
.44943 .46617 L
.44743 .47249 L
.44599 .47832 L
.44538 .4814 L
.44482 .48469 L
.44438 .48781 L
.44407 .49061 L
.44385 .49321 L
.44369 .49586 L
.4436 .49862 L
.44359 .50105 L
.44367 .50352 L
.44375 .50481 L
.44384 .50592 L
.44394 .50696 L
.44407 .50798 L
.44435 .50965 L
.4447 .51118 L
.44513 .51254 L
.44555 .51345 L
.44579 .51385 L
Mistroke
.44602 .51416 L
.44647 .51456 L
.44691 .51474 L
.44735 .51472 L
.44775 .51455 L
.4482 .51418 L
.4486 .51369 L
.44897 .51311 L
.44929 .51249 L
.44995 .51084 L
.45051 .50892 L
.451 .50667 L
.45119 .50554 L
.45136 .50436 L
.45148 .50332 L
.45157 .5024 L
.45163 .50152 L
.45165 .50109 L
.45166 .50066 L
.45167 .50026 L
.45167 .49992 L
.45166 .49941 L
.45164 .49909 L
.45161 .49893 L
.45158 .49893 L
.45154 .49914 L
.45153 .49935 L
.45152 .49961 L
.45151 .49997 L
.45152 .50042 L
.45153 .50088 L
.45155 .50137 L
.45158 .50197 L
.45162 .50268 L
.45175 .5042 L
.45192 .50586 L
.45241 .50953 L
.45312 .51368 L
.45418 .51865 L
.45696 .52863 L
.46132 .54026 L
.4679 .55359 L
.48495 .57993 L
.50711 .60937 L
.51448 .61833 L
.52299 .62773 L
.53144 .63556 L
.53576 .63878 L
.53982 .6412 L
.54447 .64312 L
Mistroke
.54694 .64371 L
.54956 .64398 L
.5538 .64349 L
.55843 .64146 L
.56103 .6395 L
.56337 .63716 L
.56601 .63376 L
.56846 .6298 L
.57259 .62094 L
.57671 .6085 L
.58016 .59407 L
.58286 .57866 L
.58523 .55965 L
.58617 .54939 L
.587 .5377 L
.58787 .51727 L
.58808 .5056 L
.58808 .49492 L
.5876 .47439 L
.58655 .45561 L
.58502 .43857 L
.58288 .42194 L
.58068 .40915 L
.57788 .39672 L
.57452 .38545 L
.57054 .3757 L
.56653 .36872 L
.56269 .3641 L
.5584 .36083 L
.55373 .35911 L
.5493 .35893 L
.54529 .35978 L
.54062 .36178 L
.53801 .3633 L
.53564 .3649 L
.52696 .37221 L
.49671 .40595 L
.47754 .42658 L
.46154 .44404 L
.45766 .44947 L
.45435 .45503 L
.45152 .46087 L
.44926 .46665 L
.44749 .47227 L
.44593 .47865 L
.44476 .48507 L
.4443 .48853 L
.44397 .49169 L
.44377 .49445 L
.44364 .49727 L
Mistroke
.44359 .4998 L
.44362 .50196 L
.44372 .50431 L
.44381 .50555 L
.44391 .50662 L
.44414 .50844 L
.44445 .51011 L
.44478 .51147 L
.44519 .51267 L
.4456 .51354 L
.446 .51413 L
.44625 .51439 L
.44649 .51457 L
.44675 .51469 L
.44703 .51475 L
.4473 .51473 L
.44755 .51465 L
.44801 .51435 L
.4484 .51395 L
.44881 .51338 L
.44922 .51264 L
.44958 .51184 L
.45015 .51021 L
.45067 .50826 L
.45091 .50713 L
.45114 .50589 L
.4513 .50483 L
.45144 .50373 L
.45153 .50281 L
.4516 .50186 L
.45165 .50109 L
.45167 .50045 L
.45167 .49986 L
.45166 .49938 L
.45163 .49906 L
.45161 .49891 L
.45157 .49891 L
.45155 .49899 L
.45154 .49912 L
.45151 .49951 L
.45151 .50012 L
.45152 .50091 L
.45157 .50197 L
.45165 .50318 L
.45176 .50445 L
.4522 .5082 L
.4529 .51253 L
.45487 .5215 L
.45771 .53092 L
.46203 .54191 L
Mistroke
.46811 .55399 L
.48574 .58105 L
.49805 .5977 L
.51368 .6174 L
.52119 .62585 L
.52978 .63417 L
.53495 .63822 L
.53977 .64118 L
.54213 .64228 L
.54471 .6432 L
.54943 .64397 L
.55368 .64352 L
.55832 .64153 L
.56062 .63985 L
.56306 .6375 L
.56736 .63169 L
.57121 .62424 L
.57498 .61424 L
.57793 .60391 L
.5808 .59079 L
.58358 .57357 L
.5856 .55591 L
.58643 .5461 L
.58715 .53497 L
.58769 .52304 L
.588 .51171 L
.58804 .49067 L
.58748 .47173 L
.58694 .46153 L
.58617 .45074 L
.58429 .43223 L
.58214 .41728 L
.57931 .40265 L
.57589 .38966 L
.57233 .37968 L
.56877 .37231 L
.56533 .36708 L
.56143 .36295 L
.55721 .36023 L
.55251 .35894 L
.54823 .35908 L
.54587 .35961 L
.54331 .36051 L
.53873 .36286 L
.53452 .36573 L
.53016 .36928 L
.52267 .37648 L
.4931 .41004 L
.47408 .43014 L
.46545 .43933 L
Mistroke
.45839 .44839 L
.45292 .45785 L
.45034 .46376 L
.4483 .46958 L
.44676 .47506 L
.4456 .4803 L
.44507 .4832 L
.44459 .48631 L
.44425 .48904 L
.44399 .49158 L
.44377 .4945 L
.44365 .49706 L
.4436 .49967 L
.4436 .50107 L
.44363 .50232 L
.44372 .50428 L
.44388 .50627 L
.4441 .50813 L
.44436 .50968 L
.4447 .51116 L
.44511 .51244 L
.44548 .5133 L
.44592 .51401 L
.44618 .5143 L
.44641 .5145 L
.44669 .51465 L
.44695 .51472 L
.44742 .51468 L
.44768 .51456 L
.44792 .5144 L
.44836 .51397 L
.44882 .51334 L
.44922 .5126 L
.44957 .51182 L
.45033 .50959 L
.45088 .50723 L
.4511 .50604 L
.4513 .50479 L
.45143 .50375 L
.45153 .5027 L
.45158 .50209 L
.45161 .50157 L
.45164 .50111 L
.45166 .50066 L
.45167 .49999 L
.45166 .49967 L
.45165 .49942 L
.45163 .49908 L
.45161 .49898 L
.45159 .49892 L
Mistroke
.45156 .49895 L
.45153 .49916 L
.45152 .49936 L
.45151 .49962 L
.45151 .50025 L
.45152 .50069 L
.45153 .50116 L
.45156 .50173 L
.4516 .50242 L
.4517 .50374 L
.45186 .5054 L
.45232 .50898 L
.453 .51311 L
.45388 .51737 L
.45627 .52646 L
.4601 .53733 L
.46553 .54917 L
.47196 .56056 L
.49175 .58928 L
.50451 .60607 L
.51837 .62276 L
.52552 .63025 L
.53261 .63648 L
.53659 .63932 L
.54031 .64144 L
.5445 .64312 L
.54906 .64395 L
.55332 .64359 L
.55727 .64212 L
.56153 .63904 L
.56595 .63384 L
.56811 .63041 L
.57038 .62605 L
.57427 .61635 L
.57774 .60467 L
.58057 .59196 L
.58325 .57592 L
.5853 .55897 L
.58668 .54258 L
.58766 .52381 L
.58809 .50287 L
.58804 .49112 L
.58781 .48055 L
.58687 .46044 L
.58542 .44251 L
.58358 .42681 L
.58118 .41182 L
.5788 .40047 L
.57588 .38964 L
.57243 .37993 L
Mistroke
.56844 .37174 L
.56446 .36602 L
.56072 .36238 L
.55618 .35981 L
.55387 .35915 L
.55131 .35887 L
.54679 .35938 L
.54258 .36084 L
.5402 .36203 L
.53771 .36351 L
.53334 .36664 L
.52393 .3752 L
.49619 .40657 L
.47489 .42932 L
.46638 .43829 L
.45956 .44671 L
.45427 .45521 L
.44973 .46537 L
.44785 .47107 L
.4464 .47656 L
.44516 .48265 L
.44463 .48601 L
.44424 .48907 L
.44395 .49203 L
.44373 .49507 L
.44362 .49797 L
.44359 .49955 L
.4436 .50098 L
.44367 .50339 L
.4438 .50542 L
.44401 .50744 L
.44413 .50837 L
.44429 .50932 L
.44461 .5108 L
.44493 .51194 L
.44534 .51301 L
.44576 .51378 L
.44616 .51429 L
.44654 .51458 L
.44697 .51473 L
.44742 .51468 L
.4479 .51442 L
.44833 .51401 L
.44856 .51372 L
.44881 .51336 L
.44924 .51257 L
.44998 .51071 L
.45056 .50871 L
.45085 .5074 L
.45109 .50616 L
Mistroke
.45141 .50392 L
.45153 .50275 L
.4516 .50178 L
.45163 .50131 L
.45165 .50084 L
.45166 .50039 L
.45167 .50002 L
.45166 .4995 L
.45165 .4993 L
.45164 .49912 L
.4516 .49894 L
.45157 .49894 L
.45155 .49901 L
.45154 .49914 L
.45152 .49953 L
.45151 .49984 L
.45151 .50018 L
.45152 .50062 L
.45154 .50116 L
.45159 .50223 L
.45164 .50293 L
.45169 .50363 L
.45202 .50677 L
.45252 .51025 L
.45328 .51449 L
.45548 .52373 L
.45858 .53335 L
.46322 .54446 L
.4697 .55676 L
.48773 .58378 L
.50026 .60058 L
.51627 .62039 L
.52526 .63 L
.52992 .63428 L
.53432 .63776 L
.53835 .64039 L
.54283 .64255 L
.5474 .64378 L
.55224 .6438 L
.55686 .64233 L
.56099 .63952 L
.56324 .6373 L
.56563 .63429 L
.56982 .62719 L
.57351 .6185 L
.5771 .60708 L
.57985 .59554 L
.5825 .581 L
.58486 .56313 L
.58651 .54502 L
Mistroke
.58766 .52393 L
.58799 .5118 L
.5881 .50071 L
.58781 .48043 L
.58679 .45913 L
.58519 .44016 L
.5832 .42408 L
.58085 .41006 L
.57832 .39847 L
.57522 .38754 L
.57157 .37792 L
.56746 .37013 L
.56337 .3648 L
.55958 .36156 L
.55537 .35953 L
.55075 .35887 L
.54641 .35947 L
.54395 .36027 L
.5417 .36125 L
.53669 .36418 L
.52754 .37167 L
.51851 .38091 L
.49214 .41112 L
.47313 .4311 L
.46456 .44035 L
.45761 .44954 L
.45225 .45926 L
.44975 .46531 L
.4478 .4712 L
.44635 .47675 L
.44527 .482 L
.44444 .48741 L
.44411 .49021 L
.44386 .49313 L
.44375 .49473 L
.44368 .4962 L
.4436 .49883 L
.44361 .5015 L
.44365 .50291 L
.44371 .50415 L
.44385 .50608 L
.44408 .508 L
.44437 .50975 L
.44469 .51115 L
.44489 .51184 L
.44512 .51251 L
.44534 .51302 L
.44557 .51349 L
.44604 .51417 L
.44649 .51456 L
Mistroke
.44674 .51468 L
.44701 .51474 L
.4475 .51467 L
.44778 .51452 L
.44808 .51429 L
.44833 .51404 L
.44859 .5137 L
.44905 .51295 L
.44946 .51211 L
.45014 .51023 L
.45074 .50794 L
.45099 .50672 L
.45122 .50539 L
.45136 .50434 L
.45148 .50327 L
.45158 .50222 L
.45163 .50133 L
.45166 .50057 L
.45167 .49996 L
.45166 .49952 L
.45164 .49917 L
.45163 .49903 L
.45161 .49894 L
.45158 .49892 L
.45156 .49898 L
.45154 .49909 L
.45153 .49927 L
.45152 .49954 L
.45151 .49982 L
.45151 .50019 L
.45153 .50103 L
.45158 .50204 L
.45165 .50316 L
.4519 .5057 L
.45234 .50913 L
.45305 .51333 L
.45397 .51777 L
.45711 .5291 L
.46137 .54038 L
.46806 .5539 L
.47623 .56728 L
.49589 .59483 L
.50976 .61266 L
.51746 .62176 L
.52507 .62982 L
.53256 .63645 L
.53667 .63937 L
.54116 .64185 L
.54574 .64346 L
.55004 .64398 L
Mistroke
.55258 .64375 L
.55497 .64313 L
.55941 .64079 L
.56315 .63741 L
.567 .63227 L
.57015 .62653 L
.57345 .61868 L
.57672 .60846 L
.57989 .59537 L
.58248 .58112 L
.58447 .5666 L
.58632 .54746 L
.58749 .52821 L
.58802 .51033 L
.58804 .49075 L
.58739 .46972 L
.58681 .45943 L
.58598 .44845 L
.58403 .4302 L
.58171 .41475 L
.57895 .40106 L
.57596 .3899 L
.57304 .38144 L
.56962 .37388 L
.56571 .36759 L
.56137 .3629 L
.55717 .36021 L
.55331 .35904 L
.54864 .35902 L
.54629 .3595 L
.54373 .36034 L
.53925 .36255 L
.53515 .36526 L
.52623 .37292 L
.5173 .38224 L
.49123 .41212 L
.47128 .43301 L
.46276 .4425 L
.45866 .44798 L
.4552 .45351 L
.45 .46464 L
.44783 .4711 L
.446 .47832 L
.44484 .48459 L
.4444 .48769 L
.44404 .49101 L
.44381 .49376 L
.44366 .49658 L
.4436 .49911 L
.4436 .50128 L
Mistroke
.44368 .50357 L
.44381 .50554 L
.44401 .50749 L
.4443 .50934 L
.44465 .51099 L
.44504 .51228 L
.44542 .51319 L
.44587 .51395 L
.44626 .51439 L
.44671 .51467 L
.44719 .51474 L
.44764 .5146 L
.44805 .51432 L
.44841 .51393 L
.4488 .51338 L
.44919 .51267 L
.44994 .51085 L
.4503 .50968 L
.4506 .50856 L
.45106 .5063 L
.45138 .50422 L
.4515 .50311 L
.45155 .50254 L
.45159 .50204 L
.45164 .50121 L
.45166 .50042 L
.45167 .50005 L
.45167 .49973 L
.45165 .49927 L
.45163 .49909 L
.45162 .49898 L
.4516 .49891 L
.45158 .49891 L
.45154 .49906 L
.45153 .49923 L
.45152 .49945 L
.45151 .49973 L
.45151 .50005 L
.45151 .50048 L
.45153 .50095 L
.45157 .50194 L
.45164 .50302 L
.45176 .5044 L
.45193 .50606 L
.45249 .51012 L
.45329 .51461 L
.45634 .52667 L
.46052 .53837 L
.46571 .54953 L
.4824 .57634 L
Mistroke
.50337 .60462 L
.5179 .62224 L
.52585 .63057 L
.53362 .63725 L
.53825 .64034 L
.54065 .64161 L
.54325 .64271 L
.54587 .64349 L
.54833 .6439 L
.55127 .64392 L
.55394 .64345 L
.55849 .64141 L
.56103 .6395 L
.56334 .63719 L
.56746 .63151 L
.57163 .62327 L
.57553 .61251 L
.57929 .59813 L
.58233 .58203 L
.58462 .5653 L
.58622 .5488 L
.58742 .52961 L
.58804 .50882 L
.58801 .48924 L
.58733 .46843 L
.58673 .45825 L
.58588 .44738 L
.58392 .42934 L
.58159 .41405 L
.57831 .39841 L
.57486 .38645 L
.5728 .38085 L
.57045 .37552 L
.56817 .37127 L
.56594 .3679 L
.56147 .36299 L
.5573 .36027 L
.55274 .35897 L
.55016 .35888 L
.54778 .35916 L
.54383 .36031 L
.53954 .36239 L
.53514 .36527 L
.53112 .36846 L
.48239 .42161 L
.47303 .43121 L
.46417 .44082 L
.45705 .45044 L
.45411 .45551 L
.45165 .4606 L
Mistroke
.44791 .47085 L
.44639 .4766 L
.44513 .48285 L
.44463 .48603 L
.44425 .48895 L
.44396 .49191 L
.44383 .49354 L
.44374 .49504 L
.44363 .49762 L
.44359 .49986 L
.44362 .50213 L
.44373 .5044 L
.4439 .50648 L
.44411 .50818 L
.44441 .50991 L
.44474 .51131 L
.44508 .51238 L
.44543 .51319 L
.44582 .51388 L
.44627 .51439 L
.44653 .51458 L
.44677 .51468 L
.44703 .51473 L
.44732 .51471 L
.44779 .51451 L
.44805 .5143 L
.44829 .51406 L
.44873 .51348 L
.44911 .51283 L
.44989 .51099 L
.45024 .50991 L
.45056 .50868 L
.45104 .50641 L
.4514 .50402 L
.45153 .50277 L
.45157 .50224 L
.45161 .5017 L
.45165 .50088 L
.45167 .50015 L
.45166 .49961 L
.45165 .49924 L
.45163 .49908 L
.45161 .49897 L
.45158 .49891 L
.45155 .49905 L
.45153 .49921 L
.45152 .49943 L
.45151 .49989 L
.45151 .50046 L
.45153 .50109 L
Mistroke
.45157 .50189 L
.45163 .5029 L
.45173 .50414 L
.45202 .50676 L
.45291 .51258 L
.4546 .52041 L
.45738 .52993 L
.46161 .54093 L
.47271 .56178 L
Mfstroke
0 g
gsave
.72727 .47273 -73.7813 -11.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 14.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
(0.6) show
84.563 14.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 0 1 r
.52058 .61259 m
.52723 .61984 L
.53105 .62334 L
.53476 .62615 L
.53828 .62822 L
.54215 .62971 L
.5457 .63021 L
.54898 .62983 L
.55284 .62817 L
.55638 .62525 L
.56015 .62035 L
.56401 .61294 L
.56583 .60836 L
.56773 .60267 L
.5709 .59049 L
.57357 .57645 L
.57562 .56167 L
.57731 .54428 L
.578 .53393 L
.57848 .52413 L
.57893 .50571 L
.5788 .48613 L
.57816 .46894 L
.57712 .45357 L
.57552 .43781 L
.57332 .42255 L
.57049 .40845 L
.56881 .40198 L
.56691 .39586 L
.56517 .39116 L
.56316 .38665 L
.55944 .38038 L
.55569 .37623 L
.55153 .37365 L
.54755 .3728 L
.54389 .37317 L
.53976 .37469 L
.53606 .3769 L
.53189 .3802 L
.52806 .38386 L
.51502 .39958 L
.49227 .43169 L
.46456 .46196 L
.45997 .46625 L
.4562 .47071 L
.45288 .47623 L
.45141 .47958 L
.4501 .48345 L
.4492 .48691 L
.44882 .48877 L
Mistroke
.44847 .49076 L
.4482 .49267 L
.44801 .49439 L
.44787 .49608 L
.44778 .49764 L
.44774 .49913 L
.44774 .50065 L
.44777 .5019 L
.44784 .50321 L
.44795 .50454 L
.44811 .50587 L
.4483 .50704 L
.4485 .50801 L
.44903 .50986 L
.44937 .51074 L
.44972 .51145 L
.45007 .51204 L
.45047 .51256 L
.45092 .51302 L
.45135 .51335 L
.45172 .51357 L
.45213 .51375 L
.45252 .51387 L
.45288 .51395 L
.4533 .51402 L
.45376 .51406 L
.45419 .51409 L
.45459 .51411 L
.45503 .51415 L
.45549 .51422 L
.45593 .51431 L
.45634 .51443 L
.45682 .51462 L
.45735 .5149 L
.45835 .51565 L
.45945 .51681 L
.46074 .51852 L
.46342 .5229 L
.482 .5555 L
.4966 .57877 L
.50738 .59487 L
.51928 .61079 L
.52611 .61846 L
.53295 .62458 L
.53686 .62719 L
.53911 .62832 L
.54119 .62913 L
.5449 .62987 L
.54883 .62955 L
.55269 .62793 L
Mistroke
.55675 .62451 L
.56045 .6195 L
.56369 .61327 L
.56721 .60389 L
.57067 .59103 L
.57348 .57645 L
.57561 .56101 L
.57735 .5427 L
.57805 .53179 L
.57851 .52147 L
.57888 .50211 L
.57861 .48165 L
.57778 .46383 L
.57654 .44806 L
.57469 .43209 L
.57219 .41691 L
.56901 .40319 L
.56702 .39664 L
.56507 .39136 L
.56126 .38356 L
.55924 .38053 L
.55697 .37785 L
.55295 .37474 L
.55066 .37377 L
.54855 .37331 L
.54465 .37345 L
.54057 .37477 L
.53666 .37698 L
.53252 .38017 L
.52532 .38737 L
.51316 .40281 L
.49209 .43298 L
.46809 .45969 L
.46326 .46357 L
.4586 .46775 L
.45656 .47003 L
.45477 .47243 L
.45184 .47771 L
.45053 .481 L
.44951 .48428 L
.44862 .48806 L
.44823 .49023 L
.44794 .4922 L
.44782 .49326 L
.4477 .49438 L
.44755 .49635 L
.44749 .49744 L
.44745 .49844 L
.44743 .49951 L
.44744 .50064 L
Mistroke
.44746 .50158 L
.44749 .50259 L
.44755 .50351 L
.44761 .50433 L
.44777 .50581 L
.44799 .50727 L
.44824 .50851 L
.44854 .50973 L
.44884 .51069 L
.44919 .51161 L
.44957 .5124 L
.44993 .51303 L
.45067 .51399 L
.45114 .51443 L
.45159 .51474 L
.45209 .515 L
.45234 .5151 L
.45262 .51519 L
.4531 .5153 L
.45361 .51538 L
.4541 .51542 L
.45454 .51544 L
.45499 .51545 L
.45546 .51548 L
.45586 .51551 L
.45631 .51556 L
.4568 .51566 L
.45732 .51581 L
.45782 .51601 L
.45829 .51625 L
.45916 .51684 L
.46015 .51776 L
.46237 .52056 L
.48062 .55209 L
.49717 .57886 L
.51942 .61048 L
.52646 .6184 L
.53346 .62459 L
.53711 .62697 L
.54108 .62876 L
.54337 .62935 L
.54555 .62958 L
.54963 .62902 L
.55372 .62693 L
.55597 .62501 L
.55798 .62277 L
.56176 .61691 L
.56512 .6095 L
.56874 .5984 L
.57169 .58589 L
Mistroke
.57442 .56976 L
.57557 .56079 L
.57665 .55038 L
.57799 .53185 L
.57868 .51347 L
.57882 .49667 L
.57845 .47855 L
.57744 .45952 L
.5767 .45036 L
.57571 .4407 L
.57356 .42499 L
.57111 .41204 L
.56844 .4015 L
.56535 .39233 L
.5625 .38605 L
.55924 .38075 L
.55556 .37675 L
.55154 .37428 L
.54769 .37342 L
.54418 .37372 L
.54035 .37503 L
.53682 .37701 L
.53302 .37986 L
.52905 .38351 L
.51489 .40047 L
.49502 .42867 L
.46712 .45986 L
.46234 .46375 L
.45779 .46813 L
.45567 .47075 L
.45355 .47404 L
.45186 .47743 L
.45049 .48094 L
.44941 .48454 L
.44852 .48852 L
.44797 .49198 L
.44775 .49394 L
.4476 .49574 L
.44753 .49674 L
.44748 .4978 L
.44744 .49968 L
.44746 .50144 L
.44753 .503 L
.44765 .50459 L
.44774 .50545 L
.44784 .50622 L
.44807 .50768 L
.44838 .5091 L
.44871 .51026 L
.44904 .51119 L
Mistroke
.44942 .51207 L
.44987 .51286 L
.45031 .51347 L
.45073 .51393 L
.45114 .51427 L
.45159 .51455 L
.45208 .51477 L
.45235 .51486 L
.45261 .51492 L
.4531 .51499 L
.45358 .51501 L
.45384 .51502 L
.45412 .51501 L
.45437 .515 L
.45463 .51498 L
.45492 .51497 L
.45522 .51495 L
.45551 .51495 L
.45578 .51495 L
.45622 .51497 L
.4567 .51503 L
.45715 .51513 L
.45757 .51527 L
.45806 .5155 L
.45861 .51583 L
.45963 .5167 L
.46078 .51801 L
.46211 .51987 L
.46488 .52452 L
.48501 .55988 L
.50085 .58499 L
.51164 .60072 L
.52517 .61744 L
.52943 .62164 L
.53357 .62504 L
.53737 .62748 L
.54155 .62927 L
.54557 .62994 L
.54981 .62932 L
.5534 .62753 L
.55725 .62402 L
.56108 .61852 L
.5644 .61173 L
.56794 .60166 L
.57095 .58992 L
.57338 .57722 L
.57527 .56405 L
.57692 .54823 L
.57815 .53022 L
.57882 .5104 L
Mistroke
.57885 .49199 L
.57864 .48191 L
.57821 .47108 L
.57694 .45216 L
.57522 .43587 L
.57286 .4203 L
.57019 .40759 L
.56746 .39783 L
.56563 .39264 L
.5636 .38787 L
.55978 .38113 L
.55757 .37833 L
.55546 .3763 L
.55312 .37467 L
.55057 .37357 L
.54837 .37312 L
.54596 .37309 L
.5437 .37347 L
.54161 .37413 L
.5377 .37609 L
.53362 .37899 L
.5265 .38577 L
.51948 .39403 L
.50827 .40923 L
.48874 .43673 L
.46583 .46083 L
.4612 .46489 L
.4573 .46901 L
.45536 .4716 L
.45346 .47472 L
.45206 .47759 L
.45072 .48101 L
.44966 .48445 L
.44887 .48781 L
.44824 .49142 L
.44799 .49345 L
.44781 .49527 L
.4477 .49693 L
.44764 .49843 L
.44762 .50002 L
.44764 .50166 L
.44772 .50314 L
.44782 .50447 L
.44795 .50559 L
.44811 .50673 L
.44835 .50796 L
.44859 .50898 L
.44889 .50997 L
.44924 .51092 L
.44959 .51167 L
Mistroke
.44994 .51227 L
.45028 .51276 L
.45066 .5132 L
.45109 .51358 L
.45149 .51385 L
.45173 .51398 L
.45199 .51409 L
.45245 .51424 L
.45268 .51429 L
.45293 .51434 L
.45338 .51439 L
.45366 .5144 L
.45392 .51441 L
.45416 .51442 L
.45441 .51442 L
.45489 .51443 L
.45534 .51445 L
.4556 .51447 L
.45584 .5145 L
.45611 .51454 L
.45637 .5146 L
.45663 .51467 L
.4569 .51476 L
.45739 .51498 L
.45798 .51533 L
.45854 .51575 L
.45957 .51678 L
.46078 .51831 L
.46329 .5223 L
.48131 .55413 L
.49915 .5826 L
.51254 .60206 L
.52018 .61187 L
.52783 .62018 L
.53183 .62373 L
.53568 .6265 L
.53977 .62864 L
.54197 .62939 L
.54434 .62986 L
.5467 .62992 L
.54928 .62948 L
.5517 .62853 L
.55392 .62714 L
.55804 .62305 L
.56027 .61985 L
.56224 .61636 L
.56584 .608 L
.56888 .59832 L
.57186 .58554 L
.57451 .56971 L
Mistroke
.57636 .55424 L
.57765 .53863 L
.57855 .52058 L
.5789 .50068 L
.5786 .48091 L
.57776 .46315 L
.57624 .44481 L
.57524 .43615 L
.57399 .42716 L
.57154 .4136 L
.56847 .40119 L
.56523 .39168 L
.56203 .38482 L
.55874 .37978 L
.55557 .37646 L
.55201 .37419 L
.54816 .37318 L
.5441 .37347 L
.54029 .37479 L
.53692 .37669 L
.53333 .37936 L
.52629 .38615 L
.51922 .39456 L
.50785 .4101 L
.48803 .43812 L
.46293 .46364 L
.45864 .46764 L
.45466 .47266 L
.4527 .47609 L
.45116 .47957 L
.44986 .48338 L
.4489 .48719 L
.44822 .49091 L
.44796 .4928 L
.44775 .49485 L
.44762 .49658 L
.44754 .49838 L
.44752 .50004 L
.44754 .50149 L
.44757 .50235 L
.44762 .50324 L
.44775 .50476 L
.44784 .50556 L
.44793 .50628 L
.4482 .50782 L
.44847 .50902 L
.44875 .51002 L
.44912 .51105 L
.44949 .51189 L
.44986 .51257 L
Mistroke
.45029 .51318 L
.45066 .51361 L
.45107 .514 L
.45154 .51433 L
.45178 .51446 L
.45203 .51459 L
.4525 .51475 L
.45295 .51486 L
.45339 .51493 L
.45388 .51497 L
.45434 .51499 L
.45477 .51501 L
.45515 .51502 L
.45557 .51505 L
.45602 .5151 L
.45644 .51518 L
.4569 .5153 L
.45742 .51549 L
.45797 .51577 L
.45849 .5161 L
.45946 .51692 L
.46056 .51813 L
.46343 .52235 L
.4667 .52803 L
.49113 .56965 L
.5106 .59907 L
.51718 .60788 L
.52488 .61693 L
.52882 .62086 L
.53267 .62415 L
.53622 .6266 L
.54015 .62857 L
.54431 .62963 L
.54825 .6295 L
.55176 .62828 L
.5555 .6256 L
.55948 .62086 L
.56141 .61769 L
.56347 .61359 L
.56691 .60465 L
.56984 .59435 L
.57246 .58208 L
.57458 .56884 L
.57615 .55577 L
.57748 .54048 L
.57842 .52294 L
.57885 .50372 L
.57872 .48724 L
.57808 .46942 L
.57681 .45132 L
Mistroke
.57489 .43379 L
.5728 .42038 L
.57011 .40759 L
.56679 .39613 L
.56478 .3908 L
.56287 .38664 L
.55898 .38029 L
.55514 .37629 L
.55144 .37413 L
.54749 .37331 L
.54411 .37363 L
.54041 .3749 L
.5365 .37714 L
.53238 .38032 L
.52526 .38744 L
.48414 .44308 L
.47021 .45745 L
.46475 .46193 L
.46013 .46591 L
.45617 .47025 L
.4542 .47312 L
.45257 .47606 L
.45019 .48203 L
.44925 .48532 L
.44845 .48908 L
.44811 .49122 L
.44785 .49325 L
.44768 .49505 L
.44755 .49697 L
.4475 .49795 L
.44748 .49901 L
.44747 .50009 L
.44748 .50109 L
.44754 .50279 L
.4476 .50371 L
.44767 .50453 L
.44784 .50602 L
.44804 .5073 L
.44829 .50859 L
.44862 .50983 L
.44896 .51087 L
.44931 .51173 L
.45004 .51303 L
.45043 .51354 L
.45086 .51398 L
.45129 .51432 L
.45168 .51456 L
.45215 .51476 L
.45242 .51484 L
.45267 .51491 L
Mistroke
.45312 .51498 L
.45361 .51502 L
.45409 .51503 L
.45459 .51502 L
.45485 .51502 L
.45514 .51502 L
.45565 .51502 L
.45612 .51506 L
.45639 .51509 L
.45664 .51513 L
.45712 .51525 L
.45757 .51542 L
.45799 .51562 L
.45844 .51589 L
.45928 .51653 L
.46022 .51749 L
.46132 .51889 L
.46704 .52848 L
.47718 .54663 L
.49247 .57185 L
.51274 .60214 L
.51959 .61099 L
.52749 .61971 L
.53153 .62336 L
.53544 .62623 L
.53902 .62821 L
.54293 .62952 L
.54681 .62981 L
.55094 .62879 L
.55479 .62636 L
.55822 .62273 L
.56208 .61658 L
.56417 .61215 L
.56601 .60742 L
.56918 .59711 L
.57215 .58391 L
.57455 .56931 L
.57659 .55167 L
.57795 .53356 L
.57867 .51615 L
.57887 .49643 L
.57871 .48529 L
.57837 .47507 L
.57782 .46448 L
.57717 .45516 L
.57622 .44483 L
.57516 .43559 L
.57321 .42249 L
.57068 .40981 L
.56767 .39863 L
Mistroke
.56456 .39013 L
.56146 .38387 L
.55849 .37952 L
.55495 .376 L
.55152 .37402 L
.54777 .37318 L
.54378 .37356 L
.54039 .37476 L
.5367 .37685 L
.53283 .37978 L
.52876 .38354 L
.52176 .39134 L
.48248 .44476 L
.46896 .4583 L
.46362 .46276 L
.45911 .46693 L
.45534 .47152 L
.45347 .47454 L
.45195 .47763 L
.45074 .48071 L
.44977 .48377 L
.44894 .48711 L
.44826 .49087 L
.44799 .49281 L
.44788 .49383 L
.44778 .49491 L
.44764 .49685 L
.44757 .49861 L
.44756 .5004 L
.44759 .50202 L
.44767 .5034 L
.44779 .50482 L
.44797 .50627 L
.44822 .50773 L
.44854 .5091 L
.44887 .51023 L
.44957 .51188 L
.44999 .51261 L
.45041 .51316 L
.4686 .53168 L
.49127 .57016 L
.50113 .5855 L
.5141 .6041 L
.52093 .61271 L
.52869 .62095 L
.53204 .62385 L
.5357 .62648 L
.5398 .62862 L
.54365 .62973 L
.54579 .62991 L
Mistroke
.54805 .62973 L
.55209 .62829 L
.55635 .62496 L
.55871 .62214 L
.56086 .61885 L
.56458 .61122 L
.56773 .60228 L
.571 .58959 L
.57367 .5753 L
.57564 .56088 L
.57725 .54407 L
.57828 .52717 L
.57879 .51132 L
.57885 .49238 L
.57825 .47221 L
.57709 .45402 L
.57552 .43846 L
.57337 .42338 L
.57059 .40934 L
.56757 .39825 L
.56454 .39003 L
.56073 .38262 L
.55847 .37946 L
.55634 .37716 L
.55235 .37435 L
.55031 .37358 L
.54805 .37317 L
.54584 .37319 L
.54353 .3736 L
.53943 .37521 L
.53717 .37652 L
.5351 .37796 L
.53049 .38186 L
.51589 .39887 L
.48064 .44706 L
.46817 .45917 L
.45903 .46715 L
.45517 .47185 L
.45327 .47498 L
.4517 .47824 L
.4503 .48202 L
.44926 .48571 L
.44879 .48781 L
.44836 .49013 L
.44804 .49234 L
.44781 .49436 L
.44767 .49609 L
.44758 .49792 L
.44754 .49959 L
.44755 .50108 L
Mistroke
.44761 .50265 L
.44772 .50429 L
.4478 .50507 L
.4479 .50588 L
.44811 .50724 L
.44838 .50856 L
.44872 .50983 L
.44909 .51088 L
.44945 .51172 L
.45021 .51299 L
.45062 .51348 L
.45108 .51391 L
.47091 .53575 L
.49689 .57884 L
.50816 .59573 L
.51531 .60556 L
.52267 .61459 L
.53008 .62209 L
.53444 .62553 L
.53854 .62795 L
.54206 .62928 L
.54595 .6298 L
.55001 .62911 L
.55375 .62713 L
.55795 .62303 L
.56024 .61976 L
.5623 .61609 L
.5659 .60767 L
.56938 .59627 L
.57212 .58397 L
.57433 .57073 L
.5763 .55453 L
.57717 .54477 L
.57782 .53549 L
.57868 .51542 L
.57886 .49634 L
.5787 .4854 L
.57838 .47559 L
.57781 .46452 L
.57709 .45442 L
.57622 .44496 L
.57512 .43546 L
.57274 .41993 L
.56965 .40565 L
.56768 .39874 L
.56573 .39309 L
.56221 .38529 L
.56013 .38182 L
.55814 .37917 L
.55441 .37567 L
Mistroke
.55035 .37369 L
.54632 .37325 L
.54253 .374 L
.53916 .37546 L
.53557 .37771 L
.52758 .38485 L
.51974 .39397 L
.50738 .41084 L
.48797 .43818 L
.47478 .4533 L
.46469 .46201 L
.46086 .46529 L
.45705 .46924 L
.45375 .47396 L
.4522 .47696 L
.45092 .48004 L
.44973 .48367 L
.44886 .48718 L
.44847 .48916 L
.44812 .49134 L
.44786 .4934 L
.44768 .49529 L
.44756 .49726 L
.44752 .49834 L
.4475 .49933 L
.44751 .50108 L
.44753 .50193 L
.44757 .50285 L
.44768 .50436 L
.44785 .50589 L
.44805 .50722 L
.44827 .50834 L
.44859 .5096 L
.44892 .51063 L
.44932 .51162 L
.44977 .51251 L
.45019 .51314 L
.45061 .51363 L
.45108 .51407 L
.45159 .51442 L
.45206 .51464 L
.45249 .51478 L
.45298 .51488 L
.45345 .51494 L
.45389 .51496 L
.4543 .51496 L
.45474 .51496 L
.45521 .51497 L
.45568 .51499 L
.45595 .51501 L
Mistroke
.45619 .51504 L
.45667 .51512 L
.45712 .51525 L
.45738 .51534 L
.45765 .51546 L
.45815 .51573 L
.45876 .51614 L
.45933 .51663 L
.46052 .51792 L
.46171 .51952 L
.46486 .52468 L
.47306 .53948 L
.50222 .58697 L
.51482 .60492 L
.52277 .61471 L
.52693 .61914 L
.53091 .62282 L
.53468 .62571 L
.53892 .62814 L
.54325 .62956 L
.54564 .62982 L
.54787 .62967 L
.5518 .62836 L
.55535 .62585 L
.55913 .62146 L
.56294 .61483 L
.56643 .60619 L
.56986 .59439 L
.5727 .58094 L
.57489 .56673 L
.5765 .55257 L
.5778 .53587 L
.57863 .51752 L
.57888 .49996 L
.57853 .47951 L
.57758 .46076 L
.57622 .44492 L
.57426 .4291 L
.57159 .41399 L
.56825 .40055 L
.56505 .39132 L
.56325 .38728 L
.56122 .3835 L
.55771 .37864 L
.55389 .37528 L
.55028 .37363 L
.54689 .37319 L
.54288 .37385 L
.53926 .37536 L
.53516 .37797 L
Mistroke
.53137 .38109 L
.51916 .39464 L
.50766 .41033 L
.47544 .45251 L
.46433 .46222 L
.45919 .46686 L
.45691 .46941 L
.45497 .47204 L
.45317 .47505 L
.45173 .47808 L
.45036 .48174 L
.44918 .48593 L
.44843 .4896 L
.44811 .49168 L
.44788 .4936 L
.44772 .49526 L
.4476 .49705 L
.44754 .49887 L
.44753 .50052 L
.44757 .50212 L
.44767 .50377 L
.44781 .50523 L
.44797 .5065 L
.44816 .50756 L
.44839 .50864 L
.44894 .51053 L
.44929 .51143 L
.44965 .51214 L
.45005 .5128 L
.4505 .51338 L
.45092 .51379 L
.45132 .5141 L
.45175 .51435 L
.45221 .51454 L
.45267 .51466 L
.45293 .51471 L
.45317 .51474 L
.45363 .51478 L
.45408 .51479 L
.45453 .51479 L
.45502 .51479 L
.45528 .51479 L
.45556 .51481 L
.45582 .51482 L
.45606 .51485 L
.45634 .51489 L
.4566 .51495 L
.45689 .51502 L
.4572 .51513 L
.45771 .51536 L
Mistroke
.45829 .5157 L
.45942 .51665 L
.46055 .51794 L
.46311 .52176 L
.46596 .52676 L
.47508 .54319 L
.48764 .56425 L
.50738 .59469 L
.52095 .61267 L
.52507 .61729 L
.52968 .62181 L
.5338 .62515 L
.53602 .62664 L
.53841 .62796 L
.54078 .62895 L
.54295 .62956 L
.5472 .62981 L
.5515 .62857 L
.55549 .62577 L
.55925 .62136 L
.56256 .61567 L
.56599 .60752 L
.5693 .59666 L
.57211 .58417 L
.57343 .57678 L
.57469 .56836 L
.5766 .55159 L
.57788 .53481 L
.57862 .518 L
.57889 .50185 L
.57868 .48414 L
.57789 .46552 L
.57653 .44788 L
.57552 .4385 L
.57444 .43024 L
.57184 .41514 L
.56856 .40156 L
.56511 .39142 L
.56157 .38405 L
.55822 .37918 L
.55446 .37563 L
.55083 .37376 L
.54739 .37316 L
.54362 .3736 L
.5396 .37515 L
.53546 .37771 L
.53163 .38083 L
.52473 .38788 L
.50294 .41711 L
.47223 .45559 L
Mistroke
.46324 .4632 L
.45916 .46696 L
.45536 .47154 L
.45362 .47431 L
.45193 .47769 L
.45061 .48107 L
.44958 .48444 L
.44873 .48806 L
.44816 .49143 L
.44792 .49329 L
.44773 .4953 L
.44761 .49715 L
.44755 .49883 L
.44754 .50052 L
.44759 .50226 L
.44768 .50381 L
.44781 .50516 L
.44799 .50655 L
.44825 .50795 L
.44856 .50926 L
.44889 .51034 L
.44928 .51135 L
.44967 .51216 L
.45006 .51278 L
.45048 .51333 L
.45096 .51381 L
.45142 .51415 L
.45192 .51441 L
.45221 .51453 L
.45248 .51461 L
.45295 .51471 L
.45339 .51477 L
.45363 .51478 L
.4539 .5148 L
.45436 .51481 L
.45463 .51481 L
.45491 .51481 L
.45516 .51482 L
.45542 .51483 L
.45567 .51485 L
.45593 .51488 L
.45641 .51495 L
.4569 .51508 L
.45718 .51518 L
.45743 .51528 L
.4579 .51552 L
.45843 .51586 L
.45938 .51667 L
.46044 .51786 L
.46272 .52116 L
Mistroke
.4657 .52631 L
.47314 .53976 L
.486 .56156 L
.49535 .57649 L
.50776 .59518 L
.51493 .60509 L
.52233 .61423 L
.52948 .62159 L
.53332 .62476 L
.5354 .62621 L
.53765 .62753 L
.5418 .62923 L
.5457 .62983 L
.54799 .62966 L
.55016 .62909 L
.55419 .62683 L
.55786 .62317 L
.56114 .61829 L
.56457 .61117 L
.56794 .6015 L
.57073 .59074 L
.57339 .57695 L
.57566 .56051 L
.57727 .54364 L
.57829 .52677 L
.57878 .5109 L
.57883 .49236 L
.57836 .47508 L
.5773 .45696 L
.57558 .43911 L
.57367 .42529 L
.57114 .41187 L
.568 .39971 L
.5661 .39405 L
.56421 .38936 L
.56239 .38559 L
.56035 .38211 L
.55663 .3775 L
.55271 .3746 L
.54896 .37335 L
.54557 .37328 L
.54192 .37417 L
.53798 .37609 L
.5339 .37895 L
.52687 .38557 L
.50454 .41487 L
.47329 .45468 L
.46417 .46243 L
.46001 .46611 L
.45608 .4705 L
Mistroke
.4543 .4731 L
.45253 .47631 L
.45112 .47957 L
.45001 .4828 L
.44908 .48629 L
.44869 .48814 L
.44832 .49017 L
.44807 .49184 L
.44786 .49362 L
.44769 .49548 L
.44758 .49717 L
.44754 .49818 L
.44752 .49922 L
.44752 .50104 L
.44755 .50201 L
.44759 .5029 L
.44766 .50384 L
.44774 .50481 L
.44795 .50644 L
.4482 .50786 L
.44846 .50902 L
.44878 .51014 L
.44949 .51191 L
.44988 .51261 L
.45034 .51326 L
.45075 .51371 L
.4512 .5141 L
.45164 .51438 L
.45205 .51457 L
.45253 .51472 L
.45298 .51482 L
.45339 .51487 L
.45383 .51489 L
.45431 .5149 L
.45456 .5149 L
.45483 .51491 L
.4553 .51491 L
.45575 .51494 L
.4562 .51499 L
.45662 .51507 L
.45701 .51518 L
.45744 .51534 L
.4579 .51556 L
.45841 .51588 L
.45935 .51665 L
.46053 .51795 L
.46192 .51987 L
.46489 .52479 L
.47274 .53896 L
.50399 .58964 L
Mistroke
.51609 .60659 L
.52365 .6157 L
.53134 .62319 L
.53589 .6265 L
.5385 .62795 L
.54094 .62895 L
.54529 .62981 L
.54749 .62972 L
.54991 .62917 L
.55422 .6268 L
.5566 .62461 L
.55873 .62202 L
.56254 .61566 L
.56628 .60663 L
.56947 .59594 L
.57251 .58195 L
.57491 .56661 L
.57666 .55088 L
.57782 .53564 L
.57861 .51808 L
.57888 .49932 L
.57861 .48181 L
.57766 .46199 L
.57616 .44434 L
.57436 .42982 L
.57195 .41572 L
.56887 .40272 L
.56701 .39664 L
.56516 .39162 L
.56336 .38751 L
.56134 .38372 L
.55769 .37861 L
.55408 .37541 L
.55065 .37375 L
.54686 .3732 L
.5428 .37388 L
.53858 .37574 L
.53467 .37835 L
.5276 .38479 L
.51597 .39882 L
.50508 .41407 L
.4741 .45386 L
.46327 .46314 L
.45827 .46785 L
.45607 .4705 L
.4542 .47325 L
.45249 .47639 L
.45114 .47952 L
.44987 .48329 L
.44881 .48756 L
Mistroke
.44816 .49125 L
.4479 .49333 L
.44772 .49522 L
.44761 .49686 L
.44754 .49861 L
.44752 .50038 L
.44756 .50197 L
.44764 .5035 L
.44778 .50506 L
.44796 .50644 L
.44816 .50762 L
.44863 .5096 L
.4489 .51046 L
.44923 .51131 L
.44998 .51273 L
.45043 .51334 L
.45087 .51379 L
.45126 .5141 L
.4517 .51436 L
.45217 .51456 L
.45261 .51469 L
.45309 .51478 L
.45333 .5148 L
.4536 .51482 L
.45407 .51484 L
.45451 .51484 L
.45478 .51484 L
.45503 .51484 L
.45551 .51486 L
.45577 .51487 L
.45602 .5149 L
.45629 .51494 L
.45658 .51499 L
.45708 .51513 L
.45736 .51524 L
.45762 .51535 L
.45809 .51561 L
.45862 .51598 L
.45958 .51684 L
.46066 .51809 L
.46603 .52685 L
.47363 .54059 L
.48734 .56373 L
.50708 .59422 L
.51827 .6094 L
.52509 .61729 L
.5319 .62367 L
.53556 .62633 L
.53958 .62847 L
.54178 .62925 L
Mistroke
.5441 .62974 L
.54826 .62963 L
.55204 .62826 L
.5555 .62574 L
.55919 .62141 L
.56296 .61482 L
.56645 .60618 L
.56992 .59419 L
.5715 .58717 L
.57306 .57894 L
.57427 .57127 L
.57545 .56238 L
.57724 .54405 L
.57835 .52541 L
.57885 .50659 L
.57879 .48902 L
.57808 .4689 L
.57681 .45093 L
.57584 .44125 L
.57479 .43283 L
.5734 .42363 L
.57195 .41572 L
.56887 .40268 L
.56707 .39679 L
.56504 .39128 L
.5628 .38634 L
.5606 .38247 L
.55856 .37962 L
.55631 .37717 L
.55235 .37439 L
.54858 .37327 L
.54444 .37343 L
.54212 .37408 L
.54001 .37496 L
.53584 .37746 L
.5314 .38105 L
.5237 .38908 L
.50038 .42082 L
.46947 .458 L
.4645 .46213 L
.45979 .46631 L
.45622 .47033 L
.45288 .47565 L
.45148 .47872 L
.45019 .4823 L
.4492 .48589 L
.44849 .48928 L
.44816 .49134 L
.44792 .49324 L
.44772 .4953 L
Mistroke
.44765 .49633 L
.44759 .49745 L
.44754 .49927 L
.44753 .50027 L
.44754 .50116 L
.4476 .50276 L
.44772 .50434 L
.44787 .50574 L
.44805 .50692 L
.44829 .50818 L
.44855 .50926 L
.44909 .51092 L
.44943 .51171 L
.44976 .51234 L
.45012 .51289 L
.45052 .51339 L
.45097 .51383 L
.4514 .51415 L
.45164 .51429 L
.4519 .51442 L
.45238 .5146 L
.45285 .51471 L
.45329 .51477 L
.45377 .5148 L
.45422 .51481 L
.45469 .51482 L
.45494 .51482 L
.45521 .51483 L
.4555 .51484 L
.45578 .51486 L
.45603 .51489 L
.4563 .51493 L
.45655 .51498 L
.45682 .51505 L
.4573 .51522 L
.45776 .51543 L
.45827 .51574 L
.45921 .51649 L
.4604 .51779 L
.46158 .51938 L
.47578 .54438 L
.48849 .56559 L
.50848 .59623 L
.51596 .60645 L
.52369 .61577 L
.53115 .62306 L
.53554 .62631 L
.53967 .6285 L
.5436 .62965 L
.54729 .62977 L
Mistroke
.55132 .62862 L
.55558 .62565 L
.55767 .62341 L
.55989 .62036 L
.56378 .61304 L
.56729 .60364 L
.57023 .59289 L
.57282 .58025 L
.57512 .56504 L
.57668 .55071 L
.57792 .5339 L
.5787 .51486 L
.57887 .504 L
.57885 .4941 L
.57837 .47506 L
.57736 .45775 L
.57597 .44252 L
.57406 .42774 L
.57209 .41642 L
.56962 .40547 L
.56665 .39557 L
.56317 .38709 L
.55966 .38109 L
.55632 .37719 L
.5523 .37438 L
.55003 .37356 L
.54795 .37322 L
.54392 .37356 L
.54014 .37491 L
.53801 .37606 L
.53579 .37751 L
.53188 .38063 L
.52349 .38934 L
.49953 .42208 L
.47059 .45708 L
.46193 .46434 L
.45799 .46819 L
.45435 .47303 L
.45274 .47591 L
.45118 .47943 L
.44999 .48291 L
.44908 .48636 L
.4487 .48813 L
.44836 .49 L
.44811 .49163 L
.44789 .49336 L
.44772 .49522 L
.4476 .49691 L
.44756 .49793 L
.44753 .49888 L
Mistroke
.44752 .5006 L
.44757 .50223 L
.44761 .50312 L
.44767 .50393 L
.44783 .50548 L
.44794 .5063 L
.44805 .50702 L
.44828 .50821 L
.44857 .50939 L
.44918 .51121 L
.44961 .51211 L
.45002 .5128 L
.45053 .51345 L
.45102 .51392 L
.45149 .51425 L
.45193 .51448 L
.45242 .51466 L
.45267 .51472 L
.45294 .51477 L
.45344 .51483 L
.45389 .51486 L
.45413 .51486 L
.4544 .51487 L
.45467 .51487 L
.45493 .51487 L
.45541 .51488 L
.45584 .51491 L
.45608 .51494 L
.45634 .51498 L
.45682 .51509 L
.4573 .51525 L
.45773 .51545 L
.45824 .51575 L
.45873 .5161 L
.45964 .51693 L
.46068 .51814 L
.46697 .52856 L
.47624 .54514 L
.48901 .56639 L
.5091 .59709 L
.51656 .60721 L
.5243 .61642 L
.53177 .62355 L
.53388 .62517 L
.53616 .62668 L
.54031 .62874 L
.54419 .62972 L
.54838 .62959 L
.55231 .62809 L
.55586 .62538 L
Mistroke
.55967 .62068 L
.56176 .61716 L
.56365 .61331 L
.56724 .60376 L
.57069 .59092 L
.57333 .5773 L
.5757 .56014 L
.57667 .55076 L
.57752 .54022 L
.57814 .52993 L
.57854 .52029 L
.57888 .50159 L
.57859 .48122 L
.5777 .46256 L
.57636 .44624 L
.57532 .43694 L
.57402 .4275 L
.57122 .41223 L
.56803 .39981 L
.56476 .39062 L
.56092 .38301 L
.55865 .37975 L
.55647 .37735 L
.55413 .37545 L
.55198 .37424 L
.54947 .37344 L
.54708 .37319 L
.54335 .37371 L
.53927 .37536 L
.53724 .37654 L
.53508 .37803 L
.53125 .38121 L
.51807 .39605 L
.49489 .42869 L
.46819 .4591 L
.46291 .46346 L
.45848 .46764 L
.45627 .47024 L
.4541 .47343 L
.45235 .47669 L
.45095 .48002 L
.44981 .4835 L
.44894 .48693 L
.44823 .4908 L
.44794 .49298 L
.44774 .49495 L
.44766 .49594 L
.4476 .49697 L
.44753 .49879 L
.44752 .49978 L
Mistroke
.44752 .50069 L
.44755 .50166 L
.44759 .50267 L
.4477 .50432 L
.44778 .5051 L
.44788 .50593 L
.4481 .50731 L
.44834 .50848 L
.44861 .50955 L
.44894 .51059 L
.44926 .5114 L
.44963 .51214 L
.44997 .51272 L
.45037 .51326 L
.45074 .51367 L
.4511 .51398 L
.45156 .51429 L
.45199 .5145 L
.45246 .51466 L
.45273 .51473 L
.45298 .51477 L
.45344 .51482 L
.45385 .51485 L
.45433 .51485 L
.45478 .51485 L
.45522 .51486 L
.45569 .51488 L
.45614 .51493 L
.45655 .515 L
.45703 .51514 L
.45731 .51524 L
.45756 .51535 L
.45807 .51562 L
.45855 .51594 L
.45954 .51681 L
.46071 .51816 L
.46342 .52226 L
.47981 .55126 L
.4957 .57702 L
.50739 .59466 L
.52053 .61214 L
.52701 .61925 L
.53347 .62488 L
.53715 .62727 L
.54121 .62907 L
.54494 .62981 L
.54839 .6296 L
.55218 .62818 L
.55568 .62556 L
.5594 .62109 L
Mistroke
.56322 .61426 L
.56505 .60999 L
.56695 .60469 L
.57014 .59328 L
.57286 .58005 L
.57499 .56605 L
.57688 .54847 L
.5776 .53905 L
.57821 .5284 L
.57882 .50896 L
.57881 .49064 L
.57854 .47961 L
.5781 .46937 L
.57681 .45099 L
.57584 .4413 L
.57479 .43283 L
.57192 .41556 L
.56919 .40383 L
.56632 .39465 L
.56292 .38659 L
.55901 .3802 L
.55699 .37784 L
.55474 .37586 L
.55057 .3737 L
.54647 .37319 L
.54266 .3739 L
.53894 .37552 L
.53497 .3781 L
.52803 .38433 L
.51617 .39853 L
.49516 .42828 L
.46849 .45883 L
.46323 .46319 L
.45877 .46734 L
.45655 .4699 L
.45435 .47304 L
.45257 .47626 L
.45114 .47956 L
.44998 .48296 L
.44909 .48633 L
.44834 .49014 L
.44803 .4923 L
.44781 .49428 L
.44765 .49619 L
.44756 .49792 L
.44753 .49978 L
.44753 .50078 L
.44755 .50167 L
.44759 .50259 L
.44764 .50341 L
Mistroke
.44771 .50427 L
.4478 .50516 L
.44798 .50657 L
.44824 .50798 L
.44852 .50917 L
.44881 .51018 L
.44945 .51177 L
.44984 .51249 L
.45022 .51305 L
.45066 .51356 L
.45114 .51399 L
.45157 .51427 L
.45204 .5145 L
.4525 .51465 L
.45292 .51474 L
.4533 .51479 L
.45372 .51482 L
.45416 .51483 L
.45457 .51483 L
.45505 .51483 L
.45529 .51484 L
.45555 .51485 L
.45602 .5149 L
.45647 .51497 L
.45672 .51503 L
.45699 .51511 L
.45748 .5153 L
.45801 .51557 L
.4586 .51597 L
.45964 .51691 L
.46082 .51833 L
.46326 .52202 L
.47958 .55089 L
.49618 .57777 L
.50807 .59564 L
.51565 .60605 L
.52343 .61549 L
.53075 .62271 L
.53503 .62598 L
.53903 .62822 L
.54133 .6291 L
.54346 .62963 L
.54582 .62985 L
.54832 .62961 L
.55249 .628 L
.55483 .62632 L
.557 .62419 L
.56066 .61913 L
.56432 .61178 L
.56724 .60379 L
Mistroke
.57016 .5932 L
.57293 .57968 L
.57425 .57138 L
.57537 .56301 L
.57712 .5455 L
.57821 .52845 L
.57879 .51082 L
.57882 .4916 L
.57831 .4737 L
.57738 .45794 L
.57577 .44067 L
.57462 .43161 L
.57341 .42371 L
.57088 .4107 L
.56778 .399 L
.56418 .38927 L
.56202 .38489 L
.55997 .38153 L
.55605 .37694 L
.55403 .37537 L
.55179 .37415 L
.54786 .37321 L
.54365 .37362 L
.5397 .37513 L
.53615 .37725 L
.53262 .37999 L
.52896 .38339 L
.52268 .3903 L
.50995 .40709 L
.49186 .43288 L
.46642 .46057 L
.46241 .46391 L
.45852 .46761 L
.45649 .46998 L
.45478 .47236 L
.45188 .47774 L
.45066 .48086 L
.44954 .48449 L
.44871 .48807 L
.44814 .49145 L
.44791 .49327 L
.44774 .49496 L
.44761 .49678 L
.44754 .49869 L
.44752 .49962 L
.44753 .50062 L
.44758 .50236 L
.44768 .50397 L
.44782 .50538 L
.44802 .50684 L
Mistroke
.4483 .50827 L
.4486 .50949 L
.44891 .51048 L
.44958 .51205 L
.44995 .51268 L
.45038 .51327 L
.45086 .51377 L
.45132 .51413 L
.45158 .51429 L
.45186 .51444 L
.4521 .51454 L
.45238 .51463 L
.45287 .51475 L
.45313 .51479 L
.45339 .51481 L
.45384 .51484 L
.45433 .51485 L
.45481 .51485 L
.45524 .51486 L
.45574 .51489 L
.45621 .51495 L
.45665 .51503 L
.45706 .51515 L
.45752 .51533 L
.458 .51559 L
.45905 .51636 L
.46008 .51742 L
.46276 .52119 L
.48176 .55453 L
.49987 .58346 L
.51191 .60103 L
.51796 .60899 L
.52515 .61734 L
.52838 .62058 L
.53197 .62371 L
.53513 .62603 L
.53866 .62804 L
.54247 .62941 L
.54651 .62982 L
.55025 .62906 L
.55369 .6272 L
.55771 .62335 L
.56137 .61789 L
.56449 .61137 L
.56764 .60249 L
.57075 .59064 L
.57359 .57573 L
.57558 .56124 L
.57726 .54374 L
.57839 .5245 L
Mistroke
.57885 .506 L
.57871 .48557 L
.57833 .47433 L
.57781 .46438 L
.57643 .44694 L
.57435 .42972 L
.57188 .41538 L
.56924 .40404 L
.56638 .39482 L
.56351 .38781 L
.56016 .38182 L
.55641 .37728 L
.55236 .37442 L
.54846 .37327 L
.54495 .37336 L
.54115 .37447 L
.53706 .37665 L
.53329 .37943 L
.5251 .3875 L
.51043 .40643 L
.49041 .43486 L
.46676 .46028 L
.4619 .46434 L
.45946 .46663 L
.4573 .46897 L
.45544 .47137 L
.4536 .47428 L
.45091 .48016 L
.44979 .48358 L
.44881 .48756 L
.44842 .48961 L
.44808 .49182 L
.44784 .49389 L
.44768 .49577 L
.44757 .49759 L
.44753 .49923 L
.44753 .50097 L
.44756 .50191 L
.44759 .50274 L
.4477 .5042 L
.44785 .50568 L
.44804 .50698 L
.44825 .50809 L
.44852 .50922 L
.44885 .51031 L
.44952 .51194 L
.44998 .51272 L
.45043 .51333 L
.45085 .51377 L
.45133 .51414 L
Mistroke
.4518 .51442 L
.45207 .51453 L
.45233 .51462 L
.4526 .5147 L
.45285 .51475 L
.45314 .51479 L
.45342 .51482 L
.4539 .51485 L
.45436 .51485 L
.45485 .51486 L
.45511 .51486 L
.45538 .51487 L
.45563 .51488 L
.4559 .5149 L
.45638 .51497 L
.45687 .51509 L
.45732 .51525 L
.45785 .51549 L
.45843 .51586 L
.45954 .51682 L
.46065 .5181 L
.46194 .5199 L
.46461 .52433 L
.48275 .55618 L
.49909 .58226 L
.51042 .59896 L
.5175 .60842 L
.52466 .61682 L
.53139 .62325 L
.5353 .62615 L
.53893 .62817 L
.54296 .62953 L
.54525 .62983 L
.54736 .62976 L
.55123 .62866 L
.55527 .62594 L
.55854 .62229 L
.56194 .61685 L
.56498 .61015 L
.56759 .60267 L
.57038 .59227 L
.57305 .57894 L
.57517 .5646 L
.57674 .54999 L
.57808 .53113 L
.57851 .52126 L
.5788 .51025 L
.57881 .49062 L
.57826 .47259 L
.57766 .46198 L
Mistroke
.57692 .45228 L
.57511 .43524 L
.57386 .42648 L
.57257 .41893 L
.56922 .40398 L
.56617 .39423 L
.56307 .3869 L
.55945 .3808 L
.55539 .37637 L
.55123 .37393 L
.54912 .37336 L
.54681 .37319 L
.54271 .37389 L
.53894 .37552 L
.53528 .37787 L
.5314 .38106 L
.52466 .38798 L
.51323 .40252 L
.49309 .43118 L
.46732 .45982 L
.46218 .4641 L
.45784 .46835 L
.4557 .47102 L
.45359 .47431 L
.45191 .47768 L
.45057 .48111 L
.44951 .4846 L
.44872 .48803 L
.44808 .49186 L
.44783 .49401 L
.44767 .49596 L
.44757 .49783 L
.44753 .49953 L
.44754 .50131 L
.44757 .50228 L
.44762 .50313 L
.44768 .504 L
.44775 .50477 L
.44796 .50642 L
.44819 .50775 L
.44848 .50903 L
.44905 .51086 L
.44941 .51171 L
.44977 .51238 L
.45012 .51292 L
.45051 .51341 L
.45089 .51379 L
.45126 .51408 L
.45174 .51437 L
.45217 .51456 L
Mistroke
.45265 .5147 L
.45292 .51475 L
.45317 .51478 L
.45359 .51482 L
.45406 .51484 L
.45454 .51484 L
.45499 .51484 L
.45545 .51486 L
.45593 .5149 L
.45635 .51496 L
.45682 .51506 L
.45732 .51524 L
.45787 .5155 L
.45839 .51583 L
.45889 .51621 L
.45983 .51712 L
.46092 .51845 L
.46344 .52232 L
.47907 .55002 L
Mfstroke
0 g
gsave
.72727 .41818 -73.7813 -11.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 14.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 0.000 1.000 setrgbcolor
(0.8) show
84.563 14.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.800 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.54369 .5296 m
.54456 .52865 L
.54532 .52764 L
.54693 .52484 L
.54825 .52159 L
.54931 .51797 L
.54982 .51572 L
.55029 .5132 L
.55062 .51092 L
.55091 .50839 L
.55113 .50561 L
.55126 .50299 L
.5513 .50139 L
.55131 .49988 L
.55126 .49707 L
.55113 .49441 L
.55093 .4921 L
.55063 .48956 L
.55027 .48733 L
.54946 .4838 L
.54892 .48209 L
.54838 .4807 L
.54779 .47948 L
.54713 .47838 L
.54636 .47742 L
.54562 .47675 L
.54521 .47648 L
.54476 .47624 L
.54434 .47608 L
.54394 .47598 L
.54319 .47591 L
.54239 .47599 L
.54162 .47619 L
.54123 .47633 L
.54082 .47651 L
.53942 .4773 L
.53647 .47938 L
.53521 .48014 L
.53486 .48032 L
.53453 .48046 L
.53392 .48065 L
.53335 .48075 L
.53282 .48075 L
.53224 .48065 L
.53162 .48043 L
.53127 .48024 L
.53093 .48003 L
.53029 .47952 L
.52877 .47784 L
.52733 .47578 L
Mistroke
.5256 .47289 L
.5149 .45237 L
.49909 .42363 L
.48832 .40623 L
.47645 .39024 L
.469 .38281 L
.46509 .38002 L
.46283 .37883 L
.46071 .37803 L
.45839 .37754 L
.4562 .37749 L
.45211 .3786 L
.44985 .38001 L
.44778 .38187 L
.44556 .38455 L
.44327 .3882 L
.44001 .39522 L
.43678 .40499 L
.43405 .41633 L
.43188 .42843 L
.42989 .44361 L
.42898 .45291 L
.42829 .46193 L
.42734 .481 L
.42709 .49196 L
.42704 .50198 L
.42738 .52007 L
.42818 .53644 L
.42959 .55331 L
.43166 .56969 L
.4329 .5771 L
.43438 .5845 L
.43739 .59609 L
.44066 .60501 L
.44391 .61122 L
.44707 .61533 L
.45012 .61785 L
.45353 .61928 L
.45723 .61945 L
.46088 .61845 L
.46468 .61635 L
.46786 .6139 L
.47126 .61067 L
.48481 .59318 L
.49664 .57422 L
.51209 .54887 L
.51774 .54103 L
.52046 .53793 L
.52284 .53571 L
.52528 .53398 L
Mistroke
.52652 .5333 L
.52784 .53275 L
.52902 .53238 L
.53013 .53212 L
.53112 .53196 L
.53168 .53188 L
.5322 .53183 L
.53415 .53169 L
.53518 .53162 L
.53573 .53158 L
.53625 .53153 L
.53719 .53142 L
.53822 .53124 L
.53909 .53102 L
.54001 .53071 L
.54115 .53018 L
.5422 .52952 L
.54313 .52878 L
.5441 .52779 L
.54496 .52671 L
.54584 .52537 L
.54729 .52246 L
.54855 .51889 L
.54909 .51687 L
.54962 .51451 L
.55 .51238 L
.55034 .51002 L
.5506 .50772 L
.55077 .5056 L
.55092 .50289 L
.55097 .5004 L
.55093 .4977 L
.55088 .49637 L
.5508 .49492 L
.55061 .49258 L
.55032 .4902 L
.54998 .48809 L
.54961 .48631 L
.54919 .48468 L
.5487 .48312 L
.5477 .48078 L
.54704 .47964 L
.54638 .47877 L
.54576 .47816 L
.54508 .47766 L
.54447 .47734 L
.54378 .47714 L
.54306 .47706 L
.54239 .47709 L
.54177 .47721 L
Mistroke
.5412 .47737 L
.54055 .47762 L
.53994 .4779 L
.53722 .47939 L
.53657 .47973 L
.53596 .48001 L
.53542 .48021 L
.53483 .48036 L
.53422 .48044 L
.53366 .48044 L
.53305 .48033 L
.53239 .4801 L
.53203 .47992 L
.53164 .47969 L
.53093 .47914 L
.52952 .47767 L
.52664 .47348 L
.52292 .46685 L
.51363 .44933 L
.49831 .42212 L
.48678 .40389 L
.4802 .39484 L
.47361 .38718 L
.47026 .38398 L
.46704 .38141 L
.46362 .37933 L
.45978 .37793 L
.45588 .37767 L
.45231 .37868 L
.44845 .38139 L
.44655 .38346 L
.44451 .38631 L
.44128 .39243 L
.43851 .39959 L
.43559 .40979 L
.43314 .4213 L
.4312 .43347 L
.4297 .44585 L
.42843 .4605 L
.42753 .47694 L
.4271 .49514 L
.42727 .5151 L
.42804 .53342 L
.42927 .54949 L
.43092 .56414 L
.43278 .57608 L
.43528 .58808 L
.43795 .59753 L
.44115 .6058 L
.44477 .61222 L
Mistroke
.448 .61595 L
.45165 .61836 L
.45563 .61922 L
.45786 .61903 L
.45989 .61848 L
.4638 .61656 L
.46742 .61388 L
.47367 .6076 L
.47987 .59973 L
.48976 .5848 L
.50667 .55632 L
.51265 .54674 L
.5179 .5395 L
.52035 .53678 L
.52285 .53457 L
.5239 .53383 L
.525 .53318 L
.52595 .53273 L
.52694 .53235 L
.52795 .53207 L
.52888 .5319 L
.52987 .53179 L
.53043 .53175 L
.53096 .53174 L
.5319 .53175 L
.53277 .53179 L
.53377 .53185 L
.53472 .53191 L
.53557 .53196 L
.53648 .53198 L
.53726 .53197 L
.53811 .53191 L
.53902 .53178 L
.54 .53155 L
.54092 .53123 L
.54175 .53083 L
.54274 .5302 L
.54365 .52945 L
.54529 .52758 L
.54615 .52626 L
.54691 .52485 L
.54774 .52299 L
.54845 .52104 L
.54948 .51739 L
.54995 .51526 L
.55038 .51285 L
.55075 .51021 L
.55102 .50762 L
.55119 .50525 L
.55131 .50265 L
Mistroke
.55134 .50114 L
.55135 .49952 L
.55128 .49663 L
.55113 .49389 L
.55091 .49147 L
.55059 .48899 L
.55015 .48647 L
.54959 .48408 L
.549 .48211 L
.54839 .48049 L
.54776 .47918 L
.54716 .47817 L
.54649 .47729 L
.54573 .47654 L
.54502 .47604 L
.54423 .4757 L
.54378 .47558 L
.54336 .47552 L
.54262 .47552 L
.54184 .47564 L
.54111 .47587 L
.54045 .47614 L
.53887 .47702 L
.53744 .47797 L
.53612 .47884 L
.53477 .47958 L
.53408 .47984 L
.53369 .47995 L
.53333 .48002 L
.5327 .48005 L
.53234 .48002 L
.53202 .47997 L
.53143 .47978 L
.5308 .47946 L
.5302 .47905 L
.52964 .47857 L
.5282 .47696 L
.52673 .47489 L
.51965 .46212 L
.50756 .43928 L
.49821 .42275 L
.48731 .40529 L
.47623 .39051 L
.47275 .38676 L
.46936 .38363 L
.46626 .38128 L
.46279 .37933 L
.45918 .37818 L
.45533 .3781 L
.45178 .3793 L
Mistroke
.4485 .38169 L
.44476 .38628 L
.44149 .39232 L
.43977 .39645 L
.43798 .40163 L
.43497 .41284 L
.43226 .42692 L
.43021 .44184 L
.42933 .45029 L
.42853 .46 L
.42788 .47054 L
.42746 .48065 L
.42714 .49966 L
.42739 .51699 L
.42774 .52639 L
.42829 .53637 L
.42974 .55354 L
.43146 .56744 L
.4338 .58101 L
.43666 .59296 L
.43968 .60203 L
.4427 .6086 L
.44562 .6131 L
.44895 .61649 L
.45253 .61846 L
.4565 .61899 L
.4601 .61821 L
.46209 .61735 L
.46422 .61611 L
.46801 .6132 L
.47502 .60587 L
.48103 .598 L
.50317 .56241 L
.51515 .54359 L
.51792 .54005 L
.52035 .5374 L
.52243 .53554 L
.52455 .53408 L
.52574 .53346 L
.5268 .53302 L
.52786 .53269 L
.52885 .53247 L
.52941 .53238 L
.52999 .5323 L
.53105 .53222 L
.53163 .5322 L
.53217 .53219 L
.53277 .53219 L
.53341 .53219 L
.53447 .53221 L
Mistroke
.53506 .53221 L
.53561 .53221 L
.53662 .53218 L
.53769 .53209 L
.53864 .53194 L
.53953 .53173 L
.54049 .5314 L
.54152 .53091 L
.5425 .53028 L
.54337 .52957 L
.54428 .52864 L
.54524 .52743 L
.54682 .52473 L
.54814 .52154 L
.5488 .51948 L
.54944 .51701 L
.54999 .51443 L
.55047 .51148 L
.55081 .50861 L
.55104 .50593 L
.55119 .50319 L
.55124 .50059 L
.55124 .49909 L
.55121 .4977 L
.5511 .49514 L
.5509 .49249 L
.55075 .49106 L
.55058 .48979 L
.54984 .48569 L
.54938 .48388 L
.54881 .48211 L
.54813 .48042 L
.54745 .47914 L
.54662 .47796 L
.54623 .47752 L
.5458 .47712 L
.54544 .47684 L
.54502 .47658 L
.54429 .47626 L
.54387 .47616 L
.54343 .4761 L
.543 .47609 L
.54261 .47611 L
.54183 .47627 L
.5411 .47651 L
.54046 .4768 L
.53977 .47718 L
.53694 .47903 L
.53572 .47978 L
.53508 .48011 L
Mistroke
.53448 .48034 L
.53398 .48048 L
.53345 .48055 L
.53285 .48054 L
.53231 .48044 L
.53167 .4802 L
.53134 .48003 L
.53097 .47979 L
.52968 .47865 L
.52806 .47661 L
.52637 .474 L
.51786 .45802 L
.50443 .43301 L
.49411 .4154 L
.48224 .39761 L
.4763 .39017 L
.47033 .38406 L
.46691 .38132 L
.46311 .37908 L
.45961 .37787 L
.45636 .3776 L
.45278 .37843 L
.44946 .38045 L
.4459 .38423 L
.44224 .39031 L
.44049 .39419 L
.43866 .39908 L
.43558 .40975 L
.43294 .42231 L
.43087 .43573 L
.42903 .45268 L
.42832 .4618 L
.42772 .47215 L
.42713 .49105 L
.42713 .50892 L
.42739 .51965 L
.42782 .52962 L
.42906 .54746 L
.43 .55682 L
.43102 .56499 L
.43379 .58152 L
.43642 .5926 L
.43917 .60116 L
.44244 .60852 L
.44617 .61417 L
.45003 .61763 L
.452 .61864 L
.45417 .61925 L
.45803 .61916 L
.4616 .61796 L
Mistroke
.46507 .6159 L
.46876 .61292 L
.47515 .60611 L
.48593 .59123 L
.50434 .56092 L
.5113 .54966 L
.51741 .54103 L
.52 .53803 L
.5223 .53583 L
.52426 .53434 L
.52631 .53319 L
.52732 .53277 L
.52842 .53242 L
.52897 .53229 L
.52955 .53216 L
.53062 .532 L
.53161 .5319 L
.53266 .53185 L
.53355 .53182 L
.53453 .5318 L
.53513 .53178 L
.5357 .53176 L
.53676 .5317 L
.53735 .53163 L
.5379 .53156 L
.5385 .53145 L
.53913 .5313 L
.54016 .53097 L
.54112 .53055 L
.54215 .52994 L
.54324 .52909 L
.54421 .52811 L
.54506 .52705 L
.54593 .52571 L
.54682 .52404 L
.54759 .52228 L
.54825 .52048 L
.54936 .51649 L
.54987 .51401 L
.55028 .51158 L
.55063 .50881 L
.55078 .50722 L
.5509 .50575 L
.55099 .50421 L
.55105 .50278 L
.55109 .50121 L
.55109 .49955 L
.55103 .49681 L
.55096 .49528 L
.55086 .49388 L
Mistroke
.55064 .49161 L
.55033 .48926 L
.54993 .48699 L
.54948 .48506 L
.54854 .48208 L
.54795 .4807 L
.54738 .47963 L
.54666 .47858 L
.54598 .47783 L
.5452 .47722 L
.5448 .47699 L
.54436 .4768 L
.54361 .47661 L
.54319 .47656 L
.54281 .47656 L
.54206 .47666 L
.54135 .47684 L
.53851 .47825 L
.53719 .47906 L
.53602 .47971 L
.53539 .47999 L
.53506 .48011 L
.53471 .48022 L
.53435 .4803 L
.53403 .48035 L
.53365 .48038 L
.53331 .48037 L
.53271 .48027 L
.53205 .48004 L
.53142 .4797 L
.53083 .47928 L
.52964 .47813 L
.52846 .47667 L
.52542 .47185 L
.51687 .45581 L
.50181 .42832 L
.49137 .41102 L
.47959 .39419 L
.47345 .38712 L
.46733 .3817 L
.46383 .37952 L
.45998 .37805 L
.45646 .37769 L
.45323 .37836 L
.44967 .3804 L
.44641 .38369 L
.44298 .38901 L
.4395 .39686 L
.43786 .40167 L
.43617 .40756 L
Mistroke
.43339 .42003 L
.43111 .4342 L
.42941 .4489 L
.42812 .46535 L
.42732 .48363 L
.42709 .49963 L
.42734 .5171 L
.42817 .53539 L
.42889 .54518 L
.42969 .55369 L
.43163 .56902 L
.43388 .58175 L
.4363 .59198 L
.43915 .60095 L
.44178 .60708 L
.44482 .61226 L
.44823 .61612 L
.45199 .61848 L
.45558 .61921 L
.45887 .61879 L
.46269 .61721 L
.46479 .6159 L
.46668 .6145 L
.47356 .60774 L
.48737 .58868 L
.50584 .55789 L
.51736 .54046 L
.51963 .53782 L
.52191 .53562 L
.52316 .53462 L
.52427 .53386 L
.52531 .53328 L
.52639 .53279 L
.52754 .53239 L
.52859 .53214 L
.52917 .53204 L
.52972 .53197 L
.53031 .53191 L
.53096 .53188 L
.53148 .53186 L
.53204 .53186 L
.53264 .53187 L
.53319 .53189 L
.53417 .53192 L
.53524 .53196 L
.5363 .53197 L
.5373 .53193 L
.53827 .53184 L
.53916 .53168 L
.54012 .53142 L
Mistroke
.54116 .531 L
.54223 .53041 L
.54321 .52968 L
.54414 .52878 L
.5451 .52763 L
.54671 .525 L
.54753 .52323 L
.54824 .52136 L
.54895 .51907 L
.54962 .51642 L
.55008 .51413 L
.5505 .5115 L
.55081 .50901 L
.55103 .50663 L
.5512 .50377 L
.55127 .50116 L
.55128 .49972 L
.55126 .49818 L
.55116 .49542 L
.55099 .49304 L
.55077 .49091 L
.55046 .48869 L
.55006 .48646 L
.54956 .48434 L
.54903 .48254 L
.5485 .48109 L
.54789 .47975 L
.54727 .47867 L
.54669 .47785 L
.54609 .47717 L
.5455 .47667 L
.54481 .47624 L
.54416 .47598 L
.54344 .47584 L
.54267 .47583 L
.54192 .47595 L
.5415 .47606 L
.54112 .4762 L
.53967 .47688 L
.53711 .47852 L
.53575 .47936 L
.5351 .47969 L
.53451 .47994 L
.5339 .48012 L
.53325 .48021 L
.53293 .48021 L
.53258 .48019 L
.53221 .48012 L
.53186 .48002 L
.53128 .47976 L
Mistroke
.53063 .47936 L
.53001 .47885 L
.52942 .47827 L
.52692 .47498 L
.51942 .46136 L
.50825 .44026 L
.48975 .40879 L
.48274 .39857 L
.47541 .38943 L
.47203 .38591 L
.46833 .38265 L
.46616 .38107 L
.46416 .37987 L
.46023 .37827 L
.45623 .37787 L
.45256 .37878 L
.44859 .38147 L
.44664 .38357 L
.44454 .38648 L
.44114 .39296 L
.43776 .40216 L
.43488 .41305 L
.43258 .42475 L
.43052 .43896 L
.429 .45367 L
.42783 .47102 L
.42719 .49059 L
.42721 .5103 L
.42746 .5201 L
.42792 .53058 L
.4292 .54833 L
.43088 .56347 L
.43303 .57721 L
.43542 .58841 L
.43781 .59693 L
.44063 .60449 L
.44393 .61081 L
.44759 .61542 L
.4508 .61783 L
.45439 .61902 L
.45641 .61911 L
.45861 .61878 L
.46257 .6172 L
.46636 .61468 L
.46979 .61168 L
.47717 .60332 L
.48434 .59331 L
.50388 .56131 L
.51601 .54247 L
.51867 .53919 L
Mistroke
.52127 .53651 L
.52336 .5348 L
.5245 .53405 L
.52555 .53348 L
.52652 .53305 L
.52757 .53268 L
.5285 .53244 L
.52937 .53227 L
.53029 .53216 L
.53131 .53208 L
.53237 .53206 L
.53336 .53206 L
.53429 .53207 L
.53517 .53208 L
.53596 .53207 L
.53683 .53203 L
.53776 .53194 L
.53875 .53178 L
.53968 .53155 L
.54051 .53125 L
.54147 .5308 L
.54234 .53026 L
.54328 .52952 L
.54425 .52854 L
.54524 .5273 L
.54613 .5259 L
.54689 .52445 L
.54765 .52271 L
.54888 .51906 L
.5498 .51519 L
.55023 .51286 L
.55056 .51059 L
.55084 .50802 L
.55106 .50519 L
.55119 .50232 L
.55122 .49966 L
.5512 .49815 L
.55116 .49679 L
.55108 .49525 L
.55099 .49383 L
.55087 .49247 L
.55072 .49108 L
.55039 .4887 L
.54995 .48633 L
.54938 .484 L
.54882 .48223 L
.54826 .48082 L
.54757 .47944 L
.54687 .47836 L
.5462 .47757 L
Mistroke
.54556 .477 L
.54484 .47655 L
.54406 .47626 L
.54331 .47614 L
.54288 .47614 L
.54247 .47618 L
.54205 .47625 L
.54167 .47635 L
.54081 .47666 L
.5401 .47701 L
.53933 .47744 L
.53798 .47831 L
.53646 .4793 L
.53566 .47976 L
.53492 .4801 L
.5343 .48031 L
.53364 .48044 L
.53327 .48046 L
.53292 .48044 L
.5326 .4804 L
.53225 .48031 L
.53192 .48019 L
.53156 .48003 L
.53089 .47962 L
.53024 .47908 L
.52961 .47846 L
.52637 .4739 L
.51822 .45871 L
.50624 .4363 L
.48656 .40376 L
.47916 .39366 L
.47525 .38905 L
.4715 .38519 L
.46806 .38224 L
.46418 .37969 L
.46021 .37808 L
.45802 .37769 L
.45595 .3777 L
.45217 .37877 L
.44825 .38161 L
.44499 .38559 L
.44159 .39175 L
.43816 .40067 L
.43638 .40672 L
.43486 .41287 L
.43223 .42654 L
.43019 .44136 L
.4287 .4569 L
.42762 .47478 L
.42713 .49233 L
Mistroke
.42714 .50853 L
.42771 .52717 L
.42829 .53735 L
.42899 .54646 L
.43065 .56209 L
.43292 .5769 L
.43577 .59005 L
.43756 .59634 L
.4393 .60141 L
.44271 .60895 L
.44452 .6119 L
.44654 .61452 L
.45016 .61763 L
.45411 .61915 L
.45785 .61911 L
.46125 .61803 L
.46467 .6161 L
.46822 .61331 L
.47434 .60697 L
.48673 .58988 L
.50386 .56156 L
.51608 .54255 L
.51875 .53923 L
.52135 .53651 L
.52345 .53478 L
.52458 .53401 L
.52563 .53342 L
.52661 .53297 L
.52765 .53259 L
.52859 .53233 L
.52945 .53216 L
.53037 .53202 L
.53139 .53194 L
.53244 .53189 L
.53343 .53188 L
.53436 .53188 L
.53523 .53187 L
.53602 .53185 L
.53688 .5318 L
.5378 .5317 L
.53879 .53153 L
.53962 .53132 L
.54053 .53099 L
.54148 .53054 L
.54235 .52999 L
.54329 .52925 L
.54426 .52827 L
.54524 .52702 L
.54612 .52563 L
.54763 .52246 L
Mistroke
.54884 .51883 L
.54976 .51499 L
.55016 .51283 L
.55052 .51034 L
.55081 .50766 L
.551 .50509 L
.55113 .50232 L
.55115 .50074 L
.55115 .4993 L
.55109 .49668 L
.55093 .49398 L
.55069 .49144 L
.55039 .48918 L
.55006 .48728 L
.54965 .48538 L
.54913 .48349 L
.5485 .48167 L
.54777 .48007 L
.54704 .47884 L
.54632 .47793 L
.54564 .47729 L
.54526 .47701 L
.54483 .47677 L
.54406 .47647 L
.54333 .47634 L
.54265 .47634 L
.54192 .47646 L
.54115 .47669 L
.54048 .47697 L
.53987 .47727 L
.53852 .47806 L
.53699 .47902 L
.53627 .47945 L
.53561 .47978 L
.53503 .48003 L
.5344 .48023 L
.53378 .48034 L
.53312 .48035 L
.53278 .4803 L
.53245 .48023 L
.53184 .48 L
.53117 .47963 L
.53043 .47905 L
.52902 .47757 L
.52762 .47566 L
.519 .46009 L
.50496 .43398 L
.49514 .41715 L
.48405 .40019 L
.4781 .39239 L
Mistroke
.47216 .38587 L
.46878 .38285 L
.46563 .38059 L
.46208 .37875 L
.45822 .37777 L
.45437 .37803 L
.45084 .37958 L
.44704 .38296 L
.44517 .38539 L
.44316 .38869 L
.43995 .39569 L
.43676 .40541 L
.43407 .41664 L
.43192 .42861 L
.42985 .44462 L
.42839 .46124 L
.42754 .47709 L
.42712 .49479 L
.42726 .51424 L
.42758 .52387 L
.4281 .53421 L
.42948 .55158 L
.43125 .56639 L
.43345 .57962 L
.43588 .5904 L
.43831 .59856 L
.44116 .60578 L
.44446 .61174 L
.44813 .61603 L
.45136 .6182 L
.45496 .61917 L
.45892 .61878 L
.4609 .61809 L
.46305 .61701 L
.4668 .6144 L
.47021 .61133 L
.48467 .59287 L
.50409 .56092 L
.51114 .54942 L
.51736 .5406 L
.51986 .53772 L
.52233 .5354 L
.52433 .53396 L
.52542 .53335 L
.52645 .53288 L
.52741 .53254 L
.52845 .53226 L
.52939 .53209 L
.53025 .53199 L
.53128 .53192 L
Mistroke
.53221 .53191 L
.53328 .53192 L
.5343 .53195 L
.53519 .53197 L
.53613 .53196 L
.53693 .53194 L
.53781 .53186 L
.53875 .53172 L
.53975 .53148 L
.54069 .53115 L
.54154 .53074 L
.54246 .53017 L
.5433 .52951 L
.54427 .52854 L
.54514 .52748 L
.54678 .52474 L
.54756 .52301 L
.54832 .52096 L
.54888 .51914 L
.54942 .51706 L
.55023 .51298 L
.55062 .51031 L
.5509 .50772 L
.55108 .50534 L
.5512 .50273 L
.55124 .4999 L
.5512 .49729 L
.55114 .49582 L
.55106 .4945 L
.55095 .49301 L
.55081 .49164 L
.55047 .48903 L
.55008 .48679 L
.54956 .48455 L
.54894 .48244 L
.54833 .48086 L
.54762 .47941 L
.54691 .47829 L
.54623 .47747 L
.54559 .47689 L
.54487 .47643 L
.54411 .47613 L
.5434 .476 L
.54262 .476 L
.54223 .47605 L
.5418 .47614 L
.54105 .47639 L
.54035 .47669 L
.53724 .47859 L
.53593 .4794 L
Mistroke
.5353 .47973 L
.53472 .47998 L
.53407 .48018 L
.53373 .48025 L
.53337 .48028 L
.53272 .48027 L
.53213 .48014 L
.53154 .47991 L
.53091 .47955 L
.53036 .47913 L
.52974 .47856 L
.52828 .47685 L
.5268 .47468 L
.51965 .46165 L
.50637 .43672 L
.49705 .42047 L
.48641 .40369 L
.47502 .38892 L
.46869 .38286 L
.46495 .38025 L
.46138 .37856 L
.45771 .37779 L
.45384 .37824 L
.45057 .37982 L
.44706 .383 L
.44339 .38833 L
.44143 .39224 L
.43971 .39639 L
.43658 .40614 L
.43394 .41737 L
.4317 .4302 L
.42974 .44578 L
.42836 .46189 L
.42753 .47748 L
.42712 .49629 L
.42715 .50701 L
.42734 .51687 L
.42813 .53447 L
.42954 .55208 L
.43055 .56102 L
.43161 .56875 L
.43288 .5765 L
.43443 .58426 L
.43735 .59553 L
.43911 .60076 L
.44079 .6049 L
.44415 .61123 L
.44794 .61582 L
.45156 .61825 L
.45503 .61914 L
Mistroke
.45824 .61891 L
.46177 .61767 L
.46539 .61546 L
.46872 .61273 L
.47444 .60673 L
.48022 .5993 L
.50044 .56716 L
.50818 .55422 L
.51486 .54404 L
.51766 .54038 L
.5201 .53763 L
.52218 .53569 L
.52428 .53415 L
.52532 .53356 L
.52644 .53304 L
.52744 .53267 L
.52837 .53242 L
.52893 .5323 L
.52946 .5322 L
.53045 .53208 L
.53151 .53202 L
.53211 .532 L
.53266 .53199 L
.53318 .532 L
.53374 .532 L
.53435 .53201 L
.5349 .53201 L
.53591 .532 L
.53648 .53198 L
.53701 .53195 L
.53807 .53184 L
.53866 .53174 L
.5392 .53162 L
.53979 .53145 L
.54042 .53123 L
.54157 .53069 L
.54252 .53008 L
.54337 .52939 L
.54426 .52849 L
.54519 .52731 L
.54675 .52469 L
.54806 .52157 L
.54878 .51936 L
.54935 .51718 L
.5499 .51466 L
.55038 .51177 L
.55074 .50897 L
.55098 .50631 L
.55113 .50374 L
.55121 .50102 L
Mistroke
.55119 .49819 L
.5511 .49566 L
.55101 .4943 L
.5509 .49285 L
.55062 .49033 L
.55028 .48811 L
.54985 .48594 L
.54892 .48256 L
.54831 .48098 L
.54761 .47954 L
.5469 .47843 L
.54622 .47762 L
.54545 .47694 L
.545 .47666 L
.54457 .47645 L
.54412 .47629 L
.54371 .4762 L
.54323 .47615 L
.54278 .47616 L
.54208 .47625 L
.54134 .47646 L
.54064 .47674 L
.54001 .47705 L
.53715 .47883 L
.53581 .47964 L
.53513 .47997 L
.53475 .48012 L
.53441 .48023 L
.53408 .48032 L
.53372 .48038 L
.53311 .4804 L
.53248 .48032 L
.5319 .48013 L
.53135 .47986 L
.53076 .47946 L
.52965 .47845 L
.52825 .47674 L
.52687 .47469 L
.51925 .46071 L
.50753 .43865 L
.48826 .40631 L
.48207 .39747 L
.47481 .3886 L
.4704 .38421 L
.46622 .38095 L
.46417 .37972 L
.46192 .37867 L
.45977 .37801 L
.45778 .37771 L
.45372 .37819 L
Mistroke
.44994 .38018 L
.44662 .38343 L
.44315 .38867 L
.43958 .39662 L
.4379 .40154 L
.43614 .40765 L
.43334 .42027 L
.43113 .434 L
.42927 .45031 L
.42854 .45913 L
.4279 .46922 L
.42721 .48768 L
.42711 .50534 L
.42729 .51537 L
.42765 .52578 L
.42876 .54366 L
.42962 .55307 L
.43057 .56138 L
.43175 .56987 L
.4332 .57837 L
.43599 .59084 L
.43896 .60044 L
.4421 .60775 L
.44517 .61278 L
.44863 .6165 L
.45253 .61871 L
.45451 .61917 L
.45664 .61922 L
.46049 .61831 L
.46418 .61638 L
.46753 .61386 L
.47481 .60636 L
.48663 .58997 L
.5036 .56191 L
.51082 .55011 L
.51716 .54106 L
.5197 .53809 L
.5222 .53569 L
.52422 .53419 L
.52532 .53354 L
.52635 .53305 L
.52733 .53267 L
.52838 .53237 L
.52932 .53217 L
.53019 .53205 L
.53113 .53196 L
.53216 .53192 L
.53268 .53191 L
.53323 .53191 L
.53424 .53192 L
Mistroke
.53513 .53192 L
.5361 .5319 L
.53711 .53184 L
.53805 .53174 L
.53892 .53157 L
.53972 .53137 L
.54062 .53104 L
.54147 .53063 L
.54236 .53008 L
.5433 .52933 L
.54493 .52755 L
.54586 .52618 L
.5467 .52466 L
.54813 .52125 L
.54877 .51924 L
.54938 .51693 L
.54984 .51479 L
.55026 .51236 L
.55063 .50965 L
.55089 .50703 L
.55101 .50549 L
.5511 .50385 L
.55115 .50245 L
.55118 .50092 L
.55117 .49825 L
.55108 .49578 L
.55094 .49362 L
.55072 .49137 L
.55041 .48906 L
.55 .48678 L
.54959 .48499 L
.54909 .48321 L
.54806 .48054 L
.54743 .47933 L
.54682 .47841 L
.54623 .47772 L
.54556 .47712 L
.54492 .4767 L
.54432 .47644 L
.54361 .47627 L
.54294 .47622 L
.54217 .4763 L
.54147 .47648 L
.54081 .47672 L
.54022 .477 L
.53889 .47774 L
.53638 .47932 L
.53572 .47968 L
.53511 .47996 L
.53448 .48018 L
Mistroke
.53415 .48026 L
.53379 .48032 L
.53315 .48035 L
.53279 .48031 L
.53244 .48024 L
.53208 .48013 L
.53175 .47999 L
.531 .47955 L
.53034 .47903 L
.5296 .47831 L
.52819 .47657 L
.52102 .46404 L
.50749 .43858 L
.49893 .42352 L
.48718 .40473 L
.48099 .39607 L
.47377 .38751 L
.47007 .38395 L
.46647 .38115 L
.46316 .37924 L
.45952 .37798 L
.45733 .37772 L
.45526 .37786 L
.45143 .37924 L
.4493 .38072 L
.44738 .38258 L
.4453 .38521 L
.44317 .38868 L
.43979 .39611 L
.43688 .40499 L
.43402 .4169 L
.43261 .42441 L
.43142 .43202 L
.42954 .44763 L
.42874 .45652 L
.42806 .46648 L
.42756 .47668 L
.42722 .48763 L
.42714 .5074 L
.42765 .52554 L
.42862 .5417 L
.4302 .5582 L
.43242 .57394 L
.43391 .58186 L
.4354 .58848 L
.43713 .59485 L
.43916 .60094 L
.44283 .60907 L
.44494 .61242 L
.44697 .6149 L
Mistroke
.44898 .61673 L
.45092 .61798 L
.45458 .61914 L
.45854 .61888 L
.46077 .61815 L
.46282 .61715 L
.46622 .61487 L
.4698 .61175 L
.476 .60487 L
.48851 .58694 L
.5071 .55595 L
.5131 .54651 L
.51847 .53934 L
.5212 .53646 L
.52353 .53455 L
.52461 .53385 L
.52576 .53324 L
.52675 .53282 L
.52781 .53247 L
.52889 .53222 L
.52989 .53206 L
.5305 .532 L
.53108 .53196 L
.5316 .53194 L
.53216 .53193 L
.53277 .53193 L
.53331 .53194 L
.53395 .53195 L
.53454 .53196 L
.5356 .53197 L
.5362 .53196 L
.53675 .53194 L
.53774 .53186 L
.53865 .53172 L
.53965 .53148 L
.54021 .5313 L
.54072 .5311 L
.54172 .5306 L
.54279 .52988 L
.54378 .52901 L
.54466 .52804 L
.54549 .52692 L
.54632 .52556 L
.54768 .52264 L
.54894 .51884 L
.54955 .51641 L
.55004 .51399 L
.55042 .51161 L
.55072 .50929 L
.55093 .50715 L
Mistroke
.55109 .5048 L
.5512 .50221 L
.55123 .49949 L
.55118 .4972 L
.55106 .49474 L
.55096 .49339 L
.55083 .49197 L
.55052 .48948 L
.55014 .48723 L
.54973 .4853 L
.54916 .48324 L
.5486 .48159 L
.54788 .47997 L
.54715 .47872 L
.54648 .47783 L
.54574 .4771 L
.5451 .47664 L
.54438 .4763 L
.5436 .4761 L
.54316 .47606 L
.54276 .47607 L
.54198 .47618 L
.54124 .4764 L
.53833 .47795 L
.5358 .47954 L
.53517 .47985 L
.53459 .48008 L
.53427 .48018 L
.53392 .48026 L
.53331 .48032 L
.53296 .48032 L
.53264 .48028 L
.53226 .4802 L
.53191 .48008 L
.53127 .47977 L
.53057 .47929 L
.52937 .47814 L
.52795 .47635 L
.52467 .47101 L
.51656 .45564 L
.50208 .42903 L
.49215 .41242 L
.48104 .39617 L
.47405 .38784 L
.47028 .38417 L
.46811 .38237 L
.46609 .38093 L
.46402 .3797 L
.46181 .37869 L
.45774 .37777 L
Mistroke
.45544 .37786 L
.45331 .37839 L
.45098 .37953 L
.44852 .38144 L
.4447 .38613 L
.44262 .38973 L
.44078 .3937 L
.43757 .40265 L
.43453 .4145 L
.43217 .42709 L
.43032 .44043 L
.42875 .45653 L
.42762 .47512 L
.42728 .4854 L
.42712 .49519 L
.42725 .51349 L
.42802 .53269 L
.42873 .54305 L
.42954 .55216 L
.43125 .56638 L
.43357 .58019 L
.43642 .59238 L
.43941 .60158 L
.44122 .60589 L
.44328 .60983 L
.44514 .61268 L
.44717 .61509 L
.45109 .61806 L
.45478 .61914 L
.45683 .61915 L
.45903 .61874 L
.46298 .61705 L
.46523 .6156 L
.46757 .61377 L
.47165 .60987 L
.48454 .59309 L
.49455 .57711 L
.51115 .54953 L
.51696 .54124 L
.51965 .53809 L
.52229 .53559 L
.52447 .53402 L
.52567 .53336 L
.52677 .53288 L
.52778 .53255 L
.52868 .53232 L
.52972 .53214 L
.5307 .53203 L
.53157 .53198 L
.53253 .53197 L
Mistroke
.53353 .53197 L
.53446 .53198 L
.53534 .53198 L
.53614 .53197 L
.53702 .53192 L
.53795 .53183 L
.53888 .53167 L
.53988 .5314 L
.54081 .53105 L
.54164 .53063 L
.5426 .52999 L
.54362 .52913 L
.54456 .52811 L
.54539 .52701 L
.54693 .52431 L
.5477 .52252 L
.54838 .52064 L
.54942 .51688 L
.54992 .51454 L
.55031 .51226 L
.55068 .50943 L
.55095 .5067 L
.55111 .5042 L
.5512 .50148 L
.55121 .50008 L
.5512 .49854 L
.55115 .49696 L
.55109 .49551 L
.55091 .49298 L
.55077 .49161 L
.55062 .4904 L
.55027 .48803 L
.5498 .48573 L
.54935 .48394 L
.54878 .48218 L
.54812 .48055 L
.54734 .4791 L
.54657 .47801 L
.54582 .47725 L
.5451 .47672 L
.54442 .47639 L
.54366 .47619 L
.54323 .47615 L
.54284 .47615 L
.54206 .47626 L
.54162 .47637 L
.54121 .4765 L
.53971 .4772 L
.53709 .47885 L
.53573 .47966 L
Mistroke
.53508 .47997 L
.53448 .48019 L
.53393 .48032 L
.53335 .48038 L
.5327 .48033 L
.53211 .48018 L
.53156 .47995 L
.53097 .47959 L
.52985 .47864 L
.52845 .47699 L
.52676 .4745 L
.5227 .4673 L
.51214 .44718 L
.49496 .41689 L
.4834 .39931 L
.47763 .39184 L
.47081 .38461 L
.46689 .38143 L
.46313 .37921 L
.4591 .37789 L
.45683 .3777 L
.45474 .37794 L
.4525 .37868 L
.45043 .37985 L
.44819 .38172 L
.44584 .38445 L
.44366 .38778 L
.44168 .39163 L
.43817 .4007 L
.43527 .41121 L
.43258 .42455 L
.43066 .43762 L
.42899 .45351 L
.42776 .47198 L
.42734 .48277 L
.42713 .49276 L
.42722 .51223 L
.42788 .53028 L
.42899 .5463 L
.43069 .56224 L
.43272 .57571 L
.43492 .58651 L
.43767 .59663 L
.44099 .60542 L
.44276 .60897 L
.44472 .61213 L
.44836 .61625 L
.45041 .61773 L
.45232 .61862 L
.45444 .61914 L
Mistroke
.45668 .6192 L
.46044 .61831 L
.46255 .61732 L
.46452 .61613 L
.46811 .61334 L
.47131 .61026 L
.47815 .60215 L
.51206 .54816 L
.51743 .54068 L
.52004 .5377 L
.52234 .53555 L
.52438 .53407 L
.52542 .53347 L
.5265 .53297 L
.5274 .53264 L
.52838 .53236 L
.52927 .53218 L
.53009 .53206 L
.53114 .53197 L
.53173 .53194 L
.53228 .53193 L
.53328 .53193 L
.53435 .53194 L
.5353 .53194 L
.5362 .53192 L
.53717 .53187 L
.53822 .53174 L
.53927 .53152 L
.53986 .53135 L
.54041 .53116 L
.5415 .53065 L
.54265 .52991 L
.54368 .52902 L
.54463 .52798 L
.54545 .52687 L
.54629 .52549 L
.54776 .52232 L
.54893 .51874 L
.54954 .51629 L
.55004 .5138 L
.55041 .51146 L
.55074 .50881 L
.55097 .50617 L
.55107 .50465 L
.55114 .50322 L
.55118 .50171 L
.5512 .50034 L
.55119 .49884 L
.55115 .49727 L
.55103 .49472 L
Mistroke
.55084 .49243 L
.55056 .49003 L
.55018 .48764 L
.54976 .4856 L
.54931 .48389 L
.54878 .48224 L
.54814 .48065 L
.54759 .47955 L
.54696 .47855 L
.54626 .4777 L
.54559 .47709 L
.54492 .47665 L
.54419 .47635 L
.54349 .4762 L
.54283 .47618 L
.54219 .47625 L
.5416 .47639 L
.54094 .47663 L
.54031 .4769 L
.53745 .47862 L
.53614 .47943 L
.53558 .47973 L
.53498 .48 L
.53436 .4802 L
.53378 .48032 L
.53312 .48035 L
.53251 .48026 L
.53188 .48006 L
.53152 .47989 L
.53118 .47969 L
.53048 .47917 L
.5297 .47844 L
.52692 .47472 L
.52337 .46853 L
.51454 .4517 L
.49974 .42491 L
.48852 .40673 L
.4821 .39754 L
.47566 .38956 L
.46916 .38319 L
.46576 .38069 L
.46195 .37872 L
.45809 .37777 L
.45591 .37777 L
.45392 .37817 L
.4501 .3801 L
.44655 .38355 L
.44349 .38811 L
.44039 .3946 L
.43766 .40236 L
Mistroke
.43538 .41076 L
.43298 .42233 L
.43078 .43669 L
.42914 .4518 L
.42804 .46673 L
.42727 .48552 L
.42711 .50369 L
.42743 .5199 L
.42828 .53693 L
.42976 .55428 L
.43071 .56243 L
.43192 .57085 L
.43439 .58414 L
.43706 .59464 L
.43987 .60278 L
.44304 .60945 L
.44589 .61366 L
.4491 .61683 L
.45265 .61871 L
.45648 .61919 L
.46008 .61842 L
.46332 .61686 L
.46713 .61415 L
.47104 .61051 L
.47769 .60272 L
.49079 .58329 L
.50811 .55433 L
.51421 .54492 L
.51909 .53866 L
.52151 .53621 L
.52272 .53518 L
.52398 .53427 L
.52502 .53365 L
.52614 .53309 L
.52714 .5327 L
.52808 .53242 L
.52896 .53222 L
.52991 .53207 L
.53091 .53198 L
.53183 .53194 L
.5327 .53194 L
.53349 .53194 L
.53435 .53196 L
.53526 .53196 L
.53626 .53195 L
.53717 .5319 L
.53815 .53179 L
.53871 .5317 L
.53923 .53158 L
.54016 .5313 L
Mistroke
.541 .53096 L
.54196 .53044 L
.54286 .52981 L
.54379 .52898 L
.54477 .52788 L
.54559 .52673 L
.54642 .52533 L
.54786 .52213 L
.549 .5186 L
.54954 .5164 L
.55004 .5139 L
.55041 .51163 L
.55073 .50907 L
.55089 .50747 L
.55101 .50598 L
.5511 .50454 L
.55116 .50301 L
.55122 .50036 L
.55121 .49887 L
.55118 .49748 L
.55108 .49522 L
.5509 .49283 L
.55064 .49045 L
.55033 .48836 L
.54963 .48498 L
.54917 .48331 L
.54871 .48194 L
.54816 .48061 L
.54755 .4794 L
.54683 .4783 L
.54614 .4775 L
.54548 .47693 L
.54485 .47654 L
.54415 .47626 L
.54339 .47612 L
.54297 .4761 L
.54257 .47612 L
.54184 .47626 L
.54105 .47651 L
.54022 .47688 L
.53745 .47857 L
.53595 .47949 L
.53516 .47988 L
.53478 .48004 L
.53444 .48015 L
.53382 .4803 L
.53317 .48034 L
.53283 .48032 L
.53246 .48026 L
.5321 .48016 L
Mistroke
.53178 .48003 L
.53119 .47972 L
.53054 .47926 L
.52932 .47807 L
.52777 .47606 L
.5262 .47362 L
.51729 .45699 L
.50466 .43355 L
.4951 .41716 L
.48407 .40027 L
.47687 .39097 L
.47284 .38658 L
.46842 .3826 L
.46459 .37999 L
.46238 .3789 L
.4603 .37818 L
.45662 .37774 L
.45269 .37862 L
.44876 .38121 L
.44659 .38351 L
.44462 .38624 L
.44116 .39281 L
.43774 .40212 L
.43498 .41248 L
.43269 .42394 L
.43058 .43828 L
.42883 .45552 L
.42769 .47355 L
.42717 .49063 L
.42719 .51057 L
.42782 .52904 L
.42891 .54531 L
.43033 .55928 L
.43229 .57316 L
.4348 .58595 L
.43769 .59665 L
.43941 .60161 L
.44113 .6057 L
.44462 .61196 L
.44796 .61587 L
.44992 .61739 L
.45203 .61848 L
.45585 .61921 L
.45819 .61896 L
.46039 .6183 L
.46235 .6174 L
.46445 .61615 L
.4683 .61314 L
.4718 .60972 L
.47929 .6006 L
Mistroke
.49232 .58081 L
.5092 .5526 L
.5153 .54344 L
.5181 .53984 L
.52084 .53688 L
.52307 .53496 L
.52422 .53416 L
.52542 .53347 L
.52651 .53297 L
.52749 .53262 L
.52841 .53237 L
.52938 .53217 L
.53034 .53205 L
.53135 .53198 L
.53187 .53196 L
.53245 .53195 L
.53346 .53195 L
.53442 .53197 L
.53545 .53197 L
.53642 .53195 L
.53731 .53189 L
.53822 .53178 L
.53906 .53161 L
.53998 .53136 L
.54095 .53097 L
.54177 .53054 L
.54253 .53004 L
.54422 .5285 L
.54505 .52748 L
.54589 .52622 L
.54729 .5235 L
.5486 .51992 L
.54924 .5176 L
.54977 .51528 L
.55024 .51267 L
.55061 .51009 L
.55086 .5077 L
.55106 .50505 L
.55113 .50367 L
.55118 .50215 L
.55121 .50056 L
.5512 .49909 L
.55113 .49649 L
.55097 .49378 L
.55074 .49137 L
.55046 .48925 L
.55009 .48707 L
.54961 .48495 L
.5491 .48313 L
.54856 .4816 L
Mistroke
.54804 .48039 L
.54745 .47928 L
.54689 .47842 L
.54625 .47765 L
.54564 .4771 L
.54507 .4767 L
.54438 .47638 L
.54375 .47621 L
.54301 .47614 L
.54232 .4762 L
.54163 .47636 L
.54089 .47662 L
.53959 .47727 L
.53677 .47905 L
.53541 .47981 L
.53474 .48009 L
.53436 .48021 L
.53401 .48029 L
.53339 .48037 L
.53283 .48034 L
.53217 .48019 L
.53155 .47993 L
.531 .4796 L
.53039 .47913 L
.52909 .4778 L
.52651 .4741 L
.51858 .45944 L
.50535 .43476 L
.4859 .40285 L
.47935 .39396 L
.47178 .38552 L
.46943 .38341 L
.46718 .38165 L
.46497 .38019 L
.46291 .37911 L
.45883 .37785 L
.45667 .37772 L
.4544 .37803 L
.45073 .37965 L
.44688 .38314 L
.44338 .38829 L
.44035 .39468 L
.43706 .40435 L
.43389 .41752 L
.43136 .43237 L
.42951 .44793 L
.42813 .46529 L
.42734 .48275 L
.42709 .49882 L
.42732 .51635 L
Mistroke
.42814 .53477 L
.42885 .54461 L
.42964 .55317 L
.43157 .5686 L
.43381 .5814 L
.43623 .59173 L
.43909 .60077 L
.44172 .60696 L
.44476 .61218 L
.44818 .61608 L
.45194 .61847 L
.45554 .61922 L
.45882 .61882 L
.46266 .61725 L
.46457 .61608 L
.46666 .61454 L
.47357 .60778 L
.48739 .58874 L
.50589 .55801 L
.51241 .54761 L
.51748 .54059 L
.52206 .53577 L
.52429 .53411 L
.52549 .53343 L
.52657 .53294 L
.52773 .53253 L
.52879 .53227 L
.52934 .53217 L
.52995 .53208 L
.53058 .53201 L
.53117 .53197 L
.53172 .53195 L
.53225 .53194 L
.53324 .53193 L
.5343 .53194 L
.5349 .53195 L
.53546 .53195 L
.53652 .53192 L
.53752 .53185 L
.53841 .53172 L
.53937 .53152 L
.54042 .53118 L
.54093 .53096 L
.5415 .53067 L
.54249 .53005 L
.54339 .52932 L
.54431 .52837 L
.54526 .52717 L
.54685 .52444 L
.54765 .52262 L
Mistroke
.54834 .52071 L
.54904 .51838 L
.54967 .51571 L
.55011 .51341 L
.55051 .51076 L
.5508 .50828 L
.551 .50591 L
.55115 .50308 L
.5512 .5005 L
.5512 .49909 L
.55117 .49757 L
.55104 .49487 L
.55086 .49254 L
.55063 .49046 L
.5503 .4883 L
.54989 .48615 L
.54939 .48411 L
.54885 .48238 L
.54831 .481 L
.5477 .47973 L
.54708 .47871 L
.5465 .47795 L
.5459 .47733 L
.54532 .47687 L
.54463 .47649 L
.54399 .47627 L
.54328 .47616 L
.54253 .47618 L
.54179 .47632 L
.54137 .47645 L
.54099 .47659 L
.53956 .47728 L
.53703 .47888 L
.53569 .47966 L
.53505 .47996 L
.53447 .48017 L
.53386 .48031 L
.53322 .48035 L
.53288 .48033 L
.53251 .48027 L
.53216 .48017 L
.53184 .48005 L
.53125 .47974 L
.5306 .47929 L
.52937 .4781 L
.52811 .4765 L
.52685 .47462 L
.51922 .46065 L
.50779 .43916 L
.48893 .40736 L
Mistroke
.48179 .39713 L
.47435 .38813 L
.47093 .38473 L
.46719 .38166 L
.4652 .38034 L
.46298 .37916 L
.45904 .37789 L
.45502 .3779 L
.45135 .37928 L
.44741 .38255 L
.44547 .38497 L
.44341 .38826 L
.44007 .3954 L
.43678 .40534 L
.43402 .41689 L
.43184 .42915 L
.42991 .44401 L
.42854 .45924 L
.42754 .47703 L
.4271 .49684 L
.42713 .50682 L
.42736 .51761 L
.42826 .53668 L
.42973 .55404 L
.43158 .56865 L
.43389 .5818 L
.43641 .59235 L
.43891 .60026 L
.44182 .60714 L
.44519 .61276 L
.4489 .61667 L
.45215 .61854 L
.45575 .61921 L
.45778 .61904 L
.45998 .61846 L
.46394 .61649 L
.46771 .61366 L
.47111 .61045 L
.48546 .5917 L
.50463 .5601 L
.51616 .54226 L
.51871 .5391 L
.5212 .53651 L
.52321 .53483 L
.52531 .5335 L
.5265 .53295 L
.52755 .53258 L
.52814 .53241 L
.52876 .53227 L
.5293 .53217 L
Mistroke
.5299 .53208 L
.53095 .53199 L
.53153 .53196 L
.53207 .53194 L
.53303 .53194 L
.53407 .53195 L
.53511 .53196 L
.5357 .53196 L
.53624 .53195 L
.53724 .53189 L
.5383 .53176 L
.53924 .53157 L
.54012 .53131 L
.54107 .53092 L
.54208 .53035 L
.54304 .52965 L
.54389 .52886 L
.54477 .52785 L
.5457 .52655 L
.54721 .52369 L
.54847 .52036 L
.54909 .51823 L
.54969 .5157 L
.55021 .51288 L
.55061 .51009 L
.55089 .50741 L
.55107 .5049 L
.55114 .50351 L
.55119 .50199 L
.55121 .49924 L
.55118 .49776 L
.55113 .49619 L
.55105 .49473 L
.55095 .49342 L
.5507 .49102 L
.55037 .48862 L
.54992 .48625 L
.54944 .48424 L
.54883 .48229 L
.5481 .4805 L
.54743 .47922 L
.54666 .4781 L
.5459 .47729 L
.54517 .47674 L
.5445 .4764 L
.54376 .47618 L
.54298 .47612 L
.54225 .47619 L
.54154 .47636 L
.54078 .47664 L
Mistroke
.53945 .47731 L
.53661 .47912 L
.5359 .47953 L
.53515 .4799 L
.53481 .48004 L
.53445 .48016 L
.53382 .48031 L
.53321 .48035 L
.53264 .4803 L
.53202 .48013 L
.53166 .47998 L
.53134 .47981 L
.53074 .47941 L
.5301 .47887 L
.52889 .47755 L
.52579 .47291 L
.51807 .45847 L
.50395 .43228 L
.49339 .41437 L
.48654 .40381 L
.47944 .39409 L
.47266 .38639 L
.46901 .38307 L
.46493 .38019 L
.46257 .37898 L
.46038 .3782 L
.45827 .37779 L
.45602 .37777 L
.45216 .37886 L
.44998 .38019 L
.44797 .38196 L
.4443 .38675 L
.44097 .39322 L
.43818 .4007 L
.43539 .41072 L
.43273 .42369 L
.43146 .4317 L
.4304 .43977 L
.42873 .45673 L
.4277 .47324 L
.42717 .49061 L
.42717 .50946 L
.42772 .52696 L
.42866 .54225 L
.43028 .55893 L
.43143 .5676 L
.43262 .57508 L
.43511 .5873 L
.43814 .59805 L
.4413 .60608 L
Mistroke
.44496 .61244 L
.44857 .6164 L
.45196 .61846 L
.45577 .61921 L
.45794 .61901 L
.45994 .61847 L
.46205 .61756 L
.46396 .61647 L
.46815 .61328 L
.47479 .60635 L
.4805 .59894 L
.49185 .58158 L
.50733 .55563 L
.51335 .5462 L
.51876 .53906 L
.5211 .53662 L
.5232 .53486 L
.525 .53369 L
.52593 .53322 L
.52691 .53281 L
.52752 .5326 L
.52808 .53244 L
.52916 .53221 L
.53014 .53207 L
.53117 .53198 L
.53171 .53196 L
.53228 .53195 L
.53331 .53195 L
.53395 .53195 L
.53454 .53196 L
.53508 .53196 L
.53566 .53196 L
.53663 .53193 L
.5377 .53184 L
.53823 .53177 L
.53881 .53167 L
.53984 .5314 L
.5408 .53103 L
.5418 .53052 L
.54264 .52995 L
.54354 .5292 L
.54536 .52704 L
.54632 .52548 L
.54715 .52382 L
.54851 .5202 L
.54911 .51812 L
.54969 .51566 L
.55013 .51334 L
.55048 .51103 L
.55081 .50828 L
Mistroke
.55102 .50571 L
.55115 .50327 L
.5512 .501 L
.5512 .49854 L
.55111 .49596 L
.55093 .49333 L
.5507 .49101 L
.55036 .48862 L
.54993 .48629 L
.54902 .48287 L
.54842 .48125 L
.54782 .47994 L
.54707 .47867 L
.54631 .47772 L
.54561 .47707 L
.54484 .47657 L
.54443 .47639 L
.54397 .47625 L
.5435 .47617 L
.54305 .47614 L
.54225 .47621 L
.54181 .47631 L
.5414 .47643 L
.53864 .47784 L
.53621 .47938 L
.53559 .47972 L
.53494 .48001 L
.5346 .48013 L
.53423 .48024 L
.53359 .48035 L
.53301 .48035 L
.53239 .48025 L
.53179 .48004 L
.53124 .47975 L
.53053 .47924 L
.52985 .47862 L
.52821 .47667 L
.52477 .47111 L
.51537 .45328 L
.50205 .42893 L
.49259 .41306 L
.48048 .3954 L
.47313 .38685 L
.46873 .38283 L
.46657 .38122 L
.46451 .37993 L
.46054 .37824 L
.45691 .37772 L
.453 .37848 L
.45081 .37961 L
Mistroke
.44881 .38115 L
.44526 .38527 L
.44208 .39079 L
.4388 .39885 L
.43559 .40988 L
.43413 .41632 L
.43268 .42402 L
.43041 .43969 L
.42873 .45674 L
.42768 .47371 L
.42713 .49309 L
.4271 .50295 L
.42725 .51372 L
.42799 .53235 L
.42921 .54877 L
.43019 .55812 L
.43126 .56646 L
.43363 .58053 L
.43666 .59325 L
.43855 .59925 L
.44039 .60404 L
.44363 .61045 L
.44683 .61476 L
.45045 .61773 L
.45442 .61912 L
.45838 .61893 L
.46036 .61832 L
.46251 .61733 L
.46627 .61485 L
.46968 .61188 L
.48224 .59649 L
.49194 .58144 L
.50828 .55408 L
.51437 .54473 L
.51726 .54086 L
.51975 .53797 L
.52191 .53589 L
.52378 .53444 L
.52579 .53328 L
.52687 .53282 L
.52788 .53249 L
.52888 .53225 L
.52993 .53208 L
.53048 .53202 L
.53108 .53198 L
.53213 .53194 L
.53312 .53194 L
.53419 .53195 L
.53519 .53196 L
.5361 .53194 L
Mistroke
.53712 .53189 L
.5377 .53183 L
.53823 .53176 L
.5392 .53157 L
.54022 .53126 L
.54074 .53105 L
.54131 .53078 L
.54231 .53018 L
.54348 .52924 L
.54451 .52816 L
.54537 .52702 L
.54625 .52561 L
.54769 .52254 L
.54847 .52032 L
.54913 .51803 L
.54966 .51578 L
.55014 .51325 L
.5505 .5109 L
.55081 .50823 L
.55101 .50574 L
.55114 .5034 L
.5512 .50063 L
.55119 .49813 L
.55114 .49677 L
.55107 .49531 L
.55088 .49274 L
.55064 .49054 L
.55036 .48858 L
.54998 .48658 L
.54952 .48459 L
.549 .48283 L
.5484 .48119 L
.54783 .47997 L
.54719 .47887 L
.54656 .47801 L
.54597 .47738 L
.54536 .47689 L
.54478 .47655 L
.54408 .47628 L
.54344 .47616 L
.54273 .47615 L
.54198 .47627 L
.54125 .47648 L
.54047 .4768 L
.53907 .47757 L
.53659 .47915 L
.53526 .47987 L
.53488 .48002 L
.53453 .48015 L
.53388 .4803 L
Mistroke
.53327 .48035 L
.53271 .48031 L
.53209 .48015 L
.53143 .47985 L
.53084 .47947 L
.53029 .47903 L
.529 .47767 L
.52642 .47394 L
.51844 .45917 L
.50626 .4364 L
.48634 .4035 L
.47998 .39476 L
.47254 .38627 L
.46804 .3823 L
.46586 .38075 L
.46381 .37956 L
.46174 .37864 L
.45947 .37797 L
.45746 .37773 L
.45531 .37785 L
.45131 .37931 L
.44908 .38091 L
.44707 .38294 L
.44347 .38815 L
.43988 .3959 L
.43691 .40491 L
.4344 .41508 L
.432 .42811 L
.42991 .44406 L
.42843 .46073 L
.42782 .47074 L
.42742 .48038 L
.42709 .50016 L
.4272 .5113 L
.42748 .52141 L
.42834 .5379 L
.42981 .55479 L
.43189 .5707 L
.43427 .5836 L
.4358 .59008 L
.43758 .59633 L
.43924 .60117 L
.44109 .60562 L
.44281 .60904 L
.44477 .61218 L
.44832 .6162 L
.45054 .61778 L
.45258 .61869 L
.45496 .61918 L
.45722 .61913 L
Mistroke
.46121 .61796 L
.46345 .61679 L
.4655 .61542 L
.47301 .6084 L
.4796 .60018 L
.49044 .58387 L
.50836 .55395 L
.51404 .54519 L
.51912 .53866 L
.521 .5367 L
.52293 .53505 L
.52495 .5337 L
.52678 .53285 L
Mfstroke
0 g
gsave
.72727 .36364 -70.1875 -11.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 14.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(1.) show
77.375 14.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00f@3oool00`3ooml0W4P0000000020000000307Bo
o`3oool0oooo0<l0oooo003K0?ooo`030?noM00007@0_ooo0=80oooo003K0?ooo`030?oo_`1d0000
M;oo0=80oooo003K0?ooo`030?oog`2LB000B9cO0=80oooo003L0?ooo`030=nLB000000000000080
000000<0M;oo0?ooo`3oool00P3oool01@3o_g@000000000000004P0W=oo0080oooo00<0oono07@0
000000000P0000003@18W=l0oooo0?ooo`3oool0_g@00000000004P0W=oo0?ooo`3o_g@000000000
B02Lgol00P3oool0102oM00000000000B02Lgol20?ooo`050?noM000000000000000B02Lgol00`3o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000000007Bo09T0oooo003L0?ooo`070?noM00004P0
W=oo0?ooo`3ooml0W4P0001d_`020?ooo`0?0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`3oool0
oooO09a8001d_ol0oooo0?oOW0180000M;oo0080oooo01L0gia80018W03Ooml0W7BL0=ooo`3o_g@0
001809cOg`2LM9`0gooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0
B000001d_`020?ooo`030?noM00007@0_ooo0080oooo00@0gia80018W03O_g@0M;ooV03oool00=`0
oooo00<0oono07@0001d_ol00P3oool01`3ooml0W4P004RLg`3oool0gia80018W03Oool00P3oool0
2P3ogi`0B00004RLg`3oool0_gAd0;ooo`3oool0oono07@0001d_ol20?ooo`030?noM00004P0W=oo
0080oooo00<0oono07@0001d_ol00`3oool00`3o_g@0001809cOo`020?ooo`030=nLB000B9`0gooo
0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol0V@3o
ool00=`0oooo00<0oooO09a80018W=l00`3oool01P3ogi`0B01809cOo`3o_g@0001d0;ooo`<0oooo
00<0gia80000M02oool00`3oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo
00<0_g@0001d_`3oool00P3oool00`3ookl0M00004RLg`020?ooo`030?noM00007@0_ooo00<0oooo
00/0gia80000M02oool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`2I0?ooo`00g@3oool0
0`3OW4P0001d0;ooo`020?ooo`060?oog`2LB000B9cO0?oo_`1d0000M;oo0`3oool00`3ogi`0B018
09cOo`020?ooo`030?noM00004P0W=oo00@0oooo00<0_g@00018W03Oool00P3oool00`3OW4P004RL
0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3ookl0M00007Boo`030?ooo`070?oOW01804P0W=oo
0?ooo`3OW4P004Q804Qd_`020?ooo`030;md0000M;l0oooo09P0oooo003M0?ooo`040?noM0000000
04RL0=ooo`80oooo00H0gia8001d_`3oool0gia80000M02oool20?ooo`0:0?oo_`1d0000M;oo0?oo
o`3ogi`0B01809cOo`3oool0giad09cOo`80oooo00<0gia80000B02Lgol00P3oool00`3ogi`0B018
09cOo`030?ooo`030=nLB00004P0W=oo0080oooo00<0gia80000M02oool00P3oool0303ookl0M000
07Boo`3oool0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;oooiP0oooo003M0?ooo`080?oo_`1d
0000M9bL04P0M02oool0oooO09a80000M;l20?ooo`0>0;md000007@0_ooo0?ooo`3o_g@0001d0;oo
o`3oool0omnL04P0B02Lgol0oooO09a8001d_ol20?ooo`030?oOW0180000B9cO0080oooo00<0oooO
09a80018W=l00`3oool00`3ogi`0B00004RLg`030?ooo`0@0;md000007@0_ooo0?ooo`3o_g@0001d
0;ooo`3oool0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOoiP0oooo003L0?ooo`090?oOW018
0000000004RLg`3ookl0M0000000000007@0_ooo00<0oooo00D0okmd000000000000000007Boo`03
0?ooo`070;md00000000000000000018W=l0oooo0?noM002000000040018W03Oool0oono07@000<0
000000H0M;oo0?noM000000000000018W03Oool30?ooo`0?0?noM000000000000000001d_ol0oooo
0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo09P0oooo003m0?ooo`030?noM00007@0
_ooo0;00oooo003n0?ooo`030=nLM02Lgol0oooo0:l0oooo003h0?ooo`040?oo_`1d000004RL0=oo
o`L0oooo00@0oono07@00000B9`0goooZ@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool005H0oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`020?ooo`040;md0000
0000000007Bood40oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`030?ooo`040;md
00000000000007Bood40oooo00@0_g@0000000000000M;ooA@3oool00`3ookl0M000000000020000
000304RLg`3oool0oooo00<0oooo00@0_g@0000000000000M;oo@@3oool00`3OW4P0000000000003
0000000304RLg`3oool0oooo0080oooo00@0_g@0000000000000M;oo4P3oool005L0oooo00<0okmd
001d_`3oool00P3oool02P2oM7@0_ooo0?ooo`3oool0gia8001d_`3oool0omnL04P00018W=m20?oo
o`030?noM0000000M;oo00D0oooo00H0gia8001d_`3oool0omnL04P00018W=lo0?ooo`060=nLB000
M;l0oooo0?oOW0180000B9cOAP3oool00`3o_g@0000007Boo`050?ooo`060=nLB000M;l0oooo0?oO
W0180000B9cO@@3oool00`3o_g@007Bo0?ooo`020?ooo`0:0;mdM02oool0oooo0?ooo`3OW4P007Bo
0?ooo`3ogi`0B00004RLga40oooo001H0?ooo`030?noM000M;l0oooo00@0oooo00<0oooO09a80018
W=l00P3oool00`3o_g@0001809cOo`110?ooo`030?oog`2LB00007Bo00@0oooo00<0oooO09a80018
W=l00P3oool00`3o_g@0001809cOo`0m0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02L
gol0A@3oool00`3ooml0W4P0001d_`040?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02L
gol0@@3oool00`3o_g@007Bo0?ooo`040?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02L
gol0403oool005T0oooo00<0okmd001d_`3oool00`3oool00`3ooml0W4P004RLg`020?ooo`040?oo
g`2LB00004RL0=oood40oooo00<0gia80018W03Oool00`3oool00`3ooml0W4P004RLg`020?ooo`04
0?oog`2LB00004RL0=oooc`0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Ooom5
0?ooo`030=nLB000B9`0gooo00<0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03O
oom10?ooo`030?noM000M;l0oooo00<0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018
W03Oool?0?ooo`00B@3oool00`3ooml0W4P0000000070000000304RLg`3oool0oooo00@0oooo00<0
okmd04RLg`3oool00P3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo0340oooo00<0
oooO09a8000000001`0000000`18W=l0oooo0?ooo`030?ooo`030?oOW01804P0W=oo00<0oooo00<0
oooO09a80000M;l00`3oool00`3OW4P0001809cOo`0l0?ooo`030?oog`2LB00007Bo00<0oooo00<0
gia80000B02Lgol0A@3oool00`3ogi`0B01809cOo`030?ooo`030?oog`2LB00007Bo00<0oooo00<0
gia80000B02Lgol0@P3oool00`3o_g@0B9cO0?ooo`020?ooo`030?oog`2LB00007Bo00<0oooo00<0
gia80000B02Lgol03`3oool005/0oooo00<0gia804RLg`3oool00P3oool00`2oM00004RL0=ooo`02
0?ooo`030?oOW0180000B9cO0440oooo00<0oono07@0001d_ol0103oool00`2oM00004RL0=ooo`02
0?ooo`030?oOW0180000B9cO03d0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`15
0?ooo`030?oo_`1d0000M;oo00@0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`13
0?ooo`030=nLB018W=l0oooo0080oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0?
0?ooo`00G03oool01`2oM000M;oo0?ooo`3oool0gia80000B02Lgol00P3oool00`3ooml0W4P0001d
_`120?ooo`030;md0000M;l0oooo00<0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d
_`0m0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0AP3oool00`2oM00007Bo0?oo
o`030?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0A03oool01`2oM000M;oo0?oo
o`3oool0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0?0?ooo`00G03oool01`3ogi`0B01d
0;ooo`3oool0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`110?ooo`030=nLB000B9`0gooo
00<0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`0l0?ooo`030?oOW0180000B9cO
00<0oooo00<0_g@00018W03Oool0A@3oool00`3OW4P004RL0=ooo`030?ooo`030?oOW0180000B9cO
00<0oooo00<0_g@00018W03Oool0@`3oool01`3ogi`0B01d0;ooo`3oool0omnL04P00018W=l00`3o
ool00`2oM00004RL0=ooo`0>0?ooo`00G03oool0203ooml0W4P007Boo`3oool0oooO09a80000B9`0
gooo0P3oool00`3OW4P004RL0=ooo`110?ooo`030?oOW01804P0W=oo00<0oooo00@0oooO09a80000
B9`0gooo0P3oool00`3OW4P004RL0=ooo`0l0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia8
0018W03Oool0A@3oool00`3ogi`0B01809cOo`030?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0
gia80018W03Oool0@`3oool0203ooml0W4P007Boo`3oool0oooO09a80000B9`0gooo0P3oool00`3O
W4P004RL0=ooo`0>0?ooo`00G03oool00`3ookl0M00004RLg`020?ooo`030?oOW0180000M;oo0080
oooo00<0gia8001d_`3oool0@@3oool00`3ookl0M00007Boo`040?ooo`030?oOW0180000M;oo0080
oooo00<0gia8001d_`3oool0?@3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo04D0
oooo00<0oono07@0001d_ol0103oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo04<0
oooo00<0oono07@00018W=l00P3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0oooo00h0
oooo001H0?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cOo`030?ooo`060=nLB00007@0_ooo
0?oog`2LB000B9cO@`3oool00`2oM00007Bo0?ooo`040?ooo`060=nLB00007@0_ooo0?oog`2LB000
B9cO?`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLgdL0oooo00<0_g@0001d_`3oool0103oool0
1P3OW4P0001d0;ooo`3ooml0W4P004RLgd00oooo00L0okmd0018W03Oool0oooo0=nLB00004P0W=oo
00<0oooo00H0gia80000M02oool0oooO09a80018W=l?0?ooo`00F@3oool01@3ogi`0B00000000000
0000M;oo00D0oooo00@0gia800000000000007Bo@P3oool01@3ookl0M0000000000007@0_ooo00D0
oooo00@0gia800000000000007Bo@@3oool0103OW4P0000000000000M;m60?ooo`050?oo_`1d0000
00000000M02oool01@3oool0103OW4P0000000000000M;m20?ooo`050?oOW018000000000000001d
_ol01@3oool0103OW4P0000000000000M;l@0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00B@3ooooo0000064000001`3oool004T0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0@03ooolF0?l004H0oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003o
ool0oooo09X0oooo9P3o002L0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0
oooo09D0oooo3P3o00090?ooo`030000003oool0oooo00T0oooo3@3o002G0?ooo`030000003oool0
oooo00D0oooo00190?ooo`030000003oool0oooo0940oooo2`3o000@0?ooo`030000003oool0oooo
0180oooo2@3o002B0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo08h0
oooo1`3o000G0?ooo`030000003oool0oooo01H0oooo203o002?0?ooo`030000003oool0oooo00D0
oooo00190?ooo`030000003oool0oooo08X0oooo1`3o000K0?ooo`030000003oool0oooo01T0oooo
203o002<0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo08P0oooo1@3o
000O0?ooo`030000003oool0oooo01d0oooo1`3o00290?ooo`030000003oool0oooo00D0oooo0019
0?ooo`030000003oool0oooo08D0oooo1@3o000R0?ooo`030000003oool0oooo0200oooo1P3o0027
0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo0840oooo1P3o000U0?oo
o`030000003oool0oooo02<0oooo1P3o00240?ooo`030000003oool0oooo00D0oooo000_0?ooo`03
0=nLB0000000000000<0000000<0B9cO0?ooo`3oool00P3oool0102oM00000000000001d_ol;0?oo
o`030000003oool0oooo07l0oooo1P3o000W0?ooo`030000003oool0oooo02H0oooo1@3o00220?oo
o`030000003oool0oooo00D0oooo000`0?ooo`030?noM000M;l0oooo0080oooo00X0_gAd0;ooo`3o
ool0oooo0=nLB000M;l0oooo0?oOW0180000B9cO2P3oool00`000000oooo0?ooo`1m0?ooo`D0o`00
:P3oool00`000000oooo0?ooo`0Y0?ooo`D0o`00O`3oool00`000000oooo0?ooo`050?ooo`00<@3o
ool00`3o_g@007Bo0?ooo`040?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol02@3o
ool00`000000oooo0?ooo`1k0?ooo`D0o`00;03oool00`000000oooo0?ooo`0[0?ooo`D0o`00O@3o
ool00`000000oooo0?ooo`050?ooo`00<P3oool00`3o_g@007Bo0?ooo`030?ooo`030?oog`2LB000
B9cO0080oooo00@0oooO09a80000B9`0gooo203oool00`000000oooo0?ooo`1i0?ooo`D0o`00;P3o
ool00`000000oooo0?ooo`0]0?ooo`D0o`00N`3oool00`000000oooo0?ooo`050?ooo`008P3oool0
0`3ooml0W4P0000000070000000304RLg`3oool0oooo00@0oooo00<0okmd04RLg`3oool00P3oool0
0`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00P0oooo00<000000?ooo`3oool0M`3oool5
0?l00300oooo00<000000?ooo`3oool0;`3oool50?l007T0oooo00<000000?ooo`3oool01@3oool0
03@0oooo00<0gia804RLg`3oool00P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO
00P0oooo0`00001e0?ooo`D0o`00<P3oool00`000000oooo0?ooo`0a0?ooo`D0o`00M@3oool30000
00L0oooo000e0?ooo`070;md001d_ol0oooo0?ooo`3OW4P0001809cOo`020?ooo`030?oog`2LB000
07Bo00P0oooo00<000000?ooo`3oool0L`3oool50?l003@0oooo00<000000?ooo`3oool0<`3oool5
0?l007D0oooo00<000000?ooo`3oool01@3oool003D0oooo00L0omnL04P0M02oool0oooo0?oOW018
0000B9cO00<0oooo00<0_g@00018W03Oool01`3oool00`000000oooo0?ooo`1b0?ooo`@0o`00=P3o
ool00`000000oooo0?ooo`0e0?ooo`D0o`00L`3oool00`000000oooo0?ooo`050?ooo`00=@3oool0
203ooml0W4P007Boo`3oool0oooO09a80000B9`0gooo0P3oool00`3OW4P004RL0=ooo`070?ooo`03
0000003oool0oooo0700oooo103o000h0?ooo`030000003oool0oooo03L0oooo103o001b0?ooo`03
0000003oool0oooo00D0oooo000e0?ooo`030?oo_`1d0000B9cO0080oooo00<0omnL04P0001d_ol0
0P3oool00`3OW4P007Bo0?ooo`070?ooo`030000003oool0oooo06l0oooo0`3o000j0?ooo`030000
003oool0oooo03T0oooo103o001`0?ooo`030000003oool0oooo00D0oooo000a0?ooo`070?noM000
B9`0gooo0?ooo`3OW4P0001809cOo`030?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO203oool0
0`000000oooo0?ooo`1]0?ooo`<0o`00?03oool00`000000oooo0?ooo`0j0?ooo`@0o`00K`3oool0
0`000000oooo0?ooo`050?ooo`00<P3oool01@3ogi`0B000000000000000M;oo00D0oooo00@0gia8
00000000000007Bo2@3oool00`000000oooo0?ooo`1/0?ooo`<0o`00?@3oool00`000000oooo0?oo
o`0l0?ooo`@0o`00K@3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`1Z
0?ooo`<0o`00?`3oool00`000000oooo0?ooo`0n0?ooo`@0o`00J`3oool00`000000oooo0?ooo`05
0?ooo`00B@3oool00`000000oooo0?ooo`1X0?ooo`@0o`00@03oool00`000000oooo0?ooo`0o0?oo
o`@0o`00JP3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`1W0?ooo`@0
o`00@@3oool00`000000oooo0?ooo`110?ooo`@0o`00J03oool00`000000oooo0?ooo`050?ooo`00
B@3oool00`000000oooo0?ooo`1V0?ooo`<0o`00@`3oool00`000000oooo0?ooo`120?ooo`@0o`00
I`3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`1T0?ooo`@0o`00A03o
ool00`000000oooo0?ooo`130?ooo`@0o`00IP3oool00`000000oooo0?ooo`050?ooo`00B@3oool0
0`000000oooo0?ooo`1R0?ooo`@0o`00AP3oool00`000000oooo0?ooo`150?ooo`<0o`00I@3oool0
0`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`1Q0?ooo`@0o`00A`3oool00`00
0000oooo0?ooo`160?ooo`<0o`00I03oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000
oooo0?ooo`1P0?ooo`@0o`00B03oool00`000000oooo0?ooo`180?ooo`80o`00H`3oool00`000000
oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`1O0?ooo`@0o`00B@3oool00`000000oooo
0?ooo`190?ooo`80o`00HP3oool00`000000oooo0?ooo`050?ooo`00B@3oool2000005l0oooo103o
001:0?ooo`030000003oool0oooo04X0oooo0`3o001O0?ooo`8000001`3oool004T0oooo00<00000
0?ooo`3oool0G@3oool30?l004`0oooo00<000000?ooo`3oool0B`3oool30?l005l0oooo00<00000
0?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0G03oool30?l004d0oooo00<000000?oo
o`3oool0C03oool30?l005h0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3o
ool0F`3oool30?l004h0oooo00<000000?ooo`3oool0C@3oool30?l005d0oooo00<000000?ooo`3o
ool01@3oool004T0oooo00<000000?ooo`3oool0FP3oool30?l004l0oooo00<000000?ooo`3oool0
CP3oool30?l005`0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0F@3o
ool30?l00500oooo00<000000?ooo`3oool0D03oool20?l005/0oooo00<000000?ooo`3oool01@3o
ool004T0oooo00<000000?ooo`3oool0F03oool30?l00540oooo00<000000?ooo`3oool0D@3oool2
0?l005X0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0E`3oool30?l0
0580oooo00<000000?ooo`3oool0DP3oool20?l005T0oooo00<000000?ooo`3oool01@3oool004T0
oooo00<000000?ooo`3oool0EP3oool30?l005<0oooo00<000000?ooo`3oool0D`3oool20?l005P0
oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0E@3oool30?l005@0oooo
00<000000?ooo`3oool0E03oool20?l005L0oooo00<000000?ooo`3oool01@3oool004T0oooo00<0
00000?ooo`3oool0E03oool20?l005H0oooo00<000000?ooo`3oool0E@3oool20?l005H0oooo00<0
00000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0D`3oool20?l005L0oooo00<00000
0?ooo`3oool0EP3oool20?l005D0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?oo
o`3oool0DP3oool20?l005P0oooo00<000000?ooo`3oool0EP3oool30?l005@0oooo00<000000?oo
o`3oool01@3oool004T0oooo00<000000?ooo`3oool0D@3oool20?l005T0oooo00<000000?ooo`3o
ool0E`3oool30?l005<0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0
D03oool20?l005X0oooo00<000000?ooo`3oool0F03oool30?l00580oooo00<000000?ooo`3oool0
1@3oool004T0oooo00<000000?ooo`3oool0C`3oool20?l005/0oooo00<000000?ooo`3oool0F@3o
ool30?l00540oooo00<000000?ooo`3oool01@3oool004T0oooo0P00001?0?ooo`<0o`00F`3oool0
0`000000oooo0?ooo`1J0?ooo`<0o`00C`3oool2000000L0oooo00190?ooo`030000003oool0oooo
04d0oooo0`3o001L0?ooo`030000003oool0oooo05/0oooo0P3o001@0?ooo`030000003oool0oooo
00D0oooo00190?ooo`030000003oool0oooo04d0oooo0P3o001M0?ooo`030000003oool0oooo05`0
oooo0P3o001?0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo04`0oooo
0P3o001N0?ooo`030000003oool0oooo05d0oooo0P3o001>0?ooo`030000003oool0oooo00D0oooo
00190?ooo`030000003oool0oooo04/0oooo0P3o001O0?ooo`030000003oool0oooo05h0oooo0P3o
001=0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo04X0oooo0`3o001O
0?ooo`030000003oool0oooo05h0oooo0`3o001<0?ooo`030000003oool0oooo00D0oooo00190?oo
o`030000003oool0oooo04T0oooo0`3o001P0?ooo`030000003oool0oooo05l0oooo0`3o001;0?oo
o`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo04P0oooo0`3o001Q0?ooo`03
0000003oool0oooo0600oooo0`3o001:0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000
003oool0oooo04P0oooo0P3o001R0?ooo`030000003oool0oooo0640oooo0P3o001:0?ooo`030000
003oool0oooo00D0oooo00190?ooo`030000003oool0oooo04L0oooo0P3o001S0?ooo`030000003o
ool0oooo0640oooo0`3o00190?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0
oooo04H0oooo0`3o001S0?ooo`030000003oool0oooo0680oooo0`3o00180?ooo`030000003oool0
oooo00D0oooo00190?ooo`030000003oool0oooo04H0oooo0P3o001T0?ooo`030000003oool0oooo
06<0oooo0P3o00180?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo04D0
oooo0P3o001U0?ooo`030000003oool0oooo06<0oooo0`3o00170?ooo`030000003oool0oooo00D0
oooo00190?ooo`030000003oool0oooo04@0oooo0P3o001V0?ooo`030000003oool0oooo06@0oooo
0P3o00170?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo04@0oooo0P3o
001V0?ooo`030000003oool0oooo06D0oooo0P3o00160?ooo`030000003oool0oooo00D0oooo0019
0?ooo`030000003oool0oooo04<0oooo0P3o001W0?ooo`030000003oool0oooo06D0oooo0`3o0015
0?ooo`030000003oool0oooo00D0oooo00190?ooo`800000@`3oool20?l006P0oooo00<000000?oo
o`3oool0IP3oool30?l004<0oooo0P0000070?ooo`00B@3oool00`000000oooo0?ooo`120?ooo`80
o`00J03oool00`000000oooo0?ooo`1W0?ooo`<0o`00@`3oool00`000000oooo0?ooo`050?ooo`00
B@3oool00`000000oooo0?ooo`110?ooo`80o`00J@3oool00`000000oooo0?ooo`1W0?ooo`<0o`00
@`3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`100?ooo`80o`00JP3o
ool00`000000oooo0?ooo`1X0?ooo`<0o`00@P3oool00`000000oooo0?ooo`050?ooo`00B@3oool0
0`000000oooo0?ooo`0o0?ooo`<0o`00JP3oool00`000000oooo0?ooo`1Y0?ooo`80o`00@P3oool0
0`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0o0?ooo`80o`00J`3oool00`00
0000oooo0?ooo`1Y0?ooo`<0o`00@@3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000
oooo0?ooo`0n0?ooo`80o`00K03oool00`000000oooo0?ooo`1Z0?ooo`<0o`00@03oool00`000000
oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0n0?ooo`80o`00K03oool00`000000oooo
0?ooo`1[0?ooo`<0o`00?`3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?oo
o`0m0?ooo`80o`00K@3oool00`000000oooo0?ooo`1[0?ooo`<0o`00?`3oool00`000000oooo0?oo
o`050?ooo`00B@3oool00`000000oooo0?ooo`0l0?ooo`<0o`00K@3oool00`000000oooo0?ooo`1/
0?ooo`<0o`00?P3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0l0?oo
o`80o`00KP3oool00`000000oooo0?ooo`1]0?ooo`80o`00?P3oool00`000000oooo0?ooo`050?oo
o`00B@3oool00`000000oooo0?ooo`0k0?ooo`80o`00K`3oool00`000000oooo0?ooo`1]0?ooo`<0
o`00?@3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0k0?ooo`80o`00
K`3oool00`000000oooo0?ooo`1^0?ooo`80o`00?@3oool00`000000oooo0?ooo`050?ooo`00B@3o
ool00`000000oooo0?ooo`0j0?ooo`80o`00L03oool00`000000oooo0?ooo`1^0?ooo`<0o`00?03o
ool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0i0?ooo`<0o`00L03oool0
0`000000oooo0?ooo`1_0?ooo`<0o`00>`3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`00
0000oooo0?ooo`0i0?ooo`80o`00L@3oool00`000000oooo0?ooo`1_0?ooo`<0o`00>`3oool00`00
0000oooo0?ooo`050?ooo`00B@3oool2000003T0oooo0`3o001a0?ooo`030000003oool0oooo0700
oooo0`3o000i0?ooo`8000001`3oool004T0oooo00<000000?ooo`3oool0>03oool20?l00780oooo
00<000000?ooo`3oool0L03oool30?l003X0oooo00<000000?ooo`3oool01@3oool004T0oooo00<0
00000?ooo`3oool0=`3oool30?l00780oooo00<000000?ooo`3oool0L@3oool30?l003T0oooo00<0
00000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0=`3oool20?l007<0oooo00<00000
0?ooo`3oool0L@3oool30?l003T0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?oo
o`3oool0=P3oool30?l007<0oooo00<000000?ooo`3oool0LP3oool30?l003P0oooo00<000000?oo
o`3oool01@3oool004T0oooo00<000000?ooo`3oool0=P3oool20?l007@0oooo00<000000?ooo`3o
ool0L`3oool20?l003P0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0
=@3oool30?l007@0oooo00<000000?ooo`3oool0L`3oool30?l003L0oooo00<000000?ooo`3oool0
1@3oool004T0oooo00<000000?ooo`3oool0=@3oool20?l007D0oooo00<000000?ooo`3oool0M03o
ool20?l003L0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0=03oool3
0?l007D0oooo00<000000?ooo`3oool0M03oool20?l003L0oooo00<000000?ooo`3oool01@3oool0
04T0oooo00<000000?ooo`3oool0=03oool20?l007H0oooo00<000000?ooo`3oool0M@3oool20?l0
03H0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0<`3oool30?l007H0
oooo00<000000?ooo`3oool0M@3oool20?l003H0oooo00<000000?ooo`3oool01@3oool002l0oooo
00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`030?ooo`040;md00000000000007Boo`/0
oooo00<000000?ooo`3oool0<`3oool20?l007L0oooo00<000000?ooo`3oool0MP3oool20?l003D0
oooo00<000000?ooo`3oool01@3oool00340oooo00<0okmd0000001d_ol01@3oool01P3OW4P007Bo
0?ooo`3ogi`0B00004RLg`X0oooo00<000000?ooo`3oool0<`3oool20?l007L0oooo00<000000?oo
o`3oool0MP3oool20?l003D0oooo00<000000?ooo`3oool01@3oool00340oooo00<0oooO09a80000
M;l0103oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00T0oooo00<000000?ooo`3o
ool0<P3oool30?l007L0oooo00<000000?ooo`3oool0M`3oool20?l003@0oooo00<000000?ooo`3o
ool01@3oool00380oooo00<0gia80018W03Oool00`3oool00`3ooml0W4P004RLg`020?ooo`040?oo
g`2LB00004RL0=ooo`P0oooo00<000000?ooo`3oool0<P3oool20?l007P0oooo00<000000?ooo`3o
ool0M`3oool20?l003@0oooo00<000000?ooo`3oool01@3oool00280oooo00<0oooO09a800000000
1`0000000`18W=l0oooo0?ooo`030?ooo`030?oOW01804P0W=oo00<0oooo00<0oooO09a80000M;l0
0`3oool00`3OW4P0001809cOo`080?ooo`030000003oool0oooo0340oooo0`3o001h0?ooo`030000
003oool0oooo07L0oooo0`3o000c0?ooo`030000003oool0oooo00D0oooo000b0?ooo`030?oo_`1d
0000M;oo00@0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`080?ooo`<00000<@3o
ool20?l007T0oooo00<000000?ooo`3oool0N03oool20?l00340oooo0`0000070?ooo`00<`3oool0
0`2oM00007Bo0?ooo`030?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0203oool0
0`000000oooo0?ooo`0`0?ooo`<0o`00N@3oool00`000000oooo0?ooo`1h0?ooo`<0o`00<P3oool0
0`000000oooo0?ooo`050?ooo`00<`3oool00`3OW4P004RL0=ooo`030?ooo`030?oOW0180000B9cO
00<0oooo00<0_g@00018W03Oool01`3oool00`000000oooo0?ooo`0`0?ooo`80o`00NP3oool00`00
0000oooo0?ooo`1i0?ooo`80o`00<P3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`3ogi`0
B01809cOo`030?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool01`3oool00`00
0000oooo0?ooo`0`0?ooo`80o`00NP3oool00`000000oooo0?ooo`1i0?ooo`80o`00<P3oool00`00
0000oooo0?ooo`050?ooo`00<`3oool00`3ookl0M00007Boo`040?ooo`030?oOW0180000M;oo0080
oooo00<0gia8001d_`3oool01`3oool00`000000oooo0?ooo`0_0?ooo`<0o`00NP3oool00`000000
oooo0?ooo`1i0?ooo`<0o`00<@3oool00`000000oooo0?ooo`050?ooo`00=03oool00`2oM00007Bo
0?ooo`040?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO203oool00`000000oooo0?ooo`0_0?oo
o`80o`00N`3oool00`000000oooo0?ooo`1j0?ooo`80o`00<@3oool00`000000oooo0?ooo`050?oo
o`00<P3oool01@3ookl0M0000000000007@0_ooo00D0oooo00@0gia800000000000007Bo2@3oool0
0`000000oooo0?ooo`0_0?ooo`80o`00N`3oool00`000000oooo0?ooo`1j0?ooo`80o`00<@3oool0
0`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0^0?ooo`80o`00O03oool00`00
0000oooo0?ooo`1k0?ooo`80o`00<03oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000
oooo0?ooo`0^0?ooo`80o`00O03oool00`000000oooo0?ooo`1k0?ooo`80o`00<03oool00`000000
oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0^0?ooo`80o`00O03oool00`000000oooo
0?ooo`1l0?ooo`80o`00;`3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?oo
o`0]0?ooo`80o`00O@3oool00`000000oooo0?ooo`1l0?ooo`80o`00;`3oool00`000000oooo0?oo
o`050?ooo`00B@3oool00`000000oooo0?ooo`0]0?ooo`80o`00O@3oool00`000000oooo0?ooo`1l
0?ooo`80o`00;`3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0]0?oo
o`80o`00O@3oool00`000000oooo0?ooo`1m0?ooo`80o`00;P3oool00`000000oooo0?ooo`050?oo
o`00B@3oool00`000000oooo0?ooo`0/0?ooo`80o`00OP3oool00`000000oooo0?ooo`1m0?ooo`80
o`00;P3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0/0?ooo`80o`00
OP3oool00`000000oooo0?ooo`1m0?ooo`80o`00;P3oool00`000000oooo0?ooo`050?ooo`00B@3o
ool00`000000oooo0?ooo`0[0?ooo`<0o`00OP3oool00`000000oooo0?ooo`1n0?ooo`80o`00;@3o
ool00`000000oooo0?ooo`050?ooo`00B@3oool2000002`0oooo0P3o001o0?ooo`030000003oool0
oooo07h0oooo0P3o000/0?ooo`8000001`3oool004T0oooo00<000000?ooo`3oool0:`3oool20?l0
06X0oooo1@00ofH@0?ooo`030000003oool0oooo07h0oooo0P3o000]0?ooo`030000003oool0oooo
00D0oooo00190?ooo`030000003oool0oooo02X0oooo0`3o001W0?ooo`@00?mV0P3oool4003oIPh0
oooo00<000000?ooo`3oool0O`3oool20?l002`0oooo00<000000?ooo`3oool01@3oool004T0oooo
00<000000?ooo`3oool0:P3oool20?l006L0oooo0`00ofH70?ooo`<00?mV303oool00`000000oooo
0?ooo`1o0?ooo`80o`00;03oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?oo
o`0Z0?ooo`80o`00IP3oool2003oIP/0oooo0`00ofH:0?ooo`030000003oool0oooo07l0oooo0`3o
000[0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo02X0oooo0P3o001U
0?ooo`800?mV3@3oool3003oIPT0oooo00<000000?ooo`3oool0O`3oool30?l002/0oooo00<00000
0?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0:@3oool30?l006@0oooo0P00ofH@0?oo
o`800?mV203oool00`000000oooo0?ooo`200?ooo`80o`00:`3oool00`000000oooo0?ooo`050?oo
o`00B@3oool00`000000oooo0?ooo`0Y0?ooo`80o`00I@3oool2003oIQ40oooo0`00ofH60?ooo`03
0000003oool0oooo0800oooo0P3o000[0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000
003oool0oooo02T0oooo0P3o001T0?ooo`800?mV4`3oool3003oIPD0oooo00<000000?ooo`3oool0
P03oool30?l002X0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0:@3o
ool20?l006@0oooo0P00ofHD0?ooo`<00?mV103oool00`000000oooo0?ooo`200?ooo`<0o`00:P3o
ool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0X0?ooo`<0o`00H`3oool2
003oIQL0oooo0P00ofH30?ooo`030000003oool0oooo0840oooo0P3o000Z0?ooo`030000003oool0
oooo00D0oooo00190?ooo`030000003oool0oooo02P0oooo0P3o001T0?ooo`800?mV603oool2003o
IP80oooo00<000000?ooo`3oool0P@3oool20?l002X0oooo00<000000?ooo`3oool01@3oool004T0
oooo00<000000?ooo`3oool0:03oool20?l006@0oooo00<00?mV0?ooo`3oool0603oool2003oIP03
0?ooo`000000oooo04D0oooo00<0oono0?l0003o00001@3o00000`3o_ol0oooo0?ooo`020?ooo`04
0?oo_`3o0000o`000?md_b`0oooo0`3o000Y0?ooo`030000003oool0oooo00D0oooo00190?ooo`03
0000003oool0oooo02P0oooo0P3o001S0?ooo`800?mV6`3oool2003oIP030000003oool0oooo04L0
oooo00<0oono0?l0B03ogol01`3oool0103ookl0o`000?l0003oM;l/0?ooo`<0o`00:@3oool00`00
0000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0W0?ooo`<0o`00H`3oool2003oIQ`0
oooo0P00ofH?0?ooo`D006Ko=@3oool00`3ookl0o`180?oOo`0h0?ooo`80o`00:@3oool00`000000
oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0W0?ooo`80o`00I03oool00`00ofH0oooo
0?ooo`0K0?ooo`<00?mV303oool4001Vo`80oooo0`00I_lc0?ooo`030?oo_`3o04P0omoo03P0oooo
0P3o000Y0?ooo`030000003oool0oooo00D0oooo00190?ooo`800000:03oool20?l006<0oooo0P00
ofHN0?ooo`<00?mV2P3oool3001Vo`H0oooo0P00I_lb0?ooo`030?oo_`3o04P0omoo03P0oooo0`3o
000W0?ooo`8000001`3oool004T0oooo00<000000?ooo`3oool09`3oool20?l006<0oooo0P00ofHN
0?ooo`0400000000ofH00?mV003oIPL0oooo0`00I_l90?ooo`8006Ko<@3oool00`3ookl0o`180?oO
o`0h0?ooo`<0o`00:03oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0V
0?ooo`<0o`00H`3oool00`00ofH0oooo0?ooo`0M0?ooo`040000003oool00?mV003oIPH0oooo0`00
I_l;0?ooo`03001Vo`3oool0oooo02l0oooo00<0oono0?l0B03ogol0>@3oool20?l002P0oooo00<0
00000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool09P3oool20?l006<0oooo0P00ofHO
0?ooo`030000003oool0oooo00800?mV103oool3001Vo`<0oooo1@3<0?l40?ooo`8006Ko<03oool0
0`3ookl0o`180?oOo`0i0?ooo`80o`00:03oool00`000000oooo0?ooo`050?ooo`00B@3oool00`00
0000oooo0?ooo`0V0?ooo`80o`00H`3oool2003oIQl0oooo00@000000?ooo`3oool0oooo0P00ofH2
0?ooo`<006Ko0P3oool40<`0o`040?ooo`3<0?l0c03o0<`0o`@0oooo00<006Ko0?ooo`3oool0;P3o
ool00`3ookl0o`180?oOo`0i0?ooo`80o`00:03oool00`000000oooo0?ooo`050?ooo`00B@3oool0
0`000000oooo0?ooo`0V0?ooo`80o`00H`3oool2003oIPh0oooo1P3o000;0?ooo`030000003oool0
oooo0080oooo0P00ofH2001Vo`<0oooo0`3<0?l50?ooo`80c03o0`3oool2001Vob`0oooo00H0omnL
0?l0003o0000oibL0?l0B03ogoli0?ooo`80o`00:03oool00`000000oooo0?ooo`050?ooo`00B@3o
ool00`000000oooo0?ooo`0U0?ooo`<0o`00H`3oool00`00ofH0oooo0?ooo`0<0?ooo`80o`00103o
ool20?l000X0oooo00<000000?ooo`3oool00`3oool2001Vo`<0oooo0P3<0?l80?ooo`80c03o0`3o
ool00`00I_l0oooo0?ooo`0]0?ooo`030?m8003o04P0omoo03X0oooo0P3o000W0?ooo`030000003o
ool0oooo00D0oooo00190?ooo`030000003oool0oooo02D0oooo0P3o001S0?ooo`800?mV3@3oool2
0?l000H0oooo0P3o00090?ooo`030000003oool0oooo0080oooo0P00I_l2003oIP030?ooo`3<0?l0
c03o00T0oooo0P3<0?l30?ooo`8006KoJ`3oool20?l002L0oooo00<000000?ooo`3oool01@3oool0
04T0oooo00<000000?ooo`3oool09@3oool20?l006<0oooo0P00ofH<0?ooo`80o`00203oool20?l0
00P0oooo00<000000?ooo`3oool00P3oool01000I_l0oooo0?ooo`00ofH20<`0o`/0oooo0P3<0?l2
0?ooo`8006KoJ`3oool20?l002L0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?oo
o`3oool09@3oool20?l006<0oooo0P00ofH80?ooo`@0c?l00P3o000:0?ooo`030?l0003oool0oooo
00D0oooo00@000000?ooo`3oool0oooo0P00I_l20?ooo`80c03o303oool20<`0o`<0oooo00<006Ko
0?ooo`3oool0J@3oool20?l002L0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?oo
o`3oool09@3oool20?l006<0oooo0P00ofH50?ooo`@0c?l00P3oool20?l000<0c?l0203oool20?l0
00H0oooo00<000000?ooo`3oool00P00I_l20?ooo`80c03o0P00ofH:0?ooo`80c?l00P3<0?l20<co
008006KoJP3oool20?l002L0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3o
ool0903oool30?l006<0oooo0P00ofH40?ooo`<0c?l0103oool20?l00080oooo0`3<o`070?ooo`80
o`001@3oool010000000oooo001Vo`00I_l20?ooo`<0c03o00<0oooo003oIP00ofH01P3oool50<co
0080c03o0P3<o`02001VofX0oooo0P3o000W0?ooo`030000003oool0oooo00D0oooo00190?ooo`03
0000003oool0oooo02@0oooo0P3o001T0?ooo`03003oIP3oool0oooo0080oooo0P3<o`060?ooo`03
0?l0003oool0oooo00<0oooo0`3<o`060?ooo`80o`00103oool00`00000006Ko001Vo`030?ooo`80
c03o0`3oool2003oIP<0oooo103<o`040?ooo`030<`0o`3oool0oooo008006Ko00<0c?l00?ooo`3o
ool0J03oool20?l002H0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0
903oool20?l006@0oooo00@00?mV0?ooo`3oool0oooo0P3<o`060?ooo`80o`001P3oool30<co00H0
oooo0P3o00030?ooo`8006Ko0`3oool20<`0o`@0oooo0P00ofH00`3oool0c?l00<co00020<co00H0
oooo0P3<0?l20?ooo`8006Ko00<0c?l00?ooo`3oool0I`3oool20?l002H0oooo00<000000?ooo`3o
ool01@3oool004T0oooo00<000000?ooo`3oool0903oool20?l006<0oooo0P00ofH20?ooo`80c?l0
1`3oool20?l000P0oooo0`3<o`040?ooo`80o`000P3oool2001Vo`<0oooo0P3<0?l60?ooo`800?mV
0P3<o`080?ooo`80c03o0P3oool2001Vo`80c?l0J03oool20?l002H0oooo00<000000?ooo`3oool0
1@3oool004T0oooo00<000000?ooo`3oool0903oool20?l006<0oooo0P00ofH20?ooo`80c?l01`3o
ool00`3o0000oooo0?ooo`090?ooo`<0c?l00`3oool20?l000<006Ko0`3oool20<`0o`D0oooo0P3<
o`000`00ofH0oooo0?ooo`080?ooo`80c03o0P3oool2001Vo`030?ooo`3<o`00c?l00280oooo00D0
okoo0<`0o`3<0?l0c03o0=FLo`070?ooo`030=h0o`3<0?l0c7Co00L0oooo00D0gP3o0<`0o`3<0?l0
c03o0<ado`0Z0?ooo`80o`009P3oool00`000000oooo0?ooo`050?ooo`00B@3oool2000002D0oooo
0P3o001S0?ooo`800?mV00<0oooo0<co003<o`001`3oool20?l000`0oooo103<o`020?ooo`80o`00
00@006Ko0000003oool0oooo0P3<0?l40?ooo`@0c?l00P00ofH:0?ooo`80c03o00@0oooo001Vo`00
I_l0oooo0P3<o`0Q0?ooo`030?oOo`3E0?l0k_oo0080oooo00<0iTSo0=joo`3oool01@3oool00`3N
0?l0c03o0<ado`060?ooo`030>ido`3N_ol0oooo0080oooo00<0kWCo0=joo`3oool0:03oool20?l0
02D0oooo0P0000070?ooo`00B@3oool00`000000oooo0?ooo`0S0?ooo`<0o`00H`3oool2003oIP03
0?ooo`3<o`00c?l000L0oooo0P3o000>0?ooo`@0c?l00P3o00000`3oool000000?ooo`020<`0o`<0
oooo103<o`030?ooo`03003oIP3oool0oooo00P0oooo0P3<0?l20?ooo`03001Vo`3oool0oooo0080
c?l0803oool00`3^M?l0g[oo0?ooo`020?ooo`030?oOo`3EB?l0oooo00h0oooo00<0gTSo0?ooo`3o
ool00P3oool00`3ogol0eDSo0?ooo`0X0?ooo`80o`009P3oool00`000000oooo0?ooo`050?ooo`00
B@3oool00`000000oooo0?ooo`0S0?ooo`<0o`00H`3oool2003oIP80c?l0203oool20?l00100oooo
00<0c?l0001Vo`00I_l00P3o0000103<o`00oooo0<`0o`3<0?l50<co00D0oooo0P00ofH90?ooo`80
c03o0P3oool2001Vo`030?ooo`3<o`00c?l00200oooo00<0gP3o0>koo`3oool00`3oool00`3N0?l0
i]oo0?ooo`0<0?ooo`030?oOo`3E0?l0k_oo00<0oooo00<0omoo0=E8o`3oool0:03oool30?l002D0
oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool08`3oool20?l006@0oooo
00@00?mV0?ooo`3<o`00c?l0203oool20?l00100oooo0P00I_l0103<o`00o`000?l0003<o`020<`0
o`@0c?l0203oool00`00ofH0oooo0?ooo`070?ooo`80c03o0P3oool2001Vo`80oooo0P3<o`0N0?oo
o`030?oOo`3E0?l0k_oo00@0oooo00<0iTSo0=joo`3oool03@3oool00`3^M?l0eIco0?ooo`020?oo
o`030>ido`3EW?l0oooo02T0oooo0P3o000U0?ooo`030000003oool0oooo00D0oooo00190?ooo`03
0000003oool0oooo02<0oooo0P3o001T0?ooo`03003oIP3oool0c?l000T0oooo00<0o`000?ooo`3o
ool03P3oool2001Vo`<0oooo0P3o00000`3<0?l0oooo0?ooo`0;0?ooo`800?mV2@3oool20<`0o`03
0?ooo`00I_l006Ko0080oooo0P3<o`0N0?ooo`030?oOo`3E0?l0k_oo00@0oooo00<0iTSo0=joo`3o
ool03P3oool01@3VB?l0c03o0<`0o`3<0?l0c7Co02/0oooo0P3o000U0?ooo`030000003oool0oooo
00D0oooo000>0?ooo`030?oo_`1dM;l0oooo03P0oooo00<000000?ooo`3oool08`3oool20?l006<0
oooo0P00ofH20<co00P0oooo0P3o000?0?ooo`8006Ko103oool00`3<0?l0o`000?ooo`0>0?ooo`03
003oIP3oool0oooo00L0oooo0P3<0?l00`3oool006Ko001Vo`030?ooo`030<co003oool0oooo01`0
oooo00<0omoo0=D0o`3^ool0103oool00`3VB?l0g[oo0?ooo`0=0?ooo`030?NLo`3EW?l0oooo0080
oooo00<0kWCo0>KOo`3oool0:@3oool20?l002D0oooo00<000000?ooo`3oool01@3oool000h0oooo
00@0omnL04P0000004P0W=oo=`3oool00`000000oooo0?ooo`0S0?ooo`80o`00H`3oool2003oIP80
c?l0203oool20?l000h0oooo0P00I_l40?ooo`80c03o0P3o000>0?ooo`800?mV203oool20<`0o`80
oooo00@006Ko0?ooo`3oool0oooo0P3<o`0N0?ooo`030=h0o`3^ool0oooo00<0oooo00<0iTSo0>KO
o`3oool03@3oool00`3N0?l0k_oo0?ooo`020?ooo`030?noo`3<M?l0oooo02T0oooo0P3o000U0?oo
o`030000003oool0oooo00D0oooo000@0?ooo`030;md00000000000000<0000000<0001d0;ooo`3o
ool0<03oool00`000000oooo0?ooo`0S0?ooo`80o`00H`3oool2003oIP030<co003oool0oooo00L0
oooo0P3o000=0?ooo`8006Ko1@3oool20<`0o`030000003o0000o`0000h0oooo00<00?mV0?ooo`3o
ool01P3oool20<`0o`80oooo00@006Ko0?ooo`3oool0oooo0P3<o`0N0?ooo`030>I8o`3Vgol0oooo
00<0oooo00<0gTSo0?ooo`3oool03@3oool00`3N0?l0i]oo0?ooo`020?ooo`030?noo`3<B?l0oooo
02T0oooo0P3o000U0?ooo`030000003oool0oooo00D0oooo000D0?ooo`030?oOW0180000M;oo0380
oooo00<000000?ooo`3oool08P3oool30?l006<0oooo0P00ofH00`3<o`00oooo0?ooo`070?ooo`80
o`00303oool2001Vo`D0oooo0P3<0?l0103oool000000?l0003o000>0?ooo`800?mV1`3oool20<`0
o`80oooo00<006Ko0?ooo`3oool00P3oool00`3<o`00oooo0?ooo`0L0?ooo`030?oOo`3E0?l0i]oo
0080oooo00<0iTSo0=joo`3oool03P3oool00`3gW?l0c4So0?ooo`020?ooo`030=h0o`3N_ol0oooo
02T0oooo0`3o000T0?ooo`030000003oool0oooo00D0oooo000C0?ooo`030=nLB00007@0_ooo03<0
oooo00<000000?ooo`3oool08P3oool30?l006<0oooo0P00ofH00`3<o`00oooo0?ooo`070?ooo`80
o`002`3oool2001Vo`D0oooo0`3<0?l00`3oool000000?ooo`020?l000d0oooo0P00ofH80?ooo`03
0<`0o`3oool0oooo008006Ko0`3oool20<co01h0oooo00D0omoo0=D0o`3<0?l0c03o0=FLo`0A0?oo
o`050?NLo`3<0?l0c03o0<`0o`3N_ol0;03oool20?l002@0oooo00<000000?ooo`3oool01@3oool0
00h0oooo00H0omnL04P0B02Lgol0okmd00000018W=le0?ooo`030000003oool0oooo0280oooo0`3o
001S0?ooo`03003oIP3<o`00c?l000T0oooo00<0o`000?ooo`3oool02@3oool2001Vo`D0oooo0`3<
0?l20?ooo`040000003oool0o`000?l000h0oooo00<00?mV0?ooo`3oool01P3oool00`3<0?l0oooo
0?ooo`02001Vo`<0oooo0P3<o`1U0?ooo`80o`00903oool00`000000oooo0?ooo`050?ooo`003P3o
ool0103ogi`0B00000000000M;lg0?ooo`030000003oool0oooo0280oooo0`3o001S0?ooo`03003o
IP3<o`00oooo00T0oooo00<0o`000?ooo`3oool0203oool2001Vo`H0oooo0P3<0?l30?ooo`030000
003oool0oooo0080o`003@3oool2003oIPL0oooo00<0c03o0?ooo`3oool00P00I_l40?ooo`030<co
003oool0oooo06<0oooo0P3o000T0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003o
ool0oooo0280oooo0`3o001S0?ooo`03003oIP3<o`00oooo00T0oooo00<0o`000?ooo`3oool0203o
ool00`00I_l0oooo0?ooo`040?ooo`80c03o103oool01@000000oooo0?ooo`3oool0o`0000d0oooo
1@00ofH40?ooo`030<`0o`3oool0oooo008006Ko103oool00`3<o`00oooo0?ooo`1S0?ooo`80o`00
903oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0R0?ooo`<0o`00H`3o
ool00`00ofH0c?l00?ooo`080?ooo`80o`002@3oool2001Vo`D0oooo0P3<0?l50?ooo`040000003o
ool0oooo0?ooo`80o`00303oool3003oIP030?ooo`00ofH00?mV00<0oooo0P3<0?l00`3oool006Ko
001Vo`040?ooo`80c?l0I03oool20?l002@0oooo00<000000?ooo`3oool01@3oool00140oooo00H0
gia800000000000000000000B02Lgolb0?ooo`030000003oool0oooo0280oooo0`3o001S0?ooo`03
003oIP3<o`00oooo00P0oooo0P3o00080?ooo`8006Ko1@3oool20<`0o`H0oooo00<000000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`090?ooo`@00?mV0P3oool2003oIP80oooo0P3<0?l00`3oool0
06Ko001Vo`040?ooo`80c?l0I03oool20?l002@0oooo00<000000?ooo`3oool01@3oool000l0oooo
00T0oono07@00018W=l0omnL09boo`3oool0gia80018W03Oool0<@3oool00`000000oooo0?ooo`0R
0?ooo`80o`00I03oool00`00ofH0c?l00?ooo`080?ooo`80o`001`3oool2001Vo`D0oooo0P3<0?l7
0?ooo`030000003oool0oooo0080oooo0P3o000:0?ooo`@00?mV0`3oool00`00ofH0oooo0?ooo`02
0<`0o`80oooo00<006Ko0?ooo`3oool00P3oool20<co06@0oooo0P3o000T0?ooo`030000003oool0
oooo00D0oooo000?0?ooo`090;mdM02oool0oooo0?noW02Lgol0oooo0?oo_`1d07@0_ooo0340oooo
0P00000S0?ooo`80o`00I03oool00`00ofH0oooo0?ooo`080?ooo`80o`001`3oool2001Vo`@0oooo
0P3<0?l80?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool01`3oool2003oIP030?oo
o`00ofH00?mV00<0oooo0P00ofH00`3oool0c03o0<`0o`020?ooo`03001Vo`3oool0oooo0080oooo
0P3<o`1T0?ooo`80o`008`3oool2000000L0oooo000>0?ooo`090?oOW02L_ol0oooo0?oog`2LM9`0
gooo0?ooo`3ogi`0B7Bo0380oooo00<000000?ooo`3oool08P3oool20?l006@0oooo00<00?mV0?oo
o`3oool0203oool20?l000H0oooo0P00I_l40?ooo`80c03o2@3oool00`000000oooo0?ooo`030?oo
o`80o`00203oool2003oIP80oooo00@00?mV0?ooo`3oool0oooo0P00ofH00`3oool0c03o0<`0o`02
0?ooo`03001Vo`3oool0oooo00<0oooo00<0c?l00?ooo`3oool0HP3oool20?l002@0oooo00<00000
0?ooo`3oool01@3oool000h0oooo00T0oknL09cOo`3oool0_g@007Boo`3oool0gia80000M02oool0
<P3oool00`000000oooo0?ooo`0R0?ooo`80o`00I03oool00`00ofH0oooo0?ooo`080?ooo`80o`00
1P3oool2001Vo`<0oooo0P3<0?l:0?ooo`030000003oool0oooo00@0oooo0P3o00070?ooo`800?mV
0P3oool2003oIP<0oooo00@00?mV0?ooo`3<0?l0c03o0P3oool00`00I_l0oooo0?ooo`030?ooo`03
0<co003oool0oooo01/0oooo00D0om;o001Vo`00I_l006Ko04Rio`070?ooo`0307AVo`00I_l009oo
00P0oooo00D0_ioo001Vo`00I_l006Ko09cXo`0[0?ooo`80o`00903oool00`000000oooo0?ooo`05
0?ooo`003P3oool0103ookl0M0000000001d_olg0?ooo`030000003oool0oooo0280oooo0P3o001T
0?ooo`03003oIP3oool0oooo00P0oooo00<0o`000?ooo`3oool01@3oool01000I_l0oooo0?ooo`3o
ool20<`0o`/0oooo00<000000?ooo`3oool0103oool20?l000L0oooo00@00?mV0?ooo`3oool0oooo
0P00ofH30?ooo`04003oIP3oool0oooo0<`0o`80oooo00<006Ko0?ooo`3oool00`3oool00`3<o`00
oooo0?ooo`0J0?ooo`030?oXo`18I_l0_ooo0080oooo00<0W8Go07CBo`3oool01@3oool00`1dI_l0
06Ko002Oo`070?ooo`070;nOo`00QOl0oooo0?ooo`3oj?l0B6Ko09cXo`0Z0?ooo`80o`00903oool0
0`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0R0?ooo`80o`00H`3oool00`3<
o`000?mV0?ooo`090?ooo`030?l0003oool0oooo00@0oooo0P00I_l20?ooo`80c03o303oool00`00
0000oooo0?ooo`050?ooo`80o`001@3oool2003oIP<0oooo0P00ofH30?ooo`04003oIP3oool0oooo
0<`0o`80oooo00<006Ko0?ooo`3oool00`3oool00`3<o`00oooo0?ooo`0J0?ooo`030;nOo`1dd_l0
oooo0080oooo00<0onSo04R5o`3oool03P3oool00`3oj?l0B6Ko09cXo`030?ooo`030?oBo`18^Ol0
oooo02T0oooo0P3o000T0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo
0280oooo0P3o001S0?ooo`800?mV2P3oool00`3o0000oooo0?ooo`040?ooo`03001Vo`3oool0oooo
0080c03o3@3oool00`000000oooo0?ooo`050?ooo`80o`001@3oool2003oIP@0oooo00@00?mV0?oo
o`3oool0oooo0P00ofH01@3oool0c03o0?ooo`3oool006Ko00D0oooo0P3<o`0K0?ooo`0307AVo`2o
ool0oooo00<0oooo00<0M6Ko09cXo`3oool03@3oool00`2oWol008Go0?ooo`030?ooo`030?oBo`00
Wol0oooo02T0oooo0P3o000T0?ooo`030000003oool0oooo00D0oooo000B0?ooo`060?noM0000000
00000000000007@0_ooo<@3oool00`000000oooo0?ooo`0R0?ooo`80o`00H`3oool2003oIPX0oooo
00<0o`000?ooo`3oool0103oool01000I_l0oooo0<`0o`3<0?l>0?ooo`030000003oool0oooo00H0
oooo0P3o00040?ooo`03003oIP3oool0oooo00<0oooo00<00?mV0?ooo`3oool00P3oool00`00ofH0
oooo0<`0o`020?ooo`03001Vo`3oool0oooo00<0oooo0P3<o`0J0?ooo`030?oXo`18I_l0_ooo00@0
oooo00<0W8Go07CBo`3oool03@3oool00`2LQOl006Ko09cXo`030?ooo`030?oXo`18Wol0oooo02T0
oooo0P3o000T0?ooo`030000003oool0oooo00D0oooo000:0?ooo`060;nLW03Oool0oooo0?ooo`3o
gi`0B0000`0000001000B9`0gooo0?oo_`1dM;lb0?ooo`030000003oool0oooo0240oooo0`3o001S
0?ooo`800?mV2P3oool00`3o0000oooo0?ooo`030?ooo`8006Ko00<0oooo0<`0o`3oool03P3oool0
0`000000oooo0?ooo`060?ooo`80o`00103oool20?l000@0oooo00<00?mV0?ooo`3oool00P3oool0
0`00ofH0oooo0<`0o`020?ooo`03001Vo`3oool0oooo00<0oooo0P3<o`0J0?ooo`030?oXo`18I_l0
_ooo00@0oooo00<0W8Go07CBo`3oool03@3oool0202oWol0M9oo001Vo`2Lj?l0oooo0?oXo`18I_l0
W>So:P3oool30?l002<0oooo00<000000?ooo`3oool01@3oool000T0oooo00<0oooO09a800000000
0`0000000`00M;l0oooo0?ooo`020?ooo`030?noM00007@0_ooo0380oooo00<000000?ooo`3oool0
8@3oool30?l006<0oooo0P00ofH:0?ooo`030?l0003oool0oooo00<0oooo0P00I_l20<`0o`l0oooo
00<000000?ooo`3oool01`3oool20?l000030?ooo`3o0000o`0000<0o`000`3oool00`00ofH0oooo
0?ooo`020?ooo`03003oIP3oool0c03o0080oooo00<006Ko0?ooo`3oool00`3oool20<co01X0oooo
00<0onSo04QVo`2oool0103oool00`2LQOl0M=;o0?ooo`0=0?ooo`030;nOo`1dd_l0gkWo00<006Ko
00<0W>So0?ooo`3oool0:@3oool30?l002<0oooo00<000000?ooo`3oool01@3oool000T0oooo00<0
oono07@00018W=l0?@3oool00`000000oooo0?ooo`0Q0?ooo`<0o`00H`3oool00`00ofH0oooo0?oo
o`090?ooo`030?l0003oool0oooo00<0oooo00<006Ko0?ooo`3<0?l0403oool00`000000oooo0?oo
o`080?ooo`@0o`0000@00?mV0?ooo`3o0000o`000P3oool00`00ofH0oooo0?ooo`020?ooo`03003o
IP3oool0c03o0080oooo00<006Ko0?ooo`3oool0103oool00`3<o`00oooo0?ooo`0I0?ooo`0307AV
o`2oool0oooo00<0oooo00<0W8Go09cXo`3oool03@3oool00`3od_l009oo0?ooo`0_0?ooo`<0o`00
8`3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0Q0?ooo`<0o`00H`3o
ool00`00ofH0oooo0?ooo`090?ooo`030?l0003oool0oooo00<0oooo00<006Ko0?ooo`3<0?l0403o
ool00`000000oooo0?ooo`0;0?ooo`800?mV0P3oool00`3o0000oooo0?ooo`02003oIP<0oooo00<0
0?mV0?ooo`3<0?l00P3oool00`00I_l0oooo0?ooo`040?ooo`030<co003oool0oooo01T0oooo00<0
W8Go09cXo`3oool00`3oool00`1dQOl0oooo0?ooo`0>0?ooo`0309b5o`1dd_l0oooo02h0oooo0`3o
000S0?ooo`030000003oool0oooo00D0oooo000A0?ooo`060?oOW018000000000000000004P0W=oo
8`3oool0102oM00000000000001d_ol;0?ooo`030000003oool0oooo0240oooo0`3o001S0?ooo`03
003oIP3oool0oooo00T0oooo00<0o`000?ooo`3oool00`3oool00`00I_l0c03o0<`0o`0@0?ooo`03
0000003oool0oooo00/0oooo00D00?mV0?ooo`3oool0oooo0?l000020?ooo`800?mV0`3oool00`00
ofH0oooo0<`0o`020?ooo`03001Vo`3oool0oooo00@0oooo00<0c?l00?ooo`3oool06@3oool00`3o
j?l0B6Ko09cXo`020?ooo`0309b5o`1dd_l0oooo0100oooo00<0M6Ko0025o`3oool0;P3oool20?l0
02<0oooo00<000000?ooo`3oool01@3oool00100oooo00<0_g@00000001d_ol00P3oool00`3ooml0
W7BL0=ooo`0Q0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO2P3oool00`000000oooo0?ooo`0Q
0?ooo`<0o`00H`3oool00`00ofH0oooo0?ooo`090?ooo`030?l0003oool0oooo00<0oooo00<006Ko
0<`0o`3oool0403oool00`000000oooo0?ooo`0;0?ooo`05003oIP3oool0oooo0?ooo`3o00000`3o
ool01`00ofH0oooo0?ooo`3oool00?mV0?ooo`3<0?l00P3oool00`00I_l0oooo0?ooo`040?ooo`03
0<co003oool0oooo01X0oooo00D0onSo04QVo`00I_l006Ko04Rio`0C0?ooo`050=nio`00I_l006Ko
001Vo`00Wol0:`3oool20?l002<0oooo00<000000?ooo`3oool01@3oool000l0oooo00<0gia804RL
g`3oool0103oool00`3OW9`0_ooo0?ooo`0O0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000
B02Lgol02@3oool00`000000oooo0?ooo`0Q0?ooo`<0o`00H`3oool00`00ofH0oooo0?ooo`090?oo
o`030?l0003oool0oooo00<0oooo00<006Ko0<`0o`3oool0403oool00`000000oooo0?ooo`0;0?oo
o`05003oIP3oool0oooo0?ooo`3o00000`3oool01`00ofH0oooo0?ooo`3oool00?mV0?ooo`3<0?l0
0P3oool00`00I_l0oooo0?ooo`040?ooo`030<co003oool0oooo0680oooo0P3o000S0?ooo`030000
003oool0oooo00D0oooo000>0?ooo`030?oOW01dW=l0oooo00@0oooo00<0oooO09adW03Oool0803o
ool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`P0oooo00<000000?ooo`3oool0
8@3oool30?l006<0oooo00<00?mV0?ooo`3oool02@3oool00`3o0000oooo0?ooo`030?ooo`03001V
o`3<0?l0oooo0100oooo00<000000?ooo`3oool02`3oool01@00ofH0oooo0?ooo`3oool0o`0000<0
oooo00L00?mV0?ooo`3oool0oooo003oIP3oool0c03o0080oooo00<006Ko0?ooo`3oool0103oool0
0`3<o`00oooo0?ooo`1R0?ooo`80o`008`3oool00`000000oooo0?ooo`050?ooo`003P3oool00`3o
_i`0W=oo0?ooo`030?ooo`030?oog`2LB000M;oo0240oooo00<0oooO09a80000M;l00`3oool00`3O
W4P0001809cOo`080?ooo`030000003oool0oooo0240oooo0`3o001S0?ooo`03003oIP3oool0oooo
00T0oooo00<0o`000?ooo`3oool00`3oool01000I_l0c03o001Vo`00I_l?0?ooo`030000003oool0
oooo00/0oooo00@00?mV0?ooo`3oool0oooo0P3o00020?ooo`07003oIP3oool0oooo0?ooo`00ofH0
oooo0<`0o`020?ooo`03001Vo`3oool0oooo00@0oooo00<0c?l00?ooo`3oool0HP3oool20?l002<0
oooo00<000000?ooo`3oool01@3oool000h0oooo00<0omnL04Qd_`3oool00P3oool00`3OW4P00000
04RLg`0S0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0203ooolT000000<0o`00
H`0000000`00ofH0000000000009000000030?l000000000000000<0000000@006Ko0<`0o`00I_l0
06Ko7@0000001000ofH000000000000000020?l00080000000L00?mV0000000000000000003oIP00
0000c03o0080000000<006Ko000000000000100000000`3<o`0000000000001R00000080o`009000
00070?ooo`003`3oool01P3o_g@0000000000000000004RL0=ooob@0oooo00<0gia80000B02Lgol0
0P3oool00`3ooml0W4P0001d_`080?ooo`030000003oool0oooo0240oooo0`3o001S0?ooo`03003o
IP3oool0oooo00T0oooo00<0o`000?ooo`3oool00`3oool01000I_l0c03o001Vo`00I_l?0?ooo`03
0000003oool0oooo00/0oooo00@00?mV0?ooo`3oool0oooo0P3o00020?ooo`07003oIP3oool0oooo
0?ooo`00ofH0oooo0<`0o`020?ooo`03001Vo`3oool0oooo00@0oooo00<0c?l00?ooo`3oool0HP3o
ool20?l002<0oooo00<000000?ooo`3oool01@3oool003T0oooo00<0omnL04P00018W=l00`3oool0
0`2oM00004RL0=ooo`070?ooo`030000003oool0oooo0240oooo0`3o001S0?ooo`03003oIP3oool0
oooo00T0oooo00<0o`000?ooo`3oool00`3oool01000I_l0c03o001Vo`00I_l?0?ooo`030000003o
ool0oooo00/0oooo00D00?mV0?ooo`3oool0oooo0?l000030?ooo`07003oIP3oool0oooo0?ooo`00
ofH0oooo0<`0o`020?ooo`03001Vo`3oool0oooo00@0oooo00<0c?l00?ooo`3oool0HP3oool20?l0
02<0oooo00<000000?ooo`3oool01@3oool003T0oooo00@0oooO09a80000B9`0gooo0P3oool00`3O
W4P004RL0=ooo`070?ooo`030000003oool0oooo0240oooo0`3o001S0?ooo`03003oIP3oool0oooo
00T0oooo00<0o`000?ooo`3oool00`3oool01000I_l0c03o0<`0o`00I_l?0?ooo`030000003oool0
oooo00/0oooo00D00?mV0?ooo`3oool0oooo0?l000030?ooo`07003oIP3oool0oooo0?ooo`00ofH0
oooo0<`0o`020?ooo`03001Vo`3oool0oooo00@0oooo00<0c?l00?ooo`3oool0HP3oool20?l002<0
oooo00<000000?ooo`3oool01@3oool00140oooo00H0omnL04P00000000000000000B02LgolS0?oo
o`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01`3oool00`000000oooo0?ooo`0Q0?oo
o`<0o`00H`3oool00`00ofH0oooo0?ooo`090?ooo`030?l0003oool0oooo00<0oooo00@006Ko0<`0
o`3<0?l006Ko3`3oool00`000000oooo0?ooo`0;0?ooo`05003oIP3oool0oooo0?ooo`3o00000`3o
ool01`00ofH0oooo0?ooo`3oool00?mV0?ooo`3<0?l00P3oool00`00I_l0oooo0?ooo`040?ooo`03
0<co003oool0oooo0680oooo0P3o000S0?ooo`030000003oool0oooo00D0oooo000?0?ooo`040?oo
g`2LB00004RL0=ooo`80oooo00<0okmd0018W03Oool08`3oool01P3OW4P0001d0;ooo`3ooml0W4P0
04RLg`P0oooo00<000000?ooo`3oool08@3oool30?l006<0oooo0P00ofH:0?ooo`030?l0003oool0
oooo00<0oooo0P00I_l40<`0o`d0oooo00<000000?ooo`3oool02`3oool2003oIP80oooo00<0o`00
0?ooo`3oool00P00ofH30?ooo`03003oIP3oool0c03o0080oooo00<006Ko0?ooo`3oool0103oool0
0`3<o`00oooo0?ooo`1R0?ooo`80o`008`3oool00`000000oooo0?ooo`050?ooo`003`3oool00`2o
M4P0W=oo0?ooo`030?ooo`030?oog`2LB7@0_ooo02@0oooo00@0gia800000000000007Bo2@3oool0
0`000000oooo0?ooo`0Q0?ooo`<0o`00H`3oool2003oIPX0oooo00<0o`000?ooo`3oool01P3oool4
0<`0o``0oooo00<000000?ooo`3oool0303oool01000ofH0oooo0?ooo`3o00020?ooo`03003oIP3o
ool0oooo0080oooo00<00?mV0?ooo`3<0?l00P3oool00`00I_l0oooo0?ooo`040?ooo`030<co003o
ool0oooo01X0oooo00D0oonO003oIP00ofH00?mV04Soj0060?ooo`040?oodP1dofH00?mV003odPP0
oooo00D0oonO003oIP00ofH00?mV003o^@0[0?ooo`<0o`008`3oool00`000000oooo0?ooo`050?oo
o`003P3oool00`3ogi`0W;oo0?ooo`040?ooo`030?oOW018M;l0oooo0340oooo00<000000?ooo`3o
ool08P3oool20?l006<0oooo0P00ofH:0?ooo`030?l0003oool0oooo00H0oooo00<006Ko0<`0o`3<
0?l00P3<0?l;0?ooo`030000003oool0oooo00`0oooo00@00?mV0?ooo`3o0000o`000P3oool00`00
ofH0oooo0?ooo`020?ooo`03003oIP3oool0c03o0080oooo00<006Ko0?ooo`3oool0103oool00`3<
o`00oooo0?ooo`0I0?ooo`030?oo^@18oil0_ooo0080oooo00<0W?mV07Coo`3oool0103oool0103o
om80M?mV003oIP00om8:0?ooo`030?ooW`00om80oooo02/0oooo0`3o000S0?ooo`030000003oool0
oooo00D0oooo000>0?ooo`030?noW02Lgol0oooo00<0oooo00<0omnL04Q8W03Oool0<P3oool00`00
0000oooo0?ooo`0R0?ooo`80o`00H`3oool2003oIPX0oooo00<0o`000?ooo`3oool01P3oool2001V
o`<0c03o2`3oool00`000000oooo0?ooo`0<0?ooo`03003oIP3oool0o`0000<0oooo00<00?mV0?oo
o`3oool00P3oool00`00ofH0oooo0<`0o`020?ooo`03001Vo`3oool0oooo00<0oooo0P3<o`0K0?oo
o`030;ooIP1dool0oooo0080oooo00<0ooni04So^@3oool04P3oool00`3ooil00?oB0?ooo`0[0?oo
o`80o`00903oool00`000000oooo0?ooo`050?ooo`003P3oool0103ookl0M0000000001d_olg0?oo
o`030000003oool0oooo0280oooo0P3o001S0?ooo`800?mV2P3oool00`3o0000oooo0?ooo`070?oo
o`8006Ko0`3<0?l:0?ooo`030000003oool0oooo00`0oooo00<00?mV0?l0003o00000`3oool00`00
ofH0oooo0?ooo`020?ooo`03003oIP3oool0c03o0080oooo00<006Ko0?ooo`3oool00`3oool20<co
01X0oooo00<0oooB07CoW`2oool00`3oool00`3oom80M?n509coo`0=0?ooo`030?oo^@18ofH00?mV
00@00?mV00<00?ni0?ooo`3oool0:@3oool20?l002@0oooo00<000000?ooo`3oool01@3oool004T0
oooo00<000000?ooo`3oool08P3oool20?l006<0oooo0P00ofH:0?ooo`030?l0003oool0oooo00L0
oooo0P00I_l00`3oool0c03o0<`0o`0:0?ooo`030000003oool0oooo00`0oooo0P3o00030?ooo`80
0?mV103oool00`00ofH0oooo0<`0o`020?ooo`03001Vo`3oool0oooo00<0oooo0P3<o`0J0?ooo`03
0?oo^@18oil0_ooo00@0oooo00<0W?mV07Coo`3oool0303oool00`3oom80M?mV07Coo`020?ooo`03
0?ooW`00om80oooo02/0oooo0P3o000T0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000
003oool0oooo0280oooo0P3o001S0?ooo`800?mV2P3oool00`3o0000oooo0?ooo`070?ooo`8006Ko
0P3oool20<`0o`T0oooo00<000000?ooo`3oool01P3oool70?l00005003oIP3oool0oooo0?ooo`00
ofH01@3oool00`00ofH0oooo0<`0o`020?ooo`03001Vo`3oool0oooo00<0oooo00<0c?l00?ooo`3o
ool06@3oool00`3ookT0B?nO0;ooo`040?ooo`0309coIP1dool0oooo00d0oooo00H0oonO003oW`2o
ool0oooo0?ooW`00om8/0?ooo`80o`00903oool00`000000oooo0?ooo`050?ooo`003P3oool00`3o
okl0W9cO0?ooo`030?ooo`040?noM0000000001d0;oooc40oooo00<000000?ooo`3oool08P3oool2
0?l006@0oooo00<00?mV0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`05001Vo`3oool0
oooo0?ooo`3<0?l02@3oool00`000000oooo0?ooo`050?ooo`<0o`001@3oool2003oIP030?ooo`00
ofH00?mV00@0oooo0P00ofH01@3oool0c03o0?ooo`3oool006Ko00D0oooo00<0c?l00?ooo`3oool0
6@3oool00`3ookT0B?nO0;ooo`040?ooo`0309coIP1dool0oooo00h0oooo00D0W?mV04Soj03oool0
oonO003odP0/0?ooo`80o`00903oool00`000000oooo0?ooo`050?ooo`003P3oool0103ookl0W9cO
0?oo_`1d0004000000030018W03Oool0oooo0300oooo00<000000?ooo`3oool08P3oool20?l006@0
oooo00<00?mV0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`8006Ko0P3oool20<`0o`P0
oooo00<000000?ooo`3oool0103oool20?l000P0oooo0`00ofH50?ooo`800?mV00D0oooo0<`0o`3o
ool0oooo001Vo`050?ooo`030<co003oool0oooo01T0oooo00<0oooB07CoW`2oool0103oool00`2L
ohD0W?oo0?ooo`0>0?ooo`050?oo^@18ohD0W?oo0?ooW`00om80;03oool20?l002@0oooo00<00000
0?ooo`3oool01@3oool000h0oooo00T0omnL04P000000000001809cOo`3oool0oooO09a8M02oool0
<P3oool00`000000oooo0?ooo`0R0?ooo`80o`00I03oool00`00ofH0oooo0?ooo`080?ooo`80o`00
2@3oool2001Vo`<0oooo0P3<0?l70?ooo`030000003oool0oooo00<0oooo0P3o000A0?ooo`04003o
IP3oool0c03o0<`0o`80oooo00<006Ko0?ooo`3oool00`3oool00`3<o`00oooo0?ooo`0J0?ooo`03
09coQ@2Lool0oooo0080oooo00<0oooB07Co^@3oool0403oool0103OohD00?ni0?ooW`00om8/0?oo
o`80o`00903oool00`000000oooo0?ooo`050?ooo`002P3oool0103ooml0W4P00000M02ooolk0?oo
o`030000003oool0oooo0280oooo0P3o001T0?ooo`03003oIP3oool0oooo00P0oooo0P3o000:0?oo
o`8006Ko0P3oool20<`0o`L0oooo00<000000?ooo`3oool00P3oool20?l00180oooo00@00?mV0?oo
o`3<0?l0c03o0P3oool00`00I_l0oooo0?ooo`030?ooo`030<co003oool0oooo01X0oooo00<0ooni
04SoQ@2Lool00P3oool00`2LofH0M?oo0?ooo`0A0?ooo`0309coIP18ohD00?oB02`0oooo0P3o000T
0?ooo`030000003oool0oooo00D0oooo00190?ooo`8000008`3oool20?l006@0oooo00<00?mV0?oo
o`3oool0203oool20?l000X0oooo0P00I_l30?ooo`80c03o1P3oool00`000000oooo0?ooo`020?oo
o`80o`004@3oool2003oIP030?ooo`3<0?l0c03o0080oooo00<006Ko0?ooo`3oool00P3oool20<co
01d0oooo00D0ooni04SoIP00ofH00?mV04Soj00C0?ooo`030?oo^@18ofH00?oB02`0oooo0P3o000S
0?ooo`8000001`3oool000h0oooo00D0omno0;oOo`3oool0oooo0;md0003000000030000M02oool0
oooo0300oooo00<000000?ooo`3oool08P3oool20?l006@0oooo00<00?mV0<co003oool0203oool2
0?l000/0oooo0P00I_l20?ooo`80c03o1P3oool010000000oooo0?ooo`3oool20?l00180oooo0P00
ofH0103oool0c03o0<`0o`3oool2001Vo`@0oooo0P3<o`1T0?ooo`80o`00903oool00`000000oooo
0?ooo`050?ooo`003P3oool00`2oM000000000000002000000050000M02oool0oooo0;nLW03Oool0
<@3oool00`000000oooo0?ooo`0R0?ooo`<0o`00H`3oool00`00ofH0c?l00?ooo`080?ooo`80o`00
303oool01000I_l0oooo0?ooo`3oool20<`0o`D0oooo00<000000?ooo`3oool00P3o000C0?ooo`80
0?mV00@0oooo0<`0o`3<0?l0oooo0P00I_l40?ooo`80c?l0I03oool20?l002@0oooo00<000000?oo
o`3oool01@3oool000`0oooo00D0_g@000000000000004RL0=ooo`030?ooo`030?oog`2LB000M;oo
0080oooo00<0_g@00018W03Oool0;@3oool00`000000oooo0?ooo`0R0?ooo`<0o`00H`3oool00`00
ofH0c?l00?ooo`090?ooo`030?l0003oool0oooo00X0oooo0P00I_l20?ooo`<0c03o103oool00`00
0000oooo0?ooo`020?l001<0oooo0P00ofH0103oool0c03o0<`0o`3oool2001Vo`@0oooo00<0c?l0
0?ooo`3oool0HP3oool30?l002@0oooo00<000000?ooo`3oool01@3oool000h0oooo00<0oknL09cO
o`3oool0203oool00`3ogi`0B7Bo0?ooo`0]0?ooo`030000003oool0oooo0280oooo0`3o001S0?oo
o`03003oIP3<o`00oooo00T0oooo00<0o`000?ooo`3oool02`3oool01000I_l0oooo0?ooo`3oool2
0<`0o`@0oooo00@000000?ooo`3o0000o`004`3oool2003oIP80oooo00<0c03o0?ooo`3oool00P00
I_l40?ooo`030<co003oool0oooo0680oooo0`3o000T0?ooo`030000003oool0oooo00D0oooo000>
0?ooo`030?oo_`1dM;l0oooo00L0oooo00<0okmd0018W03Oool0;P3oool00`000000oooo0?ooo`0R
0?ooo`<0o`00H`3oool2003oIPX0oooo00<0o`000?ooo`3oool02`3oool2001Vo`<0oooo0P3<0?l3
0?ooo`040000003oool0o`000?l001<0oooo0P00ofH20?ooo`030<`0o`3oool0oooo008006Ko0`3o
ool20<co06@0oooo0P3o000U0?ooo`030000003oool0oooo00D0oooo000>0?ooo`040?oOW0180000
001d0;ooo`D0oooo00<0gia8001d_`3oool0;`3oool00`000000oooo0?ooo`0R0?ooo`<0o`00H`3o
ool2003oIP030<co003oool0oooo00L0oooo00<0o`000?ooo`3oool0303oool2001Vo`80oooo0P3<
0?l30?ooo`030000003o0000o`0001@0oooo0P00ofH20?ooo`030<`0o`3oool0oooo008006Ko0`3o
ool20<co06@0oooo0P3o000U0?ooo`030000003oool0oooo00D0oooo000?0?ooo`030?oOW0180000
000000D0000000<0B9cO0?ooo`3oool0;`3oool00`000000oooo0?ooo`0R0?ooo`<0o`00H`3oool2
003oIP030<co003oool0oooo00L0oooo0P3o000=0?ooo`8006Ko0`3oool20<`0o`80oooo0P3o000E
0?ooo`800?mV0P3oool0103<0?l0oooo0?ooo`00I_l40?ooo`80c?l0I03oool20?l002D0oooo00<0
00000?ooo`3oool01@3oool001@0oooo00<0okmd0000B02Lgol0<P3oool00`000000oooo0?ooo`0R
0?ooo`<0o`00H`3oool2003oIP030<co003oool0oooo00L0oooo0P3o000>0?ooo`8006Ko0`3oool2
0<`0o`030?ooo`3o0000o`0001@0oooo0P00ofH20?ooo`80c03o0P3oool00`00I_l0oooo0?ooo`02
0?ooo`030<co003oool0oooo06<0oooo0P3o000U0?ooo`030000003oool0oooo00D0oooo000C0?oo
o`030;md0000M;l0oooo03<0oooo00<000000?ooo`3oool08`3oool20?l006<0oooo0P00ofH20<co
00P0oooo0P3o000?0?ooo`8006Ko0P3oool20<`0o`80o`005@3oool2003oIP80oooo0P3<0?l00`3o
ool006Ko001Vo`030?ooo`80c?l07`3oool01@3oog@0c?l00<co003<o`00eOoO00H0oooo00@0oono
0=ko003<o`00c?no1@3oool00`3^o`00c?l00<co00040<co00030<coW03oool0oooo02P0oooo0P3o
000U0?ooo`030000003oool0oooo00D0oooo000>0?ooo`060?oOW0180000M;oo0?noM0000000M;oo
=@3oool00`000000oooo0?ooo`0S0?ooo`80o`00H`3oool2003oIP80c?l0203oool20?l000l0oooo
0P00I_l30?ooo`030<`0o`3o0000000001D0oooo0P00ofH20?ooo`80c03o00<0oooo001Vo`00I_l0
0`3oool20<co01h0oooo00<0oonL0=GoM03^ool00P3oool00`3Vo`00g_oo0?ooo`040?ooo`040?oo
_`3No`00c?l00<co_`D0oooo00<0mom80<coM03^ool00`3oool00`3ooi`0eOnL0?ooo`0Y0?ooo`80
o`009@3oool00`000000oooo0?ooo`050?ooo`003P3oool0103ogi`0B00000000000M;lg0?ooo`03
0000003oool0oooo02<0oooo0P3o001S0?ooo`800?mV0P3<o`090?ooo`030?l0003oool0oooo00h0
oooo0P00I_l20?ooo`80o`0000<0c03o0?ooo`3oool04P3oool2003oIP<0oooo00<0c03o0?ooo`3o
ool00P00I_l30?ooo`030<co003oool0oooo01d0oooo00<0k_l00=koo`3oool00P3oool00`3ooi`0
eOnL0?ooo`0>0?ooo`030?ooM03<odP0i_oo02h0oooo0P3o000U0?ooo`030000003oool0oooo00D0
oooo00190?ooo`030000003oool0oooo02<0oooo0P3o001S0?ooo`800?mV00<0oooo0<co003<o`00
203oool20?l00100oooo0P00I_l20?l00080c03o503oool2003oIP<0oooo00<0c03o0?ooo`3oool0
0P00I_l20?ooo`80c?l07P3oool00`3ookl0g_md0>koo`030?ooo`030?oo_`3NodP0i_oo00l0oooo
00<0oonL0=Go003Nool0;@3oool20?l002D0oooo00<000000?ooo`3oool01@3oool004T0oooo00<0
00000?ooo`3oool08`3oool20?l006@0oooo00@00?mV0?ooo`3<o`00c?l0203oool20?l00140oooo
00@006Ko0?l0003o0000c?l00P3<0?l30<co00l0oooo0P00ofH30?ooo`80c03o0P3oool2001Vo`80
oooo0P3<o`0N0?ooo`030?ooW03Eog@0k_oo00@0oooo00<0i_l00=koo`3oool03`3oool00`3ookl0
g_l00=Gog`0/0?ooo`80o`009@3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo
0?ooo`0S0?ooo`<0o`00H`3oool2003oIP030?ooo`3<o`00c?l000L0oooo0P3o000>0?ooo`<0c?l0
0P3o0000103<o`00oooo0<`0o`3<0?l50<co00d0oooo0P00ofH30?ooo`80c03o0P3oool00`00I_l0
oooo0?ooo`020<co01l0oooo00<0oonL0=GoM03^ool0103oool00`3Vo`00g_oo0?ooo`0A0?ooo`03
0>Ko003Eoml0oooo02X0oooo00<0o`000?ooo`3oool0903oool00`000000oooo0?ooo`050?ooo`00
B@3oool00`000000oooo0?ooo`0S0?ooo`<0o`00H`3oool2003oIP030?ooo`3<o`00c?l000L0oooo
0P3o000<0?ooo`@0c?l00`3o00000`00I_l0oooo000000020<`0o`80oooo103<o`0:0?ooo`800?mV
103oool20<`0o`80oooo00<006Ko0?ooo`3oool00P3<o`0O0?ooo`030?ooW03Eog@0k_oo00@0oooo
00<0i_l00=koo`3oool04P3oool00`3VodP0i_oo0?ooo`0Y0?ooo`030?l0003oool0oooo02@0oooo
00<000000?ooo`3oool01@3oool004T0oooo0P00000T0?ooo`<0o`00H`3oool2003oIP80oooo0P3<
o`070?ooo`030?l0003oool0oooo00P0oooo1@3<o`00103oool0o`000?l0003oool2001Vo`040000
003oool0c03o0<`0o`<0oooo103<o`080?ooo`800?mV103oool00`3<0?l0oooo0?ooo`02001Vo`03
0?ooo`3<o`00c?l00200oooo00<0oono0=koM03^ool0103oool00`3VodP0i_oo0?ooo`0B0?ooo`03
0?ooM03<okl0oooo02P0oooo0P3o000U0?ooo`8000001`3oool004T0oooo00<000000?ooo`3oool0
903oool20?l006<0oooo0P00ofH20?ooo`80c?l01`3oool20?l000L0oooo1@3<o`020?ooo`80o`00
0`3oool2001Vo`030?ooo`3<0?l0c03o00D0oooo0`3<o`060?ooo`800?mV1@3oool00`3<0?l0oooo
0?ooo`02001Vo`030?ooo`3<o`00c?l00240oooo00<0i_m80>Koo`3oool00P3oool00`3ookl0g_nL
0?ooo`0=0?ooo`030?ooM03<oi`0oooo00<0oooo00<0mom80<co_`3oool0:03oool20?l002H0oooo
00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0903oool20?l006<0oooo0P00
ofH30?ooo`80c?l01P3oool20?l000H0oooo103<o`030?ooo`<0o`000`3oool2001Vo`80oooo0P3<
0?l60?ooo`<0c?l00`3oool2003oIPD0oooo0P3<0?l20?ooo`8006Ko0P3<o`0R0?ooo`030?ooW03E
odP0i_oo0080oooo00<0i_l00=koo`3oool03P3oool01`3Vo`00c?no0?ooo`3oool0oomd0<co003N
ool0:@3oool20?l002H0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0
903oool20?l006<0oooo0P00ofH40?ooo`80c?l01P3oool00`3o0000oooo0?ooo`020?ooo`@0c?l0
1@3oool20?l000D0oooo0P00I_l20?ooo`80c03o1`3oool30<co00030?ooo`00ofH00?mV00D0oooo
0P3<0?l20?ooo`8006Ko00<0c?l00?ooo`3oool08P3oool01@3ooi`0eOl00<co003<o`00eOoO0140
oooo00D0k_l00<co003<o`00c?l00=koo`0Z0?ooo`80o`009P3oool00`000000oooo0?ooo`050?oo
o`00B@3oool00`000000oooo0?ooo`0T0?ooo`80o`00I03oool00`00ofH0oooo0?ooo`030?ooo`<0
c?l0103oool20?l000D0c?l01P3oool20?l000H0oooo00<00000001Vo`00I_l00P3oool20<`0o`L0
oooo0P3<o`02003oIPH0oooo00H0c03o0?ooo`3oool0oooo001Vo`3<o`1Z0?ooo`030?l0003oool0
oooo02D0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0903oool30?l0
06<0oooo0P00ofH60?ooo`D0c?l00P3o00030<co00L0oooo0P3o00070?ooo`040000003oool006Ko
001Vo`80oooo00<0c03o0?ooo`3oool01P3oool2003oIP<0c?l00`3oool20<`0o`80oooo0P00I_mZ
0?ooo`80o`009`3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0U0?oo
o`80o`00H`3oool2003oIPT0oooo0P3<o`000`3oool0o`000?l000080?ooo`80o`00203oool01000
0000oooo001Vo`00I_l20?ooo`80c03o1P3oool2003oIP80oooo1@3<o`020<`0o`80c?l00P00I_mZ
0?ooo`80o`009`3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0U0?oo
o`80o`00H`3oool2003oIP`0oooo0P3o00070?ooo`80o`002@3oool00`000000oooo0?ooo`02001V
o`80oooo0P3<0?l40?ooo`800?mV203oool01@3<0?l0oooo0?ooo`3oool006Ko06/0oooo0P3o000W
0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo02D0oooo0P3o001T0?oo
o`03003oIP3oool0oooo00/0oooo0P3o00050?ooo`80o`002P3oool010000000oooo0?ooo`3oool2
001Vo`80oooo0P3<0?l20?ooo`800?mV203oool20<`0o`80oooo0P00I_m[0?ooo`80o`009`3oool0
0`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0U0?ooo`80o`00I03oool00`00
ofH0oooo0?ooo`0<0?ooo`<0o`0000@0oooo0?l0003o0000o`002`3oool00`000000oooo0?ooo`02
0?ooo`8006Ko0P3oool20<`0o`800?mV203oool20<`0o`<0oooo0P00I_mZ0?ooo`<0o`009`3oool0
0`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0U0?ooo`<0o`00H`3oool2003o
IPh0oooo103o000=0?ooo`030000003oool0oooo00<0oooo0P00I_l20?ooo`80c03o2@3oool20<`0
o`80oooo0P00I_m[0?ooo`80o`00:03oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000
oooo0?ooo`0V0?ooo`80o`00H`3oool2003oIQl0oooo00<000000?ooo`3oool0103oool01000I_l0
oooo003oIP00ofH20<`0o`L0oooo0P3<0?l30?ooo`8006KoJ`3oool20?l002P0oooo00<000000?oo
o`3oool01@3oool004T0oooo00<000000?ooo`3oool09P3oool20?l006<0oooo0P00ofHO0?ooo`03
0000003oool0oooo00@0oooo00<00?mV001Vo`00ofH00P3oool30<`0o`@0oooo0P3<0?l40?ooo`03
001Vo`3oool0oooo0380oooo00D0okmd0?l0003o0000o`000?nLg`0c0?ooo`80o`00:03oool00`00
0000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0V0?ooo`80o`00I03oool00`00ofH0
oooo0?ooo`0M0?ooo`030000003oool0oooo00<0oooo0P00ofH2001Vo`<0oooo1`3<0?l40?ooo`80
06Ko<`3oool00`3ogi`0o`1d0?ooo`020?ooo`030?m8003o_ol0oooo0300oooo0`3o000X0?ooo`03
0000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo02H0oooo0`3o001S0?ooo`800?mV
7P3oool00`000000oooo0?ooo`020?ooo`800?mV0P3oool3001Vo`@0oooo0P3<0?l60?ooo`03001V
o`3oool0oooo0380oooo00<0og@00?noo`3oool00P3oool00`3ogi`0odRL0?ooo`0`0?ooo`<0o`00
:03oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0V0?ooo`<0o`00H`3o
ool2003oIQh0oooo00@000000?ooo`3oool0oooo0P00ofH40?ooo`<006Ko2P3oool2001Voc<0oooo
00<0oono0?l0M03oool00`3oool00`3ookl0o`180?oOo`0`0?ooo`80o`00:@3oool00`000000oooo
0?ooo`050?ooo`00B@3oool2000002P0oooo0P3o001S0?ooo`800?mV7P3oool00`000000oooo003o
IP02003oIPL0oooo0P00I_l80?ooo`8006Ko=03oool00`3ogi`0o`1d0?ooo`040?ooo`030?m8003o
_ol0oooo02l0oooo0P3o000X0?ooo`8000001`3oool004T0oooo00<000000?ooo`3oool09`3oool2
0?l006@0oooo0P00ofHM0?ooo`0400000000ofH00?mV003oIPT0oooo0`00I_l50?ooo`8006Ko=@3o
ool00`3ogi`0o`1d0?ooo`040?ooo`030?m8003o_ol0oooo02l0oooo0P3o000Y0?ooo`030000003o
ool0oooo00D0oooo00190?ooo`030000003oool0oooo02L0oooo0P3o001T0?ooo`800?mV7@3oool2
003oIP`0oooo2000I_lf0?ooo`030?oOW03o07@0oooo00@0oooo00<0odP00?noo`3oool0;P3oool2
0?l002X0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0:03oool20?l0
06@0oooo00<00?mV0?ooo`3oool06P3oool2003oIT/0oooo00<0oono0?l0M03oool0103oool00`3o
B4P0omoo0?ooo`0^0?ooo`80o`00:P3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000
oooo0?ooo`0X0?ooo`80o`00I03oool2003oIQT0oooo0`00ofH00`000000oooo0?ooo`1:0?ooo`03
0?m8B03ogol0oooo0080oooo00<0oono0?m8W03oool0;`3oool20?l002X0oooo00<000000?ooo`3o
ool01@3oool004T0oooo00<000000?ooo`3oool0:03oool20?l006@0oooo0P00ofHH0?ooo`800?mV
0P3oool00`000000oooo0?ooo`1:0?ooo`030?oOW03o04P0omoo0080oooo00<0odP00?noo`3oool0
;`3oool20?l002X0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0:03o
ool30?l006@0oooo0P00ofHF0?ooo`800?mV0`3oool00`000000oooo0?ooo`1;0?ooo`050?oOW03o
0000o`000?l0003oW=l0<03oool20?l002/0oooo00<000000?ooo`3oool01@3oool004T0oooo00<0
00000?ooo`3oool0:@3oool20?l006@0oooo0P00ofHD0?ooo`<00?mV103oool00`000000oooo0?oo
o`200?ooo`80o`00:`3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0Y
0?ooo`80o`00I@3oool2003oIQ80oooo0`00ofH50?ooo`030000003oool0oooo0800oooo0P3o000[
0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo02T0oooo0P3o001U0?oo
o`800?mV4@3oool2003oIPL0oooo00<000000?ooo`3oool0P03oool20?l002/0oooo00<000000?oo
o`3oool01@3oool004T0oooo00<000000?ooo`3oool0:@3oool30?l006D0oooo0P00ofH>0?ooo`<0
0?mV203oool00`000000oooo0?ooo`1o0?ooo`80o`00;03oool00`000000oooo0?ooo`050?ooo`00
B@3oool00`000000oooo0?ooo`0Z0?ooo`80o`00IP3oool2003oIP`0oooo0`00ofH90?ooo`030000
003oool0oooo07l0oooo0P3o000/0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003o
ool0oooo02X0oooo0P3o001W0?ooo`800?mV2@3oool3003oIP/0oooo00<000000?ooo`3oool0O`3o
ool20?l002`0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0:P3oool3
0?l006L0oooo0`00ofH40?ooo`D00?mV303oool00`000000oooo0?ooo`1n0?ooo`<0o`00;03oool0
0`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0Z0?ooo`<0o`00J03oool8003o
IPl0oooo00<000000?ooo`3oool0OP3oool20?l002d0oooo00<000000?ooo`3oool01@3oool004T0
oooo00<000000?ooo`3oool0:`3oool20?l007l0oooo00<000000?ooo`3oool0OP3oool20?l002d0
oooo00<000000?ooo`3oool01@3oool004T0oooo0P00000/0?ooo`80o`00O`3oool00`000000oooo
0?ooo`1n0?ooo`80o`00;03oool2000000L0oooo00190?ooo`030000003oool0oooo02/0oooo0`3o
001n0?ooo`030000003oool0oooo07d0oooo0`3o000]0?ooo`030000003oool0oooo00D0oooo0019
0?ooo`030000003oool0oooo02`0oooo0P3o001n0?ooo`030000003oool0oooo07d0oooo0P3o000^
0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo02`0oooo0P3o001n0?oo
o`030000003oool0oooo07d0oooo0P3o000^0?ooo`030000003oool0oooo00D0oooo00190?ooo`03
0000003oool0oooo02`0oooo0`3o001m0?ooo`030000003oool0oooo07`0oooo0`3o000^0?ooo`03
0000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo02d0oooo0P3o001m0?ooo`030000
003oool0oooo07`0oooo0P3o000_0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003o
ool0oooo02d0oooo0`3o001l0?ooo`030000003oool0oooo07`0oooo0P3o000_0?ooo`030000003o
ool0oooo00D0oooo00190?ooo`030000003oool0oooo02d0oooo0`3o001l0?ooo`030000003oool0
oooo07/0oooo0P3o000`0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo
02h0oooo0P3o001l0?ooo`030000003oool0oooo07/0oooo0P3o000`0?ooo`030000003oool0oooo
00D0oooo00190?ooo`030000003oool0oooo02h0oooo0`3o001k0?ooo`030000003oool0oooo07X0
oooo0`3o000`0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo02h0oooo
0`3o001k0?ooo`030000003oool0oooo07X0oooo0P3o000a0?ooo`030000003oool0oooo00D0oooo
000_0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool00`3oool0102oM00000000000
001d_ol;0?ooo`030000003oool0oooo02l0oooo0P3o001k0?ooo`030000003oool0oooo07X0oooo
0P3o000a0?ooo`030000003oool0oooo00D0oooo000a0?ooo`030?noM0000000M;oo00D0oooo00H0
gia8001d_`3oool0omnL04P00018W=l:0?ooo`030000003oool0oooo02l0oooo0`3o001j0?ooo`03
0000003oool0oooo07T0oooo0`3o000a0?ooo`030000003oool0oooo00D0oooo000a0?ooo`030?oo
g`2LB00007Bo00@0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`090?ooo`030000
003oool0oooo0300oooo0P3o001j0?ooo`030000003oool0oooo07T0oooo0P3o000b0?ooo`030000
003oool0oooo00D0oooo000b0?ooo`030=nLB000B9`0gooo00<0oooo00<0oooO09a80018W=l00P3o
ool0103ooml0W4P00018W03Oool80?ooo`030000003oool0oooo0300oooo0`3o001i0?ooo`030000
003oool0oooo07P0oooo0`3o000b0?ooo`030000003oool0oooo00D0oooo000b0?ooo`030?oOW018
04P0W=oo00<0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`080?ooo`030000003o
ool0oooo0340oooo0P3o001i0?ooo`030000003oool0oooo07P0oooo0P3o000c0?ooo`030000003o
ool0oooo00D0oooo000b0?ooo`030?oo_`1d0000M;oo00@0oooo00<0_g@00018W03Oool00P3oool0
0`3ogi`0B00004RLg`080?ooo`<00000<@3oool30?l007P0oooo00<000000?ooo`3oool0N03oool2
0?l00340oooo0`0000070?ooo`00<`3oool00`2oM00007Bo0?ooo`030?ooo`030=nLB00004P0W=oo
0080oooo00<0oooO09a80000M;l0203oool00`000000oooo0?ooo`0b0?ooo`80o`00N03oool00`00
0000oooo0?ooo`1g0?ooo`80o`00=03oool00`000000oooo0?ooo`050?ooo`00<`3oool00`3OW4P0
04RL0=ooo`030?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01`3oool00`000000
oooo0?ooo`0b0?ooo`<0o`00M`3oool00`000000oooo0?ooo`1g0?ooo`80o`00=03oool00`000000
oooo0?ooo`050?ooo`00<`3oool00`3ogi`0B01809cOo`030?ooo`040?oog`2LB00004RL0=ooo`80
oooo00<0gia80018W03Oool01`3oool00`000000oooo0?ooo`0c0?ooo`80o`00M`3oool00`000000
oooo0?ooo`1f0?ooo`80o`00=@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`3ookl0M000
07Boo`040?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01`3oool00`000000oooo
0?ooo`0c0?ooo`<0o`00MP3oool00`000000oooo0?ooo`1f0?ooo`80o`00=@3oool00`000000oooo
0?ooo`050?ooo`00=03oool00`2oM00007Bo0?ooo`040?ooo`060=nLB00007@0_ooo0?oog`2LB000
B9cO203oool00`000000oooo0?ooo`0c0?ooo`<0o`00MP3oool00`000000oooo0?ooo`1e0?ooo`<0
o`00=@3oool00`000000oooo0?ooo`050?ooo`00<P3oool01@3ookl0M0000000000007@0_ooo00D0
oooo00@0gia800000000000007Bo2@3oool00`000000oooo0?ooo`0d0?ooo`<0o`00M@3oool00`00
0000oooo0?ooo`1e0?ooo`80o`00=P3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000
oooo0?ooo`0d0?ooo`<0o`00M@3oool00`000000oooo0?ooo`1d0?ooo`<0o`00=P3oool00`000000
oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0e0?ooo`<0o`00M03oool00`000000oooo
0?ooo`1d0?ooo`80o`00=`3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?oo
o`0e0?ooo`<0o`00M03oool00`000000oooo0?ooo`1c0?ooo`<0o`00=`3oool00`000000oooo0?oo
o`050?ooo`00B@3oool00`000000oooo0?ooo`0f0?ooo`<0o`00L`3oool00`000000oooo0?ooo`1c
0?ooo`80o`00>03oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0f0?oo
o`<0o`00L`3oool00`000000oooo0?ooo`1b0?ooo`<0o`00>03oool00`000000oooo0?ooo`050?oo
o`00B@3oool00`000000oooo0?ooo`0g0?ooo`<0o`00LP3oool00`000000oooo0?ooo`1b0?ooo`80
o`00>@3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0g0?ooo`<0o`00
LP3oool00`000000oooo0?ooo`1a0?ooo`<0o`00>@3oool00`000000oooo0?ooo`050?ooo`00B@3o
ool00`000000oooo0?ooo`0h0?ooo`<0o`00L@3oool00`000000oooo0?ooo`1a0?ooo`80o`00>P3o
ool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`0h0?ooo`<0o`00L@3oool0
0`000000oooo0?ooo`1`0?ooo`<0o`00>P3oool00`000000oooo0?ooo`050?ooo`00B@3oool20000
03X0oooo0`3o001`0?ooo`030000003oool0oooo0700oooo0P3o000j0?ooo`8000001`3oool004T0
oooo00<000000?ooo`3oool0>@3oool30?l00700oooo00<000000?ooo`3oool0K`3oool30?l003/0
oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0>P3oool30?l006l0oooo
00<000000?ooo`3oool0K`3oool20?l003`0oooo00<000000?ooo`3oool01@3oool004T0oooo00<0
00000?ooo`3oool0>`3oool20?l006l0oooo00<000000?ooo`3oool0KP3oool20?l003d0oooo00<0
00000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0>`3oool30?l006h0oooo00<00000
0?ooo`3oool0KP3oool20?l003d0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?oo
o`3oool0?03oool20?l006h0oooo00<000000?ooo`3oool0K@3oool20?l003h0oooo00<000000?oo
o`3oool01@3oool004T0oooo00<000000?ooo`3oool0?03oool30?l006d0oooo00<000000?ooo`3o
ool0K@3oool20?l003h0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0
?@3oool30?l006`0oooo00<000000?ooo`3oool0K03oool20?l003l0oooo00<000000?ooo`3oool0
1@3oool004T0oooo00<000000?ooo`3oool0?@3oool30?l006`0oooo00<000000?ooo`3oool0J`3o
ool30?l003l0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0?P3oool3
0?l006/0oooo00<000000?ooo`3oool0J`3oool20?l00400oooo00<000000?ooo`3oool01@3oool0
04T0oooo00<000000?ooo`3oool0?P3oool40?l006X0oooo00<000000?ooo`3oool0JP3oool30?l0
0400oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0?`3oool30?l006X0
oooo00<000000?ooo`3oool0JP3oool20?l00440oooo00<000000?ooo`3oool01@3oool004T0oooo
00<000000?ooo`3oool0@03oool30?l006T0oooo00<000000?ooo`3oool0J@3oool30?l00440oooo
00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0@03oool40?l006P0oooo00<0
00000?ooo`3oool0J03oool30?l00480oooo00<000000?ooo`3oool01@3oool004T0oooo00<00000
0?ooo`3oool0@@3oool30?l006P0oooo00<000000?ooo`3oool0J03oool30?l00480oooo00<00000
0?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0@P3oool30?l006L0oooo00<000000?oo
o`3oool0I`3oool30?l004<0oooo00<000000?ooo`3oool01@3oool004T0oooo0P0000130?ooo`<0
o`00I`3oool00`000000oooo0?ooo`1V0?ooo`<0o`00@`3oool2000000L0oooo00190?ooo`030000
003oool0oooo04<0oooo0`3o001V0?ooo`030000003oool0oooo06D0oooo0`3o00150?ooo`030000
003oool0oooo00D0oooo00190?ooo`030000003oool0oooo04@0oooo0`3o001U0?ooo`030000003o
ool0oooo06D0oooo0`3o00150?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0
oooo04@0oooo0`3o001U0?ooo`030000003oool0oooo06@0oooo0`3o00160?ooo`030000003oool0
oooo00D0oooo00190?ooo`030000003oool0oooo04D0oooo0`3o001T0?ooo`030000003oool0oooo
06<0oooo0`3o00170?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo04H0
oooo0`3o001S0?ooo`030000003oool0oooo0680oooo0`3o00180?ooo`030000003oool0oooo00D0
oooo00190?ooo`030000003oool0oooo04L0oooo0P3o001S0?ooo`030000003oool0oooo0680oooo
0P3o00190?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo04P0oooo0P3o
001R0?ooo`030000003oool0oooo0640oooo0`3o00190?ooo`030000003oool0oooo00D0oooo0019
0?ooo`030000003oool0oooo04P0oooo0`3o001Q0?ooo`030000003oool0oooo0600oooo0`3o001:
0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo04T0oooo0`3o001P0?oo
o`030000003oool0oooo05l0oooo0`3o001;0?ooo`030000003oool0oooo00D0oooo00190?ooo`03
0000003oool0oooo04X0oooo0P3o001P0?ooo`030000003oool0oooo05l0oooo0P3o001<0?ooo`03
0000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo04/0oooo0P3o001O0?ooo`030000
003oool0oooo05h0oooo0`3o001<0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003o
ool0oooo04`0oooo0P3o001N0?ooo`030000003oool0oooo05d0oooo0`3o001=0?ooo`030000003o
ool0oooo00D0oooo00190?ooo`030000003oool0oooo04`0oooo0`3o001M0?ooo`030000003oool0
oooo05`0oooo0`3o001>0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo
04d0oooo0`3o001L0?ooo`030000003oool0oooo05/0oooo0`3o001?0?ooo`030000003oool0oooo
00D0oooo00190?ooo`030000003oool0oooo04h0oooo0`3o001K0?ooo`030000003oool0oooo05X0
oooo0`3o001@0?ooo`030000003oool0oooo00D0oooo00190?ooo`800000D03oool30?l005X0oooo
00<000000?ooo`3oool0FP3oool30?l004l0oooo0P0000070?ooo`00B@3oool00`000000oooo0?oo
o`1@0?ooo`<0o`00F@3oool00`000000oooo0?ooo`1I0?ooo`<0o`00D@3oool00`000000oooo0?oo
o`050?ooo`00B@3oool00`000000oooo0?ooo`1@0?ooo`@0o`00F03oool00`000000oooo0?ooo`1H
0?ooo`<0o`00DP3oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`1A0?oo
o`<0o`00F03oool00`000000oooo0?ooo`1G0?ooo`<0o`00D`3oool00`000000oooo0?ooo`050?oo
o`00B@3oool00`000000oooo0?ooo`1B0?ooo`<0o`00E`3oool00`000000oooo0?ooo`1F0?ooo`<0
o`00E03oool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`1C0?ooo`<0o`00
EP3oool00`000000oooo0?ooo`1E0?ooo`<0o`00E@3oool00`000000oooo0?ooo`050?ooo`00B@3o
ool00`000000oooo0?ooo`1D0?ooo`<0o`00E@3oool00`000000oooo0?ooo`1C0?ooo`@0o`00EP3o
ool00`000000oooo0?ooo`050?ooo`00B@3oool00`000000oooo0?ooo`1E0?ooo`<0o`00E03oool0
0`000000oooo0?ooo`1B0?ooo`040?l0003oool0o`000?l005L0oooo00<000000?ooo`3oool01@3o
ool004T0oooo00<000000?ooo`3oool0EP3oool30?l005<0oooo00<000000?ooo`3oool0D@3oool4
0?l005P0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0E`3oool30?l0
0580oooo00<000000?ooo`3oool0D03oool40?l005T0oooo00<000000?ooo`3oool01@3oool004T0
oooo00<000000?ooo`3oool0F03oool30?l00540oooo00<000000?ooo`3oool0C`3oool40?l005X0
oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0F@3oool30?l00500oooo
00<000000?ooo`3oool0CP3oool30?l005`0oooo00<000000?ooo`3oool01@3oool004T0oooo00<0
00000?ooo`3oool0FP3oool30?l004l0oooo00<000000?ooo`3oool0C@3oool30?l005d0oooo00<0
00000?ooo`3oool01@3oool004T0oooo00<000000?ooo`3oool0F`3oool30?l004h0oooo00<00000
0?ooo`3oool0C03oool30?l005h0oooo00<000000?ooo`3oool01@3oool004T0oooo00<000000?oo
o`3oool0G@3oool30?l004`0oooo00<000000?ooo`3oool0BP3oool40?l005l0oooo00<000000?oo
o`3oool01@3oool004T0oooo00<000000?ooo`3oool0GP3oool30?l004/0oooo00<000000?ooo`3o
ool0B@3oool40?l00600oooo00<000000?ooo`3oool01@3oool004T0oooo0P00001P0?ooo`<0o`00
BP3oool00`000000oooo0?ooo`180?ooo`@0o`00H03oool2000000L0oooo00190?ooo`030000003o
ool0oooo0600oooo0`3o00190?ooo`030000003oool0oooo04L0oooo103o001R0?ooo`030000003o
ool0oooo00D0oooo00190?ooo`030000003oool0oooo0640oooo103o00170?ooo`030000003oool0
oooo04H0oooo103o001S0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo
06<0oooo0`3o00160?ooo`030000003oool0oooo04@0oooo103o001U0?ooo`030000003oool0oooo
00D0oooo00190?ooo`030000003oool0oooo06@0oooo0`3o00150?ooo`030000003oool0oooo04<0
oooo103o001V0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo06D0oooo
103o00130?ooo`030000003oool0oooo0480oooo103o001W0?ooo`030000003oool0oooo00D0oooo
00190?ooo`030000003oool0oooo06H0oooo103o00120?ooo`030000003oool0oooo0400oooo1@3o
001X0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo06P0oooo103o0010
0?ooo`030000003oool0oooo03l0oooo1@3o001Y0?ooo`030000003oool0oooo00D0oooo00190?oo
o`030000003oool0oooo06T0oooo1@3o000n0?ooo`030000003oool0oooo03h0oooo103o001[0?oo
o`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo06/0oooo103o000m0?ooo`03
0000003oool0oooo03`0oooo103o001]0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000
003oool0oooo06`0oooo1@3o000k0?ooo`030000003oool0oooo03/0oooo103o001^0?ooo`030000
003oool0oooo00D0oooo000_0?ooo`030=nLB0000000000000<0000000<0B9cO0?ooo`3oool00P3o
ool0102oM00000000000001d_ol;0?ooo`030000003oool0oooo06d0oooo1@3o000j0?ooo`030000
003oool0oooo03T0oooo1@3o001_0?ooo`030000003oool0oooo00D0oooo000`0?ooo`030?noM000
M;l0oooo0080oooo00X0_gAd0;ooo`3oool0oooo0=nLB000M;l0oooo0?oOW0180000B9cO2P3oool0
0`000000oooo0?ooo`1_0?ooo`D0o`00>03oool00`000000oooo0?ooo`0g0?ooo`D0o`00L@3oool0
0`000000oooo0?ooo`050?ooo`00<@3oool00`3o_g@007Bo0?ooo`040?ooo`030?oog`2LB000B9cO
0080oooo00<0okmd0000B02Lgol02@3oool00`000000oooo0?ooo`1a0?ooo`D0o`00=P3oool00`00
0000oooo0?ooo`0f0?ooo`@0o`00L`3oool00`000000oooo0?ooo`050?ooo`00<P3oool00`3o_g@0
07Bo0?ooo`030?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo203oool00`00
0000oooo0?ooo`1b0?ooo`H0o`00=03oool00`000000oooo0?ooo`0d0?ooo`D0o`00M03oool00`00
0000oooo0?ooo`050?ooo`00<`3oool00`3o_g@0B9cO0?ooo`020?ooo`030?oog`2LB00007Bo00<0
oooo00<0gia80000B02Lgol0203oool00`000000oooo0?ooo`1d0?ooo`H0o`00<P3oool00`000000
oooo0?ooo`0b0?ooo`D0o`00MP3oool00`000000oooo0?ooo`050?ooo`00=03oool00`3OW4P0B9cO
0?ooo`020?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0203oool3000007H0oooo
1P3o000`0?ooo`030000003oool0oooo0300oooo1@3o001f0?ooo`<000001`3oool003D0oooo00L0
_g@007Boo`3oool0oooo0=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l0203oool00`000000
oooo0?ooo`1h0?ooo`H0o`00;P3oool00`000000oooo0?ooo`0^0?ooo`D0o`00NP3oool00`000000
oooo0?ooo`050?ooo`00=@3oool01`3ogi`0B01d0;ooo`3oool0omnL04P00018W=l00`3oool00`2o
M00004RL0=ooo`070?ooo`030000003oool0oooo07X0oooo1P3o000/0?ooo`030000003oool0oooo
02/0oooo1P3o001l0?ooo`030000003oool0oooo00D0oooo000e0?ooo`080?oog`2LB000M;oo0?oo
o`3ooml0W4P00018W03Oool20?ooo`030=nLB000B9`0gooo00L0oooo00<000000?ooo`3oool0O03o
ool60?l002X0oooo00<000000?ooo`3oool0:@3oool60?l007h0oooo00<000000?ooo`3oool01@3o
ool003D0oooo00<0oono07@00018W=l00P3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000M;l0
oooo00L0oooo00<000000?ooo`3oool0O`3oool50?l002P0oooo00<000000?ooo`3oool09P3oool6
0?l00840oooo00<000000?ooo`3oool01@3oool00340oooo00L0okmd0018W03Oool0oooo0=nLB000
04P0W=oo00<0oooo00H0gia80000M02oool0oooO09a80018W=l80?ooo`030000003oool0oooo0840
oooo1P3o000U0?ooo`030000003oool0oooo02<0oooo1`3o00230?ooo`030000003oool0oooo00D0
oooo000b0?ooo`050?oOW018000000000000001d_ol01@3oool0103OW4P0000000000000M;l90?oo
o`030000003oool0oooo08<0oooo1P3o000S0?ooo`030000003oool0oooo0200oooo203o00250?oo
o`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo08H0oooo1`3o000O0?ooo`03
0000003oool0oooo01d0oooo203o00280?ooo`030000003oool0oooo00D0oooo00190?ooo`030000
003oool0oooo08P0oooo2P3o000J0?ooo`030000003oool0oooo01X0oooo203o002;0?ooo`030000
003oool0oooo00D0oooo00190?ooo`030000003oool0oooo08/0oooo2@3o000H0?ooo`030000003o
ool0oooo01H0oooo2P3o002=0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0
oooo08l0oooo203o000E0?ooo`030000003oool0oooo0140oooo2`3o002A0?ooo`030000003oool0
oooo00D0oooo00190?ooo`030000003oool0oooo09<0oooo3P3o000;0?ooo`030000003oool0oooo
00d0oooo2P3o002F0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo09L0
oooo:`3o002J0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0n0?oooah0o`00@03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool004T0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`P0o`00303oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00D0oooo00190?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool01@3oool004T0ooooo`00001Q000000L0oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003<0?ooo`090?oo
_`1d0000000004RLg`3oool0oono07@000000000B9cO01@0oooo00<0okmd0000000000000P000000
0`00B9`0gooo0?ooo`0A0?ooo`050;md00000000000000000018W=l0Z@3oool00<`0oooo00X0oono
07@0B02Lgol0_g@0001d_`3ookl0M01809cOo`2oM00007Bo4P3oool00`3o_g@0000004RLg`030?oo
o`030?oOW01804P0W=oo0180oooo00<0oooO09a80018W=l0ZP3oool00<l0oooo00<0oono07@0001d
_ol00P3oool00`3ookl0M00007Boo`0A0?ooo`030?noM00007@0_ooo00@0oooo00<0gia8001d_`3o
ool04P3oool00`3OW4P004RL0=ooo`2Y0?ooo`00d03oool00`3OW4P004RL0=ooo`020?ooo`030=nL
B000B9`0gooo0140oooo00P0_g@00000M02oool0oooo0?oog`2LB000000004RLga<0oooo00<0omnL
04P0M02oool0Z@3oool00;T0oooo00<0_g@00000000000001@0000000`00B9`0gooo0?ooo`030?oo
o`0<0?oOW018000000000018W03Oool0_g@000000000M;l0oooo0?noM00004P0W=oo0P3oool00`3o
_g@0001809cOo`030?ooo`080;md00000000001809cOo`3oool0gia80018W03Oool20?ooo`030;md
0000000007Bo0080oooo00H0oono07@00000000000000000M02oool40?ooo`030?noM00000000000
00L0000000T0M;oo0?ooo`3ogi`0B0000000000007@0_ono07@0001d_ol00P3oool02`3ogi`0B000
00000000B9`0gooo0;md0000000007Bo0?ooo`3ogi`0B0000080000000T0M;oo0=nLB000000004RL
0=ooo`3o_g@000000000B02Lgol00P3oool0102oM00000000000B02Lgol20?ooo`050?noM0000000
00000000B02Lgol00`3oool00`3OW4P004RL0=ooo`020?ooo`030;md0000000007Bo07T0oooo002j
0?ooo`040?oo_`1d000004RL0=ooo`<0oooo00<0_g@000000000M;l00`3oool0303ogi`0B01809cO
o`3ogi`0B7Bo0;md0000M;l0oknL09cOo`3ookl0M00004RLg`80oooo00<0oono07@00018W=l00`3o
ool0203OW4P004RL0=oog`2LM9`0gooo0?noM00007@0_ooo0P3oool0203OW4P004RL0=noM01d_ol0
oooo0?noM00007@0_ooo203oool0103ooml0W4P00018W03Oool30?ooo`0;0?oog`2LB00004RL0=oo
o`2oM00004RL0=ooo`3ookl0M01d07Ad0018W=l00P3oool0903ogi`0B01809cOo`3ogi`0B7Bo0;md
0000M;l0oknL09cOo`2oM00004RL0=ooo`3oool0_g@007AdM00007@0_mnL09boo`3o_g@0001809cO
g`2LM9`0gooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0B000001d
_`80oooo00<0okmd0000M02oool00P3oool0103OW4P004RL0=noM01d_omh0?ooo`00^`3oool00`3O
W4P0001809cOo`040?ooo`0=0?oo_`1d000004RL0=ooo`3oool0oooO09a80018W=l0oooo0?noM01d
M7@004RL0=ooo`020?ooo`030;md0000B9`0gooo0080oooo00<0_g@00018W03Oool00P3oool00`3o
_g@0001809cOo`020?ooo`030?oo_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol00`3oool00`2o
M000M;oo0?ooo`080?ooo`030?noM00004P0W=oo00D0oooo00@0giad09cOo`2oM00007Bo0P3oool0
403ookl0M0000018W03Oool0oooo0?oog`2LB000B9cO0?ooo`3o_g@0M7Ad0018W03Oool0oooo0;md
0000M;l30?ooo`070;md00000000M;oo0?ooo`3ookl0M00007Boo`030?ooo`030?noM00004P0W=oo
0080oooo00<0gia80018W03Oool00P3oool01`3ogi`0B00004RLg`3oool0oono07@00018W=l00P3o
ool00`3ogi`0B01809cOo`1i0?ooo`00^`3oool00`3ogi`0B00007Boo`050?ooo`030?oOW0180000
07Bo0080oooo00L0_g@00018W03Oool0oooo0;md000004P0W=oo0080oooo00<0gia80000M02oool0
0P3oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO0080oooo00P0oooO09a8000007@0
_ooo0?ooo`3ooml0W4P004RLg`80oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`04
0?ooo`030?oo_`1d0000B9cO00L0oooo00<0gia80018W03Oool00P3oool00`3o_g@0001d0;ooo`02
0?ooo`0;0;md0000B9`0gooo0?ooo`2oM000001809cOo`3oool0okmd0000M02oool00P3oool00`3o
okl0M00004RLg`020?ooo`030;md0000M;l0oooo0080oooo00<0oono07@00018W=l00P3oool00`3o
_g@0001d0;ooo`030?ooo`0;0=nLB00007@0_ooo0?oog`2LB000001d0;ooo`3oool0oooO09a80018
W=l0N@3oool00;/0oooo00<0oono07@00000M;l01P3oool02`2oM000001809cOo`3oool0okmd0000
M02oool0oooo0?oo_`1d0000M;oo0080oooo00<0omnL04P0001d_ol00P3oool00`3ogi`0B00007Bo
o`030?ooo`030;md0000B9`0gooo0080oooo00<0gia80018B018M;l00P3oool02`2oM00007Bo0?oo
o`3oool0_g@00018W03Oool0oooo0?oOW0180000B9cO00D0oooo00<0oooO09a80000M;l00P3oool0
0`3ookl0W9cO0?ooo`020?ooo`030?oOW0180000M;oo0080oooo00<0oono07@0001d_ol00P3oool0
2`3o_g@0001d0;ooo`3oool0oono07@0001d_ol0oooo0?oo_`1d0000M;oo00<0oooo00L0_g@00018
W03Oool0oooo0=nLB000B9`0gooo00<0oooo00L0_g@00018W03Oool0oooo0?oo_`1d0000M;oo00<0
oooo00L0omnL04P0B02Lgol0oooo0=nLB000B4P0B7Bo0080oooo00<0_g@0001d_`3oool0N03oool0
0;`0oooo00<0_g@00018W03Oool01@3oool01`3o_g@0000004RLg`3ogml0gono07@0001d_ol00P3o
ool01`2oM00007Bo0?ooo`3oool0oooO09a80018W=l00P3oool00`3ooml0W4P004RLg`030?ooo`03
0=nLB00004P0W=oo0080oooo00/0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;ooo`3oool0_g@0
001d_`030?ooo`030=nLB00007@0_ooo00D0oooo00H0gia80000M02oool0oooo0?oOW018M;l40?oo
o`0<0;md000007@0_ooo0?ooo`3ooml0W4P004RLg`3oool0omoO0=oo_`1d0000M;oo0P3oool01`2o
M00007Bo0?ooo`3oool0okmd0000M02oool00P3oool01`3OW4P0001d0;ooo`3oool0omnL04P0B02L
gol00`3oool00`3OW4P0001809cOo`020?ooo`030=nLB00007@0_ooo0080oooo00`0oono07@0001d
_ol0oooo0?noM00007@0_kmd04RLg`3oool0okmd0000M02ooomh0?ooo`00_03oool00`3o_g@00018
09cOo`050?ooo`070?oOW018000007Bo0?oOW018M;l0_g@0001d_`020?ooo`030?noM000B9`0gooo
0080oooo00<0_g@00018W03Oool00P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO
0080oooo00`0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOo`3oool0omnL04P00018W=l20?oo
o`030=nLB00007@0_ooo00D0oooo00<0okmd0000000000000P0000000`0007@0_ooo0?ooo`020?oo
o`0<0?oog`2LB00004RL0=ooo`3ookl0W4Q80018W03Oool0omnL04Qd_`2oM00007Bo0P3oool00`3o
_g@004RL0=ooo`020?ooo`0;0=nLB00007@0_ooo0?ooo`2oM000001809cOo`3oool0oooO09a80018
W=l00`3oool00`3ogi`0B00004RLg`030?ooo`0@0;md000007@0_ooo0?ooo`3o_g@0001d0;ooo`3o
ool0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOogP0oooo002l0?ooo`030?oOW0180000M;oo
00D0oooo00L0omnL04P00000M;l0oooo0?noM000000007Bo0080oooo00D0omnL04P0B02Lgol0oono
07@000030000000307Bo_`1d000000000080000000l0M;oo0?noM000000000000018W03Oool0oono
07@000000000B9cO0?ooo`3o_g@000000000B02Lgol00P3oool00`3ookl0M0000000000400000003
04RLg`3oool0oooo0080oooo00<0oono07@0001d_ol00P3oool00`2oM4P0W=oo0?ooo`040?ooo`0:
0=nLB0000000001d0;noM00007@0_ooo0?ooo`3o_g@00000001d_`80oooo00<0omnL04P0B02Lgol0
0`3oool0203ogi`0B00000000018W9`0M00004RLg`3ookl0M0000`0000001P1d_ol0okmd00000000
000004RL0=ooo`<0oooo00l0okmd000000000000000007Boo`3oool0oono07@000000000B9cO0?oo
o`3o_g@000000000B02Lgol0N03oool00;`0oooo00<0oooO09a80000M;l01@3oool00`3o_g@00000
04RLg`0;0?ooo`030?noM00004P0W=oo0080oooo00<0okmd0000B02Lgol07P3oool01P2oM00007Bo
0?ooo`3oool0omnL07BLgal0oooo00<0okmd0000M02oool0T03oool00;d0oooo00<0_g@00018W03O
ool00`3oool0103ooml0W4P00000M02oool;0?ooo`030?oog`2LB00007Bo0080oooo00<0oooO09a8
0000M;l07P3oool00`3OW4P0001d0;ooo`040?ooo`030=nLW02oool0oooo01`0oooo00<0giad09cO
o`3oool0S`3oool00;d0oooo00<0gia80000B02Lgol00P3oool0103ookl0M0000000001d_ol=0?oo
o`030?noM00007@0_ooo0080oooo00<0okmd0000M02oool00P3oool0103ookl0M0000018W03OoolG
0?ooo`030?noM00004P0W=oo00<0oooo00<0oono07@0B02Lgol08P3oool0103ookl0M0000018W03O
oon90?ooo`00_03oool00`2oM000000000000004000000030018W03Oool0oooo00h0oooo00X0gia8
0018W03Ooml0W4P004RLg`3OW4P004RL0=oog`2LB000B9cO6@3oool00`2oM0000000000000060000
000307Boo`3oool0oooo0:d0oooo003E0?ooo`090=nLB0000000001809cOo`3oool0gia800000000
04P0W=oo0=80oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-31.1573, -28.4395, 0.187707, \
0.187707}}]
}, Closed]],

Cell["\<\
For low-frequency, large-amplitude driving forces the attractor has a rather \
complicated shape in which the system jumps from one side to the other for no \
apparent reason (other than symmetry, perhaps) after executing some rather \
intricate loops. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(duffingPlot[1, 1, 0.05, 10, 0.1, 0, 0, 0, 100, MaxSteps \[Rule] 6000, 
        PlotRange \[Rule] All, PlotPoints \[Rule] 100];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.424999 0.17363 0.491571 0.0942658 [
[.07774 -0.0125 -9.34375 -15.6875 ]
[.07774 -0.0125 9.34375 0 ]
[.25137 -0.0125 -9.34375 -15.6875 ]
[.25137 -0.0125 9.34375 0 ]
[.425 -0.0125 -5 -15.6875 ]
[.425 -0.0125 5 0 ]
[.59863 -0.0125 -5 -15.6875 ]
[.59863 -0.0125 5 0 ]
[.77226 -0.0125 -5 -15.6875 ]
[.77226 -0.0125 5 0 ]
[.94589 -0.0125 -5 -15.6875 ]
[.94589 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.9688 -31.375 ]
[.5 -0.0125 21.9688 -15.6875 ]
[-0.0125 .11451 -18.6875 -7.84375 ]
[-0.0125 .11451 0 7.84375 ]
[-0.0125 .30304 -18.6875 -7.84375 ]
[-0.0125 .30304 0 7.84375 ]
[-0.0125 .49157 -10 -7.84375 ]
[-0.0125 .49157 0 7.84375 ]
[-0.0125 .6801 -10 -7.84375 ]
[-0.0125 .6801 0 7.84375 ]
[-0.0125 .86863 -10 -7.84375 ]
[-0.0125 .86863 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -34.375 -20.4688 ]
[-0.01875 .5 -18.6875 20.4688 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -43.9375 0 ]
[.5 1.0125 43.9375 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07774 0 m
.07774 .00625 L
s
gsave
.07774 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.25137 0 m
.25137 .00625 L
s
gsave
.25137 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.425 0 m
.425 .00625 L
s
gsave
.425 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.59863 0 m
.59863 .00625 L
s
gsave
.59863 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.77226 0 m
.77226 .00625 L
s
gsave
.77226 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.94589 0 m
.94589 .00625 L
s
gsave
.94589 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.11246 0 m
.11246 .00375 L
s
.14719 0 m
.14719 .00375 L
s
.18192 0 m
.18192 .00375 L
s
.21664 0 m
.21664 .00375 L
s
.28609 0 m
.28609 .00375 L
s
.32082 0 m
.32082 .00375 L
s
.35555 0 m
.35555 .00375 L
s
.39027 0 m
.39027 .00375 L
s
.45973 0 m
.45973 .00375 L
s
.49445 0 m
.49445 .00375 L
s
.52918 0 m
.52918 .00375 L
s
.5639 0 m
.5639 .00375 L
s
.63336 0 m
.63336 .00375 L
s
.66808 0 m
.66808 .00375 L
s
.70281 0 m
.70281 .00375 L
s
.73753 0 m
.73753 .00375 L
s
.80699 0 m
.80699 .00375 L
s
.84171 0 m
.84171 .00375 L
s
.87644 0 m
.87644 .00375 L
s
.91116 0 m
.91116 .00375 L
s
.04301 0 m
.04301 .00375 L
s
.00829 0 m
.00829 .00375 L
s
.98062 0 m
.98062 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.9688 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
102.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11451 m
.00625 .11451 L
s
gsave
-0.0125 .11451 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .30304 m
.00625 .30304 L
s
gsave
-0.0125 .30304 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .49157 m
.00625 .49157 L
s
gsave
-0.0125 .49157 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .6801 m
.00625 .6801 L
s
gsave
-0.0125 .6801 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .86863 m
.00625 .86863 L
s
gsave
-0.0125 .86863 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .16164 m
.00375 .16164 L
s
0 .20877 m
.00375 .20877 L
s
0 .25591 m
.00375 .25591 L
s
0 .35017 m
.00375 .35017 L
s
0 .39731 m
.00375 .39731 L
s
0 .44444 m
.00375 .44444 L
s
0 .5387 m
.00375 .5387 L
s
0 .58584 m
.00375 .58584 L
s
0 .63297 m
.00375 .63297 L
s
0 .72724 m
.00375 .72724 L
s
0 .77437 m
.00375 .77437 L
s
0 .8215 m
.00375 .8215 L
s
0 .06738 m
.00375 .06738 L
s
0 .02024 m
.00375 .02024 L
s
0 .91577 m
.00375 .91577 L
s
0 .9629 m
.00375 .9629 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -108 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
81.4688 11.8438 translate
90 rotate
-81.4688 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(velocity) show
99.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.07774 .99375 m
.07774 1 L
s
.25137 .99375 m
.25137 1 L
s
.425 .99375 m
.425 1 L
s
.59863 .99375 m
.59863 1 L
s
.77226 .99375 m
.77226 1 L
s
.94589 .99375 m
.94589 1 L
s
.125 Mabswid
.11246 .99625 m
.11246 1 L
s
.14719 .99625 m
.14719 1 L
s
.18192 .99625 m
.18192 1 L
s
.21664 .99625 m
.21664 1 L
s
.28609 .99625 m
.28609 1 L
s
.32082 .99625 m
.32082 1 L
s
.35555 .99625 m
.35555 1 L
s
.39027 .99625 m
.39027 1 L
s
.45973 .99625 m
.45973 1 L
s
.49445 .99625 m
.49445 1 L
s
.52918 .99625 m
.52918 1 L
s
.5639 .99625 m
.5639 1 L
s
.63336 .99625 m
.63336 1 L
s
.66808 .99625 m
.66808 1 L
s
.70281 .99625 m
.70281 1 L
s
.73753 .99625 m
.73753 1 L
s
.80699 .99625 m
.80699 1 L
s
.84171 .99625 m
.84171 1 L
s
.87644 .99625 m
.87644 1 L
s
.91116 .99625 m
.91116 1 L
s
.04301 .99625 m
.04301 1 L
s
.00829 .99625 m
.00829 1 L
s
.98062 .99625 m
.98062 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .11451 m
1 .11451 L
s
.99375 .30304 m
1 .30304 L
s
.99375 .49157 m
1 .49157 L
s
.99375 .6801 m
1 .6801 L
s
.99375 .86863 m
1 .86863 L
s
.125 Mabswid
.99625 .16164 m
1 .16164 L
s
.99625 .20877 m
1 .20877 L
s
.99625 .25591 m
1 .25591 L
s
.99625 .35017 m
1 .35017 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .44444 m
1 .44444 L
s
.99625 .5387 m
1 .5387 L
s
.99625 .58584 m
1 .58584 L
s
.99625 .63297 m
1 .63297 L
s
.99625 .72724 m
1 .72724 L
s
.99625 .77437 m
1 .77437 L
s
.99625 .8215 m
1 .8215 L
s
.99625 .06738 m
1 .06738 L
s
.99625 .02024 m
1 .02024 L
s
.99625 .91577 m
1 .91577 L
s
.99625 .9629 m
1 .9629 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .49157 m
1 .49157 L
s
.425 0 m
.425 1 L
s
gsave
.5 1.0125 -104.938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Duffing) show
102.938 15.813 moveto
(Equation) show
146.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.425 .49157 m
.42578 .51973 L
.42783 .54526 L
.43179 .57459 L
.43708 .60216 L
.45022 .65072 L
.46978 .70259 L
.49759 .75837 L
.53403 .81528 L
.57437 .86533 L
.61612 .90668 L
.66385 .94259 L
.69171 .95797 L
.71894 .96875 L
.74443 .97468 L
.76828 .97619 L
.7944 .97275 L
.82187 .96243 L
.83722 .95315 L
.85104 .9423 L
.86551 .92805 L
.8808 .90924 L
.90484 .86991 L
.92734 .81804 L
.94464 .76229 L
.95937 .69453 L
.96922 .62459 L
.97454 .55742 L
.97619 .4825 L
.97518 .43993 L
.97296 .4005 L
.96933 .36003 L
.96485 .32409 L
.95872 .28622 L
.95096 .24849 L
.93522 .1912 L
.91781 .14513 L
.89609 .10323 L
.88294 .08382 L
.87048 .06869 L
.8563 .05477 L
.84084 .04302 L
.82735 .03533 L
.81229 .02923 L
.79592 .02527 L
.77824 .02381 L
.76155 .02486 L
.74635 .0277 L
.73126 .03218 L
.71742 .03766 L
Mistroke
.68678 .05418 L
.66084 .07266 L
.63456 .0955 L
.58818 .14636 L
.54567 .20738 L
.5133 .26807 L
.49047 .32513 L
.47558 .37728 L
.4696 .40693 L
.46563 .43458 L
.46312 .46375 L
.46233 .49025 L
.46251 .50487 L
.4632 .52072 L
.46576 .5494 L
.46987 .57712 L
.47503 .60233 L
.4822 .62977 L
.49144 .65832 L
.51091 .70556 L
.5376 .75546 L
.57303 .80704 L
.61744 .85656 L
.64123 .8776 L
.6648 .89499 L
.6885 .90902 L
.71129 .91916 L
.73591 .92617 L
.74909 .92811 L
.76326 .92869 L
.7781 .92748 L
.79211 .92449 L
.81797 .91367 L
.84133 .89689 L
.86196 .87523 L
.8831 .84443 L
.9034 .80361 L
.92082 .75531 L
.92874 .72705 L
.93609 .69534 L
.94671 .6326 L
.95295 .57128 L
.95494 .53538 L
.95578 .49664 L
.95394 .42712 L
.95071 .3856 L
.94623 .34759 L
.94108 .31481 L
.93433 .28097 L
.92069 .22967 L
Mistroke
.90579 .18852 L
.88611 .14852 L
.86539 .11823 L
.84496 .09697 L
.82513 .08272 L
.80271 .07279 L
.7784 .06822 L
.76443 .06814 L
.7516 .06956 L
.7376 .07263 L
.72294 .07744 L
.69876 .08877 L
.67312 .10513 L
.62898 .14359 L
.59237 .18611 L
.55666 .23943 L
.52931 .29258 L
.51032 .34144 L
.50195 .36929 L
.49574 .39513 L
.49073 .42275 L
.48754 .44865 L
.48639 .46345 L
.48575 .47699 L
.48551 .49183 L
.48579 .5074 L
.48651 .52155 L
.48777 .5366 L
.49131 .56355 L
.49428 .57993 L
.49763 .59528 L
.50533 .62374 L
.52288 .67164 L
.54407 .71485 L
.57242 .75976 L
.60837 .80372 L
.62833 .82342 L
.6514 .84254 L
.67273 .85693 L
.68477 .86367 L
.69628 .86916 L
.70775 .87369 L
.72027 .87752 L
.74233 .88131 L
.76486 .88092 L
.78541 .87633 L
.80456 .86788 L
.82444 .85407 L
.84241 .83628 L
.85788 .81594 L
Mistroke
.87472 .78699 L
.89105 .7495 L
.90429 .70871 L
.91439 .66692 L
.92246 .62043 L
.92772 .57447 L
.93082 .52238 L
.93097 .46571 L
.92759 .40741 L
.92114 .35432 L
.91279 .30969 L
.90113 .26519 L
.88567 .22252 L
.86928 .1893 L
.8493 .15982 L
.8386 .14776 L
.82644 .13662 L
.80523 .12272 L
.79303 .11745 L
.78178 .11414 L
.75973 .11152 L
.73881 .11324 L
.71893 .11829 L
.69818 .12681 L
.6809 .13631 L
.66241 .14883 L
.62394 .18269 L
.59178 .21987 L
.56175 .26398 L
.53602 .3129 L
.51903 .35576 L
.51151 .3801 L
.50577 .40317 L
.50314 .41607 L
.50075 .43006 L
.49775 .45446 L
.49671 .46827 L
.49613 .48286 L
.49605 .49528 L
.49641 .50891 L
.49821 .53308 L
.49987 .54657 L
.50179 .55883 L
.50661 .58242 L
.51252 .60455 L
.52905 .64996 L
.54956 .69089 L
.57187 .72558 L
.59984 .76003 L
.63453 .79262 L
Mistroke
.65339 .80634 L
.67495 .81877 L
.69397 .82684 L
.71477 .83243 L
.73461 .83438 L
.7527 .833 L
.77087 .82821 L
.78976 .81908 L
.80539 .80777 L
.82189 .79138 L
.83846 .76914 L
.85472 .73981 L
.86827 .70721 L
.8789 .6735 L
.88723 .63855 L
.89334 .6039 L
.89812 .56404 L
.90091 .52013 L
.90121 .47336 L
.89901 .42971 L
.89503 .39163 L
.88866 .35231 L
.87942 .3125 L
.86906 .27952 L
.85506 .24599 L
.84004 .21904 L
.82492 .19852 L
.81004 .18323 L
.79294 .17045 L
.77412 .16126 L
.75495 .15628 L
.74407 .15518 L
.73407 .15518 L
.7157 .1575 L
.69656 .16287 L
.68655 .1668 L
.67599 .17176 L
.65742 .18243 L
.61795 .21329 L
.58469 .24862 L
.55398 .29098 L
.53052 .33318 L
.51383 .37309 L
.50292 .40938 L
.49849 .43004 L
.49549 .44936 L
.49353 .46961 L
.49282 .48805 L
.49287 .49818 L
.49328 .50919 L
Mistroke
.49496 .5291 L
.49625 .53891 L
.49793 .54922 L
.50176 .56751 L
.50705 .58692 L
.51422 .60785 L
.53056 .64418 L
.5497 .67633 L
.57137 .70508 L
.59466 .72977 L
.62444 .75414 L
.63937 .76368 L
.65383 .77129 L
.66981 .77781 L
.67842 .78049 L
.68779 .78272 L
.69714 .78422 L
.70703 .78496 L
.7247 .78401 L
.74099 .78029 L
.75589 .77416 L
.77178 .7643 L
.78801 .74996 L
.8045 .72985 L
.82067 .70272 L
.83398 .67223 L
.8443 .64032 L
.85181 .60882 L
.85527 .58996 L
.85795 .57181 L
.86167 .53406 L
.86275 .51245 L
.86308 .49258 L
.86197 .45385 L
.85879 .41818 L
.85424 .38734 L
.84759 .35582 L
.83839 .324 L
.82671 .29398 L
.81531 .27154 L
.80151 .25051 L
.7875 .23422 L
.77402 .22229 L
.75781 .21186 L
.74199 .20512 L
.72711 .20142 L
.71324 .2 L
.69799 .20045 L
.68189 .20302 L
.66471 .20793 L
Mistroke
.64928 .21412 L
.61604 .23286 L
.58759 .2547 L
.563 .27818 L
.51795 .33607 L
.49886 .37047 L
.49181 .38615 L
.48541 .40275 L
.48061 .41761 L
.47635 .4339 L
.47339 .44865 L
.4714 .46236 L
.47057 .47063 L
.47003 .47843 L
.46968 .49297 L
.46986 .50105 L
.47027 .50848 L
.47097 .51659 L
.47202 .52516 L
.47423 .53821 L
.47741 .5521 L
.48523 .57671 L
.49791 .60489 L
.51264 .6295 L
.54465 .6684 L
.5661 .68765 L
.58793 .70314 L
.60047 .71037 L
.61268 .71628 L
.62403 .7208 L
.63628 .72459 L
.64981 .72742 L
.6624 .72873 L
.67598 .72859 L
.68369 .72774 L
.69087 .72641 L
.70451 .72234 L
.71201 .71915 L
.7187 .71567 L
.73142 .70724 L
.74289 .69725 L
.75554 .68299 L
.7663 .66745 L
.77698 .64778 L
.78679 .62425 L
.79354 .60323 L
.79943 .5791 L
.80364 .55508 L
.8063 .5324 L
.80792 .50521 L
Mistroke
.80812 .48972 L
.80784 .47541 L
.80617 .44937 L
.80279 .42242 L
.79847 .39954 L
.79346 .37958 L
.78687 .35899 L
.77878 .33902 L
.76276 .30976 L
.75254 .29579 L
.74239 .28454 L
.72975 .27339 L
.71727 .26495 L
.7057 .25902 L
.69288 .25427 L
.67865 .25094 L
.67142 .24994 L
.66344 .24934 L
.64931 .24946 L
.63614 .2508 L
.62205 .25345 L
.61426 .2554 L
.60727 .25744 L
.58146 .26715 L
.55291 .28157 L
.52793 .29722 L
.48804 .32842 L
.45303 .364 L
.42853 .397 L
.41895 .41351 L
.41055 .43143 L
.40508 .44658 L
.40274 .45482 L
.40096 .46254 L
.39968 .46966 L
.39869 .47731 L
.39815 .48418 L
.39795 .49046 L
.39812 .49835 L
.3987 .50573 L
.39957 .51226 L
.40089 .51927 L
.40274 .52671 L
.4052 .53448 L
.41082 .54799 L
.41804 .56103 L
.42618 .57267 L
.44461 .59262 L
.45712 .60307 L
.47161 .61309 L
Mistroke
.5004 .62803 L
.51771 .63441 L
.52627 .63689 L
.5345 .63886 L
.5392 .63981 L
.54434 .64068 L
.55341 .64183 L
.55856 .64224 L
.56405 .64248 L
.56874 .64253 L
.57392 .64239 L
.5825 .64172 L
.59044 .64058 L
.59906 .6387 L
.60813 .63595 L
.61745 .63219 L
.626 .62778 L
.64116 .61721 L
.6541 .60452 L
.66469 .59045 L
.67457 .57256 L
.67878 .56265 L
.68275 .55115 L
.68622 .53818 L
.68872 .52538 L
.69027 .51357 L
.69121 .50047 L
.69138 .49294 L
.69132 .48611 L
.69098 .47822 L
.6904 .47081 L
.68875 .45771 L
.68747 .45043 L
.68608 .44382 L
.6796 .42146 L
.67486 .40948 L
.66979 .39885 L
.65774 .37919 L
.64247 .36106 L
.62583 .34657 L
.60646 .33424 L
.58881 .32599 L
.56843 .31902 L
.5567 .31596 L
.54579 .31363 L
.5339 .31155 L
.52077 .30973 L
.50995 .30854 L
.49834 .30753 L
.48602 .30671 L
Mistroke
.47453 .30613 L
.46879 .3059 L
.46271 .3057 L
.4518 .30544 L
.44573 .30534 L
.44006 .30527 L
.43383 .30523 L
.42714 .30522 L
.42139 .30524 L
.41513 .30529 L
.40375 .30546 L
.39269 .30573 L
.38246 .30608 L
.37258 .30653 L
.36333 .30706 L
.35236 .30784 L
.34234 .30873 L
.32211 .31113 L
.3116 .31277 L
.30065 .31484 L
.27969 .32005 L
.26055 .32663 L
.24409 .33417 L
.22721 .34429 L
.21024 .35782 L
.19421 .37508 L
.18242 .39215 L
.17661 .40266 L
.17172 .41318 L
.16779 .42319 L
.16412 .43449 L
.16135 .44516 L
.15933 .455 L
.15755 .46684 L
.15642 .47954 L
.15607 .49127 L
.15635 .5022 L
.15714 .51234 L
.15854 .5228 L
.16016 .53147 L
.16239 .54068 L
.1653 .55017 L
.16898 .55979 L
.17694 .57552 L
.18196 .58318 L
.18798 .59079 L
.19429 .59735 L
.2015 .60344 L
.20856 .60822 L
.21527 .61184 L
Mistroke
.22185 .61464 L
.22893 .61691 L
.23303 .6179 L
.23677 .61862 L
.24112 .61923 L
.24524 .6196 L
.25259 .61979 L
.25673 .61963 L
.26054 .61933 L
.26468 .61884 L
.26853 .61823 L
.2772 .61631 L
.28551 .61379 L
.29421 .61043 L
.30819 .60343 L
.32236 .59411 L
.33374 .58465 L
.34459 .57351 L
.35391 .56154 L
.36105 .55001 L
.3669 .53786 L
.37114 .52599 L
.37286 .51964 L
.3743 .51274 L
.37529 .50614 L
.37587 .50007 L
.37616 .49286 L
.37614 .48876 L
.37599 .48495 L
.37542 .47791 L
.37437 .4704 L
.37295 .46319 L
.37096 .4554 L
.36614 .44127 L
.35836 .42448 L
.34929 .40924 L
.32903 .38334 L
.31615 .37034 L
.30084 .35728 L
.28475 .34583 L
.26907 .33664 L
.25242 .32888 L
.23607 .32325 L
.22685 .32097 L
.21685 .31925 L
.20733 .3184 L
.19863 .31832 L
.18845 .31915 L
.18273 .32008 L
.17747 .32125 L
Mistroke
.16793 .32423 L
.15801 .32859 L
.14887 .33393 L
.13939 .34102 L
.12351 .35742 L
.11523 .36898 L
.10737 .3827 L
.10089 .39688 L
.09582 .41076 L
.09211 .42333 L
.08882 .43752 L
.08618 .453 L
.08451 .46792 L
.08367 .48203 L
.08356 .49696 L
.0841 .50957 L
.08534 .52319 L
.08766 .53868 L
.09056 .55221 L
.09479 .5669 L
.09962 .57978 L
.10992 .5997 L
.11661 .60915 L
.12328 .61669 L
.13106 .62358 L
.13967 .62925 L
.14728 .63281 L
.1558 .63538 L
.16066 .63624 L
.16511 .63667 L
.17026 .63674 L
.17512 .63641 L
.18372 .63491 L
.18852 .63358 L
.19292 .63204 L
.20064 .62861 L
.20769 .62466 L
.22286 .61326 L
.23617 .59942 L
.24857 .58209 L
.25731 .56579 L
.26482 .54672 L
.26776 .53669 L
.27024 .52576 L
.27195 .51527 L
.27296 .50563 L
.27345 .4959 L
.27344 .48688 L
.27292 .47695 L
.27178 .46645 L
Mistroke
.2703 .45736 L
.26851 .4489 L
.26297 .42994 L
.25904 .41965 L
.2542 .40895 L
.24386 .39056 L
.23051 .37239 L
.21336 .35492 L
.19693 .34278 L
.18713 .33738 L
.17785 .33346 L
.16953 .33091 L
.16029 .32916 L
.15057 .3286 L
.14152 .3293 L
.13277 .33119 L
.12342 .33466 L
.11483 .33932 L
.10715 .34485 L
.09353 .35855 L
.08721 .36703 L
.08077 .37754 L
.06939 .40285 L
.06432 .41889 L
.06059 .43447 L
.05795 .44952 L
.05599 .46639 L
.05505 .48255 L
.05497 .49755 L
.05586 .51507 L
.05671 .52372 L
.05793 .53303 L
.06085 .54889 L
.0644 .56284 L
.06953 .57802 L
.07503 .59047 L
.08224 .60302 L
.08979 .61298 L
.09684 .62005 L
.10471 .62593 L
.11167 .62962 L
.11953 .63229 L
.12807 .63357 L
.1329 .63359 L
.13731 .63319 L
.14539 .63143 L
.15375 .62823 L
.16112 .62421 L
.1676 .61972 L
.18121 .607 L
Mistroke
.1924 .59243 L
.20148 .57669 L
.20592 .56706 L
.21003 .5564 L
.21307 .54686 L
.21579 .53633 L
.21806 .52477 L
.21957 .51376 L
.2202 .50697 L
.22059 .5005 L
.22075 .4883 L
.22021 .47623 L
.21959 .46945 L
.21883 .46325 L
.21693 .45192 L
.21425 .44014 L
.20797 .42034 L
.19884 .39998 L
.18665 .38034 L
.17899 .37075 L
.17119 .36263 L
.1635 .35601 L
.15475 .34997 L
.1465 .34561 L
.13869 .34263 L
.13127 .34083 L
.12321 .34 L
.11559 .34034 L
.10865 .34165 L
.10104 .34425 L
.09293 .34851 L
.08475 .35455 L
.07751 .36163 L
.07024 .37074 L
.0639 .38072 L
.05366 .40273 L
.04896 .41673 L
.04537 .4305 L
.04229 .44639 L
.04006 .46381 L
.03894 .48036 L
.03873 .48976 L
.03881 .49844 L
.03962 .51417 L
.04141 .53044 L
.04379 .54435 L
.04666 .55675 L
.05049 .56946 L
.05535 .58198 L
.0609 .59311 L
Mistroke
.06765 .60358 L
.07534 .61247 L
.08297 .61883 L
.09044 .6231 L
.0974 .62556 L
.10556 .62676 L
.11328 .62634 L
.11993 .62482 L
.12712 .62195 L
.13443 .61772 L
.14103 .61269 L
.15206 .60139 L
.16256 .5864 L
.16773 .57694 L
.17272 .56588 L
.17653 .55559 L
.17996 .54415 L
.18267 .53244 L
.18454 .52157 L
.18584 .51046 L
.18651 .49989 L
.18665 .48826 L
.18609 .4758 L
.1849 .46413 L
.18325 .45362 L
.18066 .44153 L
.17704 .42878 L
.16843 .40701 L
.16323 .39706 L
.15686 .38691 L
.15005 .37799 L
.14213 .36957 L
.13429 .363 L
.12677 .35817 L
.11935 .35471 L
.11138 .35237 L
.10378 .35147 L
.09687 .35181 L
.08895 .35361 L
.08161 .35674 L
.07499 .36089 L
.0691 .36579 L
.06293 .37234 L
.05678 .38057 L
.05107 .39016 L
.04555 .40179 L
.04135 .41287 L
.03743 .42589 L
.0354 .43421 L
.03376 .44215 L
Mistroke
.03127 .45837 L
.02987 .47353 L
.02929 .48984 L
.02967 .50617 L
.0303 .5153 L
.03117 .52366 L
.03236 .53231 L
.03369 .53997 L
.03748 .5563 L
.04155 .56907 L
.04675 .58153 L
.05232 .59179 L
.05797 .59986 L
.06496 .60743 L
.07189 .61279 L
.07598 .61509 L
.07979 .61672 L
.08423 .61802 L
.08849 .61871 L
.0926 .61886 L
.09697 .6185 L
.10478 .61651 L
.10948 .61448 L
.11383 .61205 L
.12168 .60618 L
.12781 .60019 L
.13413 .59251 L
.13981 .58402 L
.14532 .57396 L
.14987 .56377 L
.15349 .55391 L
.15642 .54413 L
.15898 .53338 L
.16014 .52733 L
.16121 .52056 L
.16254 .50845 L
.16298 .50158 L
.1632 .49414 L
.16317 .48712 L
.16294 .48069 L
.162 .46901 L
.16025 .45642 L
.15907 .45018 L
.1576 .44361 L
.15442 .4321 L
.14585 .4102 L
.14057 .40026 L
.13409 .39037 L
.12806 .38292 L
.12115 .37606 L
Mistroke
.11427 .37076 L
.10775 .36702 L
.10372 .3653 L
.09938 .36393 L
.09149 .36274 L
.08664 .36283 L
.08209 .36352 L
.07804 .36463 L
.0737 .36638 L
.06989 .36841 L
.0658 .37115 L
.05786 .37831 L
.051 .38685 L
.04514 .39638 L
.03986 .40736 L
.0349 .42074 L
.03104 .43456 L
.02824 .44815 L
.02638 .4609 L
.02508 .47532 L
.02458 .49056 L
.02491 .5048 L
.02616 .52022 L
.02714 .52776 L
.02846 .53579 L
.03144 .54937 L
.03489 .56109 L
.03977 .57364 L
.04485 .58361 L
.05138 .59328 L
.05808 .60049 L
.06412 .60513 L
.07084 .60855 L
.07732 .61029 L
.08329 .61066 L
.09027 .60965 L
.09417 .60841 L
.09774 .60686 L
.10415 .60304 L
.11068 .59768 L
.11654 .59146 L
.12244 .58362 L
.13178 .56689 L
.13628 .55596 L
.14023 .54366 L
.14293 .53266 L
.14409 .52673 L
.14515 .52021 L
.14648 .50851 L
.1471 .49732 L
Mistroke
.14712 .4864 L
.14661 .47637 L
.14551 .46564 L
.14364 .45407 L
.14097 .44237 L
.13783 .43186 L
.13061 .4142 L
.12248 .40017 L
.11746 .39348 L
.11159 .38715 L
.10574 .38218 L
.1001 .37852 L
.09318 .37546 L
.08963 .37446 L
.08572 .37382 L
.07876 .37385 L
.07231 .37526 L
.06845 .37678 L
.06484 .37869 L
.05829 .38348 L
.0516 .3904 L
.04489 .39991 L
.04002 .40898 L
.03526 .42033 L
.03109 .43348 L
.02798 .44683 L
.02582 .45993 L
.02451 .47234 L
.02381 .48619 L
.02392 .5008 L
.02479 .514 L
.0262 .52566 L
.02853 .53854 L
.03138 .54996 L
.03456 .55976 L
.03791 .56804 L
.04197 .57616 L
.04675 .58374 L
.05195 .59013 L
.0571 .59492 L
.0635 .5991 L
.06953 .60147 L
.07589 .6025 L
.0795 .60244 L
.08283 .60198 L
.08889 .60018 L
.09519 .59694 L
.10124 .59246 L
.10752 .58622 L
.1136 .57838 L
Mistroke
.11877 .56997 L
.12659 .55272 L
.1301 .54207 L
.13269 .5319 L
.1339 .52596 L
.13498 .51955 L
.13635 .50786 L
.13679 .5013 L
.13701 .49513 L
.13701 .48835 L
.13675 .48109 L
.13631 .47492 L
.1356 .46825 L
.13472 .46203 L
.13371 .45635 L
.13133 .44591 L
.12814 .4353 L
.12421 .42516 L
.12005 .41656 L
.11504 .4082 L
.10896 .40025 L
.10325 .39449 L
.09764 .3902 L
.09148 .38688 L
.08795 .38559 L
.0847 .3848 L
.07855 .3843 L
.07285 .38504 L
.06669 .38721 L
.06364 .38885 L
.06033 .39109 L
.05499 .3958 L
.04956 .40223 L
.04481 .40952 L
.04083 .41719 L
.03669 .42732 L
.03335 .43785 L
.03088 .44798 L
.0288 .45954 L
.02727 .47263 L
.0268 .47936 L
.02652 .48681 L
.02663 .5 L
.02743 .51218 L
.02889 .52405 L
.03088 .53485 L
.03314 .54403 L
.03607 .55339 L
.03977 .56262 L
.04424 .57132 L
Mistroke
.0489 .57833 L
.05344 .58364 L
.0592 .58864 L
.06221 .59059 L
.06556 .59227 L
.07162 .59412 L
.07733 .59454 L
.0808 .59421 L
.08406 .59349 L
.09009 .59112 L
.09338 .58924 L
.09637 .58717 L
.10286 .58135 L
.10773 .57566 L
.11199 .56955 L
.11662 .56145 L
.12038 .55331 L
.12359 .54483 L
.12654 .53505 L
.12889 .52479 L
.1299 .51905 L
.13067 .51365 L
.13168 .50309 L
.13195 .49773 L
.13205 .49183 L
.13176 .48145 L
.13094 .47187 L
.13019 .46617 L
.12931 .46084 L
.1272 .45114 L
.12431 .4412 L
.12046 .43112 L
.11247 .41626 L
.10731 .4094 L
.10228 .4042 L
.09732 .40029 L
.09174 .39718 L
.08634 .39536 L
.08132 .39471 L
.07641 .39502 L
.07121 .39643 L
.0664 .39877 L
.06215 .40177 L
.05736 .40632 L
.05248 .41248 L
.04823 .41941 L
.04468 .4267 L
.04164 .43445 L
.03882 .4435 L
.03631 .45414 L
Mistroke
.03453 .46466 L
.03325 .47686 L
.03273 .4887 L
.03286 .49934 L
.03364 .51083 L
.03431 .51677 L
.03522 .52292 L
.03732 .53353 L
.04024 .5442 L
.04417 .55482 L
.04812 .56295 L
.05285 .57044 L
.0577 .57627 L
.06239 .58049 L
.06747 .58374 L
.07231 .58571 L
.0777 .58674 L
.08345 .58656 L
.08839 .58539 L
.09296 .58346 L
.09783 .58048 L
.10288 .5763 L
.10795 .57085 L
.11235 .56493 L
.1171 .55696 L
.12091 .54896 L
.12416 .5405 L
.12708 .53078 L
.12841 .52525 L
.12945 .52006 L
.13028 .51506 L
.13099 .50964 L
.13175 .50063 L
.132 .49218 L
.13194 .48704 L
.13173 .48219 L
.13093 .4732 L
.12955 .464 L
.12779 .45576 L
.12533 .44716 L
.12216 .43859 L
.11478 .42453 L
.11045 .41868 L
.10534 .41334 L
.1007 .40974 L
.09554 .40696 L
.09054 .40541 L
.08594 .40494 L
.08313 .40511 L
.08016 .40566 L
Mistroke
.07491 .40765 L
.07206 .4093 L
.06944 .4112 L
.06375 .41679 L
.05917 .42302 L
.05535 .42978 L
.05165 .43824 L
.04839 .44819 L
.04609 .45769 L
.0445 .46678 L
.04384 .47197 L
.04329 .47768 L
.04279 .48818 L
.04287 .49809 L
.04356 .50847 L
.04461 .51713 L
.04626 .52631 L
.04883 .53653 L
.05173 .54515 L
.05568 .55409 L
.05994 .56144 L
.06426 .56717 L
.06854 .57152 L
.07348 .5752 L
.07605 .57662 L
.07893 .57784 L
.08387 .57908 L
.08852 .57933 L
.0936 .57861 L
.09642 .57777 L
.09895 .57675 L
.10397 .57395 L
.10918 .56986 L
.11384 .56509 L
.11785 .55997 L
.12419 .54942 L
.12985 .53606 L
.13211 .5288 L
.1341 .52071 L
.13552 .51286 L
.13643 .50558 L
.13701 .49701 L
.13711 .49222 L
.13707 .4879 L
.1366 .47957 L
.13571 .47189 L
.13502 .46762 L
.13414 .46321 L
.1322 .45559 L
.12962 .44788 L
Mistroke
.12623 .44012 L
.1229 .43413 L
.11943 .4291 L
.1151 .42416 L
.11089 .42054 L
.10674 .41794 L
.1028 .41628 L
.0984 .41532 L
.09369 .41531 L
.08963 .41616 L
.08528 .41802 L
.08088 .42098 L
.07698 .42466 L
.07352 .4289 L
.0706 .43338 L
.06767 .4389 L
.06491 .4454 L
.06233 .45319 L
.06039 .46092 L
.0588 .46971 L
.05814 .47487 L
.05768 .47977 L
.05726 .48877 L
.05733 .49705 L
.05796 .50653 L
.05908 .51534 L
.06058 .52328 L
.06231 .53015 L
.0647 .53762 L
.06733 .54411 L
.07281 .55423 L
.07629 .55901 L
.07969 .56277 L
.08361 .56618 L
.08741 .56866 L
.0917 .57062 L
.09639 .57182 L
.10136 .57211 L
.10605 .57148 L
.11021 .5702 L
.11462 .56809 L
.11894 .56523 L
.12273 .56202 L
.1266 .55798 L
.13055 .55294 L
.13673 .5426 L
.14148 .53144 L
.1438 .5241 L
.14549 .51722 L
.14626 .51334 L
Mistroke
.14694 .5091 L
.14746 .50508 L
.14781 .50136 L
.14816 .4947 L
.14813 .48743 L
.14795 .48381 L
.14764 .47998 L
.14676 .4732 L
.14612 .46958 L
.14531 .46582 L
.14354 .45934 L
.14121 .45281 L
.13816 .44622 L
.13518 .44117 L
.13163 .43641 L
.12801 .43264 L
.12451 .42986 L
.12095 .4278 L
.11755 .42649 L
.11376 .42575 L
.10969 .42579 L
.10764 .42614 L
.10544 .42677 L
.10151 .42859 L
.09782 .43118 L
.09458 .43427 L
.09133 .43828 L
.08848 .44274 L
.08388 .45265 L
.08179 .45896 L
.08019 .46522 L
.07884 .47246 L
.07827 .47664 L
.07788 .4805 L
.07747 .48764 L
.07744 .49428 L
.07779 .50157 L
.0786 .50917 L
.07966 .51564 L
.08094 .52149 L
.08266 .52764 L
.08484 .53387 L
.08759 .54012 L
.0909 .54611 L
.09495 .55182 L
.09902 .55623 L
.10303 .55956 L
.10695 .56199 L
.10926 .56307 L
.11139 .56387 L
Mistroke
.11376 .56452 L
.11628 .56498 L
.12034 .56519 L
.12467 .56473 L
.12872 .56369 L
.13232 .56223 L
.13646 .55995 L
.14077 .55681 L
.14799 .54957 L
.15397 .54113 L
.15684 .53596 L
.15926 .53077 L
.16123 .52574 L
.16307 .52009 L
.16444 .51488 L
.16547 .5099 L
.16637 .504 L
.16671 .50086 L
.16696 .49748 L
.1671 .49414 L
.16713 .49065 L
.16706 .48769 L
.16688 .48449 L
.1663 .47885 L
.16583 .47578 L
.16531 .47303 L
.16408 .46788 L
.16265 .46326 L
.15871 .45421 L
.15634 .45025 L
.15346 .4464 L
.15083 .4436 L
.14783 .44109 L
.14488 .43924 L
.1421 .438 L
.1404 .43747 L
.13857 .43709 L
.13525 .43689 L
.13323 .43708 L
.13133 .43748 L
.12964 .43802 L
.12783 .43879 L
.12454 .44077 L
.12123 .44359 L
.11857 .44659 L
.11587 .45045 L
.11363 .45447 L
.11152 .45922 L
.10956 .46493 L
.10809 .47062 L
Mistroke
.10705 .47619 L
.10637 .48161 L
.10597 .48772 L
.1059 .49121 L
.10593 .49442 L
.10623 .5 L
.10677 .50517 L
.10765 .51077 L
.10892 .5166 L
.11061 .5225 L
.11252 .52781 L
.11688 .53686 L
.11956 .54112 L
.12278 .54533 L
.12616 .54891 L
.13001 .55215 L
.13378 .55459 L
.13734 .55632 L
.141 .55758 L
.14453 .55833 L
.14863 .55866 L
.15093 .55861 L
.15301 .55841 L
.15703 .55764 L
.16076 .55647 L
.16503 .55457 L
.16882 .55237 L
.17679 .54594 L
.18271 .53924 L
.18737 .53233 L
.19181 .52365 L
.19349 .51949 L
.19501 .51499 L
.19609 .5111 L
.19706 .5068 L
.19773 .50288 L
.19819 .49923 L
.19849 .49498 L
.19857 .49115 L
.19843 .48703 L
.19804 .48282 L
.19738 .47864 L
.19656 .47501 L
.19537 .47104 L
.19403 .46754 L
.19115 .46197 L
.18928 .45924 L
.18742 .45702 L
.18541 .45506 L
.18313 .4533 L
Mistroke
.18179 .45246 L
.18053 .45181 L
.17933 .45129 L
.17803 .45085 L
.17667 .45051 L
.17541 .4503 L
.17404 .4502 L
.17253 .45023 L
.17123 .45038 L
.16984 .45066 L
.16736 .45151 L
.16504 .45273 L
.163 .45417 L
.16075 .45623 L
.15876 .45854 L
.15558 .46348 L
.15404 .46671 L
.15278 .46993 L
.15162 .47368 L
.15074 .4774 L
.15002 .48167 L
.14972 .48415 L
.14953 .48645 L
.14936 .49116 L
.14939 .49387 L
.14951 .49639 L
.14993 .50104 L
.15029 .50364 L
.15069 .50598 L
.15173 .51076 L
.15315 .51569 L
.15648 .52409 L
.15874 .52844 L
.16111 .53225 L
.16415 .53636 L
.16728 .53988 L
.17017 .5426 L
.17347 .54523 L
.17961 .54893 L
.18325 .55052 L
.18528 .55124 L
.18721 .55182 L
.19064 .5526 L
.19248 .55289 L
.19447 .55312 L
.19811 .55329 L
.20142 .5532 L
.20522 .55279 L
.20878 .55213 L
.21203 .5513 L
Mistroke
.21498 .55035 L
.22145 .54761 L
.22763 .54412 L
.23392 .53958 L
.23991 .53416 L
.24472 .5288 L
.24879 .5233 L
.25248 .51717 L
.25552 .51068 L
.2567 .50749 L
.25759 .50465 L
.25827 .50202 L
.25883 .49924 L
.25907 .49774 L
.25925 .49639 L
.25946 .49381 L
.25953 .49167 L
.25947 .48942 L
.25926 .48718 L
.25896 .48521 L
.25852 .48327 L
.25794 .48136 L
.25735 .47986 L
.2566 .47834 L
.25571 .47689 L
.25466 .47552 L
.25359 .47443 L
.25255 .47361 L
.25146 .47296 L
.25043 .47251 L
.24927 .47219 L
.24862 .47209 L
.24802 .47205 L
.24693 .4721 L
.24575 .47234 L
.24466 .47273 L
.24368 .47324 L
.24277 .47385 L
.24184 .47465 L
.24027 .47644 L
.23941 .47775 L
.23867 .47913 L
.23751 .48208 L
.23704 .48376 L
.23665 .48565 L
.2364 .48735 L
.23622 .48932 L
.23615 .49152 L
.23617 .49279 L
.23623 .49398 L
Mistroke
.23642 .49623 L
.23676 .49865 L
.23724 .50113 L
.23793 .50385 L
.23961 .50889 L
.2418 .51382 L
.24431 .51834 L
.25168 .5282 L
.25624 .53284 L
.26187 .53761 L
.27252 .54467 L
.2855 .55095 L
.29895 .55566 L
.31203 .55905 L
.3275 .56202 L
.34461 .56446 L
.37664 .56786 L
.45458 .57605 L
.47471 .57828 L
.49649 .58033 L
.50807 .58114 L
.51126 .58131 L
.51468 .58147 L
.51764 .58159 L
.52086 .58168 L
.52401 .58175 L
.52693 .58179 L
.52971 .58179 L
.53267 .58177 L
.53778 .58166 L
.54068 .58155 L
.5434 .58142 L
.54837 .58109 L
.55378 .58059 L
.55938 .57991 L
.56454 .57911 L
.57367 .57728 L
.58317 .57468 L
.59392 .5707 L
.60351 .56599 L
.61157 .56094 L
.61962 .55461 L
.62625 .54808 L
.63252 .54035 L
.63718 .53315 L
.64137 .52489 L
.64347 .51971 L
.64509 .51485 L
.64633 .51026 L
.64738 .50519 L
Mistroke
.64805 .50069 L
.64843 .49651 L
.64859 .49217 L
.64857 .48977 L
.64848 .4876 L
.64814 .48352 L
.64751 .47933 L
.64669 .47555 L
.64576 .47229 L
.64446 .46867 L
.64279 .46506 L
.6392 .45936 L
.63716 .45697 L
.63477 .4547 L
.63212 .45275 L
.62952 .45132 L
.62703 .45033 L
.6247 .44971 L
.6234 .44949 L
.62198 .44935 L
.61939 .44934 L
.61811 .44946 L
.61676 .44966 L
.61437 .45025 L
.61185 .45118 L
.60916 .45255 L
.60691 .45402 L
.60461 .45586 L
.60078 .45988 L
.59733 .46491 L
.59587 .46767 L
.59466 .47038 L
.5928 .47581 L
.59205 .47884 L
.59143 .48217 L
.59097 .48589 L
.59075 .48939 L
.59074 .49332 L
.59082 .49533 L
.59098 .49754 L
.59143 .50133 L
.59214 .50542 L
.59305 .50931 L
.59406 .51284 L
.59732 .52147 L
.60208 .5306 L
.60771 .53878 L
.6138 .54577 L
.62024 .55166 L
.62692 .55654 L
Mistroke
.63082 .55888 L
.63521 .56111 L
.63937 .56285 L
.64321 .56415 L
.64724 .5652 L
.65108 .5659 L
.65516 .56632 L
.65958 .56639 L
.66346 .56612 L
.66752 .56548 L
.67096 .56465 L
.67467 .56342 L
.67929 .56138 L
.68351 .55897 L
.69097 .55319 L
.69482 .54927 L
.69814 .54523 L
.7017 .54006 L
.70469 .53479 L
.70885 .52535 L
.71063 .52005 L
.71221 .51417 L
.71285 .51118 L
.71346 .5079 L
.71427 .50188 L
.71471 .49604 L
.71481 .49066 L
.71458 .48492 L
.71434 .48209 L
.71397 .47905 L
.71308 .47384 L
.71198 .46922 L
.71036 .46412 L
.7086 .45984 L
.70628 .45539 L
.70381 .4517 L
.70149 .44894 L
.69887 .44648 L
.69652 .44477 L
.69384 .4433 L
.69089 .44224 L
.68921 .44186 L
.68766 .44166 L
.6848 .44165 L
.68179 .44213 L
.67911 .44298 L
.67673 .44409 L
.67405 .44575 L
.67162 .44768 L
.66759 .45192 L
Mistroke
.66374 .45758 L
.66196 .46094 L
.66023 .46491 L
.65879 .46904 L
.65751 .47371 L
.65659 .47826 L
.65599 .48257 L
.65562 .487 L
.65549 .49128 L
.65562 .4962 L
.65582 .49899 L
.65608 .50156 L
.65677 .50629 L
.65778 .51125 L
.66022 .51969 L
.66199 .52433 L
.66387 .52852 L
.66889 .53731 L
.67434 .54438 L
.67767 .54783 L
.68151 .55114 L
.68531 .5538 L
.689 .55586 L
.69224 .55728 L
.69579 .55843 L
.6998 .55922 L
.70349 .5595 L
.70714 .55932 L
.7111 .55862 L
.71518 .55731 L
.71888 .55556 L
.72228 .55343 L
.72537 .55101 L
.73079 .54545 L
.73595 .53807 L
.73852 .53332 L
.74061 .52867 L
.74245 .52376 L
.74415 .51817 L
.74559 .51205 L
.7466 .5061 L
.74723 .50049 L
.74757 .49451 L
.74759 .48945 L
.74733 .48395 L
.74705 .4809 L
.74665 .47775 L
.74569 .47231 L
.74432 .4668 L
.74243 .46124 L
Mistroke
.7405 .45689 L
.73817 .45276 L
.73575 .44941 L
.73338 .44685 L
.73056 .44452 L
.72909 .44359 L
.72744 .44274 L
.72446 .44172 L
.72163 .44132 L
.71992 .44133 L
.71829 .44152 L
.71527 .44233 L
.71361 .44304 L
.7121 .44385 L
.70877 .44622 L
.70601 .4489 L
.70357 .45188 L
.69955 .45855 L
.69763 .46283 L
.69612 .46707 L
.69474 .47201 L
.69411 .47483 L
.69363 .47749 L
.69296 .48242 L
.69272 .48507 L
.69256 .48791 L
.69249 .49273 L
.69272 .4981 L
.69319 .50285 L
.69397 .50794 L
.69498 .51267 L
.69612 .51692 L
.69944 .52605 L
.70176 .53085 L
.70418 .53503 L
.70976 .54242 L
.71324 .54585 L
.71658 .54846 L
.71968 .55037 L
.72307 .55192 L
.72602 .55284 L
.7293 .55341 L
.73285 .5535 L
.73665 .55296 L
.74018 .55185 L
.74335 .55033 L
.74642 .54832 L
.74916 .54603 L
.75226 .5428 L
.75489 .53942 L
Mistroke
.75925 .53209 L
.76132 .52755 L
.76303 .52299 L
.76461 .51782 L
.76598 .51205 L
.76696 .50643 L
.76758 .50123 L
.76797 .49509 L
.76803 .49163 L
.76798 .48846 L
.76764 .48273 L
.76693 .47685 L
.76593 .47151 L
.76453 .46611 L
.76291 .46142 L
.7612 .45751 L
.75906 .45365 L
.75649 .45006 L
.75359 .44705 L
.75212 .44587 L
.75073 .44495 L
.74816 .4437 L
.74532 .44294 L
.74279 .44279 L
.74012 .44313 L
.73776 .44388 L
.73559 .44494 L
.73328 .4465 L
.7309 .4486 L
.7285 .4513 L
.72609 .45474 L
.72415 .45817 L
.72231 .46219 L
.72086 .46608 L
.71951 .47065 L
.71852 .47502 L
.7178 .47928 L
.71726 .48411 L
.71697 .48939 L
.71699 .49442 L
.71725 .49901 L
.71785 .50437 L
.71833 .50736 L
.71886 .51008 L
.72005 .51498 L
.72161 .51997 L
.72337 .5245 L
.72555 .52906 L
.73015 .5363 L
.73332 .53999 L
Mistroke
.73655 .5429 L
.73959 .54499 L
.74123 .54588 L
.74303 .54667 L
.7463 .54763 L
.74942 .54798 L
.75246 .54782 L
.75524 .5472 L
.7582 .54604 L
.76137 .54417 L
.76454 .54158 L
.76733 .53859 L
.76979 .53529 L
.77194 .53177 L
.77545 .52425 L
.77708 .51959 L
.77836 .51504 L
.7795 .50984 L
.7804 .50414 L
.78093 .4988 L
.78118 .49292 L
.78107 .48684 L
.78065 .48131 L
.77996 .47628 L
.77912 .47191 L
.77788 .46715 L
.77649 .46298 L
.77472 .45884 L
.77261 .45498 L
.77063 .45214 L
.7683 .44953 L
.76565 .44736 L
.76411 .44644 L
.76268 .44578 L
.75985 .44501 L
.75715 .44489 L
.75463 .44533 L
.75238 .44616 L
.74985 .44761 L
.74756 .44945 L
.74376 .45377 L
.74182 .45673 L
.74018 .45976 L
.73725 .46702 L
.73593 .47157 L
.73496 .47602 L
.7342 .48091 L
.73375 .48548 L
.73354 .49084 L
.73365 .49594 L
Mistroke
.73401 .50067 L
.73468 .5057 L
.73558 .51033 L
.73662 .51443 L
.73809 .51901 L
.73999 .5237 L
.74417 .5312 L
.74679 .53463 L
.74935 .53726 L
.75082 .53852 L
.75246 .5397 L
.75391 .54057 L
.75553 .54137 L
.75848 .54235 L
.76012 .54263 L
.76165 .54274 L
.76439 .54254 L
.76731 .54176 L
.77017 .54039 L
.77273 .53861 L
.77542 .5361 L
.77809 .53283 L
.78207 .52606 L
.78399 .52157 L
.78554 .51701 L
.78671 .51265 L
.78771 .50786 L
.78835 .50365 L
.78883 .49896 L
.78909 .49385 L
.78907 .4884 L
.78876 .48335 L
.78824 .47887 L
.7874 .47397 L
.78636 .46963 L
.78497 .4652 L
.78321 .46088 L
.7811 .45691 L
.77888 .45373 L
.77673 .45138 L
.77426 .4494 L
.77182 .44809 L
.76956 .44739 L
.76693 .44717 L
.76445 .44751 L
.76218 .44831 L
.76014 .44943 L
.75797 .45108 L
.75578 .45326 L
.75354 .45614 L
Mistroke
.75166 .45918 L
.74984 .46285 L
.74812 .46724 L
.74679 .47162 L
.7458 .47589 L
.74508 .48012 L
.74457 .48474 L
.74431 .48979 L
.7443 .49264 L
.74437 .49525 L
.74472 .50003 L
.74537 .50496 L
.74584 .50753 L
.74644 .51022 L
.74773 .51487 L
.74962 .52002 L
.75166 .52427 L
.75554 .53014 L
.758 .5328 L
.76044 .5348 L
.76312 .53636 L
.76563 .53728 L
.76704 .53757 L
.76858 .53771 L
.77137 .53748 L
.77373 .53679 L
.77627 .53552 L
.77884 .53361 L
.78113 .5313 L
.78485 .52602 L
.78668 .52245 L
.78819 .51884 L
.78961 .51456 L
.79086 .50967 L
.79176 .50482 L
.79233 .50028 L
.7927 .49485 L
.79276 .49177 L
.79272 .48894 L
.79241 .4838 L
.79215 .48125 L
.79177 .47851 L
.79074 .47323 L
.78952 .46871 L
.78778 .46396 L
.78584 .45998 L
.78385 .45682 L
.78184 .45437 L
.7795 .45224 L
.77814 .4513 L
Mistroke
.77688 .45063 L
.77454 .4498 L
.77234 .4495 L
.76991 .4497 L
.76734 .4505 L
.76607 .45114 L
.76472 .45199 L
.76234 .45396 L
.76016 .45639 L
.75829 .45903 L
.75532 .46466 L
.75389 .46829 L
.75275 .47194 L
.75176 .47597 L
.75106 .4798 L
.75052 .48412 L
.75021 .48876 L
.75019 .49356 L
.75042 .49791 L
.75065 .50028 L
.75098 .50282 L
.7518 .50731 L
.75281 .51133 L
.75412 .51534 L
.75704 .52172 L
.75896 .52478 L
.76121 .52757 L
.76348 .52969 L
.76566 .53118 L
.76702 .53185 L
.7683 .53233 L
.76972 .53267 L
.77124 .53283 L
.77269 .53279 L
.77405 .53257 L
.77656 .5317 L
.77872 .53043 L
.78095 .52857 L
.78294 .52635 L
.78463 .52396 L
.78645 .52074 L
.7882 .51678 L
.78961 .51266 L
.79068 .50857 L
.79153 .50414 L
.79209 .49983 L
.79244 .49501 L
.79251 .49227 L
.79249 .48977 L
.79223 .48481 L
Mistroke
.79195 .48205 L
.7916 .47954 L
.79076 .47508 L
.78959 .47061 L
.78825 .46675 L
.78682 .46353 L
.78507 .46038 L
.78303 .45754 L
.78112 .45551 L
.77925 .454 L
.77712 .45279 L
.77478 .45201 L
.77268 .45178 L
.77039 .45201 L
.76825 .45267 L
.76631 .45367 L
.76462 .45486 L
.76282 .45649 L
.75947 .46072 L
.75779 .46358 L
.75639 .46652 L
.75492 .47031 L
.75381 .47399 L
.75287 .47806 L
.75222 .48204 L
.75177 .48633 L
.75164 .48877 L
.75158 .49103 L
.75165 .49475 L
.75189 .49819 L
.75234 .50188 L
.75304 .50572 L
.754 .50953 L
.75512 .51293 L
.7577 .51857 L
.75945 .52132 L
.76117 .52344 L
.76218 .52446 L
.76329 .52542 L
.76539 .5268 L
.76743 .52765 L
.76961 .52804 L
.77149 .52798 L
.77353 .52747 L
.77475 .52694 L
.77589 .52629 L
.77795 .52468 L
.78004 .5224 L
.78213 .51931 L
.78375 .51614 L
Mistroke
.78525 .51235 L
.78632 .50881 L
.7868 .50683 L
.78726 .50464 L
.78789 .50061 L
.78827 .49675 L
.7884 .49436 L
.78845 .49208 L
.78836 .48783 L
.78799 .48338 L
.78742 .47938 L
.78654 .47517 L
.78534 .47099 L
.7842 .46792 L
.78281 .46489 L
.7799 .46026 L
.77792 .45802 L
.77593 .45634 L
.77407 .4552 L
.77198 .45438 L
.77079 .45411 L
.76949 .45397 L
.76826 .45399 L
.76714 .45413 L
.76503 .45473 L
.76285 .45581 L
.76174 .45655 L
.76058 .45747 L
.75859 .45944 L
.75638 .46228 L
.75457 .46529 L
.75187 .47146 L
.75068 .4753 L
.74981 .47903 L
.74923 .48238 L
.74881 .48613 L
.7486 .49008 L
.74862 .49376 L
.74885 .49746 L
.74908 .4995 L
.74934 .5013 L
.75 .5047 L
.7508 .50774 L
.75193 .51104 L
.75315 .5138 L
.75467 .51649 L
.75644 .51889 L
.75799 .52049 L
.75974 .52182 L
.76145 .52269 L
Mistroke
.76304 .52317 L
.76493 .52331 L
.766 .52319 L
.76698 .52296 L
.76875 .52222 L
.77057 .52099 L
.77211 .51954 L
.77344 .51792 L
.77478 .51589 L
.77611 .51334 L
.77799 .50837 L
.77881 .50536 L
.77942 .5024 L
.77995 .49869 L
.78025 .49507 L
.78034 .49176 L
.78025 .48816 L
.77993 .48425 L
.77968 .48231 L
.77934 .48021 L
.77857 .4766 L
.77767 .47338 L
.77651 .47013 L
.77507 .46697 L
.77367 .4645 L
.77202 .46216 L
.76992 .45985 L
.7689 .45896 L
.7678 .45815 L
.76679 .45753 L
.76566 .45696 L
.76363 .45628 L
.76148 .45599 L
.75952 .45611 L
.75844 .45632 L
.75728 .45667 L
.7552 .45763 L
.75332 .45886 L
.75142 .46053 L
.74973 .46238 L
.74828 .46432 L
.7457 .46879 L
.74454 .47141 L
.74348 .47432 L
.74274 .4768 L
.74208 .47952 L
.74151 .48257 L
.74113 .48544 L
.74087 .48882 L
.74081 .49072 L
Mistroke
.74081 .49245 L
.74095 .49559 L
.74128 .49882 L
.74174 .50159 L
.74231 .50406 L
.74306 .50661 L
.74402 .50913 L
.74508 .51133 L
.74639 .51346 L
.74789 .51531 L
.7494 .51669 L
.75087 .51763 L
.75226 .51819 L
.75381 .51847 L
.75545 .51839 L
.7571 .51789 L
.75801 .51743 L
.75881 .51691 L
.76033 .5156 L
.76168 .51402 L
.76312 .51178 L
.76431 .50937 L
.76543 .50638 L
.76595 .50462 L
.76638 .50287 L
.76695 .49985 L
.76731 .49695 L
.76753 .49374 L
.76757 .49189 L
.76755 .49016 L
.76739 .48698 L
.76709 .48413 L
.76656 .48088 L
.7659 .4779 L
.76498 .47474 L
.76381 .4716 L
.76125 .46661 L
.75959 .46425 L
.75792 .46236 L
.75597 .46064 L
.75484 .45986 L
.75377 .45924 L
.75189 .45844 L
.75088 .45814 L
.74979 .45793 L
.74869 .45782 L
.74754 .45782 L
.74548 .45809 L
.7436 .45867 L
.74188 .45947 L
Mistroke
.74005 .46062 L
.73818 .46216 L
.73627 .46415 L
.73436 .46666 L
.73284 .46913 L
.73142 .47197 L
.7303 .4747 L
.72927 .47783 L
.72852 .48077 L
.72798 .48357 L
.72759 .48643 L
.72745 .48805 L
.72737 .48954 L
.72733 .49223 L
.72745 .49502 L
.72773 .49767 L
.72813 .50004 L
.72861 .50205 L
.72922 .50409 L
.73002 .50614 L
.73103 .50814 L
.73222 .50991 L
.73342 .51126 L
.73461 .51223 L
.73574 .51287 L
.73638 .51312 L
.73708 .5133 L
.73836 .51341 L
.73961 .51321 L
.74074 .51279 L
.742 .51201 L
.74315 .51098 L
.74415 .50979 L
.74502 .5085 L
.74589 .5069 L
.74672 .50494 L
.7475 .50256 L
.74808 .50012 L
.74851 .49759 L
.74877 .49516 L
.7489 .49242 L
.7489 .49084 L
.74885 .48935 L
.74876 .48776 L
.74862 .48632 L
.74841 .48465 L
.74816 .48308 L
.74761 .48038 L
.74682 .47748 L
.7458 .47458 L
Mistroke
.74468 .47201 L
.74232 .46788 L
.7408 .46586 L
.7393 .46422 L
.73768 .46277 L
.73586 .46149 L
.73478 .46088 L
.73379 .46041 L
.73283 .46004 L
.7318 .45973 L
.73072 .45949 L
.72972 .45935 L
.72863 .45929 L
.72744 .45932 L
.72641 .45942 L
.72532 .45962 L
.72336 .4602 L
.72235 .46061 L
.72142 .46106 L
.71972 .46207 L
.71781 .4635 L
.71615 .46503 L
.71341 .46828 L
.71088 .47235 L
.70884 .47688 L
.70793 .47958 L
.70725 .48213 L
.70695 .48352 L
.70671 .48483 L
.70637 .48727 L
.70625 .48862 L
.70617 .48985 L
.70614 .49118 L
.70615 .49256 L
.70627 .49467 L
.70648 .49651 L
.70683 .49841 L
.7073 .50026 L
.70781 .50174 L
.70835 .50298 L
.709 .50419 L
.70978 .50531 L
.7107 .5063 L
.71162 .507 L
.71255 .50745 L
.71342 .50767 L
.71437 .50768 L
.71491 .50759 L
.71541 .50744 L
.71593 .5072 L
Mistroke
.7164 .50693 L
.71742 .5061 L
.71819 .50522 L
.71887 .50423 L
.71956 .50297 L
.72021 .50142 L
.72075 .49971 L
.72101 .4987 L
.72121 .49772 L
.7215 .49591 L
.7217 .4938 L
.72176 .49175 L
.72172 .48976 L
.72159 .48793 L
.72135 .48592 L
.72097 .48372 L
.72044 .48139 L
.71913 .47731 L
.71725 .47316 L
.71471 .46914 L
.7119 .46592 L
.70902 .46355 L
.70717 .4624 L
.70539 .46153 L
.70338 .46082 L
.70224 .46053 L
.70119 .46033 L
.69927 .46012 L
.69818 .4601 L
.69717 .46014 L
.69534 .46035 L
.69342 .46077 L
.69167 .46133 L
.68981 .46212 L
.68658 .46398 L
.68367 .46627 L
.68121 .46875 L
.67868 .47197 L
.67667 .47521 L
.67497 .47873 L
.67423 .4806 L
.67356 .48263 L
.67315 .48415 L
.67279 .48574 L
.6725 .48738 L
.67232 .48885 L
.67221 .49026 L
.67218 .49154 L
.6722 .49263 L
.67228 .49374 L
Mistroke
.67243 .49488 L
.67266 .49603 L
.67297 .4971 L
.67331 .49797 L
.67367 .49866 L
.67404 .4992 L
.67448 .49969 L
.67493 .50003 L
.67544 .50026 L
.67572 .50032 L
.67599 .50034 L
.67648 .50027 L
.67698 .50004 L
.67742 .49971 L
.67781 .4993 L
.67822 .49873 L
.67861 .49799 L
.67898 .49706 L
.67915 .49651 L
.67931 .49589 L
.67943 .49532 L
.67955 .49465 L
.67969 .49339 L
.67976 .49208 L
.67974 .49058 L
.67964 .48908 L
.67947 .48766 L
.67924 .48627 L
.67891 .48475 L
.67812 .48195 L
.67682 .47859 L
.6753 .47558 L
.67339 .47255 L
.67096 .46949 L
.66833 .46686 L
.66569 .46474 L
.6626 .46277 L
.66093 .46191 L
.65906 .4611 L
.6573 .46045 L
.65563 .45995 L
.65403 .45956 L
.65228 .45924 L
.6504 .45899 L
.64862 .45887 L
.64759 .45884 L
.6465 .45884 L
.64455 .45892 L
.64357 .459 L
.64252 .45912 L
Mistroke
.64065 .45941 L
.63845 .45986 L
.63647 .46038 L
.6326 .46169 L
.6292 .46319 L
.62222 .46728 L
.61703 .47134 L
.61258 .47564 L
.60706 .48214 L
.60507 .48453 L
.60428 .48531 L
.60392 .48558 L
.60361 .48578 L
.6033 .48591 L
.60302 .48599 L
.60272 .48601 L
.6024 .48597 L
.60207 .48587 L
.6019 .48578 L
.6017 .48567 L
.60102 .48513 L
.59949 .48347 L
.59767 .48121 L
.59079 .47343 L
.58033 .46457 L
.5674 .45664 L
.54976 .44885 L
.52942 .44225 L
.5038 .43568 L
.44193 .42124 L
.40908 .41326 L
.37055 .40437 L
.34876 .40013 L
.33684 .39823 L
.3302 .39734 L
.32388 .39662 L
.31807 .39607 L
.315 .39583 L
.31175 .39561 L
.30598 .39534 L
.30065 .39522 L
.29531 .39523 L
.29031 .39538 L
.28485 .3957 L
.279 .39625 L
.27593 .39663 L
.27304 .39705 L
.2677 .39798 L
.26153 .39935 L
.25596 .40087 L
Mistroke
.24617 .40433 L
.23608 .40912 L
.22651 .41514 L
.21694 .42306 L
.20816 .43273 L
.20126 .44289 L
.19593 .45343 L
.19379 .45883 L
.19211 .46391 L
.19086 .46849 L
.18973 .47356 L
.18889 .47867 L
.18829 .48406 L
.1881 .48704 L
.188 .48985 L
.18805 .49506 L
.18821 .49791 L
.18844 .50052 L
.18878 .50333 L
.18925 .50626 L
.19035 .51138 L
.19167 .51594 L
.19485 .52372 L
.19669 .52709 L
.19887 .5304 L
.20323 .53551 L
.20614 .53805 L
.20904 .54005 L
.21173 .5415 L
.21474 .54271 L
.21772 .54351 L
.21944 .5438 L
.22106 .54397 L
.22276 .54404 L
.22433 .54401 L
.22604 .54387 L
.22783 .5436 L
.23081 .54288 L
.23353 .54193 L
.23644 .54057 L
.23946 .53877 L
.24453 .53473 L
.24945 .52924 L
.25342 .52312 L
.25643 .51678 L
.25854 .51056 L
.25947 .50685 L
.26015 .50327 L
.26067 .4994 L
.26097 .49578 L
Mistroke
.26109 .49153 L
.26098 .48743 L
.2606 .48289 L
.26027 .48031 L
.25989 .47793 L
.25901 .47354 L
.25781 .46889 L
.25509 .46087 L
.25117 .45225 L
.24591 .44335 L
.23915 .43444 L
.23175 .42681 L
.22426 .42072 L
.21615 .41562 L
.20821 .41195 L
.20393 .41047 L
.19913 .40923 L
.19405 .40838 L
.18925 .40803 L
.18496 .4081 L
.18046 .40856 L
.17665 .40929 L
.17253 .41044 L
.16815 .41212 L
.16359 .4144 L
.15577 .41977 L
.15171 .42344 L
.14751 .42801 L
.14371 .43298 L
.14 .43885 L
.1369 .44479 L
.1344 .45054 L
.13233 .45624 L
.13048 .46253 L
.12962 .46606 L
.1288 .47001 L
.12769 .47706 L
.12726 .48105 L
.12694 .48534 L
.1268 .48938 L
.12678 .49307 L
.12707 .49968 L
.1274 .50335 L
.12782 .5067 L
.12898 .51325 L
.1298 .51676 L
.13066 .51984 L
.13249 .52521 L
.13475 .53043 L
.13956 .53844 L
Mistroke
.14259 .54207 L
.14561 .54491 L
.1491 .54739 L
.15113 .54848 L
.15301 .54929 L
.15641 .55029 L
.15961 .55071 L
.16313 .55061 L
.16508 .55031 L
.16685 .54989 L
.17005 .54875 L
.17342 .54701 L
.1765 .54489 L
.17921 .54257 L
.18474 .53623 L
.18908 .52918 L
.19114 .52484 L
.19309 .51979 L
.1945 .5152 L
.19577 .50992 L
.19665 .50489 L
.19721 .50006 L
.19754 .49486 L
.19756 .48917 L
.19731 .48412 L
.19675 .4788 L
.19605 .47427 L
.19504 .46934 L
.19338 .46314 L
.19145 .45742 L
.18691 .44723 L
.18076 .4373 L
.17712 .4327 L
.1728 .42815 L
.16493 .42188 L
.16034 .41925 L
.15591 .41735 L
.15169 .4161 L
.14778 .41542 L
.14324 .4152 L
.13893 .41557 L
.1345 .41657 L
.13204 .41742 L
.1298 .41837 L
.12578 .42056 L
.12168 .4235 L
.11504 .43004 L
.1116 .43453 L
.10864 .43919 L
.10555 .44508 L
Mistroke
.10299 .45109 L
.10097 .45689 L
.09918 .46331 L
.09766 .47055 L
.09665 .47738 L
.09601 .48481 L
.09584 .48904 L
.09582 .49297 L
.09607 .49928 L
.09671 .50599 L
.09767 .51209 L
.09885 .5175 L
.10029 .52255 L
.1018 .52685 L
.10587 .53535 L
.10851 .53937 L
.11113 .54254 L
.11418 .54542 L
.11757 .54776 L
.12061 .5492 L
.12352 .55003 L
.12673 .55039 L
.13019 .55014 L
.1335 .54928 L
.13536 .54853 L
.13709 .54766 L
.14046 .54541 L
.14393 .54232 L
.14679 .53905 L
.14958 .5351 L
.15391 .52689 L
.15594 .52168 L
.15774 .51574 L
.15847 .51274 L
.15907 .50984 L
.15995 .50428 L
.16031 .50101 L
.16058 .49749 L
.16071 .49446 L
.16075 .4911 L
.16067 .48748 L
.16044 .48359 L
.16009 .47992 L
.15966 .47657 L
.15861 .47067 L
.15713 .46452 L
.15352 .45398 L
.15075 .44797 L
.14778 .44273 L
.1448 .43835 L
Mistroke
.14139 .43418 L
.13815 .4309 L
.13441 .42782 L
.13085 .42552 L
.12744 .42384 L
.12331 .42245 L
.11949 .42177 L
.11737 .42165 L
.11506 .42172 L
.11088 .4224 L
.10696 .42373 L
.10345 .42552 L
.09972 .42812 L
.09598 .43155 L
.09021 .43886 L
.0873 .44378 L
.08486 .44881 L
.08235 .45524 L
.08036 .46173 L
.07892 .46783 L
.07774 .47465 L
.07728 .47826 L
.0769 .48225 L
.07665 .48643 L
.07655 .49033 L
.07668 .49725 L
.07692 .50108 L
.07726 .50451 L
.07825 .51132 L
.07899 .51497 L
.07976 .51816 L
.08155 .52409 L
.08351 .52908 L
.08613 .53429 L
.08932 .53906 L
.09238 .54248 L
.09416 .54404 L
.09582 .54525 L
.09894 .54695 L
.10237 .54802 L
.10559 .54832 L
.10862 .548 L
.11033 .54757 L
.11212 .54691 L
.11527 .54524 L
.11697 .54406 L
.11853 .54278 L
.12192 .5393 L
.12461 .53576 L
.12723 .53144 L
Mistroke
.1312 .52248 L
.13312 .51636 L
.1339 .51321 L
.13452 .51024 L
.13544 .50453 L
.13579 .50146 L
.13605 .49817 L
.13626 .49251 L
.13614 .48639 L
.13569 .48063 L
.135 .47543 L
.13386 .46946 L
.13222 .46316 L
.13031 .45749 L
.12824 .45252 L
.12378 .44434 L
.11888 .4379 L
.11581 .43485 L
.11286 .43249 L
.1095 .43041 L
.10586 .42885 L
.10248 .428 L
.09883 .42772 L
.09539 .42807 L
.0923 .42891 L
.08873 .43053 L
.08676 .43174 L
.08499 .43305 L
.07869 .43959 L
.07576 .44391 L
.07323 .44854 L
.06923 .45843 L
.06747 .46453 L
.06617 .47045 L
.06511 .47718 L
.0647 .481 L
.06443 .48449 L
.06422 .49086 L
.06433 .49668 L
.06479 .50294 L
.06564 .50933 L
.06668 .51464 L
.06788 .51933 L
.06946 .52415 L
.07141 .52885 L
.07398 .53368 L
.07662 .53747 L
.07976 .54083 L
.08141 .5422 L
.08329 .54344 L
Mistroke
.08651 .54491 L
.08836 .54539 L
.09006 .54561 L
.09319 .5455 L
.09646 .54464 L
.09936 .54323 L
.10235 .54111 L
.10504 .53855 L
.10734 .53578 L
.10986 .53202 L
.11232 .52741 L
.11437 .52256 L
.11596 .51781 L
.11731 .51266 L
.11832 .50757 L
.11907 .50203 L
.11936 .49884 L
.11953 .49585 L
.11962 .49088 L
.11943 .48537 L
.11891 .47966 L
.11813 .47438 L
.11693 .46867 L
.11531 .46291 L
.11154 .45346 L
.109 .44881 L
.10639 .44493 L
.10328 .44125 L
.09972 .43805 L
.09798 .43682 L
.09609 .43572 L
.09262 .43429 L
.09067 .43381 L
.08882 .43357 L
.0868 .43353 L
.08462 .43377 L
.08277 .4342 L
.08076 .43491 L
.0789 .43581 L
.0772 .43684 L
.07409 .4393 L
.07095 .44263 L
.06808 .4466 L
.06528 .45159 L
.06295 .4569 L
.06111 .46223 L
.05972 .46736 L
.05851 .47326 L
.05761 .47963 L
.05712 .48569 L
Mistroke
.05696 .4922 L
.05703 .49547 L
.05722 .49905 L
.05783 .50523 L
.05873 .5108 L
.05938 .51387 L
.06017 .51699 L
.06182 .52222 L
.06392 .52731 L
.06657 .53214 L
.06916 .53571 L
.07168 .53834 L
.07313 .53954 L
.07474 .54063 L
.07775 .54204 L
.08063 .5427 L
.08369 .5427 L
.08629 .54214 L
.08911 .54094 L
.09193 .5391 L
.09449 .5368 L
.09667 .53432 L
.09889 .53119 L
.1011 .52733 L
.10319 .52277 L
.10488 .51812 L
.10618 .51357 L
.10725 .50872 L
.1081 .50328 L
.10859 .49837 L
.10882 .49313 L
.10878 .4884 L
.10853 .48401 L
.10803 .47926 L
.10723 .47428 L
.10609 .46915 L
.1045 .46379 L
.10248 .45857 L
.1003 .45411 L
.09576 .44738 L
.09292 .44438 L
.09017 .4422 L
.08857 .44121 L
.08684 .44036 L
.08367 .43937 L
.0817 .43912 L
.07985 .43912 L
.07818 .43933 L
.07639 .43978 L
.07482 .44037 L
Mistroke
.07312 .44123 L
.06978 .44362 L
.06686 .44658 L
.06432 .44997 L
.06199 .45392 L
.05974 .45879 L
.05792 .46387 L
.05652 .46893 L
.0555 .4737 L
.05466 .47917 L
.05412 .48502 L
.05391 .49057 L
.05403 .49667 L
.05423 .4997 L
.05455 .50297 L
.05538 .5086 L
.05644 .51359 L
.05803 .5191 L
.05978 .52367 L
.0621 .52834 L
.06456 .53209 L
.06682 .53472 L
.06939 .53697 L
.07193 .53852 L
.0743 .53943 L
.07712 .53989 L
.07872 .53987 L
.0802 .53966 L
.08289 .53884 L
.08568 .53734 L
.08716 .53627 L
.08848 .53513 L
.09133 .53205 L
.09365 .52878 L
.09588 .52483 L
.09909 .51694 L
.10051 .51199 L
.10156 .50714 L
.10227 .50248 L
.10276 .49731 L
.10294 .49238 L
.10286 .48782 L
.1026 .48375 L
.10209 .47933 L
.10132 .47485 L
.10039 .47079 L
.09913 .46652 L
.09757 .46232 L
.0942 .45569 L
.09205 .45257 L
Mistroke
.0899 .45008 L
.0874 .44784 L
.08597 .44684 L
.08461 .44606 L
.08193 .445 L
.0805 .44467 L
.07895 .44451 L
.07732 .44454 L
.07578 .44478 L
.07293 .44574 L
.07035 .44724 L
.06804 .44915 L
.06564 .45179 L
.06328 .45519 L
.06116 .45911 L
.05917 .4639 L
.05759 .46888 L
.05643 .47377 L
.05589 .47668 L
.05548 .47945 L
.05512 .48255 L
.05486 .4859 L
.05471 .48945 L
.05469 .49281 L
.05478 .49582 L
.05499 .49906 L
.05558 .50441 L
.05642 .50923 L
.05764 .51425 L
.05927 .51925 L
.06131 .52393 L
.06352 .5278 L
.0657 .53074 L
.06825 .53334 L
.07081 .53519 L
.0732 .53633 L
.07455 .53674 L
.07603 .53701 L
.07871 .53703 L
.08121 .53651 L
.08381 .53541 L
.08596 .53404 L
.08823 .5321 L
.09063 .52944 L
.0927 .52653 L
.09472 .52299 L
.09669 .51864 L
.09805 .51483 L
.09929 .51048 L
.10031 .50567 L
Mistroke
.101 .50102 L
.10138 .49671 L
.10154 .49195 L
.10142 .48702 L
.10103 .4825 L
.10044 .47837 L
.09972 .47474 L
.09868 .47073 L
.09749 .46718 L
.09415 .46007 L
.09217 .4571 L
.08981 .45436 L
.08766 .4525 L
.08525 .45103 L
.08291 .45016 L
.08074 .44981 L
.07943 .44982 L
.07803 .45 L
.07555 .45078 L
.07406 .45156 L
.07268 .45248 L
.07022 .45471 L
.06801 .45744 L
.06614 .46043 L
.0643 .4642 L
.06263 .46865 L
.06144 .47286 L
.0609 .47519 L
.06042 .47773 L
.05974 .48255 L
.05938 .48711 L
.05926 .49154 L
.05936 .4957 L
.0597 .50021 L
.06034 .50495 L
.0613 .50977 L
.06268 .51471 L
.06428 .519 L
.06599 .52259 L
.06784 .52568 L
.06973 .52819 L
.07207 .53059 L
.0743 .53227 L
.07636 .53336 L
.07867 .53411 L
.08111 .5344 L
.0834 .53422 L
.08551 .53365 L
.08741 .53282 L
.08955 .53149 L
Mistroke
.0915 .52989 L
.09351 .5278 L
.09552 .52521 L
.0987 .51969 L
.10021 .51623 L
.10144 .51276 L
.10257 .50875 L
.10309 .50646 L
.10352 .50426 L
.10414 .49998 L
.10448 .49605 L
.10462 .4918 L
.10459 .48942 L
.10449 .48724 L
.10419 .48367 L
.10365 .47984 L
.10286 .47601 L
.10193 .47261 L
.10061 .46889 L
.09915 .46568 L
.09766 .46308 L
.09593 .46066 L
.09391 .4585 L
.09193 .45694 L
.09067 .45622 L
.08947 .45569 L
.08838 .45535 L
.08719 .45513 L
.08493 .45513 L
.08284 .45562 L
.08166 .45612 L
.0806 .45671 L
.07938 .45756 L
.07829 .45849 L
.07621 .46079 L
.07414 .46389 L
.07251 .4671 L
.07101 .47096 L
.06995 .47451 L
.06905 .4786 L
.06843 .48266 L
.06806 .48649 L
.06789 .49084 L
.06791 .49331 L
.068 .49561 L
.06839 .50023 L
.06873 .50277 L
.06912 .50504 L
.06998 .50898 L
.07099 .51249 L
Mistroke
.0723 .5161 L
.07392 .51964 L
.07585 .52294 L
.07785 .52563 L
.07979 .52766 L
.082 .52943 L
.0842 .53067 L
.08624 .53142 L
.08863 .53184 L
.09088 .5318 L
.09297 .5314 L
.09485 .53071 L
.09688 .52964 L
.09895 .52816 L
.10112 .52613 L
.10298 .52395 L
.10483 .52129 L
.10666 .51806 L
.10815 .5148 L
.10935 .5116 L
.11032 .50843 L
.11117 .50489 L
.11186 .501 L
.1123 .4973 L
.11246 .49505 L
.11254 .49291 L
.11249 .48893 L
.11238 .48694 L
.11219 .48486 L
.11167 .48122 L
.11125 .47907 L
.11078 .47712 L
.10973 .47369 L
.10886 .47147 L
.10783 .46928 L
.10571 .46586 L
.10428 .46415 L
.10285 .46281 L
.10151 .46185 L
.10001 .46108 L
.09853 .4606 L
.09687 .46041 L
.09513 .46057 L
.09352 .46107 L
.09205 .46183 L
.09075 .46278 L
.08936 .46408 L
.08799 .46575 L
.08589 .46915 L
.08486 .47137 L
Mistroke
.08402 .47357 L
.08332 .47575 L
.08267 .47826 L
.08217 .48073 L
.08179 .48309 L
.08147 .48593 L
.08129 .48864 L
.08122 .49166 L
.08131 .49493 L
.08157 .49834 L
.08199 .50155 L
.08249 .50438 L
.08319 .50738 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00e@3oool00`3ooml0W4P0000000020000000307Bo
o`3oool0oooo0=<0oooo003G0?ooo`030?noM00007@0_ooo0=H0oooo003G0?ooo`030?oo_`1d0000
M;oo0=H0oooo003G0?ooo`030?oog`2LB000B9cO0=H0oooo003H0?ooo`030=nLB000000000000080
000000<0M;oo0?ooo`3oool00P3oool01@3o_g@000000000000004P0W=oo0080oooo00<0oono07@0
000000000P0000003@18W=l0oooo0?ooo`3oool0_g@00000000004P0W=oo0?ooo`3o_g@000000000
B02Lgol00P3oool0102oM00000000000B02Lgol20?ooo`050?noM000000000000000B02Lgol00`3o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000000007Bo09d0oooo003H0?ooo`070?noM00004P0
W=oo0?ooo`3ooml0W4P0001d_`020?ooo`0?0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`3oool0
oooO09a8001d_ol0oooo0?oOW0180000M;oo0080oooo01L0gia80018W03Ooml0W7BL0=ooo`3o_g@0
001809cOg`2LM9`0gooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0
B000001d_`020?ooo`030?noM00007@0_ooo0080oooo00@0gia80018W03O_g@0M;ooW03oool00=P0
oooo00<0oono07@0001d_ol00P3oool01`3ooml0W4P004RLg`3oool0gia80018W03Oool00P3oool0
2P3ogi`0B00004RLg`3oool0_gAd0;ooo`3oool0oono07@0001d_ol20?ooo`030?noM00004P0W=oo
0080oooo00<0oono07@0001d_ol00`3oool00`3o_g@0001809cOo`020?ooo`030=nLB000B9`0gooo
0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol0W@3o
ool00=P0oooo00<0oooO09a80018W=l00`3oool01P3ogi`0B01809cOo`3o_g@0001d0;ooo`<0oooo
00<0gia80000M02oool00`3oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo
00<0_g@0001d_`3oool00P3oool00`3ookl0M00004RLg`020?ooo`030?noM00007@0_ooo00<0oooo
00/0gia80000M02oool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`2M0?ooo`00f@3oool0
0`3OW4P0001d0;ooo`020?ooo`060?oog`2LB000B9cO0?oo_`1d0000M;oo0`3oool00`3ogi`0B018
09cOo`020?ooo`030?noM00004P0W=oo00@0oooo00<0_g@00018W03Oool00P3oool00`3OW4P004RL
0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3ookl0M00007Boo`030?ooo`070?oOW01804P0W=oo
0?ooo`3OW4P004Q804Qd_`020?ooo`030;md0000M;l0oooo09`0oooo003I0?ooo`040?noM0000000
04RL0=ooo`80oooo00H0gia8001d_`3oool0gia80000M02oool20?ooo`0:0?oo_`1d0000M;oo0?oo
o`3ogi`0B01809cOo`3oool0giad09cOo`80oooo00<0gia80000B02Lgol00P3oool00`3ogi`0B018
09cOo`030?ooo`030=nLB00004P0W=oo0080oooo00<0gia80000M02oool00P3oool0303ookl0M000
07Boo`3oool0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;oooi`0oooo003I0?ooo`080?oo_`1d
0000M9bL04P0M02oool0oooO09a80000M;l20?ooo`0>0;md000007@0_ooo0?ooo`3o_g@0001d0;oo
o`3oool0omnL04P0B02Lgol0oooO09a8001d_ol20?ooo`030?oOW0180000B9cO0080oooo00<0oooO
09a80018W=l00`3oool00`3ogi`0B00004RLg`030?ooo`0@0;md000007@0_ooo0?ooo`3o_g@0001d
0;ooo`3oool0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOoi`0oooo003H0?ooo`090?oOW018
0000000004RLg`3ookl0M0000000000007@0_ooo00<0oooo00D0okmd000000000000000007Boo`03
0?ooo`070;md00000000000000000018W=l0oooo0?noM002000000040018W03Oool0oono07@000<0
000000H0M;oo0?noM000000000000018W03Oool30?ooo`0?0?noM000000000000000001d_ol0oooo
0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo09`0oooo003i0?ooo`030?noM00007@0
_ooo0;@0oooo003j0?ooo`030=nLM02Lgol0oooo0;<0oooo003d0?ooo`040?oo_`1d000004RL0=oo
o`L0oooo00@0oono07@00000B9`0gooo[@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00680oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`0d0?ooo`030?oo_`1d
000000000080000000<0B9cO0?ooo`3oool0<03oool0102oM00000000000001d_olg0?ooo`030?oo
_`1d000000000080000000<0B9cO0?ooo`3oool0=@3oool00`3OW4P00000000000030000000304RL
g`3oool0oooo03@0oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`0L0?ooo`00H`3o
ool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02oool0oooo03H0oooo00<0okmd0000001d_ol0<P3o
ool01P3OW4P007Bo0?ooo`3ogi`0B00004RLgcP0oooo00<0okmd0000001d_ol0>@3oool00`3o_g@0
07Bo0?ooo`020?ooo`030;mdM02oool0oooo03@0oooo00<0okmd00000000M;l00P3oool00`2oM4P0
W=oo0?ooo`0L0?ooo`00I03oool00`3o_g@007Bo0?ooo`0j0?ooo`030?oog`2LB00007Bo0340oooo
00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`0g0?ooo`030?oog`2LB00007Bo03X0oooo
00<0okmd001d_`3oool0?@3oool00`3ogi`0B4RL0=ooo`0L0?ooo`00I@3oool00`3o_g@007Bo0?oo
o`0j0?ooo`030=nLB000B9`0gooo0300oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018
W03Ooolg0?ooo`030=nLB000B9`0gooo03X0oooo00<0okmd001d_`3oool0?03oool00`3ookl0M000
07Boo`0L0?ooo`00E@3oool00`3ooml0W4P0000000070000000304RLg`3oool0oooo00@0oooo00<0
okmd04RLg`3oool0:@3oool00`3ooml0W4P0000000070000000304RLg`3oool0oooo00<0oooo00<0
omnL04P0B02Lgol0<03oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo03L0oooo00<0
omnL04P0B02Lgol0>`3oool00`3o_g@0B9cO0?ooo`0k0?ooo`030?oOW0180000M;oo01`0oooo001W
0?ooo`030=nLB018W=l0oooo03P0oooo00<0oono07@0001d_ol0<@3oool00`2oM00004RL0=ooo`02
0?ooo`030?oOW0180000B9cO03L0oooo00<0oono07@0001d_ol0?03oool00`3OW4P0B9cO0?ooo`0i
0?ooo`040?oOW0180000001809cOoa`0oooo001X0?ooo`030;md001d_ol0oooo03P0oooo00<0_g@0
001d_`3oool0<03oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo03P0oooo00<0_g@0
001d_`3oool0?03oool00`2oM000M;oo0?ooo`0f0?ooo`050?oOW018000000000000001d_ol07@3o
ool006P0oooo00<0omnL04P0M02oool0>03oool00`3OW4P004RL0=ooo`0`0?ooo`030?oOW0180000
B9cO00<0oooo00<0_g@00018W03Oool0=`3oool00`3OW4P004RL0=ooo`0l0?ooo`030?oOW01807@0
_ooo03P0oooo00<0oono07@00000M;l07@3oool006P0oooo00<0oooO09a8001d_ol0>03oool00`3o
gi`0B01809cOo`0`0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0=`3oool0
0`3ogi`0B01809cOo`0l0?ooo`030?oog`2LB000M;oo03X0oooo00<0gia8001d_`3oool06`3oool0
06P0oooo00<0oono07@00018W=l0>03oool00`3ookl0M00007Boo`0a0?ooo`030?oOW0180000M;oo
0080oooo00<0gia8001d_`3oool0=`3oool00`3ookl0M00007Boo`0l0?ooo`030?oo_`1d0000B9cO
03X0oooo00<0omnL04P0B02Lgol06`3oool006@0oooo00L0okmd0018W03Oool0oooo0=nLB00004P0
W=oo03T0oooo00<0_g@0001d_`3oool0<@3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLgcT0oooo
00<0_g@0001d_`3oool0=`3oool01`3o_g@004RL0=ooo`3oool0gia80000B02Lgol0=`3oool01P2o
M000M;oo0?ooo`3OW4P0001809cOoa/0oooo001U0?ooo`050?oOW018000000000000001d_ol0>03o
ool01@3ookl0M0000000000007@0_ooo0380oooo00@0gia800000000000007Bo>03oool01@3ookl0
M0000000000007@0_ooo03P0oooo00D0omnL04P000000000000007Boo`0i0?ooo`040;md00000000
000004RLga`0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
00140?ooool00000HP00000;0?ooo`00A03oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
0<L0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000
oooo0?ooo`370?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo
00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?oo
o`2C0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool02@3oool004@0oooo0P00002D
0?ooo`030000003oool0oooo0<D0oooo0`00000;0?ooo`00A03oool00`000000oooo0?ooo`2C0?oo
o`030000003oool0oooo07L0oooo1@00001;0?ooo`030000003oool0oooo00T0oooo00140?ooo`03
0000003oool0oooo09<0oooo00<000000?ooo`3oool0L@3oool6000000D0oooo1P0000150?ooo`03
0000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
K03oool500000140oooo1@0000100?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003o
ool0oooo09<0oooo00<000000?ooo`3oool0I`3oool5000001/0oooo0P00000n0?ooo`030000003o
ool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0I@3oool2
00000280oooo0P00000l0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
09<0oooo00<000000?ooo`3oool0H`3oool2000002H0oooo0P00000j0?ooo`030000003oool0oooo
00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0H@3oool2000002X0
oooo0P00000h0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo
00<000000?ooo`3oool0G`3oool2000002h0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo05h0oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00T0oooo0014
0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0G03oool2000003<0oooo0P00000d
0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?oo
o`3oool0FP3oool2000003L0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`090?oo
o`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000
003oool0oooo09<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3o
ool00`000000oooo0?ooo`1F0?ooo`800000?P3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool0
04@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`00A03oool2000009@0
oooo00<000000?ooo`3oool0DP3oool2000001X0oooo3@00000N0?ooo`030000003oool0oooo02T0
oooo0`00000;0?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0540oooo
00<000000?ooo`3oool05P3oool4000000d0oooo1000000K0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?oo
o`1@0?ooo`030000003oool0oooo01@0oooo0`00000E0?ooo`@00000603oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0C0?ooo`800000703oool2000001L0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2C0?oo
o`030000003oool0oooo04d0oooo0P00000D0?ooo`800000803oool3000001D0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`03
0000003oool0oooo04`0oooo00<000000?ooo`3oool04P3oool2000002D0oooo0P00000D0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0
T`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0140oooo0P00000Y0?ooo`800000
4`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003o
ool0oooo09<0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`800000;@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool02@3o
ool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`180?ooo`8000004@3oool2
00000300oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0340oooo0P00000@0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo0P00000f0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`090?ooo`00=`3oool00`3ooml0W4P0
04RLg`0:0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo00T0oooo000h0?ooo`030=nLB000B9`0gooo00T0oooo00<0
00000?ooo`3oool0T`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo0P00
000k0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`090?ooo`00>03oool00`3ogi`0B01809cOo`090?ooo`030000003oool0oooo09<0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00T0oooo000d0?oo
o`030?noM0000000000000@0000000<004RL0=ooo`3oool01P3oool00`000000oooo0?ooo`2C0?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`090?oo
o`009`3oool00`3ooml0W4P0000000070000000604RLg`3oool0oooo0?oog`2LB4P0W=oo0P3oool0
0`2oM00007Bo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`0=0?ooo`800000703oool7000001h0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00T0oooo000e0?ooo`070?oo_`1d07@0_ooo
0?ooo`3o_g@004RL0=ooo`080?ooo`<00000T`3oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool05`3oool5000000L0oooo1P00000I0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool07P3oool3000000/0oooo000f0?ooo`060?oOW018B9`0
gooo0?oOW01804P0W=oo203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0D0?ooo`@000004P3oool3000001L0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00T0oooo
000g0?ooo`050?noM000M;l0oooO09a80018W=l0203oool00`000000oooo0?ooo`2C0?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0B0?ooo`<00000
6@3oool2000001H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00T0oooo000h0?ooo`040=nLB018W=l0_g@0001d_`P0oooo00<000000?ooo`3oool0
T`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
4@3oool2000001h0oooo0P00000E0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`090?ooo`00>@3oool0103OW4P0M7Ad0000M02oool70?ooo`030000
003oool0oooo09<0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0;0?ooo`800000
4P3oool200000280oooo0P00000D0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`090?ooo`00>P3oool00`2oM000001809cOo`070?ooo`030000003o
ool0oooo09<0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0100oooo0P00000V0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00T0oooo000j0?ooo`030?oog`2LB000
B9cO00L0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool03`3oool2000002T0oooo0P00000B0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`00
0000oooo0?ooo`2C0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0>0?ooo`800000;@3oool200000140oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0:0?ooo`8000003`3oool200000340
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool2000003@0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0303oool2000003L0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool2000003X0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0B0?oooa4000007P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo1000000A0?ooo`<00000703oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`090?ooo`00A03oool2000009@0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool20000
01P0oooo0`00000J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0F0?ooo`<000002`3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool2000000l0
oooo0P00000M0?ooo`800000603oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo
0?ooo`2C0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00d0oooo0P00000Q0?ooo`8000005`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo0`00
000U0?ooo`8000005P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2C
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo0P00000Z0?ooo`800000503oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`09
0?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo0P00000^0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3o
ool0T`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`800000<@3oool200000180oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`090?ooo`00A03o
ool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0
oooo09<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01`3oool2000003T0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02@3oool004@0oooo
00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03d0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?oo
o`2C0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo0P00000C0?ooo`X00000903oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`D000002P3oool500000200oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2C0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool3000001@0oooo1000000M0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool02@3oool004@0oooo0P00002D0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00@0oooo0P00000<0?ooo`<000006`3oool3000001/0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0403oool3000000/0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`090?ooo`<000008@3oool2000001T0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0203oool2000002H0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0
oooo09<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`800000:@3oool2
000001P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`00
0000oooo0?ooo`2C0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01P3oool2000002l0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`800000<P3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02@3oool004@0oooo00<0
00000?ooo`3oool0T`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0<`3oool2000001H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`090?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool2000003P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo00140?ooo`03
0000003oool0oooo09<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`800000?`3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02@3o
ool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?oo
o`3oool0T`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0103oool01@000000oooo0?ooo`3oool0000000<0oooo0P00000;0?oooa@00000:03oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool0
04@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000T0oooo1000000D0?ooo`<000009P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool02@3oool004@0oooo0P00002D0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`D000006`3oool2000002@0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`<000002`3oool004@0oooo00<000000?oo
o`3oool0T`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool2
00000280oooo0P00000S0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool0oooo0P00000V0?ooo`8000008P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool0T`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0103oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool2000002X0oooo
0P00000Q0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`<00000
00<0oooo000000000000;P3oool2000001l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P0000000`3oool000000000000b0?ooo`8000007P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool0T`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`04000003H0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool0
04@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02000003T0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool010000000oooo00000000000l0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo0`00000n0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo0P0000000`3oool00000
0?ooo`0o0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo0?ooo`800000
00@0oooo0000003oool00000@@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`00=03oool00`3OW4P00000
000000030000000304RLg`3oool0oooo00L0oooo00<000000?ooo`3oool0T`3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`00000000000P3oool00`000000
oooo000000130?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo000e0?ooo`030?noM000M;l0oooo0080oooo
00<0_gAd0;ooo`3oool01`3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01P3oool3000000@0oooo0P0000150?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo
000f0?ooo`030?noM000M;l0oooo00/0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool3000004H0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool02@3oool003L0oooo00<0okmd001d_`3oool02P3oool00`000000oooo0?ooo`2C
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`800000B03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`009`3oool00`3ooml0W4P0000000070000
000304RLg`3oool0oooo00@0oooo00<0okmd04RLg`3oool02@3oool00`000000oooo0?ooo`2C0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool3000000D0oooo0`0000180?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00T0oooo000i0?ooo`030=nLB018W=l0oooo00P0oooo0`0000260?oooa/0
0000303oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000D0oooo0P00001:0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?oo
o`<000002`3oool003X0oooo00<0_g@007Boo`3oool01`3oool00`000000oooo0?ooo`1h0?ooo`h0
00003@3oool00`000000oooo0?ooo`0;0?oooa8000000P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000004X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool003X0oooo00<0omnL04P0M02oool0
1`3oool00`000000oooo0?ooo`1]0?ooo`/000006`3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo0080oooo1P0000030?ooo`<00000C03oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`00>P3o
ool00`3ooml0W4P007Boo`070?ooo`030000003oool0oooo06X0oooo0`00000V0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool00P0000040?ooo`030000003oool0000000L00000B`3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`090?ooo`00>P3oool00`3ookl0M00004RLg`070?ooo`030000003oool0
oooo06@0oooo1P00000Y0?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`020?ooo`<000000`3oool4000004L0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool003H0oooo00L0okmd0018W03Oool0oooo0=nLB00004P0W=oo00L0oooo00<000000?ooo`3oool0
?`3oool<000001@0oooo1@00000_0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`000000
1P3oool010000000oooo0?ooo`3oool2000000030?ooo`000000oooo00H0oooo100000140?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo000g0?ooo`050?oOW018000000000000001d_ol0203oool00`000000
oooo0?ooo`0k0?ooo`@00000303oool4000000h0oooo0P00000d0?ooo`030000003oool0oooo01@0
oooo0`0000060?ooo`060000003oool0oooo0?ooo`000000oooo0P00000<0?ooo`800000@P3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0g0?ooo`@00000503oool30000
00T0oooo0P00000f0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool02000
0000oooo0?ooo`000000oooo0000003oool000003P3oool200000440oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool004@0oooo00<000000?ooo`3oool0<@3oool3000000030?ooo`000000000001/0oooo0`00
00030?ooo`<00000>03oool00`000000oooo0?ooo`0C0?ooo`800000203oool00`000000oooo0000
00020?ooo`8000004@3oool3000003l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool0;03oool500000080oooo2000000J0?ooo`<00000>`3oool00`000000oooo0?ooo`0B
0?ooo`800000203oool010000000oooo0?ooo`0000020?ooo`800000503oool3000003`0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0:P3oool2000000H0oooo00<00000
0?ooo`3oool01P3oool2000001H0oooo0P0000030?ooo`<00000>03oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0000000P0oooo00<000000?ooo`0000000P3oool2000001P0oooo0P00000k
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo02P0oooo0P0000070?oo
o`030000003oool0oooo00T0oooo0P00000B0?ooo`800000203oool2000003H0oooo00<000000?oo
o`3oool0403oool010000000oooo0?ooo`0000080?ooo`8000000`3oool2000001X0oooo0P00000i
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo02H0oooo0P0000070?oo
o`8000003P3oool2000000l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo00l0oooo00@000000?ooo`3oool00000203oool2000000<0oooo0P00000M
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?oo
o`3oool08`3oool=00000140oooo0P00000;0?ooo`8000003P3oool2000003<0oooo00<000000?oo
o`3oool03P3oool01@000000oooo0?ooo`3oool0000000P0oooo0P0000030?ooo`8000007P3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
0200oooo100000090?ooo`030000003oool0oooo008000004@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01h0oooo0P00000g0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00140?ooo`03
0000003oool0oooo01h0oooo0P0000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00`3oool200000100oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo0P0000030?ooo`8000008P3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00140?ooo`8000007P3oool01@000000oooo0?ooo`3oool0000000T0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`800000103oool00`000000
oooo0?ooo`0D0?ooo`800000;`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01`3oool3000000/0oooo00140?ooo`030000003oool0oooo01`0oooo
2P0000050?ooo`030000003oool0oooo00L0oooo0P00000@0?ooo`040000003oool00000000001T0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`3oool2000002D0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0J0?ooo`80
00000`3oool00`000000oooo0?ooo`040?ooo`<0000000<0oooo0000003oool02`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo01X0oooo0P00000/0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo0P00000V0?ooo`800000=03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo
0?ooo`0I0?ooo`8000000`3oool00`000000oooo0?ooo`080?ooo`8000003@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0000001d0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0203oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00X0oooo
00D000000?ooo`3oool0oooo0000000M0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo0P0000030?ooo`80
0000:P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00140?ooo`030000
003oool0oooo01H0oooo0P0000000`3oool0000000000008000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0K0?ooo`800000:03oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool2000000<0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003o
ool0oooo01D0oooo100000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo
000000050?ooo`800000303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`800000103oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool004@0oooo00<0
00000?ooo`3oool0503oool3000000@0oooo00<000000?ooo`3oool01P3oool3000000P0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`8000000`3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo000000030?ooo`<000002@3oool3000000P0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo0180oooo0P0000000`3oool0000000000002000000030?ooo`000000oooo
00<000001P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00T0oooo00D00000
0?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3o
ool2000000@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00T0oooo00140?ooo`030000003oool0oooo0180oooo00<000000?ooo`0000001@3oool0
0`000000oooo0?ooo`020?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0000000?0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo000000030?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`00A03oool00`00
0000oooo0?ooo`0A0?ooo`040000003oool00000000000D0oooo00<000000?ooo`3oool0103oool2
000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`09
0?ooo`8000003`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0403oool010000000oooo000000000003
0?ooo`D000001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool02@3oool200000100oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0O
0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00T0oooo00140?ooo`030000003oool0oooo00l0oooo0`0000000`3oool000000?ooo`02
00000080oooo00<000000?ooo`3oool00`0000040?ooo`8000001P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000004@3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool03P3oool2
00000080oooo0`0000030?ooo`030000003oool0oooo00@0oooo0P0000001@3oool000000?ooo`3o
ool0000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`040000003o
ool0oooo00000140oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`040000
003oool0oooo000000`0oooo00<000000?ooo`3oool0103oool00`000000oooo000000030?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`00
A03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo008000001@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0000000=0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0
3@3oool200000080oooo00<000000?ooo`3oool00P3oool7000000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
1`3ooolB000000@0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000=0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool004@0oooo0P00000=0?ooo`8000000P3o
ool2000000<0oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`3oool2000000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo0?ooo`D0
00004P3oool6000001d0oooo0P00000>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo0`00000;0?ooo`00
A03oool00`000000oooo0?ooo`0<0?ooo`80000000<0oooo0000000000000P3oool2000000030?oo
o`000000oooo00H0oooo0`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000
oooo0?ooo`0?0?ooo`@000007@3oool6000001L0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00/0
oooo10000000103oool000000?ooo`0000030?ooo`040000003oool0oooo0?ooo`800000103oool2
00000080oooo0P0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool0
10000000oooo0?ooo`0000070?ooo`030000003oool0oooo00h0oooo0`00000O0?ooo`030000003o
ool0oooo00<0oooo1P00000@0?ooo`8000003P3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00/0oooo0P0000001@3oool000000000
003oool0000000@0oooo00@000000?ooo`00000000000P3oool400000080oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool01000
0000oooo0?ooo`0000020?ooo`<000000`3oool00`000000oooo0?ooo`0;0?ooo`8000000P3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00P0oooo1000000<0?ooo`8000003P3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo0P00000j0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool02`3oool3
000000030?ooo`000000000000@0oooo00<000000?ooo`0000001`3oool3000000050?ooo`000000
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`0000000`0000030?ooo`D000002P3oool2000000D0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0;0?ooo`D000001P3oool00`000000oooo0000000>0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool02P3o
ool5000000030?ooo`000000oooo00<0oooo0P0000080?ooo`060000003oool0oooo0000003oool0
00000P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00D0oooo0`00000:0?oo
o`<000001P3oool2000000L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0?0?oo
o`@0000000D0oooo0000003oool0oooo0000000>0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool02P3oool010000000oooo0000003o
ool2000000@0oooo0P0000070?ooo`D0000000H0oooo0000003oool000000?ooo`0000030?ooo`T0
00000`3oool00`000000oooo0000000;0?ooo`030000003oool0oooo008000000`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool04`3oool5000000h0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00800000?03oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00T0
oooo100000000`3oool000000?ooo`040?ooo`030000003oool0oooo00@0oooo0P0000000`3oool0
00000?ooo`020?ooo`@000000P3oool00`000000oooo0?ooo`02000000@0oooo00<000000?ooo`3o
ool00`0000020?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool0oooo0`00000;0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`3oool4
000000/0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00800000?03o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0
oooo00T0oooo0`0000020?ooo`030000003oool0oooo0080oooo0P0000050?ooo`050000003oool0
oooo0?ooo`0000001@3oool7000000030?ooo`000000oooo00<0oooo00@000000?ooo`3oool00000
0P3oool2000000030?ooo`000000oooo00X0oooo00@000000?ooo`3oool0oooo0`00000;0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool00000
00<0oooo1@0000050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000002
0?ooo`800000?@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo000C0?oo
o`030?oo_`1dM;l0oooo02h0oooo00<000000?ooo`3oool02@3oool3000000030?ooo`000000oooo
00<0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`020?ooo`050000003oool00000
0000003oool00`0000000`3oool000000?ooo`040?ooo`800000103oool00`000000oooo0000000;
0?ooo`040000003oool0oooo000000<0oooo0P00000:0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool04@3oool01@000000oooo0?ooo`3oool0000000P0oooo100000000`3oool00000
0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool001<0oooo00@0omnL04P0000004P0
W=oo;@3oool00`000000oooo0?ooo`090?ooo`8000000P3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo``0000000@0oooo00000000000000000`3o
ool2000000D0oooo0P0000000`3oool000000?ooo`0:0?ooo`8000001P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool04@3oool01@000000oooo0?oo
o`3oool0000000`0oooo100000000`3oool000000?ooo`030?ooo`040000003oool00000000003h0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`005@3oool00`2oM0000000
00000003000000030000M02oool0oooo02H0oooo00<000000?ooo`3oool0203oool00`000000oooo
000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo
0080oooo100000000`3oool0000000000002000000050?ooo`00000000000?ooo`0000000`3oool2
000000050?ooo`000000oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02000000/0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0100000020?ooo`040000003oool00000000003l0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`090?ooo`006@3oool00`3ogi`0B00007Boo`0X0?ooo`030000003o
ool0oooo00P0oooo0`0000000`3oool00000000000020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00P3oool3000000030?ooo`000000000000@0oooo00H000000?ooo`0000000000
0?ooo`0000030?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo000000020?ooo`H00000?`3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo000H0?ooo`030=nLB00007@0_ooo
02T0oooo00<000000?ooo`3oool0203oool3000000030?ooo`00000000000080oooo00<000000?oo
o`0000000P3oool010000000oooo0?ooo`3oool2000000030?ooo`000000oooo00800000103oool0
1P000000oooo0000003oool000000?ooo`8000000P3oool2000000<0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000203oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0000000@00000?03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00T0oooo000C0?ooo`060?oOW01804P0W=oo0?noM0000000B9cO:`3oool00`000000oooo0?oo
o`080?ooo`8000000P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0000003o
ool01`0000020?ooo`040000003oool0oooo000000<0oooo2P0000030?ooo`040000003oool0oooo
000000@0oooo0P0000070?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo008000000`3oool4000003P0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`090?ooo`004`3oool0103ogi`0B00000000000M;l]0?ooo`030000003oool0oooo00L0oooo
0`0000000`3oool00000000000020?ooo`040000003oool0oooo00000080oooo1@0000020?ooo`80
00000`3oool2000000D0oooo0`0000020?ooo`030000003oool00000008000000P3oool00`000000
oooo000000060?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0000003oool0000000L0oooo1000000d0?ooo`@00000203oool4
000001/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool02@3oool004@0oooo0P0000080?ooo`<0000000D0oooo0000
00000000oooo000000030?ooo`060000003oool000000?ooo`000000oooo0`000000103oool00000
0?ooo`0000030?ooo`800000103oool4000000050?ooo`000000oooo0000003oool00P0000020?oo
o`8000001P3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`000004
0?ooo`040000003oool00000000000`0oooo0P00000`0?ooo`80000000@0oooo0000003oool0oooo
0P0000050?ooo`030000003oool0oooo0080oooo0P0000000`3oool0000000000004000000030?oo
o`00000000000100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo0`00000;0?ooo`00A03oool00`000000oooo0?ooo`070?ooo`<0000000D0
oooo000000000000oooo000000030?ooo`030000003oool0000000<000000`3oool200000080oooo
00<000000?ooo`3oool00P0000030?ooo`040000003oool000000?ooo`80000000<0oooo00000000
00000P3oool2000000030?ooo`000000000000H0oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0;0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`00000000003P3oool2
000002`0oooo0P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P000007
0?ooo`030000003oool0oooo00<0oooo0`0000000`3oool0000000000002000000`0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool02@3oool001H0oooo00H0gia800000000000000000000B02LgolX0?ooo`030000003o
ool0oooo00L0oooo0P0000001P3oool000000?ooo`000000oooo000000<0oooo100000000`3oool0
000000000003000000060?ooo`000000oooo0000003oool000000P3oool00`000000oooo00000002
0?ooo`@0000000<0oooo0000000000000P3oool010000000oooo0000000000030?ooo`@0000000<0
oooo0000000000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`000000
103oool010000000oooo00000000000@0?ooo`<000005@3oool6000000d0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`800000203oool00`000000oooo000000030?ooo`03
0000003oool0oooo00<0000000<0oooo0000000000000P00000:0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0
oooo000D0?ooo`090?oo_`1d0000B9cO0?oOW02L_ol0oooo0=nLB000B9`0gooo02L0oooo00<00000
0?ooo`3oool01`3oool2000000060?ooo`000000oooo0000003oool000000`3oool300000080oooo
00<000000?ooo`3oool00`0000000`3oool000000?ooo`0200000080oooo0P0000040?ooo`030000
003oool000000080oooo0P0000020?ooo`<0000000<0oooo0000000000000`3oool400000080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`00
000000004`3oool200000140oooo0P0000060?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00L000000?oo
o`3oool0oooo0000003oool0000000<0oooo0P0000000`3oool0000000000004000000T0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool02@3oool001@0oooo00T0_gAd0;ooo`3oool0oknL09cOo`3oool0oono07@0M02o
ool09`3oool00`000000oooo0?ooo`060?ooo`<0000000D0oooo000000000000oooo000000040?oo
o`8000000P3oool010000000oooo0?ooo`3oool5000000030?ooo`00000000000080oooo0P000004
0?ooo`030000003oool000000080oooo0P0000020?ooo`040000003oool00000000000L0oooo00@0
00000?ooo`00000000001`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`00
000000005@3oool2000000h0oooo0P0000080?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000020?ooo`030000003oool0000000P00000203oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`090?ooo`004`3oool02@3ogi`0W;oo0?ooo`3ooml0W7BL0=ooo`3oool0omnL04Qd
_`0X0?ooo`030000003oool0oooo00H0oooo0`0000001@3oool000000000003oool0000000<0oooo
0`0000000`3oool00000000000020?ooo`<000000P3oool010000000oooo0?ooo`0000020?ooo`80
0000103oool3000000<0oooo00D000000?ooo`3oool000000?ooo`02000000L0oooo100000070?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P00000G0?ooo`8000002`3oool0
0`000000oooo0?ooo`090?ooo`L000000`3oool00`000000oooo0?ooo`050?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`<000000`3oool;000000030?ooo`00
00000000008000001`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`004`3oool02@3o_i`0W=oo0?ooo`2o
M000M;oo0?ooo`3OW4P0001d0;ooo`0X0?ooo`030000003oool0oooo00H0oooo10000000103oool0
00000?ooo`0000030?ooo`D000000P3oool400000080oooo100000020?ooo`8000001@3oool30000
0080oooo00@000000?ooo`3oool0oooo0`0000070?ooo`040000003oool00000000000P0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`02000001T0oooo0P0000080?ooo`030000
003oool0oooo00T0oooo0`0000040?ooo`@00000203oool8000000<0oooo0`0000000`3oool00000
0000000300000080oooo00<000000?ooo`0000000P0000020?ooo`@0000000<0oooo0000003oool0
1P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`090?ooo`004`3oool0103ookl0M0000000001d_ol]0?ooo`030000
003oool0oooo00H0oooo10000000103oool000000?ooo`0000030?ooo`80000000X0oooo00000000
0000oooo0000003oool000000?ooo`000000oooo1P000000103oool000000?ooo`0000040?ooo`<0
00000P3oool010000000oooo0?ooo`3oool3000000L0oooo00@000000?ooo`0000000000203oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo008000006`3oool2000000D0oooo00<0
00000?ooo`3oool0203oool2000000<0oooo00<000000?ooo`3oool00`3oool3000000L0oooo00@0
00000?ooo`3oool000000`3oool2000000040?ooo`0000000000000000@0oooo0`000000103oool0
00000000003oool3000000<0oooo0P000000103oool000000000000000060?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00T0oooo00140?ooo`030000003oool0oooo00H0oooo10000000103oool000000?ooo`000003
0?ooo`@000000P3oool010000000oooo0000003oool200000080oooo0P0000000`3oool000000000
00020?ooo`030000003oool0oooo0080oooo0`0000020?ooo`030000003oool0oooo00D000001P3o
ool010000000oooo0000000000080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00P00000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool2000000D0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000050?ooo`050000003oool00000
0?ooo`000000103oool200000080oooo00@000000?ooo`3oool0oooo0P0000001@3oool000000000
00000000oooo0080000000<0oooo0000000000000`3oool2000000030?ooo`000000000000H0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool01P3oool4000000040?ooo`00
0000oooo000000<0oooo100000001`3oool000000?ooo`3oool000000?ooo`000000103oool40000
0080oooo00@000000?ooo`3oool0oooo100000020?ooo`80000000<0oooo0000003oool00`000006
0?ooo`030000003oool00000008000001`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo008000007P3oool2000000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`02000000H0oooo00<000000?ooo`000000103oool2000000050?ooo`00000000000000003o
ool00P0000000`3oool00000000000030?ooo`80000000@0oooo00000000000000001@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`090?ooo`005`3oool01P3o_g@00000000000000000001d0;ooobL0oooo00<00000
0?ooo`3oool01P3oool4000000040?ooo`000000oooo000000<0oooo100000001`3oool000000?oo
o`3oool000000?ooo`000000103oool400000080oooo00@000000?ooo`3oool0oooo100000030?oo
o`8000000P3oool3000000L0oooo0P0000000`3oool000000?ooo`060?ooo`030000003oool0oooo
00H0oooo100000000`3oool000000?ooo`030?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0200000200oooo0P0000070?ooo`030000003oool0
oooo00L0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0000000<0oooo0P00
00050?ooo`@000000`3oool00`000000oooo000000020?ooo`80000000<0oooo0000003oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool00000008000001@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`090?ooo`003`3oool01P2oW9`0gooo0?ooo`3oool0omnL04P000<0000000@004RL0=ooo`3ookl0
M7Bo:03oool00`000000oooo0?ooo`060?ooo`@0000000<0oooo000000000000103oool400000004
0?ooo`000000oooo0?ooo`<000000`3oool3000000030?ooo`00000000000080oooo00<000000?oo
o`3oool00P0000000`3oool000000?ooo`020?ooo`80000000<0oooo0000000000000P0000070?oo
o`80000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`040?ooo`8000000P3oool30000
00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo000000050?ooo`030000003oool0oooo
008000008@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo00000002
000000<0oooo00<000000?ooo`0000000P3oool010000000oooo0000000000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P0000050?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo000>
0?ooo`030?oog`2LB000000000<0000000<007Bo0?ooo`3oool00P3oool00`3o_g@0001d0;ooo`0J
0?ooo`040;md00000000000007Boo`X0oooo00<000000?ooo`3oool01P3oool4000000030?ooo`00
0000000000<0oooo0`0000000`3oool00000000000020?ooo`@000000`3oool3000000030?ooo`00
000000000080oooo00<000000?ooo`3oool0100000030?ooo`80000000H0oooo0000000000000000
0?ooo`0000060?ooo`80000000<0oooo0000000000001`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0000000D0oooo00<000000?ooo`3oool00P00000P0?ooo`8000001@3oool00`000000
oooo0?ooo`0:0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool00P3oool20000
00@0oooo00D000000?ooo`000000oooo000000030?ooo`8000000P3oool5000000<0oooo0P000003
0?ooo`030000003oool0oooo00<00000103oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`003P3oool00`3o
okl0M00004RLg`0T0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO2@3oool00`000000oooo0?oo
o`060?ooo`80000000<0oooo0000003oool00P0000030?ooo`<0000000<0oooo0000000000000P3o
ool4000000<0oooo1P0000020?ooo`030000003oool0oooo00@000000`3oool2000000060?ooo`00
000000000000003oool000001P3oool00`000000oooo0?ooo`02000000L0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0000000D0oooo00D000000?ooo`000000oooo0000000P0?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0
000000<0oooo0P0000040?ooo`030000003oool00000008000000P3oool00`000000oooo00000002
0?ooo`D00000103oool010000000oooo0?ooo`3oool2000000040?ooo`000000oooo000000@0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool02@3oool003@0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cO
o`080?ooo`030000003oool0oooo00H0oooo0P0000000`3oool000000?ooo`02000000<0oooo0`00
00000`3oool00000000000020?ooo`040000003oool00000000000<0oooo00<000000?ooo`000000
0P000000103oool000000?ooo`0000020?ooo`@000000`3oool2000000060?ooo`000000oooo0000
003oool000001P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0000000D0oooo00D000000?ooo`000000oooo0000000P0?ooo`060000003oool0oooo0000003o
ool000003P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000<0oooo0P000004
0?ooo`0:0000003oool000000000003oool000000?ooo`000000oooo00000080oooo1@0000040?oo
o`040000003oool0oooo0?ooo`80000000@0oooo0000000000000000103oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`090?ooo`005P3oool01P3ogi`0B000000000000000001809cOoaP0oooo00<0oooO09a80018W=l0
0P3oool0103ooml0W4P00018W03Oool70?ooo`030000003oool0oooo00H0oooo0P0000000`3oool0
00000?ooo`02000000<0oooo0`0000000`3oool00000000000020?ooo`040000003oool000000000
00<0oooo00<000000?ooo`0000000P000000103oool000000?ooo`0000020?ooo`040000003oool0
0000000000<0oooo0P0000000`3oool000000?ooo`03000000H0oooo00D000000?ooo`3oool0oooo
000000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool2000000<0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool02P3oool00`000000oooo000000050?ooo`050000003oool000000?ooo`00
0000803oool010000000oooo0?ooo`3oool2000000h0oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo000000030?ooo`800000103oool02P000000oooo000000000000oooo0000003oool0
00000?ooo`0000020?ooo`D00000103oool010000000oooo0?ooo`3oool2000000040?ooo`000000
0000000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool02@3oool001D0oooo00<0_g@00000001d_ol00P3oool0
0`3ooml0W7BL0=ooo`0G0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol01`3oool0
0`000000oooo0?ooo`060?ooo`80000000<0oooo0000003oool00P0000030?ooo`<0000000<0oooo
0000000000000P3oool010000000oooo0000000000030?ooo`030000003oool000000080000000@0
oooo0000003oool000000P3oool010000000oooo0000000000030?ooo`80000000<0oooo0000003o
ool00`0000060?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00D0oooo0P0000030?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`0000001@3oool01@000000oooo0000003oool000000200oooo00<000000?ooo`3oool04@3oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0000000<0oooo0P0000030?ooo`8000000P3o
ool01`000000oooo0000003oool000000?ooo`0000000P3oool4000000D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo00000002000000@0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool001@0oooo
00<0gia804RLg`3oool0103oool00`3OW9`0_ooo0?ooo`0G0?ooo`030;md0000B9`0gooo0080oooo
00<0omnL04P00018W=l01`3ooooo0000068000002`3oool001<0oooo00<0omnL07BLg`3oool0103o
ool00`3ooml0W7BL0=ooo`0H0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l01`3o
ool00`000000oooo0?ooo`060?ooo`80000000<0oooo0000003oool00P0000030?ooo`<0000000<0
oooo0000000000000P3oool010000000oooo0000000000030?ooo`030000003oool0000000800000
00@0oooo0000003oool000000P3oool010000000oooo0000000000030?ooo`80000000<0oooo0000
003oool00`0000060?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00D0oooo0P0000030?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`0000001@3oool01@000000oooo0000003oool000000200oooo00<000000?ooo`3oool04@3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0000000<0oooo0P0000040?ooo`0:0000
003oool000000000003oool000000?ooo`000000oooo00000080oooo100000050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000000P0000040?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo000C
0?ooo`030?noW02Lgol0oooo00<0oooo00<0oooO09a8001d_ol06@3oool00`3ogi`0B00004RLg`03
0?ooo`030;md0000B9`0gooo00H0oooo00<000000?ooo`3oool01P3oool2000000030?ooo`000000
oooo008000000`3oool3000000030?ooo`00000000000080oooo00@000000?ooo`00000000000`3o
ool00`000000oooo00000002000000040?ooo`000000oooo00000080oooo00@000000?ooo`000000
00000`3oool2000000060?ooo`000000oooo0000003oool000001P3oool01@000000oooo0?ooo`3o
ool0000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`8000000`3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000D0oooo00D000000?ooo`000000oooo
0000000P0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool000001@3oool00`000000
oooo000000030?ooo`800000103oool02P000000oooo000000000000oooo0000003oool000000?oo
o`0000020?ooo`D00000103oool010000000oooo0?ooo`3oool2000000040?ooo`00000000000000
00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool02@3oool001<0oooo00<0omnL04Qd_`3oool00P3oool00`3OW4P0
000004RLg`0J0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool01P3oool00`00
0000oooo0?ooo`060?ooo`@0000000<0oooo0000000000000`3oool3000000030?ooo`0000000000
0080oooo100000030?ooo`030000003oool000000080000000@0oooo0000003oool000000P3oool4
000000<0oooo0P0000001P3oool000000?ooo`000000oooo000000H0oooo00D000000?ooo`3oool0
oooo000000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool2000000<0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool02P3oool00`000000oooo000000050?ooo`050000003oool000000?oo
o`000000803oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo000000D0oooo0`000003
0?ooo`800000103oool00`000000oooo00000003000000040?ooo`000000oooo00000080oooo1@00
00040?ooo`040000003oool0oooo0?ooo`80000000@0oooo0000003oool00000103oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`090?ooo`00503oool01P3o_g@0000000000000000004RL0=oooa`0oooo00<0omnL04P0
001d_ol00P3oool00`3OW4P007Bo0?ooo`060?ooo`030000003oool0oooo00H0oooo100000000`3o
ool00000000000030?ooo`<0000000<0oooo0000000000000P3oool4000000<0oooo1P0000020?oo
o`030000003oool0oooo00@000000`3oool2000000060?ooo`00000000000000003oool000001P3o
ool2000000030?ooo`000000000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`8000000`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000D0oooo00D0
00000?ooo`000000oooo0000000P0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool0
00002`3oool2000000@0oooo00D000000?ooo`000000oooo000000030?ooo`8000000P3oool50000
00<0oooo0P0000030?ooo`80000000@0oooo0000000000000000103oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`09
0?ooo`00=`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`L0oooo00<000000?ooo`3oool01P3o
ool4000000030?ooo`000000000000<0oooo0`0000000`3oool00000000000020?ooo`@000000`3o
ool3000000030?ooo`00000000000080oooo00<000000?ooo`3oool0100000030?ooo`80000000<0
oooo0000000000000P0000070?ooo`80000000<0oooo0000003oool01`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0200000200oooo00<000000?ooo`3oool0
4@3oool010000000oooo0?ooo`00000;0?ooo`8000001@3oool4000000<0oooo00@000000?ooo`00
0000oooo1@0000030?ooo`8000000`3oool00`000000oooo0?ooo`02000000D0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02@3oool003P0oooo00@0gia800000000000007Bo203oool00`000000oooo0?ooo`060?oo
o`@0000000<0oooo000000000000103oool4000000070?ooo`000000oooo0?ooo`000000oooo0000
00030?ooo`<0000000D0oooo000000000000oooo000000030?ooo`@000000`3oool2000000030?oo
o`0000000000008000001`3oool2000000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`800000103oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00P00000Q0?ooo`030000003oool0oooo00l0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`8000001P3oool00`000000oooo000000030?oo
o`<000000P3oool4000000<0oooo0P0000030?ooo`030000003oool0oooo008000001@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`090?ooo`005P3oool01P3ogi`0B000000000000000001809cOobP0oooo00<00000
0?ooo`3oool01P3oool4000000030?ooo`000000000000@0oooo100000001`3oool000000?ooo`3o
ool000000?ooo`000000103oool2000000050?ooo`00000000000?ooo`000000103oool3000000<0
oooo00<000000?ooo`000000100000070?ooo`80000000<0oooo0000003oool01P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0200000240oooo00<000000?oo
o`3oool03`3oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`0000001@3oool0
0`000000oooo000000040?ooo`H0000000<0oooo0000000000000P3oool200000080oooo0P000000
103oool000000000000000050?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo000D0?ooo`040?oog`2LB000
04RL0=ooo`80oooo00<0okmd0018W03Oool09`3oool00`000000oooo0?ooo`060?ooo`@0000000@0
oooo0000003oool000000`3oool3000000080?ooo`000000oooo0000003oool000000?ooo`000004
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool300000080oooo00<0
00000?ooo`3oool01@0000060?ooo`030000003oool0oooo008000001`3oool00`000000oooo0?oo
o`050?ooo`040000003oool0oooo0?ooo`8000001@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00P00000Q0?ooo`030000003oool0oooo00l0
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000003oool0000000D0oooo00<000000?oo
o`0000001@3oool00`000000oooo0?ooo`02000000040?ooo`00000000000?ooo`8000000`3oool2
000000040?ooo`0000000000000000D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool001@0oooo00<0_gA8
09cOo`3oool00`3oool00`3ooml0W4Qd0;ooo`0W0?ooo`030000003oool0oooo00H0oooo10000000
103oool000000?ooo`0000030?ooo`80000000T0oooo000000000000oooo0000003oool000000?oo
o`0000000`3oool2000000030?ooo`00000000000080oooo00<000000?ooo`3oool00P3oool30000
0080oooo00<000000?ooo`3oool00P0000000`3oool00000000000060?ooo`040000003oool0oooo
000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02000000D0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool02P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo008000008P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203o
ool00`000000oooo000000040?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`000000
1@000000103oool000000?ooo`3oool2000000040?ooo`0000000000000000H0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02@3oool001<0oooo00<0omnL09boo`3oool0103oool00`3ogi`0B7Bo0?ooo`0W0?ooo`03
0000003oool0oooo00H0oooo10000000103oool000000?ooo`0000030?ooo`80000000H0oooo0000
00000000oooo0000003oool300000080oooo1P0000000`3oool000000?ooo`030?ooo`@000000P3o
ool010000000oooo0?ooo`3oool4000000H0oooo00<000000?ooo`3oool00P0000070?ooo`030000
003oool0oooo00L0oooo0`0000050?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0200000280oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000103oool01@00
0000oooo0?ooo`3oool0000000D0oooo0P0000020?ooo`030000003oool00000008000000P3oool3
000000040?ooo`0000000000000000H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool001<0oooo00<0oknL
09cOo`3oool00`3oool00`3ogi`0B4RL0=ooo`0X0?ooo`030000003oool0oooo00H0oooo0`000000
0`3oool000000?ooo`02000000<0oooo100000001@3oool000000?ooo`000000oooo008000000P3o
ool400000080oooo0P0000040?ooo`<000000`3oool00`000000oooo0?ooo`04000000L0oooo00<0
00000?ooo`0000000P0000070?ooo`030000003oool0oooo00L0oooo0`0000050?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00X0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0200000280oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool200000080oooo00<000000?ooo`3oool0100000020?ooo`D000001P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`090?ooo`004`3oool0103ookl0M0000000001d_ol]0?ooo`030000003oool0oooo00H0
oooo0`0000000`3oool000000?ooo`02000000<0oooo1P0000020?ooo`<000000P3oool200000004
0?ooo`000000oooo0?ooo`800000103oool3000000<0oooo00<000000?ooo`3oool0100000060?oo
o`060000003oool0oooo0000003oool000001`3oool00`000000oooo0?ooo`070?ooo`8000001P3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0P00000S0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`<0000000@0oooo0000
00000000oooo0P0000070?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
00H0oooo0P000000103oool000000000003oool2000000@0oooo0`0000000`3oool000000?ooo`02
0?ooo`80000000<0oooo0000000000000`0000020?ooo`800000103oool01P000000oooo00000000
0000oooo000000<0oooo00<000000?ooo`0000001`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool010000000oooo0000000000050?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`02
000002<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`80000000<0oooo0000003oool00P00
00000`3oool00000000000080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0
oooo00H0oooo1@0000000`3oool00000000000040?ooo`L000000P3oool6000000030?ooo`000000
oooo00800000103oool4000000050?ooo`000000oooo0?ooo`0000000P3oool2000000H0oooo00<0
00000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000002<0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool0
00001@3oool010000000oooo00000000000T0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0P0000070?oo
o`070000003oool0oooo0?ooo`000000oooo000000040?ooo`030000003oool0000000H00000203o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`090?ooo`004`3oool00`3ookl0W9cO0?ooo`030?ooo`040?noM0000000
001d0;ooobL0oooo00<000000?ooo`3oool01`3oool4000000040?ooo`000000oooo000000<0oooo
00<000000?ooo`0000000`0000000`3oool000000000000200000080oooo00<000000?ooo`3oool0
0P0000020?ooo`030000003oool0oooo00@0000000<0oooo0000000000000P3oool00`000000oooo
00000002000000H0oooo0`0000050?ooo`050000003oool0oooo0?ooo`000000203oool2000000@0
oooo00@000000?ooo`3oool000008P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00@0oooo0P00000;0?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`00
000U0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool010000000oooo0?oo
o`0000030?ooo`040000003oool0oooo0?ooo`8000000P3oool010000000oooo0000000000090?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00T0oooo000C0?ooo`040?oo_`2LW=l0oono07@000@0000000<004RL0=oo
o`3oool09P3oool2000000P0oooo100000020?ooo`8000000`3oool010000000oooo0000003oool9
000000<0oooo00H000000?ooo`3oool0oooo0000003oool400000080oooo00L000000?ooo`3oool0
00000?ooo`000000oooo00<00000103oool00`000000oooo000000070?ooo`040000003oool0oooo
000000H0oooo0`0000060?ooo`030000003oool000000280oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`040?ooo`800000303oool010000000oooo0?ooo`0000040?ooo`040000003o
ool0oooo000002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000070?ooo`030000
003oool0000000@0oooo00<000000?ooo`0000000P3oool4000000/0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo0`00000;0?ooo`004`3o
ool02@3ogi`0B0000000000004P0W=oo0?ooo`3ooml0W4Qd0;ooo`0X0?ooo`030000003oool0oooo
00L0oooo00H000000?ooo`000000oooo0000003oool2000000<0oooo00<000000?ooo`0000000P3o
ool300000080oooo0`0000020?ooo`030000003oool0000000<0oooo1@0000001@3oool000000000
003oool000000080oooo0P000000103oool000000?ooo`0000030?ooo`8000002@3oool3000000D0
oooo0P0000090?ooo`8000008@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0
oooo0P00000<0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P00000V0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`040?oo
o`8000000P3oool3000000`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool000l0oooo00@0oooO09a80000
07@0_ooo<@3oool00`000000oooo0?ooo`070?ooo`<0000000H0oooo0000003oool000000?ooo`00
00030?ooo`030000003oool000000080oooo1@000000103oool000000000000000030?ooo`050000
003oool000000000003oool00`0000000`3oool0000000000002000000060?ooo`000000oooo0000
003oool000000P3oool010000000oooo0?ooo`00000;0?ooo`P000002P3oool010000000oooo0000
0000000O0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool2000000`0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`02000002H0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`000000103oool01@00
0000oooo0?ooo`3oool0000000L0oooo0P0000050?ooo`030000003oool00000008000003@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`080?ooo`80000000H0oooo0000
003oool000000?ooo`0000030?ooo`030000003oool0000000D0oooo1P0000030?ooo`<0000000@0
oooo000000000000oooo0P0000000`3oool0000000000003000000050?ooo`000000oooo0?ooo`00
00000P3oool3000000/0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`040000003oool0oooo
0?ooo`800000703oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo0P00000<
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02000002L0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00800000
0P3oool010000000oooo00000000000?0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo000C0?ooo`050?oO
_`2ogol0oooo0?ooo`2oM0000`0000000`0007@0_ooo0?ooo`0V0?ooo`030000003oool0oooo00P0
oooo0P0000020?ooo`8000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00@0oooo0P0000020?ooo`<000000P3oool900000080oooo100000020?ooo`H000002`3oool40000
00h0oooo00<000000?ooo`3oool00`3oool2000001X0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`020?ooo`800000303oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00P00000X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`0000000`3o
ool2000000H0oooo0P0000020?ooo`030000003oool0oooo00<0oooo1000000A0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00T0oooo000C0?ooo`030;md0000000000000080000000D0001d0;ooo`3oool0_ibL0=oo
o`0W0?ooo`030000003oool0oooo00P0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0000000L0oooo0P000000
1@3oool000000000003oool000000080oooo00D000000?ooo`3oool000000?ooo`03000000050?oo
o`000000oooo0000003oool01P0000000`3oool000000000000300000100oooo00<000000?ooo`3o
ool01P3oool2000001L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`80
0000303oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`0000000000:@3oool2
000001<0oooo0P0000020?ooo`030000003oool0oooo00P0oooo0P0000030?ooo`<000005@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`090?ooo`004@3oool01@2oM000000000000000B9`0gooo00<0oooo00<0oooO
09a8001d_ol00P3oool00`2oM00004RL0=ooo`0S0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`0000000P3oool200000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0000000L0oooo100000000`3oool00000000000020?ooo`040000003oool0
oooo000000<0oooo0P0000020?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo
0000000A0?ooo`030000003oool0oooo00P0oooo1000000C0?ooo`030000003oool0oooo0140oooo
00@000000?ooo`3oool0oooo0P00000<0?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`02000002P0oooo0`00000C0?ooo`<000002P3oool2000000040?ooo`0000000000
000001P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool02@3oool001<0oooo00<0oknL09cOo`3oool0203oool00`3o
gi`0B7Bo0?ooo`0S0?ooo`030000003oool0oooo00T0oooo0P0000020?ooo`8000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000001@3oool2
000000030?ooo`00000000000080oooo2P0000001@3oool000000?ooo`3oool0000000/0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?ooo`800000403oool00`000000oooo0?oo
o`0B0?ooo`040000003oool0oooo0?ooo`800000303oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000000P3oool2000002H0oooo0P0000030?ooo`800000403oool010000000
oooo0000003oool3000000@0oooo0`00000N0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo000C0?ooo`03
0?oo_`1dM;l0oooo00L0oooo00<0okmd0018W03Oool0903oool00`000000oooo0?ooo`090?ooo`<0
00000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000000@0oooo100000020?ooo`<000000`3oool00`000000oooo0?oo
o`040?ooo`800000303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo1000
000<0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P00000<0?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`8000009@3oool00`000000oooo
0?ooo`050?ooo`8000003P3oool2000000D0oooo1000000Q0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo
000C0?ooo`040?oOW0180000001d0;ooo`D0oooo00<0gia8001d_`3oool09@3oool00`000000oooo
0?ooo`090?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0000000<0oooo0000003oool00`0000050?ooo`030000
003oool0oooo00@0oooo0P00000;0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
4`3oool<000001L0oooo00D000000?ooo`000000oooo0000000;0?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000020?ooo`8000008`3oool2000000X0oooo0P0000090?oo
o`@00000:P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`090?ooo`00503oool00`3ogi`0B0000000000500000003
04RLg`3oool0oooo02D0oooo00<000000?ooo`3oool02P3oool300000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`D0
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01d0oooo1`00000B0?ooo`05
0000003oool000000?ooo`000000303oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0<0?ooo`T000000P3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo000I0?ooo`030?noM00004P0W=oo
02P0oooo00<000000?ooo`3oool02P3oool300000080oooo00<000000?ooo`3oool00P3oool20000
00H0oooo00@000000?ooo`3oool00000103oool4000000<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`050?ooo`8000002P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0103oool8000000/0oooo0P0000000`3oool000000?ooo`0;
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0N0?ooo`8000006P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo000H
0?ooo`030;md0000M;l0oooo02T0oooo00<000000?ooo`3oool02`3oool3000000030?ooo`000000
000000@0oooo00<000000?ooo`3oool01@3oool8000000030?ooo`000000oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000T0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00d0oooo2@000003
0?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00030?ooo`8000007@3oool2000001/0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`090?ooo`004`3oool01P3ogi`0B00007Boo`3o_g@0000007Boob/0oooo00<000000?ooo`3oool0
2`3oool300000080oooo00<000000?ooo`3oool00`3oool2000000P0oooo00@000000?ooo`000000
00000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01@3oool01000
0000oooo0?ooo`0000080?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0G0?ooo`T000002@3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo00000080oooo0P00000I0?ooo`@000007@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00T0oooo000C0?ooo`040?oOW01800000000001d_bd0oooo00<000000?ooo`3oool0303o
ool3000000030?ooo`000000000000@0oooo00@000000?ooo`0000000000103oool500000080oooo
00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3o
ool0oooo000000070?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0000000<0oooo400000020?ooo`030000003oool0oooo
008000005P3oool300000200oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?oo
o`00A03oool00`000000oooo0?ooo`0<0?ooo`@0000000@0oooo00000000000000000P3oool01000
0000oooo0?ooo`3oool400000080oooo0P0000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0703oool010000000oooo00000000000;0?ooo`030000003oool0oooo00<0oooo3@00
00050?ooo``000008`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo0014
0?ooo`030000003oool0oooo00d0oooo0P0000000`3oool00000000000020?ooo`80000000<0oooo
0000003oool01@3oool400000080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo008000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool00`3oool5000002h0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`090?ooo`00A03oool2000000h0oooo0`0000000`3oool000000?ooo`030?ooo`P0000000H0oooo
0000003oool000000?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo00H000000?ooo`3oool000000?ooo`00000:
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo0`00000;0?ooo`00A03oool00`000000oooo0?ooo`0>0?oo
o`8000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo01h0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool004@0oooo00<0
00000?ooo`3oool03P3oool010000000oooo0000003oool3000000<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000403oool00`000000
oooo0?ooo`0K0?ooo`8000008@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo000000030?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000
oooo0?ooo`0?0?ooo`060000003oool000000?ooo`000000oooo200000030?ooo`060000003oool0
oooo0000003oool000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0240oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0403oool5000000@0oooo
00<000000?ooo`3oool00P3oool2000000<0oooo0P0000060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0203oool00`000000oooo0000000?0?ooo`030000003oool0oooo01T0oooo
0P00000T0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo0P0000030?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0B0?ooo`030000
003oool00000008000000P3oool00`000000oooo0?ooo`02000000D0oooo0P0000050?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`02000000`0oooo
00<000000?ooo`3oool0603oool2000002H0oooo00D000000?ooo`3oool0oooo000000050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo000000020?ooo`80
0000<`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00140?ooo`030000
003oool0oooo01<0oooo00@000000?ooo`000000oooo1@0000060?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
02H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01@3oool2000000<0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01<0oooo0P0000000`3o
ool000000?ooo`030?ooo`030000003oool0oooo0080oooo0P0000030?ooo`040000003oool0oooo
000000P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`8000001`3oool0
0`000000oooo0?ooo`0G0?ooo`800000:@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`8000000`3oool200000300oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0D
0?ooo`@00000103oool4000000H0oooo0P0000080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo0P00000[
0?ooo`050000003oool0oooo0?ooo`000000203oool2000000<0oooo00<000000?ooo`3oool01@3o
ool010000000oooo0?ooo`3oool2000002l0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0E0?ooo`L0000000<0oooo0000003oool01P3o
ool00`000000oooo000000070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3o
ool2000000<0oooo00<000000?ooo`3oool0503oool2000002d0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000L0oooo0P0000030?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`00A03o
ool00`000000oooo0?ooo`0G0?ooo`<00000103oool00`000000oooo0?ooo`030?ooo`050000003o
ool0oooo0?ooo`000000103oool2000000/0oooo00<000000?ooo`3oool03@3oool3000001@0oooo
0`00000_0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo
000000080?ooo`040000003oool0oooo0?ooo`800000;03oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01T0oooo0`0000020?ooo`H00000
1@3oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo00h0oooo0P0000000`3oool0
000000000002000000/0oooo1@00000b0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02@3oool3000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0
6P3oool6000000X0oooo0P00000<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
1@3oool;000003L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`800000
1`3oool010000000oooo0?ooo`3oool2000002P0oooo0P00000c0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0
oooo00140?ooo`030000003oool0oooo01`0oooo0P0000020?ooo`8000001`3oool3000000X0oooo
0P00000?0?ooo`800000BP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo
00@000000?ooo`00000000001@3oool200000080oooo0P00000W0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool07P3oool;000000<0oooo
0P0000060?ooo`800000403oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`02000000<0oooo0P0000030?ooo`800000
903oool2000003H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool08`3o
ool3000000P0oooo0P0000020?ooo`8000003`3oool3000004d0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo0`0000000`3oool000000000
00020?ooo`8000008P3oool2000003L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool09P3oool3000000H0oooo1000000>0?ooo`800000D03oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool400000080oooo0P00000O
0?ooo`800000>@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`00A03oool2000002X0oooo1P0000040?oo
o`800000203oool400000580oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`0000001000000M0?ooo`800000>P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool30000
00/0oooo00140?ooo`030000003oool0oooo03D0oooo2000001F0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
00006P3oool2000003`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0
T`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0?ooo`000000oooo00T000003@3oool6000003d0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`3oool200000003
0?ooo`000000oooo00D0oooo3@0000130?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00140?ooo`030000
003oool0oooo09<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00H0oooo00@000000?ooo`3oool0oooo0`00001E0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0000001D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00@0
00000?ooo`3oool0oooo0`00001D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003o
ool0oooo09<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool300000580oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
00000580oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`020?ooo`<00000D03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000
oooo0?ooo`2C0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000D03oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`00=03oool00`3OW4P00000000000030000000304RLg`3oool0oooo00L0oooo
00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000004h0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool003D0oooo00<0okmd001d_`3oool00P3oool00`2oM7@0_ooo0?oo
o`070?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool010000000oooo0000
0000001=0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo000f0?ooo`030?noM000M;l0oooo00/0oooo00<0
00000?ooo`3oool0T`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`040000003oool00000000004/0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool003L0oooo00<0okmd001d_`3oool02P3oool00`000000oooo0?oo
o`2C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000190?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo000h0?ooo`030?noM018W=l0oooo00T0oooo00<000000?ooo`3oool0T`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`000000B03oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`00>@3oool00`3OW4P0B9cO0?ooo`080?ooo`<00000T`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`030?ooo`060000003oool0oooo0000003oool00000AP3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool3000000/0oooo000j0?ooo`030;md
001d_ol0oooo00L0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`060000
003oool0oooo0000003oool00000A03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`00>P3oool00`3ogi`0
B01d0;ooo`070?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool003X0
oooo00<0oooO09a8001d_ol01`3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00T0oooo000j0?ooo`030?oo_`1d0000B9cO00L0oooo00<000000?ooo`3oool0T`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool2000003d0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02@3oool003H0oooo00L0okmd0018W03Oool0oooo0=nLB00004P0W=oo00L0oooo00<00000
0?ooo`3oool0T`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo000g0?ooo`050?oOW0180000
00000000001d_ol0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000003P0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`050000003o
ool0oooo0?ooo`0000001@3oool2000003D0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool004@0oooo00<0
00000?ooo`3oool0T`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000
1P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003o
ool0oooo09<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`2C0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`800000;P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`00A03oool00`00
0000oooo0?ooo`2C0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`050?ooo`800000:`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000
oooo0?ooo`2C0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`060?ooo`8000009`3oool2000001l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
0`00000S0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo0`00
000M0?ooo`<00000803oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool2000001L0oooo1000000S
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`09
0?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`@00000403oool3000002H0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo00140?ooo`80
0000U03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0403oool@000002T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`<0
00002`3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo0P0000160?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000
oooo0?ooo`2C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool200000400
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0
oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo0014
0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`800000>@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3o
ool0T`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo0P00000d0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`00
A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
2@3oool200000340oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0
oooo09<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`800000;03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02@3oool0
04@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00/0oooo0P00000X0?ooo`8000005`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0<0?ooo`800000903oool2000001P0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`090?ooo`00A03oool2000009@0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0=0?ooo`<000007P3oool3000001T0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0403oool3000000/0oooo
00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0?0?ooo`<000006@3oool2000001`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`090?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool04@3oool3000001<0oooo0`00000M0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01<0oooo0`00000=0?ooo`<000007`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0E0?ooo`d000008@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
2@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`2C0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0?P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
09<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02@3oool2000003d0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0
oooo0P00000j0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02@3oool004@0oooo
00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`800000=`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=
0?ooo`800000<P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo09<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3o
ool0T`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool02P3oool2000000l0oooo0P00000/0?ooo`8000005@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`090?ooo`00
A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo0P00000Y0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02@0oooo0P00000F0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00T0oooo00140?ooo`800000U03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`8000008P3oool2
000001L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01D0oooo0`00000;0?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0100oooo0P00000N0?ooo`800000603oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000
oooo0?ooo`2C0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0140oooo0`00000H0?ooo`<000006P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01<0oooo
1000000A0?ooo`<00000703oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?oo
o`2C0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0<0?ooo`8000005`3ooolA000001h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool0T`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo09<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`090?oo
o`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool2000003d0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
2@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo0P00000h0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00T0oooo000g0?ooo`030?oog`2LB000B9cO00X0oooo00<000000?ooo`3oool0T`3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0403oool20000
03D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool02@3oool003P0oooo00<0gia80018W03Oool02@3oool00`000000
oooo0?ooo`2C0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0300oooo0P00000B0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`090?ooo`00>03oool00`3ogi`0B018
09cOo`090?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`090?ooo`00=03oool00`3o_g@0000000000004000000030018W03Oool0oooo00H0oooo00<0
00000?ooo`3oool0T`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool04@3oool2000002d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02@3oool003@0oooo00<0oooO
09a8B02Lgol00P3oool00`2oM00007Bo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0:03oool2000001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo00T0oooo000e0?ooo`070?oo_`1d07@0_ooo0?ooo`3o_g@004RL0=oo
o`080?ooo`<00000T`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00l0oooo0P00
000C0?ooo`8000009P3oool2000001D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0M0?ooo`<000002`3oool003H0oooo00H0omnL04Q8W03Oool0omnL04P0B02Lgol80?ooo`030000
003oool0oooo09<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0180oooo0`00000Q0?ooo`8000005P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool02@3oool003L0oooo00D0okmd001d_`3ooml0W4P0
04RLg`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo01@0oooo0`00000L0?ooo`800000603oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool02@3oool003P0oooo00@0
gia804RLg`2oM00007Bo203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0F0?ooo`8000005`3oool3000001T0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00T0oooo
000i0?ooo`040=nLB01dM7@0001d0;ooo`L0oooo00<000000?ooo`3oool0T`3oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05`3oool5000000h0oooo
1000000K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`090?ooo`00>P3oool00`2oM000001809cOo`070?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01/0oooo3P00
000N0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`090?ooo`00>P3oool00`3ooml0W4P004RLg`070?ooo`030000003oool0oooo09<0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0@0?ooo`800000AP3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?oo
o`3oool0T`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0
T`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0140oooo0P00000o0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`090?ooo`00A03o
ool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool04P3oool2000003X0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
09<0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
03D0oooo0P00000A0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool02@3oool004@0
oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01<0
oooo0P00000d0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool0503oool200000340oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0@@3oool2000001H0oooo0P00000]0?ooo`8000004`3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0E0?ooo`800000:@3oool2000001@0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`00A03oool2000009@0oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`0F0?ooo`<00000903oool2000001D0oooo00<000000?oo
o`3oool09`3oool3000000/0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3o
ool0A@3oool2000001T0oooo0`00000O0?ooo`8000005P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0I0?ooo`<000006P3oool2000001P0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003o
ool0oooo04P0oooo0P00000L0?ooo`<000004`3oool4000001T0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0703ooolC000001`0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
04/0oooo0P00001:0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool004@0
oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo
0?ooo`2C0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0@`3oool200000340oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?oo
o`1?0?ooo`800000@P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00T0oooo0014
0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?oo
o`3oool0T`3oool00`000000oooo0?ooo`1B0?ooo`800000?@3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`1E0?ooo`800000
>03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003o
ool0oooo09<0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool0
0`000000oooo0?ooo`1H0?ooo`800000<P3oool2000003T0oooo00<000000?ooo`3oool02@3oool0
04@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`1J0?ooo`800000;P3oool20000
03/0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0T`3oool00`000000
oooo0?ooo`1L0?ooo`800000:@3oool3000003d0oooo00<000000?ooo`3oool02@3oool004@0oooo
0P00002D0?ooo`030000003oool0oooo05h0oooo0`00000T0?ooo`800000?P3oool3000000/0oooo
00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0H@3oool200000200oooo0P00
00120?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<00000
0?ooo`3oool0H`3oool4000001X0oooo0P0000140?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo09<0oooo00<000000?ooo`3oool0I`3oool400000100oooo1P0000160?oo
o`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3o
ool0J`3oool@000004`0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0
T`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003o
ool0oooo09<0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool02@3oool0
04@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo
00T0oooo00140?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0a`3oool00`000000
oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo
00140?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`090?ooo`00A03oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02@3oool004@0ooooo`00001R000000/0oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo00370?oo
o`090?oo_`1d0000000004RLg`3oool0oono07@000000000B9cO01@0oooo00<0okmd000000000000
0P0000000`00B9`0gooo0?ooo`0B0?ooo`050;md00000000000000000018W=l0[@3oool00<L0oooo
00X0oono07@0B02Lgol0_g@0001d_`3ookl0M01809cOo`2oM00007Bo4P3oool00`3o_g@0000004RL
g`030?ooo`030?oOW01804P0W=oo01<0oooo00<0oooO09a80018W=l0[P3oool00<X0oooo00<0oono
07@0001d_ol00P3oool00`3ookl0M00007Boo`0A0?ooo`030?noM00007@0_ooo00@0oooo00<0gia8
001d_`3oool04`3oool00`3OW4P004RL0=ooo`2]0?ooo`00b`3oool00`3OW4P004RL0=ooo`020?oo
o`030=nLB000B9`0gooo0140oooo00P0_g@00000M02oool0oooo0?oog`2LB000000004RLga@0oooo
00<0omnL04P0M02oool0[@3oool00;@0oooo00<0_g@00000000000001@0000000`00B9`0gooo0?oo
o`030?ooo`0<0?oOW018000000000018W03Oool0_g@000000000M;l0oooo0?noM00004P0W=oo0P3o
ool00`3o_g@0001809cOo`030?ooo`080;md00000000001809cOo`3oool0gia80018W03Oool20?oo
o`030;md0000000007Bo0080oooo00H0oono07@00000000000000000M02oool50?ooo`030?noM000
0000000000L0000000T0M;oo0?ooo`3ogi`0B0000000000007@0_ono07@0001d_ol00P3oool02`3o
gi`0B00000000000B9`0gooo0;md0000000007Bo0?ooo`3ogi`0B0000080000000T0M;oo0=nLB000
000004RL0=ooo`3o_g@000000000B02Lgol00P3oool0102oM00000000000B02Lgol20?ooo`050?no
M000000000000000B02Lgol00`3oool00`3OW4P004RL0=ooo`020?ooo`030;md0000000007Bo07d0
oooo002e0?ooo`040?oo_`1d000004RL0=ooo`<0oooo00<0_g@000000000M;l00`3oool0303ogi`0
B01809cOo`3ogi`0B7Bo0;md0000M;l0oknL09cOo`3ookl0M00004RLg`80oooo00<0oono07@00018
W=l00`3oool0203OW4P004RL0=oog`2LM9`0gooo0?noM00007@0_ooo0P3oool0203OW4P004RL0=no
M01d_ol0oooo0?noM00007@0_ooo2@3oool0103ooml0W4P00018W03Oool30?ooo`0;0?oog`2LB000
04RL0=ooo`2oM00004RL0=ooo`3ookl0M01d07Ad0018W=l00P3oool0903ogi`0B01809cOo`3ogi`0
B7Bo0;md0000M;l0oknL09cOo`2oM00004RL0=ooo`3oool0_g@007AdM00007@0_mnL09boo`3o_g@0
001809cOg`2LM9`0gooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0
B000001d_`80oooo00<0okmd0000M02oool00P3oool0103OW4P004RL0=noM01d_oml0?ooo`00]P3o
ool00`3OW4P0001809cOo`040?ooo`0=0?oo_`1d000004RL0=ooo`3oool0oooO09a80018W=l0oooo
0?noM01dM7@004RL0=ooo`020?ooo`030;md0000B9`0gooo0080oooo00<0_g@00018W03Oool00P3o
ool00`3o_g@0001809cOo`020?ooo`030?oo_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol00`3o
ool00`2oM000M;oo0?ooo`090?ooo`030?noM00004P0W=oo00D0oooo00@0giad09cOo`2oM00007Bo
0P3oool0403ookl0M0000018W03Oool0oooo0?oog`2LB000B9cO0?ooo`3o_g@0M7Ad0018W03Oool0
oooo0;md0000M;l30?ooo`070;md00000000M;oo0?ooo`3ookl0M00007Boo`030?ooo`030?noM000
04P0W=oo0080oooo00<0gia80018W03Oool00P3oool01`3ogi`0B00004RLg`3oool0oono07@00018
W=l00P3oool00`3ogi`0B01809cOo`1m0?ooo`00]P3oool00`3ogi`0B00007Boo`050?ooo`030?oO
W018000007Bo0080oooo00L0_g@00018W03Oool0oooo0;md000004P0W=oo0080oooo00<0gia80000
M02oool00P3oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO0080oooo00P0oooO09a8
000007@0_ooo0?ooo`3ooml0W4P004RLg`80oooo00<0oono07@0000000000P0000000`1d_ol0oooo
0?ooo`050?ooo`030?oo_`1d0000B9cO00L0oooo00<0gia80018W03Oool00P3oool00`3o_g@0001d
0;ooo`020?ooo`0;0;md0000B9`0gooo0?ooo`2oM000001809cOo`3oool0okmd0000M02oool00P3o
ool00`3ookl0M00004RLg`020?ooo`030;md0000M;l0oooo0080oooo00<0oono07@00018W=l00P3o
ool00`3o_g@0001d0;ooo`030?ooo`0;0=nLB00007@0_ooo0?oog`2LB000001d0;ooo`3oool0oooO
09a80018W=l0O@3oool00;H0oooo00<0oono07@00000M;l01P3oool02`2oM000001809cOo`3oool0
okmd0000M02oool0oooo0?oo_`1d0000M;oo0080oooo00<0omnL04P0001d_ol00P3oool00`3ogi`0
B00007Boo`030?ooo`030;md0000B9`0gooo0080oooo00<0gia80018B018M;l00P3oool02`2oM000
07Bo0?ooo`3oool0_g@00018W03Oool0oooo0?oOW0180000B9cO00H0oooo00<0oooO09a80000M;l0
0P3oool00`3ookl0W9cO0?ooo`020?ooo`030?oOW0180000M;oo0080oooo00<0oono07@0001d_ol0
0P3oool02`3o_g@0001d0;ooo`3oool0oono07@0001d_ol0oooo0?oo_`1d0000M;oo00<0oooo00L0
_g@00018W03Oool0oooo0=nLB000B9`0gooo00<0oooo00L0_g@00018W03Oool0oooo0?oo_`1d0000
M;oo00<0oooo00L0omnL04P0B02Lgol0oooo0=nLB000B4P0B7Bo0080oooo00<0_g@0001d_`3oool0
O03oool00;L0oooo00<0_g@00018W03Oool01@3oool01`3o_g@0000004RLg`3ogml0gono07@0001d
_ol00P3oool01`2oM00007Bo0?ooo`3oool0oooO09a80018W=l00P3oool00`3ooml0W4P004RLg`03
0?ooo`030=nLB00004P0W=oo0080oooo00/0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;ooo`3o
ool0_g@0001d_`030?ooo`030=nLB00007@0_ooo00H0oooo00H0gia80000M02oool0oooo0?oOW018
M;l40?ooo`0<0;md000007@0_ooo0?ooo`3ooml0W4P004RLg`3oool0omoO0=oo_`1d0000M;oo0P3o
ool01`2oM00007Bo0?ooo`3oool0okmd0000M02oool00P3oool01`3OW4P0001d0;ooo`3oool0omnL
04P0B02Lgol00`3oool00`3OW4P0001809cOo`020?ooo`030=nLB00007@0_ooo0080oooo00`0oono
07@0001d_ol0oooo0?noM00007@0_kmd04RLg`3oool0okmd0000M02oooml0?ooo`00]`3oool00`3o
_g@0001809cOo`050?ooo`070?oOW018000007Bo0?oOW018M;l0_g@0001d_`020?ooo`030?noM000
B9`0gooo0080oooo00<0_g@00018W03Oool00P3oool00`2oM00004RL0=ooo`020?ooo`030?oOW018
0000B9cO0080oooo00`0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOo`3oool0omnL04P00018
W=l20?ooo`030=nLB00007@0_ooo00H0oooo00<0okmd0000000000000P0000000`0007@0_ooo0?oo
o`020?ooo`0<0?oog`2LB00004RL0=ooo`3ookl0W4Q80018W03Oool0omnL04Qd_`2oM00007Bo0P3o
ool00`3o_g@004RL0=ooo`020?ooo`0;0=nLB00007@0_ooo0?ooo`2oM000001809cOo`3oool0oooO
09a80018W=l00`3oool00`3ogi`0B00004RLg`030?ooo`0@0;md000007@0_ooo0?ooo`3o_g@0001d
0;ooo`3oool0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOog`0oooo002g0?ooo`030?oOW018
0000M;oo00D0oooo00L0omnL04P00000M;l0oooo0?noM000000007Bo0080oooo00D0omnL04P0B02L
gol0oono07@000030000000307Bo_`1d000000000080000000l0M;oo0?noM000000000000018W03O
ool0oono07@000000000B9cO0?ooo`3o_g@000000000B02Lgol00P3oool00`3ookl0M00000000004
0000000304RLg`3oool0oooo00<0oooo00<0oono07@0001d_ol00P3oool00`2oM4P0W=oo0?ooo`04
0?ooo`0:0=nLB0000000001d0;noM00007@0_ooo0?ooo`3o_g@00000001d_`80oooo00<0omnL04P0
B02Lgol00`3oool0203ogi`0B00000000018W9`0M00004RLg`3ookl0M0000`0000001P1d_ol0okmd
00000000000004RL0=ooo`<0oooo00l0okmd000000000000000007Boo`3oool0oono07@000000000
B9cO0?ooo`3o_g@000000000B02Lgol0O03oool00;L0oooo00<0oooO09a80000M;l01@3oool00`3o
_g@0000004RLg`0;0?ooo`030?noM00004P0W=oo0080oooo00<0okmd0000B02Lgol07`3oool01P2o
M00007Bo0?ooo`3oool0omnL07BLgal0oooo00<0okmd0000M02oool0U03oool00;P0oooo00<0_g@0
0018W03Oool00`3oool0103ooml0W4P00000M02oool;0?ooo`030?oog`2LB00007Bo0080oooo00<0
oooO09a80000M;l07`3oool00`3OW4P0001d0;ooo`040?ooo`030=nLW02oool0oooo01`0oooo00<0
giad09cOo`3oool0T`3oool00;P0oooo00<0gia80000B02Lgol00P3oool0103ookl0M0000000001d
_ol=0?ooo`030?noM00007@0_ooo0080oooo00<0okmd0000M02oool00P3oool0103ookl0M0000018
W03OoolH0?ooo`030?noM00004P0W=oo00<0oooo00<0oono07@0B02Lgol08P3oool0103ookl0M000
0018W03Ooon=0?ooo`00]`3oool00`2oM000000000000004000000030018W03Oool0oooo00h0oooo
00X0gia80018W03Ooml0W4P004RLg`3OW4P004RL0=oog`2LB000B9cO6P3oool00`2oM00000000000
00060000000307Boo`3oool0oooo0;40oooo003@0?ooo`090=nLB0000000001809cOo`3oool0gia8
0000000004P0W=oo0=L0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-3.57266, -6.76729, 0.0245698, \
0.0452557}}]
}, Closed]],

Cell["\<\
Although the limiting orbit remains quite complicated even after suppressing \
initial transients, graphical experimentation suggests that it is independent \
of initial conditions nonetheless.  However, formal proof of this hypothesis \
is beyond the scope of this presentation.\
\>", "Text"],

Cell[BoxData[
    \(\(stuff = 
        Table[duffingPlot[1, 1, 0.05, 10, 0.1, x0, v0, 200, 300, 
            MaxSteps \[Rule] 10000, PlotRange \[Rule] All, 
            PlotPoints \[Rule] 100, DisplayFunction \[Rule] Identity, 
            Frame \[Rule] False, PlotLabel \[Rule] "\< \>", 
            Axes \[Rule] False], {x0, \(-1\), 1, 1}, {v0, \(-1\), 1, 
            1}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[stuff]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0238095 0.31746 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.321429 0.321429 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.221784 0.499997 0.443846 [
[.5 1.0125 -3.5 0 ]
[.5 1.0125 3.5 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -64.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.000 15.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
.82215 .53288 m
.8226 .52671 L
.82292 .52065 L
.82319 .51315 L
.82333 .50564 L
.82335 .49835 L
.82329 .49137 L
.82312 .48349 L
.82281 .47491 L
.82237 .46612 L
.82176 .45655 L
.82026 .43913 L
.81782 .4187 L
.81499 .40081 L
.81154 .38378 L
.80786 .36947 L
.80337 .35579 L
.79813 .34382 L
.7956 .3393 L
.7928 .33511 L
.79026 .33203 L
.78754 .32939 L
.78505 .32757 L
.7823 .32616 L
.77977 .3254 L
.77741 .32515 L
.77594 .3252 L
.77439 .32543 L
.7716 .32629 L
.77006 .32699 L
.76863 .32781 L
.76538 .33018 L
.76008 .33561 L
.75459 .3433 L
.74508 .36182 L
.73751 .38181 L
.72479 .42926 L
.71765 .46704 L
.71674 .4721 L
.71591 .47623 L
.71556 .47764 L
.71522 .47879 L
.71494 .47949 L
.71464 .47995 L
.71446 .48008 L
.7143 .4801 L
.71412 .48 L
.71394 .47979 L
.71362 .47915 L
.71343 .47863 L
Mistroke
.71325 .47804 L
.71255 .47513 L
.7117 .47071 L
.70659 .44263 L
.69816 .40535 L
.6825 .35549 L
.67163 .32921 L
.65823 .30256 L
.63147 .26118 L
.5966 .21986 L
.51 .13535 L
.46065 .09042 L
.40999 .05076 L
.3829 .03511 L
.36892 .02931 L
.36089 .02684 L
.35333 .02514 L
.34561 .02411 L
.34172 .02387 L
.33748 .02385 L
.32995 .02445 L
.32297 .02579 L
.31871 .027 L
.31472 .02842 L
.30728 .03188 L
.29935 .03681 L
.29086 .04365 L
.2778 .0578 L
.26401 .07844 L
.2504 .10598 L
.23861 .13735 L
.2287 .17088 L
.22026 .20661 L
.21179 .2521 L
.20535 .297 L
.20259 .32073 L
.2 .34692 L
.19809 .36993 L
.19636 .3954 L
.19488 .42378 L
.19427 .43927 L
.19383 .45367 L
.19333 .47931 L
.19322 .50635 L
.19334 .521 L
.19356 .53434 L
.19393 .54876 L
.19446 .56374 L
.19566 .58815 L
.19741 .61376 L
Mistroke
.19934 .63526 L
.20177 .6569 L
.20436 .67568 L
.20701 .69172 L
.21321 .72049 L
.21681 .73309 L
.22084 .74448 L
.22485 .75336 L
.22875 .75995 L
.23232 .76439 L
.23624 .76763 L
.23987 .7692 L
.24386 .76941 L
.24802 .76796 L
.25188 .76511 L
.25544 .76116 L
.25863 .75653 L
.26556 .74268 L
.26914 .73328 L
.27236 .72333 L
.27912 .69682 L
.28481 .66637 L
.28735 .64912 L
.2898 .62916 L
.29311 .59321 L
.29445 .57254 L
.29539 .55274 L
.29601 .53368 L
.29633 .51604 L
.29641 .49534 L
.29621 .47555 L
.29567 .45371 L
.29469 .42951 L
.29323 .40413 L
.29146 .3804 L
.28734 .33826 L
.28155 .29404 L
.27304 .24468 L
.26335 .20138 L
.25342 .16651 L
.24145 .13398 L
.22908 .10942 L
.2218 .09882 L
.21828 .09468 L
.21497 .09137 L
.20888 .08673 L
.20214 .08383 L
.19554 .08331 L
.19185 .08404 L
.1885 .08537 L
Mistroke
.1822 .08965 L
.17645 .09568 L
.17026 .10464 L
.16386 .11685 L
.15365 .14358 L
.14821 .1622 L
.14339 .18182 L
.13835 .20616 L
.13333 .23539 L
.12936 .26326 L
.12562 .29489 L
.12247 .32782 L
.12009 .35882 L
.11818 .39081 L
.11684 .42145 L
.11628 .43868 L
.11582 .45763 L
.11552 .47739 L
.1154 .49576 L
.11559 .52827 L
.11634 .5623 L
.117 .58089 L
.11791 .6006 L
.12007 .63486 L
.12276 .6659 L
.12571 .69227 L
.12875 .71404 L
.13229 .73456 L
.13934 .76471 L
.1436 .77769 L
.14774 .78724 L
.15241 .79489 L
.15507 .79788 L
.15751 .7998 L
.16194 .80135 L
.16604 .80062 L
.17051 .7975 L
.17517 .79164 L
.17913 .78449 L
.18273 .77614 L
.19046 .75155 L
.1944 .73485 L
.19837 .71437 L
.20156 .69453 L
.20459 .67174 L
.20722 .64765 L
.20924 .62469 L
.21093 .60066 L
.21218 .5773 L
.21323 .54908 L
Mistroke
.21358 .53463 L
.21382 .51862 L
.21389 .48996 L
.21354 .46302 L
.21312 .44663 L
.21259 .43113 L
.21124 .40223 L
.20926 .37148 L
.20651 .33879 L
.20098 .28975 L
.19345 .24122 L
.18499 .20085 L
.17625 .16965 L
.17123 .15554 L
.16565 .14274 L
.15933 .13157 L
.1533 .12406 L
.14999 .12121 L
.14638 .11911 L
.14296 .11811 L
.1398 .11804 L
.13383 .1202 L
.12758 .12582 L
.12144 .13493 L
.11599 .1463 L
.10995 .163 L
.10451 .1823 L
.09575 .22441 L
.09139 .25228 L
.08778 .28042 L
.08461 .31065 L
.08173 .34513 L
.08035 .36557 L
.07925 .3847 L
.07831 .40444 L
.07759 .42302 L
.07662 .46078 L
.07636 .48079 L
.07628 .50212 L
.07641 .52434 L
.07674 .54507 L
.07719 .56338 L
.07787 .58286 L
.07941 .61485 L
.08125 .64258 L
.08385 .67246 L
.08676 .69842 L
.09284 .73786 L
.09672 .75609 L
.10057 .77019 L
Mistroke
.10284 .77698 L
.10536 .78329 L
.11005 .79197 L
.11472 .79701 L
.11907 .79868 L
.12379 .79735 L
.12645 .79516 L
.12892 .79222 L
.13148 .78817 L
.13379 .78367 L
.13883 .77082 L
.1432 .75595 L
.14754 .73713 L
.15442 .69635 L
.15764 .67036 L
.16023 .64413 L
.16256 .61362 L
.16362 .59592 L
.16444 .57909 L
.16546 .55011 L
.16582 .53452 L
.16605 .51772 L
.16613 .49993 L
.16606 .48307 L
.16552 .45148 L
.16453 .42201 L
.16322 .39518 L
.16135 .36631 L
.15887 .33668 L
.15615 .31034 L
.15274 .28308 L
.14541 .23825 L
.1415 .21964 L
.13706 .20188 L
.13267 .18732 L
.12846 .17586 L
.12293 .16413 L
.11994 .1593 L
.11676 .15523 L
.11132 .15087 L
.10822 .14982 L
.10532 .14978 L
.0999 .15222 L
.09503 .1573 L
.08952 .16658 L
.08448 .17872 L
.08026 .19188 L
.07583 .2091 L
.07178 .22851 L
.06776 .25212 L
Mistroke
.06435 .2765 L
.06155 .3006 L
.05703 .35206 L
.055 .38466 L
.05358 .41591 L
.05253 .45086 L
.05202 .48841 L
.05212 .52394 L
.05273 .55679 L
.05369 .58541 L
.05516 .61515 L
.05721 .64538 L
.05949 .67102 L
.06255 .69798 L
.06585 .72063 L
.06895 .73769 L
.07249 .7532 L
.0766 .76697 L
.08057 .77662 L
.08495 .7836 L
.08746 .78599 L
.08977 .78723 L
.09405 .78713 L
.09852 .78373 L
.10087 .7806 L
.10334 .77625 L
.10769 .76591 L
.11261 .74964 L
.11678 .73137 L
.12047 .71093 L
.12399 .68653 L
.12667 .66343 L
.12914 .63681 L
.13128 .60651 L
.1328 .57684 L
.13347 .55826 L
.13395 .54034 L
.13422 .5241 L
.13436 .50626 L
.13435 .48935 L
.13419 .47341 L
.13355 .44373 L
.13234 .41217 L
.13143 .39471 L
.13045 .3789 L
.12594 .32597 L
.12308 .3013 L
.11953 .27616 L
.11168 .23494 L
.10672 .2161 L
Mistroke
.10185 .2019 L
.09743 .19223 L
.09242 .18467 L
.08708 .18041 L
.08204 .17993 L
.07741 .18255 L
.07261 .18851 L
.0686 .19621 L
.06435 .20733 L
.05996 .22246 L
.05555 .24205 L
.04854 .2855 L
.04497 .31635 L
.04218 .34727 L
.03974 .38345 L
.03876 .40237 L
.03789 .42358 L
.0373 .44245 L
.0369 .45981 L
.03662 .47993 L
.03653 .49901 L
.03678 .53259 L
.03715 .55127 L
.03764 .56828 L
.03905 .60162 L
.04087 .63123 L
.04289 .65608 L
.04544 .68074 L
.04864 .70486 L
.05241 .72669 L
.05591 .7422 L
.05998 .7557 L
.06434 .76564 L
.06849 .77128 L
.07068 .77288 L
.0731 .77358 L
.07564 .77313 L
.078 .77162 L
.08229 .76621 L
.08612 .75834 L
.09036 .74597 L
.09418 .73114 L
.09736 .71563 L
.1005 .69689 L
.10535 .65814 L
.10778 .63172 L
.10965 .60532 L
.11096 .5806 L
.11199 .55305 L
.11261 .52244 L
Mistroke
.11274 .49355 L
.11261 .47694 L
.11236 .46183 L
.11192 .4445 L
.11135 .42823 L
.1098 .39644 L
.10787 .36811 L
.10522 .33863 L
.10186 .30958 L
.09883 .28869 L
.09523 .2684 L
.09187 .25292 L
.08797 .23837 L
.0834 .2254 L
.08083 .21979 L
.07839 .21556 L
.07394 .21039 L
.06913 .20841 L
.06457 .21001 L
.06199 .21244 L
.05961 .21572 L
.05491 .22525 L
.05235 .23229 L
.05007 .23977 L
.0462 .25546 L
.04228 .2759 L
.03893 .29799 L
.03612 .32112 L
.03308 .35313 L
.03087 .38436 L
.02992 .40141 L
.02909 .4198 L
.02837 .44033 L
.0279 .45943 L
.02751 .49377 L
.02766 .52565 L
.02797 .54371 L
.0284 .55992 L
.02905 .57825 L
.02982 .59515 L
.03142 .62187 L
.03363 .64933 L
.03639 .67536 L
.03935 .69697 L
.04241 .71445 L
.04541 .72805 L
.04891 .74018 L
.05275 .7497 L
.0568 .75592 L
.0591 .75785 L
Mistroke
.0612 .75865 L
.06528 .75762 L
.0691 .75359 L
.07123 .75002 L
.07345 .74526 L
.0773 .7343 L
.08122 .71921 L
.08519 .69904 L
.08831 .67869 L
.09089 .65781 L
.09334 .63296 L
.09546 .60467 L
.09688 .57899 L
.09785 .55408 L
.09849 .52618 L
.09865 .51033 L
.09868 .49575 L
.09844 .47055 L
.09789 .4473 L
.09694 .42225 L
.09553 .39625 L
.09362 .37012 L
.09143 .34681 L
.08643 .30771 L
.08334 .28981 L
.07964 .27273 L
.07551 .25809 L
.07142 .24759 L
.06748 .24076 L
.0638 .23712 L
.05951 .23613 L
.05545 .23842 L
.05115 .24443 L
.04879 .24937 L
.04671 .25483 L
.04279 .26805 L
.03932 .28352 L
.0356 .30511 L
.03255 .32799 L
.02966 .35604 L
.0272 .38845 L
.02568 .41621 L
.02501 .43237 L
.02452 .44755 L
.02395 .47578 L
.02381 .50595 L
.02408 .53268 L
.02468 .5573 L
.0257 .5835 L
.02722 .61042 L
Mistroke
.02916 .63569 L
.03171 .66094 L
.03481 .68423 L
.03803 .70276 L
.04133 .71719 L
.0445 .72767 L
.04831 .73654 L
.05202 .74171 L
.0553 .74365 L
.05891 .74307 L
.06265 .7395 L
.06607 .73351 L
.06918 .72568 L
.07192 .71675 L
.0776 .6909 L
.08042 .67344 L
.08278 .65553 L
.08523 .63235 L
.0871 .60988 L
.08856 .58731 L
.08962 .56533 L
.0904 .54156 L
.09085 .5155 L
.09089 .48921 L
.09056 .46543 L
.08976 .43846 L
.08859 .41371 L
.08717 .39175 L
.08558 .37244 L
.08108 .33306 L
.07829 .3154 L
.07544 .30088 L
.07208 .28742 L
.06825 .27603 L
.06627 .27162 L
.06407 .2678 L
.06196 .26518 L
.05998 .26362 L
.05624 .26301 L
.05414 .264 L
.05225 .26575 L
.04837 .27195 L
.04646 .27638 L
.04441 .28223 L
.04093 .29506 L
.0379 .30977 L
.03464 .33028 L
.03201 .35169 L
.02944 .37918 L
.02751 .4075 L
Mistroke
.02626 .43347 L
.02539 .46203 L
.02502 .48686 L
.02503 .51437 L
.02552 .5435 L
.02601 .55957 L
.02659 .57401 L
.02798 .59966 L
.02987 .625 L
.03201 .64669 L
.03468 .66783 L
.03752 .68522 L
.04037 .69886 L
.04309 .70909 L
.04623 .71796 L
.04963 .7245 L
.05289 .72807 L
.05672 .72913 L
.06035 .72708 L
.06356 .72277 L
.06698 .71551 L
.06886 .71024 L
.07053 .70479 L
.07408 .69032 L
.07712 .67436 L
.07972 .65733 L
.08371 .62216 L
.08532 .60277 L
.08676 .5805 L
.08771 .56082 L
.08843 .5393 L
.08883 .51874 L
.08894 .49995 L
.08876 .4765 L
.08827 .45516 L
.08738 .43235 L
.08605 .40911 L
.0846 .39003 L
.08299 .37319 L
.07853 .33944 L
.07601 .32574 L
.07312 .31331 L
.07022 .3038 L
.06748 .29715 L
.06416 .29183 L
.06225 .29007 L
.06049 .28926 L
.05724 .28981 L
.05383 .29328 L
.05064 .29939 L
Mistroke
.04735 .30891 L
.0444 .32061 L
.0419 .33349 L
.03922 .35104 L
.03667 .37289 L
.03465 .3958 L
.03315 .41865 L
.03219 .43862 L
.03146 .46088 L
.03107 .48235 L
.03097 .50224 L
.03116 .52424 L
.03171 .54803 L
.03267 .57219 L
.0339 .59378 L
.03555 .6155 L
.03742 .63456 L
.04163 .66566 L
.04434 .68009 L
.04702 .69133 L
.05014 .70125 L
.05358 .7089 L
.05682 .71327 L
.06041 .71516 L
.06381 .71424 L
.06693 .71107 L
.06996 .70581 L
.07263 .6993 L
.07559 .68982 L
.07823 .67909 L
.08093 .6655 L
.08354 .64926 L
.08748 .61608 L
.08923 .59578 L
.09055 .57594 L
.09165 .55346 L
.09209 .54063 L
.09239 .52885 L
.09267 .50913 L
.09265 .48827 L
.09238 .47069 L
.09182 .45172 L
.09092 .43208 L
.08962 .41195 L
.08809 .39414 L
.08645 .37903 L
.08294 .3549 L
.08069 .34347 L
.07845 .33446 L
.07595 .3267 L
Mistroke
.0736 .32133 L
.07081 .3172 L
.06813 .3154 L
.06542 .31566 L
.06253 .31831 L
.05986 .32302 L
.0575 .32919 L
.05485 .3386 L
.05216 .35141 L
.04985 .36582 L
.04792 .381 L
.04604 .40003 L
.04459 .41951 L
.04355 .43807 L
.04275 .459 L
.04246 .4702 L
.04225 .48264 L
.04215 .49573 L
.04216 .50798 L
.04246 .52989 L
.04315 .553 L
.04415 .57412 L
.04537 .59283 L
.047 .61224 L
.04907 .63127 L
.0532 .65887 L
.05588 .67181 L
.05856 .68195 L
.06111 .6894 L
.06388 .69539 L
.06631 .69899 L
.069 .70133 L
.07194 .70198 L
.07506 .70055 L
.07798 .69724 L
.08057 .69265 L
.08346 .6856 L
.08604 .67739 L
.08895 .66571 L
.09142 .65341 L
.09581 .62406 L
.09781 .60591 L
.09941 .58769 L
.10053 .57146 L
.10147 .55377 L
.10207 .53843 L
.10249 .52138 L
.10268 .50317 L
.10257 .48377 L
.10218 .46587 L
Mistroke
.10158 .44997 L
.10068 .43341 L
.09945 .41673 L
.09804 .40214 L
.09657 .38998 L
.09463 .37717 L
.09231 .36528 L
.08993 .35613 L
.08762 .34959 L
.08514 .34487 L
.08277 .34236 L
.08013 .34178 L
.07866 .34247 L
.07731 .34374 L
.07593 .3457 L
.07467 .3481 L
.0732 .35168 L
.0719 .35558 L
.06959 .36446 L
.06731 .37613 L
.0655 .38807 L
.06399 .40055 L
.06254 .41559 L
.06127 .43306 L
.06074 .4423 L
.06026 .45263 L
.05963 .47207 L
.05934 .49156 L
.05935 .50985 L
.0596 .52691 L
.06006 .5428 L
.0608 .55993 L
.06187 .57785 L
.0632 .59486 L
.06487 .61174 L
.0685 .63862 L
.07091 .65186 L
.07329 .6623 L
.0762 .67238 L
.0791 .67984 L
.08188 .68493 L
.0845 .68804 L
.08741 .68971 L
.09051 .68951 L
.0936 .68729 L
.09532 .68519 L
.09687 .68275 L
.09981 .67662 L
.10249 .6692 L
.10544 .65878 L
Mistroke
.108 .64752 L
.11059 .63353 L
.11302 .61722 L
.11479 .60262 L
.11646 .58577 L
.11773 .56968 L
.11865 .55469 L
.11907 .54609 L
.11945 .53671 L
.11975 .52678 L
.11995 .51742 L
.12007 .5087 L
.1201 .49953 L
.11996 .48336 L
.1196 .46886 L
.11898 .45389 L
.11817 .4405 L
.11726 .42898 L
.116 .41655 L
.11441 .40437 L
.11271 .39435 L
.111 .38645 L
.10927 .38024 L
.1073 .37506 L
.10537 .37169 L
.10356 .36993 L
.10192 .36946 L
.10011 .37018 L
.09824 .37231 L
.09653 .37557 L
.0946 .3809 L
.09286 .38743 L
.09139 .39445 L
.08991 .40329 L
.08845 .4142 L
.08711 .42717 L
.08614 .43923 L
.08529 .45346 L
.08468 .46802 L
.08432 .48211 L
.08416 .498 L
.08418 .50702 L
.08427 .51527 L
.08466 .53199 L
.08499 .54138 L
.08538 .54997 L
.08628 .56551 L
.08748 .58143 L
.09023 .60762 L
.09344 .62928 L
Mistroke
.09759 .64913 L
.10016 .65824 L
.10262 .66519 L
.10538 .67113 L
.10695 .67376 L
.1084 .6757 L
.11126 .6783 L
.11397 .6793 L
.11552 .67926 L
.11716 .67873 L
.12006 .67659 L
.12166 .67474 L
.12313 .67261 L
.1264 .66637 L
.12914 .65942 L
.13161 .65166 L
.13587 .63432 L
.13983 .61228 L
.14174 .59856 L
.14327 .58541 L
.14545 .56091 L
.1463 .54779 L
.14697 .53395 L
.14737 .52193 L
.14759 .51089 L
.14767 .49901 L
.14755 .48671 L
.1474 .47991 L
.14721 .47379 L
.14695 .46727 L
.14661 .4606 L
.14589 .44999 L
.14491 .43928 L
.14389 .43068 L
.14266 .42252 L
.14137 .4159 L
.14012 .41083 L
.1386 .40624 L
.13781 .40441 L
.13692 .40279 L
.13532 .40096 L
.1338 .40045 L
.13293 .40069 L
.13202 .40136 L
.13041 .40363 L
.12954 .40547 L
.12874 .40757 L
.127 .41362 L
.12559 .42033 L
.12438 .42782 L
Mistroke
.12338 .43553 L
.12246 .44459 L
.12162 .45538 L
.12101 .46609 L
.12055 .47831 L
.12038 .48554 L
.12028 .49246 L
.12026 .50512 L
.12034 .51233 L
.12046 .51891 L
.12086 .53183 L
.12142 .54401 L
.1223 .55813 L
.12332 .57087 L
.12477 .58528 L
.12636 .59813 L
.12951 .61806 L
.13359 .63692 L
.13809 .65172 L
.1408 .65832 L
.14336 .66323 L
.14577 .66678 L
.14838 .66954 L
.15064 .67107 L
.15314 .67189 L
.15583 .67176 L
.15734 .67124 L
.15872 .67048 L
.16124 .66841 L
.16386 .66532 L
.1661 .66187 L
.16844 .65746 L
.17247 .64778 L
.1769 .63371 L
.1805 .61895 L
.18375 .6022 L
.18674 .58255 L
.18917 .56134 L
.19008 .55111 L
.19079 .54147 L
.19132 .53273 L
.19175 .52339 L
.19202 .5151 L
.19217 .50765 L
.19222 .49911 L
.19215 .49172 L
.19195 .48366 L
.19165 .47658 L
.19124 .46993 L
.19068 .46332 L
Mistroke
.18997 .45722 L
.18923 .45233 L
.18847 .44847 L
.18772 .44558 L
.18682 .44302 L
.18594 .44137 L
.18495 .44044 L
.18445 .44032 L
.1839 .44045 L
.18294 .44137 L
.18205 .44302 L
.18153 .44438 L
.18105 .44592 L
.18019 .44947 L
.17933 .4542 L
.17851 .46041 L
.17789 .46665 L
.17742 .47303 L
.17721 .47659 L
.17702 .48067 L
.17686 .48512 L
.17675 .48942 L
.17665 .49772 L
.17667 .50565 L
.17674 .51016 L
.17685 .51516 L
.17717 .52445 L
.17757 .53288 L
.17817 .54232 L
.17982 .56159 L
.18189 .57921 L
.18431 .59518 L
.1877 .61283 L
.19187 .6296 L
.19586 .64211 L
.20061 .65365 L
.20611 .66338 L
.20932 .66753 L
.2123 .6705 L
.21512 .67257 L
.21673 .67345 L
.21822 .67407 L
.22096 .67476 L
.22388 .67485 L
.22656 .67438 L
.22948 .67328 L
.23221 .6717 L
.23471 .66979 L
.23936 .66511 L
.24415 .65871 L
Mistroke
.25426 .63974 L
.2622 .61912 L
.27393 .57666 L
.28059 .54315 L
.28292 .52988 L
.28378 .52532 L
.28446 .52234 L
.2848 .52121 L
.2851 .52045 L
.28542 .51999 L
.28559 .51989 L
.28575 .51989 L
.28607 .52016 L
.28625 .52048 L
.28643 .52089 L
.28679 .52201 L
.28721 .52367 L
.29828 .58006 L
.31074 .62513 L
.3203 .65174 L
.33083 .67606 L
.35673 .72205 L
.39061 .76604 L
.46779 .84376 L
.51667 .88938 L
.54603 .91538 L
.57518 .93879 L
.60246 .95711 L
.61822 .96545 L
.63283 .97132 L
.63687 .97257 L
.64118 .97373 L
.64896 .97528 L
.65373 .97587 L
.65823 .97616 L
.66227 .97619 L
.66662 .97596 L
.67051 .97552 L
.67477 .97477 L
.6792 .97367 L
.68333 .97235 L
.69068 .96921 L
.69848 .96471 L
.70605 .95908 L
.71294 .95275 L
.72812 .93417 L
.74089 .9126 L
.75364 .88421 L
.76419 .85398 L
.77324 .82162 L
Mistroke
.78211 .7819 L
.79028 .7348 L
.79703 .6829 L
.80005 .65263 L
.80232 .62465 L
.80403 .59817 L
.80541 .56939 L
.80629 .54227 L
.80672 .51752 L
.80677 .48901 L
.80639 .46299 L
.80599 .44839 L
.80551 .43532 L
.80406 .4069 L
.80217 .38107 L
.79962 .3548 L
.79677 .33196 L
.79377 .31267 L
.79092 .29745 L
.78761 .28271 L
.78109 .26057 L
.77704 .2505 L
.77263 .24211 L
.76876 .23675 L
.76445 .23277 L
.76207 .23142 L
.75981 .23067 L
.75558 .23064 L
.75321 .23139 L
.75104 .23255 L
.74867 .23435 L
.74618 .23684 L
.74211 .24224 L
.73839 .2487 L
.73441 .25732 L
.73035 .26816 L
.72313 .29336 L
.71725 .32145 L
.71409 .34065 L
.71146 .35996 L
.70937 .37847 L
.7075 .39889 L
.70612 .41779 L
.70494 .43919 L
.70418 .45919 L
.70374 .47823 L
.70357 .50117 L
.70375 .52239 L
.70398 .53424 L
.70435 .54718 L
Mistroke
.70532 .57084 L
.70651 .59197 L
.7079 .6118 L
.71209 .6567 L
.7175 .69955 L
.72476 .74389 L
.73232 .78067 L
.74138 .81628 L
.74996 .84367 L
.76 .86938 L
.76643 .88269 L
.77254 .89323 L
.77841 .90148 L
.78498 .90862 L
.79096 .91321 L
.7966 .91584 L
.80258 .91682 L
.80899 .91572 L
.8159 .91193 L
.81977 .90856 L
.82332 .90464 L
.82973 .89542 L
.83636 .8827 L
.84723 .85369 L
.85299 .83327 L
.85807 .81162 L
.86635 .76675 L
.87357 .71258 L
.87839 .6619 L
.88053 .63182 L
.88212 .60321 L
.88349 .56943 L
.88428 .53733 L
.88459 .5086 L
.88449 .47778 L
.88388 .4449 L
.88267 .41122 L
.8812 .38367 L
.87914 .3549 L
.87652 .32696 L
.8737 .30309 L
.8699 .27755 L
.86608 .25726 L
.86241 .24162 L
.85821 .22736 L
.85355 .21538 L
.84901 .20704 L
.84479 .20194 L
.8401 .19901 L
.83518 .1989 L
Mistroke
.83061 .20144 L
.82637 .20607 L
.82259 .21211 L
.81833 .22116 L
.81444 .23169 L
.80629 .26189 L
.80259 .28023 L
.79886 .30261 L
.79601 .32324 L
.79331 .34693 L
.79115 .37038 L
.78946 .39311 L
.78789 .42087 L
.78726 .43592 L
.78673 .45222 L
.78634 .46959 L
.78613 .48616 L
.78607 .50114 L
.78616 .51747 L
.7867 .5474 L
.78717 .5625 L
.78782 .57907 L
.78936 .60819 L
.79122 .63506 L
.79659 .69074 L
.80315 .73879 L
.81195 .78595 L
.81704 .80726 L
.82291 .82779 L
.82888 .84477 L
.8346 .85782 L
.84025 .86783 L
.84636 .87563 L
.85194 .88008 L
.85718 .88194 L
.86294 .88138 L
.86907 .87767 L
.87499 .87085 L
.88035 .86174 L
.88604 .84863 L
.89183 .83122 L
.90078 .79421 L
.90536 .76909 L
.90926 .74312 L
.91259 .71642 L
.91538 .68946 L
.9176 .66382 L
.91959 .63546 L
.92132 .6039 L
.92252 .574 L
Mistroke
.92341 .53807 L
.92372 .50547 L
.92355 .47142 L
.92292 .44027 L
.92172 .4072 L
.91988 .37341 L
.91736 .34034 L
.91446 .3116 L
.91146 .28823 L
.90783 .26566 L
.90412 .24743 L
.9004 .23297 L
.89632 .22074 L
.89164 .21066 L
.8875 .20491 L
.88365 .20199 L
.8794 .20135 L
.87493 .20353 L
.87006 .20923 L
.86573 .21731 L
.86092 .22989 L
.8566 .24478 L
.8496 .27783 L
.84612 .29979 L
.84324 .3219 L
.84067 .34592 L
.83835 .3733 L
.83722 .38963 L
.83633 .40491 L
.8356 .41968 L
.83497 .43567 L
.83446 .45241 L
.83413 .46811 L
.8339 .48695 L
.83386 .50413 L
.83397 .52048 L
.83424 .53817 L
.83515 .57011 L
.8365 .59988 L
.83813 .6265 L
.84049 .6564 L
.84317 .68364 L
.84896 .72876 L
.85659 .77171 L
.86108 .79112 L
.86636 .80974 L
.87219 .82576 L
.87495 .83183 L
.8779 .83734 L
.88337 .84494 L
Mistroke
.88847 .84906 L
.89401 .85033 L
.89714 .84956 L
.90004 .84786 L
.90584 .84153 L
.90905 .83624 L
.91195 .83028 L
.91714 .81662 L
.92236 .79843 L
.93057 .75833 L
.93466 .73113 L
.93805 .70316 L
.94139 .66844 L
.94395 .63339 L
.94574 .60059 L
.9471 .5639 L
.94757 .54475 L
.94789 .52354 L
.94801 .50141 L
.94793 .48074 L
.94731 .44448 L
.9467 .42459 L
.94598 .40675 L
.9442 .37435 L
.94206 .34566 L
.93978 .32177 L
.93694 .2981 L
.93347 .27526 L
.92943 .25467 L
.92571 .2402 L
.92141 .22771 L
.91724 .21939 L
.91334 .2146 L
.90878 .21241 L
.90444 .2136 L
.90048 .21744 L
.89687 .22328 L
.89302 .23211 L
.88906 .24419 L
.88466 .26173 L
.88092 .28077 L
.87719 .30457 L
.87375 .33261 L
.8712 .35911 L
.86923 .38532 L
.86754 .41542 L
.86682 .43279 L
.86631 .44887 L
.86573 .47908 L
.86563 .50735 L
Mistroke
.86601 .53846 L
.86639 .5541 L
.86695 .57126 L
.86824 .59952 L
.87011 .62918 L
.8723 .65616 L
.87467 .67981 L
.87781 .70553 L
.88113 .72803 L
.88822 .76469 L
.89262 .78169 L
.8969 .79485 L
.9018 .80632 L
.90433 .81086 L
.90715 .81485 L
.91195 .81913 L
.91636 .82032 L
.92145 .81841 L
.92623 .81327 L
.93054 .80569 L
.93443 .79623 L
.93854 .78321 L
.94269 .76641 L
.94723 .74283 L
.95101 .7179 L
.95466 .68729 L
.95789 .65188 L
.96013 .61891 L
.96172 .58684 L
.9624 .56802 L
.96288 .5507 L
.96326 .53059 L
.96345 .51153 L
.96337 .47894 L
.96276 .44499 L
.96181 .41687 L
.96033 .38718 L
.95826 .35724 L
.95551 .32768 L
.95247 .30271 L
.94934 .28263 L
.94563 .2641 L
.94189 .24991 L
.93836 .23996 L
.93441 .23224 L
.92999 .22746 L
.92774 .22649 L
.92527 .22653 L
.92091 .22938 L
.91691 .23516 L
Mistroke
.91298 .24391 L
.90941 .25478 L
.90319 .2814 L
.90005 .2995 L
.8974 .31807 L
.89482 .34009 L
.89243 .36566 L
.89046 .39291 L
.88905 .41904 L
.88807 .4448 L
.88745 .47252 L
.88725 .50335 L
.88752 .53211 L
.88788 .54855 L
.88833 .56339 L
.889 .58033 L
.88978 .5961 L
.8916 .62482 L
.89403 .65381 L
.89959 .70093 L
.90328 .72376 L
.90707 .74259 L
.91156 .76009 L
.91417 .76825 L
.9167 .77488 L
.91896 .77982 L
.92145 .78422 L
.92586 .78948 L
.92839 .79107 L
.93108 .79162 L
.93588 .78968 L
.94027 .78451 L
.94427 .77676 L
.94851 .76506 L
.95282 .74892 L
.95714 .72753 L
.96134 .69999 L
.96479 .67031 L
.96745 .64019 L
.9694 .6113 L
.97101 .57793 L
.9716 .56073 L
.97208 .54199 L
.97249 .50784 L
.97235 .47502 L
.97176 .44506 L
.97059 .41326 L
.96971 .39614 L
.96879 .3811 L
.96653 .35234 L
Mistroke
.96357 .32419 L
.96032 .3009 L
.957 .28256 L
.95372 .26855 L
.95048 .258 L
.94678 .24935 L
.94269 .24352 L
.94062 .24195 L
.93835 .24126 L
.93422 .2427 L
.93024 .24737 L
.92665 .25448 L
.92269 .2657 L
.91875 .28088 L
.91562 .29637 L
.91247 .31576 L
.90944 .33921 L
.90668 .36679 L
.90457 .39478 L
.90309 .42155 L
.90204 .4495 L
.90148 .47585 L
.90132 .50505 L
.90143 .51979 L
.90168 .53596 L
.90244 .56272 L
.90371 .59079 L
.90532 .61633 L
.90714 .63862 L
.90932 .66014 L
.91197 .68141 L
.91752 .71459 L
.92134 .73119 L
.92518 .74395 L
.92878 .75285 L
.93279 .75963 L
.93644 .76305 L
.94047 .7639 L
.94468 .76149 L
.94854 .75617 L
.95207 .74853 L
.95518 .73936 L
.9586 .72625 L
.96165 .71142 L
.96459 .69368 L
.96745 .67212 L
.96963 .65165 L
.97169 .62755 L
.97355 .59912 L
.97436 .58299 L
Mistroke
.97499 .56768 L
.97579 .53969 L
.97618 .50936 L
.97619 .49263 L
.97607 .47727 L
.97579 .46056 L
.97534 .44312 L
.97421 .41465 L
.97338 .39907 L
.97247 .38496 L
.97051 .36056 L
.96832 .33926 L
.96543 .31729 L
.96249 .29988 L
.95943 .28572 L
.95648 .27521 L
.95294 .2659 L
.94949 .25997 L
.94622 .25692 L
.9432 .25621 L
.93988 .25771 L
.93643 .26182 L
.933 .26853 L
.92947 .27844 L
.92629 .29022 L
.92356 .30287 L
.92059 .31985 L
.91768 .34065 L
.91527 .36236 L
.91338 .38368 L
.91185 .40561 L
.91059 .4296 L
.9097 .45438 L
.90917 .48194 L
.90908 .50602 L
.90938 .53159 L
.91001 .55537 L
.91089 .57645 L
.91241 .60243 L
.91419 .62512 L
.91655 .64833 L
.91945 .67061 L
.92208 .68671 L
.92516 .7018 L
.92878 .71553 L
.93236 .72546 L
.93433 .72956 L
.93646 .73297 L
.94034 .73657 L
.94251 .73715 L
Mistroke
.94455 .73676 L
.94678 .73527 L
.94916 .73243 L
.95107 .7292 L
.95311 .72471 L
.9571 .71269 L
.96057 .69814 L
.96356 .68182 L
.96641 .66186 L
.96879 .64073 L
.97063 .62009 L
.97228 .59621 L
.97366 .56879 L
.97417 .55454 L
.9746 .53861 L
.975 .51009 L
.97495 .48331 L
.97447 .45586 L
.97401 .4408 L
.97348 .42741 L
.97214 .4022 L
.97053 .37978 L
.96825 .35556 L
.96579 .33551 L
.96276 .31625 L
.95922 .29936 L
.95613 .28841 L
.95267 .27956 L
.94929 .274 L
.94615 .27132 L
.94245 .27105 L
.94037 .27225 L
.93845 .27422 L
.93499 .27992 L
.93144 .28881 L
.92845 .29894 L
.92585 .30999 L
.92322 .32363 L
.92059 .34042 L
.91679 .37261 L
.91509 .39185 L
.91376 .41059 L
.91251 .43397 L
.91168 .45664 L
.91123 .47729 L
.91106 .49977 L
.91125 .52416 L
.9115 .53631 L
.91188 .54951 L
.91284 .57227 L
Mistroke
.91407 .5927 L
.91571 .61354 L
.91781 .63411 L
.9199 .65033 L
.92241 .66604 L
.92566 .68187 L
.92897 .69383 L
.9306 .69845 L
.93236 .70256 L
.93559 .70789 L
.93873 .7105 L
.94211 .71054 L
.94529 .70794 L
.94812 .70335 L
.95136 .69529 L
.95311 .6895 L
.95469 .68338 L
.95741 .67037 L
.9601 .65386 L
.96224 .63724 L
.96397 .62055 L
.9655 .60231 L
.96668 .58438 L
.96776 .56263 L
.96857 .53799 L
.96895 .51577 L
.96901 .49188 L
.96869 .46707 L
.96833 .45327 L
.9679 .44075 L
.96684 .41834 L
.96537 .39577 L
.96375 .37677 L
.962 .36027 L
.95987 .34397 L
.95727 .328 L
.9544 .31425 L
.95114 .30239 L
.94795 .29407 L
.94486 .28864 L
.94306 .28659 L
.94115 .28526 L
.93773 .28499 L
.93582 .28599 L
.93406 .28765 L
.93214 .29027 L
.93013 .29398 L
.92684 .30219 L
.92345 .3138 L
.92046 .32713 L
Mistroke
.91791 .34128 L
.91373 .37227 L
.91198 .38964 L
.91036 .40981 L
.9091 .4303 L
.9082 .45031 L
.90766 .46855 L
.90735 .48857 L
.90734 .51018 L
.90748 .52214 L
.9077 .53286 L
.90838 .5533 L
.9093 .57183 L
.91041 .58852 L
.91184 .60513 L
.91496 .63179 L
.91698 .64465 L
.91903 .65522 L
.92142 .6651 L
.92414 .67357 L
.92689 .67958 L
.92849 .68199 L
.93 .68358 L
.93308 .68476 L
.93481 .68423 L
.93639 .68298 L
.93902 .67924 L
.94181 .67283 L
.9446 .6636 L
.94704 .65281 L
.94971 .63728 L
.95194 .62022 L
.95368 .60313 L
.95525 .58299 L
.95657 .55943 L
.95706 .54706 L
.95747 .53317 L
.9577 .52114 L
.95784 .50809 L
.95786 .49571 L
.95778 .4844 L
.95736 .46227 L
.95701 .45123 L
.95653 .4392 L
.95542 .41856 L
.95409 .40004 L
.95219 .37972 L
.95016 .36262 L
.94763 .34581 L
.94468 .33057 L
Mistroke
.94208 .32018 L
.93914 .3112 L
.93625 .30482 L
.93356 .30082 L
.93033 .29833 L
.9285 .29797 L
.92681 .2983 L
.92373 .30056 L
.92052 .3052 L
.91758 .3116 L
.9145 .3207 L
.91175 .3312 L
.90935 .34245 L
.90532 .36717 L
.90339 .38269 L
.90184 .39763 L
.90039 .41489 L
.89915 .43381 L
.89863 .44392 L
.89815 .45512 L
.89758 .47497 L
.89733 .49373 L
.8974 .51362 L
.89776 .53198 L
.89833 .5482 L
.89914 .56382 L
.90024 .57954 L
.90137 .59215 L
.90279 .60506 L
.90451 .61758 L
.90657 .62943 L
.90869 .63891 L
.91074 .64603 L
.91277 .65133 L
.91472 .65495 L
.9169 .65742 L
.91925 .6583 L
.92172 .65725 L
.92403 .65438 L
.92605 .65028 L
.92817 .64422 L
.93037 .63578 L
.93224 .62646 L
.93423 .61392 L
.93592 .60038 L
.93718 .5876 L
.93834 .57296 L
.93935 .55585 L
.94005 .5392 L
.94035 .52868 L
Mistroke
.94055 .51885 L
.94067 .50792 L
.94069 .49631 L
.94047 .47667 L
.94021 .46557 L
.93987 .4553 L
.93901 .43641 L
.93797 .41976 L
.93647 .40142 L
.93478 .38515 L
.93058 .35593 L
.92812 .3436 L
.9252 .3321 L
.92257 .32415 L
.91961 .31754 L
.91674 .31321 L
.91406 .31088 L
.91251 .31024 L
.91086 .31013 L
.9079 .31135 L
.9061 .31299 L
.90443 .31515 L
.90135 .3207 L
.89822 .32863 L
.89547 .33769 L
.89249 .3501 L
.8899 .36356 L
.88796 .37577 L
.88605 .39004 L
.8833 .41694 L
.88209 .43296 L
.88109 .45038 L
.88048 .46541 L
.88005 .48204 L
.8799 .49728 L
.87996 .51104 L
.88023 .52577 L
.88076 .54072 L
.88141 .55317 L
.88217 .56418 L
.88316 .57553 L
.88438 .58672 L
.88602 .59841 L
.8877 .60776 L
.88971 .6163 L
.89078 .61992 L
.89198 .62325 L
.89404 .62745 L
.89602 .62979 L
.89724 .63045 L
Mistroke
.89841 .63052 L
.90058 .62921 L
.9025 .62644 L
.90449 .62184 L
.90629 .61598 L
.90784 .60945 L
.90953 .6003 L
.91119 .58878 L
.91255 .57649 L
.91362 .5641 L
.91454 .54997 L
.91519 .53579 L
.91559 .52254 L
.91582 .5077 L
.91581 .49123 L
.9157 .48284 L
.91551 .47358 L
.91496 .45727 L
.91421 .44219 L
.91329 .4282 L
.91211 .41397 L
.9095 .3902 L
.90602 .36769 L
.90378 .35662 L
.90155 .34754 L
.89897 .33907 L
.89603 .33165 L
.89464 .32887 L
.89315 .32637 L
.89043 .32301 L
.88778 .32116 L
.88528 .32064 L
.88254 .32139 L
.87963 .3237 L
.87804 .32563 L
.87659 .3278 L
.87338 .3341 L
.87066 .34113 L
.86791 .35002 L
.86314 .37052 L
.85949 .39234 L
.85663 .41553 L
.85532 .42931 L
.85431 .4424 L
.85347 .45638 L
.85291 .4691 L
.85268 .47611 L
.85249 .48366 L
.85234 .49715 L
.85238 .50839 L
Mistroke
.8526 .52036 L
.85303 .53229 L
.8536 .54284 L
.85428 .55207 L
.855 .55993 L
.85699 .57537 L
.85828 .58247 L
.85977 .58876 L
.86126 .59343 L
.86268 .59655 L
.86357 .59792 L
.86439 .59882 L
.86531 .5994 L
.86628 .59955 L
.86791 .59872 L
.86882 .59764 L
.86966 .59624 L
.87124 .59249 L
.87268 .58769 L
.87389 .58238 L
.87511 .57556 L
.87631 .56702 L
.87742 .55673 L
.87822 .54705 L
.87858 .54158 L
.87891 .53553 L
.87938 .52429 L
.87965 .51334 L
.87974 .50646 L
.87976 .49985 L
.87966 .48726 L
.87934 .47375 L
.87885 .46123 L
.87809 .44755 L
.87704 .43329 L
.87478 .41079 L
.8721 .39131 L
.86858 .37229 L
.86422 .35519 L
.86159 .3474 L
.85905 .34132 L
.85615 .33594 L
.85463 .33372 L
.85297 .33173 L
.85136 .33022 L
.84987 .32918 L
.84844 .3285 L
.84693 .3281 L
.84429 .32819 L
.84142 .32941 L
Mistroke
.83861 .33171 L
.8361 .33472 L
.83326 .33924 L
.83065 .34446 L
.82625 .35585 L
.8219 .37083 L
.81829 .38683 L
.81496 .40563 L
.81238 .42433 L
.81053 .44181 L
.80903 .46114 L
.80845 .47185 L
.80807 .48157 L
.80793 .48674 L
.80784 .49152 L
.80778 .50019 L
.80786 .50907 L
.80797 .51384 L
.80811 .51807 L
.80844 .52515 L
.80892 .53213 L
.80947 .53808 L
.81004 .54294 L
.8108 .54789 L
.81172 .55233 L
.81216 .55403 L
.81265 .5556 L
.81355 .55778 L
.8145 .55916 L
.81504 .55956 L
.81554 .55969 L
.81646 .55932 L
.81741 .55809 L
.81791 .55709 L
.81843 .55575 L
.81933 .55267 L
.82032 .54789 L
.82114 .54254 L
.82174 .53734 L
.82223 .53193 L
.82268 .52541 L
.82304 .51779 L
.82317 .51377 L
.82328 .50922 L
.82336 .50056 L
.8233 .49172 L
.82311 .48322 L
.82278 .47431 L
.82235 .46575 L
.82121 .44951 L
Mistroke
.81949 .432 L
.81707 .41348 L
.81402 .39555 L
.81004 .37752 L
.80525 .36105 L
.80028 .34823 L
.79526 .3387 L
.79046 .3322 L
.78773 .32951 L
.78628 .32835 L
.78472 .32731 L
.78185 .32593 L
.77918 .32525 L
.77665 .3251 L
.77388 .32549 L
.771 .32648 L
.76835 .32792 L
.76587 .3297 L
.76365 .33167 L
.75877 .33718 L
.75372 .34464 L
.74854 .35421 L
.74006 .37441 L
.73328 .39524 L
.72746 .41735 L
.72026 .45206 L
.71777 .46624 L
.71608 .47535 L
.71571 .47699 L
.71534 .47837 L
.71514 .47899 L
.71496 .47943 L
.71478 .47977 L
.71461 .47998 L
.71431 .48013 L
.71402 .47996 L
.71371 .47944 L
.71336 .47852 L
.71304 .47738 L
.71273 .47609 L
.71197 .47233 L
.71024 .46266 L
.7038 .4292 L
.69204 .38369 L
.67583 .33878 L
.6521 .29194 L
.62071 .24734 L
.54865 .17189 L
.46329 .09267 L
.43692 .07053 L
Mistroke
.40657 .04846 L
.39223 .03986 L
.37665 .03226 L
.369 .0293 L
.36175 .02702 L
.35521 .02546 L
.34812 .02432 L
.34112 .02381 L
.33459 .02394 L
.32743 .0248 L
.31977 .02662 L
.31594 .02791 L
.31178 .02962 L
.30427 .03355 L
.29702 .03847 L
.29039 .04403 L
.27869 .05664 L
.2662 .07466 L
.25379 .09831 L
.24283 .12512 L
.23177 .15959 L
.2225 .19625 L
.21362 .24113 L
.20576 .29364 L
.20249 .32154 L
.19949 .35261 L
.19732 .3805 L
.19551 .41035 L
.19433 .43732 L
.19385 .45263 L
.19351 .46689 L
.19322 .49172 L
.19329 .51798 L
.19378 .54371 L
.19458 .56688 L
.19584 .59138 L
.1976 .61623 L
.19967 .63857 L
.20193 .65827 L
.20692 .69124 L
.21269 .71851 L
.21862 .73857 L
.22191 .74711 L
.22564 .75489 L
.22964 .76124 L
.23345 .76554 L
.23775 .7685 L
.23993 .76927 L
.24234 .76956 L
.2466 .76869 L
Mistroke
.25057 .76628 L
.25282 .76423 L
.25517 .76155 L
.2593 .75548 L
.26362 .74717 L
.26816 .73608 L
.27527 .71301 L
.28196 .68287 L
.28726 .64988 L
.29112 .61663 L
.29271 .59861 L
.29409 .57886 L
.29503 .56151 L
.29579 .54197 L
.29628 .52048 L
.29641 .50823 L
.29643 .49694 L
.29621 .47478 L
.29567 .45352 L
.29489 .43364 L
.29376 .4124 L
.29095 .3742 L
.2863 .32923 L
.28088 .28955 L
.27403 .24966 L
.26519 .20876 L
.25462 .17024 L
.24367 .13926 L
.23257 .11545 L
.22193 .09894 L
.21588 .09217 L
.2092 .08688 L
.20283 .08397 L
.19693 .08317 L
.19059 .08442 L
.18381 .08828 L
.17749 .09439 L
.1718 .10211 L
.16531 .11375 L
.15848 .12968 L
.1469 .16717 L
.14114 .19208 L
.13633 .21718 L
.13162 .24668 L
.12714 .28116 L
.12359 .31521 L
.12085 .34797 L
.11875 .38025 L
.11707 .41506 L
.11601 .44837 L
Mistroke
.11564 .46722 L
.11545 .48462 L
.11546 .51626 L
.11597 .54922 L
.11687 .5778 L
.11807 .60372 L
.11978 .63093 L
.12204 .65859 L
.12474 .68432 L
.12812 .70994 L
.1321 .73362 L
.13615 .75265 L
.14015 .76751 L
.14412 .7791 L
.14888 .78946 L
.15334 .79609 L
.15735 .79974 L
.1618 .80138 L
.16646 .80048 L
.17079 .79727 L
.17478 .79229 L
.17835 .7861 L
.18237 .77711 L
.18605 .76682 L
.19368 .73824 L
.19988 .70546 L
.20555 .6636 L
.20814 .63796 L
.21009 .61356 L
.21164 .58845 L
.21273 .56434 L
.21353 .53725 L
.21391 .50768 L
.21391 .49266 L
.21377 .47626 L
.21312 .44637 L
.21202 .41731 L
.21057 .39065 L
.20697 .34355 L
.20435 .3176 L
.20155 .29402 L
.19489 .24933 L
.18634 .20648 L
.17627 .16965 L
.17008 .15262 L
.16408 .13959 L
.16072 .13368 L
.1575 .12892 L
.15138 .12226 L
.14792 .11983 L
Mistroke
.14471 .11846 L
.14118 .11792 L
.13744 .11849 L
.13172 .12166 L
.12566 .12823 L
.12006 .13746 L
.11509 .14846 L
.10949 .16442 L
.10371 .18547 L
.09861 .20884 L
.0943 .233 L
.08716 .2858 L
.08407 .31647 L
.08134 .35052 L
.07942 .38138 L
.07804 .41081 L
.07697 .44359 L
.07637 .47883 L
.07627 .49875 L
.07633 .51702 L
.07658 .53686 L
.07702 .55758 L
.07822 .59141 L
.07913 .60998 L
.08014 .62684 L
.08238 .65668 L
.08483 .682 L
.08809 .7086 L
.09158 .73102 L
.09565 .75152 L
.0996 .76703 L
.10189 .77433 L
.10443 .78116 L
.10918 .79069 L
.11375 .79629 L
.11865 .79869 L
.12284 .79792 L
.12741 .79417 L
.13014 .79045 L
.1327 .78596 L
.13736 .77507 L
.14214 .75995 L
.147 .73979 L
.15089 .71931 L
.15463 .69491 L
.15746 .67204 L
.16014 .64525 L
.16222 .61887 L
.16377 .59328 L
.16499 .56536 L
Mistroke
.16582 .53478 L
.16613 .50575 L
.16602 .47812 L
.16557 .45328 L
.16472 .42647 L
.16336 .39743 L
.16134 .36615 L
.15868 .33456 L
.1557 .30628 L
.14923 .25967 L
.14505 .23637 L
.14085 .21679 L
.13191 .18502 L
.12684 .17199 L
.12124 .16124 L
.11576 .15415 L
.11052 .15046 L
.10579 .14968 L
.10068 .15162 L
.09603 .15598 L
.09102 .16363 L
.08593 .17481 L
.08136 .18811 L
.07373 .21865 L
.06983 .23932 L
.06655 .26018 L
.06029 .31294 L
.05746 .34615 L
.05532 .37889 L
.05362 .41455 L
.05259 .4479 L
.05224 .46643 L
.05203 .48668 L
.05211 .52334 L
.05273 .55692 L
.05373 .58646 L
.05538 .61907 L
.05741 .64798 L
.05967 .67292 L
.06205 .69408 L
.06835 .73469 L
.07207 .75159 L
.07631 .7662 L
.08051 .77655 L
.08447 .78304 L
.08918 .78705 L
.09187 .78761 L
.09436 .78704 L
.09888 .78335 L
.10114 .78021 L
Mistroke
.1036 .77578 L
.10835 .76407 L
.1125 .75011 L
.11677 .73149 L
.12087 .7085 L
.12673 .66295 L
.12937 .63398 L
.13136 .60539 L
.13283 .5762 L
.13339 .56111 L
.13386 .54429 L
.13433 .51414 L
.13433 .48565 L
.13412 .46843 L
.13378 .45211 L
.13277 .42175 L
.132 .40503 L
.13115 .38973 L
.12875 .35601 L
.12614 .32775 L
.12326 .30262 L
.11689 .2604 L
.11281 .23988 L
.10878 .22333 L
.1041 .20794 L
.09891 .1951 L
.09435 .18713 L
.09012 .18232 L
.08517 .17978 L
.08047 .18044 L
.07616 .18373 L
.07223 .18909 L
.06801 .19751 L
.06368 .20934 L
.05954 .22407 L
.05535 .24305 L
.04861 .28492 L
.04529 .31314 L
.04233 .34543 L
.04025 .37475 L
.03849 .4082 L
.03781 .42553 L
.03725 .44406 L
.03664 .47757 L
.03657 .51362 L
.03679 .53387 L
.03718 .55255 L
.03828 .58543 L
.03974 .61411 L
.04194 .64518 L
Mistroke
.04448 .67223 L
.04711 .69413 L
.05022 .71482 L
.05315 .73036 L
.05653 .74458 L
.06034 .75671 L
.06406 .76516 L
.06626 .76874 L
.06862 .77144 L
.07286 .7736 L
.07742 .77213 L
.08151 .76749 L
.08374 .76361 L
.08612 .75837 L
.0903 .74623 L
.094 .73197 L
.09767 .71402 L
.10342 .67536 L
.10612 .65061 L
.10854 .62195 L
.11034 .59331 L
.11156 .56607 L
.1121 .5492 L
.11245 .53336 L
.11269 .51582 L
.11275 .49704 L
.11264 .47911 L
.11237 .46226 L
.112 .44722 L
.11147 .43108 L
.11016 .40263 L
.10857 .37747 L
.1063 .34967 L
.10374 .32484 L
.09827 .2852 L
.09472 .2658 L
.09118 .25004 L
.0874 .23649 L
.08312 .22468 L
.08059 .2193 L
.07824 .21529 L
.07353 .21004 L
.0689 .20837 L
.06628 .20897 L
.06384 .21054 L
.06128 .21328 L
.05898 .21671 L
.05637 .2218 L
.05395 .22769 L
.04983 .24061 L
Mistroke
.04556 .25842 L
.04146 .28081 L
.03801 .30499 L
.03522 .32962 L
.03293 .35488 L
.03077 .3859 L
.02925 .41562 L
.02812 .44932 L
.02774 .46843 L
.02754 .4858 L
.02759 .51957 L
.02814 .55083 L
.02866 .56825 L
.02939 .5862 L
.03109 .61698 L
.03348 .64771 L
.0367 .67792 L
.03985 .70017 L
.04307 .71779 L
.04689 .73366 L
.04894 .74031 L
.0512 .74635 L
.05509 .75378 L
.05882 .75771 L
.061 .75865 L
.0633 .75858 L
.06738 .75581 L
.07098 .75053 L
.07471 .74208 L
.0781 .73157 L
.08104 .72004 L
.08428 .70417 L
.0875 .68446 L
.09244 .6429 L
.0946 .61729 L
.09622 .59204 L
.09696 .57736 L
.09754 .5632 L
.09807 .54664 L
.09841 .53136 L
.09861 .5162 L
.09869 .50002 L
.09845 .47097 L
.09811 .45498 L
.09766 .44009 L
.09703 .42398 L
.09617 .40693 L
.09453 .38165 L
.0923 .35541 L
.08952 .32997 L
Mistroke
.08654 .3084 L
.08038 .27578 L
.07656 .26137 L
.07289 .25091 L
.06906 .24308 L
.06538 .23833 L
.06129 .23609 L
.05688 .23721 L
.0547 .23916 L
.05233 .24235 L
.04812 .25098 L
.04419 .2628 L
.04073 .2767 L
.03744 .29364 L
.0346 .31195 L
.03006 .35164 L
.028 .37655 L
.02645 .40079 L
.02515 .42854 L
.02424 .45873 L
.02382 .49012 L
.02389 .51872 L
.02411 .53439 L
.0245 .55122 L
.02558 .581 L
.02703 .60753 L
.029 .63393 L
.03101 .65474 L
.03354 .67557 L
.03689 .69677 L
.04026 .71296 L
.04423 .72693 L
.04631 .7324 L
.04864 .73716 L
.05267 .74231 L
.05495 .74359 L
.05703 .74376 L
.06106 .74142 L
.0648 .73608 L
.06822 .72839 L
.07174 .71742 L
.07489 .70464 L
.07758 .69106 L
.08048 .67306 L
.0833 .65113 L
.08558 .62869 L
.08737 .60619 L
.0882 .59348 L
.08898 .57945 L
.09003 .55437 L
Mistroke
.09045 .53985 L
.09075 .52441 L
.09093 .49663 L
.09067 .47095 L
.09008 .44736 L
.08904 .42211 L
.08828 .40836 L
.08749 .39615 L
.08582 .37502 L
.08372 .354 L
.07919 .32062 L
.07629 .30487 L
.07338 .29216 L
.06999 .28067 L
.06802 .27544 L
.06616 .27137 L
.06278 .26605 L
.05902 .26314 L
.05569 .26314 L
.05216 .26582 L
.04875 .27115 L
.04562 .2786 L
.04292 .28723 L
.04013 .29859 L
.03707 .31442 L
.03452 .33109 L
.03205 .35119 L
.02975 .37531 L
.02799 .39936 L
.02671 .42282 L
.02581 .44607 L
.0252 .47137 L
.02497 .49876 L
.02503 .51416 L
.0252 .52821 L
.02581 .55373 L
.02686 .57978 L
.02758 .59316 L
.02847 .60702 L
.03037 .63064 L
.03311 .65613 L
.03599 .67644 L
.03908 .69317 L
.04263 .70757 L
.04584 .71704 L
.04952 .72435 L
.05162 .72701 L
.05356 .72853 L
.05582 .72921 L
.05796 .72879 L
Mistroke
.06173 .72555 L
.06383 .72234 L
.06574 .71849 L
.06939 .70864 L
.07264 .69671 L
.07812 .66825 L
.08079 .64919 L
.08295 .63003 L
.08497 .60747 L
.08667 .58226 L
.08777 .55946 L
.08824 .54633 L
.08856 .53408 L
.0889 .51145 L
.08889 .48744 L
.08857 .46622 L
.08799 .44669 L
.08706 .42586 L
.08573 .40436 L
.08406 .38397 L
.08189 .36335 L
.07926 .34399 L
.07652 .32825 L
.07373 .31564 L
.07103 .30617 L
.06778 .29773 L
.0646 .29234 L
.06177 .28975 L
.05865 .28922 L
.05539 .29128 L
.0524 .29563 L
.04967 .3018 L
.04726 .30915 L
.04461 .31963 L
.04225 .33146 L
.03989 .34616 L
.03764 .36382 L
.03592 .38059 L
.03433 .40007 L
.03295 .42222 L
.03198 .44402 L
.03156 .45698 L
.03124 .47082 L
.03097 .49589 L
.0311 .52064 L
.03135 .53451 L
.03168 .54718 L
.03256 .56996 L
.03385 .59313 L
.03531 .61275 L
Mistroke
.03693 .62998 L
.0414 .66427 L
.04428 .67983 L
.04723 .69214 L
.05004 .70102 L
.05323 .70829 L
.05508 .71127 L
.05678 .71326 L
.05876 .71469 L
.06064 .71521 L
.06397 .71415 L
.06754 .71021 L
.07057 .70451 L
.07331 .69737 L
.07618 .68762 L
.07909 .6751 L
.0819 .65988 L
.08432 .64369 L
.08628 .62767 L
.0881 .60949 L
.08944 .593 L
.09066 .5741 L
.09153 .55644 L
.09213 .53957 L
.09256 .51959 L
.0927 .50125 L
.09257 .48128 L
.09212 .46064 L
.09134 .44034 L
.09077 .42925 L
.09015 .41931 L
.08883 .40215 L
.0871 .3846 L
.08348 .35799 L
.0812 .34582 L
.07891 .33613 L
.07608 .32702 L
.07328 .32071 L
.07069 .31705 L
.06782 .31529 L
.06618 .31535 L
.0647 .31606 L
.06301 .31767 L
.06143 .31996 L
.05867 .32585 L
.05582 .33479 L
.05347 .34468 L
.05143 .35557 L
.0492 .37048 L
.0474 .38574 L
Mistroke
.04576 .40333 L
.04447 .42121 L
.04341 .44119 L
.04294 .45286 L
.04261 .46385 L
.04225 .4823 L
.04214 .49982 L
.04227 .5191 L
.0427 .53971 L
.04348 .56081 L
.04451 .58023 L
.04568 .59695 L
.04719 .61425 L
.04913 .63186 L
.05147 .6487 L
.05434 .6648 L
.05722 .67724 L
.06007 .68664 L
.06286 .69345 L
.06601 .69865 L
.06781 .70053 L
.06946 .70158 L
.07253 .7019 L
.07536 .70033 L
.07842 .69659 L
.0816 .69041 L
.08425 .68331 L
.08664 .67524 L
.09163 .65228 L
.09389 .63835 L
.09611 .62167 L
.09798 .60421 L
.09966 .58447 L
.1009 .56519 L
.10176 .54722 L
.10234 .52894 L
.10263 .51163 L
.10265 .49159 L
.10254 .48162 L
.10232 .4708 L
.10168 .45219 L
.10082 .43552 L
.09948 .41706 L
.09798 .40151 L
.09593 .38539 L
.09373 .37211 L
.09162 .36231 L
.08918 .35373 L
.08676 .34768 L
.08447 .34393 L
Mistroke
.08235 .34209 L
.08001 .34179 L
.07758 .34341 L
.07535 .34671 L
.07412 .34931 L
.07281 .35274 L
.07052 .36054 L
.06842 .37 L
.06662 .38031 L
.06486 .39298 L
.06316 .40866 L
.06169 .4267 L
.06061 .44492 L
.05996 .46054 L
.0595 .47819 L
.05931 .49705 L
.05939 .51478 L
.05971 .53144 L
.06019 .54642 L
.06098 .5634 L
.06194 .57894 L
.06322 .59522 L
.06484 .61148 L
.06832 .63758 L
.07056 .65013 L
.07282 .66044 L
.07545 .67006 L
.07843 .67834 L
.08002 .68174 L
.08153 .68441 L
.0844 .68797 L
.08754 .68976 L
.08932 .68985 L
.09094 .68934 L
.09366 .68726 L
.09659 .68325 L
.09956 .67723 L
.10223 .67003 L
.10525 .65958 L
.10791 .648 L
.1123 .62249 L
.11437 .6064 L
.11602 .59067 L
.11752 .57264 L
.11819 .56259 L
.11874 .55294 L
.11945 .53669 L
.11987 .52179 L
.12009 .50586 L
.1201 .49695 L
Mistroke
.12004 .48877 L
.11977 .47415 L
.11933 .46134 L
.11861 .44719 L
.11774 .43462 L
.11657 .4217 L
.11511 .40931 L
.1137 .39988 L
.11201 .39085 L
.11004 .38279 L
.1089 .37912 L
.10779 .37618 L
.10674 .3739 L
.10557 .37195 L
.1035 .36987 L
.10148 .36949 L
.09964 .37056 L
.09764 .3733 L
.09559 .37791 L
.09388 .38336 L
.09237 .38959 L
.09082 .39758 L
.08929 .40758 L
.08781 .41998 L
.08661 .43297 L
.08566 .44664 L
.08498 .46002 L
.08447 .47517 L
.08428 .48403 L
.08418 .49245 L
.08416 .50142 L
.0842 .50969 L
.08434 .51927 L
.08455 .52837 L
.08483 .53729 L
.08517 .54564 L
.08599 .56102 L
.08712 .57712 L
.08864 .59376 L
.09021 .60754 L
.0921 .62108 L
.09598 .64232 L
.09843 .65238 L
.10123 .66149 L
.104 .66841 L
.10661 .67326 L
.10824 .67553 L
.10976 .67716 L
.11144 .67843 L
.11324 .67919 L
Mistroke
.1148 .67935 L
.11626 .6791 L
.11786 .67838 L
.11957 .67708 L
.12239 .67376 L
.12489 .66954 L
.12769 .66332 L
.13022 .65621 L
.13443 .64085 L
.13843 .62089 L
.1421 .59575 L
.14361 .5822 L
.145 .56685 L
.14596 .55351 L
.1464 .54612 L
.14675 .53911 L
.14727 .52555 L
.14756 .51332 L
.14767 .5008 L
.14765 .49382 L
.14757 .48739 L
.14725 .47485 L
.14699 .46808 L
.14669 .46206 L
.14608 .4524 L
.14525 .44258 L
.14423 .43325 L
.14315 .42548 L
.14171 .41747 L
.14024 .41124 L
.13883 .40681 L
.13724 .40329 L
.13639 .40201 L
.13545 .40104 L
.13446 .40051 L
.13352 .40047 L
.13187 .4015 L
.13095 .4027 L
.13012 .40419 L
.12858 .40803 L
.12719 .41283 L
.12602 .41809 L
.12484 .42474 L
.12367 .43308 L
.1226 .44303 L
.12183 .45236 L
.12114 .46338 L
.12067 .47437 L
.12039 .48484 L
.12024 .49738 L
Mistroke
.1203 .50958 L
.12051 .52103 L
.12085 .5317 L
.12138 .54342 L
.12213 .55577 L
.12426 .58055 L
.12578 .59378 L
.12738 .6053 L
.13079 .62468 L
.13494 .64196 L
.13736 .64968 L
.14007 .65671 L
.14273 .66215 L
.14522 .66607 L
.14667 .66786 L
.14821 .66941 L
.14992 .67069 L
.15151 .67147 L
.15438 .67197 L
.15601 .67173 L
.15753 .67117 L
.16025 .66936 L
.16175 .66791 L
.1631 .66634 L
.16806 .65826 L
.17072 .65236 L
.17347 .64498 L
.17807 .62931 L
.18192 .61212 L
.18536 .59228 L
.18776 .57448 L
.18888 .56429 L
.18979 .55462 L
.19053 .5453 L
.19118 .5353 L
.19163 .52637 L
.19193 .5183 L
.19213 .50983 L
.19222 .50084 L
.19216 .49192 L
.19197 .48404 L
.19168 .47715 L
.19132 .47106 L
.19093 .46599 L
.19043 .46093 L
.18981 .45602 L
.18908 .45147 L
.18833 .44787 L
.18761 .44518 L
.18675 .44285 L
Mistroke
.18593 .44134 L
.185 .44045 L
.184 .44039 L
.1835 .44071 L
.18296 .44132 L
.182 .44313 L
.18109 .44576 L
.1803 .44892 L
.17961 .45247 L
.17902 .45632 L
.17842 .46111 L
.17787 .46689 L
.17741 .47321 L
.17703 .48047 L
.17681 .4871 L
.17667 .49477 L
.17664 .49929 L
.17666 .50433 L
.17672 .5092 L
.17681 .51377 L
.17709 .52263 L
.17754 .53223 L
.17819 .5427 L
.17897 .55257 L
.18133 .57492 L
.18404 .5936 L
.18703 .60969 L
.19105 .62663 L
.19536 .64071 L
.20021 .65282 L
.20511 .66188 L
.20971 .66799 L
.21238 .67058 L
.21485 .67242 L
.21756 .67383 L
.2201 .67462 L
.22289 .6749 L
.22446 .67481 L
.22589 .67456 L
.22875 .67362 L
.23036 .67284 L
.23184 .67196 L
.23736 .66732 L
.24194 .66187 L
.24609 .65566 L
.25487 .63838 L
.26233 .61876 L
.26906 .59641 L
.27821 .55613 L
.28339 .52729 L
Mistroke
.28387 .52488 L
.28434 .52278 L
.28476 .52132 L
.28494 .5208 L
.28512 .52042 L
.28543 .51997 L
.2856 .51988 L
.28577 .51988 L
.28596 .52002 L
.28614 .52026 L
.28648 .52101 L
.28682 .52209 L
.2872 .52363 L
.28797 .52738 L
.29026 .54021 L
.29667 .57294 L
.30848 .618 L
.31785 .64542 L
.32817 .67033 L
.35303 .71637 L
.38249 .75655 L
.41426 .79154 L
.50173 .87564 L
.55505 .92295 L
.58354 .94485 L
.5965 .95349 L
.61103 .96189 L
.62335 .96774 L
.63021 .97042 L
.63676 .97255 L
.64421 .97442 L
.65104 .97557 L
.65745 .97613 L
.66446 .97611 L
.67217 .97527 L
.67913 .97369 L
.68298 .97247 L
.68714 .97085 L
.69462 .9671 L
.7016 .96255 L
.70888 .95663 L
.72164 .94294 L
.73695 .91992 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.0238095 0.64881 0.321429 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.500001 0.221783 0.499996 0.443845 [
[.5 1.0125 -3.5 0 ]
[.5 1.0125 3.5 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -64.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.000 15.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
.82215 .53288 m
.8226 .52671 L
.82292 .52065 L
.82318 .51316 L
.82332 .50564 L
.82335 .49835 L
.82329 .49138 L
.82311 .48349 L
.82281 .47491 L
.82237 .46613 L
.82176 .45656 L
.82025 .43914 L
.81782 .41871 L
.81499 .40083 L
.81154 .38379 L
.80786 .36949 L
.80337 .3558 L
.79813 .34383 L
.79561 .33931 L
.7928 .33512 L
.79027 .33204 L
.78755 .3294 L
.78506 .32758 L
.7823 .32616 L
.77977 .32541 L
.77741 .32515 L
.77595 .32521 L
.77439 .32544 L
.77161 .32629 L
.77007 .327 L
.76863 .32781 L
.76538 .33018 L
.76008 .33561 L
.7546 .3433 L
.74508 .36182 L
.73751 .3818 L
.72479 .42924 L
.71765 .46702 L
.71674 .47209 L
.71591 .47622 L
.71556 .47763 L
.71522 .47878 L
.71494 .47948 L
.71464 .47994 L
.71446 .48007 L
.7143 .48009 L
.71411 .47999 L
.71394 .47978 L
.71361 .47914 L
.71343 .47862 L
Mistroke
.71325 .47804 L
.71255 .47513 L
.71169 .4707 L
.70658 .44263 L
.69816 .40535 L
.6825 .3555 L
.67163 .32922 L
.65823 .30257 L
.63147 .26118 L
.59661 .21986 L
.51001 .13535 L
.46066 .09042 L
.40999 .05075 L
.3829 .03511 L
.36892 .02931 L
.36089 .02683 L
.35334 .02514 L
.34561 .0241 L
.34173 .02387 L
.33748 .02385 L
.32995 .02444 L
.32297 .02578 L
.31872 .02699 L
.31472 .02842 L
.30729 .03187 L
.29935 .0368 L
.29087 .04364 L
.27781 .05779 L
.26401 .07843 L
.2504 .10597 L
.23861 .13734 L
.2287 .17086 L
.22026 .2066 L
.21179 .25208 L
.20535 .29698 L
.20259 .32072 L
.2 .34691 L
.19809 .36992 L
.19636 .39538 L
.19488 .42377 L
.19427 .43926 L
.19383 .45366 L
.19333 .4793 L
.19321 .50634 L
.19333 .52099 L
.19356 .53433 L
.19393 .54875 L
.19446 .56373 L
.19566 .58815 L
.19741 .61375 L
Mistroke
.19934 .63525 L
.20177 .6569 L
.20436 .67568 L
.20701 .69172 L
.21321 .72049 L
.21681 .73309 L
.22084 .74448 L
.22485 .75337 L
.22875 .75995 L
.23232 .76439 L
.23624 .76763 L
.23986 .76921 L
.24386 .76941 L
.24802 .76796 L
.25188 .76511 L
.25544 .76117 L
.25863 .75654 L
.26556 .74269 L
.26914 .73329 L
.27236 .72334 L
.27912 .69683 L
.28481 .66638 L
.28735 .64913 L
.2898 .62917 L
.29311 .59322 L
.29445 .57255 L
.29539 .55275 L
.29601 .53369 L
.29633 .51605 L
.29641 .49535 L
.29621 .47555 L
.29567 .45372 L
.29469 .42952 L
.29323 .40414 L
.29147 .3804 L
.28734 .33826 L
.28155 .29405 L
.27304 .24468 L
.26335 .20139 L
.25342 .16651 L
.24145 .13398 L
.22908 .10942 L
.22181 .09882 L
.21828 .09468 L
.21497 .09136 L
.20888 .08673 L
.20214 .08383 L
.19554 .0833 L
.19185 .08404 L
.1885 .08537 L
Mistroke
.1822 .08964 L
.17645 .09567 L
.17026 .10463 L
.16387 .11684 L
.15366 .14357 L
.14821 .16219 L
.14339 .18181 L
.13835 .20614 L
.13333 .23538 L
.12936 .26325 L
.12562 .29487 L
.12247 .3278 L
.12009 .35881 L
.11818 .3908 L
.11684 .42143 L
.11627 .43867 L
.11582 .45762 L
.11552 .47738 L
.1154 .49575 L
.11559 .52826 L
.11634 .56229 L
.117 .58088 L
.11791 .60059 L
.12007 .63485 L
.12275 .66589 L
.12571 .69227 L
.12875 .71403 L
.13229 .73456 L
.13934 .76471 L
.1436 .77769 L
.14773 .78724 L
.15241 .79489 L
.15507 .79788 L
.15751 .7998 L
.16194 .80135 L
.16604 .80063 L
.17051 .79751 L
.17517 .79164 L
.17913 .7845 L
.18273 .77615 L
.19046 .75156 L
.1944 .73486 L
.19837 .71438 L
.20156 .69454 L
.20459 .67175 L
.20722 .64766 L
.20925 .6247 L
.21093 .60067 L
.21218 .57731 L
.21323 .54909 L
Mistroke
.21358 .53464 L
.21382 .51863 L
.21389 .48997 L
.21354 .46303 L
.21312 .44664 L
.2126 .43114 L
.21124 .40224 L
.20927 .37149 L
.20652 .3388 L
.20098 .28975 L
.19345 .24122 L
.18499 .20085 L
.17626 .16965 L
.17123 .15554 L
.16566 .14274 L
.15933 .13156 L
.1533 .12405 L
.14999 .1212 L
.14638 .11911 L
.14296 .11811 L
.1398 .11804 L
.13384 .1202 L
.12759 .12581 L
.12145 .13492 L
.116 .14629 L
.10995 .16299 L
.10451 .18229 L
.09575 .2244 L
.09139 .25227 L
.08778 .2804 L
.08461 .31063 L
.08173 .34512 L
.08035 .36556 L
.07925 .38469 L
.07831 .40442 L
.07759 .423 L
.07662 .46076 L
.07636 .48078 L
.07628 .50211 L
.07641 .52433 L
.07673 .54505 L
.07719 .56337 L
.07786 .58285 L
.07941 .61484 L
.08125 .64258 L
.08385 .67245 L
.08676 .69841 L
.09284 .73786 L
.09672 .75608 L
.10057 .77019 L
Mistroke
.10284 .77698 L
.10536 .78329 L
.11005 .79197 L
.11472 .79701 L
.11907 .79868 L
.12379 .79735 L
.12645 .79517 L
.12891 .79222 L
.13148 .78818 L
.13379 .78368 L
.13883 .77083 L
.1432 .75596 L
.14754 .73714 L
.15442 .69636 L
.15764 .67037 L
.16023 .64414 L
.16256 .61363 L
.16362 .59593 L
.16444 .5791 L
.16547 .55012 L
.16582 .53453 L
.16605 .51773 L
.16614 .49994 L
.16606 .48308 L
.16552 .45149 L
.16453 .42202 L
.16323 .39519 L
.16135 .36632 L
.15888 .33669 L
.15616 .31034 L
.15274 .28308 L
.14541 .23825 L
.1415 .21964 L
.13706 .20188 L
.13267 .18732 L
.12847 .17586 L
.12293 .16413 L
.11995 .1593 L
.11676 .15523 L
.11132 .15087 L
.10822 .14981 L
.10532 .14978 L
.09991 .15221 L
.09503 .15729 L
.08952 .16658 L
.08448 .17871 L
.08026 .19186 L
.07583 .20909 L
.07178 .2285 L
.06776 .25211 L
Mistroke
.06435 .27648 L
.06155 .30059 L
.05703 .35204 L
.055 .38465 L
.05358 .4159 L
.05253 .45085 L
.05202 .4884 L
.05212 .52393 L
.05273 .55678 L
.05369 .5854 L
.05516 .61514 L
.05721 .64537 L
.05949 .67101 L
.06255 .69797 L
.06585 .72063 L
.06895 .73769 L
.07249 .7532 L
.0766 .76697 L
.08057 .77662 L
.08495 .7836 L
.08746 .786 L
.08977 .78723 L
.09405 .78713 L
.09852 .78374 L
.10087 .7806 L
.10334 .77626 L
.10769 .76592 L
.11261 .74965 L
.11678 .73138 L
.12047 .71094 L
.12399 .68654 L
.12667 .66344 L
.12914 .63682 L
.13128 .60652 L
.1328 .57685 L
.13348 .55827 L
.13395 .54035 L
.13422 .52411 L
.13437 .50627 L
.13435 .48935 L
.13419 .47342 L
.13355 .44374 L
.13234 .41218 L
.13143 .39471 L
.13045 .37891 L
.12595 .32597 L
.12309 .3013 L
.11953 .27616 L
.11168 .23494 L
.10672 .2161 L
Mistroke
.10185 .2019 L
.09743 .19223 L
.09242 .18466 L
.08708 .18041 L
.08204 .17992 L
.07741 .18254 L
.07261 .18851 L
.0686 .1962 L
.06435 .20732 L
.05996 .22245 L
.05556 .24203 L
.04854 .28549 L
.04497 .31633 L
.04219 .34726 L
.03974 .38344 L
.03876 .40236 L
.03789 .42356 L
.0373 .44244 L
.0369 .4598 L
.03662 .47992 L
.03653 .499 L
.03678 .53258 L
.03715 .55126 L
.03764 .56827 L
.03905 .60161 L
.04087 .63122 L
.04289 .65607 L
.04544 .68074 L
.04864 .70485 L
.05241 .72669 L
.05591 .74219 L
.05998 .7557 L
.06434 .76564 L
.06849 .77129 L
.07068 .77289 L
.0731 .77358 L
.07563 .77313 L
.078 .77163 L
.08229 .76621 L
.08612 .75834 L
.09036 .74597 L
.09418 .73115 L
.09736 .71564 L
.1005 .6969 L
.10535 .65815 L
.10778 .63173 L
.10965 .60532 L
.11096 .58061 L
.11199 .55306 L
.11261 .52245 L
Mistroke
.11274 .49355 L
.11261 .47694 L
.11236 .46184 L
.11192 .44451 L
.11135 .42824 L
.1098 .39645 L
.10787 .36812 L
.10523 .33863 L
.10186 .30959 L
.09883 .2887 L
.09523 .2684 L
.09188 .25292 L
.08797 .23837 L
.0834 .2254 L
.08083 .21979 L
.07839 .21555 L
.07394 .21038 L
.06913 .20841 L
.06457 .21001 L
.06199 .21244 L
.05961 .21571 L
.05491 .22524 L
.05235 .23228 L
.05007 .23976 L
.0462 .25546 L
.04228 .27589 L
.03893 .29798 L
.03612 .32111 L
.03308 .35311 L
.03087 .38435 L
.02992 .4014 L
.02909 .41979 L
.02837 .44032 L
.0279 .45942 L
.02751 .49376 L
.02766 .52564 L
.02797 .5437 L
.0284 .55991 L
.02905 .57824 L
.02982 .59514 L
.03142 .62186 L
.03363 .64932 L
.03639 .67535 L
.03935 .69697 L
.0424 .71445 L
.04541 .72804 L
.04891 .74018 L
.05275 .7497 L
.0568 .75592 L
.0591 .75785 L
Mistroke
.0612 .75865 L
.06528 .75762 L
.0691 .75359 L
.07123 .75002 L
.07345 .74526 L
.0773 .7343 L
.08122 .71922 L
.08519 .69904 L
.08831 .67869 L
.09089 .65782 L
.09334 .63297 L
.09546 .60468 L
.09688 .579 L
.09785 .55409 L
.09849 .52619 L
.09865 .51034 L
.09868 .49576 L
.09844 .47056 L
.09789 .44731 L
.09694 .42226 L
.09553 .39626 L
.09362 .37012 L
.09143 .34681 L
.08643 .30771 L
.08334 .28981 L
.07965 .27273 L
.07551 .25809 L
.07142 .24759 L
.06748 .24076 L
.0638 .23712 L
.05951 .23613 L
.05545 .23842 L
.05115 .24442 L
.0488 .24936 L
.04671 .25482 L
.04279 .26804 L
.03932 .28351 L
.0356 .3051 L
.03255 .32798 L
.02966 .35603 L
.0272 .38844 L
.02568 .4162 L
.02501 .43236 L
.02453 .44754 L
.02395 .47577 L
.02381 .50594 L
.02408 .53267 L
.02468 .55729 L
.0257 .58349 L
.02722 .61041 L
Mistroke
.02916 .63569 L
.03171 .66094 L
.0348 .68423 L
.03803 .70275 L
.04133 .71719 L
.0445 .72767 L
.04831 .73654 L
.05202 .74171 L
.0553 .74365 L
.05891 .74308 L
.06265 .73951 L
.06607 .73352 L
.06918 .72569 L
.07192 .71675 L
.0776 .69091 L
.08042 .67344 L
.08278 .65553 L
.08523 .63236 L
.0871 .60988 L
.08856 .58731 L
.08962 .56533 L
.0904 .54156 L
.09085 .5155 L
.09089 .48921 L
.09056 .46543 L
.08976 .43846 L
.08859 .41372 L
.08717 .39176 L
.08558 .37244 L
.08108 .33306 L
.07829 .31541 L
.07544 .30088 L
.07208 .28742 L
.06825 .27603 L
.06627 .27162 L
.06407 .2678 L
.06196 .26518 L
.05999 .26362 L
.05624 .263 L
.05414 .264 L
.05226 .26574 L
.04837 .27195 L
.04646 .27637 L
.04441 .28223 L
.04094 .29505 L
.0379 .30976 L
.03464 .33027 L
.03201 .35168 L
.02944 .37917 L
.02751 .40749 L
Mistroke
.02626 .43346 L
.02539 .46202 L
.02502 .48685 L
.02503 .51436 L
.02552 .54349 L
.02601 .55956 L
.02659 .574 L
.02798 .59965 L
.02987 .625 L
.03201 .64669 L
.03468 .66782 L
.03752 .68521 L
.04037 .69886 L
.04309 .70908 L
.04623 .71796 L
.04963 .7245 L
.05288 .72807 L
.05672 .72913 L
.06035 .72708 L
.06356 .72277 L
.06698 .71551 L
.06886 .71025 L
.07053 .70479 L
.07408 .69033 L
.07712 .67437 L
.07972 .65734 L
.08371 .62217 L
.08532 .60277 L
.08676 .58051 L
.08771 .56083 L
.08843 .53931 L
.08883 .51875 L
.08894 .49996 L
.08876 .47651 L
.08827 .45516 L
.08738 .43235 L
.08606 .40912 L
.0846 .39004 L
.08299 .3732 L
.07853 .33944 L
.07601 .32575 L
.07312 .31331 L
.07023 .3038 L
.06749 .29715 L
.06416 .29183 L
.06226 .29007 L
.06049 .28926 L
.05724 .2898 L
.05383 .29327 L
.05064 .29938 L
Mistroke
.04735 .3089 L
.04441 .32061 L
.0419 .33348 L
.03922 .35103 L
.03667 .37288 L
.03465 .39579 L
.03315 .41865 L
.03219 .43861 L
.03146 .46087 L
.03107 .48234 L
.03097 .50223 L
.03116 .52423 L
.03171 .54802 L
.03267 .57218 L
.0339 .59377 L
.03555 .61549 L
.03742 .63455 L
.04163 .66565 L
.04434 .68009 L
.04702 .69133 L
.05013 .70125 L
.05358 .7089 L
.05682 .71327 L
.06041 .71517 L
.06381 .71424 L
.06693 .71107 L
.06996 .70582 L
.07263 .6993 L
.07559 .68982 L
.07823 .6791 L
.08093 .66551 L
.08354 .64927 L
.08748 .61609 L
.08923 .59578 L
.09056 .57594 L
.09165 .55346 L
.0921 .54064 L
.0924 .52886 L
.09267 .50913 L
.09265 .48827 L
.09238 .4707 L
.09182 .45172 L
.09092 .43209 L
.08962 .41195 L
.08809 .39415 L
.08646 .37903 L
.08294 .3549 L
.08069 .34348 L
.07845 .33446 L
.07595 .3267 L
Mistroke
.0736 .32133 L
.07081 .3172 L
.06813 .31539 L
.06542 .31566 L
.06253 .3183 L
.05986 .32302 L
.0575 .32918 L
.05486 .33859 L
.05217 .35141 L
.04985 .36581 L
.04792 .38099 L
.04604 .40003 L
.04459 .4195 L
.04355 .43806 L
.04275 .459 L
.04246 .4702 L
.04225 .48263 L
.04215 .49572 L
.04216 .50797 L
.04246 .52989 L
.04315 .553 L
.04415 .57411 L
.04537 .59282 L
.047 .61224 L
.04907 .63126 L
.0532 .65887 L
.05588 .67181 L
.05856 .68195 L
.06111 .68939 L
.06388 .69539 L
.06631 .69899 L
.069 .70133 L
.07194 .70198 L
.07506 .70055 L
.07798 .69724 L
.08057 .69265 L
.08346 .68561 L
.08604 .67739 L
.08895 .66572 L
.09142 .65341 L
.09581 .62407 L
.09781 .60591 L
.09941 .58769 L
.10053 .57147 L
.10148 .55377 L
.10207 .53844 L
.10249 .52138 L
.10268 .50317 L
.10257 .48377 L
.10218 .46587 L
Mistroke
.10158 .44998 L
.10068 .43342 L
.09945 .41674 L
.09804 .40214 L
.09657 .38998 L
.09463 .37717 L
.09231 .36528 L
.08994 .35613 L
.08762 .34959 L
.08514 .34486 L
.08277 .34235 L
.08013 .34178 L
.07866 .34247 L
.07732 .34374 L
.07593 .3457 L
.07467 .3481 L
.0732 .35167 L
.0719 .35558 L
.06959 .36445 L
.06731 .37613 L
.0655 .38806 L
.06399 .40054 L
.06254 .41558 L
.06127 .43306 L
.06074 .44229 L
.06026 .45263 L
.05963 .47206 L
.05934 .49155 L
.05935 .50984 L
.0596 .5269 L
.06006 .54279 L
.0608 .55992 L
.06187 .57784 L
.0632 .59486 L
.06487 .61173 L
.0685 .63862 L
.07091 .65185 L
.07329 .6623 L
.0762 .67237 L
.0791 .67984 L
.08188 .68493 L
.0845 .68804 L
.08741 .68971 L
.09051 .68951 L
.0936 .6873 L
.09532 .68519 L
.09687 .68275 L
.09981 .67662 L
.10249 .66921 L
.10544 .65878 L
Mistroke
.108 .64752 L
.11059 .63353 L
.11302 .61722 L
.1148 .60262 L
.11646 .58578 L
.11773 .56969 L
.11865 .5547 L
.11907 .54609 L
.11945 .53671 L
.11975 .52679 L
.11996 .51742 L
.12007 .5087 L
.1201 .49953 L
.11996 .48337 L
.11961 .46886 L
.11898 .45389 L
.11817 .4405 L
.11726 .42898 L
.116 .41655 L
.11441 .40437 L
.11272 .39435 L
.111 .38645 L
.10927 .38024 L
.1073 .37506 L
.10537 .37169 L
.10356 .36993 L
.10192 .36946 L
.10011 .37018 L
.09824 .37231 L
.09654 .37556 L
.0946 .3809 L
.09286 .38742 L
.09139 .39445 L
.08991 .40328 L
.08845 .4142 L
.08711 .42716 L
.08614 .43922 L
.08529 .45346 L
.08468 .46802 L
.08432 .4821 L
.08416 .49799 L
.08418 .50702 L
.08427 .51527 L
.08466 .53198 L
.08499 .54137 L
.08538 .54997 L
.08628 .5655 L
.08748 .58143 L
.09023 .60761 L
.09344 .62928 L
Mistroke
.09759 .64913 L
.10016 .65824 L
.10262 .66519 L
.10538 .67113 L
.10695 .67376 L
.1084 .6757 L
.11126 .6783 L
.11397 .6793 L
.11552 .67926 L
.11716 .67873 L
.12006 .67659 L
.12166 .67475 L
.12313 .67262 L
.1264 .66637 L
.12914 .65942 L
.13161 .65166 L
.13587 .63433 L
.13983 .61228 L
.14174 .59856 L
.14327 .58541 L
.14545 .56092 L
.1463 .54779 L
.14697 .53395 L
.14738 .52193 L
.14759 .51089 L
.14767 .49902 L
.14755 .48671 L
.14741 .47991 L
.14722 .47379 L
.14695 .46727 L
.14661 .4606 L
.14589 .44999 L
.14491 .43928 L
.14389 .43068 L
.14266 .42252 L
.14137 .4159 L
.14012 .41083 L
.1386 .40624 L
.13781 .40441 L
.13692 .40279 L
.13532 .40096 L
.1338 .40045 L
.13293 .40069 L
.13202 .40136 L
.13042 .40362 L
.12954 .40547 L
.12874 .40756 L
.127 .41362 L
.1256 .42032 L
.12438 .42781 L
Mistroke
.12338 .43553 L
.12246 .44459 L
.12162 .45537 L
.12101 .46608 L
.12055 .47831 L
.12038 .48553 L
.12028 .49245 L
.12026 .50511 L
.12034 .51232 L
.12046 .51891 L
.12086 .53183 L
.12142 .54401 L
.1223 .55813 L
.12332 .57087 L
.12477 .58528 L
.12636 .59812 L
.12951 .61806 L
.13359 .63692 L
.13809 .65172 L
.1408 .65832 L
.14336 .66323 L
.14577 .66678 L
.14838 .66954 L
.15064 .67107 L
.15314 .67189 L
.15583 .67176 L
.15734 .67124 L
.15872 .67048 L
.16124 .66842 L
.16386 .66532 L
.1661 .66187 L
.16844 .65746 L
.17247 .64778 L
.1769 .63372 L
.1805 .61895 L
.18375 .6022 L
.18674 .58256 L
.18917 .56135 L
.19008 .55112 L
.19079 .54148 L
.19132 .53273 L
.19175 .52339 L
.19202 .5151 L
.19217 .50765 L
.19222 .49911 L
.19215 .49172 L
.19195 .48366 L
.19165 .47658 L
.19124 .46993 L
.19068 .46332 L
Mistroke
.18998 .45722 L
.18923 .45233 L
.18847 .44847 L
.18772 .44558 L
.18682 .44301 L
.18594 .44136 L
.18495 .44044 L
.18445 .44031 L
.1839 .44045 L
.18294 .44137 L
.18205 .44302 L
.18153 .44438 L
.18105 .44592 L
.18019 .44946 L
.17933 .4542 L
.17851 .4604 L
.17789 .46664 L
.17742 .47302 L
.17722 .47659 L
.17702 .48067 L
.17687 .48511 L
.17675 .48942 L
.17665 .49771 L
.17667 .50564 L
.17674 .51015 L
.17685 .51515 L
.17717 .52445 L
.17757 .53288 L
.17817 .54232 L
.17982 .56158 L
.18189 .5792 L
.18431 .59518 L
.1877 .61282 L
.19187 .62959 L
.19586 .64211 L
.20061 .65365 L
.20611 .66338 L
.20932 .66753 L
.2123 .6705 L
.21512 .67257 L
.21673 .67345 L
.21822 .67407 L
.22096 .67476 L
.22388 .67485 L
.22656 .67438 L
.22948 .67328 L
.23221 .6717 L
.23471 .66979 L
.23936 .66511 L
.24415 .65871 L
Mistroke
.25426 .63975 L
.26221 .61913 L
.27393 .57666 L
.28059 .54315 L
.28292 .52988 L
.28378 .52532 L
.28446 .52234 L
.2848 .5212 L
.2851 .52045 L
.28542 .51999 L
.28559 .51989 L
.28575 .51989 L
.28607 .52016 L
.28625 .52048 L
.28643 .52088 L
.28679 .52201 L
.28721 .52367 L
.29828 .58006 L
.31074 .62512 L
.3203 .65174 L
.33083 .67605 L
.35673 .72204 L
.39061 .76604 L
.46779 .84376 L
.51667 .88938 L
.54603 .91538 L
.57518 .93879 L
.60246 .95711 L
.61822 .96545 L
.63283 .97132 L
.63687 .97257 L
.64118 .97373 L
.64896 .97528 L
.65373 .97587 L
.65823 .97616 L
.66227 .97619 L
.66662 .97596 L
.67051 .97552 L
.67477 .97477 L
.6792 .97367 L
.68333 .97235 L
.69068 .96921 L
.69848 .96471 L
.70605 .95908 L
.71294 .95275 L
.72812 .93417 L
.74089 .9126 L
.75364 .88421 L
.76419 .85398 L
.77324 .82162 L
Mistroke
.78211 .7819 L
.79028 .7348 L
.79703 .6829 L
.80005 .65263 L
.80232 .62465 L
.80403 .59817 L
.80541 .56939 L
.80629 .54227 L
.80672 .51752 L
.80677 .48901 L
.80639 .46299 L
.80599 .44839 L
.80551 .43531 L
.80406 .4069 L
.80217 .38106 L
.79962 .3548 L
.79677 .33196 L
.79377 .31266 L
.79092 .29745 L
.78761 .28271 L
.78109 .26057 L
.77704 .2505 L
.77263 .24211 L
.76876 .23675 L
.76445 .23276 L
.76207 .23141 L
.75981 .23067 L
.75558 .23064 L
.75321 .23138 L
.75104 .23255 L
.74867 .23435 L
.74618 .23684 L
.74211 .24224 L
.73839 .2487 L
.73441 .25732 L
.73035 .26815 L
.72313 .29336 L
.71725 .32145 L
.71409 .34065 L
.71146 .35996 L
.70937 .37846 L
.7075 .39888 L
.70612 .41779 L
.70494 .43919 L
.70418 .45918 L
.70374 .47823 L
.70357 .50117 L
.70375 .52239 L
.70398 .53424 L
.70435 .54718 L
Mistroke
.70532 .57084 L
.70651 .59197 L
.7079 .6118 L
.71209 .6567 L
.7175 .69955 L
.72476 .74389 L
.73232 .78067 L
.74138 .81628 L
.74996 .84367 L
.76 .86938 L
.76643 .88269 L
.77254 .89323 L
.77841 .90148 L
.78498 .90862 L
.79096 .91321 L
.7966 .91584 L
.80258 .91682 L
.80899 .91572 L
.8159 .91193 L
.81977 .90857 L
.82332 .90464 L
.82973 .89542 L
.83636 .8827 L
.84723 .85369 L
.85299 .83327 L
.85807 .81162 L
.86635 .76675 L
.87357 .71258 L
.87839 .6619 L
.88053 .63182 L
.88212 .60321 L
.88349 .56943 L
.88428 .53733 L
.88459 .5086 L
.88449 .47778 L
.88388 .4449 L
.88267 .41122 L
.8812 .38367 L
.87914 .3549 L
.87652 .32696 L
.8737 .30309 L
.8699 .27755 L
.86608 .25726 L
.86241 .24161 L
.85821 .22736 L
.85355 .21538 L
.84901 .20704 L
.84479 .20193 L
.8401 .19901 L
.83518 .1989 L
Mistroke
.83061 .20144 L
.82637 .20606 L
.82259 .21211 L
.81833 .22116 L
.81444 .23169 L
.80629 .26189 L
.80258 .28023 L
.79886 .30261 L
.79601 .32324 L
.79331 .34693 L
.79115 .37037 L
.78946 .39311 L
.78789 .42087 L
.78726 .43592 L
.78673 .45222 L
.78634 .46959 L
.78613 .48615 L
.78607 .50114 L
.78616 .51746 L
.7867 .5474 L
.78716 .5625 L
.78782 .57907 L
.78936 .60819 L
.79122 .63506 L
.79659 .69074 L
.80315 .73879 L
.81195 .78594 L
.81704 .80726 L
.82291 .82779 L
.82888 .84477 L
.8346 .85782 L
.84025 .86783 L
.84636 .87563 L
.85194 .88008 L
.85718 .88194 L
.86294 .88138 L
.86907 .87767 L
.87499 .87085 L
.88035 .86174 L
.88604 .84863 L
.89183 .83122 L
.90078 .79421 L
.90536 .76909 L
.90926 .74312 L
.91259 .71642 L
.91538 .68946 L
.9176 .66382 L
.9196 .63546 L
.92132 .6039 L
.92252 .574 L
Mistroke
.92341 .53807 L
.92373 .50547 L
.92355 .47142 L
.92292 .44027 L
.92172 .40719 L
.91988 .37341 L
.91736 .34034 L
.91446 .3116 L
.91146 .28823 L
.90783 .26566 L
.90412 .24743 L
.9004 .23297 L
.89632 .22074 L
.89164 .21066 L
.8875 .20491 L
.88365 .20199 L
.8794 .20135 L
.87493 .20352 L
.87006 .20923 L
.86573 .21731 L
.86092 .22989 L
.8566 .24478 L
.8496 .27783 L
.84612 .29979 L
.84324 .3219 L
.84067 .34592 L
.83835 .3733 L
.83722 .38963 L
.83633 .4049 L
.8356 .41968 L
.83497 .43567 L
.83446 .45241 L
.83413 .46811 L
.8339 .48695 L
.83386 .50413 L
.83397 .52048 L
.83424 .53817 L
.83515 .57011 L
.8365 .59988 L
.83813 .6265 L
.84049 .6564 L
.84317 .68364 L
.84896 .72876 L
.85659 .77171 L
.86108 .79112 L
.86636 .80973 L
.87219 .82576 L
.87495 .83183 L
.8779 .83734 L
.88337 .84494 L
Mistroke
.88847 .84906 L
.89401 .85033 L
.89714 .84956 L
.90004 .84786 L
.90584 .84153 L
.90905 .83624 L
.91195 .83028 L
.91714 .81662 L
.92236 .79843 L
.93057 .75833 L
.93466 .73113 L
.93805 .70316 L
.94139 .66844 L
.94395 .63339 L
.94574 .60059 L
.9471 .5639 L
.94757 .54475 L
.94789 .52353 L
.94801 .50141 L
.94793 .48074 L
.94731 .44448 L
.9467 .42459 L
.94598 .40674 L
.9442 .37435 L
.94206 .34565 L
.93978 .32177 L
.93694 .2981 L
.93347 .27526 L
.92943 .25467 L
.92571 .2402 L
.92141 .22771 L
.91724 .21939 L
.91334 .2146 L
.90878 .21241 L
.90444 .2136 L
.90048 .21743 L
.89687 .22327 L
.89302 .23211 L
.88906 .24419 L
.88466 .26173 L
.88092 .28077 L
.87719 .30457 L
.87375 .33261 L
.8712 .35911 L
.86923 .38532 L
.86754 .41542 L
.86682 .43279 L
.86631 .44887 L
.86573 .47908 L
.86563 .50735 L
Mistroke
.86601 .53846 L
.86638 .5541 L
.86695 .57126 L
.86824 .59952 L
.87011 .62918 L
.8723 .65616 L
.87467 .67981 L
.8778 .70552 L
.88113 .72803 L
.88822 .76469 L
.89262 .78169 L
.8969 .79485 L
.9018 .80632 L
.90433 .81086 L
.90715 .81485 L
.91194 .81913 L
.91636 .82032 L
.92145 .81841 L
.92623 .81327 L
.93054 .80569 L
.93443 .79623 L
.93854 .78321 L
.94269 .76641 L
.94723 .74283 L
.95101 .7179 L
.95466 .68729 L
.95789 .65188 L
.96013 .61891 L
.96172 .58684 L
.9624 .56802 L
.96288 .5507 L
.96326 .53059 L
.96345 .51153 L
.96337 .47894 L
.96276 .44499 L
.96181 .41687 L
.96033 .38717 L
.95826 .35724 L
.95551 .32768 L
.95247 .30271 L
.94934 .28263 L
.94563 .2641 L
.94189 .2499 L
.93836 .23996 L
.93441 .23224 L
.92999 .22746 L
.92774 .22649 L
.92527 .22653 L
.92091 .22938 L
.91691 .23516 L
Mistroke
.91298 .24391 L
.90941 .25478 L
.90319 .2814 L
.90005 .29949 L
.8974 .31807 L
.89482 .34009 L
.89243 .36565 L
.89046 .3929 L
.88905 .41904 L
.88807 .4448 L
.88745 .47252 L
.88725 .50335 L
.88752 .53211 L
.88788 .54855 L
.88833 .56339 L
.889 .58033 L
.88978 .5961 L
.8916 .62482 L
.89403 .65381 L
.89959 .70093 L
.90328 .72376 L
.90707 .74259 L
.91156 .76009 L
.91417 .76825 L
.9167 .77488 L
.91896 .77982 L
.92145 .78422 L
.92586 .78948 L
.92839 .79107 L
.93108 .79162 L
.93588 .78968 L
.94027 .78451 L
.94427 .77676 L
.94851 .76506 L
.95282 .74892 L
.95714 .72753 L
.96134 .69999 L
.96479 .67031 L
.96745 .64019 L
.9694 .6113 L
.97101 .57793 L
.9716 .56073 L
.97208 .54199 L
.97249 .50784 L
.97235 .47502 L
.97176 .44506 L
.97059 .41326 L
.96971 .39614 L
.96879 .38109 L
.96653 .35234 L
Mistroke
.96357 .32419 L
.96032 .3009 L
.957 .28256 L
.95372 .26855 L
.95048 .258 L
.94678 .24935 L
.94269 .24352 L
.94062 .24195 L
.93835 .24126 L
.93422 .2427 L
.93024 .24737 L
.92665 .25448 L
.92269 .26569 L
.91875 .28088 L
.91562 .29637 L
.91247 .31576 L
.90944 .3392 L
.90668 .36679 L
.90457 .39478 L
.90309 .42155 L
.90204 .4495 L
.90148 .47585 L
.90132 .50505 L
.90143 .51979 L
.90168 .53595 L
.90244 .56271 L
.90371 .59079 L
.90532 .61633 L
.90714 .63862 L
.90932 .66014 L
.91197 .68141 L
.91752 .71459 L
.92134 .73119 L
.92518 .74395 L
.92878 .75285 L
.93279 .75963 L
.93644 .76305 L
.94047 .7639 L
.94467 .76149 L
.94854 .75617 L
.95207 .74853 L
.95518 .73936 L
.9586 .72625 L
.96165 .71142 L
.96459 .69368 L
.96745 .67212 L
.96963 .65165 L
.97169 .62755 L
.97355 .59912 L
.97436 .58299 L
Mistroke
.97499 .56768 L
.97579 .53969 L
.97618 .50936 L
.97619 .49263 L
.97607 .47727 L
.97579 .46056 L
.97534 .44312 L
.97421 .41465 L
.97338 .39907 L
.97247 .38496 L
.97051 .36056 L
.96832 .33926 L
.96543 .31729 L
.96249 .29988 L
.95943 .28572 L
.95648 .27521 L
.95294 .2659 L
.94949 .25996 L
.94622 .25692 L
.9432 .25621 L
.93988 .25771 L
.93642 .26182 L
.933 .26853 L
.92947 .27844 L
.92629 .29022 L
.92356 .30286 L
.92059 .31984 L
.91768 .34065 L
.91527 .36236 L
.91338 .38367 L
.91185 .40561 L
.91059 .4296 L
.9097 .45438 L
.90917 .48194 L
.90908 .50602 L
.90938 .53159 L
.91001 .55537 L
.91089 .57644 L
.91241 .60243 L
.91419 .62512 L
.91655 .64833 L
.91945 .67061 L
.92208 .68671 L
.92516 .7018 L
.92878 .71553 L
.93236 .72546 L
.93433 .72956 L
.93646 .73297 L
.94034 .73657 L
.94251 .73715 L
Mistroke
.94455 .73676 L
.94678 .73527 L
.94916 .73243 L
.95106 .7292 L
.95311 .72471 L
.9571 .71269 L
.96057 .69814 L
.96356 .68182 L
.96641 .66186 L
.96879 .64073 L
.97063 .62009 L
.97228 .59621 L
.97366 .56879 L
.97417 .55454 L
.9746 .53861 L
.975 .51009 L
.97495 .48331 L
.97447 .45586 L
.97401 .4408 L
.97348 .42741 L
.97214 .4022 L
.97053 .37978 L
.96825 .35556 L
.96579 .3355 L
.96276 .31625 L
.95922 .29936 L
.95613 .28841 L
.95267 .27956 L
.94929 .274 L
.94615 .27131 L
.94245 .27105 L
.94037 .27225 L
.93845 .27422 L
.93499 .27992 L
.93144 .28881 L
.92845 .29894 L
.92584 .30999 L
.92322 .32363 L
.92059 .34042 L
.91679 .37261 L
.91509 .39185 L
.91376 .41059 L
.91251 .43397 L
.91168 .45664 L
.91123 .47729 L
.91106 .49977 L
.91125 .52416 L
.9115 .53631 L
.91188 .5495 L
.91284 .57227 L
Mistroke
.91407 .5927 L
.91571 .61354 L
.91781 .63411 L
.9199 .65033 L
.92241 .66604 L
.92566 .68186 L
.92897 .69383 L
.9306 .69845 L
.93236 .70256 L
.93559 .70789 L
.93873 .7105 L
.94211 .71053 L
.94529 .70794 L
.94812 .70335 L
.95136 .69529 L
.95311 .6895 L
.95469 .68338 L
.95741 .67037 L
.9601 .65386 L
.96224 .63724 L
.96397 .62055 L
.9655 .60231 L
.96668 .58438 L
.96776 .56263 L
.96857 .53799 L
.96895 .51577 L
.96901 .49188 L
.96869 .46707 L
.96833 .45327 L
.9679 .44075 L
.96684 .41834 L
.96537 .39577 L
.96375 .37677 L
.962 .36027 L
.95987 .34397 L
.95727 .328 L
.9544 .31424 L
.95114 .30239 L
.94795 .29407 L
.94486 .28864 L
.94306 .28659 L
.94115 .28526 L
.93773 .28498 L
.93582 .28599 L
.93406 .28765 L
.93214 .29027 L
.93013 .29397 L
.92684 .30219 L
.92345 .3138 L
.92046 .32713 L
Mistroke
.91791 .34127 L
.91373 .37227 L
.91198 .38964 L
.91036 .40981 L
.9091 .4303 L
.9082 .45031 L
.90766 .46855 L
.90735 .48856 L
.90734 .51018 L
.90748 .52214 L
.9077 .53286 L
.90837 .5533 L
.9093 .57183 L
.91041 .58852 L
.91183 .60513 L
.91495 .63179 L
.91698 .64465 L
.91902 .65522 L
.92142 .6651 L
.92414 .67357 L
.92689 .67958 L
.92849 .68199 L
.93 .68358 L
.93308 .68476 L
.93481 .68423 L
.93639 .68298 L
.93902 .67924 L
.94181 .67283 L
.9446 .6636 L
.94704 .65281 L
.94971 .63728 L
.95194 .62022 L
.95368 .60313 L
.95525 .58299 L
.95657 .55943 L
.95706 .54706 L
.95747 .53317 L
.9577 .52114 L
.95784 .50809 L
.95786 .49571 L
.95778 .4844 L
.95736 .46227 L
.95701 .45123 L
.95653 .4392 L
.95542 .41856 L
.95409 .40004 L
.95219 .37972 L
.95016 .36262 L
.94763 .34581 L
.94468 .33057 L
Mistroke
.94208 .32018 L
.93914 .3112 L
.93625 .30482 L
.93356 .30082 L
.93033 .29833 L
.9285 .29797 L
.92681 .2983 L
.92373 .30056 L
.92052 .3052 L
.91758 .3116 L
.9145 .3207 L
.91175 .33119 L
.90935 .34244 L
.90532 .36717 L
.90339 .38269 L
.90184 .39762 L
.90039 .41489 L
.89915 .43381 L
.89863 .44391 L
.89815 .45512 L
.89758 .47497 L
.89733 .49373 L
.8974 .51362 L
.89776 .53198 L
.89833 .5482 L
.89914 .56382 L
.90024 .57954 L
.90136 .59215 L
.90279 .60506 L
.90451 .61758 L
.90657 .62943 L
.90869 .63891 L
.91074 .64603 L
.91277 .65133 L
.91472 .65495 L
.9169 .65742 L
.91925 .6583 L
.92172 .65725 L
.92403 .65438 L
.92605 .65028 L
.92817 .64422 L
.93036 .63578 L
.93224 .62646 L
.93423 .61392 L
.93592 .60038 L
.93718 .5876 L
.93834 .57296 L
.93935 .55585 L
.94005 .5392 L
.94035 .52867 L
Mistroke
.94055 .51885 L
.94067 .50792 L
.94069 .49631 L
.94047 .47667 L
.94021 .46557 L
.93987 .45529 L
.93901 .43641 L
.93797 .41976 L
.93647 .40141 L
.93478 .38515 L
.93058 .35593 L
.92812 .3436 L
.9252 .3321 L
.92257 .32415 L
.91961 .31754 L
.91674 .31321 L
.91406 .31087 L
.91251 .31024 L
.91086 .31013 L
.9079 .31135 L
.9061 .31299 L
.90443 .31515 L
.90135 .3207 L
.89822 .32863 L
.89547 .33769 L
.89249 .35009 L
.8899 .36355 L
.88796 .37577 L
.88605 .39004 L
.8833 .41694 L
.88209 .43296 L
.88109 .45038 L
.88048 .46541 L
.88005 .48203 L
.8799 .49728 L
.87996 .51104 L
.88023 .52577 L
.88076 .54072 L
.88141 .55317 L
.88217 .56418 L
.88316 .57553 L
.88438 .58672 L
.88602 .59841 L
.8877 .60776 L
.8897 .61629 L
.89078 .61992 L
.89198 .62325 L
.89404 .62745 L
.89602 .62979 L
.89724 .63045 L
Mistroke
.8984 .63052 L
.90058 .62921 L
.9025 .62644 L
.90449 .62184 L
.90629 .61598 L
.90784 .60945 L
.90953 .6003 L
.91119 .58878 L
.91255 .57649 L
.91362 .5641 L
.91454 .54997 L
.91519 .53579 L
.91559 .52254 L
.91582 .5077 L
.91581 .49123 L
.9157 .48284 L
.91551 .47358 L
.91496 .45727 L
.91421 .44219 L
.91329 .4282 L
.91211 .41397 L
.9095 .3902 L
.90602 .36768 L
.90378 .35662 L
.90155 .34754 L
.89897 .33907 L
.89603 .33165 L
.89464 .32887 L
.89315 .32637 L
.89043 .32301 L
.88778 .32116 L
.88528 .32064 L
.88254 .32139 L
.87963 .3237 L
.87804 .32562 L
.87659 .3278 L
.87338 .3341 L
.87066 .34113 L
.86791 .35002 L
.86314 .37052 L
.85949 .39233 L
.85663 .41553 L
.85532 .42931 L
.85431 .4424 L
.85347 .45638 L
.85291 .4691 L
.85268 .4761 L
.85249 .48365 L
.85234 .49715 L
.85238 .50839 L
Mistroke
.8526 .52036 L
.85303 .53229 L
.8536 .54284 L
.85427 .55207 L
.855 .55993 L
.85699 .57537 L
.85828 .58247 L
.85977 .58876 L
.86126 .59343 L
.86268 .59654 L
.86357 .59792 L
.86439 .59882 L
.86531 .5994 L
.86628 .59955 L
.86791 .59872 L
.86882 .59764 L
.86966 .59624 L
.87124 .59249 L
.87268 .58769 L
.87389 .58238 L
.87511 .57556 L
.87631 .56702 L
.87742 .55673 L
.87822 .54705 L
.87858 .54158 L
.87891 .53553 L
.87938 .52429 L
.87965 .51334 L
.87974 .50646 L
.87976 .49985 L
.87966 .48726 L
.87934 .47375 L
.87885 .46123 L
.87809 .44755 L
.87704 .43329 L
.87478 .41079 L
.8721 .39131 L
.86858 .37229 L
.86422 .35519 L
.86159 .3474 L
.85905 .34132 L
.85615 .33594 L
.85463 .33371 L
.85297 .33173 L
.85136 .33022 L
.84987 .32918 L
.84844 .3285 L
.84693 .3281 L
.84429 .32819 L
.84142 .3294 L
Mistroke
.83861 .33171 L
.8361 .33472 L
.83326 .33923 L
.83065 .34446 L
.82625 .35584 L
.8219 .37083 L
.81829 .38683 L
.81496 .40563 L
.81238 .42433 L
.81053 .44181 L
.80903 .46114 L
.80845 .47185 L
.80807 .48157 L
.80793 .48674 L
.80784 .49152 L
.80778 .50019 L
.80786 .50907 L
.80797 .51384 L
.80811 .51807 L
.80844 .52515 L
.80892 .53213 L
.80947 .53808 L
.81004 .54293 L
.8108 .54789 L
.81172 .55233 L
.81216 .55403 L
.81265 .5556 L
.81355 .55778 L
.8145 .55916 L
.81504 .55956 L
.81554 .55969 L
.81646 .55932 L
.81741 .55809 L
.81791 .55709 L
.81843 .55575 L
.81933 .55267 L
.82032 .54789 L
.82114 .54254 L
.82174 .53734 L
.82223 .53193 L
.82268 .52541 L
.82304 .51779 L
.82317 .51377 L
.82328 .50922 L
.82336 .50056 L
.8233 .49172 L
.82311 .48322 L
.82278 .47431 L
.82235 .46575 L
.82121 .44951 L
Mistroke
.81949 .432 L
.81707 .41348 L
.81402 .39555 L
.81004 .37752 L
.80525 .36105 L
.80028 .34823 L
.79526 .3387 L
.79046 .3322 L
.78773 .32951 L
.78628 .32835 L
.78472 .32731 L
.78185 .32593 L
.77918 .32524 L
.77665 .3251 L
.77388 .32549 L
.771 .32648 L
.76835 .32792 L
.76587 .3297 L
.76365 .33167 L
.75877 .33718 L
.75372 .34464 L
.74854 .35421 L
.74006 .37441 L
.73328 .39523 L
.72746 .41735 L
.72026 .45206 L
.71777 .46624 L
.71608 .47534 L
.71571 .47699 L
.71534 .47837 L
.71514 .47899 L
.71495 .47943 L
.71478 .47976 L
.71461 .47998 L
.71431 .48013 L
.71402 .47996 L
.71371 .47944 L
.71336 .47851 L
.71304 .47738 L
.71273 .47609 L
.71197 .47233 L
.71024 .46266 L
.7038 .4292 L
.69204 .38369 L
.67583 .33878 L
.6521 .29194 L
.62071 .24734 L
.54865 .17189 L
.4633 .09267 L
.43692 .07053 L
Mistroke
.40658 .04846 L
.39223 .03986 L
.37665 .03226 L
.369 .0293 L
.36175 .02702 L
.35521 .02546 L
.34812 .02432 L
.34112 .02381 L
.33459 .02394 L
.32743 .0248 L
.31977 .02662 L
.31594 .02791 L
.31178 .02962 L
.30427 .03355 L
.29702 .03847 L
.29039 .04403 L
.27869 .05664 L
.2662 .07466 L
.25379 .09831 L
.24283 .12512 L
.23177 .15959 L
.22251 .19625 L
.21362 .24113 L
.20576 .29364 L
.20249 .32154 L
.19949 .35261 L
.19732 .3805 L
.19551 .41035 L
.19433 .43732 L
.19385 .45263 L
.19352 .46689 L
.19322 .49172 L
.19329 .51797 L
.19378 .54371 L
.19458 .56688 L
.19584 .59138 L
.1976 .61623 L
.19967 .63857 L
.20193 .65827 L
.20692 .69124 L
.21269 .71851 L
.21862 .73857 L
.22191 .74711 L
.22564 .75489 L
.22964 .76124 L
.23346 .76554 L
.23775 .7685 L
.23993 .76927 L
.24235 .76956 L
.2466 .76869 L
Mistroke
.25057 .76628 L
.25282 .76423 L
.25517 .76155 L
.2593 .75548 L
.26362 .74717 L
.26816 .73607 L
.27527 .71301 L
.28196 .68287 L
.28726 .64987 L
.29112 .61663 L
.29271 .59861 L
.29409 .57886 L
.29503 .56151 L
.29579 .54197 L
.29628 .52048 L
.29641 .50823 L
.29643 .49694 L
.29621 .47478 L
.29567 .45352 L
.2949 .43364 L
.29377 .4124 L
.29095 .3742 L
.2863 .32923 L
.28088 .28955 L
.27403 .24966 L
.2652 .20876 L
.25462 .17024 L
.24367 .13926 L
.23257 .11544 L
.22193 .09894 L
.21588 .09217 L
.2092 .08688 L
.20283 .08397 L
.19693 .08317 L
.19059 .08442 L
.18381 .08828 L
.17749 .09439 L
.1718 .10211 L
.16531 .11375 L
.15848 .12968 L
.1469 .16717 L
.14114 .19208 L
.13633 .21718 L
.13162 .24668 L
.12714 .28115 L
.12359 .31521 L
.12085 .34797 L
.11875 .38025 L
.11707 .41506 L
.11601 .44837 L
Mistroke
.11564 .46722 L
.11545 .48462 L
.11546 .51626 L
.11597 .54922 L
.11687 .5778 L
.11807 .60372 L
.11978 .63093 L
.12204 .65858 L
.12474 .68432 L
.12812 .70994 L
.1321 .73362 L
.13615 .75264 L
.14016 .7675 L
.14412 .77909 L
.14888 .78946 L
.15334 .79609 L
.15735 .79974 L
.16181 .80138 L
.16646 .80048 L
.17079 .79727 L
.17478 .79229 L
.17835 .7861 L
.18237 .77711 L
.18606 .76682 L
.19368 .73824 L
.19989 .70546 L
.20555 .6636 L
.20814 .63796 L
.21009 .61355 L
.21164 .58845 L
.21273 .56434 L
.21353 .53724 L
.21391 .50768 L
.21391 .49266 L
.21377 .47626 L
.21312 .44636 L
.21202 .4173 L
.21057 .39065 L
.20697 .34355 L
.20435 .3176 L
.20155 .29402 L
.19489 .24933 L
.18634 .20648 L
.17627 .16965 L
.17008 .15262 L
.16408 .13958 L
.16072 .13368 L
.1575 .12892 L
.15138 .12226 L
.14792 .11983 L
Mistroke
.14471 .11846 L
.14118 .11792 L
.13744 .11849 L
.13172 .12166 L
.12566 .12823 L
.12006 .13746 L
.11509 .14846 L
.10949 .16442 L
.10372 .18547 L
.09861 .20884 L
.0943 .233 L
.08716 .2858 L
.08407 .31647 L
.08134 .35052 L
.07942 .38138 L
.07804 .41081 L
.07697 .44358 L
.07637 .47883 L
.07627 .49875 L
.07633 .51702 L
.07658 .53686 L
.07703 .55758 L
.07822 .59141 L
.07913 .60997 L
.08014 .62684 L
.08238 .65668 L
.08483 .682 L
.08809 .7086 L
.09158 .73102 L
.09565 .75152 L
.0996 .76703 L
.10189 .77433 L
.10443 .78116 L
.10918 .79069 L
.11375 .79629 L
.11865 .79868 L
.12284 .79792 L
.12741 .79417 L
.13014 .79045 L
.1327 .78596 L
.13736 .77507 L
.14214 .75994 L
.147 .73978 L
.15089 .7193 L
.15463 .69491 L
.15746 .67204 L
.16014 .64525 L
.16222 .61886 L
.16377 .59328 L
.165 .56536 L
Mistroke
.16582 .53478 L
.16613 .50575 L
.16602 .47812 L
.16557 .45328 L
.16472 .42647 L
.16336 .39743 L
.16134 .36615 L
.15868 .33456 L
.1557 .30628 L
.14923 .25967 L
.14505 .23637 L
.14085 .21679 L
.13191 .18502 L
.12684 .17199 L
.12124 .16124 L
.11576 .15415 L
.11052 .15046 L
.10579 .14968 L
.10068 .15162 L
.09603 .15598 L
.09102 .16363 L
.08593 .17481 L
.08136 .18811 L
.07373 .21865 L
.06983 .23932 L
.06655 .26018 L
.06029 .31294 L
.05746 .34615 L
.05532 .37889 L
.05362 .41455 L
.05259 .4479 L
.05224 .46643 L
.05203 .48668 L
.05211 .52334 L
.05273 .55692 L
.05373 .58646 L
.05538 .61907 L
.05741 .64797 L
.05967 .67292 L
.06205 .69408 L
.06835 .73469 L
.07207 .75159 L
.07631 .7662 L
.08052 .77655 L
.08447 .78304 L
.08918 .78704 L
.09187 .7876 L
.09436 .78704 L
.09888 .78335 L
.10114 .78021 L
Mistroke
.1036 .77578 L
.10835 .76407 L
.1125 .75011 L
.11677 .73149 L
.12087 .70849 L
.12673 .66295 L
.12937 .63398 L
.13136 .60539 L
.13283 .57619 L
.13339 .56111 L
.13386 .54429 L
.13433 .51414 L
.13433 .48565 L
.13412 .46843 L
.13378 .45211 L
.13277 .42175 L
.132 .40503 L
.13115 .38973 L
.12875 .35601 L
.12614 .32775 L
.12326 .30262 L
.11689 .26039 L
.11281 .23988 L
.10879 .22333 L
.1041 .20794 L
.09891 .1951 L
.09435 .18713 L
.09012 .18232 L
.08517 .17978 L
.08047 .18044 L
.07616 .18373 L
.07223 .18909 L
.06802 .19751 L
.06368 .20934 L
.05954 .22407 L
.05535 .24305 L
.04861 .28492 L
.04529 .31314 L
.04233 .34543 L
.04025 .37475 L
.03849 .4082 L
.03781 .42553 L
.03725 .44406 L
.03664 .47757 L
.03657 .51362 L
.03679 .53387 L
.03718 .55255 L
.03828 .58543 L
.03974 .61411 L
.04194 .64518 L
Mistroke
.04448 .67223 L
.04711 .69413 L
.05022 .71482 L
.05315 .73036 L
.05653 .74458 L
.06034 .75671 L
.06406 .76516 L
.06627 .76873 L
.06862 .77144 L
.07286 .7736 L
.07742 .77213 L
.08151 .76749 L
.08374 .76361 L
.08612 .75837 L
.0903 .74623 L
.09401 .73196 L
.09767 .71401 L
.10342 .67536 L
.10612 .65061 L
.10854 .62195 L
.11034 .59331 L
.11156 .56607 L
.1121 .5492 L
.11246 .53336 L
.11269 .51582 L
.11275 .49704 L
.11264 .47911 L
.11237 .46226 L
.112 .44722 L
.11147 .43108 L
.11016 .40263 L
.10857 .37747 L
.1063 .34967 L
.10374 .32484 L
.09827 .2852 L
.09472 .2658 L
.09118 .25004 L
.0874 .23649 L
.08312 .22468 L
.08059 .2193 L
.07824 .21529 L
.07353 .21004 L
.0689 .20837 L
.06628 .20897 L
.06384 .21054 L
.06128 .21328 L
.05898 .21671 L
.05637 .2218 L
.05395 .22769 L
.04983 .24061 L
Mistroke
.04556 .25842 L
.04146 .28081 L
.03801 .30499 L
.03522 .32962 L
.03294 .35488 L
.03077 .3859 L
.02925 .41562 L
.02812 .44932 L
.02774 .46843 L
.02754 .4858 L
.02759 .51957 L
.02814 .55083 L
.02866 .56825 L
.02939 .5862 L
.03109 .61698 L
.03348 .64771 L
.0367 .67792 L
.03985 .70017 L
.04307 .71779 L
.04689 .73366 L
.04894 .74031 L
.0512 .74634 L
.05509 .75377 L
.05882 .75771 L
.061 .75864 L
.0633 .75858 L
.06738 .75581 L
.07098 .75052 L
.07471 .74207 L
.0781 .73157 L
.08104 .72004 L
.08428 .70417 L
.0875 .68446 L
.09244 .6429 L
.0946 .61729 L
.09622 .59204 L
.09696 .57736 L
.09754 .5632 L
.09807 .54664 L
.09841 .53136 L
.09861 .5162 L
.09869 .50001 L
.09845 .47097 L
.09811 .45497 L
.09766 .44009 L
.09703 .42398 L
.09617 .40692 L
.09453 .38165 L
.09231 .35541 L
.08952 .32997 L
Mistroke
.08654 .3084 L
.08039 .27578 L
.07656 .26136 L
.07289 .25091 L
.06906 .24308 L
.06538 .23833 L
.06129 .23609 L
.05689 .23721 L
.0547 .23916 L
.05233 .24235 L
.04812 .25098 L
.04419 .2628 L
.04074 .2767 L
.03744 .29364 L
.0346 .31195 L
.03006 .35164 L
.028 .37655 L
.02645 .40079 L
.02515 .42854 L
.02424 .45873 L
.02382 .49012 L
.02389 .51872 L
.02411 .53439 L
.0245 .55122 L
.02558 .581 L
.02703 .60753 L
.029 .63393 L
.03101 .65474 L
.03354 .67557 L
.03689 .69677 L
.04026 .71296 L
.04423 .72693 L
.04631 .7324 L
.04864 .73716 L
.05267 .74231 L
.05495 .74359 L
.05703 .74376 L
.06106 .74142 L
.06481 .73608 L
.06822 .72839 L
.07174 .71742 L
.07489 .70464 L
.07758 .69106 L
.08048 .67305 L
.0833 .65113 L
.08558 .62868 L
.08737 .60618 L
.0882 .59348 L
.08898 .57945 L
.09003 .55436 L
Mistroke
.09045 .53985 L
.09075 .52441 L
.09093 .49663 L
.09067 .47095 L
.09008 .44736 L
.08904 .42211 L
.08829 .40836 L
.08749 .39615 L
.08582 .37502 L
.08372 .354 L
.07919 .32062 L
.0763 .30487 L
.07338 .29216 L
.06999 .28067 L
.06802 .27544 L
.06616 .27136 L
.06278 .26605 L
.05902 .26314 L
.05569 .26314 L
.05216 .26582 L
.04875 .27115 L
.04562 .27859 L
.04292 .28723 L
.04013 .29859 L
.03707 .31442 L
.03452 .33109 L
.03206 .35119 L
.02975 .37531 L
.02799 .39936 L
.02671 .42282 L
.02581 .44607 L
.0252 .47137 L
.02497 .49875 L
.02503 .51416 L
.0252 .52821 L
.02581 .55373 L
.02686 .57978 L
.02758 .59316 L
.02847 .60701 L
.03037 .63064 L
.03311 .65613 L
.03599 .67644 L
.03909 .69317 L
.04264 .70757 L
.04584 .71704 L
.04952 .72435 L
.05162 .72701 L
.05356 .72853 L
.05582 .72921 L
.05796 .72879 L
Mistroke
.06173 .72555 L
.06383 .72233 L
.06575 .71849 L
.06939 .70864 L
.07264 .69671 L
.07812 .66825 L
.08079 .64919 L
.08295 .63003 L
.08497 .60747 L
.08667 .58226 L
.08777 .55946 L
.08824 .54633 L
.08856 .53408 L
.0889 .51145 L
.08889 .48744 L
.08857 .46622 L
.08799 .44669 L
.08706 .42586 L
.08573 .40436 L
.08406 .38397 L
.08189 .36335 L
.07926 .34399 L
.07653 .32825 L
.07373 .31564 L
.07104 .30617 L
.06778 .29773 L
.0646 .29234 L
.06177 .28975 L
.05865 .28922 L
.05539 .29128 L
.0524 .29563 L
.04967 .3018 L
.04727 .30915 L
.04461 .31963 L
.04225 .33146 L
.03989 .34616 L
.03764 .36382 L
.03592 .38059 L
.03433 .40007 L
.03295 .42222 L
.03198 .44402 L
.03156 .45698 L
.03124 .47082 L
.03098 .49589 L
.0311 .52064 L
.03135 .53451 L
.03168 .54718 L
.03256 .56996 L
.03385 .59313 L
.03531 .61275 L
Mistroke
.03693 .62998 L
.0414 .66427 L
.04428 .67983 L
.04723 .69214 L
.05004 .70102 L
.05323 .70829 L
.05508 .71127 L
.05678 .71326 L
.05877 .71469 L
.06064 .71521 L
.06397 .71415 L
.06754 .71021 L
.07057 .70451 L
.07331 .69737 L
.07618 .68762 L
.07909 .6751 L
.08191 .65988 L
.08432 .64369 L
.08628 .62767 L
.0881 .60949 L
.08944 .593 L
.09066 .5741 L
.09153 .55643 L
.09213 .53957 L
.09256 .51959 L
.0927 .50125 L
.09257 .48127 L
.09212 .46064 L
.09134 .44033 L
.09077 .42925 L
.09015 .41931 L
.08883 .40215 L
.0871 .3846 L
.08348 .35799 L
.0812 .34582 L
.07891 .33613 L
.07608 .32702 L
.07328 .32071 L
.07069 .31705 L
.06782 .31529 L
.06618 .31535 L
.0647 .31606 L
.06301 .31767 L
.06143 .31996 L
.05867 .32585 L
.05582 .33479 L
.05348 .34468 L
.05143 .35557 L
.0492 .37048 L
.0474 .38574 L
Mistroke
.04576 .40333 L
.04447 .42121 L
.04341 .44119 L
.04294 .45286 L
.04261 .46385 L
.04225 .4823 L
.04214 .49982 L
.04227 .5191 L
.0427 .53971 L
.04348 .56081 L
.04451 .58023 L
.04568 .59695 L
.04719 .61425 L
.04914 .63186 L
.05147 .6487 L
.05434 .6648 L
.05722 .67724 L
.06008 .68664 L
.06286 .69345 L
.06601 .69865 L
.06781 .70053 L
.06946 .70158 L
.07253 .7019 L
.07536 .70032 L
.07842 .69659 L
.0816 .69041 L
.08425 .68331 L
.08664 .67524 L
.09163 .65228 L
.09389 .63835 L
.09611 .62167 L
.09798 .6042 L
.09966 .58447 L
.1009 .56518 L
.10176 .54722 L
.10234 .52894 L
.10263 .51163 L
.10265 .49159 L
.10254 .48162 L
.10232 .4708 L
.10168 .45218 L
.10082 .43551 L
.09948 .41706 L
.09798 .40151 L
.09593 .38539 L
.09373 .37211 L
.09162 .36231 L
.08918 .35373 L
.08676 .34768 L
.08447 .34393 L
Mistroke
.08235 .34209 L
.08001 .34179 L
.07758 .34341 L
.07535 .34671 L
.07412 .34931 L
.07281 .35274 L
.07052 .36054 L
.06842 .37 L
.06662 .3803 L
.06486 .39298 L
.06316 .40866 L
.06169 .4267 L
.06061 .44492 L
.05996 .46054 L
.0595 .47819 L
.05931 .49705 L
.05939 .51478 L
.05971 .53144 L
.06019 .54642 L
.06098 .5634 L
.06194 .57894 L
.06322 .59522 L
.06484 .61148 L
.06832 .63758 L
.07056 .65013 L
.07282 .66043 L
.07545 .67006 L
.07843 .67834 L
.08002 .68174 L
.08153 .6844 L
.0844 .68797 L
.08754 .68976 L
.08932 .68984 L
.09094 .68934 L
.09366 .68726 L
.09659 .68325 L
.09956 .67723 L
.10223 .67002 L
.10525 .65958 L
.10791 .648 L
.1123 .62248 L
.11437 .6064 L
.11602 .59066 L
.11752 .57263 L
.1182 .56259 L
.11874 .55293 L
.11945 .53669 L
.11987 .52179 L
.12009 .50586 L
.1201 .49695 L
Mistroke
.12004 .48877 L
.11977 .47415 L
.11933 .46134 L
.11861 .44719 L
.11774 .43462 L
.11657 .42169 L
.11511 .40931 L
.1137 .39988 L
.11201 .39085 L
.11004 .38279 L
.1089 .37912 L
.10779 .37618 L
.10674 .3739 L
.10557 .37195 L
.1035 .36987 L
.10148 .36949 L
.09964 .37056 L
.09764 .37329 L
.0956 .37791 L
.09388 .38336 L
.09237 .38959 L
.09082 .39757 L
.08929 .40758 L
.08781 .41998 L
.08661 .43296 L
.08566 .44664 L
.08498 .46002 L
.08447 .47517 L
.08428 .48403 L
.08418 .49245 L
.08416 .50142 L
.0842 .50968 L
.08434 .51926 L
.08455 .52837 L
.08483 .53729 L
.08517 .54564 L
.08599 .56102 L
.08712 .57712 L
.08864 .59375 L
.09021 .60754 L
.0921 .62108 L
.09598 .64232 L
.09844 .65238 L
.10123 .66148 L
.104 .66841 L
.10661 .67326 L
.10824 .67553 L
.10976 .67716 L
.11145 .67843 L
.11324 .67918 L
Mistroke
.1148 .67935 L
.11626 .6791 L
.11786 .67837 L
.11957 .67708 L
.12239 .67376 L
.12489 .66954 L
.12769 .66332 L
.13023 .65621 L
.13443 .64085 L
.13843 .62089 L
.1421 .59575 L
.14361 .5822 L
.145 .56685 L
.14596 .55351 L
.1464 .54612 L
.14675 .53911 L
.14727 .52555 L
.14756 .51332 L
.14767 .5008 L
.14765 .49382 L
.14757 .48739 L
.14726 .47485 L
.14699 .46807 L
.14669 .46206 L
.14608 .4524 L
.14525 .44258 L
.14423 .43325 L
.14315 .42548 L
.14171 .41747 L
.14024 .41124 L
.13883 .40681 L
.13724 .40329 L
.13639 .40201 L
.13545 .40104 L
.13446 .40051 L
.13352 .40047 L
.13187 .4015 L
.13095 .4027 L
.13012 .40419 L
.12858 .40803 L
.12719 .41283 L
.12602 .41809 L
.12484 .42473 L
.12367 .43308 L
.1226 .44303 L
.12183 .45236 L
.12114 .46338 L
.12067 .47437 L
.12039 .48484 L
.12024 .49738 L
Mistroke
.1203 .50958 L
.12051 .52103 L
.12085 .5317 L
.12138 .54342 L
.12213 .55577 L
.12426 .58055 L
.12578 .59378 L
.12738 .6053 L
.13079 .62468 L
.13494 .64195 L
.13736 .64968 L
.14007 .65671 L
.14273 .66215 L
.14522 .66607 L
.14667 .66786 L
.14821 .66941 L
.14992 .67068 L
.15151 .67147 L
.15438 .67197 L
.15601 .67173 L
.15753 .67117 L
.16025 .66935 L
.16175 .66791 L
.1631 .66634 L
.16806 .65826 L
.17072 .65236 L
.17347 .64498 L
.17807 .62931 L
.18192 .61212 L
.18536 .59228 L
.18776 .57448 L
.18888 .56428 L
.18979 .55462 L
.19053 .5453 L
.19118 .5353 L
.19163 .52636 L
.19193 .5183 L
.19213 .50983 L
.19222 .50084 L
.19216 .49192 L
.19197 .48404 L
.19168 .47715 L
.19132 .47105 L
.19093 .46599 L
.19043 .46093 L
.18981 .45602 L
.18908 .45147 L
.18833 .44787 L
.18761 .44518 L
.18675 .44284 L
Mistroke
.18593 .44134 L
.185 .44045 L
.184 .44039 L
.1835 .44071 L
.18296 .44132 L
.182 .44313 L
.18109 .44575 L
.1803 .44892 L
.17962 .45247 L
.17902 .45632 L
.17842 .46111 L
.17787 .46689 L
.17741 .47321 L
.17703 .48046 L
.17681 .4871 L
.17667 .49477 L
.17664 .49929 L
.17666 .50433 L
.17672 .5092 L
.17681 .51377 L
.17709 .52263 L
.17754 .53223 L
.17819 .5427 L
.17897 .55257 L
.18133 .57492 L
.18404 .5936 L
.18703 .60969 L
.19105 .62663 L
.19536 .64071 L
.20021 .65282 L
.20511 .66188 L
.20971 .66799 L
.21238 .67058 L
.21485 .67242 L
.21756 .67383 L
.2201 .67462 L
.22289 .6749 L
.22446 .67481 L
.22589 .67456 L
.22875 .67362 L
.23036 .67284 L
.23184 .67196 L
.23736 .66732 L
.24195 .66186 L
.2461 .65566 L
.25487 .63838 L
.26233 .61876 L
.26906 .59641 L
.27821 .55613 L
.28339 .52729 L
Mistroke
.28387 .52488 L
.28434 .52278 L
.28476 .52132 L
.28495 .5208 L
.28512 .52041 L
.28543 .51997 L
.2856 .51987 L
.28577 .51988 L
.28596 .52002 L
.28614 .52026 L
.28648 .52101 L
.28682 .52209 L
.2872 .52363 L
.28797 .52738 L
.29026 .54021 L
.29667 .57294 L
.30848 .618 L
.31786 .64542 L
.32817 .67033 L
.35303 .71637 L
.38249 .75654 L
.41426 .79154 L
.50173 .87564 L
.55505 .92295 L
.58354 .94485 L
.5965 .95348 L
.61103 .96188 L
.62335 .96774 L
.63021 .97041 L
.63676 .97254 L
.64421 .97441 L
.65104 .97557 L
.65746 .97613 L
.66446 .97611 L
.67217 .97527 L
.67913 .97369 L
.68298 .97247 L
.68714 .97085 L
.69462 .9671 L
.7016 .96255 L
.70888 .95663 L
.72164 .94294 L
.73695 .91992 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.0238095 0.97619 0.321429 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.221784 0.499996 0.443845 [
[.5 1.0125 -3.5 0 ]
[.5 1.0125 3.5 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -64.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.000 15.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
.82215 .53286 m
.8226 .52669 L
.82292 .52063 L
.82318 .51314 L
.82332 .50562 L
.82335 .49833 L
.82329 .49136 L
.82311 .48347 L
.8228 .4749 L
.82237 .46611 L
.82175 .45654 L
.82025 .43912 L
.81782 .4187 L
.81499 .40082 L
.81153 .38378 L
.80786 .36948 L
.80336 .3558 L
.79813 .34383 L
.7956 .33931 L
.79279 .33512 L
.79026 .33204 L
.78754 .32941 L
.78505 .32759 L
.78229 .32617 L
.77977 .32542 L
.77741 .32517 L
.77594 .32522 L
.77439 .32545 L
.7716 .3263 L
.77006 .32701 L
.76863 .32783 L
.76538 .3302 L
.76008 .33563 L
.7546 .34332 L
.74508 .36183 L
.73751 .38182 L
.72479 .42925 L
.71765 .46703 L
.71675 .47209 L
.71591 .47622 L
.71557 .47763 L
.71522 .47877 L
.71494 .47947 L
.71464 .47994 L
.71447 .48006 L
.7143 .48008 L
.71412 .47998 L
.71394 .47978 L
.71362 .47913 L
.71343 .47861 L
Mistroke
.71325 .47803 L
.71255 .47512 L
.7117 .47069 L
.70658 .44262 L
.69815 .40534 L
.6825 .35549 L
.67162 .32921 L
.65822 .30257 L
.63147 .26118 L
.5966 .21987 L
.51 .13536 L
.46066 .09043 L
.40999 .05076 L
.3829 .03512 L
.36892 .02932 L
.36089 .02684 L
.35334 .02515 L
.34561 .02411 L
.34173 .02388 L
.33748 .02386 L
.32995 .02445 L
.32297 .02579 L
.31872 .027 L
.31472 .02843 L
.30729 .03188 L
.29935 .03681 L
.29087 .04364 L
.27781 .0578 L
.26401 .07844 L
.2504 .10597 L
.23861 .13734 L
.22871 .17087 L
.22026 .2066 L
.21179 .25208 L
.20535 .29698 L
.20259 .32071 L
.2 .3469 L
.19809 .36991 L
.19636 .39538 L
.19488 .42376 L
.19427 .43925 L
.19383 .45365 L
.19333 .47929 L
.19322 .50633 L
.19333 .52098 L
.19356 .53432 L
.19393 .54874 L
.19446 .56372 L
.19566 .58814 L
.19741 .61374 L
Mistroke
.19934 .63524 L
.20177 .65689 L
.20436 .67567 L
.20701 .69171 L
.21321 .72048 L
.21681 .73308 L
.22084 .74447 L
.22485 .75336 L
.22875 .75994 L
.23232 .76438 L
.23623 .76763 L
.23986 .7692 L
.24386 .76941 L
.24802 .76795 L
.25187 .7651 L
.25544 .76116 L
.25863 .75653 L
.26556 .74268 L
.26913 .73329 L
.27235 .72333 L
.27911 .69683 L
.28481 .66638 L
.28735 .64913 L
.2898 .62917 L
.29311 .59322 L
.29445 .57255 L
.29539 .55275 L
.296 .53369 L
.29632 .51605 L
.29641 .49536 L
.29621 .47556 L
.29567 .45372 L
.29469 .42953 L
.29323 .40414 L
.29146 .38041 L
.28734 .33827 L
.28155 .29405 L
.27304 .24469 L
.26335 .20139 L
.25342 .16652 L
.24145 .13399 L
.22908 .10943 L
.22181 .09883 L
.21828 .09469 L
.21497 .09137 L
.20888 .08674 L
.20214 .08383 L
.19554 .08331 L
.19185 .08404 L
.1885 .08537 L
Mistroke
.1822 .08965 L
.17645 .09568 L
.17026 .10464 L
.16387 .11684 L
.15366 .14358 L
.14821 .1622 L
.14339 .18181 L
.13835 .20615 L
.13333 .23538 L
.12936 .26325 L
.12562 .29487 L
.12247 .3278 L
.12009 .35881 L
.11819 .39079 L
.11684 .42143 L
.11628 .43866 L
.11582 .45761 L
.11552 .47737 L
.1154 .49574 L
.11559 .52825 L
.11634 .56228 L
.117 .58087 L
.11791 .60059 L
.12007 .63485 L
.12275 .66588 L
.12571 .69226 L
.12875 .71402 L
.13229 .73455 L
.13934 .7647 L
.1436 .77768 L
.14773 .78723 L
.1524 .79488 L
.15507 .79787 L
.1575 .79979 L
.16194 .80134 L
.16604 .80062 L
.17051 .7975 L
.17517 .79164 L
.17913 .78449 L
.18273 .77614 L
.19046 .75155 L
.1944 .73485 L
.19837 .71438 L
.20155 .69454 L
.20459 .67175 L
.20722 .64766 L
.20924 .6247 L
.21093 .60067 L
.21218 .57731 L
.21323 .5491 L
Mistroke
.21358 .53464 L
.21382 .51863 L
.21389 .48997 L
.21354 .46303 L
.21312 .44664 L
.21259 .43115 L
.21124 .40224 L
.20926 .3715 L
.20651 .3388 L
.20098 .28976 L
.19345 .24123 L
.18499 .20086 L
.17625 .16966 L
.17123 .15555 L
.16566 .14275 L
.15933 .13157 L
.1533 .12406 L
.14999 .12121 L
.14638 .11912 L
.14296 .11812 L
.1398 .11804 L
.13384 .1202 L
.12759 .12582 L
.12145 .13493 L
.116 .14629 L
.10995 .163 L
.10451 .1823 L
.09575 .2244 L
.09139 .25227 L
.08779 .2804 L
.08461 .31063 L
.08173 .34512 L
.08035 .36556 L
.07925 .38469 L
.07831 .40442 L
.07759 .423 L
.07662 .46076 L
.07636 .48078 L
.07628 .5021 L
.07641 .52432 L
.07674 .54505 L
.07719 .56336 L
.07787 .58284 L
.07941 .61483 L
.08125 .64257 L
.08385 .67244 L
.08676 .6984 L
.09283 .73785 L
.09672 .75608 L
.10056 .77018 L
Mistroke
.10284 .77697 L
.10536 .78328 L
.11005 .79197 L
.11472 .797 L
.11907 .79868 L
.12379 .79734 L
.12645 .79516 L
.12891 .79221 L
.13148 .78817 L
.13379 .78367 L
.13882 .77083 L
.14319 .75596 L
.14754 .73713 L
.15442 .69635 L
.15764 .67037 L
.16023 .64414 L
.16256 .61363 L
.16362 .59593 L
.16444 .5791 L
.16546 .55012 L
.16582 .53453 L
.16605 .51774 L
.16613 .49994 L
.16606 .48308 L
.16552 .45149 L
.16453 .42202 L
.16322 .39519 L
.16135 .36633 L
.15887 .33669 L
.15615 .31035 L
.15274 .28309 L
.14541 .23826 L
.1415 .21965 L
.13706 .20189 L
.13267 .18733 L
.12846 .17587 L
.12293 .16414 L
.11994 .1593 L
.11676 .15524 L
.11132 .15087 L
.10822 .14982 L
.10532 .14978 L
.09991 .15222 L
.09503 .1573 L
.08952 .16658 L
.08448 .17871 L
.08026 .19187 L
.07583 .20909 L
.07178 .2285 L
.06776 .25211 L
Mistroke
.06435 .27649 L
.06155 .30059 L
.05703 .35204 L
.055 .38465 L
.05358 .4159 L
.05253 .45085 L
.05202 .48839 L
.05212 .52393 L
.05273 .55677 L
.05369 .5854 L
.05516 .61513 L
.05721 .64537 L
.05949 .67101 L
.06255 .69796 L
.06585 .72062 L
.06895 .73768 L
.07249 .75319 L
.07659 .76696 L
.08057 .77661 L
.08495 .78359 L
.08746 .78599 L
.08977 .78723 L
.09404 .78712 L
.09852 .78373 L
.10087 .7806 L
.10334 .77625 L
.10769 .76591 L
.11261 .74964 L
.11678 .73138 L
.12047 .71093 L
.12399 .68654 L
.12667 .66344 L
.12913 .63682 L
.13128 .60652 L
.13279 .57685 L
.13347 .55827 L
.13395 .54035 L
.13422 .52411 L
.13436 .50627 L
.13434 .48936 L
.13419 .47342 L
.13355 .44374 L
.13234 .41219 L
.13143 .39472 L
.13045 .37891 L
.12594 .32598 L
.12308 .30131 L
.11953 .27617 L
.11168 .23495 L
.10672 .21611 L
Mistroke
.10185 .20191 L
.09743 .19224 L
.09242 .18467 L
.08708 .18042 L
.08204 .17993 L
.07741 .18255 L
.07261 .18851 L
.0686 .19621 L
.06435 .20733 L
.05996 .22246 L
.05556 .24204 L
.04854 .28549 L
.04497 .31634 L
.04219 .34726 L
.03974 .38344 L
.03876 .40236 L
.03789 .42356 L
.0373 .44243 L
.0369 .4598 L
.03662 .47992 L
.03653 .49899 L
.03678 .53257 L
.03715 .55125 L
.03764 .56827 L
.03905 .6016 L
.04087 .63122 L
.04289 .65606 L
.04544 .68073 L
.04864 .70485 L
.05241 .72668 L
.05591 .74219 L
.05998 .7557 L
.06434 .76563 L
.06848 .77128 L
.07068 .77288 L
.0731 .77358 L
.07563 .77313 L
.078 .77162 L
.08229 .76621 L
.08611 .75834 L
.09036 .74597 L
.09418 .73114 L
.09736 .71563 L
.10049 .69689 L
.10535 .65814 L
.10778 .63172 L
.10965 .60532 L
.11096 .58061 L
.11198 .55306 L
.11261 .52245 L
Mistroke
.11274 .49356 L
.11261 .47695 L
.11236 .46184 L
.11192 .44451 L
.11135 .42824 L
.1098 .39645 L
.10787 .36812 L
.10522 .33864 L
.10186 .30959 L
.09883 .2887 L
.09523 .26841 L
.09187 .25293 L
.08797 .23838 L
.0834 .2254 L
.08083 .2198 L
.07839 .21556 L
.07394 .21039 L
.06913 .20841 L
.06457 .21001 L
.06199 .21244 L
.05961 .21572 L
.05491 .22525 L
.05235 .23229 L
.05007 .23977 L
.0462 .25546 L
.04228 .2759 L
.03893 .29799 L
.03612 .32111 L
.03308 .35312 L
.03087 .38435 L
.02992 .4014 L
.02909 .41979 L
.02837 .44032 L
.0279 .45942 L
.02751 .49376 L
.02766 .52563 L
.02797 .5437 L
.0284 .5599 L
.02905 .57824 L
.02982 .59514 L
.03142 .62186 L
.03363 .64931 L
.03639 .67535 L
.03935 .69696 L
.0424 .71444 L
.04541 .72804 L
.04891 .74017 L
.05275 .74969 L
.0568 .75591 L
.0591 .75784 L
Mistroke
.06119 .75864 L
.06528 .75762 L
.0691 .75359 L
.07123 .75002 L
.07345 .74526 L
.0773 .7343 L
.08121 .71922 L
.08519 .69904 L
.08831 .67869 L
.09089 .65782 L
.09333 .63296 L
.09546 .60468 L
.09688 .579 L
.09785 .55409 L
.09849 .52619 L
.09865 .51034 L
.09867 .49576 L
.09844 .47056 L
.09789 .44731 L
.09694 .42226 L
.09553 .39626 L
.09362 .37013 L
.09143 .34682 L
.08643 .30771 L
.08334 .28982 L
.07964 .27273 L
.07551 .2581 L
.07142 .2476 L
.06748 .24076 L
.0638 .23713 L
.05951 .23613 L
.05545 .23842 L
.05115 .24443 L
.0488 .24937 L
.04671 .25482 L
.04279 .26804 L
.03932 .28352 L
.0356 .3051 L
.03255 .32798 L
.02966 .35603 L
.0272 .38844 L
.02568 .4162 L
.02501 .43236 L
.02453 .44754 L
.02395 .47577 L
.02381 .50594 L
.02408 .53267 L
.02468 .55729 L
.0257 .58349 L
.02722 .61041 L
Mistroke
.02916 .63568 L
.03171 .66093 L
.0348 .68422 L
.03803 .70275 L
.04133 .71718 L
.0445 .72766 L
.04831 .73654 L
.05202 .7417 L
.0553 .74364 L
.05891 .74307 L
.06265 .7395 L
.06607 .73351 L
.06918 .72568 L
.07192 .71675 L
.0776 .6909 L
.08042 .67344 L
.08278 .65553 L
.08523 .63235 L
.0871 .60988 L
.08856 .58731 L
.08962 .56533 L
.0904 .54156 L
.09085 .5155 L
.09089 .48921 L
.09056 .46543 L
.08976 .43846 L
.08859 .41372 L
.08717 .39176 L
.08558 .37244 L
.08108 .33307 L
.07829 .31541 L
.07544 .30089 L
.07208 .28742 L
.06825 .27604 L
.06627 .27162 L
.06407 .26781 L
.06196 .26518 L
.05999 .26362 L
.05624 .26301 L
.05414 .26401 L
.05226 .26575 L
.04837 .27195 L
.04646 .27638 L
.04441 .28223 L
.04094 .29506 L
.0379 .30976 L
.03464 .33027 L
.03201 .35168 L
.02944 .37917 L
.02751 .4075 L
Mistroke
.02626 .43346 L
.02539 .46202 L
.02502 .48684 L
.02503 .51436 L
.02552 .54349 L
.02601 .55956 L
.02659 .574 L
.02798 .59965 L
.02987 .62499 L
.032 .64669 L
.03468 .66782 L
.03752 .68521 L
.04037 .69886 L
.04309 .70908 L
.04623 .71795 L
.04963 .72449 L
.05288 .72807 L
.05672 .72912 L
.06035 .72707 L
.06356 .72277 L
.06697 .71551 L
.06886 .71024 L
.07052 .70479 L
.07408 .69032 L
.07712 .67437 L
.07972 .65733 L
.08371 .62217 L
.08532 .60277 L
.08676 .58051 L
.08771 .56083 L
.08843 .53931 L
.08882 .51875 L
.08894 .49996 L
.08876 .47651 L
.08827 .45517 L
.08738 .43235 L
.08605 .40912 L
.0846 .39004 L
.08299 .3732 L
.07853 .33944 L
.07601 .32575 L
.07312 .31332 L
.07022 .30381 L
.06748 .29715 L
.06416 .29183 L
.06225 .29008 L
.06049 .28926 L
.05724 .28981 L
.05383 .29328 L
.05064 .29938 L
Mistroke
.04735 .30891 L
.04441 .32061 L
.0419 .33348 L
.03922 .35103 L
.03667 .37288 L
.03465 .39579 L
.03315 .41865 L
.03219 .43861 L
.03146 .46087 L
.03107 .48234 L
.03097 .50223 L
.03116 .52423 L
.03171 .54802 L
.03267 .57218 L
.0339 .59377 L
.03555 .61549 L
.03742 .63455 L
.04163 .66565 L
.04434 .68008 L
.04702 .69133 L
.05013 .70125 L
.05358 .7089 L
.05682 .71326 L
.06041 .71516 L
.06381 .71424 L
.06693 .71107 L
.06996 .70581 L
.07262 .6993 L
.07558 .68982 L
.07823 .67909 L
.08093 .66551 L
.08354 .64927 L
.08748 .61608 L
.08923 .59578 L
.09055 .57594 L
.09165 .55346 L
.09209 .54064 L
.09239 .52886 L
.09267 .50914 L
.09265 .48827 L
.09238 .4707 L
.09182 .45172 L
.09092 .43209 L
.08962 .41195 L
.08809 .39415 L
.08646 .37904 L
.08294 .3549 L
.08069 .34348 L
.07845 .33446 L
.07595 .3267 L
Mistroke
.0736 .32133 L
.07081 .3172 L
.06813 .3154 L
.06542 .31567 L
.06253 .3183 L
.05986 .32302 L
.0575 .32919 L
.05485 .33859 L
.05216 .35141 L
.04985 .36581 L
.04792 .38099 L
.04604 .40003 L
.04459 .41951 L
.04355 .43806 L
.04275 .459 L
.04246 .4702 L
.04225 .48263 L
.04215 .49572 L
.04216 .50797 L
.04246 .52988 L
.04315 .55299 L
.04415 .57411 L
.04537 .59282 L
.047 .61223 L
.04907 .63126 L
.0532 .65886 L
.05588 .6718 L
.05856 .68195 L
.06111 .68939 L
.06388 .69538 L
.06631 .69899 L
.069 .70132 L
.07194 .70197 L
.07506 .70055 L
.07798 .69724 L
.08057 .69265 L
.08345 .6856 L
.08604 .67739 L
.08895 .66572 L
.09142 .65341 L
.09581 .62407 L
.09781 .60591 L
.09941 .58769 L
.10053 .57147 L
.10147 .55377 L
.10207 .53844 L
.10249 .52139 L
.10268 .50318 L
.10257 .48377 L
.10218 .46588 L
Mistroke
.10158 .44998 L
.10068 .43342 L
.09945 .41674 L
.09804 .40215 L
.09657 .38998 L
.09463 .37717 L
.09231 .36528 L
.08994 .35613 L
.08762 .3496 L
.08514 .34487 L
.08277 .34236 L
.08013 .34178 L
.07866 .34247 L
.07731 .34374 L
.07593 .3457 L
.07467 .3481 L
.0732 .35168 L
.0719 .35558 L
.06959 .36445 L
.06731 .37613 L
.0655 .38806 L
.06399 .40054 L
.06254 .41558 L
.06127 .43306 L
.06074 .44229 L
.06026 .45263 L
.05963 .47206 L
.05934 .49155 L
.05935 .50984 L
.0596 .5269 L
.06006 .54279 L
.0608 .55992 L
.06187 .57784 L
.0632 .59485 L
.06487 .61173 L
.0685 .63861 L
.07091 .65185 L
.07328 .6623 L
.0762 .67237 L
.0791 .67983 L
.08188 .68492 L
.0845 .68803 L
.08741 .68971 L
.09051 .6895 L
.0936 .68729 L
.09532 .68519 L
.09687 .68275 L
.09981 .67662 L
.10249 .6692 L
.10544 .65878 L
Mistroke
.108 .64752 L
.11059 .63353 L
.11302 .61722 L
.11479 .60262 L
.11646 .58578 L
.11773 .56969 L
.11865 .5547 L
.11907 .54609 L
.11945 .53671 L
.11975 .52679 L
.11995 .51742 L
.12007 .5087 L
.1201 .49953 L
.11996 .48337 L
.1196 .46887 L
.11898 .45389 L
.11817 .4405 L
.11726 .42899 L
.116 .41655 L
.11441 .40438 L
.11271 .39436 L
.111 .38645 L
.10927 .38025 L
.1073 .37507 L
.10537 .3717 L
.10356 .36993 L
.10192 .36946 L
.10011 .37018 L
.09824 .37231 L
.09654 .37557 L
.0946 .3809 L
.09286 .38742 L
.09139 .39445 L
.08991 .40329 L
.08845 .4142 L
.08711 .42716 L
.08614 .43922 L
.08529 .45346 L
.08468 .46802 L
.08432 .4821 L
.08416 .49799 L
.08418 .50702 L
.08427 .51527 L
.08466 .53198 L
.08499 .54137 L
.08538 .54996 L
.08628 .5655 L
.08748 .58143 L
.09023 .60761 L
.09344 .62928 L
Mistroke
.09759 .64913 L
.10016 .65823 L
.10262 .66519 L
.10537 .67113 L
.10695 .67375 L
.1084 .6757 L
.11126 .67829 L
.11397 .6793 L
.11552 .67925 L
.11716 .67873 L
.12006 .67659 L
.12166 .67474 L
.12313 .67261 L
.1264 .66637 L
.12914 .65942 L
.13161 .65166 L
.13587 .63433 L
.13983 .61228 L
.14174 .59856 L
.14327 .58541 L
.14545 .56092 L
.1463 .54779 L
.14697 .53395 L
.14737 .52193 L
.14759 .51089 L
.14767 .49902 L
.14755 .48671 L
.1474 .47991 L
.14721 .4738 L
.14695 .46727 L
.14661 .46061 L
.14589 .44999 L
.14491 .43928 L
.14389 .43068 L
.14266 .42252 L
.14137 .4159 L
.14012 .41083 L
.1386 .40624 L
.13781 .40441 L
.13692 .40279 L
.13532 .40096 L
.1338 .40045 L
.13293 .40069 L
.13202 .40136 L
.13042 .40363 L
.12954 .40547 L
.12874 .40757 L
.127 .41362 L
.12559 .42032 L
.12438 .42781 L
Mistroke
.12338 .43553 L
.12246 .44459 L
.12162 .45537 L
.12101 .46608 L
.12055 .47831 L
.12038 .48553 L
.12028 .49245 L
.12026 .50511 L
.12034 .51232 L
.12046 .51891 L
.12086 .53183 L
.12142 .54401 L
.1223 .55813 L
.12332 .57087 L
.12477 .58528 L
.12636 .59812 L
.12951 .61806 L
.13359 .63692 L
.13809 .65172 L
.1408 .65832 L
.14336 .66323 L
.14577 .66677 L
.14838 .66953 L
.15064 .67107 L
.15314 .67188 L
.15583 .67175 L
.15734 .67123 L
.15872 .67048 L
.16124 .66841 L
.16386 .66532 L
.1661 .66187 L
.16844 .65746 L
.17247 .64778 L
.1769 .63372 L
.1805 .61895 L
.18375 .6022 L
.18674 .58256 L
.18917 .56135 L
.19008 .55112 L
.19079 .54148 L
.19132 .53273 L
.19175 .52339 L
.19202 .51511 L
.19217 .50765 L
.19222 .49911 L
.19215 .49173 L
.19195 .48367 L
.19165 .47658 L
.19124 .46993 L
.19068 .46332 L
Mistroke
.18997 .45723 L
.18923 .45233 L
.18847 .44847 L
.18772 .44558 L
.18682 .44302 L
.18594 .44137 L
.18495 .44044 L
.18445 .44032 L
.1839 .44045 L
.18294 .44137 L
.18205 .44302 L
.18153 .44438 L
.18105 .44592 L
.18019 .44947 L
.17933 .4542 L
.17851 .4604 L
.17789 .46664 L
.17742 .47302 L
.17722 .47659 L
.17702 .48067 L
.17687 .48511 L
.17675 .48942 L
.17665 .49771 L
.17667 .50564 L
.17674 .51015 L
.17685 .51515 L
.17717 .52445 L
.17757 .53288 L
.17817 .54232 L
.17982 .56158 L
.18189 .5792 L
.18431 .59518 L
.1877 .61282 L
.19187 .62959 L
.19586 .64211 L
.20061 .65365 L
.20611 .66337 L
.20932 .66753 L
.2123 .6705 L
.21512 .67257 L
.21673 .67345 L
.21822 .67407 L
.22096 .67475 L
.22388 .67485 L
.22656 .67438 L
.22947 .67328 L
.23221 .6717 L
.23471 .66979 L
.23936 .66511 L
.24414 .65871 L
Mistroke
.25426 .63974 L
.2622 .61913 L
.27393 .57666 L
.28059 .54315 L
.28292 .52988 L
.28378 .52532 L
.28446 .52234 L
.2848 .52121 L
.2851 .52045 L
.28542 .51999 L
.28559 .51989 L
.28575 .51989 L
.28607 .52016 L
.28625 .52048 L
.28643 .52089 L
.28679 .52201 L
.28721 .52367 L
.29828 .58006 L
.31074 .62512 L
.3203 .65174 L
.33083 .67605 L
.35673 .72204 L
.39061 .76604 L
.46779 .84376 L
.51667 .88938 L
.54603 .91538 L
.57518 .93879 L
.60246 .95711 L
.61822 .96545 L
.63282 .97132 L
.63687 .97257 L
.64118 .97373 L
.64896 .97528 L
.65373 .97587 L
.65823 .97616 L
.66226 .97619 L
.66662 .97596 L
.67051 .97552 L
.67477 .97477 L
.6792 .97367 L
.68333 .97235 L
.69068 .96921 L
.69848 .96471 L
.70605 .95908 L
.71294 .95275 L
.72812 .93417 L
.74089 .9126 L
.75364 .88421 L
.76419 .85398 L
.77324 .82162 L
Mistroke
.78211 .7819 L
.79028 .7348 L
.79703 .6829 L
.80005 .65263 L
.80232 .62465 L
.80403 .59817 L
.80541 .56939 L
.80629 .54227 L
.80672 .51752 L
.80677 .48901 L
.80639 .46299 L
.80599 .44839 L
.80551 .43532 L
.80406 .4069 L
.80217 .38107 L
.79962 .3548 L
.79677 .33196 L
.79377 .31267 L
.79092 .29745 L
.78761 .28271 L
.78109 .26057 L
.77704 .2505 L
.77263 .24211 L
.76876 .23675 L
.76445 .23276 L
.76207 .23141 L
.75981 .23067 L
.75558 .23064 L
.75321 .23138 L
.75104 .23255 L
.74867 .23435 L
.74618 .23684 L
.74211 .24224 L
.73839 .2487 L
.73441 .25732 L
.73035 .26815 L
.72313 .29336 L
.71725 .32145 L
.71409 .34065 L
.71146 .35996 L
.70937 .37846 L
.7075 .39888 L
.70612 .41779 L
.70494 .43918 L
.70418 .45918 L
.70374 .47823 L
.70357 .50117 L
.70375 .52239 L
.70398 .53424 L
.70435 .54718 L
Mistroke
.70532 .57084 L
.70651 .59197 L
.7079 .6118 L
.71209 .6567 L
.7175 .69955 L
.72476 .74388 L
.73232 .78067 L
.74137 .81627 L
.74996 .84367 L
.76 .86938 L
.76643 .88269 L
.77254 .89322 L
.77841 .90148 L
.78498 .90862 L
.79096 .91321 L
.7966 .91584 L
.80257 .91682 L
.80899 .91572 L
.8159 .91193 L
.81977 .90857 L
.82332 .90464 L
.82973 .89542 L
.83636 .8827 L
.84722 .85369 L
.85299 .83327 L
.85807 .81162 L
.86635 .76675 L
.87357 .71258 L
.87839 .6619 L
.88053 .63182 L
.88212 .60321 L
.88349 .56943 L
.88428 .53733 L
.88459 .5086 L
.88449 .47778 L
.88388 .4449 L
.88267 .41122 L
.8812 .38367 L
.87914 .3549 L
.87652 .32696 L
.8737 .30309 L
.8699 .27755 L
.86608 .25726 L
.86241 .24161 L
.85821 .22736 L
.85355 .21538 L
.84901 .20704 L
.84479 .20193 L
.8401 .19901 L
.83518 .1989 L
Mistroke
.83061 .20144 L
.82637 .20606 L
.82259 .21211 L
.81833 .22116 L
.81444 .23169 L
.80629 .26189 L
.80259 .28023 L
.79886 .30261 L
.79601 .32323 L
.79331 .34693 L
.79115 .37037 L
.78946 .3931 L
.78789 .42087 L
.78726 .43591 L
.78673 .45222 L
.78634 .46959 L
.78613 .48615 L
.78607 .50114 L
.78616 .51746 L
.7867 .5474 L
.78716 .5625 L
.78782 .57907 L
.78936 .60819 L
.79122 .63506 L
.79659 .69074 L
.80315 .73879 L
.81195 .78594 L
.81703 .80726 L
.82291 .82779 L
.82888 .84477 L
.8346 .85781 L
.84025 .86783 L
.84636 .87563 L
.85194 .88008 L
.85718 .88194 L
.86294 .88138 L
.86907 .87767 L
.87499 .87085 L
.88035 .86174 L
.88604 .84863 L
.89183 .83122 L
.90078 .79421 L
.90536 .76909 L
.90926 .74312 L
.91259 .71643 L
.91538 .68947 L
.9176 .66382 L
.91959 .63547 L
.92132 .6039 L
.92252 .574 L
Mistroke
.92341 .53807 L
.92373 .50548 L
.92355 .47142 L
.92292 .44027 L
.92172 .4072 L
.91988 .37341 L
.91736 .34034 L
.91446 .3116 L
.91146 .28823 L
.90783 .26566 L
.90412 .24743 L
.9004 .23297 L
.89632 .22074 L
.89164 .21066 L
.8875 .20491 L
.88365 .20199 L
.8794 .20135 L
.87493 .20352 L
.87006 .20923 L
.86573 .21731 L
.86092 .22989 L
.8566 .24477 L
.8496 .27783 L
.84612 .29979 L
.84324 .3219 L
.84067 .34591 L
.83835 .37329 L
.83722 .38962 L
.83633 .4049 L
.8356 .41968 L
.83497 .43567 L
.83446 .45241 L
.83413 .46811 L
.8339 .48695 L
.83386 .50413 L
.83397 .52048 L
.83424 .53817 L
.83515 .57011 L
.8365 .59988 L
.83813 .6265 L
.84049 .6564 L
.84317 .68364 L
.84896 .72876 L
.85659 .77171 L
.86108 .79112 L
.86636 .80973 L
.87219 .82575 L
.87495 .83183 L
.8779 .83734 L
.88337 .84494 L
Mistroke
.88847 .84906 L
.89401 .85033 L
.89714 .84956 L
.90004 .84786 L
.90584 .84153 L
.90905 .83625 L
.91195 .83028 L
.91714 .81662 L
.92236 .79843 L
.93057 .75833 L
.93466 .73113 L
.93805 .70316 L
.94138 .66844 L
.94395 .63339 L
.94574 .60059 L
.9471 .5639 L
.94757 .54476 L
.94789 .52354 L
.94801 .50141 L
.94793 .48074 L
.94731 .44448 L
.9467 .42459 L
.94598 .40675 L
.9442 .37435 L
.94206 .34566 L
.93978 .32177 L
.93694 .2981 L
.93347 .27526 L
.92943 .25467 L
.92571 .2402 L
.92141 .22771 L
.91724 .21939 L
.91334 .2146 L
.90878 .21241 L
.90444 .2136 L
.90048 .21743 L
.89687 .22327 L
.89302 .23211 L
.88906 .24419 L
.88466 .26173 L
.88092 .28077 L
.87719 .30457 L
.87375 .33261 L
.8712 .3591 L
.86923 .38532 L
.86754 .41542 L
.86682 .43279 L
.86631 .44887 L
.86573 .47908 L
.86563 .50735 L
Mistroke
.86601 .53846 L
.86638 .5541 L
.86695 .57126 L
.86824 .59952 L
.87011 .62918 L
.8723 .65616 L
.87467 .67981 L
.8778 .70552 L
.88113 .72803 L
.88822 .76469 L
.89262 .78169 L
.8969 .79485 L
.9018 .80632 L
.90433 .81086 L
.90715 .81485 L
.91194 .81913 L
.91636 .82032 L
.92145 .81841 L
.92623 .81327 L
.93054 .80569 L
.93443 .79623 L
.93854 .78321 L
.94268 .76641 L
.94723 .74283 L
.95101 .7179 L
.95466 .68729 L
.95789 .65188 L
.96013 .61891 L
.96172 .58684 L
.9624 .56802 L
.96288 .5507 L
.96326 .53059 L
.96345 .51153 L
.96337 .47894 L
.96276 .44499 L
.96181 .41687 L
.96033 .38718 L
.95826 .35724 L
.95551 .32768 L
.95247 .30271 L
.94934 .28263 L
.94563 .2641 L
.94189 .24991 L
.93836 .23996 L
.93441 .23224 L
.92999 .22746 L
.92774 .22649 L
.92527 .22653 L
.92091 .22937 L
.91691 .23516 L
Mistroke
.91298 .24391 L
.90941 .25478 L
.90319 .2814 L
.90005 .29949 L
.8974 .31807 L
.89482 .34009 L
.89243 .36565 L
.89046 .3929 L
.88905 .41904 L
.88807 .4448 L
.88745 .47252 L
.88725 .50335 L
.88752 .53211 L
.88788 .54855 L
.88833 .56339 L
.889 .58033 L
.88978 .5961 L
.8916 .62482 L
.89403 .65381 L
.89959 .70092 L
.90328 .72376 L
.90707 .74259 L
.91156 .76009 L
.91417 .76825 L
.9167 .77488 L
.91896 .77982 L
.92145 .78422 L
.92586 .78948 L
.92839 .79107 L
.93108 .79162 L
.93587 .78968 L
.94027 .78451 L
.94427 .77676 L
.94851 .76506 L
.95282 .74892 L
.95714 .72754 L
.96134 .69999 L
.96479 .67032 L
.96745 .64019 L
.9694 .6113 L
.97101 .57793 L
.9716 .56073 L
.97208 .54199 L
.97249 .50784 L
.97235 .47502 L
.97176 .44506 L
.97059 .41326 L
.96971 .39614 L
.96879 .3811 L
.96653 .35234 L
Mistroke
.96357 .32419 L
.96032 .3009 L
.957 .28256 L
.95372 .26855 L
.95048 .258 L
.94678 .24935 L
.94269 .24352 L
.94062 .24195 L
.93835 .24126 L
.93422 .2427 L
.93024 .24737 L
.92665 .25448 L
.92269 .26569 L
.91875 .28088 L
.91562 .29637 L
.91247 .31576 L
.90944 .3392 L
.90668 .36679 L
.90457 .39478 L
.90309 .42155 L
.90204 .4495 L
.90148 .47585 L
.90132 .50505 L
.90143 .51979 L
.90168 .53595 L
.90244 .56271 L
.90371 .59079 L
.90532 .61633 L
.90714 .63862 L
.90932 .66014 L
.91197 .68141 L
.91752 .71459 L
.92134 .73119 L
.92518 .74395 L
.92878 .75285 L
.93279 .75963 L
.93644 .76305 L
.94047 .7639 L
.94467 .76149 L
.94854 .75617 L
.95207 .74853 L
.95518 .73937 L
.9586 .72625 L
.96165 .71142 L
.96459 .69368 L
.96745 .67212 L
.96963 .65165 L
.97169 .62755 L
.97355 .59912 L
.97436 .583 L
Mistroke
.97499 .56768 L
.97579 .53969 L
.97618 .50937 L
.97619 .49263 L
.97607 .47727 L
.97579 .46056 L
.97534 .44312 L
.97421 .41465 L
.97338 .39907 L
.97247 .38497 L
.97051 .36056 L
.96832 .33926 L
.96543 .31729 L
.96249 .29988 L
.95943 .28572 L
.95648 .27521 L
.95294 .2659 L
.94949 .25997 L
.94622 .25692 L
.9432 .25621 L
.93988 .25771 L
.93643 .26182 L
.933 .26853 L
.92947 .27844 L
.92629 .29022 L
.92356 .30286 L
.92059 .31984 L
.91768 .34065 L
.91527 .36235 L
.91338 .38367 L
.91185 .40561 L
.91059 .4296 L
.9097 .45438 L
.90917 .48194 L
.90908 .50602 L
.90938 .53159 L
.91001 .55537 L
.91089 .57644 L
.91241 .60243 L
.91419 .62511 L
.91655 .64833 L
.91945 .67061 L
.92208 .68671 L
.92516 .7018 L
.92878 .71553 L
.93236 .72546 L
.93433 .72956 L
.93645 .73297 L
.94034 .73657 L
.94251 .73715 L
Mistroke
.94455 .73676 L
.94678 .73527 L
.94916 .73243 L
.95106 .7292 L
.95311 .72471 L
.9571 .71269 L
.96057 .69814 L
.96356 .68182 L
.96641 .66186 L
.96879 .64073 L
.97063 .62009 L
.97228 .59621 L
.97365 .56879 L
.97417 .55454 L
.9746 .53861 L
.975 .5101 L
.97495 .48331 L
.97447 .45586 L
.97401 .44081 L
.97348 .42741 L
.97214 .4022 L
.97054 .37978 L
.96825 .35556 L
.96579 .33551 L
.96276 .31625 L
.95922 .29936 L
.95613 .28841 L
.95267 .27956 L
.94929 .274 L
.94615 .27131 L
.94245 .27105 L
.94037 .27225 L
.93845 .27422 L
.93499 .27992 L
.93144 .28881 L
.92845 .29894 L
.92584 .30999 L
.92322 .32363 L
.92059 .34042 L
.91679 .37261 L
.91509 .39185 L
.91376 .41059 L
.91251 .43397 L
.91168 .45664 L
.91123 .47729 L
.91106 .49977 L
.91125 .52416 L
.9115 .53631 L
.91188 .5495 L
.91284 .57227 L
Mistroke
.91407 .5927 L
.91571 .61354 L
.91781 .63411 L
.9199 .65033 L
.92241 .66604 L
.92566 .68186 L
.92897 .69383 L
.9306 .69845 L
.93236 .70256 L
.93559 .70789 L
.93873 .7105 L
.94211 .71054 L
.94529 .70794 L
.94812 .70335 L
.95135 .69529 L
.95311 .6895 L
.95469 .68338 L
.95741 .67037 L
.9601 .65387 L
.96224 .63725 L
.96397 .62056 L
.9655 .60231 L
.96668 .58438 L
.96776 .56263 L
.96857 .53799 L
.96895 .51577 L
.96901 .49188 L
.96869 .46707 L
.96833 .45328 L
.9679 .44075 L
.96684 .41834 L
.96537 .39577 L
.96375 .37677 L
.962 .36027 L
.95987 .34397 L
.95727 .328 L
.9544 .31424 L
.95114 .30239 L
.94795 .29407 L
.94486 .28864 L
.94306 .28659 L
.94115 .28526 L
.93773 .28498 L
.93582 .28599 L
.93406 .28765 L
.93214 .29027 L
.93013 .29397 L
.92684 .30219 L
.92345 .3138 L
.92046 .32713 L
Mistroke
.91791 .34127 L
.91373 .37227 L
.91198 .38964 L
.91036 .40981 L
.9091 .4303 L
.9082 .45031 L
.90766 .46855 L
.90734 .48856 L
.90734 .51018 L
.90748 .52214 L
.9077 .53286 L
.90837 .5533 L
.9093 .57183 L
.91041 .58852 L
.91183 .60513 L
.91495 .63179 L
.91698 .64465 L
.91902 .65522 L
.92142 .6651 L
.92414 .67357 L
.92689 .67958 L
.92849 .68199 L
.93 .68358 L
.93308 .68476 L
.93481 .68423 L
.93639 .68298 L
.93902 .67924 L
.94181 .67283 L
.9446 .66361 L
.94704 .65281 L
.94971 .63728 L
.95194 .62022 L
.95368 .60313 L
.95525 .58299 L
.95657 .55943 L
.95706 .54706 L
.95747 .53317 L
.9577 .52114 L
.95784 .50809 L
.95786 .49571 L
.95778 .4844 L
.95736 .46227 L
.95701 .45123 L
.95653 .4392 L
.95542 .41856 L
.95409 .40004 L
.95219 .37972 L
.95016 .36262 L
.94763 .34581 L
.94468 .33057 L
Mistroke
.94208 .32018 L
.93914 .3112 L
.93625 .30482 L
.93356 .30082 L
.93033 .29833 L
.9285 .29797 L
.92681 .2983 L
.92373 .30056 L
.92052 .3052 L
.91758 .3116 L
.9145 .3207 L
.91175 .33119 L
.90935 .34244 L
.90532 .36717 L
.90339 .38269 L
.90184 .39762 L
.90039 .41489 L
.89915 .43381 L
.89863 .44391 L
.89815 .45511 L
.89758 .47497 L
.89733 .49373 L
.8974 .51362 L
.89776 .53198 L
.89833 .5482 L
.89914 .56382 L
.90024 .57954 L
.90136 .59214 L
.90279 .60505 L
.90451 .61758 L
.90657 .62943 L
.90869 .63891 L
.91074 .64603 L
.91277 .65133 L
.91472 .65495 L
.9169 .65742 L
.91925 .6583 L
.92172 .65725 L
.92403 .65438 L
.92605 .65028 L
.92817 .64422 L
.93036 .63578 L
.93224 .62646 L
.93423 .61392 L
.93592 .60038 L
.93718 .5876 L
.93834 .57296 L
.93935 .55586 L
.94005 .53921 L
.94035 .52868 L
Mistroke
.94055 .51885 L
.94067 .50793 L
.94069 .49631 L
.94047 .47667 L
.94021 .46557 L
.93987 .4553 L
.93901 .43641 L
.93797 .41976 L
.93647 .40142 L
.93478 .38515 L
.93058 .35593 L
.92812 .3436 L
.9252 .3321 L
.92257 .32415 L
.91961 .31754 L
.91674 .31321 L
.91406 .31088 L
.91251 .31024 L
.91086 .31013 L
.9079 .31135 L
.9061 .31299 L
.90443 .31515 L
.90135 .3207 L
.89822 .32863 L
.89547 .33769 L
.89249 .35009 L
.8899 .36355 L
.88796 .37577 L
.88605 .39004 L
.8833 .41694 L
.88209 .43296 L
.88109 .45038 L
.88048 .46541 L
.88005 .48203 L
.8799 .49728 L
.87996 .51104 L
.88023 .52577 L
.88076 .54071 L
.88141 .55317 L
.88217 .56418 L
.88316 .57553 L
.88438 .58672 L
.88602 .59841 L
.8877 .60775 L
.8897 .61629 L
.89078 .61992 L
.89198 .62325 L
.89404 .62745 L
.89602 .62979 L
.89724 .63045 L
Mistroke
.8984 .63052 L
.90058 .62921 L
.9025 .62644 L
.90449 .62184 L
.90629 .61598 L
.90784 .60945 L
.90953 .6003 L
.91119 .58879 L
.91255 .57649 L
.91362 .5641 L
.91454 .54997 L
.91519 .53579 L
.91559 .52254 L
.91582 .5077 L
.91581 .49123 L
.9157 .48285 L
.91551 .47358 L
.91496 .45727 L
.91421 .44219 L
.91329 .4282 L
.91211 .41397 L
.9095 .3902 L
.90602 .36769 L
.90378 .35662 L
.90155 .34754 L
.89897 .33907 L
.89603 .33165 L
.89464 .32887 L
.89315 .32637 L
.89043 .32301 L
.88778 .32116 L
.88528 .32064 L
.88254 .32139 L
.87963 .3237 L
.87804 .32562 L
.87659 .3278 L
.87338 .3341 L
.87066 .34113 L
.86791 .35002 L
.86314 .37052 L
.85949 .39233 L
.85663 .41553 L
.85532 .42931 L
.85431 .4424 L
.85347 .45638 L
.85291 .4691 L
.85268 .4761 L
.85249 .48365 L
.85234 .49715 L
.85238 .50839 L
Mistroke
.8526 .52036 L
.85303 .53229 L
.8536 .54284 L
.85427 .55207 L
.855 .55993 L
.85699 .57537 L
.85828 .58247 L
.85977 .58876 L
.86126 .59343 L
.86268 .59654 L
.86357 .59792 L
.86439 .59882 L
.86531 .5994 L
.86628 .59955 L
.8679 .59872 L
.86882 .59764 L
.86966 .59624 L
.87124 .59249 L
.87268 .58769 L
.87389 .58238 L
.87511 .57556 L
.87631 .56702 L
.87742 .55673 L
.87822 .54705 L
.87858 .54158 L
.87891 .53553 L
.87938 .52429 L
.87965 .51334 L
.87974 .50646 L
.87976 .49985 L
.87966 .48726 L
.87934 .47375 L
.87885 .46123 L
.87809 .44755 L
.87704 .43329 L
.87478 .41079 L
.8721 .39131 L
.86858 .37229 L
.86422 .35519 L
.86159 .3474 L
.85905 .34132 L
.85615 .33594 L
.85463 .33372 L
.85297 .33173 L
.85136 .33022 L
.84987 .32918 L
.84844 .3285 L
.84693 .3281 L
.84429 .32819 L
.84142 .3294 L
Mistroke
.83861 .33171 L
.8361 .33472 L
.83326 .33923 L
.83065 .34446 L
.82625 .35584 L
.8219 .37083 L
.81829 .38683 L
.81496 .40563 L
.81238 .42433 L
.81053 .44181 L
.80903 .46114 L
.80845 .47185 L
.80807 .48156 L
.80793 .48674 L
.80784 .49152 L
.80778 .50019 L
.80786 .50907 L
.80797 .51384 L
.80811 .51807 L
.80844 .52515 L
.80892 .53213 L
.80947 .53808 L
.81004 .54293 L
.8108 .54789 L
.81172 .55233 L
.81216 .55403 L
.81265 .5556 L
.81355 .55778 L
.8145 .55916 L
.81504 .55956 L
.81554 .55969 L
.81646 .55932 L
.81741 .55809 L
.81791 .55709 L
.81843 .55575 L
.81933 .55267 L
.82032 .54789 L
.82114 .54254 L
.82174 .53734 L
.82223 .53193 L
.82268 .52541 L
.82304 .51779 L
.82317 .51377 L
.82327 .50922 L
.82336 .50056 L
.82329 .49172 L
.82311 .48322 L
.82278 .47431 L
.82235 .46575 L
.82121 .44951 L
Mistroke
.81949 .432 L
.81707 .41348 L
.81402 .39555 L
.81004 .37752 L
.80525 .36105 L
.80028 .34823 L
.79526 .3387 L
.79046 .3322 L
.78773 .32951 L
.78628 .32835 L
.78472 .32731 L
.78185 .32593 L
.77918 .32524 L
.77665 .3251 L
.77388 .32549 L
.771 .32648 L
.76835 .32792 L
.76587 .3297 L
.76365 .33167 L
.75877 .33718 L
.75372 .34464 L
.74854 .35421 L
.74006 .37441 L
.73328 .39523 L
.72746 .41735 L
.72026 .45206 L
.71777 .46624 L
.71608 .47534 L
.71571 .47699 L
.71534 .47837 L
.71513 .47899 L
.71495 .47943 L
.71478 .47976 L
.71461 .47998 L
.7143 .48013 L
.71402 .47996 L
.71371 .47944 L
.71336 .47851 L
.71304 .47738 L
.71273 .47609 L
.71197 .47233 L
.71024 .46266 L
.7038 .4292 L
.69204 .38369 L
.67583 .33878 L
.6521 .29194 L
.62071 .24734 L
.54865 .17189 L
.46329 .09267 L
.43692 .07053 L
Mistroke
.40657 .04846 L
.39223 .03986 L
.37665 .03226 L
.369 .0293 L
.36175 .02702 L
.35521 .02546 L
.34812 .02432 L
.34112 .02381 L
.33459 .02394 L
.32743 .0248 L
.31977 .02662 L
.31594 .02791 L
.31178 .02962 L
.30427 .03355 L
.29702 .03847 L
.29039 .04403 L
.27869 .05664 L
.2662 .07466 L
.25378 .09831 L
.24283 .12512 L
.23177 .15959 L
.2225 .19625 L
.21362 .24113 L
.20576 .29364 L
.20249 .32154 L
.19948 .35261 L
.19731 .3805 L
.19551 .41035 L
.19433 .43732 L
.19385 .45263 L
.19351 .46689 L
.19322 .49172 L
.19329 .51797 L
.19377 .54371 L
.19458 .56688 L
.19584 .59138 L
.1976 .61623 L
.19967 .63857 L
.20193 .65827 L
.20692 .69124 L
.21269 .71851 L
.21862 .73857 L
.22191 .74711 L
.22564 .75489 L
.22964 .76124 L
.23345 .76554 L
.23775 .7685 L
.23993 .76927 L
.24234 .76956 L
.2466 .76869 L
Mistroke
.25057 .76628 L
.25282 .76423 L
.25517 .76155 L
.2593 .75548 L
.26362 .74717 L
.26816 .73607 L
.27527 .71301 L
.28196 .68287 L
.28726 .64987 L
.29112 .61663 L
.29271 .59861 L
.29409 .57886 L
.29503 .56151 L
.29579 .54197 L
.29628 .52048 L
.29641 .50823 L
.29643 .49694 L
.29621 .47478 L
.29567 .45352 L
.29489 .43364 L
.29376 .4124 L
.29095 .3742 L
.2863 .32923 L
.28088 .28955 L
.27403 .24966 L
.26519 .20876 L
.25462 .17024 L
.24367 .13926 L
.23257 .11545 L
.22193 .09894 L
.21588 .09217 L
.2092 .08688 L
.20283 .08397 L
.19693 .08317 L
.19059 .08442 L
.18381 .08828 L
.17748 .09439 L
.1718 .10211 L
.16531 .11375 L
.15848 .12968 L
.1469 .16717 L
.14114 .19208 L
.13633 .21718 L
.13162 .24668 L
.12714 .28115 L
.12358 .31521 L
.12085 .34796 L
.11875 .38025 L
.11707 .41506 L
.11601 .44837 L
Mistroke
.11564 .46722 L
.11545 .48462 L
.11546 .51626 L
.11597 .54922 L
.11687 .5778 L
.11807 .60372 L
.11978 .63093 L
.12204 .65859 L
.12474 .68432 L
.12812 .70994 L
.1321 .73362 L
.13615 .75265 L
.14015 .7675 L
.14412 .77909 L
.14888 .78946 L
.15334 .79609 L
.15735 .79974 L
.1618 .80138 L
.16646 .80048 L
.17079 .79727 L
.17478 .79229 L
.17835 .7861 L
.18237 .77711 L
.18605 .76682 L
.19368 .73824 L
.19988 .70546 L
.20555 .6636 L
.20814 .63796 L
.21009 .61355 L
.21164 .58845 L
.21273 .56434 L
.21353 .53725 L
.21391 .50768 L
.21391 .49266 L
.21377 .47626 L
.21312 .44637 L
.21202 .4173 L
.21057 .39065 L
.20697 .34355 L
.20435 .3176 L
.20155 .29402 L
.19489 .24933 L
.18634 .20648 L
.17627 .16965 L
.17008 .15262 L
.16408 .13958 L
.16072 .13368 L
.1575 .12892 L
.15138 .12226 L
.14792 .11983 L
Mistroke
.14471 .11846 L
.14118 .11792 L
.13744 .11849 L
.13172 .12166 L
.12566 .12823 L
.12006 .13746 L
.11509 .14846 L
.10949 .16442 L
.10371 .18547 L
.09861 .20884 L
.0943 .233 L
.08716 .2858 L
.08407 .31647 L
.08134 .35052 L
.07942 .38138 L
.07804 .41081 L
.07697 .44358 L
.07637 .47883 L
.07627 .49875 L
.07633 .51702 L
.07658 .53686 L
.07702 .55758 L
.07822 .59141 L
.07913 .60997 L
.08014 .62684 L
.08238 .65668 L
.08483 .682 L
.08809 .7086 L
.09158 .73102 L
.09565 .75152 L
.0996 .76703 L
.10189 .77433 L
.10443 .78116 L
.10918 .79069 L
.11375 .79629 L
.11865 .79868 L
.12284 .79792 L
.12741 .79417 L
.13014 .79045 L
.1327 .78596 L
.13736 .77507 L
.14214 .75995 L
.147 .73978 L
.15089 .7193 L
.15463 .69491 L
.15746 .67204 L
.16014 .64525 L
.16222 .61886 L
.16377 .59328 L
.16499 .56536 L
Mistroke
.16582 .53478 L
.16613 .50575 L
.16602 .47812 L
.16557 .45328 L
.16472 .42647 L
.16336 .39743 L
.16134 .36615 L
.15868 .33456 L
.1557 .30628 L
.14923 .25967 L
.14505 .23637 L
.14085 .21679 L
.13191 .18502 L
.12684 .17199 L
.12124 .16124 L
.11576 .15415 L
.11052 .15046 L
.10579 .14968 L
.10068 .15162 L
.09603 .15598 L
.09102 .16363 L
.08593 .1748 L
.08136 .18811 L
.07373 .21865 L
.06983 .23932 L
.06655 .26018 L
.06029 .31294 L
.05746 .34615 L
.05531 .37889 L
.05362 .41455 L
.05259 .4479 L
.05224 .46643 L
.05202 .48668 L
.05211 .52334 L
.05273 .55692 L
.05373 .58646 L
.05538 .61906 L
.05741 .64797 L
.05967 .67292 L
.06205 .69408 L
.06835 .73469 L
.07207 .75159 L
.07631 .7662 L
.08051 .77655 L
.08447 .78304 L
.08918 .78704 L
.09187 .7876 L
.09436 .78704 L
.09888 .78335 L
.10114 .78021 L
Mistroke
.1036 .77578 L
.10835 .76407 L
.1125 .75011 L
.11677 .73149 L
.12087 .7085 L
.12673 .66295 L
.12937 .63398 L
.13136 .60539 L
.13283 .57619 L
.13339 .56111 L
.13386 .54429 L
.13433 .51414 L
.13433 .48565 L
.13412 .46843 L
.13378 .45211 L
.13277 .42175 L
.132 .40503 L
.13115 .38973 L
.12875 .35601 L
.12614 .32775 L
.12326 .30262 L
.11689 .2604 L
.11281 .23988 L
.10878 .22333 L
.1041 .20794 L
.09891 .1951 L
.09435 .18713 L
.09012 .18232 L
.08517 .17978 L
.08047 .18044 L
.07616 .18373 L
.07223 .18909 L
.06801 .19751 L
.06368 .20933 L
.05954 .22407 L
.05535 .24305 L
.04861 .28492 L
.04529 .31314 L
.04232 .34543 L
.04025 .37475 L
.03849 .4082 L
.03781 .42553 L
.03725 .44406 L
.03664 .47757 L
.03657 .51362 L
.03679 .53387 L
.03718 .55255 L
.03828 .58543 L
.03974 .61411 L
.04194 .64518 L
Mistroke
.04448 .67223 L
.04711 .69413 L
.05022 .71482 L
.05315 .73036 L
.05653 .74458 L
.06033 .75671 L
.06406 .76516 L
.06626 .76873 L
.06862 .77144 L
.07286 .7736 L
.07742 .77213 L
.08151 .76749 L
.08374 .76361 L
.08612 .75837 L
.0903 .74623 L
.094 .73196 L
.09767 .71401 L
.10342 .67536 L
.10611 .65061 L
.10854 .62195 L
.11034 .59331 L
.11156 .56607 L
.1121 .5492 L
.11245 .53336 L
.11269 .51582 L
.11275 .49704 L
.11264 .47911 L
.11237 .46226 L
.112 .44722 L
.11147 .43108 L
.11016 .40263 L
.10857 .37747 L
.1063 .34967 L
.10374 .32484 L
.09827 .2852 L
.09472 .2658 L
.09118 .25004 L
.0874 .23649 L
.08312 .22468 L
.08059 .2193 L
.07824 .21529 L
.07353 .21004 L
.0689 .20837 L
.06628 .20897 L
.06384 .21054 L
.06128 .21328 L
.05898 .21671 L
.05637 .2218 L
.05395 .22769 L
.04983 .24061 L
Mistroke
.04556 .25842 L
.04146 .28081 L
.03801 .30499 L
.03522 .32962 L
.03293 .35488 L
.03077 .3859 L
.02925 .41562 L
.02812 .44932 L
.02774 .46843 L
.02754 .4858 L
.02759 .51957 L
.02814 .55083 L
.02866 .56825 L
.02939 .5862 L
.03109 .61698 L
.03348 .64771 L
.0367 .67792 L
.03985 .70017 L
.04307 .71779 L
.04689 .73366 L
.04894 .74031 L
.0512 .74634 L
.05509 .75377 L
.05882 .75771 L
.061 .75864 L
.06329 .75858 L
.06738 .75581 L
.07098 .75052 L
.07471 .74208 L
.0781 .73157 L
.08104 .72004 L
.08428 .70417 L
.0875 .68446 L
.09243 .6429 L
.0946 .61729 L
.09622 .59204 L
.09696 .57736 L
.09754 .5632 L
.09807 .54664 L
.09841 .53136 L
.09861 .5162 L
.09869 .50002 L
.09845 .47097 L
.09811 .45497 L
.09766 .44009 L
.09703 .42398 L
.09617 .40692 L
.09453 .38165 L
.0923 .35541 L
.08952 .32997 L
Mistroke
.08654 .3084 L
.08038 .27578 L
.07656 .26136 L
.07289 .25091 L
.06906 .24308 L
.06538 .23833 L
.06129 .23609 L
.05688 .23721 L
.0547 .23916 L
.05233 .24235 L
.04812 .25098 L
.04419 .2628 L
.04073 .2767 L
.03744 .29363 L
.0346 .31195 L
.03006 .35164 L
.028 .37655 L
.02645 .40079 L
.02515 .42853 L
.02424 .45873 L
.02382 .49012 L
.02389 .51872 L
.02411 .53439 L
.0245 .55122 L
.02558 .581 L
.02703 .60753 L
.029 .63393 L
.03101 .65474 L
.03354 .67557 L
.03689 .69677 L
.04026 .71296 L
.04423 .72693 L
.04631 .7324 L
.04864 .73716 L
.05267 .74231 L
.05495 .74359 L
.05703 .74376 L
.06106 .74142 L
.0648 .73608 L
.06822 .72839 L
.07174 .71742 L
.07489 .70464 L
.07758 .69106 L
.08048 .67306 L
.0833 .65113 L
.08558 .62869 L
.08737 .60618 L
.0882 .59348 L
.08898 .57945 L
.09003 .55436 L
Mistroke
.09045 .53985 L
.09075 .52441 L
.09092 .49663 L
.09067 .47095 L
.09008 .44736 L
.08904 .42211 L
.08828 .40836 L
.08749 .39615 L
.08582 .37502 L
.08372 .354 L
.07919 .32062 L
.07629 .30487 L
.07338 .29216 L
.06999 .28067 L
.06802 .27544 L
.06616 .27136 L
.06278 .26605 L
.05902 .26314 L
.05569 .26314 L
.05216 .26582 L
.04875 .27115 L
.04562 .27859 L
.04292 .28723 L
.04012 .29859 L
.03707 .31442 L
.03452 .33109 L
.03205 .35119 L
.02975 .37531 L
.02799 .39936 L
.02671 .42282 L
.02581 .44607 L
.0252 .47137 L
.02497 .49875 L
.02503 .51416 L
.0252 .52821 L
.02581 .55373 L
.02685 .57978 L
.02757 .59316 L
.02847 .60701 L
.03037 .63064 L
.03311 .65613 L
.03599 .67644 L
.03908 .69317 L
.04263 .70757 L
.04584 .71704 L
.04952 .72435 L
.05162 .72701 L
.05356 .72853 L
.05582 .72921 L
.05796 .72879 L
Mistroke
.06173 .72555 L
.06383 .72233 L
.06574 .71849 L
.06939 .70864 L
.07264 .69671 L
.07812 .66825 L
.08079 .64919 L
.08295 .63003 L
.08497 .60747 L
.08667 .58226 L
.08777 .55946 L
.08824 .54633 L
.08856 .53408 L
.0889 .51145 L
.08889 .48744 L
.08857 .46622 L
.08799 .44669 L
.08706 .42586 L
.08573 .40436 L
.08406 .38397 L
.08189 .36335 L
.07926 .34399 L
.07652 .32825 L
.07373 .31564 L
.07103 .30617 L
.06778 .29773 L
.0646 .29234 L
.06177 .28975 L
.05865 .28922 L
.05539 .29128 L
.0524 .29563 L
.04967 .30179 L
.04726 .30915 L
.04461 .31963 L
.04225 .33146 L
.03989 .34616 L
.03764 .36382 L
.03592 .38059 L
.03433 .40007 L
.03295 .42222 L
.03198 .44402 L
.03156 .45698 L
.03124 .47082 L
.03097 .49589 L
.0311 .52064 L
.03135 .53451 L
.03168 .54718 L
.03256 .56996 L
.03385 .59313 L
.03531 .61275 L
Mistroke
.03693 .62998 L
.0414 .66427 L
.04428 .67983 L
.04723 .69214 L
.05004 .70102 L
.05323 .70829 L
.05508 .71127 L
.05678 .71326 L
.05876 .71469 L
.06064 .71521 L
.06397 .71415 L
.06754 .71021 L
.07057 .70451 L
.07331 .69737 L
.07618 .68762 L
.07909 .6751 L
.0819 .65988 L
.08432 .64369 L
.08628 .62767 L
.0881 .60949 L
.08944 .593 L
.09066 .5741 L
.09153 .55644 L
.09213 .53957 L
.09256 .51959 L
.0927 .50125 L
.09257 .48128 L
.09212 .46064 L
.09134 .44034 L
.09077 .42925 L
.09015 .41931 L
.08883 .40215 L
.0871 .3846 L
.08348 .35799 L
.0812 .34582 L
.07891 .33613 L
.07608 .32702 L
.07328 .32071 L
.07069 .31705 L
.06782 .31529 L
.06618 .31535 L
.0647 .31606 L
.06301 .31767 L
.06143 .31996 L
.05867 .32585 L
.05582 .33479 L
.05347 .34468 L
.05143 .35557 L
.0492 .37048 L
.0474 .38574 L
Mistroke
.04576 .40333 L
.04447 .42121 L
.04341 .44119 L
.04294 .45286 L
.04261 .46385 L
.04225 .4823 L
.04214 .49982 L
.04227 .5191 L
.0427 .53971 L
.04347 .5608 L
.04451 .58023 L
.04568 .59695 L
.04719 .61425 L
.04913 .63186 L
.05147 .6487 L
.05434 .6648 L
.05722 .67724 L
.06007 .68664 L
.06286 .69345 L
.06601 .69865 L
.06781 .70053 L
.06946 .70158 L
.07253 .7019 L
.07536 .70032 L
.07842 .69659 L
.0816 .69041 L
.08425 .68331 L
.08664 .67524 L
.09163 .65228 L
.09389 .63835 L
.09611 .62167 L
.09798 .60421 L
.09966 .58447 L
.1009 .56519 L
.10176 .54722 L
.10234 .52894 L
.10263 .51163 L
.10265 .49159 L
.10254 .48162 L
.10232 .4708 L
.10168 .45219 L
.10082 .43551 L
.09948 .41706 L
.09797 .40151 L
.09593 .38539 L
.09373 .37211 L
.09162 .36231 L
.08918 .35373 L
.08676 .34768 L
.08447 .34393 L
Mistroke
.08235 .34209 L
.08001 .34179 L
.07758 .34341 L
.07535 .34671 L
.07412 .34931 L
.07281 .35274 L
.07052 .36054 L
.06842 .37 L
.06662 .3803 L
.06486 .39298 L
.06316 .40866 L
.06169 .4267 L
.06061 .44492 L
.05996 .46054 L
.0595 .47819 L
.05931 .49705 L
.05939 .51478 L
.05971 .53144 L
.06019 .54642 L
.06098 .5634 L
.06194 .57894 L
.06322 .59522 L
.06484 .61148 L
.06832 .63758 L
.07056 .65013 L
.07282 .66043 L
.07545 .67006 L
.07843 .67834 L
.08002 .68174 L
.08153 .6844 L
.0844 .68797 L
.08754 .68976 L
.08931 .68984 L
.09094 .68934 L
.09366 .68726 L
.09659 .68325 L
.09956 .67723 L
.10223 .67002 L
.10525 .65958 L
.10791 .648 L
.1123 .62249 L
.11437 .6064 L
.11602 .59066 L
.11752 .57263 L
.11819 .56259 L
.11874 .55293 L
.11945 .53669 L
.11987 .52179 L
.12009 .50586 L
.1201 .49695 L
Mistroke
.12004 .48877 L
.11977 .47415 L
.11933 .46134 L
.11861 .44719 L
.11774 .43462 L
.11657 .42169 L
.11511 .40931 L
.1137 .39988 L
.11201 .39085 L
.11004 .38279 L
.1089 .37912 L
.10779 .37618 L
.10674 .3739 L
.10557 .37195 L
.1035 .36987 L
.10148 .36949 L
.09964 .37056 L
.09764 .37329 L
.09559 .37791 L
.09388 .38336 L
.09237 .38959 L
.09082 .39757 L
.08929 .40758 L
.08781 .41998 L
.08661 .43296 L
.08566 .44664 L
.08498 .46002 L
.08447 .47517 L
.08428 .48403 L
.08418 .49245 L
.08416 .50142 L
.0842 .50968 L
.08434 .51926 L
.08455 .52837 L
.08483 .53729 L
.08517 .54564 L
.08599 .56102 L
.08712 .57712 L
.08864 .59375 L
.09021 .60754 L
.09209 .62108 L
.09598 .64232 L
.09843 .65238 L
.10123 .66148 L
.104 .66841 L
.10661 .67326 L
.10824 .67553 L
.10976 .67716 L
.11144 .67843 L
.11324 .67919 L
Mistroke
.1148 .67935 L
.11626 .6791 L
.11786 .67837 L
.11957 .67708 L
.12239 .67376 L
.12489 .66954 L
.12769 .66332 L
.13022 .65621 L
.13443 .64085 L
.13843 .62089 L
.14209 .59575 L
.14361 .5822 L
.145 .56685 L
.14596 .55351 L
.1464 .54612 L
.14675 .53911 L
.14727 .52555 L
.14756 .51332 L
.14767 .5008 L
.14765 .49382 L
.14757 .48739 L
.14725 .47485 L
.14699 .46807 L
.14669 .46206 L
.14607 .4524 L
.14525 .44258 L
.14423 .43325 L
.14315 .42548 L
.14171 .41747 L
.14024 .41124 L
.13883 .40681 L
.13724 .40329 L
.13639 .40201 L
.13545 .40104 L
.13446 .40051 L
.13352 .40047 L
.13187 .4015 L
.13095 .4027 L
.13012 .40419 L
.12857 .40803 L
.12719 .41283 L
.12602 .41809 L
.12484 .42473 L
.12367 .43308 L
.1226 .44303 L
.12183 .45236 L
.12114 .46338 L
.12067 .47437 L
.12039 .48484 L
.12024 .49738 L
Mistroke
.1203 .50958 L
.12051 .52103 L
.12085 .5317 L
.12138 .54342 L
.12213 .55577 L
.12426 .58055 L
.12578 .59378 L
.12738 .6053 L
.13079 .62468 L
.13494 .64195 L
.13736 .64968 L
.14007 .65671 L
.14273 .66215 L
.14522 .66607 L
.14666 .66786 L
.14821 .66941 L
.14992 .67068 L
.15151 .67147 L
.15438 .67197 L
.15601 .67173 L
.15753 .67117 L
.16025 .66935 L
.16175 .66791 L
.1631 .66634 L
.16806 .65826 L
.17072 .65236 L
.17347 .64498 L
.17807 .62931 L
.18192 .61212 L
.18536 .59228 L
.18776 .57448 L
.18888 .56429 L
.18979 .55462 L
.19053 .5453 L
.19118 .5353 L
.19163 .52636 L
.19193 .5183 L
.19213 .50983 L
.19222 .50084 L
.19216 .49192 L
.19197 .48404 L
.19168 .47715 L
.19132 .47105 L
.19093 .46599 L
.19043 .46093 L
.18981 .45602 L
.18908 .45147 L
.18833 .44787 L
.18761 .44518 L
.18675 .44284 L
Mistroke
.18593 .44134 L
.185 .44045 L
.184 .44039 L
.1835 .44071 L
.18296 .44132 L
.182 .44313 L
.18109 .44575 L
.1803 .44892 L
.17961 .45247 L
.17902 .45632 L
.17842 .46111 L
.17787 .46689 L
.17741 .47321 L
.17703 .48046 L
.17681 .4871 L
.17667 .49477 L
.17664 .49929 L
.17666 .50433 L
.17672 .5092 L
.17681 .51377 L
.17709 .52263 L
.17754 .53223 L
.17819 .5427 L
.17897 .55257 L
.18133 .57492 L
.18404 .5936 L
.18703 .60969 L
.19105 .62663 L
.19536 .64071 L
.20021 .65282 L
.20511 .66188 L
.20971 .66799 L
.21237 .67058 L
.21485 .67242 L
.21756 .67383 L
.2201 .67462 L
.22289 .6749 L
.22446 .67481 L
.22589 .67456 L
.22875 .67362 L
.23036 .67284 L
.23184 .67196 L
.23736 .66732 L
.24194 .66186 L
.24609 .65566 L
.25487 .63838 L
.26233 .61876 L
.26906 .59641 L
.27821 .55613 L
.28339 .52729 L
Mistroke
.28387 .52488 L
.28434 .52278 L
.28476 .52132 L
.28494 .5208 L
.28512 .52041 L
.28543 .51997 L
.2856 .51987 L
.28577 .51988 L
.28596 .52002 L
.28614 .52026 L
.28648 .52101 L
.28682 .52209 L
.2872 .52363 L
.28797 .52738 L
.29026 .54021 L
.29667 .57294 L
.30848 .618 L
.31785 .64542 L
.32817 .67033 L
.35303 .71637 L
.38249 .75654 L
.41426 .79154 L
.50173 .87564 L
.55505 .92295 L
.58354 .94485 L
.5965 .95348 L
.61103 .96188 L
.62335 .96774 L
.63021 .97041 L
.63676 .97254 L
.64421 .97441 L
.65104 .97557 L
.65745 .97613 L
.66446 .97611 L
.67217 .97527 L
.67913 .97369 L
.68298 .97247 L
.68714 .97085 L
.69462 .9671 L
.70159 .96255 L
.70888 .95663 L
.72164 .94294 L
.73695 .91992 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.35119 0.321429 0.64881 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.500021 0.221792 0.5 0.443828 [
[.5 1.0125 -3.5 0 ]
[.5 1.0125 3.5 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -64.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.000 15.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
.82217 .53306 m
.82262 .52689 L
.82295 .52083 L
.82322 .51334 L
.82336 .50582 L
.82339 .49853 L
.82333 .49156 L
.82316 .48367 L
.82285 .47508 L
.82242 .46629 L
.8218 .45671 L
.82031 .43928 L
.81788 .41883 L
.81505 .40092 L
.8116 .38385 L
.80792 .36953 L
.80343 .35582 L
.7982 .34381 L
.79567 .33928 L
.79286 .33508 L
.79033 .33198 L
.78761 .32934 L
.78511 .3275 L
.78235 .32608 L
.77983 .32532 L
.77747 .32506 L
.776 .3251 L
.77444 .32533 L
.77165 .32618 L
.77012 .32688 L
.76868 .32769 L
.76542 .33005 L
.76012 .33548 L
.75463 .34316 L
.74511 .36168 L
.73753 .38167 L
.72479 .42917 L
.7207 .44973 L
.71764 .46702 L
.71667 .47244 L
.71579 .47674 L
.71543 .47814 L
.71524 .47875 L
.71506 .47923 L
.71477 .47983 L
.71445 .48014 L
.71414 .48009 L
.71385 .47973 L
.71358 .47914 L
.71328 .47823 L
Mistroke
.71254 .47516 L
.71175 .47108 L
.70578 .43862 L
.69506 .39393 L
.6787 .3457 L
.66683 .31903 L
.65429 .29561 L
.59667 .21985 L
.52068 .14529 L
.46858 .0973 L
.41535 .05434 L
.38751 .03733 L
.37972 .03358 L
.37138 .03014 L
.36413 .0277 L
.35629 .02567 L
.34893 .0244 L
.34218 .02384 L
.33572 .02386 L
.32894 .02454 L
.32148 .02612 L
.31459 .02843 L
.30706 .03195 L
.29911 .03693 L
.29085 .04362 L
.28336 .05115 L
.26699 .07337 L
.25336 .09925 L
.23998 .13323 L
.22909 .16939 L
.22 .20779 L
.21139 .25451 L
.20389 .30905 L
.19856 .36375 L
.19656 .39207 L
.19561 .40849 L
.19489 .42359 L
.19391 .45035 L
.19333 .47901 L
.1932 .50394 L
.19346 .5297 L
.19419 .55696 L
.1948 .57179 L
.19547 .58497 L
.19709 .6097 L
.19899 .63182 L
.20163 .65589 L
.20445 .67632 L
.20789 .69649 L
.21198 .71558 L
Mistroke
.21552 .72892 L
.21894 .73949 L
.22256 .74862 L
.22603 .75561 L
.23017 .76194 L
.23239 .76451 L
.23477 .76667 L
.23923 .76909 L
.2433 .76955 L
.24552 .7691 L
.24786 .76812 L
.25202 .76505 L
.25643 .75993 L
.26116 .75222 L
.26511 .74386 L
.26919 .73326 L
.27603 .71012 L
.28242 .68049 L
.28549 .66227 L
.28806 .64402 L
.29182 .60941 L
.29338 .58991 L
.29472 .56815 L
.29527 .55648 L
.29569 .54547 L
.29605 .53322 L
.29631 .51998 L
.29644 .50588 L
.29643 .49243 L
.29631 .48026 L
.29607 .46698 L
.29575 .45536 L
.2953 .44253 L
.29403 .41648 L
.29243 .39229 L
.29057 .36972 L
.28547 .32239 L
.27921 .27881 L
.2639 .20343 L
.25352 .16669 L
.24289 .13731 L
.23029 .11136 L
.22291 .10018 L
.21607 .09234 L
.20976 .08722 L
.20382 .08427 L
.19727 .08316 L
.19359 .08354 L
.19026 .08454 L
.18356 .08847 L
Mistroke
.17982 .09184 L
.17639 .0957 L
.17019 .1047 L
.16379 .11696 L
.15312 .1452 L
.14397 .17923 L
.1351 .22436 L
.12718 .28084 L
.12362 .31482 L
.12087 .34782 L
.11847 .38522 L
.11743 .40652 L
.11667 .42599 L
.11573 .46187 L
.11547 .48206 L
.11539 .50054 L
.11567 .53409 L
.11654 .56862 L
.1178 .59843 L
.11963 .62891 L
.12181 .65602 L
.12414 .67912 L
.12727 .70403 L
.13111 .72824 L
.13512 .7482 L
.13907 .76383 L
.14297 .77603 L
.14725 .78632 L
.15169 .79397 L
.15664 .79927 L
.161 .80129 L
.16566 .80084 L
.17004 .79802 L
.17397 .79349 L
.17637 .78977 L
.17887 .7851 L
.18325 .77488 L
.18776 .76138 L
.19244 .74372 L
.19619 .7263 L
.19989 .70551 L
.20562 .66317 L
.20828 .63649 L
.21032 .61046 L
.21205 .58067 L
.21278 .56357 L
.21329 .54784 L
.21364 .53258 L
.21385 .51843 L
.21394 .50277 L
Mistroke
.21389 .48615 L
.21345 .45803 L
.21301 .44205 L
.21246 .42717 L
.21101 .39769 L
.20919 .37014 L
.20463 .32003 L
.19813 .26942 L
.18934 .22001 L
.18045 .18338 L
.17537 .16688 L
.16977 .15182 L
.16465 .14065 L
.15889 .13085 L
.15354 .12423 L
.14849 .12015 L
.14534 .11865 L
.14192 .11794 L
.13571 .11914 L
.12971 .12345 L
.12427 .13022 L
.11851 .1406 L
.11239 .15563 L
.10633 .17531 L
.10101 .19725 L
.09619 .22183 L
.09144 .25186 L
.08772 .28087 L
.08429 .31398 L
.08171 .34537 L
.07942 .38148 L
.07786 .41526 L
.07688 .44748 L
.07653 .46569 L
.07631 .48561 L
.07628 .50632 L
.07641 .52544 L
.07707 .55912 L
.07833 .59391 L
.07929 .6128 L
.08052 .6326 L
.08326 .66645 L
.08649 .69638 L
.08992 .72102 L
.0936 .74187 L
.09738 .75882 L
.10098 .77155 L
.10507 .7827 L
.10967 .79148 L
.1123 .79489 L
Mistroke
.1147 .79705 L
.11941 .79876 L
.12385 .79738 L
.128 .79349 L
.1323 .78676 L
.13588 .77895 L
.13968 .76831 L
.14359 .75454 L
.14753 .7373 L
.15387 .70037 L
.15717 .67474 L
.1598 .6492 L
.16219 .61943 L
.16321 .60361 L
.16414 .58616 L
.16531 .55631 L
.16595 .52764 L
.16612 .51082 L
.16614 .49302 L
.16576 .46108 L
.16496 .43261 L
.16364 .40252 L
.16196 .37463 L
.16007 .34991 L
.15742 .32177 L
.15405 .29274 L
.14669 .24494 L
.13845 .20699 L
.13336 .18935 L
.12848 .17582 L
.12377 .16561 L
.11849 .15724 L
.11341 .15211 L
.10865 .14984 L
.10572 .14968 L
.10257 .15055 L
.0969 .15497 L
.09147 .1628 L
.08662 .17306 L
.08155 .18749 L
.07628 .20712 L
.07118 .23167 L
.06686 .25801 L
.06307 .28693 L
.05951 .32125 L
.05675 .35597 L
.05474 .38959 L
.05339 .42077 L
.05242 .45573 L
.052 .49243 L
Mistroke
.05214 .52656 L
.05245 .54525 L
.05297 .56532 L
.05362 .58389 L
.05438 .60073 L
.05617 .63122 L
.05858 .66155 L
.06202 .69387 L
.06581 .72047 L
.0696 .74086 L
.07404 .75894 L
.07822 .77137 L
.08218 .77966 L
.08687 .78559 L
.09138 .78761 L
.09555 .78642 L
.09937 .78277 L
.10349 .77603 L
.10774 .76586 L
.1118 .75278 L
.11592 .73562 L
.12255 .69734 L
.12582 .67148 L
.12874 .64179 L
.13078 .61476 L
.13251 .58376 L
.13317 .56789 L
.13372 .5504 L
.13409 .53369 L
.13431 .51814 L
.13436 .48848 L
.13391 .45702 L
.13348 .44084 L
.13286 .42357 L
.13134 .39287 L
.12889 .35758 L
.12606 .3269 L
.11978 .27765 L
.11557 .25323 L
.1113 .23321 L
.10698 .2169 L
.1027 .20403 L
.10025 .198 L
.09755 .1924 L
.09275 .185 L
.08773 .18067 L
.08311 .17969 L
.0778 .18217 L
.07283 .18812 L
.06835 .19673 L
Mistroke
.06434 .20732 L
.06012 .22178 L
.0559 .24026 L
.05199 .26181 L
.04819 .28816 L
.04527 .31329 L
.04253 .34292 L
.04005 .378 L
.03897 .39788 L
.03814 .41675 L
.03707 .45122 L
.03672 .4707 L
.03655 .48842 L
.03666 .52447 L
.03694 .54239 L
.03743 .56179 L
.03872 .59504 L
.0404 .62455 L
.04295 .65685 L
.04577 .68357 L
.04953 .71063 L
.05354 .73217 L
.0573 .74734 L
.06153 .75977 L
.06568 .7679 L
.06952 .77221 L
.07412 .7736 L
.0767 .77264 L
.07907 .77067 L
.08335 .76439 L
.08546 .75996 L
.08773 .75418 L
.09187 .74066 L
.09546 .72537 L
.09912 .70574 L
.1026 .68198 L
.10509 .66082 L
.10741 .63636 L
.10951 .60781 L
.11102 .57978 L
.11202 .55241 L
.11264 .52189 L
.11275 .49275 L
.11245 .46568 L
.11176 .4391 L
.11081 .41538 L
.10934 .38867 L
.10758 .36438 L
.10235 .31324 L
.09911 .29034 L
Mistroke
.09515 .26787 L
.09147 .25115 L
.08726 .23601 L
.08308 .22456 L
.07913 .21668 L
.07669 .21314 L
.07406 .21043 L
.0693 .20837 L
.06666 .20881 L
.06418 .21026 L
.06148 .21302 L
.05861 .21735 L
.05632 .2219 L
.05386 .22792 L
.04909 .24333 L
.04495 .26135 L
.0414 .28117 L
.03804 .30477 L
.03492 .33264 L
.03265 .35845 L
.03061 .38861 L
.02969 .40587 L
.02897 .42259 L
.02831 .44217 L
.02788 .46027 L
.0275 .49323 L
.02753 .51185 L
.0277 .52899 L
.02845 .56196 L
.02965 .59186 L
.03112 .61743 L
.03309 .64336 L
.03567 .66935 L
.03884 .6937 L
.04186 .71171 L
.04546 .72828 L
.04919 .74107 L
.05289 .75002 L
.0563 .7554 L
.06007 .75838 L
.0642 .75828 L
.06627 .75692 L
.06854 .75442 L
.07248 .74753 L
.07606 .73829 L
.07931 .72715 L
.08255 .71313 L
.08776 .68273 L
.0903 .66314 L
.09239 .6435 L
Mistroke
.09433 .6209 L
.09608 .59473 L
.0974 .56721 L
.09793 .55181 L
.0983 .53726 L
.09866 .51095 L
.09861 .48259 L
.09838 .46675 L
.09797 .44964 L
.09744 .43366 L
.09681 .41908 L
.09528 .39225 L
.0932 .36506 L
.09102 .34283 L
.08831 .32059 L
.08256 .28579 L
.07881 .26935 L
.07458 .25533 L
.0708 .24624 L
.06652 .23951 L
.06234 .23635 L
.05836 .23641 L
.05482 .23903 L
.05102 .24461 L
.04701 .25392 L
.04505 .25987 L
.04295 .26737 L
.03938 .28318 L
.03636 .30018 L
.03123 .3398 L
.02891 .36473 L
.02709 .39007 L
.02575 .41453 L
.02481 .43798 L
.02413 .46426 L
.02381 .49257 L
.02393 .52267 L
.02421 .53956 L
.02461 .55511 L
.02517 .57124 L
.0258 .58561 L
.02763 .6165 L
.02962 .64092 L
.03219 .66511 L
.03498 .68539 L
.03782 .7017 L
.04135 .71731 L
.04488 .72877 L
.04697 .7339 L
.04893 .73767 L
Mistroke
.0511 .74077 L
.05342 .74287 L
.05555 .74375 L
.05782 .74359 L
.06189 .74053 L
.06434 .73694 L
.06661 .73238 L
.07073 .72096 L
.07392 .70895 L
.0772 .69319 L
.08013 .6755 L
.08295 .65422 L
.08524 .63246 L
.08701 .61126 L
.08848 .5889 L
.08956 .56691 L
.09043 .54085 L
.09073 .52609 L
.09089 .51266 L
.09088 .48645 L
.0905 .46199 L
.09012 .44822 L
.08959 .4339 L
.08833 .40895 L
.08654 .38336 L
.08408 .35722 L
.08152 .33614 L
.07886 .3186 L
.07564 .30175 L
.07195 .28689 L
.06855 .27673 L
.06525 .26965 L
.06152 .26472 L
.0594 .26328 L
.05745 .26283 L
.05389 .26416 L
.05061 .2679 L
.0471 .27476 L
.04349 .28522 L
.04024 .29808 L
.03737 .31267 L
.03266 .34578 L
.03045 .3673 L
.02841 .39295 L
.02756 .40655 L
.02677 .42155 L
.0257 .44949 L
.02511 .47805 L
.02498 .50536 L
.02522 .52977 L
Mistroke
.02588 .55587 L
.02703 .58328 L
.02789 .59829 L
.02882 .6119 L
.03104 .63763 L
.03393 .66249 L
.03684 .68149 L
.04023 .69831 L
.04333 .7099 L
.04691 .71953 L
.05064 .72592 L
.05416 .72884 L
.05601 .72923 L
.05805 .72876 L
.06017 .7273 L
.06213 .72503 L
.06568 .71866 L
.06882 .71044 L
.07226 .69829 L
.07533 .68429 L
.07786 .66998 L
.08031 .65301 L
.08403 .6187 L
.08583 .59575 L
.08716 .57313 L
.08805 .55221 L
.08867 .52919 L
.08895 .50388 L
.08882 .48035 L
.08859 .46698 L
.08827 .45493 L
.08778 .44125 L
.08721 .42855 L
.08572 .40411 L
.08397 .38288 L
.08166 .36143 L
.07882 .34113 L
.07631 .32715 L
.0734 .31432 L
.07047 .30447 L
.06768 .2975 L
.06448 .29217 L
.06263 .29031 L
.06091 .28935 L
.05741 .28968 L
.05546 .2912 L
.05371 .29342 L
.05061 .29942 L
.04781 .30731 L
.04489 .31843 L
Mistroke
.04196 .33308 L
.03919 .35123 L
.03688 .37083 L
.03509 .39018 L
.03348 .41283 L
.03241 .43341 L
.03156 .45703 L
.03107 .48233 L
.03098 .50637 L
.03123 .52867 L
.03173 .54887 L
.03258 .57051 L
.03381 .59244 L
.03553 .61526 L
.03741 .63451 L
.03993 .65462 L
.04261 .6713 L
.04531 .68452 L
.04797 .69473 L
.05104 .70362 L
.05442 .71032 L
.0579 .71419 L
.05988 .71511 L
.06169 .71517 L
.06519 .71316 L
.06846 .70873 L
.07027 .7052 L
.07215 .70065 L
.07542 .69049 L
.07905 .67532 L
.08206 .65896 L
.08631 .62748 L
.08828 .60752 L
.08982 .58783 L
.09109 .5662 L
.09194 .54595 L
.09227 .53461 L
.09253 .52222 L
.09271 .49968 L
.09257 .48065 L
.09211 .46002 L
.09129 .43914 L
.09023 .42037 L
.08898 .4038 L
.08764 .3895 L
.08398 .36102 L
.08173 .34838 L
.07913 .33694 L
.07653 .32823 L
.07405 .32218 L
Mistroke
.07105 .31743 L
.06933 .31591 L
.06773 .31527 L
.0648 .31599 L
.06333 .3173 L
.06173 .31946 L
.0601 .32247 L
.05859 .32607 L
.05585 .3347 L
.05307 .34664 L
.05031 .36259 L
.04818 .37876 L
.04621 .39805 L
.04469 .41793 L
.0436 .4371 L
.04279 .45761 L
.04232 .47731 L
.04214 .49931 L
.04232 .52296 L
.04257 .53479 L
.04295 .54751 L
.04393 .57011 L
.04524 .59119 L
.04675 .60961 L
.05014 .6396 L
.05241 .65444 L
.05474 .6667 L
.05718 .67708 L
.05989 .68612 L
.063 .69374 L
.06595 .69857 L
.06928 .70151 L
.07233 .70195 L
.07402 .70131 L
.07584 .6999 L
.0791 .6955 L
.08207 .68931 L
.08509 .68069 L
.08755 .67176 L
.09009 .6604 L
.09512 .62963 L
.09744 .60978 L
.0992 .59043 L
.10054 .57161 L
.10111 .56145 L
.10163 .55051 L
.102 .5409 L
.10231 .53024 L
.10264 .51141 L
.10267 .49296 L
Mistroke
.10245 .47607 L
.10193 .45803 L
.10151 .44823 L
.10106 .43953 L
.09994 .4227 L
.09843 .40575 L
.09674 .39119 L
.09498 .37917 L
.09334 .37006 L
.09144 .36157 L
.08924 .3539 L
.08709 .34834 L
.08459 .34407 L
.08217 .34199 L
.07998 .34179 L
.07761 .34338 L
.07626 .34515 L
.07482 .34775 L
.07349 .35087 L
.0723 .35428 L
.07011 .36218 L
.06795 .37247 L
.06583 .38563 L
.06408 .39971 L
.06243 .41692 L
.06165 .4272 L
.06103 .43711 L
.06014 .45555 L
.0598 .46562 L
.05953 .47651 L
.05932 .49512 L
.05932 .50583 L
.05941 .51591 L
.05979 .53455 L
.0604 .55142 L
.06133 .5695 L
.0626 .5878 L
.06412 .60467 L
.06605 .62168 L
.06798 .63541 L
.07024 .64848 L
.07245 .65888 L
.07503 .66868 L
.0775 .67603 L
.0799 .68152 L
.08299 .68647 L
.08599 .68915 L
.0887 .6899 L
.09165 .68896 L
.09332 .68762 L
Mistroke
.09482 .68591 L
.09653 .68336 L
.09812 .68043 L
.10087 .67394 L
.10372 .66522 L
.10815 .64687 L
.11233 .6223 L
.11414 .60847 L
.11582 .59283 L
.11706 .57875 L
.11818 .56303 L
.11904 .54705 L
.11961 .53218 L
.11996 .51796 L
.12011 .50301 L
.12006 .48985 L
.11986 .47779 L
.11948 .46494 L
.11887 .45165 L
.11793 .43699 L
.11687 .42463 L
.11542 .41161 L
.11385 .40072 L
.11236 .39247 L
.11066 .38502 L
.10867 .37844 L
.10676 .37393 L
.10463 .37078 L
.10342 .36982 L
.1023 .36945 L
.10014 .37013 L
.09812 .37248 L
.097 .37453 L
.09583 .37728 L
.09381 .38365 L
.09177 .39248 L
.08973 .40448 L
.08828 .41568 L
.08696 .42884 L
.08602 .44106 L
.08519 .45531 L
.08483 .46373 L
.08457 .47157 L
.08434 .48081 L
.08421 .48969 L
.08417 .50576 L
.08427 .51492 L
.08442 .52339 L
.08488 .53858 L
.08551 .55265 L
Mistroke
.08643 .56778 L
.08766 .58349 L
.08922 .59914 L
.09094 .61309 L
.09474 .63632 L
.09699 .64671 L
.09959 .65643 L
.10202 .66365 L
.10468 .66982 L
.10716 .67409 L
.10995 .67733 L
.11251 .67896 L
.11492 .67936 L
.11637 .67908 L
.11794 .67834 L
.12078 .67586 L
.12349 .67208 L
.12593 .66745 L
.12848 .66128 L
.13118 .65318 L
.13615 .63305 L
.13988 .61204 L
.1427 .59073 L
.14509 .56584 L
.146 .553 L
.14677 .53888 L
.14726 .52638 L
.14754 .51515 L
.14767 .50241 L
.14762 .49071 L
.14742 .48022 L
.14712 .47091 L
.14665 .46115 L
.14601 .45142 L
.14518 .44184 L
.14413 .43237 L
.14299 .42441 L
.14182 .41798 L
.14061 .41261 L
.1394 .40842 L
.13809 .40497 L
.13659 .40227 L
.13504 .40075 L
.13338 .4005 L
.13198 .40139 L
.13046 .40353 L
.12887 .40718 L
.12801 .40983 L
.12725 .4126 L
.12593 .41856 L
Mistroke
.12464 .42608 L
.12364 .43342 L
.12266 .44242 L
.1219 .45135 L
.12131 .46031 L
.12078 .47149 L
.12045 .48224 L
.12026 .49514 L
.12028 .50778 L
.12046 .5189 L
.12082 .53086 L
.12132 .54215 L
.12191 .55234 L
.12276 .56421 L
.12387 .57675 L
.12639 .59836 L
.12968 .61897 L
.13384 .63791 L
.13607 .64573 L
.13828 .65225 L
.14267 .66204 L
.1453 .66618 L
.14677 .66798 L
.14816 .66936 L
.15063 .67109 L
.15338 .67194 L
.15484 .67195 L
.15637 .67164 L
.15909 .67027 L
.16059 .66906 L
.16199 .66767 L
.16509 .66355 L
.16779 .65881 L
.17062 .65261 L
.17544 .63885 L
.17964 .62284 L
.18304 .60631 L
.18614 .58708 L
.18882 .56504 L
.18987 .55383 L
.19078 .54187 L
.19143 .53076 L
.19186 .52084 L
.19212 .51121 L
.19223 .50248 L
.19221 .49497 L
.19207 .48726 L
.1918 .47934 L
.19161 .47558 L
.19137 .47164 L
Mistroke
.19086 .46516 L
.1903 .45973 L
.18965 .45486 L
.18898 .45087 L
.18833 .44781 L
.18758 .44506 L
.18673 .44276 L
.18579 .44114 L
.18498 .44043 L
.18407 .44036 L
.18357 .44065 L
.18303 .44123 L
.18206 .44299 L
.18116 .44556 L
.18036 .4487 L
.17948 .45332 L
.17876 .45832 L
.17804 .465 L
.17748 .47212 L
.1771 .47898 L
.17682 .4868 L
.17669 .49388 L
.17665 .50205 L
.17676 .51122 L
.17689 .51651 L
.17705 .52142 L
.17748 .53112 L
.17804 .54047 L
.17953 .55866 L
.18143 .57561 L
.18405 .5936 L
.18748 .6118 L
.19146 .62813 L
.1962 .64306 L
.20062 .65369 L
.20324 .65876 L
.20579 .66292 L
.20822 .66623 L
.2109 .66922 L
.21337 .67138 L
.21568 .67291 L
.21819 .67408 L
.22098 .67478 L
.22389 .67487 L
.22661 .67439 L
.22915 .67346 L
.23154 .67216 L
.23367 .67066 L
.23598 .6687 L
.24101 .66311 L
Mistroke
.24552 .65662 L
.25507 .63794 L
.26389 .61404 L
.27549 .56963 L
.28182 .53618 L
.28366 .52597 L
.2843 .52302 L
.28461 .52185 L
.28492 .5209 L
.28524 .52022 L
.28553 .5199 L
.2858 .51988 L
.28609 .52017 L
.28641 .5208 L
.28677 .52187 L
.28747 .5248 L
.2923 .55138 L
.29649 .57206 L
.30254 .59719 L
.3181 .64604 L
.33867 .69167 L
.36648 .73603 L
.43008 .80743 L
.51831 .89085 L
.57364 .93761 L
.60378 .95785 L
.62145 .96689 L
.62947 .97012 L
.63825 .97295 L
.64233 .97398 L
.64668 .97488 L
.65452 .97592 L
.65871 .97616 L
.66265 .97617 L
.67 .97558 L
.67726 .97419 L
.6839 .97214 L
.69115 .96898 L
.69873 .96455 L
.70629 .95888 L
.71427 .9514 L
.72826 .934 L
.74405 .90632 L
.7574 .8743 L
.76858 .83926 L
.77785 .80228 L
.78673 .75704 L
.79449 .70457 L
.79976 .65623 L
.80338 .6094 L
Mistroke
.80488 .58225 L
.80588 .55738 L
.80659 .52883 L
.80684 .50201 L
.80666 .47549 L
.80637 .46084 L
.806 .44758 L
.80503 .42381 L
.80362 .39971 L
.80204 .37909 L
.8003 .3608 L
.79549 .32304 L
.79235 .30459 L
.7891 .28888 L
.7824 .26433 L
.77837 .25347 L
.77448 .24529 L
.77009 .23838 L
.76784 .23571 L
.76532 .2334 L
.76137 .23113 L
.75719 .23046 L
.75362 .23124 L
.74973 .23351 L
.74559 .23757 L
.74124 .24368 L
.73725 .25106 L
.73373 .25908 L
.72725 .27804 L
.72089 .30321 L
.71565 .3309 L
.71156 .35941 L
.70946 .37785 L
.70775 .39613 L
.70644 .41332 L
.70531 .43218 L
.7044 .45319 L
.70386 .47313 L
.70367 .48555 L
.7036 .49735 L
.70374 .51966 L
.70415 .53971 L
.7049 .56105 L
.70579 .57936 L
.70703 .59948 L
.71081 .64426 L
.71558 .68537 L
.7227 .73223 L
.73088 .77407 L
.73944 .80917 L
Mistroke
.74958 .8425 L
.7617 .87306 L
.77372 .89497 L
.78065 .90413 L
.78728 .91057 L
.79112 .91328 L
.79466 .9151 L
.79855 .91635 L
.80265 .91681 L
.80922 .91564 L
.81291 .91392 L
.81629 .91165 L
.82244 .90572 L
.82883 .89692 L
.83443 .88683 L
.83951 .87549 L
.85042 .84296 L
.85601 .821 L
.86094 .79775 L
.86912 .74829 L
.87302 .71772 L
.87616 .68785 L
.87904 .65388 L
.8815 .61597 L
.88295 .58517 L
.8839 .55664 L
.88444 .52933 L
.88464 .50069 L
.88442 .46965 L
.88381 .44136 L
.8827 .41126 L
.88103 .38045 L
.87895 .35224 L
.87621 .32374 L
.87341 .30066 L
.87009 .27849 L
.86682 .26067 L
.86293 .24353 L
.85943 .23104 L
.85553 .21994 L
.85084 .21 L
.84638 .20355 L
.8436 .20091 L
.84096 .19934 L
.83602 .19873 L
.83129 .20094 L
.82699 .20531 L
.82236 .2126 L
.81763 .22299 L
.81381 .23372 L
Mistroke
.8099 .24715 L
.80341 .27604 L
.79986 .29635 L
.79682 .31725 L
.79206 .36021 L
.79011 .38411 L
.78839 .41157 L
.7877 .42574 L
.7871 .44124 L
.78636 .46981 L
.78611 .49722 L
.7863 .52638 L
.78684 .55139 L
.78784 .5787 L
.78865 .59534 L
.78956 .61095 L
.79163 .63979 L
.79438 .67013 L
.79797 .70187 L
.80591 .75507 L
.81477 .79808 L
.82461 .83288 L
.83443 .85739 L
.84012 .86757 L
.84318 .87191 L
.84648 .87571 L
.85259 .8804 L
.8583 .88204 L
.86403 .88096 L
.87017 .87666 L
.87589 .86957 L
.88102 .86043 L
.88555 .85 L
.89034 .83623 L
.89933 .80132 L
.90443 .7748 L
.90879 .74675 L
.9156 .68751 L
.91857 .65126 L
.92074 .61634 L
.92164 .5977 L
.92245 .57692 L
.9231 .55506 L
.9235 .5345 L
.92377 .49774 L
.92346 .46324 L
.92274 .433 L
.92147 .40109 L
.91957 .36825 L
.91697 .3356 L
Mistroke
.914 .30742 L
.91093 .28435 L
.90772 .26487 L
.90398 .2467 L
.89959 .23016 L
.89527 .21804 L
.89287 .21288 L
.89022 .20833 L
.88531 .20296 L
.88047 .20127 L
.876 .20278 L
.87188 .20674 L
.86808 .21264 L
.86402 .22145 L
.85979 .23354 L
.85581 .24805 L
.85188 .26585 L
.84564 .30343 L
.84258 .32791 L
.84016 .35174 L
.83783 .38086 L
.83611 .40968 L
.83495 .43727 L
.83425 .46331 L
.83391 .49235 L
.83404 .52339 L
.83468 .55464 L
.83526 .57211 L
.83593 .58797 L
.83762 .61833 L
.83967 .64645 L
.84579 .70565 L
.85013 .73615 L
.85467 .76201 L
.85914 .78303 L
.86422 .80256 L
.86886 .81704 L
.87405 .82986 L
.87705 .83579 L
.87984 .84035 L
.88537 .84685 L
.88851 .84905 L
.89193 .85023 L
.89517 .85017 L
.89816 .84908 L
.9034 .84472 L
.90823 .83777 L
.91339 .82697 L
.91874 .81168 L
.92376 .79285 L
Mistroke
.92867 .7693 L
.93287 .744 L
.93631 .71857 L
.94176 .66438 L
.94407 .6321 L
.94578 .60046 L
.94694 .57042 L
.94765 .54239 L
.94802 .51151 L
.94795 .47905 L
.94741 .4469 L
.94631 .41345 L
.94479 .38325 L
.94303 .35715 L
.94053 .32868 L
.93731 .30063 L
.93385 .27729 L
.93033 .25865 L
.92662 .24326 L
.92247 .23033 L
.9188 .22204 L
.91466 .21589 L
.91012 .21269 L
.90757 .21245 L
.90525 .21317 L
.90076 .21713 L
.89661 .22388 L
.89283 .23272 L
.88898 .24463 L
.88257 .27203 L
.87936 .2903 L
.8766 .30917 L
.87369 .33342 L
.87136 .3576 L
.86928 .38503 L
.86829 .40133 L
.86753 .41643 L
.86645 .44508 L
.8658 .47633 L
.86566 .50481 L
.86599 .53572 L
.86675 .56474 L
.86784 .59108 L
.86957 .62098 L
.87161 .64796 L
.87432 .67624 L
.87772 .70466 L
.88182 .73196 L
.88614 .75506 L
.89037 .77332 L
Mistroke
.89523 .78998 L
.89989 .8022 L
.90431 .81076 L
.90863 .81646 L
.91325 .81973 L
.91835 .82 L
.92308 .81705 L
.92819 .81024 L
.93099 .80479 L
.93349 .79884 L
.93838 .78389 L
.94264 .76678 L
.94698 .74453 L
.95113 .71731 L
.95411 .69276 L
.95691 .66423 L
.95944 .63074 L
.96127 .59782 L
.96254 .56477 L
.96325 .5336 L
.96351 .49927 L
.96342 .4802 L
.9632 .46309 L
.96242 .43223 L
.96108 .40013 L
.95936 .37142 L
.95741 .34669 L
.95287 .30543 L
.94986 .28542 L
.94679 .26922 L
.94334 .25479 L
.94002 .24417 L
.93604 .23497 L
.93217 .22931 L
.92821 .22662 L
.92392 .22706 L
.9199 .2306 L
.91629 .23641 L
.91239 .24563 L
.90831 .25884 L
.90432 .2759 L
.90089 .2945 L
.89757 .31704 L
.89482 .34049 L
.89265 .36342 L
.89074 .38907 L
.8899 .4029 L
.88911 .4184 L
.88806 .44635 L
.88766 .46237 L
Mistroke
.88739 .47973 L
.88728 .4962 L
.88731 .51126 L
.88767 .53827 L
.88848 .5667 L
.88952 .59052 L
.89102 .61615 L
.89304 .64253 L
.89566 .66945 L
.89828 .6912 L
.90149 .71311 L
.90818 .74718 L
.91221 .76211 L
.91615 .77345 L
.91999 .7817 L
.92357 .7871 L
.92776 .79074 L
.93176 .79157 L
.93601 .78959 L
.94053 .78414 L
.94469 .77585 L
.94837 .76563 L
.95247 .75057 L
.95664 .73051 L
.96023 .70831 L
.96322 .68515 L
.96615 .6564 L
.96843 .62719 L
.97008 .59954 L
.97139 .56853 L
.97188 .55204 L
.97227 .5338 L
.97249 .51466 L
.97254 .49682 L
.97225 .46514 L
.97138 .43201 L
.97008 .40214 L
.96847 .37595 L
.96627 .34917 L
.9635 .32336 L
.96077 .30349 L
.95795 .28714 L
.95462 .27191 L
.95081 .25884 L
.94747 .25065 L
.94372 .2446 L
.93973 .24155 L
.936 .24168 L
.93251 .24436 L
.92939 .24888 L
Mistroke
.92587 .25649 L
.92267 .26591 L
.91932 .2786 L
.91595 .29478 L
.91058 .32996 L
.90784 .35467 L
.90565 .37996 L
.90404 .40393 L
.90271 .43111 L
.90217 .44649 L
.90178 .46113 L
.90139 .48875 L
.90136 .50434 L
.90145 .51865 L
.90168 .53429 L
.90208 .55067 L
.90308 .57751 L
.90438 .60179 L
.9062 .62737 L
.9086 .65316 L
.91387 .69399 L
.91736 .71361 L
.92086 .72918 L
.9241 .74062 L
.92784 .75072 L
.93189 .75832 L
.93576 .76257 L
.93956 .76397 L
.94318 .76276 L
.9464 .75954 L
.94985 .75373 L
.95348 .74478 L
.95718 .73224 L
.96048 .7177 L
.96327 .70236 L
.96867 .66157 L
.97116 .63491 L
.97306 .60816 L
.9746 .57842 L
.97558 .55034 L
.97593 .53456 L
.97616 .51729 L
.97619 .48585 L
.97581 .45938 L
.97495 .43086 L
.9736 .40228 L
.97192 .37694 L
.97002 .35495 L
.96802 .33634 L
.96536 .31653 L
Mistroke
.96269 .30073 L
.9595 .28587 L
.95586 .27322 L
.95233 .26458 L
.94889 .2592 L
.94481 .25634 L
.94103 .25696 L
.93907 .25849 L
.93692 .26113 L
.93471 .26492 L
.93268 .2694 L
.92873 .28103 L
.9252 .29514 L
.92224 .31013 L
.9193 .32875 L
.91647 .3513 L
.91391 .37763 L
.91197 .40425 L
.91063 .42951 L
.90974 .45433 L
.90926 .47787 L
.90911 .50387 L
.90941 .53159 L
.90974 .54538 L
.91022 .56017 L
.91145 .58638 L
.91305 .61079 L
.91488 .63211 L
.91894 .66685 L
.92165 .68407 L
.92441 .69831 L
.92732 .71032 L
.93054 .7207 L
.93422 .72929 L
.9377 .73444 L
.94163 .73703 L
.94521 .73645 L
.94718 .73491 L
.9493 .73228 L
.95306 .72492 L
.95646 .71505 L
.95987 .7016 L
.96258 .68779 L
.96533 .6703 L
.96819 .64687 L
.97042 .62315 L
.97147 .60922 L
.97248 .59349 L
.97322 .57947 L
.9739 .56362 L
Mistroke
.97472 .53473 L
.97497 .51864 L
.97507 .50347 L
.97491 .47645 L
.97428 .44776 L
.97323 .42124 L
.97192 .39817 L
.97001 .37318 L
.96783 .35148 L
.96318 .31841 L
.96017 .30328 L
.95721 .29177 L
.95382 .28206 L
.95053 .27566 L
.94683 .27169 L
.94474 .27085 L
.94282 .27096 L
.93899 .27363 L
.93686 .27658 L
.9349 .2802 L
.93142 .289 L
.92789 .30128 L
.92443 .31722 L
.92152 .33433 L
.91867 .35549 L
.91611 .38014 L
.91429 .40317 L
.91294 .42568 L
.91233 .43894 L
.91188 .45119 L
.91148 .46547 L
.91124 .47908 L
.91109 .50246 L
.91134 .52713 L
.91186 .54783 L
.91277 .57005 L
.91411 .59288 L
.91597 .61602 L
.91809 .63617 L
.92032 .65296 L
.92294 .66873 L
.92563 .68157 L
.9282 .69126 L
.93112 .69967 L
.93443 .70623 L
.93614 .70848 L
.93803 .7101 L
.94139 .71077 L
.94453 .70883 L
.94763 .70437 L
Mistroke
.9505 .69784 L
.95298 .69011 L
.95556 .67975 L
.95818 .66633 L
.96072 .64971 L
.96271 .63337 L
.96455 .61452 L
.96638 .58994 L
.96766 .5659 L
.9682 .55204 L
.96859 .53889 L
.96888 .52427 L
.96905 .50849 L
.96906 .4948 L
.96894 .47997 L
.9687 .46604 L
.96837 .45331 L
.96747 .42973 L
.96611 .40576 L
.96457 .38539 L
.96258 .36502 L
.95821 .33314 L
.95514 .3173 L
.95198 .305 L
.94899 .29639 L
.9456 .28967 L
.94387 .28738 L
.94202 .28574 L
.93868 .28481 L
.93509 .28664 L
.93307 .28896 L
.93121 .29194 L
.92793 .29927 L
.92505 .30803 L
.92191 .32044 L
.91914 .33428 L
.91686 .34822 L
.91467 .36448 L
.91139 .39676 L
.90997 .41602 L
.90891 .43475 L
.90805 .4558 L
.90771 .46778 L
.9075 .47882 L
.90733 .50004 L
.90752 .5225 L
.90804 .54326 L
.90878 .56155 L
.90999 .58213 L
.91167 .60303 L
Mistroke
.9136 .62112 L
.91563 .63617 L
.91781 .64902 L
.92035 .66083 L
.92189 .66662 L
.92334 .67124 L
.92475 .67502 L
.92629 .67839 L
.9279 .68113 L
.92941 .683 L
.93123 .68436 L
.93288 .68477 L
.93444 .68443 L
.93613 .68327 L
.93915 .67908 L
.94193 .6726 L
.94437 .66463 L
.94702 .6531 L
.94933 .63999 L
.95287 .61199 L
.9545 .59385 L
.95574 .57586 L
.95678 .55532 L
.95745 .53527 L
.95784 .5127 L
.9579 .49986 L
.95785 .48808 L
.95748 .46576 L
.95712 .45327 L
.95668 .44182 L
.9555 .41929 L
.95383 .39652 L
.95177 .37549 L
.94955 .3579 L
.94679 .34086 L
.94356 .32568 L
.94054 .31507 L
.93758 .3074 L
.93583 .30402 L
.93421 .30159 L
.93231 .29955 L
.93051 .29839 L
.9274 .29813 L
.92412 .3002 L
.92136 .30382 L
.91838 .30974 L
.91531 .31819 L
.91217 .32958 L
.9094 .34239 L
.90708 .35557 L
Mistroke
.90313 .38529 L
.90137 .40329 L
.89998 .42113 L
.89895 .43816 L
.89823 .45419 L
.89768 .47198 L
.89739 .49086 L
.89739 .50965 L
.89752 .52005 L
.89772 .52945 L
.89833 .54721 L
.89915 .5634 L
.9004 .58109 L
.90183 .59632 L
.90366 .61147 L
.90589 .62561 L
.90827 .63708 L
.91063 .64558 L
.91192 .6492 L
.91336 .65249 L
.9149 .65516 L
.91636 .65692 L
.91775 .65794 L
.91908 .6583 L
.92156 .65741 L
.92294 .65601 L
.9242 .65415 L
.92556 .65149 L
.92698 .64795 L
.92916 .64086 L
.93137 .63127 L
.9333 .62045 L
.93491 .60915 L
.9365 .59518 L
.93798 .57837 L
.93862 .56936 L
.93921 .55938 L
.94004 .54064 L
.94053 .52216 L
.94068 .51144 L
.94073 .50132 L
.94058 .4808 L
.94035 .46929 L
.94004 .45884 L
.93926 .44053 L
.93811 .4212 L
.93672 .40377 L
.9352 .38852 L
.93297 .37076 L
.93059 .3558 L
Mistroke
.92821 .34384 L
.92551 .33307 L
.92238 .32357 L
.91936 .31703 L
.91764 .31432 L
.91602 .3124 L
.91422 .31096 L
.91228 .3102 L
.9107 .31016 L
.90902 .3107 L
.90603 .31312 L
.90439 .31525 L
.90288 .31775 L
.89951 .32516 L
.89671 .33346 L
.89428 .34246 L
.89162 .35451 L
.88935 .36704 L
.88591 .39153 L
.88438 .40556 L
.88299 .42115 L
.8818 .43808 L
.88094 .45435 L
.88039 .46908 L
.88004 .485 L
.87993 .50102 L
.88005 .51534 L
.88044 .53138 L
.88104 .54595 L
.8818 .55871 L
.88267 .56986 L
.88378 .58124 L
.88514 .59227 L
.88666 .60206 L
.88846 .61114 L
.89029 .61822 L
.89205 .62335 L
.89409 .62747 L
.89526 .62905 L
.89637 .63002 L
.89755 .63051 L
.89862 .63048 L
.89986 .62989 L
.90102 .62877 L
.90298 .62558 L
.90407 .62306 L
.90507 .62025 L
.90701 .61328 L
.90895 .60392 L
.91058 .59362 L
Mistroke
.91196 .5825 L
.91305 .57151 L
.91405 .55856 L
.91456 .55014 L
.91497 .54194 L
.91554 .52602 L
.91574 .51681 L
.91585 .5082 L
.91588 .49863 L
.91582 .48844 L
.91548 .4714 L
.91492 .45558 L
.91449 .4466 L
.91402 .43851 L
.91274 .42079 L
.91005 .39425 L
.90818 .38048 L
.90623 .36862 L
.90178 .34829 L
.89903 .33917 L
.89638 .33236 L
.89399 .32766 L
.89171 .32437 L
.88917 .32195 L
.88642 .32074 L
.88353 .32098 L
.88082 .32261 L
.87841 .3252 L
.87584 .32915 L
.87308 .33488 L
.87059 .34144 L
.86777 .35063 L
.86536 .36023 L
.86097 .38287 L
.8589 .39678 L
.85718 .41069 L
.85592 .42302 L
.85478 .43643 L
.85397 .44819 L
.85328 .46094 L
.85295 .46877 L
.85272 .47594 L
.85243 .48984 L
.85237 .5022 L
.85251 .51483 L
.85283 .52657 L
.85309 .53295 L
.85338 .53866 L
.85404 .54864 L
.85489 .55844 L
Mistroke
.8567 .57328 L
.8579 .58039 L
.85912 .58611 L
.8606 .59145 L
.86209 .59531 L
.86346 .59774 L
.865 .59924 L
.86587 .59955 L
.86667 .59949 L
.86759 .59901 L
.86845 .59817 L
.86996 .59573 L
.87153 .59175 L
.87284 .58719 L
.87399 .58205 L
.87526 .57486 L
.87631 .56734 L
.87722 .55916 L
.87808 .54941 L
.87881 .53825 L
.87932 .52697 L
.87961 .5169 L
.87978 .50538 L
.87977 .493 L
.87958 .48115 L
.87925 .47002 L
.87882 .45979 L
.87819 .44861 L
.87737 .43698 L
.87629 .42451 L
.87489 .41143 L
.87181 .38932 L
.86819 .37037 L
.86439 .35564 L
.85986 .34305 L
.85714 .33755 L
.85451 .33353 L
.85169 .33048 L
.84907 .32876 L
.84762 .32824 L
.84603 .32803 L
.84453 .32816 L
.84314 .32856 L
.84063 .32998 L
.83795 .33246 L
.83546 .33569 L
.83322 .33937 L
.82913 .34812 L
.82509 .35958 L
.82112 .3741 L
Mistroke
.81784 .38928 L
.81474 .40725 L
.81205 .42747 L
.81001 .44811 L
.80924 .45846 L
.80859 .4697 L
.80819 .47904 L
.80792 .4888 L
.80782 .49767 L
.80784 .50543 L
.8079 .5097 L
.80801 .51411 L
.80829 .52165 L
.80852 .52598 L
.80878 .52987 L
.80934 .53657 L
.81006 .54282 L
.81082 .54777 L
.81173 .55225 L
.81226 .55426 L
.81278 .55588 L
.81368 .55797 L
.81453 .55917 L
.81546 .55968 L
.81599 .55962 L
.81648 .55933 L
.81728 .55837 L
.81814 .55661 L
.81901 .55401 L
.81978 .55086 L
.82058 .54658 L
.82134 .54123 L
.82191 .53601 L
.82244 .52965 L
.82289 .52208 L
.82308 .51755 L
.82322 .51326 L
.82331 .50912 L
.82337 .50449 L
.82337 .49574 L
.82324 .48702 L
.823 .4788 L
.82257 .46908 L
.82201 .4597 L
.82066 .44288 L
.81865 .42467 L
.81582 .4054 L
.81213 .38625 L
.80805 .37001 L
.80392 .35717 L
Mistroke
.79878 .345 L
.79372 .33631 L
.79097 .33275 L
.78789 .32963 L
.78632 .32837 L
.78463 .32725 L
.78302 .32641 L
.78155 .32583 L
.77865 .32518 L
.77597 .32515 L
.77457 .32535 L
.77303 .32574 L
.77143 .32632 L
.76993 .32703 L
.7672 .32873 L
.76472 .33071 L
.75927 .33659 L
.75422 .34389 L
.74985 .35168 L
.74093 .37214 L
.73392 .39318 L
.72847 .4133 L
.72006 .45332 L
.71737 .46868 L
.71639 .47397 L
.71602 .47578 L
.71564 .47741 L
.7153 .47861 L
.71499 .47942 L
.71471 .47991 L
.71442 .48013 L
.71426 .48011 L
.71408 .47999 L
.71376 .47949 L
.71343 .47865 L
.71312 .47757 L
.71238 .47427 L
.71142 .46918 L
.70885 .45463 L
.70127 .4179 L
.68953 .37562 L
.67008 .32581 L
.64688 .28346 L
.61658 .24231 L
.57795 .20053 L
.49435 .12072 L
.44154 .07426 L
.40985 .05063 L
.39364 .04065 L
.37828 .03297 L
Mistroke
.37076 .02995 L
.36363 .02758 L
.35967 .02649 L
.35537 .02551 L
.34785 .02431 L
.34381 .02395 L
.33938 .02381 L
.33474 .02395 L
.33041 .02437 L
.32268 .02584 L
.31836 .02709 L
.31443 .02852 L
.30703 .032 L
.30023 .03618 L
.293 .04176 L
.28512 .04929 L
.27222 .06537 L
.2591 .08745 L
.2466 .11522 L
.23597 .14554 L
.22539 .184 L
.21564 .22994 L
.20844 .27399 L
.20292 .31766 L
.19826 .36772 L
.1963 .39634 L
.19494 .42253 L
.19396 .44883 L
.19341 .47331 L
.1932 .49984 L
.19344 .5278 L
.19373 .5415 L
.19417 .55619 L
.19532 .58215 L
.19685 .60631 L
.1986 .6276 L
.20071 .6481 L
.20298 .66615 L
.20787 .69636 L
.21397 .72337 L
.21773 .73593 L
.22134 .74573 L
.22517 .754 L
.2294 .76089 L
.23348 .76555 L
.23725 .76824 L
.24171 .76953 L
.24423 .76939 L
.24656 .7687 L
.25081 .76609 L
Mistroke
.25293 .76412 L
.25525 .76145 L
.2598 .75464 L
.26385 .74669 L
.26804 .73642 L
.27241 .72325 L
.27915 .69679 L
.28524 .6638 L
.28997 .62791 L
.2921 .60608 L
.29371 .58509 L
.29482 .56609 L
.29571 .54462 L
.29603 .53359 L
.29627 .52162 L
.29644 .49968 L
.29627 .47814 L
.29571 .45439 L
.29482 .43177 L
.29367 .41072 L
.29067 .37094 L
.28629 .32907 L
.27951 .28078 L
.27037 .23153 L
.26011 .18903 L
.24945 .1546 L
.23889 .12813 L
.22652 .10532 L
.22003 .09661 L
.2164 .0927 L
.21295 .08958 L
.20617 .08525 L
.19996 .08337 L
.19388 .08352 L
.18736 .08595 L
.18125 .09048 L
.17574 .09656 L
.16942 .10605 L
.16272 .11937 L
.15121 .15152 L
.14539 .17326 L
.14047 .19539 L
.13556 .22165 L
.13078 .25266 L
.12687 .28361 L
.12374 .31366 L
.12121 .34334 L
.11899 .37614 L
.1174 .40732 L
.11635 .43608 L
Mistroke
.11568 .46509 L
.11541 .49246 L
.11554 .52393 L
.11606 .55247 L
.11708 .5829 L
.11866 .61391 L
.12047 .64006 L
.12282 .66656 L
.12805 .70941 L
.13159 .73086 L
.13567 .75055 L
.13973 .76607 L
.14368 .77792 L
.14813 .78803 L
.15053 .79222 L
.1531 .79579 L
.15748 .79981 L
.16235 .8014 L
.16668 .80036 L
.1713 .79674 L
.1756 .79102 L
.17943 .78391 L
.18403 .77273 L
.18812 .76014 L
.1927 .74257 L
.19655 .7244 L
.20284 .68561 L
.20575 .66188 L
.20813 .63818 L
.20999 .61503 L
.21142 .59265 L
.21258 .56862 L
.21344 .54161 L
.21385 .51782 L
.21393 .4959 L
.21369 .4704 L
.21313 .44619 L
.21215 .41997 L
.21069 .39235 L
.2091 .36905 L
.207 .34379 L
.20102 .28991 L
.19387 .24348 L
.18524 .20181 L
.17615 .16929 L
.17053 .15373 L
.16522 .14182 L
.1622 .13618 L
.15889 .13088 L
.15277 .12352 L
Mistroke
.14675 .11925 L
.14331 .11814 L
.14009 .11799 L
.13669 .11877 L
.1336 .12033 L
.13006 .12315 L
.12672 .12686 L
.12093 .13585 L
.11571 .14697 L
.11019 .16223 L
.10462 .18188 L
.09631 .22119 L
.09216 .24693 L
.08871 .2726 L
.08338 .32431 L
.08123 .35209 L
.07931 .38353 L
.07771 .41947 L
.07677 .45262 L
.07646 .47104 L
.07629 .49098 L
.07644 .52687 L
.07709 .55977 L
.07831 .59348 L
.07977 .62102 L
.08181 .64974 L
.08451 .67892 L
.08742 .70361 L
.09103 .72778 L
.09529 .74991 L
.09969 .7673 L
.10407 .78024 L
.10816 .78897 L
.1127 .79528 L
.11694 .79824 L
.12161 .7984 L
.12646 .79519 L
.13092 .78919 L
.13499 .78104 L
.13859 .77158 L
.14615 .74374 L
.15 .72441 L
.15373 .70131 L
.15933 .65412 L
.16177 .62528 L
.16359 .59685 L
.16441 .58007 L
.16503 .56444 L
.16556 .54702 L
.16593 .52847 L
Mistroke
.16615 .49921 L
.16588 .46775 L
.16514 .43808 L
.16408 .41136 L
.16234 .38041 L
.15989 .34779 L
.15702 .31807 L
.15397 .29222 L
.14704 .24689 L
.14297 .22622 L
.1382 .20605 L
.13351 .18984 L
.12896 .17705 L
.12445 .16696 L
.11952 .15866 L
.11643 .15486 L
.11358 .15226 L
.11042 .15043 L
.10707 .14967 L
.10145 .15116 L
.09828 .15358 L
.09534 .15687 L
.08995 .16571 L
.08518 .17679 L
.07991 .19309 L
.0752 .21188 L
.06661 .25979 L
.06292 .28828 L
.05941 .3225 L
.05692 .35357 L
.0548 .38859 L
.05333 .42272 L
.05245 .4545 L
.05214 .47371 L
.052 .49418 L
.0522 .5307 L
.05262 .55267 L
.05322 .57297 L
.05392 .59078 L
.05484 .60955 L
.05701 .64285 L
.05991 .67518 L
.06282 .70008 L
.06644 .72422 L
.07033 .7442 L
.07419 .75945 L
.07867 .77245 L
.08101 .77751 L
.08364 .7819 L
.08809 .78645 L
Mistroke
.09062 .78748 L
.09294 .78748 L
.09721 .78511 L
.10164 .7794 L
.10554 .77153 L
.10956 .76039 L
.11319 .74744 L
.11631 .73375 L
.11974 .71547 L
.12312 .69322 L
.12825 .64729 L
.13045 .61949 L
.13209 .5922 L
.13284 .5761 L
.13339 .56115 L
.13389 .54366 L
.1342 .52686 L
.13436 .51057 L
.13438 .49314 L
.13401 .46175 L
.13353 .44261 L
.1329 .42474 L
.13128 .3919 L
.12938 .36384 L
.12691 .3354 L
.12137 .28847 L
.11772 .26507 L
.11398 .24532 L
.10953 .22614 L
.10448 .20906 L
.0998 .19701 L
.09724 .19184 L
.09444 .18726 L
.08944 .18179 L
.0847 .17973 L
.082 .17992 L
.07906 .18125 L
.076 .18393 L
.07319 .18759 L
.06825 .19699 L
.06556 .20382 L
.06318 .21097 L
.05892 .22664 L
.0547 .24644 L
.05046 .27171 L
.04698 .298 L
.04431 .32292 L
.04185 .35151 L
.03967 .3847 L
.03813 .417 L
Mistroke
.03709 .45068 L
.0366 .48222 L
.03659 .51676 L
.0368 .53402 L
.03719 .55285 L
.0382 .58345 L
.0398 .615 L
.04176 .64298 L
.04392 .66684 L
.04882 .7061 L
.05202 .72474 L
.05524 .73954 L
.05884 .75237 L
.06226 .76146 L
.06634 .76883 L
.07028 .77269 L
.07427 .77355 L
.07855 .77116 L
.08254 .76582 L
.08609 .75843 L
.0901 .74689 L
.09424 .73095 L
.09787 .71292 L
.10096 .69385 L
.10407 .66995 L
.10661 .64539 L
.10855 .62189 L
.11024 .59519 L
.11102 .57963 L
.11161 .56484 L
.1121 .5492 L
.11249 .53183 L
.11276 .50285 L
.11254 .47167 L
.11187 .44264 L
.11085 .41621 L
.10929 .38797 L
.10715 .35917 L
.10251 .31456 L
.09932 .29177 L
.09602 .2724 L
.09279 .25681 L
.08919 .2425 L
.08591 .23199 L
.08228 .22279 L
.07825 .21531 L
.07441 .21076 L
.06979 .20844 L
.06559 .20934 L
.0612 .2134 L
Mistroke
.05718 .2201 L
.0529 .23065 L
.04851 .24561 L
.04422 .26512 L
.0405 .28704 L
.03745 .30958 L
.03459 .33604 L
.0323 .36315 L
.03058 .38909 L
.02923 .41622 L
.02831 .44243 L
.02767 .47362 L
.0275 .50241 L
.02778 .53375 L
.02859 .56605 L
.02994 .59752 L
.03162 .62463 L
.03403 .65364 L
.03676 .67844 L
.03963 .69876 L
.04253 .71511 L
.04596 .73021 L
.04983 .74282 L
.05388 .75182 L
.05621 .75526 L
.05837 .75738 L
.06238 .75872 L
.06659 .75661 L
.06881 .75403 L
.07115 .75021 L
.07525 .74061 L
.07767 .73309 L
.07988 .7249 L
.08377 .70693 L
.0867 .68984 L
.08954 .66937 L
.09173 .65009 L
.09379 .62765 L
.09578 .59977 L
.0972 .57207 L
.09813 .54426 L
.0986 .51804 L
.09866 .49043 L
.09834 .46457 L
.09754 .43657 L
.0969 .42111 L
.09619 .40716 L
.09453 .38151 L
.09226 .35489 L
.08942 .32913 L
Mistroke
.08638 .30734 L
.08342 .29021 L
.07995 .27396 L
.07646 .26104 L
.07308 .25137 L
.06993 .2446 L
.06637 .23937 L
.06261 .23648 L
.05906 .23621 L
.05494 .23892 L
.05109 .24451 L
.04773 .25202 L
.04419 .26284 L
.04055 .27755 L
.03697 .29647 L
.03141 .33807 L
.02905 .36315 L
.02692 .39276 L
.02605 .40837 L
.02527 .42549 L
.02469 .44196 L
.02428 .45715 L
.02385 .48655 L
.02389 .51853 L
.02442 .5483 L
.02532 .57506 L
.02599 .58942 L
.02684 .60447 L
.0287 .63033 L
.03142 .65843 L
.03435 .6812 L
.03759 .70052 L
.04148 .71778 L
.04355 .72488 L
.04584 .73124 L
.04804 .73606 L
.05008 .73943 L
.05395 .74316 L
.05592 .74377 L
.05809 .74348 L
.06189 .7405 L
.06539 .73496 L
.06745 .73036 L
.06937 .72516 L
.07284 .7133 L
.07634 .69765 L
.07983 .67751 L
.08253 .65764 L
.08477 .63723 L
.08696 .61196 L
Mistroke
.08854 .58778 L
.08968 .56396 L
.09041 .54155 L
.09085 .5166 L
.0909 .49016 L
.09055 .46447 L
.09017 .45014 L
.08971 .43709 L
.0886 .41367 L
.08704 .38985 L
.08533 .36967 L
.08348 .35189 L
.07845 .31626 L
.07524 .29995 L
.07196 .28696 L
.06886 .27754 L
.06533 .26982 L
.06328 .26668 L
.06141 .26464 L
.05922 .26323 L
.05716 .26286 L
.05348 .26451 L
.04957 .26964 L
.04626 .27689 L
.04328 .28596 L
.04018 .29837 L
.03708 .31441 L
.03412 .33404 L
.03165 .35502 L
.02973 .37561 L
.02798 .39961 L
.02678 .4214 L
.0258 .44635 L
.02518 .47306 L
.02497 .49843 L
.02511 .52202 L
.02552 .54341 L
.02626 .56638 L
.02738 .58973 L
.02898 .61404 L
.03113 .63847 L
.03353 .65939 L
.03602 .67657 L
.03869 .69124 L
.04136 .70291 L
.04431 .71288 L
.04769 .72114 L
.05145 .72682 L
.05508 .7291 L
.05835 .7286 L
Mistroke
.06189 .72534 L
.06387 .72226 L
.06564 .71873 L
.06948 .70835 L
.07285 .69585 L
.07581 .68175 L
.08056 .65106 L
.0826 .63347 L
.08454 .61283 L
.08593 .59424 L
.08714 .57356 L
.088 .5535 L
.08855 .53491 L
.08891 .51136 L
.08891 .48959 L
.08856 .46594 L
.08779 .4414 L
.08679 .42085 L
.08559 .40236 L
.08399 .38314 L
.08196 .36391 L
.07729 .33229 L
.0743 .31795 L
.07138 .30726 L
.06852 .2994 L
.06532 .29333 L
.06222 .29003 L
.05934 .28914 L
.05599 .29072 L
.05289 .29477 L
.04959 .30204 L
.0478 .30739 L
.0462 .31305 L
.04317 .32659 L
.04015 .34445 L
.03762 .36402 L
.0356 .38422 L
.03398 .40512 L
.03261 .42911 L
.03168 .4528 L
.03117 .47514 L
.03097 .50023 L
.03104 .51448 L
.03122 .52769 L
.03152 .54156 L
.03191 .55401 L
.03248 .56814 L
.03313 .58118 L
.0347 .605 L
.03677 .62844 L
Mistroke
.03886 .6467 L
.04146 .66466 L
.04457 .68117 L
.0464 .68896 L
.0482 .69547 L
.04992 .70069 L
.05185 .70549 L
.05533 .71159 L
.05708 .71352 L
.05894 .71477 L
.06229 .715 L
.06587 .71242 L
.06788 .70968 L
.06973 .70632 L
.07298 .69832 L
.07583 .68898 L
.07892 .67595 L
.08162 .66158 L
.08384 .64719 L
.08596 .63052 L
.0891 .59765 L
.09043 .57814 L
.09141 .55924 L
.09218 .53808 L
.09246 .52606 L
.09263 .51503 L
.09269 .4938 L
.0924 .47141 L
.09179 .45081 L
.09096 .43272 L
.08966 .41244 L
.08788 .39196 L
.08588 .37433 L
.08377 .35978 L
.08154 .34744 L
.07894 .33623 L
.07737 .33081 L
.0759 .32654 L
.07293 .3201 L
.0713 .31775 L
.06978 .31625 L
.0681 .31537 L
.06631 .31533 L
.0646 .31615 L
.06301 .31769 L
.06007 .32256 L
.05748 .32923 L
.05484 .33865 L
.0525 .34962 L
.05052 .36125 L
Mistroke
.04841 .37678 L
.04643 .39569 L
.04487 .41524 L
.04373 .43452 L
.04286 .45533 L
.04235 .47547 L
.04214 .49799 L
.04218 .51072 L
.04232 .52236 L
.04288 .54542 L
.04337 .55825 L
.04392 .56994 L
.04521 .59065 L
.04693 .61146 L
.04884 .62943 L
.05085 .64453 L
.05324 .65906 L
.0561 .67278 L
.05878 .68269 L
.0614 .69014 L
.06427 .69607 L
.06742 .70018 L
.07032 .70187 L
.07348 .70157 L
.07644 .69925 L
.07914 .6954 L
.08152 .6906 L
.08406 .68389 L
.08888 .66606 L
.09136 .65381 L
.09348 .64113 L
.09575 .62464 L
.09756 .60849 L
.09909 .59177 L
.10046 .57287 L
.10107 .56222 L
.10155 .55228 L
.10225 .53248 L
.10259 .51556 L
.10269 .49979 L
.10256 .4827 L
.10215 .46475 L
.10143 .44664 L
.10049 .43025 L
.09942 .41635 L
.09805 .4022 L
.09615 .38689 L
.09413 .37424 L
.09214 .36448 L
.08983 .35576 L
Mistroke
.08717 .34854 L
.08578 .34586 L
.08424 .34367 L
.08291 .34244 L
.08147 .34177 L
.07888 .34231 L
.07631 .3451 L
.07488 .34766 L
.07358 .35065 L
.07128 .35768 L
.06898 .36725 L
.06707 .37753 L
.06543 .38855 L
.06382 .40214 L
.06233 .41814 L
.06114 .43521 L
.0603 .45164 L
.05971 .46885 L
.05939 .48556 L
.05932 .50541 L
.05954 .52381 L
.0601 .54386 L
.06051 .55383 L
.06105 .56462 L
.06233 .58423 L
.06378 .60124 L
.06578 .61954 L
.06797 .63533 L
.07247 .65897 L
.07531 .66957 L
.07808 .67747 L
.08076 .68311 L
.08373 .68729 L
.08658 .68943 L
.08922 .68985 L
.0916 .68897 L
.0942 .68666 L
.09686 .68279 L
.09928 .6779 L
.10203 .67064 L
.10452 .66237 L
.1088 .64356 L
.11276 .6192 L
.11466 .60394 L
.11617 .5891 L
.11746 .57351 L
.11846 .5583 L
.11915 .54445 L
.1197 .52924 L
.12003 .5128 L
Mistroke
.12011 .50369 L
.1201 .49551 L
.11991 .47987 L
.1195 .4656 L
.11893 .45271 L
.11813 .43975 L
.1173 .42933 L
.11625 .41864 L
.11495 .4081 L
.1134 .39804 L
.11191 .39036 L
.11023 .38343 L
.10924 .38013 L
.10812 .37699 L
.10609 .37275 L
.10492 .37112 L
.10365 .36997 L
.10244 .36948 L
.10133 .36954 L
.09931 .3709 L
.09818 .3724 L
.09715 .37425 L
.0951 .37934 L
.094 .38296 L
.09303 .38671 L
.09139 .39447 L
.08979 .4041 L
.08822 .41621 L
.08697 .42869 L
.086 .4413 L
.08527 .45384 L
.08467 .46831 L
.08428 .4845 L
.08418 .4933 L
.08416 .50167 L
.08431 .51747 L
.08474 .53452 L
.08511 .54407 L
.08552 .55276 L
.08638 .56711 L
.08756 .58235 L
.09065 .61088 L
.09282 .62563 L
.09503 .63775 L
.09762 .64924 L
.10064 .65975 L
.10361 .66753 L
.10646 .673 L
.10926 .67666 L
.11069 .67792 L
Mistroke
.11227 .67885 L
.11517 .67932 L
.11663 .67897 L
.11821 .67815 L
.121 .67559 L
.12354 .67197 L
.12648 .66622 L
.12905 .65971 L
.13438 .64108 L
.13839 .62115 L
.142 .59654 L
.14338 .58448 L
.14463 .57135 L
.14561 .55891 L
.14634 .54727 L
.14697 .53425 L
.14722 .5274 L
.14743 .52016 L
.14763 .50817 L
.14766 .49523 L
.14751 .48412 L
.14718 .4726 L
.14671 .46226 L
.14615 .45328 L
.14534 .44351 L
.14446 .43515 L
.14337 .42688 L
.14206 .41917 L
.14055 .41241 L
.13903 .40736 L
.1376 .40397 L
.136 .40156 L
.13457 .40055 L
.13322 .40056 L
.13175 .40164 L
.1302 .40404 L
.12862 .40791 L
.1272 .41283 L
.126 .41824 L
.12478 .42517 L
.12288 .44023 L
.12202 .44992 L
.12137 .4594 L
.12089 .4688 L
.12052 .47947 L
.12031 .48994 L
.12024 .49984 L
.12035 .51286 L
.12064 .52538 L
.12106 .53668 L
Mistroke
.1217 .54893 L
.1226 .56208 L
.12378 .57574 L
.12647 .59897 L
.12956 .61834 L
.13293 .63427 L
.13707 .64881 L
.13957 .65552 L
.14195 .66069 L
.14445 .66496 L
.14718 .66841 L
.1498 .6706 L
.1522 .6717 L
.15504 .67191 L
.15665 .67153 L
.15812 .67086 L
.1608 .66887 L
.16359 .6657 L
.16621 .6617 L
.16895 .65643 L
.17362 .64454 L
.17864 .62703 L
.18262 .60855 L
.18579 .5895 L
.18812 .57148 L
.18918 .56135 L
.19015 .5504 L
.19084 .54101 L
.19143 .53086 L
.19183 .52162 L
.19207 .51323 L
.19221 .50466 L
.19221 .49588 L
.19209 .48813 L
.19187 .48121 L
.1916 .47536 L
.19122 .46945 L
.19066 .46308 L
.19006 .45776 L
.1893 .45267 L
.1884 .44814 L
.18793 .44625 L
.18739 .44448 L
.1869 .44317 L
.18637 .44204 L
.18583 .4412 L
.18534 .44068 L
.18437 .44031 L
.1834 .44081 L
.18252 .44205 L
Mistroke
.18158 .44425 L
.18112 .44568 L
.18064 .44751 L
.17986 .45116 L
.17909 .45584 L
.17845 .46098 L
.17793 .46622 L
.17747 .47232 L
.17712 .47853 L
.17685 .48584 L
.17668 .49423 L
.17666 .50302 L
.1767 .50759 L
.1768 .51269 L
.17707 .52196 L
.17747 .53079 L
.17801 .5399 L
.17864 .54857 L
.18016 .56481 L
.18228 .58201 L
.18514 .59988 L
.18858 .61672 L
.19296 .63328 L
.1981 .64795 L
.20334 .65893 L
.20598 .66319 L
.20854 .66663 L
.21092 .66923 L
.21348 .67145 L
.21629 .67323 L
.21891 .67431 L
.22053 .67469 L
.22205 .67488 L
.22489 .67475 L
.22748 .67411 L
.23024 .67291 L
.23282 .67129 L
.23514 .66944 L
.24072 .66348 L
.24578 .65619 L
.25506 .63796 L
.26371 .61461 L
.27505 .57165 L
.28123 .53962 L
.28321 .52832 L
.28402 .52422 L
.28442 .52254 L
.28476 .52134 L
.28505 .52058 L
.28535 .52006 L
Mistroke
.28568 .51987 L
.28598 .52003 L
.28625 .52045 L
.28656 .52121 L
.28686 .5222 L
.28715 .52336 L
.29177 .54853 L
.30033 .58855 L
.313 .63188 L
.33226 .67903 L
.34578 .70444 L
.36022 .72719 L
.39121 .76671 L
.46256 .83877 L
.50918 .88249 L
.55832 .92559 L
.59759 .95414 L
.60876 .96064 L
.6207 .96656 L
.63101 .97067 L
.63645 .97243 L
.64238 .97399 L
.64893 .97526 L
.65514 .97597 L
.66118 .97619 L
.66676 .97594 L
.67279 .97515 L
.67941 .97361 L
.68629 .9712 L
.6927 .96817 L
.70425 .96055 L
.71462 .95103 L
.72628 .93682 L
.73698 .91991 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.35119 0.64881 0.64881 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.50002 0.221793 0.5 0.443828 [
[.5 1.0125 -3.5 0 ]
[.5 1.0125 3.5 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -64.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.000 15.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
.82218 .53304 m
.82263 .52687 L
.82296 .5208 L
.82323 .51331 L
.82337 .50579 L
.8234 .4985 L
.82333 .49152 L
.82316 .48362 L
.82286 .47504 L
.82242 .46625 L
.82181 .45666 L
.82031 .43922 L
.81788 .41878 L
.81505 .40086 L
.8116 .3838 L
.80792 .36948 L
.80343 .35577 L
.79819 .34377 L
.79566 .33924 L
.79285 .33504 L
.79032 .33195 L
.7876 .32931 L
.78511 .32748 L
.78235 .32606 L
.77982 .3253 L
.77746 .32504 L
.77599 .32509 L
.77443 .32532 L
.77164 .32617 L
.7701 .32688 L
.76867 .32769 L
.76541 .33005 L
.76011 .33549 L
.75462 .34318 L
.7451 .36171 L
.73752 .38171 L
.72479 .42921 L
.7207 .44978 L
.71765 .46706 L
.71668 .47248 L
.71579 .47677 L
.71543 .47817 L
.71524 .47878 L
.71507 .47925 L
.71478 .47985 L
.71446 .48016 L
.71415 .48011 L
.71386 .47974 L
.71359 .47916 L
.71329 .47824 L
Mistroke
.71255 .47517 L
.71176 .47108 L
.70579 .4386 L
.69507 .3939 L
.67871 .34566 L
.66683 .31899 L
.65429 .29557 L
.59666 .21983 L
.52066 .14528 L
.46857 .0973 L
.41533 .05435 L
.3875 .03734 L
.3797 .03359 L
.37137 .03016 L
.36412 .02771 L
.35628 .02569 L
.34892 .02442 L
.34217 .02386 L
.33571 .02389 L
.32893 .02457 L
.32147 .02615 L
.31457 .02846 L
.30705 .03198 L
.2991 .03696 L
.29084 .04365 L
.28335 .05119 L
.26699 .07341 L
.25335 .09929 L
.23998 .13327 L
.22908 .16943 L
.22 .20783 L
.21139 .25455 L
.20389 .30909 L
.19857 .36379 L
.19656 .39211 L
.19562 .40853 L
.19489 .42363 L
.19392 .45038 L
.19333 .47904 L
.19321 .50397 L
.19347 .52973 L
.1942 .55698 L
.19481 .57181 L
.19548 .58499 L
.1971 .60972 L
.199 .63183 L
.20164 .6559 L
.20445 .67633 L
.20789 .69648 L
.21198 .71557 L
Mistroke
.21553 .72891 L
.21895 .73948 L
.22257 .7486 L
.22604 .75559 L
.23017 .76192 L
.23239 .76449 L
.23478 .76665 L
.23924 .76907 L
.2433 .76952 L
.24552 .76908 L
.24787 .76809 L
.25203 .76502 L
.25644 .75989 L
.26116 .75218 L
.26511 .74383 L
.26919 .73323 L
.27603 .71008 L
.28242 .68045 L
.28549 .66223 L
.28806 .64398 L
.29181 .60937 L
.29338 .58987 L
.29472 .56811 L
.29527 .55644 L
.29569 .54543 L
.29604 .53319 L
.2963 .51995 L
.29643 .50585 L
.29642 .4924 L
.29631 .48023 L
.29606 .46694 L
.29575 .45533 L
.29529 .4425 L
.29402 .41645 L
.29242 .39227 L
.29056 .3697 L
.28546 .32237 L
.2792 .2788 L
.26389 .20342 L
.25351 .16669 L
.24288 .13732 L
.23028 .11137 L
.2229 .10019 L
.21606 .09235 L
.20975 .08724 L
.20381 .08429 L
.19726 .08318 L
.19358 .08357 L
.19025 .08457 L
.18355 .0885 L
Mistroke
.17981 .09187 L
.17638 .09574 L
.17018 .10474 L
.16379 .117 L
.15312 .14525 L
.14396 .17928 L
.1351 .2244 L
.12718 .28089 L
.12362 .31487 L
.12087 .34786 L
.11847 .38527 L
.11743 .40656 L
.11667 .42603 L
.11574 .46191 L
.11547 .4821 L
.1154 .50057 L
.11567 .53412 L
.11654 .56865 L
.1178 .59845 L
.11964 .62893 L
.12181 .65603 L
.12415 .67913 L
.12727 .70404 L
.13111 .72824 L
.13512 .7482 L
.13908 .76382 L
.14298 .77602 L
.14726 .78631 L
.15169 .79395 L
.15665 .79925 L
.161 .80126 L
.16567 .80082 L
.17005 .79799 L
.17397 .79346 L
.17637 .78974 L
.17888 .78507 L
.18325 .77485 L
.18776 .76135 L
.19244 .74368 L
.19619 .72626 L
.19989 .70547 L
.20562 .66313 L
.20828 .63645 L
.21032 .61042 L
.21205 .58063 L
.21277 .56353 L
.21328 .5478 L
.21364 .53254 L
.21384 .51839 L
.21394 .50274 L
Mistroke
.21388 .48611 L
.21344 .458 L
.213 .44202 L
.21245 .42713 L
.211 .39766 L
.20918 .37011 L
.20463 .32001 L
.19812 .2694 L
.18933 .22001 L
.18044 .18338 L
.17536 .16689 L
.16976 .15183 L
.16464 .14066 L
.15888 .13086 L
.15353 .12425 L
.14848 .12017 L
.14533 .11867 L
.14191 .11796 L
.1357 .11917 L
.1297 .12349 L
.12426 .13026 L
.1185 .14064 L
.11239 .15567 L
.10632 .17535 L
.101 .19729 L
.09619 .22188 L
.09144 .25191 L
.08772 .28091 L
.08429 .31403 L
.08171 .34541 L
.07942 .38153 L
.07786 .4153 L
.07688 .44752 L
.07653 .46573 L
.07632 .48565 L
.07628 .50635 L
.07642 .52548 L
.07707 .55915 L
.07833 .59394 L
.07929 .61282 L
.08053 .63262 L
.08326 .66646 L
.0865 .69639 L
.08993 .72102 L
.09361 .74187 L
.09739 .75882 L
.10098 .77154 L
.10508 .78268 L
.10968 .79146 L
.1123 .79487 L
Mistroke
.1147 .79703 L
.11942 .79873 L
.12386 .79735 L
.128 .79346 L
.1323 .78673 L
.13588 .77892 L
.13968 .76827 L
.14359 .7545 L
.14753 .73726 L
.15387 .70033 L
.15717 .6747 L
.1598 .64916 L
.16219 .61939 L
.1632 .60357 L
.16414 .58613 L
.1653 .55627 L
.16595 .5276 L
.16612 .51079 L
.16614 .49298 L
.16575 .46105 L
.16495 .43258 L
.16364 .40249 L
.16195 .3746 L
.16006 .34988 L
.15741 .32175 L
.15404 .29272 L
.14668 .24493 L
.13844 .20699 L
.13335 .18936 L
.12847 .17583 L
.12376 .16562 L
.11848 .15726 L
.1134 .15213 L
.10864 .14987 L
.10572 .1497 L
.10256 .15058 L
.09689 .155 L
.09147 .16283 L
.08662 .17309 L
.08154 .18753 L
.07628 .20716 L
.07118 .23171 L
.06686 .25805 L
.06306 .28698 L
.05951 .3213 L
.05675 .35601 L
.05474 .38963 L
.05339 .42081 L
.05242 .45577 L
.052 .49247 L
Mistroke
.05215 .5266 L
.05245 .54528 L
.05297 .56535 L
.05362 .58392 L
.05438 .60075 L
.05617 .63124 L
.05858 .66157 L
.06203 .69388 L
.06582 .72048 L
.0696 .74086 L
.07404 .75893 L
.07822 .77136 L
.08218 .77965 L
.08688 .78557 L
.09139 .78759 L
.09555 .7864 L
.09938 .78274 L
.1035 .776 L
.10774 .76582 L
.1118 .75274 L
.11592 .73558 L
.12255 .6973 L
.12581 .67144 L
.12873 .64175 L
.13078 .61473 L
.1325 .58372 L
.13316 .56785 L
.13372 .55037 L
.13409 .53365 L
.1343 .5181 L
.13435 .48845 L
.1339 .45699 L
.13347 .44081 L
.13285 .42354 L
.13134 .39284 L
.12888 .35756 L
.12605 .32688 L
.11977 .27764 L
.11556 .25322 L
.11129 .23321 L
.10697 .2169 L
.10269 .20403 L
.10024 .19801 L
.09755 .19241 L
.09274 .18502 L
.08772 .18069 L
.0831 .17971 L
.07779 .18219 L
.07282 .18815 L
.06835 .19676 L
Mistroke
.06434 .20735 L
.06012 .22182 L
.0559 .2403 L
.05199 .26185 L
.04818 .2882 L
.04527 .31333 L
.04253 .34296 L
.04005 .37804 L
.03897 .39793 L
.03814 .41679 L
.03707 .45126 L
.03672 .47074 L
.03655 .48846 L
.03666 .5245 L
.03695 .54242 L
.03743 .56181 L
.03872 .59507 L
.04041 .62457 L
.04295 .65687 L
.04577 .68358 L
.04953 .71063 L
.05354 .73217 L
.0573 .74734 L
.06153 .75976 L
.06568 .76788 L
.06953 .77219 L
.07412 .77358 L
.07671 .77261 L
.07907 .77064 L
.08335 .76436 L
.08546 .75993 L
.08773 .75415 L
.09187 .74063 L
.09546 .72534 L
.09912 .7057 L
.1026 .68195 L
.10509 .66078 L
.10741 .63632 L
.1095 .60778 L
.11101 .57974 L
.11202 .55238 L
.11263 .52186 L
.11275 .49272 L
.11244 .46565 L
.11176 .43907 L
.11081 .41535 L
.10933 .38865 L
.10758 .36436 L
.10234 .31323 L
.0991 .29034 L
Mistroke
.09514 .26787 L
.09146 .25115 L
.08725 .23601 L
.08307 .22457 L
.07912 .21669 L
.07668 .21315 L
.07405 .21045 L
.06929 .20839 L
.06665 .20883 L
.06417 .21028 L
.06148 .21304 L
.0586 .21738 L
.05631 .22193 L
.05385 .22795 L
.04909 .24336 L
.04495 .26139 L
.0414 .28121 L
.03803 .30481 L
.03492 .33268 L
.03265 .35849 L
.03061 .38865 L
.02969 .40591 L
.02897 .42263 L
.02831 .44221 L
.02788 .4603 L
.0275 .49327 L
.02753 .51188 L
.0277 .52902 L
.02845 .56199 L
.02965 .59188 L
.03112 .61744 L
.03309 .64337 L
.03568 .66936 L
.03885 .6937 L
.04187 .71171 L
.04546 .72828 L
.0492 .74106 L
.05289 .75001 L
.0563 .75538 L
.06007 .75836 L
.0642 .75825 L
.06627 .75689 L
.06854 .7544 L
.07248 .7475 L
.07606 .73826 L
.07931 .72712 L
.08255 .7131 L
.08776 .6827 L
.0903 .66311 L
.09238 .64346 L
Mistroke
.09433 .62087 L
.09608 .59469 L
.0974 .56718 L
.09793 .55178 L
.0983 .53722 L
.09866 .51091 L
.0986 .48256 L
.09838 .46673 L
.09797 .44961 L
.09743 .43364 L
.0968 .41905 L
.09528 .39223 L
.09319 .36504 L
.09101 .34282 L
.08831 .32058 L
.08256 .28578 L
.0788 .26935 L
.07457 .25533 L
.07079 .24625 L
.06651 .23953 L
.06233 .23637 L
.05836 .23643 L
.05481 .23905 L
.05102 .24464 L
.04701 .25395 L
.04505 .2599 L
.04295 .2674 L
.03938 .28321 L
.03635 .30022 L
.03122 .33983 L
.02891 .36477 L
.02709 .39011 L
.02575 .41457 L
.02481 .43801 L
.02413 .46429 L
.02381 .4926 L
.02393 .5227 L
.02421 .53959 L
.02461 .55514 L
.02517 .57126 L
.0258 .58563 L
.02763 .61651 L
.02962 .64093 L
.0322 .66512 L
.03498 .68539 L
.03782 .7017 L
.04135 .71731 L
.04488 .72876 L
.04697 .73389 L
.04893 .73765 L
Mistroke
.05111 .74076 L
.05342 .74286 L
.05555 .74373 L
.05782 .74357 L
.06189 .74051 L
.06434 .73691 L
.06661 .73236 L
.07073 .72093 L
.07392 .70892 L
.0772 .69316 L
.08013 .67547 L
.08295 .65418 L
.08524 .63243 L
.08701 .61122 L
.08848 .58886 L
.08956 .56688 L
.09043 .54082 L
.09073 .52606 L
.09088 .51263 L
.09088 .48642 L
.09049 .46196 L
.09011 .4482 L
.08958 .43388 L
.08832 .40893 L
.08653 .38334 L
.08407 .3572 L
.08151 .33613 L
.07885 .31859 L
.07564 .30175 L
.07194 .28689 L
.06855 .27674 L
.06524 .26966 L
.06151 .26473 L
.05939 .2633 L
.05745 .26285 L
.05388 .26418 L
.05061 .26792 L
.04709 .27479 L
.04349 .28524 L
.04023 .29811 L
.03737 .3127 L
.03266 .34581 L
.03044 .36734 L
.02841 .39299 L
.02756 .40659 L
.02677 .42159 L
.0257 .44953 L
.02511 .47808 L
.02498 .50539 L
.02522 .5298 L
Mistroke
.02588 .55589 L
.02703 .5833 L
.02789 .59831 L
.02882 .61192 L
.03105 .63765 L
.03393 .66249 L
.03684 .68149 L
.04023 .69831 L
.04333 .7099 L
.04691 .71953 L
.05065 .72591 L
.05416 .72882 L
.05602 .72921 L
.05805 .72875 L
.06017 .72728 L
.06213 .725 L
.06568 .71863 L
.06882 .71042 L
.07226 .69826 L
.07533 .68427 L
.07786 .66995 L
.08031 .65298 L
.08403 .61867 L
.08583 .59572 L
.08716 .5731 L
.08805 .55218 L
.08867 .52916 L
.08894 .50385 L
.08882 .48033 L
.08858 .46695 L
.08827 .45491 L
.08778 .44123 L
.0872 .42853 L
.08571 .40409 L
.08396 .38287 L
.08166 .36142 L
.07881 .34112 L
.07631 .32715 L
.07339 .31432 L
.07047 .30447 L
.06767 .29751 L
.06447 .29218 L
.06263 .29032 L
.0609 .28936 L
.0574 .28969 L
.05546 .29122 L
.05371 .29344 L
.05061 .29944 L
.04781 .30734 L
.04488 .31845 L
Mistroke
.04196 .33311 L
.03919 .35126 L
.03687 .37086 L
.03509 .39021 L
.03348 .41286 L
.03241 .43344 L
.03156 .45706 L
.03107 .48236 L
.03098 .5064 L
.03123 .5287 L
.03173 .54889 L
.03258 .57053 L
.03381 .59246 L
.03553 .61527 L
.03741 .63452 L
.03993 .65463 L
.04261 .67131 L
.04531 .68452 L
.04797 .69472 L
.05104 .70361 L
.05442 .71031 L
.0579 .71418 L
.05988 .7151 L
.06169 .71515 L
.06519 .71314 L
.06847 .70871 L
.07027 .70518 L
.07215 .70063 L
.07542 .69046 L
.07905 .67529 L
.08206 .65893 L
.08631 .62745 L
.08828 .60749 L
.08981 .58781 L
.09109 .56618 L
.09193 .54592 L
.09227 .53459 L
.09253 .5222 L
.09271 .49966 L
.09257 .48062 L
.09211 .46 L
.09129 .43912 L
.09022 .42036 L
.08897 .40378 L
.08763 .38949 L
.08397 .36101 L
.08172 .34838 L
.07913 .33694 L
.07652 .32824 L
.07405 .32219 L
Mistroke
.07105 .31744 L
.06932 .31592 L
.06773 .31528 L
.06479 .31601 L
.06332 .31731 L
.06172 .31948 L
.0601 .32249 L
.05859 .32609 L
.05584 .33472 L
.05307 .34666 L
.05031 .36262 L
.04817 .37879 L
.04621 .39808 L
.04468 .41796 L
.0436 .43713 L
.04279 .45764 L
.04232 .47734 L
.04214 .49933 L
.04232 .52298 L
.04257 .53481 L
.04295 .54753 L
.04393 .57012 L
.04524 .5912 L
.04675 .60962 L
.05014 .6396 L
.05241 .65444 L
.05474 .66671 L
.05718 .67708 L
.05989 .68612 L
.063 .69374 L
.06595 .69856 L
.06928 .70149 L
.07233 .70194 L
.07402 .70129 L
.07584 .69988 L
.0791 .69548 L
.08207 .68929 L
.08509 .68067 L
.08755 .67173 L
.09009 .66038 L
.09511 .62961 L
.09743 .60976 L
.0992 .5904 L
.10053 .57159 L
.10111 .56142 L
.10163 .55048 L
.10199 .54088 L
.10231 .53022 L
.10263 .51139 L
.10267 .49294 L
Mistroke
.10244 .47605 L
.10192 .45801 L
.10151 .44821 L
.10106 .43952 L
.09994 .42269 L
.09843 .40574 L
.09674 .39118 L
.09497 .37916 L
.09333 .37006 L
.09144 .36158 L
.08924 .3539 L
.08708 .34835 L
.08459 .34408 L
.08217 .342 L
.07998 .3418 L
.0776 .3434 L
.07626 .34517 L
.07482 .34777 L
.07349 .35088 L
.07229 .3543 L
.07011 .3622 L
.06795 .37249 L
.06583 .38566 L
.06407 .39973 L
.06243 .41694 L
.06165 .42723 L
.06102 .43713 L
.06014 .45558 L
.0598 .46564 L
.05953 .47653 L
.05931 .49515 L
.05932 .50586 L
.05941 .51594 L
.05979 .53457 L
.0604 .55144 L
.06133 .56951 L
.0626 .58781 L
.06412 .60468 L
.06605 .62169 L
.06798 .63542 L
.07024 .64849 L
.07245 .65888 L
.07503 .66868 L
.0775 .67603 L
.0799 .68152 L
.08299 .68646 L
.08599 .68914 L
.0887 .68989 L
.09165 .68894 L
.09332 .6876 L
Mistroke
.09482 .68589 L
.09653 .68335 L
.09812 .68041 L
.10087 .67392 L
.10372 .6652 L
.10815 .64685 L
.11233 .62228 L
.11413 .60845 L
.11582 .59281 L
.11706 .57873 L
.11817 .56301 L
.11903 .54703 L
.11961 .53216 L
.11995 .51794 L
.12011 .50299 L
.12006 .48984 L
.11986 .47778 L
.11947 .46492 L
.11887 .45164 L
.11793 .43698 L
.11686 .42462 L
.11541 .41161 L
.11384 .40072 L
.11235 .39247 L
.11065 .38502 L
.10867 .37845 L
.10676 .37394 L
.10463 .37079 L
.10341 .36983 L
.1023 .36946 L
.10014 .37014 L
.09811 .3725 L
.09699 .37455 L
.09583 .3773 L
.09381 .38366 L
.09177 .3925 L
.08973 .4045 L
.08828 .4157 L
.08696 .42886 L
.08601 .44108 L
.08519 .45533 L
.08483 .46375 L
.08456 .47159 L
.08434 .48083 L
.08421 .48971 L
.08417 .50578 L
.08427 .51494 L
.08442 .52341 L
.08488 .5386 L
.08551 .55267 L
Mistroke
.08643 .56779 L
.08766 .58351 L
.08922 .59916 L
.09094 .6131 L
.09474 .63632 L
.09699 .64671 L
.09959 .65643 L
.10202 .66365 L
.10468 .66981 L
.10716 .67409 L
.10995 .67732 L
.11251 .67895 L
.11492 .67934 L
.11637 .67907 L
.11794 .67833 L
.12078 .67585 L
.12349 .67207 L
.12593 .66743 L
.12848 .66127 L
.13118 .65316 L
.13615 .63303 L
.13987 .61202 L
.1427 .59071 L
.14509 .56582 L
.146 .55298 L
.14677 .53887 L
.14725 .52636 L
.14753 .51513 L
.14767 .50239 L
.14762 .4907 L
.14742 .4802 L
.14711 .4709 L
.14664 .46114 L
.14601 .45141 L
.14518 .44183 L
.14412 .43236 L
.14298 .42441 L
.14182 .41798 L
.1406 .41261 L
.1394 .40843 L
.13808 .40497 L
.13659 .40227 L
.13503 .40075 L
.13338 .40051 L
.13197 .4014 L
.13046 .40354 L
.12887 .4072 L
.12801 .40984 L
.12725 .41261 L
.12592 .41858 L
Mistroke
.12463 .4261 L
.12363 .43344 L
.12266 .44244 L
.1219 .45137 L
.12131 .46033 L
.12078 .47151 L
.12044 .48226 L
.12026 .49516 L
.12028 .5078 L
.12046 .51892 L
.12082 .53087 L
.12132 .54217 L
.12191 .55236 L
.12276 .56422 L
.12387 .57676 L
.12639 .59837 L
.12968 .61898 L
.13384 .63791 L
.13607 .64573 L
.13829 .65225 L
.14267 .66204 L
.1453 .66617 L
.14677 .66797 L
.14816 .66936 L
.15063 .67108 L
.15338 .67193 L
.15484 .67194 L
.15637 .67163 L
.15909 .67026 L
.1606 .66905 L
.16199 .66766 L
.16509 .66354 L
.16779 .65879 L
.17062 .65259 L
.17544 .63884 L
.17964 .62283 L
.18303 .6063 L
.18613 .58707 L
.18881 .56502 L
.18987 .55382 L
.19078 .54186 L
.19143 .53075 L
.19185 .52083 L
.19212 .51119 L
.19222 .50247 L
.1922 .49496 L
.19207 .48725 L
.19179 .47933 L
.19161 .47557 L
.19137 .47164 L
Mistroke
.19086 .46516 L
.1903 .45973 L
.18965 .45486 L
.18897 .45087 L
.18832 .44781 L
.18757 .44506 L
.18672 .44276 L
.18579 .44115 L
.18497 .44043 L
.18407 .44037 L
.18357 .44066 L
.18303 .44124 L
.18206 .443 L
.18115 .44557 L
.18035 .44871 L
.17947 .45333 L
.17876 .45833 L
.17804 .46501 L
.17748 .47214 L
.1771 .479 L
.17682 .48682 L
.17668 .4939 L
.17665 .50206 L
.17676 .51124 L
.17689 .51653 L
.17705 .52143 L
.17748 .53114 L
.17804 .54048 L
.17953 .55868 L
.18143 .57562 L
.18405 .59361 L
.18749 .61181 L
.19146 .62814 L
.1962 .64306 L
.20063 .65369 L
.20325 .65876 L
.20579 .66292 L
.20822 .66623 L
.2109 .66922 L
.21337 .67138 L
.21568 .67291 L
.2182 .67407 L
.22098 .67477 L
.22389 .67486 L
.22661 .67438 L
.22915 .67345 L
.23154 .67215 L
.23367 .67065 L
.23598 .66869 L
.24101 .6631 L
Mistroke
.24552 .6566 L
.25507 .63793 L
.26389 .61403 L
.27549 .56962 L
.28182 .53617 L
.28366 .52597 L
.28429 .52302 L
.2846 .52185 L
.28491 .5209 L
.28523 .52022 L
.28552 .51991 L
.28579 .51989 L
.28609 .52017 L
.28641 .5208 L
.28676 .52187 L
.28747 .52481 L
.2923 .55139 L
.29648 .57207 L
.30254 .5972 L
.3181 .64605 L
.33867 .69168 L
.36648 .73604 L
.43009 .80743 L
.51831 .89085 L
.57364 .9376 L
.60378 .95784 L
.62145 .96689 L
.62947 .97012 L
.63825 .97294 L
.64233 .97397 L
.64668 .97487 L
.65452 .97592 L
.65871 .97615 L
.66265 .97616 L
.67 .97558 L
.67726 .97418 L
.6839 .97213 L
.69115 .96897 L
.69873 .96454 L
.70629 .95888 L
.71427 .9514 L
.72826 .93399 L
.74405 .90631 L
.7574 .87429 L
.76858 .83926 L
.77785 .80228 L
.78673 .75703 L
.79449 .70457 L
.79975 .65623 L
.80338 .60941 L
Mistroke
.80488 .58226 L
.80588 .55739 L
.80659 .52883 L
.80683 .50201 L
.80666 .4755 L
.80637 .46085 L
.806 .44759 L
.80502 .42382 L
.80362 .39971 L
.80204 .3791 L
.8003 .36081 L
.79549 .32305 L
.79235 .3046 L
.7891 .28889 L
.7824 .26434 L
.77836 .25348 L
.77448 .24529 L
.77009 .23838 L
.76784 .23572 L
.76532 .23341 L
.76137 .23114 L
.75719 .23046 L
.75362 .23125 L
.74973 .23352 L
.74559 .23757 L
.74124 .24368 L
.73725 .25107 L
.73373 .25909 L
.72725 .27805 L
.72089 .30322 L
.71565 .33091 L
.71156 .35942 L
.70946 .37786 L
.70775 .39613 L
.70644 .41332 L
.70531 .43218 L
.7044 .45319 L
.70386 .47313 L
.70368 .48555 L
.7036 .49735 L
.70374 .51966 L
.70415 .53971 L
.7049 .56105 L
.70579 .57936 L
.70703 .59948 L
.71081 .64426 L
.71558 .68537 L
.7227 .73223 L
.73088 .77407 L
.73944 .80917 L
Mistroke
.74958 .84249 L
.7617 .87305 L
.77372 .89496 L
.78065 .90412 L
.78728 .91056 L
.79112 .91327 L
.79466 .91509 L
.79855 .91634 L
.80265 .9168 L
.80922 .91563 L
.81291 .91391 L
.81629 .91164 L
.82244 .90571 L
.82883 .89692 L
.83443 .88682 L
.83951 .87548 L
.85042 .84295 L
.85601 .82099 L
.86094 .79774 L
.86912 .74829 L
.87302 .71772 L
.87616 .68784 L
.87904 .65388 L
.8815 .61597 L
.88295 .58517 L
.88389 .55664 L
.88444 .52933 L
.88464 .5007 L
.88442 .46965 L
.88381 .44136 L
.8827 .41126 L
.88103 .38046 L
.87895 .35225 L
.87621 .32375 L
.87341 .30067 L
.87009 .2785 L
.86681 .26068 L
.86293 .24354 L
.85943 .23105 L
.85553 .21995 L
.85085 .21001 L
.84638 .20356 L
.8436 .20092 L
.84096 .19935 L
.83602 .19874 L
.83129 .20094 L
.82699 .20532 L
.82236 .2126 L
.81763 .223 L
.81381 .23373 L
Mistroke
.8099 .24716 L
.80341 .27605 L
.79986 .29636 L
.79682 .31726 L
.79206 .36021 L
.79011 .38412 L
.78839 .41157 L
.7877 .42574 L
.7871 .44124 L
.78636 .46981 L
.78611 .49722 L
.7863 .52638 L
.78684 .55139 L
.78784 .5787 L
.78865 .59534 L
.78956 .61095 L
.79163 .63979 L
.79439 .67013 L
.79797 .70187 L
.80591 .75506 L
.81477 .79808 L
.82461 .83288 L
.83443 .85739 L
.84012 .86757 L
.84319 .8719 L
.84648 .8757 L
.85259 .8804 L
.8583 .88203 L
.86403 .88096 L
.87018 .87666 L
.87589 .86956 L
.88102 .86042 L
.88555 .84999 L
.89034 .83623 L
.89933 .80132 L
.90443 .7748 L
.90879 .74675 L
.9156 .68751 L
.91857 .65126 L
.92074 .61634 L
.92164 .59769 L
.92245 .57692 L
.9231 .55506 L
.9235 .5345 L
.92377 .49774 L
.92346 .46324 L
.92274 .433 L
.92147 .40109 L
.91957 .36825 L
.91697 .3356 L
Mistroke
.914 .30743 L
.91093 .28436 L
.90772 .26487 L
.90398 .2467 L
.89959 .23017 L
.89527 .21805 L
.89287 .21288 L
.89022 .20834 L
.88531 .20296 L
.88047 .20128 L
.876 .20278 L
.87188 .20675 L
.86808 .21265 L
.86402 .22145 L
.85979 .23355 L
.85581 .24806 L
.85188 .26585 L
.84564 .30343 L
.84258 .32792 L
.84016 .35175 L
.83784 .38087 L
.83611 .40969 L
.83495 .43728 L
.83425 .46332 L
.83391 .49235 L
.83404 .52339 L
.83468 .55464 L
.83526 .57211 L
.83593 .58797 L
.83762 .61833 L
.83967 .64645 L
.8458 .70565 L
.85013 .73614 L
.85467 .762 L
.85914 .78302 L
.86422 .80256 L
.86886 .81703 L
.87405 .82985 L
.87705 .83579 L
.87984 .84034 L
.88537 .84684 L
.88851 .84904 L
.89193 .85022 L
.89517 .85016 L
.89816 .84907 L
.9034 .84471 L
.90823 .83776 L
.91339 .82697 L
.91874 .81167 L
.92376 .79284 L
Mistroke
.92867 .76929 L
.93287 .744 L
.93631 .71856 L
.94176 .66437 L
.94407 .63209 L
.94578 .60046 L
.94694 .57042 L
.94765 .54239 L
.94802 .51151 L
.94795 .47905 L
.94741 .4469 L
.94631 .41345 L
.94479 .38325 L
.94303 .35715 L
.94053 .32868 L
.93731 .30063 L
.93385 .2773 L
.93033 .25866 L
.92662 .24326 L
.92247 .23034 L
.9188 .22205 L
.91466 .2159 L
.91012 .2127 L
.90757 .21245 L
.90525 .21318 L
.90077 .21714 L
.89661 .22389 L
.89283 .23273 L
.88898 .24463 L
.88257 .27204 L
.87936 .2903 L
.8766 .30917 L
.87369 .33342 L
.87136 .3576 L
.86928 .38503 L
.86829 .40133 L
.86753 .41643 L
.86645 .44509 L
.8658 .47633 L
.86566 .50481 L
.86599 .53572 L
.86675 .56474 L
.86785 .59108 L
.86957 .62098 L
.87162 .64796 L
.87432 .67624 L
.87773 .70466 L
.88182 .73195 L
.88614 .75506 L
.89037 .77332 L
Mistroke
.89524 .78998 L
.89989 .8022 L
.90431 .81075 L
.90863 .81645 L
.91325 .81972 L
.91835 .81999 L
.92308 .81705 L
.92819 .81023 L
.93099 .80479 L
.93349 .79883 L
.93838 .78388 L
.94264 .76678 L
.94698 .74453 L
.95113 .7173 L
.95411 .69276 L
.95691 .66422 L
.95944 .63074 L
.96127 .59782 L
.96254 .56476 L
.96325 .5336 L
.96351 .49926 L
.96342 .4802 L
.9632 .46309 L
.96242 .43223 L
.96108 .40014 L
.95936 .37142 L
.95741 .34669 L
.95287 .30543 L
.94986 .28543 L
.94679 .26922 L
.94334 .2548 L
.94002 .24418 L
.93604 .23497 L
.93217 .22932 L
.92821 .22662 L
.92392 .22707 L
.9199 .23061 L
.91629 .23642 L
.91239 .24563 L
.90832 .25885 L
.90432 .27591 L
.90089 .2945 L
.89758 .31704 L
.89482 .3405 L
.89265 .36343 L
.89074 .38908 L
.8899 .4029 L
.88911 .41841 L
.88806 .44635 L
.88766 .46238 L
Mistroke
.88739 .47973 L
.88729 .4962 L
.88732 .51126 L
.88768 .53827 L
.88849 .56669 L
.88952 .59052 L
.89103 .61615 L
.89304 .64253 L
.89566 .66945 L
.89828 .69119 L
.90149 .71311 L
.90818 .74718 L
.91221 .76211 L
.91616 .77344 L
.91999 .7817 L
.92357 .78709 L
.92777 .79074 L
.93176 .79156 L
.93601 .78958 L
.94053 .78414 L
.94469 .77584 L
.94837 .76562 L
.95247 .75057 L
.95664 .7305 L
.96023 .70831 L
.96322 .68514 L
.96615 .65639 L
.96843 .62718 L
.97008 .59953 L
.97139 .56853 L
.97188 .55204 L
.97227 .53379 L
.97249 .51466 L
.97254 .49682 L
.97225 .46514 L
.97138 .43201 L
.97008 .40214 L
.96847 .37595 L
.96627 .34917 L
.9635 .32336 L
.96077 .30349 L
.95795 .28714 L
.95462 .27191 L
.95081 .25884 L
.94747 .25065 L
.94372 .24461 L
.93973 .24156 L
.936 .24169 L
.93251 .24437 L
.92939 .24889 L
Mistroke
.92587 .2565 L
.92267 .26592 L
.91932 .27861 L
.91595 .29479 L
.91058 .32997 L
.90784 .35467 L
.90565 .37996 L
.90405 .40393 L
.90271 .43111 L
.90217 .44649 L
.90178 .46113 L
.90139 .48875 L
.90136 .50434 L
.90145 .51865 L
.90168 .53429 L
.90208 .55067 L
.90308 .57751 L
.90438 .60179 L
.90621 .62737 L
.9086 .65316 L
.91387 .69399 L
.91736 .7136 L
.92086 .72917 L
.92411 .74061 L
.92784 .75072 L
.93189 .75831 L
.93576 .76257 L
.93956 .76396 L
.94318 .76275 L
.9464 .75953 L
.94985 .75373 L
.95348 .74477 L
.95718 .73224 L
.96048 .7177 L
.96327 .70235 L
.96867 .66157 L
.97116 .6349 L
.97306 .60816 L
.9746 .57842 L
.97558 .55034 L
.97593 .53456 L
.97616 .51729 L
.97619 .48585 L
.97581 .45938 L
.97495 .43086 L
.9736 .40228 L
.97192 .37694 L
.97002 .35495 L
.96802 .33634 L
.96536 .31653 L
Mistroke
.96269 .30074 L
.9595 .28588 L
.95586 .27322 L
.95233 .26458 L
.94889 .2592 L
.94481 .25635 L
.94103 .25696 L
.93907 .2585 L
.93692 .26114 L
.93471 .26492 L
.93268 .2694 L
.92874 .28104 L
.9252 .29514 L
.92225 .31013 L
.9193 .32875 L
.91647 .35131 L
.91391 .37764 L
.91197 .40426 L
.91064 .42951 L
.90974 .45433 L
.90926 .47787 L
.90911 .50387 L
.90941 .53159 L
.90974 .54538 L
.91022 .56017 L
.91145 .58638 L
.91305 .61079 L
.91488 .63211 L
.91894 .66684 L
.92165 .68407 L
.92442 .6983 L
.92732 .71031 L
.93054 .7207 L
.93422 .72928 L
.9377 .73444 L
.94163 .73702 L
.94521 .73644 L
.94718 .73491 L
.9493 .73227 L
.95307 .72492 L
.95646 .71505 L
.95987 .7016 L
.96258 .68779 L
.96533 .6703 L
.96819 .64687 L
.97042 .62315 L
.97147 .60922 L
.97248 .59348 L
.97322 .57947 L
.9739 .56362 L
Mistroke
.97472 .53472 L
.97497 .51864 L
.97507 .50347 L
.97491 .47645 L
.97428 .44776 L
.97323 .42124 L
.97192 .39817 L
.97001 .37318 L
.96783 .35148 L
.96318 .31842 L
.96017 .30328 L
.95721 .29177 L
.95382 .28206 L
.95053 .27567 L
.94684 .27169 L
.94474 .27086 L
.94282 .27096 L
.93899 .27364 L
.93686 .27658 L
.9349 .28021 L
.93142 .289 L
.92789 .30129 L
.92443 .31722 L
.92152 .33434 L
.91867 .3555 L
.91611 .38015 L
.91429 .40317 L
.91294 .42568 L
.91233 .43894 L
.91188 .45119 L
.91149 .46547 L
.91124 .47908 L
.91109 .50247 L
.91134 .52713 L
.91186 .54783 L
.91277 .57005 L
.91411 .59288 L
.91597 .61601 L
.91809 .63617 L
.92032 .65296 L
.92294 .66873 L
.92563 .68157 L
.9282 .69125 L
.93112 .69966 L
.93443 .70623 L
.93614 .70847 L
.93803 .7101 L
.94139 .71077 L
.94453 .70882 L
.94763 .70436 L
Mistroke
.9505 .69783 L
.95298 .69011 L
.95556 .67975 L
.95818 .66632 L
.96072 .64971 L
.96271 .63337 L
.96455 .61451 L
.96638 .58994 L
.96766 .5659 L
.9682 .55204 L
.96859 .53889 L
.96888 .52427 L
.96905 .50849 L
.96906 .4948 L
.96894 .47996 L
.9687 .46604 L
.96837 .45331 L
.96747 .42973 L
.96611 .40576 L
.96457 .38539 L
.96258 .36502 L
.95821 .33315 L
.95514 .3173 L
.95198 .30501 L
.94899 .29639 L
.9456 .28968 L
.94387 .28739 L
.94202 .28575 L
.93868 .28481 L
.93509 .28664 L
.93307 .28896 L
.93121 .29194 L
.92793 .29927 L
.92505 .30803 L
.92191 .32044 L
.91914 .33428 L
.91686 .34823 L
.91467 .36448 L
.9114 .39676 L
.90997 .41602 L
.90891 .43475 L
.90805 .4558 L
.90771 .46778 L
.9075 .47882 L
.90733 .50004 L
.90752 .5225 L
.90804 .54325 L
.90878 .56155 L
.90999 .58213 L
.91167 .60302 L
Mistroke
.9136 .62111 L
.91563 .63617 L
.91781 .64901 L
.92035 .66083 L
.92189 .66661 L
.92334 .67124 L
.92475 .67502 L
.92629 .67839 L
.9279 .68113 L
.92941 .683 L
.93123 .68435 L
.93288 .68476 L
.93445 .68443 L
.93613 .68327 L
.93915 .67907 L
.94193 .67259 L
.94437 .66463 L
.94702 .65309 L
.94933 .63999 L
.95287 .61198 L
.9545 .59385 L
.95574 .57586 L
.95678 .55532 L
.95745 .53527 L
.95784 .5127 L
.9579 .49986 L
.95785 .48808 L
.95748 .46576 L
.95712 .45327 L
.95668 .44182 L
.9555 .41929 L
.95383 .39653 L
.95177 .37549 L
.94955 .3579 L
.94679 .34086 L
.94356 .32569 L
.94054 .31507 L
.93758 .30741 L
.93583 .30403 L
.93421 .30159 L
.93232 .29956 L
.93051 .2984 L
.9274 .29814 L
.92412 .3002 L
.92136 .30383 L
.91838 .30975 L
.91531 .31819 L
.91217 .32959 L
.9094 .3424 L
.90708 .35558 L
Mistroke
.90313 .38529 L
.90137 .4033 L
.89998 .42114 L
.89895 .43816 L
.89823 .4542 L
.89768 .47198 L
.89739 .49086 L
.89739 .50965 L
.89752 .52005 L
.89772 .52944 L
.89833 .54721 L
.89915 .56339 L
.9004 .58109 L
.90183 .59631 L
.90366 .61147 L
.90589 .62561 L
.90827 .63708 L
.91063 .64558 L
.91192 .64919 L
.91336 .65249 L
.9149 .65516 L
.91636 .65692 L
.91775 .65793 L
.91908 .65829 L
.92156 .6574 L
.92294 .65601 L
.9242 .65415 L
.92556 .65148 L
.92698 .64794 L
.92916 .64085 L
.93137 .63126 L
.9333 .62045 L
.93491 .60914 L
.9365 .59518 L
.93798 .57837 L
.93862 .56935 L
.93921 .55937 L
.94004 .54063 L
.94053 .52216 L
.94068 .51144 L
.94073 .50132 L
.94058 .4808 L
.94035 .46929 L
.94004 .45884 L
.93927 .44053 L
.93811 .4212 L
.93672 .40377 L
.9352 .38852 L
.93297 .37076 L
.93059 .3558 L
Mistroke
.92821 .34385 L
.92551 .33307 L
.92238 .32357 L
.91936 .31704 L
.91764 .31432 L
.91602 .3124 L
.91422 .31096 L
.91228 .3102 L
.9107 .31017 L
.90902 .3107 L
.90603 .31313 L
.90439 .31526 L
.90288 .31775 L
.89951 .32516 L
.89671 .33347 L
.89428 .34246 L
.89162 .35451 L
.88935 .36704 L
.88591 .39153 L
.88438 .40556 L
.88299 .42115 L
.8818 .43808 L
.88094 .45436 L
.8804 .46908 L
.88004 .485 L
.87993 .50102 L
.88005 .51534 L
.88044 .53138 L
.88105 .54595 L
.88181 .55871 L
.88267 .56985 L
.88378 .58124 L
.88514 .59226 L
.88666 .60205 L
.88846 .61114 L
.89029 .61821 L
.89206 .62335 L
.89409 .62747 L
.89526 .62904 L
.89637 .63001 L
.89755 .63051 L
.89862 .63048 L
.89986 .62988 L
.90102 .62876 L
.90298 .62557 L
.90407 .62306 L
.90507 .62024 L
.90701 .61328 L
.90895 .60392 L
.91058 .59362 L
Mistroke
.91196 .5825 L
.91305 .57151 L
.91405 .55855 L
.91456 .55014 L
.91497 .54194 L
.91554 .52602 L
.91574 .5168 L
.91585 .50819 L
.91588 .49863 L
.91582 .48843 L
.91548 .4714 L
.91492 .45558 L
.91449 .4466 L
.91402 .43851 L
.91274 .42079 L
.91005 .39425 L
.90818 .38048 L
.90623 .36862 L
.90178 .3483 L
.89903 .33917 L
.89638 .33236 L
.89399 .32767 L
.89171 .32437 L
.88917 .32195 L
.88642 .32074 L
.88353 .32099 L
.88082 .32262 L
.87841 .3252 L
.87585 .32916 L
.87308 .33489 L
.87059 .34144 L
.86778 .35063 L
.86536 .36023 L
.86097 .38288 L
.8589 .39678 L
.85719 .41069 L
.85592 .42302 L
.85478 .43644 L
.85397 .44819 L
.85328 .46094 L
.85295 .46877 L
.85272 .47594 L
.85243 .48984 L
.85237 .5022 L
.85251 .51483 L
.85283 .52657 L
.85309 .53295 L
.85338 .53865 L
.85404 .54863 L
.85489 .55844 L
Mistroke
.8567 .57328 L
.8579 .58039 L
.85912 .5861 L
.8606 .59145 L
.86209 .59531 L
.86346 .59773 L
.865 .59923 L
.86588 .59954 L
.86667 .59948 L
.86759 .59901 L
.86845 .59817 L
.86996 .59573 L
.87153 .59174 L
.87284 .58719 L
.87399 .58204 L
.87526 .57485 L
.87631 .56734 L
.87722 .55916 L
.87808 .54941 L
.87881 .53825 L
.87932 .52696 L
.87961 .51689 L
.87978 .50537 L
.87977 .493 L
.87958 .48115 L
.87925 .47002 L
.87882 .45979 L
.87819 .44861 L
.87737 .43698 L
.87629 .42451 L
.87489 .41143 L
.87181 .38932 L
.86819 .37037 L
.86439 .35564 L
.85986 .34305 L
.85714 .33755 L
.85451 .33353 L
.85169 .33048 L
.84907 .32876 L
.84762 .32825 L
.84603 .32803 L
.84453 .32816 L
.84314 .32857 L
.84063 .32998 L
.83795 .33247 L
.83546 .33569 L
.83322 .33938 L
.82913 .34812 L
.82509 .35958 L
.82112 .3741 L
Mistroke
.81784 .38928 L
.81474 .40726 L
.81205 .42747 L
.81001 .44811 L
.80924 .45846 L
.80859 .4697 L
.80819 .47904 L
.80792 .4888 L
.80782 .49767 L
.80784 .50543 L
.8079 .5097 L
.80801 .51411 L
.80829 .52165 L
.80852 .52598 L
.80878 .52987 L
.80934 .53657 L
.81006 .54282 L
.81082 .54777 L
.81173 .55225 L
.81226 .55425 L
.81278 .55587 L
.81368 .55797 L
.81453 .55917 L
.81546 .55968 L
.81599 .55962 L
.81648 .55933 L
.81728 .55837 L
.81814 .55661 L
.81901 .554 L
.81978 .55085 L
.82058 .54658 L
.82134 .54123 L
.82191 .53601 L
.82244 .52965 L
.82289 .52208 L
.82308 .51755 L
.82322 .51326 L
.82331 .50912 L
.82337 .50449 L
.82337 .49574 L
.82324 .48702 L
.823 .4788 L
.82257 .46908 L
.82201 .45969 L
.82066 .44288 L
.81865 .42467 L
.81582 .4054 L
.81213 .38625 L
.80805 .37001 L
.80392 .35717 L
Mistroke
.79878 .345 L
.79372 .33631 L
.79097 .33275 L
.78789 .32963 L
.78632 .32837 L
.78463 .32725 L
.78302 .32641 L
.78155 .32583 L
.77865 .32518 L
.77597 .32516 L
.77457 .32536 L
.77303 .32574 L
.77143 .32632 L
.76993 .32703 L
.7672 .32873 L
.76472 .33072 L
.75927 .33659 L
.75422 .34389 L
.74985 .35168 L
.74093 .37214 L
.73392 .39318 L
.72847 .4133 L
.72007 .45332 L
.71737 .46868 L
.71639 .47397 L
.71602 .47578 L
.71564 .47741 L
.7153 .47861 L
.71499 .47941 L
.71471 .4799 L
.71442 .48012 L
.71426 .48011 L
.71408 .47999 L
.71376 .47949 L
.71343 .47864 L
.71312 .47757 L
.71238 .47427 L
.71142 .46918 L
.70885 .45462 L
.70127 .4179 L
.68953 .37562 L
.67008 .32581 L
.64688 .28346 L
.61658 .24231 L
.57795 .20053 L
.49434 .12073 L
.44154 .07426 L
.40985 .05063 L
.39363 .04066 L
.37828 .03297 L
Mistroke
.37076 .02995 L
.36363 .02758 L
.35967 .02649 L
.35537 .02551 L
.34785 .02431 L
.34381 .02395 L
.33937 .02381 L
.33474 .02395 L
.33041 .02437 L
.32268 .02584 L
.31836 .02709 L
.31443 .02852 L
.30702 .032 L
.30023 .03618 L
.29299 .04175 L
.28512 .04929 L
.27222 .06537 L
.2591 .08745 L
.2466 .11522 L
.23597 .14553 L
.22538 .184 L
.21563 .22994 L
.20844 .27398 L
.20292 .31766 L
.19826 .36772 L
.1963 .39634 L
.19494 .42253 L
.19396 .44883 L
.19341 .47331 L
.1932 .49984 L
.19343 .5278 L
.19372 .5415 L
.19417 .55619 L
.19532 .58215 L
.19684 .60631 L
.1986 .6276 L
.20071 .64809 L
.20298 .66614 L
.20787 .69636 L
.21397 .72337 L
.21772 .73593 L
.22134 .74573 L
.22517 .754 L
.2294 .76089 L
.23348 .76555 L
.23725 .76824 L
.24171 .76953 L
.24423 .76938 L
.24656 .7687 L
.25081 .76609 L
Mistroke
.25293 .76412 L
.25525 .76145 L
.2598 .75464 L
.26384 .74669 L
.26804 .73642 L
.27241 .72325 L
.27915 .69679 L
.28524 .6638 L
.28996 .62791 L
.2921 .60608 L
.2937 .58509 L
.29482 .56609 L
.29571 .54462 L
.29603 .5336 L
.29627 .52162 L
.29644 .49969 L
.29627 .47814 L
.29571 .45439 L
.29482 .43177 L
.29367 .41072 L
.29067 .37094 L
.28628 .32907 L
.27951 .28078 L
.27037 .23153 L
.26011 .18903 L
.24945 .1546 L
.23888 .12813 L
.22651 .10532 L
.22002 .09662 L
.2164 .0927 L
.21294 .08958 L
.20617 .08525 L
.19996 .08337 L
.19388 .08352 L
.18736 .08595 L
.18125 .09048 L
.17574 .09656 L
.16942 .10605 L
.16272 .11937 L
.15121 .15152 L
.14539 .17325 L
.14046 .19539 L
.13556 .22165 L
.13078 .25266 L
.12687 .28361 L
.12374 .31366 L
.12121 .34334 L
.11899 .37614 L
.1174 .40732 L
.11635 .43608 L
Mistroke
.11568 .46508 L
.11541 .49246 L
.11553 .52393 L
.11606 .55247 L
.11708 .5829 L
.11866 .61391 L
.12047 .64006 L
.12282 .66656 L
.12805 .7094 L
.13159 .73086 L
.13566 .75055 L
.13973 .76607 L
.14368 .77792 L
.14813 .78803 L
.15052 .79221 L
.1531 .79579 L
.15748 .79981 L
.16235 .8014 L
.16668 .80036 L
.1713 .79674 L
.17559 .79102 L
.17943 .78391 L
.18403 .77273 L
.18811 .76014 L
.19269 .74257 L
.19655 .7244 L
.20283 .68561 L
.20575 .66188 L
.20812 .63818 L
.20999 .61503 L
.21142 .59265 L
.21257 .56862 L
.21344 .54161 L
.21385 .51782 L
.21393 .4959 L
.21369 .4704 L
.21313 .44619 L
.21214 .41997 L
.21068 .39235 L
.2091 .36905 L
.207 .34379 L
.20101 .28991 L
.19387 .24348 L
.18524 .20181 L
.17615 .16929 L
.17053 .15373 L
.16522 .14182 L
.1622 .13618 L
.15889 .13088 L
.15277 .12352 L
Mistroke
.14675 .11925 L
.14331 .11814 L
.14009 .11799 L
.13669 .11877 L
.1336 .12033 L
.13005 .12315 L
.12672 .12686 L
.12093 .13585 L
.11571 .14697 L
.11019 .16223 L
.10461 .18188 L
.09631 .22119 L
.09216 .24693 L
.08871 .2726 L
.08338 .32431 L
.08123 .35209 L
.07931 .38352 L
.07771 .41946 L
.07677 .45262 L
.07646 .47103 L
.07629 .49098 L
.07643 .52687 L
.07709 .55977 L
.07831 .59347 L
.07977 .62102 L
.0818 .64974 L
.0845 .67892 L
.08742 .70361 L
.09103 .72778 L
.09529 .7499 L
.09969 .7673 L
.10407 .78024 L
.10816 .78896 L
.1127 .79528 L
.11694 .79824 L
.12161 .7984 L
.12646 .79519 L
.13092 .78919 L
.13499 .78104 L
.13859 .77158 L
.14614 .74374 L
.15 .72441 L
.15373 .70131 L
.15933 .65412 L
.16177 .62528 L
.16358 .59685 L
.16441 .58007 L
.16503 .56444 L
.16556 .54703 L
.16593 .52847 L
Mistroke
.16615 .49921 L
.16587 .46775 L
.16514 .43808 L
.16407 .41136 L
.16234 .38041 L
.15988 .3478 L
.15702 .31807 L
.15397 .29222 L
.14704 .24689 L
.14297 .22622 L
.13819 .20605 L
.13351 .18984 L
.12896 .17705 L
.12445 .16696 L
.11952 .15866 L
.11643 .15486 L
.11357 .15226 L
.11042 .15043 L
.10707 .14967 L
.10144 .15116 L
.09827 .15358 L
.09534 .15687 L
.08995 .16571 L
.08518 .17678 L
.0799 .19309 L
.0752 .21187 L
.06661 .25979 L
.06291 .28828 L
.05941 .32249 L
.05692 .35357 L
.05479 .38859 L
.05332 .42272 L
.05245 .4545 L
.05214 .47371 L
.05199 .49418 L
.0522 .5307 L
.05262 .55266 L
.05322 .57296 L
.05391 .59078 L
.05484 .60954 L
.05701 .64285 L
.05991 .67518 L
.06282 .70008 L
.06644 .72422 L
.07033 .7442 L
.07419 .75944 L
.07867 .77245 L
.08101 .77751 L
.08363 .7819 L
.08809 .78645 L
Mistroke
.09062 .78748 L
.09294 .78748 L
.09721 .78511 L
.10164 .7794 L
.10553 .77153 L
.10956 .76039 L
.11318 .74744 L
.1163 .73375 L
.11973 .71547 L
.12312 .69322 L
.12825 .64729 L
.13045 .61949 L
.13209 .5922 L
.13284 .5761 L
.13339 .56115 L
.13388 .54366 L
.1342 .52686 L
.13436 .51057 L
.13437 .49314 L
.134 .46176 L
.13352 .44262 L
.1329 .42474 L
.13128 .3919 L
.12938 .36384 L
.12691 .3354 L
.12137 .28847 L
.11772 .26507 L
.11398 .24532 L
.10953 .22614 L
.10448 .20906 L
.09979 .19701 L
.09723 .19184 L
.09443 .18726 L
.08944 .18179 L
.0847 .17973 L
.082 .17992 L
.07905 .18125 L
.076 .18393 L
.07319 .18759 L
.06825 .19699 L
.06556 .20381 L
.06318 .21097 L
.05892 .22664 L
.0547 .24644 L
.05046 .27171 L
.04698 .29799 L
.04431 .32292 L
.04185 .35151 L
.03967 .3847 L
.03813 .417 L
Mistroke
.03709 .45068 L
.0366 .48222 L
.03659 .51675 L
.0368 .53402 L
.03718 .55285 L
.0382 .58345 L
.0398 .615 L
.04176 .64298 L
.04392 .66684 L
.04882 .7061 L
.05202 .72474 L
.05524 .73953 L
.05884 .75237 L
.06226 .76146 L
.06634 .76882 L
.07027 .77269 L
.07427 .77355 L
.07855 .77116 L
.08253 .76582 L
.08609 .75843 L
.0901 .74689 L
.09424 .73095 L
.09787 .71292 L
.10096 .69385 L
.10407 .66995 L
.10661 .64539 L
.10854 .62189 L
.11024 .5952 L
.11102 .57963 L
.11161 .56484 L
.1121 .5492 L
.11248 .53183 L
.11276 .50285 L
.11254 .47167 L
.11187 .44264 L
.11085 .41621 L
.10929 .38797 L
.10715 .35917 L
.1025 .31456 L
.09932 .29177 L
.09602 .27241 L
.09279 .25681 L
.08918 .2425 L
.08591 .23199 L
.08228 .22279 L
.07824 .21531 L
.07441 .21076 L
.06979 .20844 L
.06559 .20934 L
.0612 .2134 L
Mistroke
.05718 .2201 L
.05289 .23065 L
.04851 .24561 L
.04422 .26512 L
.04049 .28704 L
.03744 .30958 L
.03459 .33603 L
.0323 .36315 L
.03058 .38909 L
.02923 .41622 L
.02831 .44243 L
.02766 .47362 L
.02749 .50241 L
.02777 .53375 L
.02859 .56605 L
.02994 .59752 L
.03161 .62463 L
.03403 .65364 L
.03676 .67844 L
.03963 .69875 L
.04253 .71511 L
.04596 .73021 L
.04982 .74282 L
.05387 .75182 L
.05621 .75526 L
.05836 .75738 L
.06237 .75872 L
.06658 .75661 L
.0688 .75403 L
.07114 .75021 L
.07525 .74061 L
.07767 .73309 L
.07987 .7249 L
.08377 .70693 L
.0867 .68984 L
.08954 .66937 L
.09172 .65009 L
.09379 .62765 L
.09578 .59977 L
.0972 .57207 L
.09813 .54426 L
.0986 .51804 L
.09866 .49043 L
.09833 .46457 L
.09754 .43657 L
.0969 .42111 L
.09619 .40716 L
.09452 .38151 L
.09226 .35489 L
.08942 .32913 L
Mistroke
.08638 .30734 L
.08342 .29021 L
.07995 .27396 L
.07646 .26105 L
.07307 .25137 L
.06992 .2446 L
.06637 .23937 L
.0626 .23648 L
.05905 .23621 L
.05494 .23892 L
.05109 .24451 L
.04772 .25202 L
.04419 .26284 L
.04055 .27755 L
.03696 .29647 L
.03141 .33807 L
.02904 .36315 L
.02692 .39276 L
.02605 .40837 L
.02527 .42549 L
.02469 .44196 L
.02428 .45715 L
.02384 .48655 L
.02389 .51853 L
.02442 .5483 L
.02532 .57506 L
.02599 .58942 L
.02684 .60446 L
.0287 .63033 L
.03141 .65843 L
.03434 .6812 L
.03759 .70051 L
.04148 .71778 L
.04355 .72488 L
.04583 .73124 L
.04804 .73606 L
.05008 .73943 L
.05395 .74316 L
.05592 .74377 L
.05808 .74348 L
.06189 .7405 L
.06538 .73496 L
.06745 .73036 L
.06937 .72516 L
.07284 .7133 L
.07634 .69765 L
.07982 .67751 L
.08253 .65764 L
.08477 .63723 L
.08696 .61196 L
Mistroke
.08854 .58778 L
.08968 .56396 L
.09041 .54155 L
.09085 .5166 L
.0909 .49016 L
.09055 .46447 L
.09017 .45014 L
.08971 .43709 L
.08859 .41367 L
.08704 .38985 L
.08533 .36967 L
.08348 .35189 L
.07845 .31626 L
.07524 .29995 L
.07196 .28696 L
.06885 .27754 L
.06533 .26982 L
.06328 .26668 L
.0614 .26464 L
.05922 .26323 L
.05715 .26286 L
.05348 .26451 L
.04957 .26964 L
.04626 .27689 L
.04328 .28596 L
.04018 .29837 L
.03707 .31441 L
.03412 .33403 L
.03165 .35502 L
.02972 .37561 L
.02798 .39961 L
.02678 .4214 L
.0258 .44634 L
.02518 .47306 L
.02497 .49843 L
.02511 .52202 L
.02551 .5434 L
.02626 .56637 L
.02738 .58973 L
.02898 .61403 L
.03113 .63847 L
.03352 .65939 L
.03602 .67657 L
.03868 .69123 L
.04136 .70291 L
.0443 .71288 L
.04769 .72114 L
.05144 .72682 L
.05507 .7291 L
.05835 .7286 L
Mistroke
.06188 .72534 L
.06387 .72226 L
.06563 .71873 L
.06948 .70835 L
.07285 .69585 L
.07581 .68175 L
.08056 .65106 L
.0826 .63347 L
.08454 .61283 L
.08593 .59424 L
.08714 .57356 L
.088 .5535 L
.08855 .53491 L
.0889 .51136 L
.08891 .48959 L
.08856 .46594 L
.08779 .4414 L
.08679 .42085 L
.08559 .40236 L
.08399 .38314 L
.08196 .36391 L
.07729 .33229 L
.07429 .31795 L
.07138 .30726 L
.06852 .2994 L
.06532 .29333 L
.06222 .29003 L
.05934 .28914 L
.05598 .29072 L
.05289 .29477 L
.04959 .30204 L
.04779 .30739 L
.0462 .31305 L
.04316 .32659 L
.04014 .34445 L
.03762 .36402 L
.0356 .38422 L
.03398 .40512 L
.03261 .42911 L
.03168 .4528 L
.03117 .47514 L
.03097 .50023 L
.03104 .51448 L
.03121 .52769 L
.03152 .54156 L
.03191 .55401 L
.03247 .56814 L
.03313 .58118 L
.03469 .605 L
.03677 .62844 L
Mistroke
.03886 .64669 L
.04146 .66466 L
.04456 .68117 L
.04639 .68896 L
.0482 .69547 L
.04992 .70069 L
.05185 .70548 L
.05532 .71159 L
.05707 .71352 L
.05894 .71477 L
.06229 .715 L
.06587 .71242 L
.06788 .70968 L
.06972 .70632 L
.07298 .69832 L
.07582 .68898 L
.07891 .67595 L
.08162 .66158 L
.08384 .64719 L
.08596 .63052 L
.08909 .59765 L
.09043 .57814 L
.09141 .55924 L
.09218 .53808 L
.09246 .52606 L
.09262 .51503 L
.09269 .4938 L
.0924 .47141 L
.09179 .45081 L
.09096 .43272 L
.08966 .41244 L
.08788 .39196 L
.08588 .37433 L
.08377 .35978 L
.08153 .34744 L
.07894 .33623 L
.07737 .33081 L
.0759 .32654 L
.07292 .3201 L
.0713 .31775 L
.06978 .31625 L
.0681 .31537 L
.06631 .31533 L
.0646 .31615 L
.063 .31769 L
.06007 .32256 L
.05748 .32923 L
.05484 .33865 L
.05249 .34962 L
.05052 .36125 L
Mistroke
.04841 .37678 L
.04643 .39569 L
.04487 .41524 L
.04372 .43452 L
.04286 .45533 L
.04235 .47547 L
.04214 .49799 L
.04218 .51072 L
.04231 .52235 L
.04288 .54542 L
.04336 .55825 L
.04392 .56994 L
.0452 .59065 L
.04693 .61146 L
.04884 .62943 L
.05084 .64453 L
.05323 .65906 L
.0561 .67278 L
.05878 .68269 L
.0614 .69014 L
.06427 .69607 L
.06742 .70018 L
.07031 .70187 L
.07347 .70157 L
.07644 .69925 L
.07914 .6954 L
.08151 .6906 L
.08406 .68389 L
.08888 .66606 L
.09135 .65381 L
.09347 .64113 L
.09575 .62464 L
.09756 .60849 L
.09909 .59178 L
.10045 .57287 L
.10107 .56222 L
.10155 .55228 L
.10225 .53248 L
.10259 .51556 L
.10269 .49979 L
.10256 .4827 L
.10215 .46475 L
.10143 .44664 L
.10048 .43025 L
.09942 .41635 L
.09805 .4022 L
.09615 .38689 L
.09412 .37424 L
.09213 .36448 L
.08983 .35576 L
Mistroke
.08717 .34854 L
.08578 .34586 L
.08424 .34367 L
.08291 .34244 L
.08147 .34177 L
.07888 .34231 L
.0763 .3451 L
.07488 .34766 L
.07358 .35065 L
.07128 .35768 L
.06898 .36725 L
.06707 .37752 L
.06543 .38855 L
.06381 .40214 L
.06233 .41814 L
.06114 .43521 L
.0603 .45164 L
.05971 .46885 L
.05939 .48556 L
.05932 .50541 L
.05954 .52381 L
.0601 .54386 L
.0605 .55383 L
.06105 .56461 L
.06233 .58423 L
.06378 .60124 L
.06578 .61954 L
.06797 .63533 L
.07247 .65897 L
.0753 .66957 L
.07808 .67747 L
.08075 .6831 L
.08373 .68729 L
.08658 .68943 L
.08922 .68985 L
.0916 .68897 L
.09419 .68666 L
.09686 .68279 L
.09928 .6779 L
.10203 .67064 L
.10452 .66237 L
.1088 .64356 L
.11276 .6192 L
.11466 .60394 L
.11617 .5891 L
.11746 .57351 L
.11845 .5583 L
.11915 .54445 L
.11969 .52924 L
.12003 .5128 L
Mistroke
.1201 .50369 L
.1201 .49551 L
.1199 .47987 L
.1195 .4656 L
.11893 .45271 L
.11813 .43975 L
.1173 .42933 L
.11624 .41864 L
.11495 .4081 L
.11339 .39804 L
.11191 .39036 L
.11022 .38343 L
.10924 .38013 L
.10812 .37699 L
.10609 .37275 L
.10492 .37112 L
.10365 .36997 L
.10244 .36948 L
.10133 .36954 L
.09931 .3709 L
.09818 .3724 L
.09714 .37425 L
.0951 .37934 L
.094 .38296 L
.09303 .38671 L
.09139 .39447 L
.08979 .4041 L
.08822 .41621 L
.08697 .42869 L
.086 .4413 L
.08527 .45384 L
.08467 .46831 L
.08428 .4845 L
.08418 .4933 L
.08416 .50167 L
.08431 .51746 L
.08474 .53452 L
.0851 .54407 L
.08552 .55276 L
.08638 .56711 L
.08756 .58235 L
.09065 .61088 L
.09282 .62563 L
.09503 .63774 L
.09761 .64924 L
.10064 .65975 L
.10361 .66753 L
.10646 .673 L
.10925 .67666 L
.11069 .67792 L
Mistroke
.11227 .67885 L
.11517 .67932 L
.11663 .67897 L
.11821 .67815 L
.121 .67559 L
.12354 .67197 L
.12648 .66622 L
.12905 .65971 L
.13437 .64108 L
.13839 .62115 L
.142 .59654 L
.14338 .58448 L
.14463 .57135 L
.1456 .55891 L
.14634 .54727 L
.14697 .53425 L
.14722 .5274 L
.14743 .52016 L
.14763 .50817 L
.14766 .49523 L
.14751 .48412 L
.14718 .4726 L
.14671 .46226 L
.14614 .45328 L
.14534 .44351 L
.14446 .43515 L
.14336 .42688 L
.14206 .41917 L
.14055 .41241 L
.13903 .40736 L
.1376 .40397 L
.136 .40156 L
.13457 .40055 L
.13322 .40056 L
.13175 .40164 L
.1302 .40404 L
.12862 .40791 L
.1272 .41282 L
.12599 .41824 L
.12478 .42517 L
.12288 .44023 L
.12201 .44992 L
.12137 .4594 L
.12089 .4688 L
.12052 .47947 L
.12031 .48994 L
.12024 .49984 L
.12034 .51286 L
.12064 .52538 L
.12106 .53667 L
Mistroke
.1217 .54892 L
.12259 .56208 L
.12378 .57574 L
.12647 .59897 L
.12956 .61834 L
.13293 .63427 L
.13707 .64881 L
.13957 .65552 L
.14195 .66068 L
.14445 .66496 L
.14718 .66841 L
.1498 .6706 L
.1522 .6717 L
.15504 .67191 L
.15664 .67153 L
.15811 .67086 L
.1608 .66886 L
.16359 .6657 L
.16621 .6617 L
.16895 .65643 L
.17362 .64454 L
.17864 .62703 L
.18262 .60855 L
.18578 .5895 L
.18811 .57148 L
.18918 .56135 L
.19015 .5504 L
.19083 .54101 L
.19142 .53086 L
.19183 .52162 L
.19207 .51323 L
.19221 .50466 L
.19221 .49588 L
.19209 .48813 L
.19187 .48121 L
.1916 .47536 L
.19121 .46945 L
.19066 .46308 L
.19005 .45776 L
.1893 .45267 L
.1884 .44814 L
.18792 .44625 L
.18738 .44448 L
.1869 .44317 L
.18636 .44204 L
.18583 .4412 L
.18534 .44068 L
.18437 .44031 L
.1834 .44081 L
.18252 .44205 L
Mistroke
.18158 .44425 L
.18112 .44568 L
.18064 .44751 L
.17986 .45116 L
.17909 .45584 L
.17845 .46098 L
.17793 .46622 L
.17747 .47232 L
.17712 .47853 L
.17685 .48584 L
.17668 .49423 L
.17666 .50302 L
.1767 .50759 L
.17679 .51269 L
.17707 .52196 L
.17747 .53079 L
.178 .53989 L
.17864 .54856 L
.18016 .56481 L
.18228 .58201 L
.18514 .59988 L
.18858 .61671 L
.19295 .63328 L
.19809 .64795 L
.20334 .65893 L
.20598 .66319 L
.20854 .66663 L
.21091 .66923 L
.21348 .67145 L
.21628 .67323 L
.21891 .67431 L
.22052 .67469 L
.22205 .67487 L
.22489 .67474 L
.22748 .67411 L
.23024 .67291 L
.23282 .67129 L
.23514 .66944 L
.24071 .66348 L
.24578 .65619 L
.25506 .63796 L
.26371 .61461 L
.27505 .57165 L
.28123 .53962 L
.28321 .52832 L
.28402 .52422 L
.28442 .52254 L
.28476 .52134 L
.28505 .52058 L
.28535 .52006 L
Mistroke
.28568 .51987 L
.28598 .52003 L
.28625 .52045 L
.28656 .52121 L
.28686 .5222 L
.28715 .52336 L
.29177 .54853 L
.30033 .58855 L
.313 .63188 L
.33226 .67902 L
.34578 .70444 L
.36021 .72719 L
.39121 .76671 L
.46256 .83877 L
.50918 .88249 L
.55832 .92559 L
.59759 .95413 L
.60876 .96064 L
.6207 .96656 L
.63101 .97067 L
.63645 .97243 L
.64238 .97399 L
.64893 .97526 L
.65514 .97597 L
.66118 .97619 L
.66676 .97594 L
.67279 .97515 L
.67941 .97361 L
.68629 .9712 L
.6927 .96817 L
.70425 .96055 L
.71462 .95103 L
.72628 .93682 L
.73698 .91991 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.35119 0.97619 0.64881 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.500019 0.221793 0.5 0.443828 [
[.5 1.0125 -3.5 0 ]
[.5 1.0125 3.5 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -64.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.000 15.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
.82219 .53302 m
.82264 .52685 L
.82296 .52078 L
.82323 .51329 L
.82337 .50577 L
.8234 .49848 L
.82334 .4915 L
.82316 .4836 L
.82286 .47501 L
.82242 .46622 L
.82181 .45664 L
.82031 .4392 L
.81788 .41875 L
.81505 .40084 L
.81159 .38378 L
.80792 .36946 L
.80342 .35576 L
.79818 .34376 L
.79566 .33923 L
.79285 .33504 L
.79031 .33195 L
.78759 .32931 L
.7851 .32748 L
.78234 .32606 L
.77982 .3253 L
.77745 .32504 L
.77598 .3251 L
.77443 .32533 L
.77164 .32618 L
.7701 .32688 L
.76866 .3277 L
.76541 .33006 L
.76011 .3355 L
.75462 .34319 L
.7451 .36172 L
.73752 .38173 L
.72479 .42923 L
.7207 .44979 L
.71765 .46707 L
.71668 .47248 L
.7158 .47678 L
.71544 .47818 L
.71525 .47879 L
.71508 .47926 L
.71478 .47986 L
.71446 .48016 L
.71416 .48011 L
.71387 .47974 L
.7136 .47916 L
.71329 .47824 L
Mistroke
.71255 .47516 L
.71176 .47108 L
.70579 .43859 L
.69507 .39388 L
.6787 .34565 L
.66683 .31897 L
.65429 .29556 L
.59665 .21983 L
.52066 .14528 L
.46856 .0973 L
.41533 .05435 L
.38749 .03735 L
.3797 .0336 L
.37137 .03017 L
.36412 .02772 L
.35628 .0257 L
.34892 .02444 L
.34217 .02387 L
.33571 .0239 L
.32892 .02458 L
.32147 .02616 L
.31457 .02847 L
.30705 .03199 L
.2991 .03698 L
.29084 .04366 L
.28335 .0512 L
.26699 .07342 L
.25335 .0993 L
.23998 .13328 L
.22908 .16945 L
.22 .20784 L
.21139 .25456 L
.20389 .3091 L
.19857 .3638 L
.19656 .39212 L
.19562 .40854 L
.19489 .42363 L
.19392 .45039 L
.19333 .47905 L
.19321 .50397 L
.19347 .52973 L
.1942 .55698 L
.19481 .57181 L
.19548 .58499 L
.1971 .60971 L
.199 .63182 L
.20164 .65589 L
.20446 .67632 L
.2079 .69648 L
.21198 .71557 L
Mistroke
.21553 .7289 L
.21895 .73947 L
.22257 .74859 L
.22604 .75558 L
.23017 .76191 L
.23239 .76448 L
.23478 .76664 L
.23924 .76905 L
.2433 .76951 L
.24552 .76906 L
.24787 .76808 L
.25203 .76501 L
.25644 .75988 L
.26116 .75217 L
.26511 .74381 L
.26919 .73321 L
.27603 .71007 L
.28242 .68044 L
.28548 .66222 L
.28805 .64397 L
.29181 .60936 L
.29338 .58986 L
.29471 .5681 L
.29527 .55643 L
.29569 .54542 L
.29604 .53318 L
.2963 .51994 L
.29643 .50584 L
.29642 .49239 L
.2963 .48022 L
.29606 .46694 L
.29574 .45532 L
.29529 .44249 L
.29402 .41644 L
.29242 .39226 L
.29056 .36969 L
.28546 .32237 L
.27919 .2788 L
.26389 .20343 L
.2535 .1667 L
.24287 .13732 L
.23027 .11138 L
.2229 .1002 L
.21606 .09236 L
.20975 .08725 L
.20381 .0843 L
.19725 .0832 L
.19358 .08358 L
.19025 .08458 L
.18355 .08851 L
Mistroke
.17981 .09188 L
.17638 .09575 L
.17018 .10476 L
.16378 .11701 L
.15312 .14526 L
.14396 .17929 L
.1351 .22442 L
.12718 .2809 L
.12362 .31488 L
.12087 .34788 L
.11847 .38528 L
.11743 .40657 L
.11667 .42604 L
.11574 .46192 L
.11547 .4821 L
.1154 .50058 L
.11568 .53413 L
.11654 .56865 L
.1178 .59846 L
.11964 .62893 L
.12182 .65603 L
.12415 .67913 L
.12727 .70403 L
.13111 .72823 L
.13512 .7482 L
.13908 .76381 L
.14298 .77602 L
.14726 .7863 L
.15169 .79394 L
.15665 .79924 L
.161 .80125 L
.16567 .8008 L
.17004 .79798 L
.17397 .79344 L
.17637 .78973 L
.17888 .78505 L
.18325 .77484 L
.18776 .76133 L
.19244 .74367 L
.19619 .72625 L
.19989 .70546 L
.20561 .66312 L
.20828 .63644 L
.21031 .61041 L
.21204 .58062 L
.21277 .56352 L
.21328 .54779 L
.21363 .53254 L
.21384 .51838 L
.21393 .50273 L
Mistroke
.21388 .48611 L
.21344 .45799 L
.213 .44201 L
.21245 .42713 L
.211 .39766 L
.20918 .37011 L
.20462 .32001 L
.19812 .2694 L
.18933 .22001 L
.18043 .18338 L
.17536 .16689 L
.16975 .15183 L
.16464 .14067 L
.15888 .13087 L
.15352 .12426 L
.14848 .12018 L
.14533 .11868 L
.14191 .11797 L
.1357 .11918 L
.1297 .1235 L
.12426 .13027 L
.1185 .14065 L
.11239 .15569 L
.10632 .17537 L
.101 .1973 L
.09619 .22189 L
.09144 .25192 L
.08772 .28093 L
.08429 .31404 L
.08171 .34542 L
.07942 .38154 L
.07787 .41531 L
.07688 .44753 L
.07653 .46574 L
.07632 .48566 L
.07628 .50636 L
.07642 .52548 L
.07707 .55915 L
.07833 .59394 L
.07929 .61282 L
.08053 .63263 L
.08327 .66646 L
.0865 .69638 L
.08993 .72102 L
.09361 .74187 L
.09739 .75881 L
.10098 .77154 L
.10508 .78268 L
.10968 .79145 L
.1123 .79486 L
Mistroke
.1147 .79702 L
.11942 .79872 L
.12386 .79734 L
.128 .79345 L
.1323 .78671 L
.13588 .77891 L
.13968 .76826 L
.14359 .75449 L
.14753 .73725 L
.15387 .70031 L
.15716 .67469 L
.15979 .64915 L
.16219 .61938 L
.1632 .60356 L
.16413 .58612 L
.1653 .55627 L
.16595 .52759 L
.16612 .51078 L
.16613 .49298 L
.16575 .46104 L
.16495 .43258 L
.16363 .40248 L
.16195 .3746 L
.16006 .34988 L
.15741 .32175 L
.15404 .29272 L
.14668 .24493 L
.13844 .20699 L
.13335 .18936 L
.12847 .17583 L
.12376 .16563 L
.11848 .15727 L
.1134 .15213 L
.10864 .14988 L
.10571 .14971 L
.10256 .15059 L
.09689 .15501 L
.09146 .16284 L
.08661 .17311 L
.08154 .18754 L
.07628 .20717 L
.07118 .23172 L
.06686 .25807 L
.06306 .28699 L
.05951 .32131 L
.05675 .35602 L
.05474 .38964 L
.05339 .42082 L
.05242 .45578 L
.052 .49248 L
Mistroke
.05215 .5266 L
.05245 .54528 L
.05297 .56535 L
.05363 .58392 L
.05438 .60075 L
.05617 .63124 L
.05858 .66157 L
.06203 .69387 L
.06582 .72047 L
.0696 .74085 L
.07404 .75892 L
.07822 .77135 L
.08218 .77964 L
.08688 .78556 L
.09139 .78758 L
.09555 .78639 L
.09938 .78273 L
.1035 .77599 L
.10774 .76581 L
.1118 .75273 L
.11592 .73557 L
.12255 .69729 L
.12581 .67143 L
.12873 .64174 L
.13077 .61471 L
.1325 .58371 L
.13316 .56784 L
.13371 .55036 L
.13409 .53364 L
.1343 .5181 L
.13435 .48844 L
.1339 .45699 L
.13347 .4408 L
.13285 .42354 L
.13133 .39284 L
.12888 .35756 L
.12605 .32688 L
.11977 .27764 L
.11556 .25323 L
.11128 .23321 L
.10697 .21691 L
.10269 .20404 L
.10024 .19801 L
.09754 .19242 L
.09274 .18502 L
.08772 .1807 L
.0831 .17972 L
.07779 .18221 L
.07282 .18816 L
.06834 .19677 L
Mistroke
.06433 .20736 L
.06012 .22183 L
.0559 .24032 L
.05199 .26186 L
.04818 .28821 L
.04527 .31334 L
.04253 .34298 L
.04005 .37805 L
.03897 .39794 L
.03814 .4168 L
.03707 .45126 L
.03672 .47075 L
.03656 .48846 L
.03666 .52451 L
.03695 .54242 L
.03743 .56182 L
.03872 .59507 L
.04041 .62457 L
.04296 .65687 L
.04577 .68358 L
.04953 .71063 L
.05354 .73216 L
.0573 .74733 L
.06153 .75975 L
.06568 .76788 L
.06953 .77219 L
.07412 .77357 L
.07671 .7726 L
.07907 .77063 L
.08335 .76435 L
.08546 .75992 L
.08773 .75414 L
.09187 .74062 L
.09546 .72532 L
.09911 .70569 L
.1026 .68194 L
.10509 .66077 L
.10741 .63631 L
.1095 .60777 L
.11101 .57973 L
.11201 .55237 L
.11263 .52185 L
.11274 .49271 L
.11244 .46564 L
.11175 .43907 L
.1108 .41535 L
.10933 .38864 L
.10758 .36436 L
.10233 .31323 L
.0991 .29034 L
Mistroke
.09514 .26787 L
.09146 .25116 L
.08725 .23602 L
.08307 .22457 L
.07912 .2167 L
.07668 .21316 L
.07405 .21045 L
.06929 .2084 L
.06665 .20884 L
.06417 .21029 L
.06147 .21305 L
.0586 .21739 L
.05631 .22194 L
.05385 .22796 L
.04908 .24338 L
.04495 .2614 L
.0414 .28122 L
.03803 .30482 L
.03492 .33269 L
.03265 .3585 L
.03061 .38866 L
.02969 .40592 L
.02897 .42264 L
.02831 .44222 L
.02788 .46031 L
.0275 .49327 L
.02753 .51189 L
.0277 .52903 L
.02845 .56199 L
.02965 .59188 L
.03112 .61745 L
.03309 .64338 L
.03568 .66936 L
.03885 .6937 L
.04187 .7117 L
.04546 .72827 L
.0492 .74106 L
.05289 .75 L
.0563 .75537 L
.06007 .75836 L
.0642 .75825 L
.06627 .75688 L
.06854 .75439 L
.07248 .74749 L
.07606 .73825 L
.07931 .72711 L
.08255 .71309 L
.08776 .68268 L
.0903 .6631 L
.09238 .64345 L
Mistroke
.09433 .62086 L
.09607 .59468 L
.09739 .56717 L
.09792 .55177 L
.09829 .53722 L
.09865 .51091 L
.0986 .48256 L
.09837 .46672 L
.09797 .44961 L
.09743 .43363 L
.0968 .41905 L
.09528 .39222 L
.09319 .36504 L
.09101 .34281 L
.0883 .32058 L
.08255 .28578 L
.0788 .26935 L
.07457 .25534 L
.07079 .24626 L
.06651 .23953 L
.06233 .23638 L
.05836 .23644 L
.05481 .23906 L
.05102 .24465 L
.047 .25396 L
.04504 .25991 L
.04295 .26741 L
.03938 .28322 L
.03635 .30023 L
.03122 .33984 L
.02891 .36478 L
.02708 .39012 L
.02575 .41458 L
.02481 .43802 L
.02413 .4643 L
.02381 .49261 L
.02393 .5227 L
.02421 .5396 L
.02461 .55514 L
.02517 .57127 L
.0258 .58564 L
.02763 .61652 L
.02962 .64093 L
.0322 .66512 L
.03498 .68539 L
.03782 .70169 L
.04135 .7173 L
.04488 .72876 L
.04697 .73388 L
.04893 .73765 L
Mistroke
.05111 .74075 L
.05342 .74285 L
.05555 .74372 L
.05782 .74356 L
.06189 .7405 L
.06434 .7369 L
.06661 .73235 L
.07073 .72092 L
.07392 .70891 L
.0772 .69315 L
.08013 .67546 L
.08295 .65417 L
.08523 .63242 L
.08701 .61121 L
.08848 .58885 L
.08956 .56687 L
.09042 .54081 L
.09072 .52605 L
.09088 .51263 L
.09087 .48642 L
.09049 .46196 L
.09011 .44819 L
.08958 .43387 L
.08832 .40893 L
.08653 .38334 L
.08407 .3572 L
.08151 .33613 L
.07885 .3186 L
.07563 .30175 L
.07194 .2869 L
.06854 .27675 L
.06524 .26967 L
.06151 .26473 L
.05939 .2633 L
.05744 .26285 L
.05388 .26418 L
.0506 .26793 L
.04709 .2748 L
.04348 .28525 L
.04023 .29812 L
.03737 .31271 L
.03266 .34583 L
.03044 .36735 L
.02841 .393 L
.02755 .4066 L
.02677 .4216 L
.0257 .44953 L
.02511 .47808 L
.02498 .5054 L
.02522 .5298 L
Mistroke
.02588 .5559 L
.02703 .5833 L
.02789 .59831 L
.02882 .61192 L
.03105 .63765 L
.03393 .66249 L
.03684 .68149 L
.04023 .69831 L
.04333 .7099 L
.04691 .71952 L
.05065 .72591 L
.05416 .72882 L
.05602 .7292 L
.05805 .72874 L
.06017 .72727 L
.06213 .725 L
.06568 .71862 L
.06882 .71041 L
.07226 .69825 L
.07533 .68426 L
.07785 .66994 L
.08031 .65297 L
.08403 .61866 L
.08583 .59571 L
.08716 .57309 L
.08804 .55217 L
.08867 .52915 L
.08894 .50385 L
.08882 .48032 L
.08858 .46695 L
.08826 .45491 L
.08778 .44122 L
.0872 .42853 L
.08571 .40409 L
.08396 .38287 L
.08165 .36142 L
.07881 .34112 L
.0763 .32715 L
.07339 .31432 L
.07047 .30448 L
.06767 .29751 L
.06447 .29219 L
.06263 .29033 L
.0609 .28937 L
.0574 .2897 L
.05546 .29123 L
.05371 .29345 L
.0506 .29945 L
.0478 .30735 L
.04488 .31846 L
Mistroke
.04196 .33312 L
.03919 .35127 L
.03687 .37087 L
.03509 .39022 L
.03348 .41287 L
.03241 .43345 L
.03156 .45706 L
.03107 .48236 L
.03098 .5064 L
.03123 .5287 L
.03173 .5489 L
.03258 .57053 L
.03381 .59246 L
.03553 .61527 L
.03741 .63452 L
.03993 .65463 L
.04261 .6713 L
.04531 .68452 L
.04797 .69472 L
.05104 .7036 L
.05442 .7103 L
.0579 .71417 L
.05988 .71509 L
.06169 .71514 L
.06519 .71313 L
.06846 .7087 L
.07027 .70517 L
.07215 .70062 L
.07542 .69045 L
.07905 .67529 L
.08206 .65892 L
.08631 .62744 L
.08828 .60749 L
.08981 .5878 L
.09109 .56617 L
.09193 .54592 L
.09227 .53458 L
.09252 .52219 L
.0927 .49966 L
.09257 .48062 L
.0921 .46 L
.09129 .43912 L
.09022 .42036 L
.08897 .40378 L
.08763 .38949 L
.08397 .36101 L
.08172 .34838 L
.07913 .33695 L
.07652 .32824 L
.07404 .32219 L
Mistroke
.07104 .31745 L
.06932 .31593 L
.06773 .31529 L
.06479 .31602 L
.06332 .31732 L
.06172 .31949 L
.0601 .3225 L
.05858 .3261 L
.05584 .33473 L
.05307 .34667 L
.05031 .36263 L
.04817 .3788 L
.04621 .39809 L
.04468 .41797 L
.04359 .43713 L
.04279 .45764 L
.04232 .47734 L
.04214 .49934 L
.04232 .52299 L
.04257 .53481 L
.04295 .54753 L
.04393 .57013 L
.04524 .59121 L
.04675 .60962 L
.05014 .6396 L
.05241 .65444 L
.05474 .6667 L
.05718 .67708 L
.05989 .68611 L
.063 .69373 L
.06595 .69856 L
.06928 .70149 L
.07233 .70193 L
.07402 .70128 L
.07584 .69987 L
.0791 .69548 L
.08207 .68928 L
.08509 .68066 L
.08755 .67173 L
.09009 .66037 L
.09511 .6296 L
.09743 .60975 L
.0992 .59039 L
.10053 .57158 L
.10111 .56141 L
.10162 .55048 L
.10199 .54087 L
.10231 .53021 L
.10263 .51139 L
.10266 .49294 L
Mistroke
.10244 .47605 L
.10192 .45801 L
.10151 .44821 L
.10105 .43952 L
.09994 .42269 L
.09842 .40574 L
.09673 .39119 L
.09497 .37916 L
.09333 .37007 L
.09144 .36158 L
.08924 .3539 L
.08708 .34835 L
.08458 .34409 L
.08216 .34201 L
.07998 .34181 L
.0776 .34341 L
.07625 .34517 L
.07482 .34778 L
.07349 .35089 L
.07229 .35431 L
.07011 .36221 L
.06795 .3725 L
.06583 .38567 L
.06407 .39974 L
.06243 .41695 L
.06165 .42724 L
.06102 .43714 L
.06014 .45558 L
.0598 .46565 L
.05953 .47654 L
.05931 .49515 L
.05932 .50586 L
.05941 .51594 L
.05979 .53458 L
.0604 .55144 L
.06133 .56952 L
.0626 .58782 L
.06412 .60468 L
.06605 .62169 L
.06798 .63542 L
.07024 .64849 L
.07245 .65888 L
.07503 .66868 L
.0775 .67603 L
.0799 .68151 L
.08299 .68645 L
.08599 .68914 L
.0887 .68989 L
.09165 .68894 L
.09332 .68759 L
Mistroke
.09482 .68588 L
.09653 .68334 L
.09812 .68041 L
.10087 .67391 L
.10372 .66519 L
.10815 .64684 L
.11233 .62227 L
.11413 .60844 L
.11582 .5928 L
.11706 .57872 L
.11817 .563 L
.11903 .54703 L
.1196 .53215 L
.11995 .51793 L
.1201 .50298 L
.12006 .48983 L
.11986 .47777 L
.11947 .46492 L
.11887 .45163 L
.11792 .43698 L
.11686 .42462 L
.11541 .41161 L
.11384 .40072 L
.11235 .39247 L
.11065 .38502 L
.10867 .37845 L
.10676 .37394 L
.10462 .37079 L
.10341 .36983 L
.1023 .36946 L
.10014 .37015 L
.09811 .3725 L
.09699 .37456 L
.09583 .3773 L
.0938 .38367 L
.09177 .39251 L
.08973 .40451 L
.08828 .41571 L
.08696 .42887 L
.08601 .44109 L
.08519 .45534 L
.08483 .46376 L
.08456 .4716 L
.08434 .48084 L
.08421 .48972 L
.08417 .50579 L
.08427 .51495 L
.08442 .52342 L
.08488 .53861 L
.08551 .55267 L
Mistroke
.08643 .5678 L
.08766 .58351 L
.08922 .59916 L
.09094 .6131 L
.09474 .63632 L
.09699 .64671 L
.09959 .65643 L
.10202 .66364 L
.10468 .66981 L
.10716 .67408 L
.10995 .67732 L
.11251 .67895 L
.11492 .67934 L
.11637 .67906 L
.11794 .67832 L
.12078 .67584 L
.12349 .67206 L
.12593 .66743 L
.12848 .66126 L
.13118 .65315 L
.13615 .63302 L
.13987 .61201 L
.14269 .59071 L
.14509 .56582 L
.146 .55298 L
.14677 .53886 L
.14725 .52636 L
.14753 .51513 L
.14767 .50239 L
.14762 .49069 L
.14742 .4802 L
.14711 .4709 L
.14664 .46114 L
.146 .45141 L
.14518 .44183 L
.14412 .43236 L
.14298 .42441 L
.14182 .41798 L
.1406 .41261 L
.13939 .40843 L
.13808 .40498 L
.13658 .40228 L
.13503 .40076 L
.13338 .40051 L
.13197 .40141 L
.13045 .40355 L
.12887 .4072 L
.12801 .40985 L
.12725 .41262 L
.12592 .41859 L
Mistroke
.12463 .4261 L
.12363 .43345 L
.12266 .44244 L
.1219 .45138 L
.12131 .46033 L
.12078 .47151 L
.12044 .48226 L
.12026 .49517 L
.12028 .50781 L
.12046 .51892 L
.12082 .53088 L
.12132 .54217 L
.12191 .55236 L
.12276 .56422 L
.12387 .57676 L
.12639 .59837 L
.12968 .61898 L
.13384 .63791 L
.13607 .64573 L
.13829 .65225 L
.14267 .66203 L
.1453 .66617 L
.14677 .66797 L
.14816 .66935 L
.15063 .67108 L
.15338 .67193 L
.15484 .67194 L
.15637 .67162 L
.15909 .67025 L
.16059 .66905 L
.16199 .66765 L
.16509 .66353 L
.16779 .65879 L
.17062 .65259 L
.17544 .63883 L
.17964 .62282 L
.18303 .60629 L
.18613 .58706 L
.18881 .56502 L
.18986 .55382 L
.19078 .54186 L
.19143 .53074 L
.19185 .52083 L
.19211 .51119 L
.19222 .50247 L
.1922 .49496 L
.19207 .48725 L
.19179 .47933 L
.1916 .47557 L
.19137 .47164 L
Mistroke
.19086 .46516 L
.19029 .45973 L
.18965 .45486 L
.18897 .45087 L
.18832 .44781 L
.18757 .44506 L
.18672 .44277 L
.18578 .44115 L
.18497 .44044 L
.18406 .44037 L
.18357 .44066 L
.18302 .44124 L
.18206 .443 L
.18115 .44558 L
.18035 .44871 L
.17947 .45333 L
.17875 .45834 L
.17803 .46502 L
.17748 .47214 L
.1771 .479 L
.17682 .48682 L
.17668 .49391 L
.17665 .50207 L
.17676 .51124 L
.17689 .51653 L
.17705 .52144 L
.17748 .53114 L
.17804 .54049 L
.17953 .55868 L
.18143 .57563 L
.18405 .59362 L
.18749 .61181 L
.19146 .62814 L
.1962 .64306 L
.20063 .65369 L
.20325 .65876 L
.20579 .66292 L
.20822 .66623 L
.2109 .66921 L
.21337 .67137 L
.21568 .67291 L
.21819 .67407 L
.22098 .67477 L
.22389 .67486 L
.22661 .67437 L
.22915 .67344 L
.23154 .67214 L
.23367 .67065 L
.23597 .66868 L
.24101 .66309 L
Mistroke
.24552 .6566 L
.25507 .63792 L
.26389 .61403 L
.27549 .56962 L
.28182 .53617 L
.28365 .52597 L
.28429 .52302 L
.2846 .52185 L
.28491 .5209 L
.28523 .52022 L
.28552 .51991 L
.28579 .51989 L
.28609 .52017 L
.28641 .52081 L
.28676 .52188 L
.28747 .52481 L
.2923 .55139 L
.29648 .57207 L
.30254 .59721 L
.3181 .64605 L
.33867 .69168 L
.36648 .73604 L
.43009 .80743 L
.51831 .89084 L
.57364 .9376 L
.60378 .95784 L
.62145 .96688 L
.62947 .97011 L
.63825 .97294 L
.64233 .97397 L
.64668 .97487 L
.65452 .97591 L
.65871 .97615 L
.66264 .97616 L
.66999 .97557 L
.67726 .97418 L
.6839 .97213 L
.69115 .96897 L
.69873 .96454 L
.70629 .95887 L
.71427 .9514 L
.72826 .93399 L
.74405 .90631 L
.7574 .87429 L
.76857 .83925 L
.77785 .80228 L
.78672 .75704 L
.79449 .70457 L
.79975 .65623 L
.80338 .60941 L
Mistroke
.80488 .58226 L
.80588 .55739 L
.80659 .52883 L
.80683 .50201 L
.80665 .4755 L
.80637 .46085 L
.806 .44759 L
.80502 .42382 L
.80362 .39971 L
.80203 .3791 L
.8003 .36081 L
.79549 .32305 L
.79235 .3046 L
.7891 .28889 L
.7824 .26434 L
.77837 .25348 L
.77448 .2453 L
.77009 .23839 L
.76784 .23572 L
.76532 .23341 L
.76137 .23114 L
.75719 .23047 L
.75362 .23125 L
.74973 .23352 L
.74559 .23757 L
.74124 .24369 L
.73725 .25107 L
.73373 .25909 L
.72725 .27805 L
.72089 .30322 L
.71565 .33091 L
.71156 .35942 L
.70946 .37786 L
.70775 .39613 L
.70644 .41332 L
.70531 .43218 L
.7044 .45319 L
.70386 .47313 L
.70368 .48555 L
.7036 .49735 L
.70374 .51966 L
.70415 .53971 L
.7049 .56105 L
.70579 .57936 L
.70703 .59948 L
.71081 .64426 L
.71558 .68536 L
.7227 .73223 L
.73088 .77406 L
.73944 .80916 L
Mistroke
.74958 .84249 L
.7617 .87305 L
.77372 .89496 L
.78065 .90412 L
.78728 .91056 L
.79112 .91327 L
.79466 .91509 L
.79855 .91634 L
.80265 .9168 L
.80922 .91563 L
.81291 .91391 L
.81629 .91164 L
.82244 .90571 L
.82883 .89692 L
.83443 .88682 L
.83951 .87548 L
.85042 .84295 L
.85601 .82099 L
.86094 .79774 L
.86912 .74829 L
.87302 .71772 L
.87616 .68784 L
.87904 .65388 L
.8815 .61597 L
.88295 .58517 L
.88389 .55665 L
.88444 .52933 L
.88464 .5007 L
.88442 .46965 L
.88381 .44137 L
.8827 .41127 L
.88103 .38046 L
.87895 .35225 L
.87621 .32375 L
.87341 .30067 L
.87009 .2785 L
.86681 .26068 L
.86293 .24354 L
.85943 .23105 L
.85553 .21995 L
.85085 .21001 L
.84638 .20356 L
.8436 .20092 L
.84096 .19935 L
.83602 .19874 L
.83129 .20095 L
.82699 .20532 L
.82237 .2126 L
.81763 .223 L
.81381 .23373 L
Mistroke
.8099 .24716 L
.80341 .27605 L
.79986 .29636 L
.79682 .31726 L
.79206 .36021 L
.79011 .38412 L
.78839 .41157 L
.7877 .42574 L
.7871 .44124 L
.78636 .46981 L
.78611 .49722 L
.7863 .52638 L
.78684 .55139 L
.78784 .5787 L
.78865 .59534 L
.78956 .61095 L
.79163 .63979 L
.79439 .67012 L
.79797 .70187 L
.80591 .75506 L
.81477 .79808 L
.82461 .83287 L
.83443 .85738 L
.84012 .86756 L
.84319 .8719 L
.84648 .8757 L
.85259 .88039 L
.8583 .88203 L
.86403 .88095 L
.87018 .87666 L
.87589 .86956 L
.88102 .86042 L
.88555 .84999 L
.89034 .83623 L
.89933 .80131 L
.90443 .7748 L
.90879 .74675 L
.9156 .68751 L
.91857 .65126 L
.92074 .61634 L
.92164 .59769 L
.92245 .57692 L
.9231 .55506 L
.9235 .5345 L
.92377 .49774 L
.92346 .46324 L
.92274 .433 L
.92147 .4011 L
.91957 .36825 L
.91697 .3356 L
Mistroke
.914 .30743 L
.91093 .28436 L
.90772 .26488 L
.90398 .24671 L
.89959 .23017 L
.89527 .21805 L
.89287 .21289 L
.89022 .20834 L
.88531 .20297 L
.88047 .20128 L
.876 .20279 L
.87188 .20675 L
.86808 .21265 L
.86402 .22145 L
.8598 .23355 L
.85581 .24806 L
.85188 .26585 L
.84564 .30343 L
.84258 .32792 L
.84016 .35175 L
.83784 .38087 L
.83611 .40969 L
.83495 .43728 L
.83425 .46332 L
.83391 .49235 L
.83404 .52339 L
.83468 .55464 L
.83526 .57211 L
.83593 .58797 L
.83762 .61833 L
.83967 .64645 L
.8458 .70564 L
.85013 .73614 L
.85467 .762 L
.85914 .78302 L
.86422 .80255 L
.86886 .81703 L
.87405 .82985 L
.87705 .83578 L
.87984 .84034 L
.88537 .84684 L
.88851 .84904 L
.89193 .85022 L
.89517 .85016 L
.89816 .84907 L
.9034 .84471 L
.90823 .83776 L
.91339 .82697 L
.91874 .81167 L
.92376 .79284 L
Mistroke
.92867 .76929 L
.93287 .744 L
.93631 .71856 L
.94176 .66437 L
.94407 .63209 L
.94578 .60046 L
.94694 .57042 L
.94765 .54239 L
.94802 .51151 L
.94795 .47905 L
.94741 .4469 L
.94631 .41345 L
.94479 .38326 L
.94303 .35715 L
.94053 .32868 L
.93731 .30063 L
.93385 .2773 L
.93033 .25866 L
.92662 .24327 L
.92247 .23034 L
.9188 .22205 L
.91466 .2159 L
.91012 .2127 L
.90757 .21245 L
.90525 .21318 L
.90077 .21714 L
.89661 .22389 L
.89283 .23273 L
.88898 .24463 L
.88257 .27204 L
.87936 .2903 L
.8766 .30917 L
.8737 .33342 L
.87136 .3576 L
.86928 .38503 L
.86829 .40133 L
.86753 .41643 L
.86645 .44509 L
.8658 .47633 L
.86566 .50481 L
.86599 .53572 L
.86675 .56474 L
.86785 .59108 L
.86957 .62098 L
.87162 .64796 L
.87432 .67624 L
.87773 .70466 L
.88182 .73195 L
.88614 .75506 L
.89037 .77332 L
Mistroke
.89524 .78997 L
.89989 .80219 L
.90431 .81075 L
.90863 .81645 L
.91325 .81972 L
.91835 .81999 L
.92308 .81705 L
.92819 .81023 L
.93099 .80479 L
.93349 .79883 L
.93838 .78388 L
.94264 .76678 L
.94698 .74452 L
.95113 .7173 L
.95411 .69276 L
.95691 .66422 L
.95944 .63074 L
.96127 .59782 L
.96254 .56476 L
.96325 .5336 L
.96351 .49927 L
.96342 .4802 L
.9632 .46309 L
.96242 .43223 L
.96108 .40014 L
.95936 .37142 L
.95741 .3467 L
.95287 .30543 L
.94986 .28543 L
.94679 .26922 L
.94334 .2548 L
.94002 .24418 L
.93604 .23497 L
.93217 .22932 L
.92821 .22662 L
.92392 .22707 L
.91991 .23061 L
.91629 .23642 L
.91239 .24563 L
.90832 .25885 L
.90432 .27591 L
.90089 .29451 L
.89758 .31704 L
.89482 .3405 L
.89265 .36343 L
.89074 .38908 L
.8899 .4029 L
.88911 .4184 L
.88806 .44635 L
.88766 .46237 L
Mistroke
.88739 .47973 L
.88729 .4962 L
.88732 .51126 L
.88768 .53827 L
.88849 .56669 L
.88952 .59052 L
.89103 .61615 L
.89304 .64252 L
.89566 .66945 L
.89828 .69119 L
.90149 .71311 L
.90818 .74718 L
.91221 .76211 L
.91616 .77344 L
.91999 .78169 L
.92357 .78709 L
.92777 .79073 L
.93176 .79156 L
.93601 .78958 L
.94053 .78413 L
.94469 .77584 L
.94837 .76562 L
.95247 .75056 L
.95664 .7305 L
.96023 .7083 L
.96322 .68514 L
.96615 .65639 L
.96843 .62718 L
.97008 .59953 L
.97139 .56853 L
.97188 .55204 L
.97227 .53379 L
.97249 .51466 L
.97254 .49682 L
.97225 .46514 L
.97138 .43201 L
.97008 .40214 L
.96847 .37595 L
.96627 .34917 L
.9635 .32336 L
.96077 .3035 L
.95795 .28714 L
.95462 .27191 L
.95081 .25884 L
.94747 .25065 L
.94372 .24461 L
.93973 .24156 L
.936 .24169 L
.93251 .24437 L
.92939 .24889 L
Mistroke
.92587 .2565 L
.92267 .26592 L
.91932 .27861 L
.91595 .29479 L
.91058 .32997 L
.90784 .35467 L
.90565 .37996 L
.90405 .40393 L
.90271 .43111 L
.90217 .44649 L
.90178 .46113 L
.90139 .48875 L
.90136 .50434 L
.90145 .51865 L
.90168 .53429 L
.90208 .55067 L
.90308 .5775 L
.90438 .60179 L
.90621 .62737 L
.9086 .65316 L
.91387 .69399 L
.91736 .7136 L
.92086 .72917 L
.92411 .74061 L
.92784 .75071 L
.93189 .75831 L
.93576 .76256 L
.93956 .76396 L
.94318 .76275 L
.9464 .75953 L
.94985 .75373 L
.95348 .74477 L
.95718 .73224 L
.96048 .7177 L
.96327 .70235 L
.96867 .66157 L
.97116 .6349 L
.97306 .60816 L
.9746 .57842 L
.97558 .55034 L
.97593 .53456 L
.97616 .51729 L
.97619 .48585 L
.97581 .45938 L
.97495 .43086 L
.9736 .40228 L
.97192 .37694 L
.97002 .35495 L
.96802 .33635 L
.96536 .31653 L
Mistroke
.96269 .30074 L
.9595 .28588 L
.95586 .27322 L
.95233 .26458 L
.94889 .2592 L
.94481 .25635 L
.94103 .25696 L
.93907 .2585 L
.93692 .26114 L
.93471 .26493 L
.93268 .2694 L
.92874 .28104 L
.9252 .29514 L
.92225 .31013 L
.9193 .32875 L
.91647 .35131 L
.91391 .37764 L
.91197 .40426 L
.91064 .42951 L
.90974 .45433 L
.90926 .47787 L
.90911 .50387 L
.90941 .53159 L
.90974 .54538 L
.91022 .56017 L
.91145 .58638 L
.91305 .61079 L
.91488 .63211 L
.91894 .66684 L
.92165 .68406 L
.92442 .6983 L
.92732 .71031 L
.93054 .7207 L
.93422 .72928 L
.9377 .73444 L
.94163 .73702 L
.94521 .73644 L
.94718 .73491 L
.9493 .73227 L
.95307 .72491 L
.95646 .71505 L
.95987 .7016 L
.96258 .68778 L
.96533 .6703 L
.96819 .64687 L
.97042 .62315 L
.97147 .60922 L
.97248 .59348 L
.97322 .57947 L
.9739 .56362 L
Mistroke
.97472 .53472 L
.97497 .51864 L
.97507 .50347 L
.97491 .47645 L
.97428 .44776 L
.97323 .42124 L
.97192 .39817 L
.97001 .37318 L
.96783 .35149 L
.96318 .31842 L
.96017 .30328 L
.95721 .29177 L
.95382 .28206 L
.95053 .27567 L
.94684 .2717 L
.94474 .27086 L
.94282 .27096 L
.93899 .27364 L
.93686 .27658 L
.9349 .28021 L
.93142 .289 L
.92789 .30129 L
.92443 .31723 L
.92152 .33434 L
.91867 .3555 L
.91611 .38015 L
.91429 .40317 L
.91294 .42568 L
.91233 .43894 L
.91188 .45119 L
.91149 .46547 L
.91124 .47908 L
.9111 .50246 L
.91134 .52713 L
.91186 .54783 L
.91277 .57005 L
.91412 .59287 L
.91597 .61601 L
.91809 .63617 L
.92032 .65295 L
.92294 .66873 L
.92563 .68156 L
.9282 .69125 L
.93112 .69966 L
.93443 .70623 L
.93614 .70847 L
.93803 .71009 L
.94139 .71076 L
.94453 .70882 L
.94763 .70436 L
Mistroke
.9505 .69783 L
.95298 .69011 L
.95556 .67974 L
.95818 .66632 L
.96072 .64971 L
.96271 .63337 L
.96455 .61451 L
.96638 .58994 L
.96766 .5659 L
.9682 .55204 L
.96859 .53889 L
.96888 .52427 L
.96905 .50849 L
.96906 .4948 L
.96894 .47996 L
.9687 .46604 L
.96837 .45331 L
.96747 .42973 L
.96611 .40577 L
.96457 .38539 L
.96258 .36502 L
.95821 .33315 L
.95514 .3173 L
.95198 .30501 L
.94899 .29639 L
.9456 .28968 L
.94387 .28739 L
.94202 .28575 L
.93868 .28481 L
.93509 .28664 L
.93307 .28896 L
.93121 .29194 L
.92793 .29927 L
.92505 .30803 L
.92191 .32044 L
.91914 .33428 L
.91686 .34823 L
.91467 .36448 L
.9114 .39676 L
.90997 .41602 L
.90891 .43475 L
.90805 .4558 L
.90771 .46778 L
.9075 .47882 L
.90733 .50004 L
.90752 .5225 L
.90804 .54325 L
.90878 .56155 L
.90999 .58213 L
.91167 .60302 L
Mistroke
.9136 .62111 L
.91563 .63617 L
.91781 .64901 L
.92035 .66083 L
.92189 .66661 L
.92334 .67123 L
.92475 .67502 L
.92629 .67839 L
.9279 .68113 L
.92941 .68299 L
.93123 .68435 L
.93288 .68476 L
.93445 .68443 L
.93613 .68327 L
.93915 .67907 L
.94193 .67259 L
.94437 .66463 L
.94702 .65309 L
.94933 .63999 L
.95287 .61198 L
.9545 .59385 L
.95574 .57586 L
.95678 .55532 L
.95745 .53527 L
.95784 .5127 L
.9579 .49986 L
.95785 .48808 L
.95748 .46576 L
.95712 .45327 L
.95668 .44182 L
.9555 .41929 L
.95383 .39653 L
.95177 .37549 L
.94955 .3579 L
.94679 .34086 L
.94356 .32569 L
.94055 .31507 L
.93758 .30741 L
.93583 .30403 L
.93421 .30159 L
.93232 .29956 L
.93051 .2984 L
.9274 .29814 L
.92412 .30021 L
.92136 .30383 L
.91838 .30975 L
.91531 .31819 L
.91217 .32959 L
.9094 .3424 L
.90708 .35558 L
Mistroke
.90313 .38529 L
.90137 .4033 L
.89998 .42114 L
.89895 .43816 L
.89823 .4542 L
.89768 .47198 L
.89739 .49086 L
.89739 .50965 L
.89752 .52005 L
.89772 .52944 L
.89833 .54721 L
.89915 .56339 L
.9004 .58109 L
.90183 .59631 L
.90366 .61147 L
.90589 .62561 L
.90827 .63708 L
.91063 .64557 L
.91192 .64919 L
.91336 .65249 L
.9149 .65516 L
.91636 .65692 L
.91775 .65793 L
.91908 .65829 L
.92156 .6574 L
.92294 .65601 L
.9242 .65415 L
.92556 .65148 L
.92698 .64794 L
.92916 .64085 L
.93137 .63126 L
.9333 .62045 L
.93491 .60914 L
.9365 .59518 L
.93798 .57837 L
.93862 .56935 L
.93921 .55937 L
.94004 .54063 L
.94053 .52216 L
.94068 .51144 L
.94073 .50132 L
.94058 .4808 L
.94035 .46929 L
.94004 .45884 L
.93927 .44053 L
.93811 .4212 L
.93672 .40377 L
.9352 .38853 L
.93297 .37076 L
.93059 .3558 L
Mistroke
.92821 .34385 L
.92551 .33307 L
.92238 .32357 L
.91936 .31704 L
.91764 .31433 L
.91602 .3124 L
.91422 .31096 L
.91228 .3102 L
.9107 .31017 L
.90902 .31071 L
.90603 .31313 L
.9044 .31526 L
.90288 .31775 L
.89951 .32516 L
.89671 .33347 L
.89428 .34246 L
.89162 .35451 L
.88935 .36704 L
.88591 .39153 L
.88438 .40556 L
.88299 .42115 L
.8818 .43808 L
.88094 .45435 L
.8804 .46908 L
.88004 .485 L
.87993 .50101 L
.88005 .51534 L
.88044 .53138 L
.88105 .54595 L
.88181 .55871 L
.88267 .56985 L
.88378 .58124 L
.88514 .59226 L
.88666 .60205 L
.88846 .61114 L
.89029 .61821 L
.89206 .62335 L
.89409 .62747 L
.89526 .62904 L
.89637 .63001 L
.89755 .6305 L
.89862 .63048 L
.89986 .62988 L
.90102 .62876 L
.90298 .62557 L
.90407 .62305 L
.90507 .62024 L
.90701 .61328 L
.90895 .60392 L
.91058 .59362 L
Mistroke
.91196 .5825 L
.91305 .57151 L
.91405 .55855 L
.91456 .55014 L
.91497 .54194 L
.91554 .52602 L
.91574 .5168 L
.91585 .50819 L
.91588 .49863 L
.91582 .48843 L
.91548 .4714 L
.91492 .45558 L
.91449 .4466 L
.91402 .43851 L
.91274 .42079 L
.91005 .39425 L
.90818 .38048 L
.90623 .36862 L
.90178 .3483 L
.89903 .33917 L
.89638 .33236 L
.89399 .32767 L
.89171 .32437 L
.88917 .32195 L
.88642 .32074 L
.88353 .32099 L
.88082 .32262 L
.87841 .3252 L
.87585 .32916 L
.87308 .33489 L
.87059 .34144 L
.86778 .35063 L
.86536 .36023 L
.86097 .38288 L
.8589 .39678 L
.85719 .41069 L
.85592 .42302 L
.85478 .43644 L
.85397 .44819 L
.85328 .46094 L
.85295 .46877 L
.85272 .47593 L
.85243 .48984 L
.85237 .5022 L
.85251 .51483 L
.85283 .52657 L
.85309 .53295 L
.85338 .53865 L
.85404 .54863 L
.85489 .55844 L
Mistroke
.8567 .57328 L
.8579 .58039 L
.85912 .5861 L
.8606 .59144 L
.86209 .59531 L
.86346 .59773 L
.865 .59923 L
.86588 .59954 L
.86667 .59948 L
.86759 .59901 L
.86845 .59817 L
.86996 .59573 L
.87153 .59174 L
.87284 .58719 L
.87399 .58204 L
.87526 .57485 L
.87631 .56734 L
.87722 .55916 L
.87808 .54941 L
.87881 .53825 L
.87932 .52696 L
.87961 .51689 L
.87978 .50537 L
.87977 .493 L
.87958 .48115 L
.87925 .47002 L
.87882 .45979 L
.87819 .44861 L
.87737 .43698 L
.87629 .42451 L
.87489 .41143 L
.87181 .38932 L
.86819 .37037 L
.86439 .35564 L
.85986 .34305 L
.85714 .33756 L
.85451 .33353 L
.85169 .33048 L
.84907 .32876 L
.84762 .32825 L
.84603 .32803 L
.84453 .32816 L
.84314 .32857 L
.84063 .32998 L
.83795 .33247 L
.83546 .33569 L
.83322 .33938 L
.82913 .34812 L
.82509 .35958 L
.82112 .37411 L
Mistroke
.81784 .38928 L
.81474 .40726 L
.81205 .42747 L
.81001 .44811 L
.80924 .45846 L
.80859 .4697 L
.80819 .47904 L
.80792 .4888 L
.80782 .49766 L
.80784 .50543 L
.8079 .5097 L
.80801 .51411 L
.80829 .52165 L
.80852 .52598 L
.80878 .52987 L
.80934 .53657 L
.81006 .54282 L
.81082 .54777 L
.81173 .55225 L
.81226 .55425 L
.81278 .55587 L
.81368 .55797 L
.81453 .55916 L
.81546 .55968 L
.81599 .55962 L
.81648 .55933 L
.81728 .55837 L
.81814 .55661 L
.81901 .554 L
.81978 .55085 L
.82058 .54658 L
.82134 .54123 L
.82191 .53601 L
.82244 .52965 L
.82289 .52208 L
.82308 .51755 L
.82322 .51326 L
.82331 .50912 L
.82337 .50449 L
.82337 .49574 L
.82324 .48702 L
.823 .4788 L
.82257 .46908 L
.82201 .45969 L
.82066 .44288 L
.81865 .42467 L
.81582 .4054 L
.81213 .38625 L
.80805 .37001 L
.80392 .35717 L
Mistroke
.79878 .345 L
.79372 .33631 L
.79097 .33275 L
.78789 .32963 L
.78632 .32837 L
.78463 .32725 L
.78302 .32641 L
.78155 .32583 L
.77865 .32518 L
.77597 .32516 L
.77457 .32536 L
.77303 .32574 L
.77143 .32632 L
.76993 .32703 L
.7672 .32873 L
.76472 .33072 L
.75927 .33659 L
.75422 .34389 L
.74985 .35168 L
.74093 .37214 L
.73392 .39318 L
.72847 .4133 L
.72007 .45331 L
.71737 .46868 L
.71639 .47397 L
.71602 .47578 L
.71564 .47741 L
.7153 .47861 L
.71499 .47941 L
.71471 .4799 L
.71442 .48012 L
.71426 .48011 L
.71408 .47999 L
.71376 .47948 L
.71343 .47864 L
.71312 .47757 L
.71238 .47427 L
.71142 .46918 L
.70885 .45462 L
.70127 .4179 L
.68953 .37562 L
.67008 .32581 L
.64688 .28346 L
.61658 .24231 L
.57795 .20053 L
.49434 .12073 L
.44154 .07426 L
.40985 .05063 L
.39363 .04066 L
.37828 .03297 L
Mistroke
.37075 .02995 L
.36363 .02758 L
.35967 .02649 L
.35537 .02551 L
.34785 .02431 L
.34381 .02395 L
.33937 .02381 L
.33474 .02395 L
.33041 .02437 L
.32268 .02584 L
.31836 .02709 L
.31443 .02852 L
.30702 .032 L
.30023 .03618 L
.29299 .04175 L
.28512 .04929 L
.27222 .06537 L
.2591 .08745 L
.2466 .11522 L
.23597 .14553 L
.22538 .184 L
.21563 .22994 L
.20843 .27398 L
.20292 .31766 L
.19826 .36771 L
.1963 .39634 L
.19494 .42253 L
.19396 .44883 L
.19341 .4733 L
.1932 .49984 L
.19343 .5278 L
.19372 .5415 L
.19417 .55619 L
.19532 .58215 L
.19684 .60631 L
.1986 .6276 L
.20071 .64809 L
.20298 .66614 L
.20787 .69636 L
.21397 .72337 L
.21772 .73593 L
.22134 .74573 L
.22517 .75399 L
.2294 .76089 L
.23348 .76555 L
.23725 .76824 L
.24171 .76953 L
.24423 .76938 L
.24656 .7687 L
.2508 .76609 L
Mistroke
.25293 .76412 L
.25525 .76145 L
.2598 .75464 L
.26384 .74669 L
.26804 .73642 L
.2724 .72325 L
.27915 .69679 L
.28524 .66381 L
.28996 .62791 L
.2921 .60608 L
.2937 .58509 L
.29482 .56609 L
.29571 .54462 L
.29603 .5336 L
.29627 .52162 L
.29644 .49969 L
.29627 .47814 L
.29571 .45439 L
.29482 .43177 L
.29367 .41072 L
.29067 .37094 L
.28628 .32907 L
.27951 .28078 L
.27037 .23153 L
.26011 .18903 L
.24945 .1546 L
.23888 .12813 L
.22651 .10532 L
.22002 .09662 L
.2164 .0927 L
.21294 .08958 L
.20617 .08525 L
.19996 .08337 L
.19388 .08352 L
.18736 .08595 L
.18125 .09048 L
.17574 .09656 L
.16942 .10605 L
.16271 .11937 L
.1512 .15152 L
.14539 .17325 L
.14046 .19539 L
.13556 .22165 L
.13078 .25266 L
.12686 .28361 L
.12374 .31366 L
.12121 .34334 L
.11899 .37614 L
.1174 .40732 L
.11635 .43608 L
Mistroke
.11568 .46508 L
.11541 .49246 L
.11553 .52393 L
.11606 .55247 L
.11708 .5829 L
.11866 .61391 L
.12046 .64006 L
.12282 .66656 L
.12805 .7094 L
.13159 .73086 L
.13566 .75055 L
.13973 .76607 L
.14368 .77792 L
.14813 .78803 L
.15052 .79221 L
.1531 .79579 L
.15748 .79981 L
.16235 .8014 L
.16668 .80036 L
.1713 .79674 L
.17559 .79102 L
.17943 .78391 L
.18403 .77273 L
.18811 .76014 L
.19269 .74257 L
.19655 .7244 L
.20283 .68561 L
.20575 .66188 L
.20812 .63818 L
.20999 .61503 L
.21142 .59265 L
.21257 .56862 L
.21344 .54162 L
.21384 .51782 L
.21393 .4959 L
.21369 .4704 L
.21313 .44619 L
.21214 .41997 L
.21068 .39235 L
.2091 .36905 L
.207 .34379 L
.20101 .28991 L
.19387 .24348 L
.18524 .20181 L
.17615 .16929 L
.17053 .15373 L
.16522 .14182 L
.1622 .13618 L
.15889 .13088 L
.15277 .12352 L
Mistroke
.14675 .11925 L
.14331 .11814 L
.14008 .11799 L
.13669 .11877 L
.1336 .12033 L
.13005 .12315 L
.12672 .12686 L
.12092 .13585 L
.1157 .14697 L
.11019 .16223 L
.10461 .18188 L
.09631 .22119 L
.09216 .24693 L
.08871 .2726 L
.08338 .32431 L
.08123 .35208 L
.07931 .38352 L
.07771 .41946 L
.07677 .45262 L
.07646 .47103 L
.07629 .49098 L
.07643 .52687 L
.07709 .55977 L
.07831 .59347 L
.07977 .62102 L
.0818 .64973 L
.0845 .67892 L
.08742 .70361 L
.09103 .72778 L
.09529 .7499 L
.09969 .7673 L
.10407 .78024 L
.10816 .78896 L
.1127 .79528 L
.11693 .79824 L
.12161 .7984 L
.12646 .79519 L
.13091 .78919 L
.13499 .78104 L
.13859 .77158 L
.14614 .74374 L
.15 .72441 L
.15373 .70131 L
.15933 .65412 L
.16176 .62528 L
.16358 .59685 L
.16441 .58008 L
.16503 .56444 L
.16556 .54703 L
.16593 .52847 L
Mistroke
.16615 .49921 L
.16587 .46775 L
.16514 .43808 L
.16407 .41136 L
.16234 .38041 L
.15988 .3478 L
.15702 .31807 L
.15397 .29222 L
.14704 .24689 L
.14297 .22622 L
.13819 .20605 L
.13351 .18984 L
.12895 .17705 L
.12445 .16696 L
.11951 .15866 L
.11643 .15486 L
.11357 .15226 L
.11041 .15043 L
.10707 .14967 L
.10144 .15116 L
.09827 .15358 L
.09534 .15687 L
.08994 .16571 L
.08518 .17678 L
.0799 .19309 L
.07519 .21187 L
.06661 .25979 L
.06291 .28828 L
.0594 .32249 L
.05692 .35357 L
.05479 .38859 L
.05332 .42272 L
.05245 .45449 L
.05214 .47371 L
.05199 .49418 L
.0522 .5307 L
.05262 .55266 L
.05322 .57296 L
.05391 .59078 L
.05484 .60954 L
.05701 .64285 L
.05991 .67518 L
.06282 .70008 L
.06644 .72422 L
.07033 .7442 L
.07419 .75944 L
.07867 .77245 L
.08101 .77751 L
.08363 .7819 L
.08809 .78645 L
Mistroke
.09061 .78748 L
.09294 .78748 L
.0972 .78511 L
.10163 .7794 L
.10553 .77153 L
.10956 .76039 L
.11318 .74744 L
.1163 .73375 L
.11973 .71547 L
.12312 .69322 L
.12824 .64729 L
.13045 .61949 L
.13209 .5922 L
.13284 .5761 L
.13339 .56115 L
.13388 .54366 L
.1342 .52686 L
.13436 .51057 L
.13437 .49314 L
.134 .46176 L
.13352 .44262 L
.1329 .42474 L
.13128 .3919 L
.12938 .36384 L
.12691 .3354 L
.12137 .28847 L
.11771 .26507 L
.11398 .24532 L
.10953 .22614 L
.10448 .20906 L
.09979 .19701 L
.09723 .19184 L
.09443 .18726 L
.08944 .18179 L
.0847 .17973 L
.082 .17992 L
.07905 .18125 L
.076 .18393 L
.07319 .18759 L
.06825 .19699 L
.06556 .20381 L
.06318 .21097 L
.05892 .22664 L
.05469 .24644 L
.05046 .27171 L
.04698 .29799 L
.04431 .32292 L
.04185 .35151 L
.03966 .38469 L
.03813 .417 L
Mistroke
.03709 .45068 L
.0366 .48222 L
.03659 .51675 L
.03679 .53402 L
.03718 .55285 L
.0382 .58345 L
.0398 .615 L
.04176 .64298 L
.04392 .66684 L
.04882 .7061 L
.05202 .72474 L
.05523 .73953 L
.05884 .75237 L
.06226 .76146 L
.06634 .76882 L
.07027 .77269 L
.07427 .77355 L
.07855 .77116 L
.08253 .76582 L
.08609 .75843 L
.0901 .74689 L
.09424 .73095 L
.09787 .71292 L
.10095 .69386 L
.10407 .66995 L
.10661 .64539 L
.10854 .62189 L
.11024 .5952 L
.11101 .57963 L
.11161 .56484 L
.1121 .5492 L
.11248 .53183 L
.11275 .50285 L
.11254 .47167 L
.11187 .44264 L
.11084 .41621 L
.10928 .38797 L
.10714 .35917 L
.1025 .31456 L
.09932 .29177 L
.09601 .27241 L
.09279 .25681 L
.08918 .2425 L
.08591 .23199 L
.08228 .22279 L
.07824 .21531 L
.07441 .21076 L
.06979 .20844 L
.06559 .20934 L
.0612 .2134 L
Mistroke
.05718 .2201 L
.05289 .23065 L
.04851 .24561 L
.04422 .26512 L
.04049 .28704 L
.03744 .30958 L
.03459 .33603 L
.03229 .36315 L
.03058 .38909 L
.02923 .41622 L
.0283 .44243 L
.02766 .47362 L
.02749 .50241 L
.02777 .53375 L
.02859 .56605 L
.02994 .59752 L
.03161 .62463 L
.03403 .65364 L
.03676 .67844 L
.03962 .69875 L
.04253 .71511 L
.04596 .73021 L
.04982 .74282 L
.05387 .75182 L
.0562 .75526 L
.05836 .75738 L
.06237 .75872 L
.06658 .75661 L
.0688 .75403 L
.07114 .75021 L
.07525 .74061 L
.07767 .73309 L
.07987 .7249 L
.08377 .70693 L
.0867 .68984 L
.08954 .66937 L
.09172 .65009 L
.09379 .62765 L
.09577 .59977 L
.0972 .57207 L
.09813 .54426 L
.0986 .51804 L
.09866 .49043 L
.09833 .46457 L
.09754 .43657 L
.0969 .42111 L
.09618 .40716 L
.09452 .38151 L
.09226 .35489 L
.08942 .32913 L
Mistroke
.08637 .30734 L
.08342 .29021 L
.07995 .27396 L
.07646 .26105 L
.07307 .25137 L
.06992 .2446 L
.06637 .23937 L
.0626 .23648 L
.05905 .23621 L
.05494 .23892 L
.05109 .24451 L
.04772 .25202 L
.04418 .26284 L
.04055 .27755 L
.03696 .29647 L
.03141 .33807 L
.02904 .36315 L
.02692 .39276 L
.02605 .40836 L
.02527 .42549 L
.02468 .44195 L
.02428 .45715 L
.02384 .48655 L
.02389 .51853 L
.02442 .5483 L
.02532 .57506 L
.02599 .58942 L
.02684 .60446 L
.02869 .63033 L
.03141 .65843 L
.03434 .6812 L
.03759 .70051 L
.04148 .71778 L
.04355 .72488 L
.04583 .73124 L
.04804 .73606 L
.05008 .73943 L
.05395 .74316 L
.05592 .74377 L
.05808 .74348 L
.06189 .7405 L
.06538 .73496 L
.06745 .73036 L
.06937 .72516 L
.07284 .7133 L
.07634 .69765 L
.07982 .67751 L
.08253 .65764 L
.08477 .63723 L
.08695 .61196 L
Mistroke
.08854 .58778 L
.08968 .56396 L
.09041 .54155 L
.09085 .5166 L
.0909 .49016 L
.09055 .46447 L
.09017 .45014 L
.08971 .43709 L
.08859 .41367 L
.08704 .38985 L
.08533 .36967 L
.08348 .35189 L
.07845 .31626 L
.07524 .29995 L
.07196 .28696 L
.06885 .27754 L
.06533 .26982 L
.06328 .26668 L
.0614 .26464 L
.05922 .26323 L
.05715 .26286 L
.05348 .26451 L
.04956 .26964 L
.04626 .27689 L
.04328 .28596 L
.04018 .29837 L
.03707 .31441 L
.03412 .33403 L
.03165 .35502 L
.02972 .37561 L
.02798 .39961 L
.02678 .4214 L
.0258 .44634 L
.02518 .47306 L
.02497 .49843 L
.02511 .52202 L
.02551 .5434 L
.02626 .56637 L
.02738 .58973 L
.02898 .61403 L
.03113 .63847 L
.03352 .65939 L
.03601 .67657 L
.03868 .69123 L
.04136 .70291 L
.0443 .71288 L
.04769 .72114 L
.05144 .72682 L
.05507 .7291 L
.05834 .7286 L
Mistroke
.06188 .72534 L
.06386 .72226 L
.06563 .71873 L
.06948 .70835 L
.07284 .69585 L
.07581 .68175 L
.08056 .65106 L
.0826 .63347 L
.08453 .61283 L
.08593 .59424 L
.08713 .57356 L
.088 .5535 L
.08854 .53491 L
.0889 .51136 L
.08891 .48959 L
.08856 .46594 L
.08778 .4414 L
.08679 .42085 L
.08559 .40236 L
.08399 .38314 L
.08196 .36391 L
.07729 .33229 L
.07429 .31795 L
.07138 .30726 L
.06852 .2994 L
.06532 .29333 L
.06222 .29003 L
.05934 .28914 L
.05598 .29072 L
.05289 .29477 L
.04959 .30204 L
.04779 .30739 L
.0462 .31305 L
.04316 .32659 L
.04014 .34445 L
.03762 .36402 L
.03559 .38422 L
.03398 .40512 L
.0326 .42911 L
.03168 .4528 L
.03116 .47514 L
.03097 .50023 L
.03104 .51448 L
.03121 .52769 L
.03152 .54156 L
.0319 .55401 L
.03247 .56814 L
.03313 .58118 L
.03469 .605 L
.03677 .62844 L
Mistroke
.03886 .64669 L
.04146 .66466 L
.04456 .68117 L
.04639 .68896 L
.0482 .69547 L
.04992 .70069 L
.05185 .70548 L
.05532 .71159 L
.05707 .71352 L
.05894 .71477 L
.06228 .715 L
.06587 .71242 L
.06788 .70968 L
.06972 .70632 L
.07298 .69832 L
.07582 .68898 L
.07891 .67595 L
.08162 .66158 L
.08384 .64719 L
.08596 .63052 L
.08909 .59765 L
.09043 .57814 L
.09141 .55924 L
.09217 .53808 L
.09246 .52606 L
.09262 .51503 L
.09269 .4938 L
.0924 .47141 L
.09179 .45081 L
.09096 .43272 L
.08966 .41244 L
.08788 .39196 L
.08587 .37433 L
.08377 .35978 L
.08153 .34744 L
.07894 .33623 L
.07737 .33081 L
.0759 .32654 L
.07292 .3201 L
.0713 .31775 L
.06978 .31625 L
.0681 .31537 L
.06631 .31533 L
.0646 .31615 L
.063 .31769 L
.06007 .32256 L
.05748 .32923 L
.05484 .33865 L
.05249 .34962 L
.05052 .36125 L
Mistroke
.04841 .37678 L
.04643 .39569 L
.04487 .41524 L
.04372 .43452 L
.04286 .45533 L
.04235 .47547 L
.04214 .49799 L
.04218 .51072 L
.04231 .52235 L
.04288 .54542 L
.04336 .55825 L
.04392 .56994 L
.0452 .59065 L
.04693 .61146 L
.04884 .62943 L
.05084 .64453 L
.05323 .65906 L
.0561 .67278 L
.05878 .68269 L
.0614 .69014 L
.06426 .69607 L
.06742 .70018 L
.07031 .70187 L
.07347 .70157 L
.07644 .69925 L
.07914 .6954 L
.08151 .6906 L
.08406 .68389 L
.08888 .66606 L
.09135 .65381 L
.09347 .64113 L
.09575 .62464 L
.09756 .60849 L
.09909 .59178 L
.10045 .57287 L
.10107 .56222 L
.10155 .55228 L
.10225 .53248 L
.10258 .51556 L
.10269 .49979 L
.10256 .4827 L
.10215 .46475 L
.10143 .44664 L
.10048 .43025 L
.09942 .41635 L
.09805 .4022 L
.09615 .38689 L
.09412 .37424 L
.09213 .36448 L
.08983 .35576 L
Mistroke
.08717 .34854 L
.08578 .34586 L
.08424 .34367 L
.08291 .34244 L
.08147 .34177 L
.07887 .34231 L
.0763 .3451 L
.07488 .34766 L
.07358 .35065 L
.07128 .35768 L
.06898 .36725 L
.06707 .37752 L
.06543 .38855 L
.06381 .40214 L
.06233 .41814 L
.06114 .43521 L
.0603 .45164 L
.05971 .46885 L
.05939 .48556 L
.05932 .50541 L
.05954 .52381 L
.0601 .54386 L
.0605 .55383 L
.06105 .56461 L
.06232 .58423 L
.06378 .60124 L
.06578 .61954 L
.06797 .63533 L
.07247 .65897 L
.0753 .66957 L
.07807 .67747 L
.08075 .6831 L
.08372 .68729 L
.08658 .68943 L
.08921 .68985 L
.0916 .68897 L
.09419 .68666 L
.09685 .68279 L
.09927 .6779 L
.10203 .67064 L
.10451 .66237 L
.1088 .64356 L
.11276 .6192 L
.11465 .60394 L
.11617 .5891 L
.11746 .57351 L
.11845 .5583 L
.11915 .54445 L
.11969 .52924 L
.12003 .5128 L
Mistroke
.1201 .50369 L
.1201 .49551 L
.1199 .47987 L
.1195 .4656 L
.11892 .45271 L
.11813 .43975 L
.1173 .42933 L
.11624 .41864 L
.11495 .4081 L
.11339 .39804 L
.11191 .39036 L
.11022 .38343 L
.10924 .38013 L
.10812 .37699 L
.10609 .37275 L
.10492 .37112 L
.10365 .36997 L
.10244 .36948 L
.10133 .36954 L
.09931 .3709 L
.09818 .3724 L
.09714 .37425 L
.0951 .37934 L
.094 .38296 L
.09303 .38671 L
.09139 .39447 L
.08979 .4041 L
.08822 .41621 L
.08697 .42869 L
.086 .44129 L
.08526 .45384 L
.08467 .46831 L
.08428 .4845 L
.08418 .4933 L
.08416 .50167 L
.08431 .51746 L
.08474 .53452 L
.0851 .54407 L
.08552 .55276 L
.08638 .56711 L
.08756 .58235 L
.09065 .61088 L
.09282 .62563 L
.09503 .63774 L
.09761 .64924 L
.10064 .65975 L
.10361 .66753 L
.10646 .673 L
.10925 .67666 L
.11068 .67792 L
Mistroke
.11227 .67885 L
.11517 .67932 L
.11663 .67897 L
.11821 .67815 L
.121 .67559 L
.12354 .67197 L
.12648 .66622 L
.12905 .65971 L
.13437 .64108 L
.13839 .62115 L
.142 .59654 L
.14338 .58448 L
.14463 .57135 L
.1456 .55891 L
.14634 .54727 L
.14697 .53425 L
.14722 .5274 L
.14743 .52016 L
.14763 .50817 L
.14766 .49523 L
.14751 .48412 L
.14718 .4726 L
.1467 .46226 L
.14614 .45328 L
.14534 .44351 L
.14446 .43515 L
.14336 .42688 L
.14205 .41917 L
.14055 .41241 L
.13903 .40736 L
.1376 .40397 L
.136 .40156 L
.13457 .40055 L
.13322 .40056 L
.13175 .40164 L
.13019 .40404 L
.12862 .40791 L
.1272 .41282 L
.12599 .41824 L
.12477 .42517 L
.12288 .44023 L
.12201 .44992 L
.12137 .4594 L
.12089 .4688 L
.12051 .47947 L
.12031 .48994 L
.12024 .49984 L
.12034 .51286 L
.12063 .52538 L
.12106 .53667 L
Mistroke
.1217 .54892 L
.12259 .56208 L
.12377 .57574 L
.12647 .59897 L
.12956 .61834 L
.13293 .63427 L
.13707 .64881 L
.13957 .65552 L
.14195 .66068 L
.14445 .66496 L
.14718 .66841 L
.1498 .6706 L
.1522 .6717 L
.15504 .67191 L
.15664 .67153 L
.15811 .67086 L
.16079 .66886 L
.16359 .6657 L
.16621 .6617 L
.16894 .65643 L
.17362 .64454 L
.17864 .62703 L
.18262 .60855 L
.18578 .5895 L
.18811 .57148 L
.18918 .56135 L
.19015 .5504 L
.19083 .54101 L
.19142 .53086 L
.19182 .52162 L
.19207 .51323 L
.19221 .50466 L
.19221 .49588 L
.19209 .48813 L
.19187 .48121 L
.19159 .47536 L
.19121 .46945 L
.19066 .46308 L
.19005 .45776 L
.1893 .45267 L
.1884 .44814 L
.18792 .44625 L
.18738 .44448 L
.1869 .44317 L
.18636 .44204 L
.18583 .4412 L
.18534 .44068 L
.18437 .44031 L
.1834 .44081 L
.18252 .44205 L
Mistroke
.18158 .44425 L
.18112 .44568 L
.18063 .44751 L
.17986 .45116 L
.17909 .45584 L
.17844 .46098 L
.17793 .46622 L
.17747 .47232 L
.17712 .47853 L
.17685 .48584 L
.17668 .49423 L
.17666 .50302 L
.1767 .50759 L
.17679 .51269 L
.17707 .52196 L
.17747 .53079 L
.178 .53989 L
.17864 .54856 L
.18016 .56481 L
.18228 .58201 L
.18514 .59988 L
.18858 .61671 L
.19295 .63328 L
.19809 .64795 L
.20334 .65893 L
.20598 .66319 L
.20854 .66663 L
.21091 .66923 L
.21348 .67145 L
.21628 .67323 L
.21891 .67431 L
.22052 .67469 L
.22205 .67487 L
.22489 .67474 L
.22748 .67411 L
.23023 .67291 L
.23281 .67129 L
.23514 .66944 L
.24071 .66348 L
.24578 .65619 L
.25505 .63796 L
.26371 .61461 L
.27505 .57165 L
.28122 .53962 L
.28321 .52832 L
.28402 .52422 L
.28442 .52254 L
.28476 .52134 L
.28505 .52058 L
.28535 .52006 L
Mistroke
.28568 .51987 L
.28598 .52003 L
.28625 .52045 L
.28656 .52121 L
.28686 .5222 L
.28715 .52336 L
.29177 .54853 L
.30033 .58855 L
.313 .63188 L
.33226 .67902 L
.34578 .70444 L
.36021 .72719 L
.3912 .76671 L
.46256 .83877 L
.50918 .88249 L
.55832 .92559 L
.59759 .95413 L
.60876 .96064 L
.6207 .96656 L
.63101 .97067 L
.63645 .97243 L
.64238 .97399 L
.64893 .97526 L
.65514 .97597 L
.66118 .97619 L
.66676 .97594 L
.67279 .97515 L
.67941 .97361 L
.68629 .9712 L
.6927 .96817 L
.70425 .96055 L
.71462 .95103 L
.72628 .93682 L
.73698 .91991 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.678571 0.321429 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.499997 0.221786 0.500005 0.443853 [
[.5 1.0125 -3.5 0 ]
[.5 1.0125 3.5 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -64.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.000 15.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
.82218 .53277 m
.82262 .52659 L
.82294 .52051 L
.8232 .51301 L
.82334 .50549 L
.82337 .4982 L
.8233 .49122 L
.82312 .48332 L
.82281 .47474 L
.82238 .46596 L
.82176 .45638 L
.82025 .43896 L
.81781 .41854 L
.81498 .40067 L
.81152 .38365 L
.80784 .36936 L
.80334 .3557 L
.7981 .34375 L
.79557 .33924 L
.79276 .33507 L
.79023 .332 L
.78751 .32938 L
.78502 .32756 L
.78226 .32617 L
.77974 .32542 L
.77738 .32518 L
.77591 .32524 L
.77436 .32548 L
.77157 .32634 L
.77003 .32705 L
.7686 .32787 L
.76535 .33025 L
.76005 .33571 L
.75457 .34341 L
.74506 .36196 L
.7375 .38195 L
.7248 .42939 L
.71768 .46713 L
.71677 .47218 L
.71594 .4763 L
.71559 .4777 L
.71525 .47883 L
.71497 .47953 L
.71467 .47998 L
.7145 .48011 L
.71434 .48012 L
.71415 .48002 L
.71397 .47981 L
.71365 .47915 L
.71346 .47863 L
Mistroke
.71328 .47804 L
.71259 .47512 L
.71173 .47067 L
.70661 .44255 L
.69817 .40524 L
.6825 .35537 L
.67162 .3291 L
.65821 .30247 L
.63144 .26111 L
.59656 .21983 L
.50996 .13536 L
.46061 .09045 L
.40996 .05081 L
.38287 .03518 L
.36889 .02939 L
.36086 .02691 L
.35331 .02522 L
.34558 .02419 L
.3417 .02396 L
.33745 .02394 L
.32992 .02454 L
.32294 .02588 L
.31869 .02709 L
.3147 .02852 L
.30726 .03197 L
.29933 .03691 L
.29085 .04375 L
.27779 .0579 L
.26399 .07855 L
.25039 .10609 L
.2386 .13746 L
.2287 .17098 L
.22026 .20671 L
.21179 .25219 L
.20536 .29708 L
.2026 .32081 L
.20001 .347 L
.1981 .37 L
.19637 .39546 L
.19489 .42383 L
.19428 .43932 L
.19384 .45371 L
.19334 .47935 L
.19323 .50638 L
.19335 .52102 L
.19357 .53436 L
.19394 .54877 L
.19447 .56375 L
.19567 .58816 L
.19743 .61376 L
Mistroke
.19935 .63525 L
.20178 .65688 L
.20437 .67566 L
.20703 .69169 L
.21322 .72044 L
.21682 .73304 L
.22085 .74442 L
.22486 .7533 L
.22875 .75988 L
.23232 .76431 L
.23624 .76756 L
.23987 .76913 L
.24386 .76933 L
.24802 .76788 L
.25188 .76502 L
.25544 .76108 L
.25863 .75645 L
.26556 .7426 L
.26913 .7332 L
.27235 .72325 L
.2791 .69674 L
.28479 .6663 L
.28733 .64905 L
.28978 .62909 L
.29309 .59315 L
.29443 .57248 L
.29537 .55268 L
.29598 .53362 L
.2963 .51599 L
.29639 .49529 L
.29618 .4755 L
.29564 .45367 L
.29466 .42948 L
.2932 .4041 L
.29144 .38037 L
.28731 .33824 L
.28152 .29403 L
.27301 .24468 L
.26332 .2014 L
.25339 .16654 L
.24142 .13403 L
.22905 .10948 L
.22178 .09889 L
.21826 .09475 L
.21495 .09144 L
.20885 .08681 L
.20211 .08392 L
.19552 .0834 L
.19183 .08414 L
.18848 .08547 L
Mistroke
.18218 .08975 L
.17643 .09578 L
.17024 .10475 L
.16385 .11696 L
.15364 .1437 L
.1482 .16232 L
.14338 .18194 L
.13835 .20627 L
.13333 .2355 L
.12936 .26337 L
.12562 .29499 L
.12247 .32792 L
.1201 .35892 L
.11819 .3909 L
.11684 .42153 L
.11628 .43875 L
.11583 .4577 L
.11553 .47746 L
.11541 .49582 L
.1156 .52832 L
.11635 .56234 L
.11701 .58092 L
.11792 .60063 L
.12008 .63488 L
.12277 .6659 L
.12572 .69226 L
.12876 .71402 L
.1323 .73454 L
.13935 .76467 L
.14361 .77764 L
.14774 .78718 L
.15241 .79482 L
.15507 .79781 L
.15751 .79973 L
.16195 .80127 L
.16604 .80054 L
.17051 .79742 L
.17517 .79155 L
.17913 .7844 L
.18273 .77605 L
.19046 .75146 L
.1944 .73476 L
.19836 .71429 L
.20155 .69445 L
.20458 .67166 L
.2072 .64757 L
.20923 .62462 L
.21091 .60059 L
.21216 .57723 L
.21321 .54902 L
Mistroke
.21356 .53457 L
.2138 .51856 L
.21387 .48991 L
.21351 .46297 L
.2131 .44659 L
.21257 .43109 L
.21122 .40219 L
.20924 .37146 L
.20649 .33877 L
.20095 .28974 L
.19342 .24123 L
.18496 .20087 L
.17623 .16969 L
.1712 .15559 L
.16563 .1428 L
.1593 .13163 L
.15327 .12413 L
.14996 .12128 L
.14636 .1192 L
.14294 .1182 L
.13978 .11813 L
.13381 .1203 L
.12757 .12592 L
.12143 .13503 L
.11598 .14641 L
.10994 .16311 L
.1045 .18242 L
.09574 .22453 L
.09139 .2524 L
.08778 .28053 L
.08461 .31075 L
.08173 .34523 L
.08035 .36567 L
.07925 .3848 L
.07831 .40453 L
.07759 .4231 L
.07662 .46085 L
.07636 .48086 L
.07628 .50219 L
.07641 .5244 L
.07674 .54512 L
.0772 .56342 L
.07787 .5829 L
.07942 .61488 L
.08126 .6426 L
.08386 .67246 L
.08676 .69841 L
.09284 .73784 L
.09673 .75605 L
.10057 .77015 L
Mistroke
.10285 .77693 L
.10536 .78324 L
.11005 .79191 L
.11473 .79694 L
.11907 .79861 L
.12379 .79727 L
.12645 .79508 L
.12891 .79213 L
.13148 .78809 L
.13379 .78358 L
.13882 .77074 L
.14319 .75587 L
.14753 .73704 L
.15441 .69626 L
.15763 .67028 L
.16022 .64405 L
.16255 .61354 L
.1636 .59584 L
.16443 .57901 L
.16545 .55004 L
.1658 .53446 L
.16603 .51766 L
.16611 .49988 L
.16604 .48302 L
.16549 .45143 L
.16451 .42197 L
.1632 .39515 L
.16132 .36629 L
.15885 .33667 L
.15613 .31033 L
.15271 .28308 L
.14538 .23826 L
.14148 .21967 L
.13704 .20191 L
.13265 .18737 L
.12844 .17591 L
.1229 .16419 L
.11992 .15936 L
.11673 .1553 L
.1113 .15095 L
.1082 .1499 L
.1053 .14987 L
.09989 .15231 L
.09502 .1574 L
.08951 .16669 L
.08446 .17882 L
.08025 .19198 L
.07582 .20921 L
.07177 .22862 L
.06775 .25223 L
Mistroke
.06434 .27661 L
.06155 .30071 L
.05703 .35216 L
.055 .38476 L
.05358 .416 L
.05253 .45094 L
.05202 .48848 L
.05212 .524 L
.05273 .55684 L
.0537 .58545 L
.05516 .61518 L
.05722 .6454 L
.05949 .67103 L
.06256 .69797 L
.06585 .72062 L
.06896 .73767 L
.07249 .75317 L
.0766 .76693 L
.08058 .77657 L
.08496 .78354 L
.08746 .78593 L
.08977 .78717 L
.09405 .78706 L
.09852 .78366 L
.10087 .78052 L
.10334 .77617 L
.10769 .76583 L
.1126 .74956 L
.11677 .73129 L
.12047 .71084 L
.12398 .68645 L
.12666 .66335 L
.12912 .63673 L
.13127 .60644 L
.13278 .57677 L
.13346 .55819 L
.13393 .54028 L
.1342 .52404 L
.13435 .5062 L
.13433 .48929 L
.13417 .47336 L
.13353 .44369 L
.13232 .41214 L
.13141 .39468 L
.13043 .37888 L
.12592 .32596 L
.12306 .3013 L
.1195 .27617 L
.11166 .23497 L
.10669 .21614 L
Mistroke
.10183 .20195 L
.09741 .19229 L
.0924 .18473 L
.08706 .18049 L
.08202 .18001 L
.07739 .18264 L
.07259 .18861 L
.06859 .19631 L
.06434 .20743 L
.05995 .22257 L
.05554 .24215 L
.04853 .28561 L
.04496 .31645 L
.04218 .34737 L
.03974 .38354 L
.03876 .40246 L
.03789 .42366 L
.0373 .44253 L
.0369 .45989 L
.03662 .48 L
.03653 .49908 L
.03678 .53264 L
.03715 .55132 L
.03764 .56833 L
.03906 .60165 L
.04088 .63126 L
.04289 .65609 L
.04544 .68075 L
.04864 .70485 L
.05242 .72667 L
.05592 .74217 L
.05999 .75567 L
.06434 .76559 L
.06849 .77123 L
.07068 .77283 L
.0731 .77352 L
.07564 .77306 L
.078 .77156 L
.08229 .76614 L
.08611 .75826 L
.09036 .74589 L
.09418 .73106 L
.09736 .71555 L
.10049 .69681 L
.10534 .65806 L
.10777 .63164 L
.10963 .60524 L
.11095 .58054 L
.11197 .55299 L
.1126 .52239 L
Mistroke
.11272 .4935 L
.11259 .47689 L
.11234 .46179 L
.1119 .44446 L
.11133 .4282 L
.10978 .39642 L
.10784 .3681 L
.1052 .33862 L
.10183 .30959 L
.09881 .28871 L
.09521 .26842 L
.09185 .25295 L
.08795 .23841 L
.08338 .22544 L
.08081 .21985 L
.07837 .21561 L
.07392 .21045 L
.06911 .20849 L
.06455 .21009 L
.06198 .21253 L
.05959 .21581 L
.05489 .22534 L
.05234 .23238 L
.05006 .23986 L
.04619 .25556 L
.04227 .276 L
.03893 .29809 L
.03611 .32122 L
.03308 .35322 L
.03086 .38445 L
.02992 .4015 L
.02908 .41988 L
.02837 .44041 L
.0279 .45951 L
.02751 .49384 L
.02766 .52571 L
.02797 .54376 L
.0284 .55997 L
.02905 .57829 L
.02983 .59519 L
.03143 .6219 L
.03363 .64934 L
.03639 .67536 L
.03936 .69697 L
.04241 .71444 L
.04542 .72802 L
.04891 .74015 L
.05275 .74966 L
.0568 .75587 L
.0591 .7578 L
Mistroke
.0612 .75859 L
.06528 .75756 L
.06909 .75352 L
.07123 .74995 L
.07344 .74519 L
.07729 .73422 L
.08121 .71914 L
.08518 .69896 L
.0883 .67861 L
.09088 .65774 L
.09332 .63289 L
.09545 .6046 L
.09687 .57893 L
.09783 .55402 L
.09847 .52613 L
.09863 .51028 L
.09866 .4957 L
.09842 .47051 L
.09787 .44727 L
.09692 .42222 L
.09551 .39623 L
.0936 .37011 L
.09141 .3468 L
.0864 .30772 L
.08332 .28983 L
.07962 .27276 L
.07549 .25813 L
.0714 .24764 L
.06746 .24081 L
.06378 .23719 L
.05949 .2362 L
.05543 .2385 L
.05113 .24451 L
.04878 .24946 L
.04669 .25491 L
.04278 .26814 L
.03931 .28361 L
.03559 .3052 L
.03254 .32808 L
.02965 .35613 L
.02719 .38854 L
.02567 .41629 L
.02501 .43245 L
.02452 .44763 L
.02395 .47585 L
.02381 .50601 L
.02408 .53273 L
.02468 .55735 L
.0257 .58354 L
.02722 .61045 L
Mistroke
.02916 .63571 L
.03171 .66095 L
.03481 .68423 L
.03804 .70275 L
.04133 .71717 L
.0445 .72764 L
.04831 .73651 L
.05202 .74166 L
.0553 .7436 L
.05891 .74302 L
.06264 .73945 L
.06607 .73345 L
.06918 .72562 L
.07191 .71668 L
.07759 .69083 L
.08041 .67337 L
.08277 .65546 L
.08522 .63228 L
.08709 .60981 L
.08854 .58724 L
.0896 .56527 L
.09038 .5415 L
.09083 .51545 L
.09087 .48917 L
.09054 .46539 L
.08974 .43843 L
.08857 .41369 L
.08715 .39174 L
.08556 .37243 L
.08106 .33307 L
.07827 .31542 L
.07542 .30091 L
.07206 .28745 L
.06823 .27607 L
.06625 .27166 L
.06405 .26785 L
.06194 .26524 L
.05997 .26368 L
.05622 .26307 L
.05413 .26407 L
.05224 .26582 L
.04836 .27203 L
.04645 .27646 L
.0444 .28231 L
.04092 .29514 L
.03789 .30985 L
.03463 .33037 L
.032 .35178 L
.02943 .37927 L
.0275 .40758 L
Mistroke
.02626 .43354 L
.02538 .4621 L
.02502 .48692 L
.02503 .51443 L
.02552 .54355 L
.02601 .55961 L
.02659 .57405 L
.02798 .59969 L
.02987 .62502 L
.03201 .64671 L
.03468 .66783 L
.03752 .68521 L
.04037 .69885 L
.04309 .70906 L
.04623 .71793 L
.04963 .72446 L
.05288 .72803 L
.05672 .72908 L
.06035 .72702 L
.06356 .72271 L
.06697 .71545 L
.06886 .71018 L
.07052 .70473 L
.07407 .69026 L
.07711 .6743 L
.07971 .65727 L
.0837 .6221 L
.08531 .60271 L
.08675 .58044 L
.0877 .56077 L
.08842 .53925 L
.08881 .5187 L
.08892 .49991 L
.08874 .47647 L
.08825 .45513 L
.08736 .43232 L
.08604 .4091 L
.08458 .39003 L
.08297 .37319 L
.07851 .33945 L
.07599 .32577 L
.0731 .31334 L
.07021 .30384 L
.06747 .29719 L
.06414 .29188 L
.06224 .29013 L
.06047 .28932 L
.05722 .28987 L
.05382 .29335 L
.05063 .29946 L
Mistroke
.04733 .30898 L
.04439 .32069 L
.04189 .33357 L
.03921 .35112 L
.03666 .37297 L
.03464 .39588 L
.03314 .41873 L
.03219 .43869 L
.03146 .46095 L
.03107 .48242 L
.03097 .5023 L
.03116 .52429 L
.03171 .54807 L
.03267 .57223 L
.0339 .59381 L
.03555 .61552 L
.03742 .63458 L
.04163 .66566 L
.04434 .68008 L
.04702 .69132 L
.05014 .70123 L
.05358 .70888 L
.05682 .71323 L
.06041 .71512 L
.0638 .71419 L
.06692 .71102 L
.06995 .70576 L
.07262 .69924 L
.07558 .68976 L
.07822 .67903 L
.08092 .66545 L
.08353 .64921 L
.08747 .61602 L
.08922 .59572 L
.09054 .57589 L
.09163 .55341 L
.09208 .54059 L
.09238 .52881 L
.09265 .50909 L
.09263 .48824 L
.09236 .47067 L
.0918 .4517 L
.0909 .43207 L
.0896 .41194 L
.08807 .39414 L
.08644 .37904 L
.08292 .35492 L
.08067 .3435 L
.07843 .33449 L
.07594 .32673 L
Mistroke
.07358 .32137 L
.07079 .31725 L
.06811 .31545 L
.06541 .31572 L
.06252 .31837 L
.05985 .32309 L
.05749 .32926 L
.05484 .33867 L
.05215 .35149 L
.04984 .36589 L
.04792 .38107 L
.04604 .40011 L
.04458 .41958 L
.04355 .43814 L
.04274 .45907 L
.04245 .47027 L
.04224 .4827 L
.04214 .49579 L
.04216 .50804 L
.04246 .52994 L
.04315 .55305 L
.04415 .57415 L
.04537 .59286 L
.047 .61226 L
.04907 .63128 L
.0532 .65887 L
.05588 .6718 L
.05856 .68194 L
.06111 .68938 L
.06388 .69536 L
.06631 .69896 L
.069 .70129 L
.07194 .70194 L
.07506 .70051 L
.07797 .6972 L
.08057 .69261 L
.08345 .68555 L
.08604 .67734 L
.08894 .66566 L
.09141 .65336 L
.0958 .62401 L
.0978 .60586 L
.0994 .58764 L
.10052 .57142 L
.10146 .55373 L
.10205 .53839 L
.10247 .52135 L
.10266 .50314 L
.10255 .48374 L
.10216 .46585 L
Mistroke
.10157 .44996 L
.10067 .4334 L
.09943 .41673 L
.09802 .40215 L
.09655 .38999 L
.09462 .37718 L
.09229 .3653 L
.08992 .35616 L
.08761 .34963 L
.08513 .34491 L
.08275 .3424 L
.08012 .34183 L
.07864 .34253 L
.0773 .3438 L
.07592 .34576 L
.07466 .34816 L
.07319 .35174 L
.07188 .35565 L
.06958 .36452 L
.0673 .3762 L
.06549 .38813 L
.06398 .40062 L
.06254 .41566 L
.06126 .43313 L
.06074 .44236 L
.06026 .4527 L
.05963 .47213 L
.05933 .49161 L
.05934 .5099 L
.0596 .52696 L
.06006 .54284 L
.0608 .55997 L
.06187 .57788 L
.0632 .59489 L
.06487 .61176 L
.0685 .63863 L
.07091 .65186 L
.07329 .6623 L
.0762 .67237 L
.0791 .67982 L
.08188 .6849 L
.0845 .68801 L
.08741 .68968 L
.0905 .68947 L
.0936 .68726 L
.09532 .68515 L
.09687 .68271 L
.0998 .67658 L
.10248 .66916 L
.10544 .65873 L
Mistroke
.10799 .64748 L
.11058 .63348 L
.11301 .61717 L
.11478 .60258 L
.11645 .58573 L
.11771 .56965 L
.11863 .55466 L
.11906 .54606 L
.11943 .53668 L
.11974 .52675 L
.11994 .51739 L
.12005 .50867 L
.12009 .49951 L
.11995 .48335 L
.11959 .46885 L
.11896 .45388 L
.11816 .4405 L
.11725 .42898 L
.11599 .41656 L
.11439 .40439 L
.1127 .39437 L
.11099 .38647 L
.10925 .38027 L
.10728 .3751 L
.10536 .37173 L
.10355 .36997 L
.1019 .36951 L
.10009 .37023 L
.09823 .37237 L
.09652 .37562 L
.09459 .38096 L
.09285 .38749 L
.09138 .39451 L
.0899 .40335 L
.08844 .41427 L
.0871 .42723 L
.08614 .43929 L
.08528 .45352 L
.08467 .46808 L
.08431 .48216 L
.08416 .49805 L
.08418 .50707 L
.08427 .51532 L
.08465 .53203 L
.08499 .54142 L
.08538 .55001 L
.08627 .56554 L
.08748 .58146 L
.09023 .60764 L
.09344 .62929 L
Mistroke
.09759 .64913 L
.10016 .65824 L
.10262 .66518 L
.10537 .67112 L
.10695 .67374 L
.1084 .67568 L
.11125 .67827 L
.11397 .67927 L
.11552 .67923 L
.11715 .6787 L
.12006 .67656 L
.12166 .67471 L
.12313 .67258 L
.1264 .66633 L
.12913 .65938 L
.1316 .65162 L
.13586 .63429 L
.13982 .61224 L
.14173 .59852 L
.14326 .58537 L
.14544 .56088 L
.14629 .54776 L
.14696 .53393 L
.14736 .5219 L
.14758 .51087 L
.14765 .499 L
.14754 .4867 L
.14739 .4799 L
.1472 .47379 L
.14693 .46726 L
.14659 .4606 L
.14587 .44999 L
.1449 .43929 L
.14388 .43069 L
.14264 .42253 L
.14136 .41592 L
.1401 .41085 L
.13859 .40627 L
.1378 .40444 L
.13691 .40282 L
.13531 .401 L
.13379 .40049 L
.13292 .40073 L
.13201 .40141 L
.1304 .40367 L
.12953 .40552 L
.12873 .40762 L
.12699 .41367 L
.12558 .42038 L
.12437 .42787 L
Mistroke
.12338 .43559 L
.12245 .44465 L
.12161 .45543 L
.121 .46614 L
.12054 .47837 L
.12037 .48559 L
.12027 .49251 L
.12025 .50517 L
.12033 .51237 L
.12046 .51896 L
.12086 .53188 L
.12142 .54405 L
.1223 .55817 L
.12332 .57091 L
.12477 .58531 L
.12636 .59815 L
.12951 .61808 L
.13359 .63693 L
.13809 .65172 L
.1408 .65832 L
.14336 .66322 L
.14577 .66677 L
.14838 .66952 L
.15063 .67105 L
.15314 .67187 L
.15583 .67173 L
.15734 .67121 L
.15872 .67046 L
.16124 .66839 L
.16385 .66529 L
.1661 .66184 L
.16844 .65743 L
.17247 .64775 L
.17689 .63368 L
.18049 .61892 L
.18374 .60217 L
.18673 .58253 L
.18916 .56132 L
.19007 .55109 L
.19078 .54146 L
.1913 .53272 L
.19174 .52337 L
.192 .51509 L
.19215 .50764 L
.1922 .4991 L
.19214 .49172 L
.19194 .48366 L
.19164 .47659 L
.19122 .46994 L
.19066 .46333 L
Mistroke
.18996 .45724 L
.18922 .45235 L
.18845 .44849 L
.18771 .4456 L
.18681 .44304 L
.18592 .4414 L
.18494 .44047 L
.18444 .44035 L
.18389 .44048 L
.18292 .44141 L
.18204 .44306 L
.18152 .44442 L
.18104 .44596 L
.18018 .44951 L
.17932 .45425 L
.1785 .46045 L
.17788 .46669 L
.17741 .47307 L
.17721 .47664 L
.17702 .48072 L
.17686 .48517 L
.17675 .48947 L
.17664 .49777 L
.17667 .50569 L
.17673 .5102 L
.17685 .5152 L
.17716 .5245 L
.17757 .53293 L
.17816 .54236 L
.17982 .56162 L
.18189 .57924 L
.18431 .59521 L
.1877 .61285 L
.19187 .62961 L
.19586 .64212 L
.20061 .65366 L
.20611 .66338 L
.20932 .66753 L
.2123 .67049 L
.21512 .67256 L
.21673 .67344 L
.21822 .67406 L
.22096 .67474 L
.22388 .67483 L
.22656 .67436 L
.22947 .67326 L
.2322 .67168 L
.23471 .66977 L
.23936 .66508 L
.24414 .65869 L
Mistroke
.25426 .63972 L
.26219 .6191 L
.27392 .57665 L
.28058 .54315 L
.2829 .52989 L
.28377 .52533 L
.28445 .52236 L
.28478 .52122 L
.28509 .52047 L
.2854 .52002 L
.28558 .51991 L
.28574 .51991 L
.28606 .52019 L
.28624 .52051 L
.28641 .52091 L
.28678 .52204 L
.2872 .5237 L
.29827 .5801 L
.31074 .62516 L
.3203 .65177 L
.33083 .67608 L
.35673 .72206 L
.39061 .76605 L
.46779 .84376 L
.51667 .88938 L
.54603 .91538 L
.57518 .93879 L
.60246 .9571 L
.61821 .96545 L
.63282 .97131 L
.63687 .97257 L
.64118 .97373 L
.64896 .97528 L
.65373 .97587 L
.65822 .97616 L
.66226 .97619 L
.66662 .97596 L
.67051 .97552 L
.67477 .97477 L
.6792 .97367 L
.68332 .97235 L
.69067 .96921 L
.69848 .96472 L
.70604 .95908 L
.71294 .95275 L
.72812 .93417 L
.74089 .91261 L
.75364 .88422 L
.76419 .85399 L
.77324 .82163 L
Mistroke
.78211 .78191 L
.79028 .73482 L
.79702 .68292 L
.80005 .65265 L
.80232 .62467 L
.80402 .59819 L
.80541 .56941 L
.80628 .5423 L
.80671 .51755 L
.80677 .48904 L
.80639 .46302 L
.80599 .44841 L
.80551 .43534 L
.80405 .40693 L
.80217 .38109 L
.79962 .35483 L
.79677 .33199 L
.79377 .31269 L
.79092 .29748 L
.78761 .28273 L
.78109 .2606 L
.77705 .25053 L
.77263 .24214 L
.76876 .23677 L
.76445 .23279 L
.76207 .23144 L
.75981 .23069 L
.75558 .23066 L
.75322 .2314 L
.75104 .23257 L
.74867 .23437 L
.74618 .23686 L
.74211 .24226 L
.73839 .24871 L
.73442 .25733 L
.73035 .26817 L
.72313 .29337 L
.71725 .32146 L
.7141 .34066 L
.71146 .35997 L
.70938 .37847 L
.7075 .39889 L
.70612 .41779 L
.70494 .43919 L
.70418 .45919 L
.70375 .47824 L
.70358 .50118 L
.70375 .52239 L
.70399 .53424 L
.70435 .54718 L
Mistroke
.70532 .57084 L
.70651 .59197 L
.7079 .6118 L
.71209 .6567 L
.71751 .69955 L
.72476 .74388 L
.73232 .78067 L
.74138 .81627 L
.74996 .84367 L
.76 .86938 L
.76643 .88269 L
.77254 .89322 L
.77841 .90148 L
.78498 .90862 L
.79096 .9132 L
.79659 .91584 L
.80257 .91682 L
.80899 .91572 L
.8159 .91193 L
.81977 .90857 L
.82332 .90464 L
.82973 .89542 L
.83636 .8827 L
.84722 .85369 L
.85299 .83328 L
.85807 .81163 L
.86634 .76676 L
.87357 .71259 L
.87839 .66191 L
.88053 .63184 L
.88212 .60323 L
.88348 .56945 L
.88428 .53735 L
.88459 .50862 L
.88449 .4778 L
.88388 .44493 L
.88267 .41124 L
.8812 .3837 L
.87913 .35493 L
.87652 .32698 L
.8737 .30312 L
.8699 .27757 L
.86608 .25729 L
.86241 .24164 L
.85821 .22738 L
.85355 .21541 L
.84901 .20706 L
.84479 .20196 L
.8401 .19903 L
.83518 .19892 L
Mistroke
.83061 .20146 L
.82638 .20608 L
.82259 .21212 L
.81833 .22118 L
.81444 .23171 L
.8063 .2619 L
.80259 .28024 L
.79886 .30262 L
.79602 .32324 L
.79332 .34694 L
.79115 .37038 L
.78946 .39311 L
.7879 .42088 L
.78726 .43592 L
.78673 .45222 L
.78634 .46959 L
.78613 .48616 L
.78608 .50114 L
.78616 .51747 L
.7867 .5474 L
.78717 .5625 L
.78782 .57907 L
.78936 .60819 L
.79122 .63506 L
.79659 .69074 L
.80315 .73878 L
.81195 .78594 L
.81704 .80726 L
.82291 .82779 L
.82888 .84476 L
.8346 .85781 L
.84025 .86783 L
.84636 .87563 L
.85194 .88007 L
.85718 .88194 L
.86294 .88138 L
.86907 .87767 L
.87499 .87085 L
.88034 .86174 L
.88604 .84863 L
.89183 .83122 L
.90078 .79422 L
.90535 .7691 L
.90925 .74313 L
.91259 .71644 L
.91538 .68948 L
.91759 .66383 L
.91959 .63548 L
.92132 .60391 L
.92252 .57402 L
Mistroke
.92341 .53809 L
.92372 .50549 L
.92355 .47144 L
.92292 .44029 L
.92172 .40722 L
.91988 .37343 L
.91736 .34036 L
.91446 .31162 L
.91146 .28825 L
.90783 .26568 L
.90412 .24745 L
.9004 .233 L
.89633 .22076 L
.89164 .21068 L
.8875 .20493 L
.88365 .20201 L
.8794 .20137 L
.87493 .20354 L
.87006 .20925 L
.86574 .21733 L
.86092 .2299 L
.8566 .24479 L
.84961 .27784 L
.84612 .2998 L
.84324 .32191 L
.84068 .34593 L
.83835 .3733 L
.83722 .38963 L
.83633 .40491 L
.83561 .41969 L
.83497 .43568 L
.83447 .45241 L
.83413 .46812 L
.83391 .48696 L
.83387 .50413 L
.83397 .52048 L
.83424 .53817 L
.83515 .57011 L
.8365 .59988 L
.83813 .6265 L
.84049 .6564 L
.84317 .68364 L
.84896 .72876 L
.8566 .77171 L
.86108 .79112 L
.86636 .80973 L
.87219 .82575 L
.87495 .83183 L
.8779 .83734 L
.88337 .84494 L
Mistroke
.88847 .84906 L
.89401 .85033 L
.89714 .84956 L
.90004 .84786 L
.90584 .84153 L
.90905 .83625 L
.91195 .83028 L
.91714 .81662 L
.92236 .79843 L
.93057 .75834 L
.93466 .73114 L
.93805 .70317 L
.94138 .66845 L
.94395 .6334 L
.94574 .6006 L
.9471 .56391 L
.94757 .54477 L
.94789 .52355 L
.94801 .50142 L
.94793 .48076 L
.94731 .4445 L
.9467 .42461 L
.94598 .40676 L
.9442 .37437 L
.94206 .34568 L
.93978 .32179 L
.93694 .29812 L
.93347 .27528 L
.92943 .25469 L
.92571 .24022 L
.92141 .22773 L
.91724 .21941 L
.91334 .21462 L
.90878 .21243 L
.90444 .21362 L
.90049 .21745 L
.89688 .22329 L
.89302 .23213 L
.88907 .2442 L
.88467 .26174 L
.88092 .28078 L
.87719 .30458 L
.87375 .33262 L
.8712 .35912 L
.86923 .38533 L
.86754 .41542 L
.86682 .43279 L
.86631 .44887 L
.86574 .47909 L
.86564 .50736 L
Mistroke
.86601 .53846 L
.86639 .5541 L
.86695 .57126 L
.86825 .59952 L
.87011 .62918 L
.8723 .65616 L
.87467 .67981 L
.87781 .70552 L
.88114 .72803 L
.88823 .76469 L
.89262 .78169 L
.8969 .79485 L
.9018 .80632 L
.90433 .81086 L
.90715 .81485 L
.91195 .81913 L
.91636 .82032 L
.92145 .81841 L
.92623 .81327 L
.93054 .80569 L
.93443 .79623 L
.93854 .78321 L
.94268 .76641 L
.94723 .74284 L
.95101 .7179 L
.95466 .6873 L
.95789 .65189 L
.96013 .61892 L
.96172 .58686 L
.9624 .56803 L
.96288 .55071 L
.96326 .5306 L
.96345 .51154 L
.96337 .47895 L
.96276 .445 L
.96181 .41689 L
.96033 .38719 L
.95826 .35726 L
.95551 .3277 L
.95247 .30273 L
.94934 .28265 L
.94563 .26412 L
.94189 .24992 L
.93836 .23998 L
.93441 .23226 L
.92999 .22748 L
.92774 .22651 L
.92527 .22655 L
.92091 .22939 L
.91691 .23518 L
Mistroke
.91299 .24392 L
.90941 .25479 L
.90319 .28141 L
.90005 .29951 L
.89741 .31808 L
.89483 .3401 L
.89243 .36566 L
.89046 .39291 L
.88905 .41905 L
.88808 .44481 L
.88745 .47252 L
.88725 .50335 L
.88753 .53211 L
.88788 .54855 L
.88833 .56339 L
.889 .58033 L
.88978 .5961 L
.8916 .62482 L
.89403 .65381 L
.89959 .70093 L
.90328 .72376 L
.90708 .74259 L
.91157 .76009 L
.91418 .76825 L
.9167 .77488 L
.91896 .77982 L
.92145 .78421 L
.92586 .78948 L
.92839 .79106 L
.93108 .79162 L
.93588 .78968 L
.94027 .78451 L
.94427 .77676 L
.94851 .76506 L
.95282 .74892 L
.95714 .72754 L
.96134 .69999 L
.96479 .67032 L
.96745 .6402 L
.9694 .61131 L
.97101 .57794 L
.9716 .56074 L
.97208 .54201 L
.97249 .50785 L
.97235 .47503 L
.97176 .44507 L
.97059 .41328 L
.96971 .39616 L
.96879 .38111 L
.96653 .35236 L
Mistroke
.96357 .32421 L
.96032 .30092 L
.957 .28258 L
.95372 .26856 L
.95048 .25802 L
.94678 .24937 L
.9427 .24354 L
.94062 .24197 L
.93835 .24128 L
.93422 .24272 L
.93025 .24739 L
.92665 .25449 L
.9227 .26571 L
.91876 .28089 L
.91562 .29638 L
.91247 .31577 L
.90944 .33921 L
.90668 .3668 L
.90457 .39479 L
.90309 .42155 L
.90204 .44951 L
.90148 .47586 L
.90133 .50506 L
.90143 .51979 L
.90168 .53596 L
.90244 .56272 L
.90371 .5908 L
.90532 .61633 L
.90714 .63862 L
.90932 .66014 L
.91197 .68141 L
.91752 .71459 L
.92134 .73119 L
.92518 .74395 L
.92878 .75285 L
.93279 .75963 L
.93644 .76305 L
.94047 .7639 L
.94468 .76149 L
.94854 .75617 L
.95207 .74854 L
.95518 .73937 L
.9586 .72625 L
.96165 .71142 L
.96459 .69369 L
.96745 .67212 L
.96963 .65165 L
.97169 .62756 L
.97355 .59913 L
.97436 .583 L
Mistroke
.97499 .56769 L
.97579 .5397 L
.97618 .50938 L
.97619 .49264 L
.97607 .47728 L
.97579 .46057 L
.97534 .44313 L
.97421 .41467 L
.97338 .39909 L
.97247 .38498 L
.97051 .36057 L
.96832 .33927 L
.96543 .3173 L
.96249 .2999 L
.95943 .28574 L
.95649 .27523 L
.95294 .26592 L
.94949 .25998 L
.94622 .25694 L
.9432 .25623 L
.93988 .25773 L
.93643 .26183 L
.933 .26855 L
.92947 .27845 L
.92629 .29024 L
.92356 .30288 L
.92059 .31986 L
.91768 .34066 L
.91527 .36237 L
.91339 .38368 L
.91186 .40561 L
.9106 .42961 L
.90971 .45438 L
.90917 .48194 L
.90909 .50602 L
.90938 .5316 L
.91002 .55537 L
.91089 .57645 L
.91241 .60243 L
.9142 .62512 L
.91655 .64833 L
.91945 .67061 L
.92208 .68671 L
.92516 .7018 L
.92878 .71553 L
.93236 .72546 L
.93433 .72956 L
.93646 .73297 L
.94034 .73658 L
.94251 .73715 L
Mistroke
.94455 .73676 L
.94678 .73527 L
.94916 .73244 L
.95107 .72921 L
.95311 .72472 L
.9571 .7127 L
.96057 .69815 L
.96356 .68182 L
.96641 .66187 L
.96879 .64073 L
.97063 .6201 L
.97228 .59622 L
.97366 .5688 L
.97417 .55455 L
.9746 .53862 L
.975 .51011 L
.97495 .48332 L
.97447 .45587 L
.97401 .44082 L
.97348 .42743 L
.97214 .40221 L
.97054 .3798 L
.96825 .35558 L
.9658 .33552 L
.96276 .31627 L
.95922 .29938 L
.95613 .28843 L
.95267 .27958 L
.94929 .27402 L
.94616 .27133 L
.94245 .27106 L
.94037 .27227 L
.93845 .27424 L
.935 .27993 L
.93144 .28882 L
.92845 .29895 L
.92585 .31 L
.92322 .32364 L
.92059 .34043 L
.91679 .37262 L
.91509 .39186 L
.91377 .4106 L
.91251 .43398 L
.91168 .45665 L
.91123 .4773 L
.91106 .49978 L
.91125 .52416 L
.9115 .53631 L
.91188 .54951 L
.91285 .57227 L
Mistroke
.91407 .59271 L
.91571 .61354 L
.91782 .63411 L
.9199 .65034 L
.92241 .66604 L
.92566 .68187 L
.92897 .69383 L
.9306 .69845 L
.93236 .70256 L
.93559 .70789 L
.93873 .7105 L
.94211 .71054 L
.94529 .70794 L
.94812 .70335 L
.95136 .6953 L
.95312 .68951 L
.95469 .68338 L
.95741 .67038 L
.9601 .65387 L
.96224 .63725 L
.96397 .62056 L
.9655 .60232 L
.96668 .58439 L
.96776 .56264 L
.96857 .538 L
.96895 .51578 L
.96901 .49189 L
.96869 .46709 L
.96833 .45329 L
.9679 .44077 L
.96684 .41835 L
.96537 .39578 L
.96375 .37679 L
.962 .36028 L
.95987 .34398 L
.95727 .32802 L
.9544 .31426 L
.95114 .3024 L
.94795 .29408 L
.94486 .28866 L
.94306 .28661 L
.94116 .28528 L
.93773 .285 L
.93582 .286 L
.93406 .28767 L
.93215 .29029 L
.93013 .29399 L
.92684 .30221 L
.92345 .31381 L
.92046 .32714 L
Mistroke
.91791 .34129 L
.91373 .37228 L
.91198 .38965 L
.91036 .40982 L
.9091 .43031 L
.90821 .45032 L
.90766 .46856 L
.90735 .48857 L
.90734 .51019 L
.90748 .52215 L
.9077 .53286 L
.90838 .5533 L
.9093 .57183 L
.91041 .58852 L
.91184 .60513 L
.91496 .63179 L
.91698 .64466 L
.91903 .65522 L
.92143 .66511 L
.92414 .67357 L
.92689 .67958 L
.92849 .68199 L
.93 .68358 L
.93308 .68477 L
.93482 .68423 L
.93639 .68299 L
.93902 .67925 L
.94182 .67283 L
.9446 .66361 L
.94704 .65282 L
.94971 .63728 L
.95194 .62023 L
.95368 .60314 L
.95525 .583 L
.95657 .55943 L
.95706 .54707 L
.95747 .53318 L
.9577 .52115 L
.95784 .5081 L
.95786 .49572 L
.95778 .48441 L
.95736 .46228 L
.95701 .45124 L
.95653 .43921 L
.95542 .41857 L
.95409 .40006 L
.95219 .37973 L
.95016 .36263 L
.94763 .34583 L
.94468 .33059 L
Mistroke
.94208 .3202 L
.93914 .31122 L
.93625 .30484 L
.93356 .30084 L
.93034 .29834 L
.92851 .29798 L
.92682 .29832 L
.92373 .30057 L
.92052 .30522 L
.91758 .31161 L
.9145 .32072 L
.91175 .33121 L
.90935 .34246 L
.90532 .36718 L
.90339 .3827 L
.90185 .39763 L
.90039 .4149 L
.89915 .43382 L
.89863 .44392 L
.89816 .45512 L
.89758 .47498 L
.89734 .49373 L
.8974 .51362 L
.89776 .53198 L
.89834 .5482 L
.89914 .56382 L
.90024 .57955 L
.90137 .59215 L
.90279 .60506 L
.90451 .61759 L
.90657 .62943 L
.90869 .63891 L
.91074 .64603 L
.91278 .65133 L
.91472 .65495 L
.9169 .65742 L
.91925 .65831 L
.92172 .65725 L
.92403 .65439 L
.92605 .65028 L
.92817 .64422 L
.93037 .63578 L
.93224 .62647 L
.93423 .61393 L
.93592 .60039 L
.93718 .5876 L
.93834 .57296 L
.93935 .55586 L
.94005 .53921 L
.94035 .52868 L
Mistroke
.94055 .51885 L
.94067 .50793 L
.94069 .49632 L
.94047 .47668 L
.94021 .46558 L
.93987 .45531 L
.93901 .43642 L
.93797 .41977 L
.93647 .40143 L
.93478 .38516 L
.93058 .35594 L
.92812 .34361 L
.9252 .33211 L
.92257 .32416 L
.91961 .31756 L
.91674 .31322 L
.91406 .31089 L
.91251 .31026 L
.91086 .31014 L
.9079 .31136 L
.90611 .31301 L
.90443 .31516 L
.90135 .32071 L
.89822 .32865 L
.89547 .3377 L
.89249 .35011 L
.88991 .36357 L
.88796 .37578 L
.88605 .39005 L
.8833 .41695 L
.88209 .43297 L
.88109 .45039 L
.88048 .46542 L
.88005 .48204 L
.8799 .49729 L
.87996 .51104 L
.88023 .52577 L
.88076 .54072 L
.88141 .55317 L
.88217 .56418 L
.88316 .57553 L
.88438 .58672 L
.88602 .59841 L
.8877 .60776 L
.88971 .6163 L
.89078 .61993 L
.89198 .62325 L
.89404 .62746 L
.89602 .62979 L
.89724 .63045 L
Mistroke
.89841 .63052 L
.90058 .62922 L
.9025 .62644 L
.90449 .62185 L
.90629 .61599 L
.90784 .60945 L
.90953 .60031 L
.91119 .58879 L
.91255 .5765 L
.91362 .56411 L
.91454 .54997 L
.91519 .5358 L
.91559 .52255 L
.91582 .50771 L
.91581 .49124 L
.9157 .48285 L
.91551 .47359 L
.91496 .45728 L
.91421 .4422 L
.91329 .42821 L
.91211 .41398 L
.9095 .39021 L
.90602 .3677 L
.90378 .35663 L
.90155 .34756 L
.89897 .33909 L
.89603 .33166 L
.89464 .32888 L
.89315 .32638 L
.89043 .32302 L
.88778 .32117 L
.88528 .32065 L
.88254 .3214 L
.87963 .32372 L
.87804 .32564 L
.87659 .32782 L
.87338 .33411 L
.87066 .34114 L
.86791 .35003 L
.86314 .37053 L
.85949 .39234 L
.85663 .41553 L
.85532 .42931 L
.85431 .44241 L
.85347 .45638 L
.85291 .46911 L
.85268 .47611 L
.8525 .48366 L
.85234 .49716 L
.85238 .5084 L
Mistroke
.8526 .52036 L
.85303 .53229 L
.8536 .54284 L
.85428 .55207 L
.855 .55993 L
.85699 .57537 L
.85828 .58247 L
.85977 .58877 L
.86126 .59343 L
.86268 .59655 L
.86357 .59793 L
.86439 .59883 L
.86531 .59941 L
.86628 .59956 L
.86791 .59872 L
.86882 .59764 L
.86966 .59624 L
.87124 .5925 L
.87268 .58769 L
.87389 .58238 L
.87511 .57557 L
.87631 .56702 L
.87742 .55674 L
.87822 .54706 L
.87858 .54159 L
.87891 .53553 L
.87938 .52429 L
.87965 .51335 L
.87973 .50647 L
.87976 .49986 L
.87966 .48727 L
.87934 .47376 L
.87885 .46124 L
.87809 .44756 L
.87704 .4333 L
.87478 .4108 L
.8721 .39132 L
.86858 .3723 L
.86422 .3552 L
.86159 .34742 L
.85905 .34133 L
.85615 .33595 L
.85463 .33373 L
.85297 .33174 L
.85136 .33023 L
.84987 .3292 L
.84844 .32851 L
.84693 .32811 L
.8443 .3282 L
.84142 .32942 L
Mistroke
.83861 .33172 L
.8361 .33473 L
.83326 .33925 L
.83065 .34447 L
.82625 .35585 L
.8219 .37084 L
.81829 .38684 L
.81496 .40564 L
.81238 .42433 L
.81053 .44182 L
.80904 .46114 L
.80845 .47186 L
.80808 .48157 L
.80794 .48674 L
.80784 .49153 L
.80778 .5002 L
.80786 .50907 L
.80797 .51384 L
.80811 .51807 L
.80844 .52516 L
.80892 .53214 L
.80947 .53808 L
.81004 .54294 L
.8108 .54789 L
.81172 .55234 L
.81216 .55403 L
.81265 .5556 L
.81355 .55779 L
.8145 .55917 L
.81504 .55957 L
.81554 .55969 L
.81646 .55933 L
.81741 .5581 L
.81791 .55709 L
.81843 .55576 L
.81933 .55267 L
.82032 .54789 L
.82113 .54255 L
.82174 .53735 L
.82223 .53193 L
.82268 .52542 L
.82304 .5178 L
.82317 .51377 L
.82327 .50922 L
.82336 .50057 L
.82329 .49173 L
.82311 .48322 L
.82278 .47432 L
.82235 .46576 L
.82121 .44952 L
Mistroke
.81949 .43201 L
.81707 .41349 L
.81402 .39556 L
.81004 .37753 L
.80525 .36106 L
.80028 .34824 L
.79526 .33871 L
.79046 .33221 L
.78773 .32952 L
.78628 .32836 L
.78472 .32732 L
.78185 .32594 L
.77918 .32526 L
.77665 .32511 L
.77388 .3255 L
.771 .32649 L
.76835 .32793 L
.76587 .32971 L
.76365 .33168 L
.75877 .33719 L
.75372 .34465 L
.74854 .35422 L
.74006 .37442 L
.73328 .39524 L
.72746 .41735 L
.72026 .45206 L
.71777 .46624 L
.71608 .47535 L
.71571 .477 L
.71534 .47837 L
.71513 .47899 L
.71495 .47943 L
.71478 .47977 L
.71461 .47999 L
.7143 .48013 L
.71402 .47996 L
.71371 .47944 L
.71336 .47852 L
.71304 .47738 L
.71273 .47609 L
.71197 .47233 L
.71024 .46267 L
.7038 .4292 L
.69204 .38369 L
.67582 .33879 L
.6521 .29195 L
.62071 .24735 L
.54864 .1719 L
.46329 .09268 L
.43692 .07053 L
Mistroke
.40657 .04847 L
.39223 .03986 L
.37665 .03226 L
.369 .0293 L
.36175 .02703 L
.35521 .02546 L
.34811 .02432 L
.34112 .02381 L
.33459 .02394 L
.32742 .0248 L
.31976 .02662 L
.31593 .02791 L
.31178 .02961 L
.30426 .03355 L
.29702 .03847 L
.29038 .04403 L
.27868 .05664 L
.2662 .07466 L
.25378 .0983 L
.24283 .12511 L
.23177 .15958 L
.2225 .19625 L
.21361 .24112 L
.20576 .29364 L
.20248 .32154 L
.19948 .35261 L
.19731 .3805 L
.19551 .41035 L
.19433 .43733 L
.19384 .45263 L
.19351 .4669 L
.19321 .49173 L
.19328 .51798 L
.19377 .54372 L
.19457 .56689 L
.19583 .59139 L
.1976 .61623 L
.19966 .63858 L
.20192 .65828 L
.20691 .69125 L
.21269 .71852 L
.21861 .73858 L
.2219 .74712 L
.22563 .7549 L
.22963 .76125 L
.23345 .76555 L
.23774 .76851 L
.23993 .76928 L
.24234 .76958 L
.24659 .7687 L
Mistroke
.25056 .7663 L
.25282 .76424 L
.25516 .76157 L
.25929 .7555 L
.26361 .74719 L
.26815 .73609 L
.27526 .71302 L
.28195 .68289 L
.28726 .64989 L
.29111 .61664 L
.2927 .59862 L
.29409 .57888 L
.29502 .56153 L
.29578 .54198 L
.29627 .52049 L
.2964 .50824 L
.29642 .49695 L
.2962 .47479 L
.29567 .45353 L
.29489 .43365 L
.29376 .41241 L
.29094 .37421 L
.28629 .32924 L
.28088 .28956 L
.27402 .24967 L
.26519 .20877 L
.25462 .17025 L
.24366 .13927 L
.23257 .11545 L
.22193 .09894 L
.21587 .09217 L
.20919 .08688 L
.20283 .08397 L
.19692 .08318 L
.19058 .08442 L
.1838 .08828 L
.17748 .09439 L
.17179 .10211 L
.16531 .11375 L
.15848 .12968 L
.14689 .16717 L
.14113 .19208 L
.13632 .21718 L
.13162 .24668 L
.12713 .28115 L
.12358 .31521 L
.12085 .34797 L
.11874 .38025 L
.11706 .41506 L
.11601 .44837 L
Mistroke
.11564 .46722 L
.11544 .48462 L
.11545 .51626 L
.11597 .54923 L
.11686 .57781 L
.11806 .60373 L
.11977 .63094 L
.12204 .65859 L
.12473 .68432 L
.12811 .70995 L
.13209 .73363 L
.13615 .75266 L
.14015 .76752 L
.14412 .77911 L
.14888 .78948 L
.15333 .7961 L
.15734 .79976 L
.1618 .80139 L
.16645 .80049 L
.17078 .79729 L
.17477 .7923 L
.17834 .78612 L
.18236 .77713 L
.18605 .76683 L
.19367 .73825 L
.19988 .70548 L
.20555 .66362 L
.20813 .63797 L
.21008 .61357 L
.21163 .58847 L
.21273 .56435 L
.21353 .53726 L
.2139 .5077 L
.21391 .49267 L
.21376 .47627 L
.21312 .44638 L
.21201 .41732 L
.21057 .39066 L
.20696 .34356 L
.20435 .31761 L
.20154 .29403 L
.19488 .24933 L
.18634 .20649 L
.17626 .16966 L
.17008 .15263 L
.16407 .13959 L
.16071 .13368 L
.15749 .12893 L
.15138 .12226 L
.14791 .11983 L
Mistroke
.1447 .11846 L
.14117 .11793 L
.13744 .11849 L
.13171 .12166 L
.12565 .12823 L
.12005 .13746 L
.11508 .14846 L
.10948 .16442 L
.10371 .18547 L
.09861 .20884 L
.09429 .233 L
.08715 .2858 L
.08406 .31647 L
.08133 .35053 L
.07941 .38138 L
.07803 .41081 L
.07697 .44359 L
.07636 .47883 L
.07626 .49875 L
.07633 .51702 L
.07657 .53687 L
.07702 .55758 L
.07821 .59142 L
.07912 .60998 L
.08013 .62685 L
.08237 .65669 L
.08482 .68201 L
.08808 .70861 L
.09157 .73103 L
.09564 .75153 L
.09959 .76704 L
.10188 .77434 L
.10443 .78117 L
.10917 .7907 L
.11375 .7963 L
.11864 .7987 L
.12284 .79793 L
.1274 .79418 L
.13014 .79047 L
.13269 .78597 L
.13735 .77509 L
.14213 .75996 L
.14699 .7398 L
.15089 .71932 L
.15462 .69492 L
.15745 .67206 L
.16013 .64526 L
.16221 .61888 L
.16376 .59329 L
.16499 .56537 L
Mistroke
.16581 .53479 L
.16613 .50576 L
.16601 .47813 L
.16556 .45329 L
.16471 .42648 L
.16335 .39744 L
.16134 .36616 L
.15868 .33457 L
.15569 .30629 L
.14922 .25968 L
.14505 .23638 L
.14085 .21679 L
.1319 .18502 L
.12683 .17199 L
.12124 .16124 L
.11575 .15415 L
.11051 .15046 L
.10578 .14968 L
.10068 .15162 L
.09602 .15598 L
.09101 .16363 L
.08592 .17481 L
.08135 .18811 L
.07372 .21865 L
.06982 .23932 L
.06654 .26018 L
.06029 .31294 L
.05745 .34615 L
.05531 .37889 L
.05361 .41455 L
.05258 .4479 L
.05223 .46643 L
.05202 .48669 L
.0521 .52335 L
.05272 .55692 L
.05372 .58646 L
.05538 .61907 L
.0574 .64798 L
.05966 .67293 L
.06204 .69409 L
.06834 .7347 L
.07206 .7516 L
.0763 .76621 L
.08051 .77656 L
.08446 .78305 L
.08918 .78706 L
.09186 .78762 L
.09435 .78705 L
.09888 .78337 L
.10113 .78023 L
Mistroke
.10359 .77579 L
.10834 .76408 L
.11249 .75012 L
.11676 .73151 L
.12086 .70851 L
.12672 .66297 L
.12936 .634 L
.13135 .6054 L
.13282 .57621 L
.13338 .56112 L
.13386 .5443 L
.13432 .51415 L
.13432 .48567 L
.13411 .46844 L
.13378 .45212 L
.13276 .42176 L
.13199 .40504 L
.13114 .38974 L
.12875 .35602 L
.12613 .32775 L
.12325 .30263 L
.11688 .2604 L
.1128 .23989 L
.10878 .22333 L
.10409 .20794 L
.0989 .1951 L
.09435 .18713 L
.09011 .18232 L
.08516 .17979 L
.08047 .18044 L
.07616 .18373 L
.07223 .18909 L
.06801 .19751 L
.06368 .20934 L
.05953 .22407 L
.05534 .24305 L
.0486 .28493 L
.04528 .31314 L
.04232 .34543 L
.04024 .37475 L
.03848 .4082 L
.0378 .42553 L
.03724 .44406 L
.03663 .47758 L
.03656 .51362 L
.03678 .53388 L
.03717 .55256 L
.03827 .58544 L
.03974 .61412 L
.04193 .64519 L
Mistroke
.04447 .67224 L
.0471 .69414 L
.05021 .71483 L
.05314 .73037 L
.05652 .74459 L
.06033 .75672 L
.06405 .76518 L
.06626 .76875 L
.06861 .77146 L
.07285 .77361 L
.07741 .77215 L
.0815 .7675 L
.08373 .76362 L
.08611 .75838 L
.09029 .74624 L
.094 .73198 L
.09766 .71403 L
.10342 .67537 L
.10611 .65062 L
.10853 .62196 L
.11033 .59333 L
.11156 .56609 L
.11209 .54921 L
.11245 .53337 L
.11268 .51584 L
.11274 .49705 L
.11263 .47912 L
.11236 .46227 L
.112 .44723 L
.11146 .43109 L
.11015 .40264 L
.10856 .37748 L
.10629 .34968 L
.10373 .32485 L
.09826 .28521 L
.09471 .2658 L
.09117 .25004 L
.08739 .23649 L
.08311 .22469 L
.08058 .21931 L
.07823 .21529 L
.07353 .21004 L
.0689 .20838 L
.06627 .20898 L
.06384 .21055 L
.06128 .21328 L
.05898 .21671 L
.05636 .2218 L
.05394 .22769 L
.04982 .24061 L
Mistroke
.04555 .25842 L
.04145 .28081 L
.038 .30499 L
.03521 .32962 L
.03293 .35488 L
.03076 .3859 L
.02925 .41562 L
.02811 .44933 L
.02773 .46844 L
.02753 .48581 L
.02758 .51958 L
.02813 .55083 L
.02865 .56825 L
.02938 .58621 L
.03108 .61699 L
.03347 .64772 L
.03669 .67793 L
.03984 .70018 L
.04306 .7178 L
.04688 .73367 L
.04893 .74032 L
.05119 .74636 L
.05508 .75379 L
.05881 .75772 L
.06099 .75866 L
.06329 .75859 L
.06737 .75582 L
.07097 .75054 L
.07471 .74209 L
.0781 .73159 L
.08103 .72005 L
.08427 .70419 L
.0875 .68447 L
.09243 .64292 L
.09459 .6173 L
.09621 .59205 L
.09695 .57737 L
.09754 .56321 L
.09806 .54665 L
.0984 .53137 L
.0986 .51621 L
.09868 .50003 L
.09844 .47098 L
.0981 .45499 L
.09765 .4401 L
.09702 .42399 L
.09616 .40694 L
.09453 .38166 L
.0923 .35542 L
.08951 .32998 L
Mistroke
.08653 .30841 L
.08038 .27579 L
.07655 .26137 L
.07288 .25091 L
.06905 .24309 L
.06537 .23834 L
.06128 .23609 L
.05688 .23721 L
.05469 .23917 L
.05232 .24235 L
.04811 .25098 L
.04418 .26281 L
.04073 .2767 L
.03744 .29364 L
.03459 .31195 L
.03005 .35164 L
.02799 .37655 L
.02645 .40079 L
.02514 .42854 L
.02423 .45873 L
.02381 .49012 L
.02388 .51872 L
.0241 .5344 L
.02449 .55123 L
.02557 .581 L
.02702 .60754 L
.02899 .63394 L
.031 .65475 L
.03353 .67558 L
.03688 .69678 L
.04025 .71297 L
.04422 .72694 L
.0463 .73241 L
.04863 .73718 L
.05266 .74232 L
.05494 .7436 L
.05702 .74377 L
.06105 .74144 L
.0648 .73609 L
.06821 .72841 L
.07173 .71744 L
.07488 .70465 L
.07757 .69107 L
.08047 .67307 L
.08329 .65115 L
.08557 .6287 L
.08736 .6062 L
.0882 .59349 L
.08897 .57946 L
.09002 .55438 L
Mistroke
.09044 .53986 L
.09074 .52442 L
.09092 .49664 L
.09066 .47097 L
.09007 .44737 L
.08903 .42212 L
.08828 .40837 L
.08748 .39616 L
.08581 .37503 L
.08371 .35401 L
.07918 .32062 L
.07629 .30488 L
.07337 .29217 L
.06998 .28068 L
.06802 .27544 L
.06615 .27137 L
.06277 .26605 L
.05902 .26314 L
.05568 .26314 L
.05215 .26583 L
.04874 .27116 L
.04562 .2786 L
.04291 .28723 L
.04012 .29859 L
.03706 .31443 L
.03451 .33109 L
.03205 .35119 L
.02974 .37532 L
.02798 .39936 L
.0267 .42282 L
.0258 .44608 L
.02519 .47137 L
.02496 .49876 L
.02502 .51416 L
.02519 .52822 L
.0258 .55374 L
.02685 .57979 L
.02757 .59317 L
.02846 .60702 L
.03036 .63065 L
.0331 .65614 L
.03598 .67645 L
.03908 .69318 L
.04263 .70758 L
.04584 .71705 L
.04951 .72437 L
.05161 .72703 L
.05355 .72854 L
.05581 .72922 L
.05795 .7288 L
Mistroke
.06172 .72556 L
.06382 .72235 L
.06574 .7185 L
.06938 .70865 L
.07263 .69673 L
.07811 .66826 L
.08078 .64921 L
.08294 .63004 L
.08496 .60748 L
.08666 .58227 L
.08776 .55947 L
.08823 .54634 L
.08855 .53409 L
.08889 .51146 L
.08889 .48745 L
.08856 .46623 L
.08798 .4467 L
.08705 .42587 L
.08572 .40437 L
.08406 .38398 L
.08188 .36336 L
.07925 .344 L
.07652 .32826 L
.07372 .31564 L
.07103 .30617 L
.06777 .29773 L
.06459 .29234 L
.06177 .28975 L
.05864 .28922 L
.05539 .29128 L
.05239 .29563 L
.04966 .3018 L
.04726 .30916 L
.04461 .31964 L
.04224 .33146 L
.03989 .34616 L
.03763 .36382 L
.03591 .3806 L
.03432 .40008 L
.03294 .42222 L
.03197 .44402 L
.03155 .45698 L
.03123 .47083 L
.03097 .49589 L
.0311 .52065 L
.03134 .53452 L
.03167 .54719 L
.03255 .56996 L
.03384 .59313 L
.03531 .61275 L
Mistroke
.03692 .62999 L
.04139 .66428 L
.04427 .67984 L
.04722 .69215 L
.05003 .70103 L
.05322 .7083 L
.05507 .71129 L
.05678 .71327 L
.05876 .71471 L
.06063 .71522 L
.06397 .71417 L
.06753 .71022 L
.07056 .70452 L
.0733 .69738 L
.07618 .68763 L
.07908 .67511 L
.0819 .65989 L
.08431 .6437 L
.08627 .62768 L
.08809 .6095 L
.08943 .59301 L
.09066 .57411 L
.09152 .55645 L
.09212 .53958 L
.09256 .5196 L
.09269 .50126 L
.09257 .48129 L
.09212 .46065 L
.09134 .44035 L
.09076 .42926 L
.09014 .41932 L
.08882 .40216 L
.0871 .38461 L
.08347 .358 L
.08119 .34583 L
.0789 .33613 L
.07608 .32703 L
.07327 .32071 L
.07068 .31705 L
.06781 .3153 L
.06618 .31535 L
.0647 .31607 L
.063 .31768 L
.06142 .31996 L
.05867 .32585 L
.05581 .33479 L
.05347 .34468 L
.05142 .35557 L
.0492 .37048 L
.04739 .38575 L
Mistroke
.04575 .40333 L
.04447 .42122 L
.0434 .44119 L
.04294 .45287 L
.0426 .46386 L
.04224 .48231 L
.04213 .49983 L
.04226 .51911 L
.04269 .53971 L
.04347 .56081 L
.0445 .58024 L
.04567 .59696 L
.04719 .61426 L
.04913 .63187 L
.05147 .64871 L
.05433 .66481 L
.05721 .67725 L
.06007 .68665 L
.06285 .69346 L
.066 .69866 L
.0678 .70054 L
.06946 .70159 L
.07252 .70191 L
.07535 .70034 L
.07841 .6966 L
.08159 .69042 L
.08424 .68332 L
.08663 .67526 L
.09162 .65229 L
.09388 .63836 L
.0961 .62168 L
.09797 .60422 L
.09965 .58448 L
.1009 .5652 L
.10175 .54723 L
.10233 .52895 L
.10262 .51164 L
.10265 .4916 L
.10253 .48163 L
.10231 .47081 L
.10168 .4522 L
.10081 .43552 L
.09947 .41707 L
.09797 .40152 L
.09593 .3854 L
.09372 .37212 L
.09161 .36232 L
.08917 .35374 L
.08675 .34768 L
.08446 .34394 L
Mistroke
.08234 .34209 L
.08 .34179 L
.07757 .34342 L
.07534 .34671 L
.07411 .34932 L
.0728 .35274 L
.07051 .36054 L
.06841 .37001 L
.06661 .38031 L
.06485 .39298 L
.06315 .40866 L
.06168 .42671 L
.0606 .44493 L
.05995 .46055 L
.05949 .4782 L
.0593 .49706 L
.05939 .51478 L
.0597 .53145 L
.06018 .54643 L
.06097 .5634 L
.06193 .57895 L
.06321 .59523 L
.06483 .61149 L
.06831 .63759 L
.07055 .65014 L
.07281 .66045 L
.07544 .67007 L
.07843 .67835 L
.08001 .68176 L
.08152 .68442 L
.08439 .68798 L
.08753 .68978 L
.08931 .68986 L
.09093 .68935 L
.09365 .68727 L
.09658 .68327 L
.09955 .67725 L
.10222 .67004 L
.10524 .65959 L
.1079 .64801 L
.11229 .6225 L
.11436 .60642 L
.11601 .59068 L
.11751 .57265 L
.11819 .5626 L
.11873 .55295 L
.11944 .5367 L
.11987 .5218 L
.12008 .50587 L
.12009 .49696 L
Mistroke
.12004 .48878 L
.11976 .47416 L
.11932 .46135 L
.1186 .4472 L
.11773 .43463 L
.11656 .4217 L
.1151 .40932 L
.1137 .39989 L
.11201 .39086 L
.11003 .3828 L
.10889 .37913 L
.10778 .37618 L
.10673 .37391 L
.10557 .37196 L
.10349 .36988 L
.10147 .3695 L
.09963 .37057 L
.09763 .3733 L
.09559 .37792 L
.09388 .38337 L
.09236 .38959 L
.09082 .39758 L
.08928 .40758 L
.0878 .41999 L
.0866 .43297 L
.08565 .44664 L
.08497 .46002 L
.08446 .47518 L
.08427 .48404 L
.08418 .49246 L
.08415 .50143 L
.08419 .50969 L
.08433 .51927 L
.08454 .52838 L
.08482 .5373 L
.08516 .54565 L
.08598 .56103 L
.08711 .57713 L
.08863 .59376 L
.0902 .60755 L
.09209 .62109 L
.09598 .64233 L
.09843 .65239 L
.10122 .6615 L
.10399 .66842 L
.10661 .67327 L
.10823 .67554 L
.10975 .67717 L
.11144 .67844 L
.11323 .6792 L
Mistroke
.11479 .67936 L
.11625 .67911 L
.11785 .67839 L
.11957 .67709 L
.12238 .67377 L
.12488 .66956 L
.12768 .66334 L
.13022 .65623 L
.13442 .64086 L
.13842 .6209 L
.14209 .59576 L
.1436 .58221 L
.14499 .56686 L
.14595 .55352 L
.14639 .54613 L
.14675 .53912 L
.14727 .52556 L
.14755 .51333 L
.14766 .50081 L
.14764 .49383 L
.14756 .4874 L
.14725 .47486 L
.14698 .46808 L
.14668 .46207 L
.14607 .45241 L
.14524 .44259 L
.14422 .43326 L
.14314 .42549 L
.14171 .41748 L
.14023 .41125 L
.13882 .40682 L
.13723 .4033 L
.13638 .40202 L
.13544 .40104 L
.13445 .40051 L
.13352 .40047 L
.13186 .40151 L
.13094 .40271 L
.13011 .40419 L
.12857 .40803 L
.12718 .41284 L
.12601 .41809 L
.12483 .42474 L
.12367 .43309 L
.12259 .44303 L
.12182 .45236 L
.12113 .46338 L
.12066 .47437 L
.12038 .48485 L
.12024 .49739 L
Mistroke
.12029 .50959 L
.1205 .52104 L
.12084 .53171 L
.12138 .54342 L
.12212 .55578 L
.12425 .58056 L
.12577 .59379 L
.12737 .60531 L
.13078 .62469 L
.13494 .64196 L
.13735 .64969 L
.14006 .65672 L
.14272 .66216 L
.14521 .66608 L
.14666 .66788 L
.1482 .66942 L
.14991 .6707 L
.1515 .67149 L
.15437 .67198 L
.156 .67174 L
.15752 .67118 L
.16024 .66937 L
.16174 .66792 L
.16309 .66635 L
.16805 .65828 L
.17071 .65237 L
.17346 .64499 L
.17806 .62932 L
.18191 .61213 L
.18536 .5923 L
.18775 .57449 L
.18888 .5643 L
.18978 .55463 L
.19052 .54531 L
.19117 .53531 L
.19162 .52638 L
.19192 .51831 L
.19213 .50984 L
.19221 .50085 L
.19215 .49193 L
.19196 .48405 L
.19168 .47716 L
.19132 .47106 L
.19092 .466 L
.19042 .46093 L
.18981 .45603 L
.18908 .45148 L
.18833 .44787 L
.1876 .44519 L
.18675 .44285 L
Mistroke
.18592 .44135 L
.18499 .44046 L
.18399 .4404 L
.18349 .44072 L
.18295 .44133 L
.18199 .44314 L
.18109 .44576 L
.1803 .44892 L
.17961 .45248 L
.17901 .45633 L
.17842 .46111 L
.17786 .46689 L
.1774 .47322 L
.17702 .48047 L
.1768 .4871 L
.17666 .49477 L
.17664 .4993 L
.17665 .50434 L
.17671 .5092 L
.17681 .51378 L
.17708 .52264 L
.17753 .53224 L
.17818 .5427 L
.17896 .55258 L
.18133 .57492 L
.18404 .59361 L
.18703 .6097 L
.19104 .62663 L
.19535 .64072 L
.2002 .65283 L
.2051 .66189 L
.20971 .668 L
.21237 .67059 L
.21485 .67243 L
.21755 .67384 L
.22009 .67463 L
.22289 .67492 L
.22445 .67482 L
.22588 .67457 L
.22874 .67363 L
.23035 .67285 L
.23183 .67197 L
.23735 .66734 L
.24194 .66188 L
.24609 .65567 L
.25486 .63839 L
.26233 .61877 L
.26905 .59642 L
.2782 .55614 L
.28339 .5273 L
Mistroke
.28386 .52489 L
.28434 .52279 L
.28475 .52133 L
.28494 .52081 L
.28511 .52042 L
.28543 .51998 L
.28559 .51988 L
.28577 .51989 L
.28595 .52003 L
.28613 .52027 L
.28647 .52102 L
.28681 .5221 L
.2872 .52364 L
.28797 .52739 L
.29026 .54022 L
.29666 .57295 L
.30847 .61801 L
.31785 .64543 L
.32817 .67034 L
.35303 .71638 L
.38249 .75656 L
.41425 .79156 L
.50173 .87565 L
.55505 .92297 L
.58354 .94487 L
.59649 .9535 L
.61103 .9619 L
.62335 .96775 L
.63021 .97043 L
.63676 .97256 L
.6442 .97443 L
.65104 .97559 L
.65745 .97615 L
.66446 .97613 L
.67216 .97528 L
.67913 .97371 L
.68298 .97249 L
.68714 .97087 L
.69462 .96711 L
.70159 .96257 L
.70887 .95664 L
.72164 .94295 L
.73695 .91994 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.678571 0.64881 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.499995 0.221787 0.500007 0.443854 [
[.5 1.0125 -3.5 0 ]
[.5 1.0125 3.5 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -64.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.000 15.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
.82218 .53271 m
.82262 .52653 L
.82294 .52046 L
.82321 .51295 L
.82334 .50543 L
.82337 .49814 L
.8233 .49116 L
.82312 .48326 L
.82281 .47468 L
.82237 .4659 L
.82175 .45633 L
.82025 .43891 L
.8178 .4185 L
.81497 .40063 L
.81151 .38361 L
.80783 .36934 L
.80333 .35569 L
.79809 .34375 L
.79556 .33925 L
.79275 .33507 L
.79022 .33201 L
.7875 .3294 L
.78501 .32758 L
.78225 .32619 L
.77973 .32545 L
.77737 .32521 L
.7759 .32527 L
.77435 .32551 L
.77156 .32637 L
.77002 .32709 L
.76859 .32791 L
.76534 .3303 L
.76005 .33575 L
.75456 .34346 L
.74506 .36201 L
.7375 .382 L
.7248 .42943 L
.71769 .46714 L
.71678 .47219 L
.71595 .4763 L
.71561 .4777 L
.71526 .47883 L
.71498 .47952 L
.71468 .47998 L
.71451 .4801 L
.71435 .48011 L
.71416 .48001 L
.71398 .47979 L
.71366 .47914 L
.71347 .47861 L
Mistroke
.71329 .47802 L
.7126 .47509 L
.71173 .47065 L
.70661 .44251 L
.69817 .4052 L
.68249 .35534 L
.67161 .32907 L
.65819 .30245 L
.63142 .2611 L
.59655 .21983 L
.50995 .13538 L
.4606 .09048 L
.40995 .05084 L
.38286 .03521 L
.36888 .02941 L
.36086 .02694 L
.3533 .02525 L
.34558 .02422 L
.34169 .02398 L
.33745 .02396 L
.32992 .02457 L
.32294 .0259 L
.31869 .02712 L
.31469 .02855 L
.30726 .032 L
.29933 .03693 L
.29085 .04378 L
.27779 .05793 L
.264 .07857 L
.25039 .10611 L
.2386 .13748 L
.2287 .171 L
.22026 .20673 L
.21179 .2522 L
.20536 .29709 L
.2026 .32082 L
.20001 .347 L
.1981 .37 L
.19637 .39546 L
.1949 .42383 L
.19429 .43932 L
.19384 .45371 L
.19335 .47934 L
.19323 .50637 L
.19335 .52101 L
.19358 .53435 L
.19394 .54876 L
.19447 .56374 L
.19567 .58814 L
.19743 .61374 L
Mistroke
.19935 .63523 L
.20178 .65686 L
.20437 .67563 L
.20703 .69166 L
.21322 .72042 L
.21682 .73301 L
.22085 .7444 L
.22486 .75327 L
.22875 .75985 L
.23232 .76429 L
.23624 .76753 L
.23987 .7691 L
.24386 .7693 L
.24802 .76785 L
.25187 .765 L
.25543 .76106 L
.25862 .75643 L
.26555 .74257 L
.26912 .73318 L
.27234 .72323 L
.2791 .69672 L
.28479 .66628 L
.28733 .64903 L
.28978 .62908 L
.29308 .59314 L
.29442 .57247 L
.29536 .55268 L
.29597 .53362 L
.29629 .51598 L
.29638 .49529 L
.29617 .4755 L
.29563 .45367 L
.29465 .42948 L
.29319 .40411 L
.29143 .38038 L
.2873 .33825 L
.28151 .29405 L
.273 .2447 L
.26331 .20142 L
.25338 .16656 L
.24141 .13405 L
.22905 .1095 L
.22177 .09892 L
.21825 .09478 L
.21494 .09147 L
.20885 .08684 L
.20211 .08395 L
.19552 .08343 L
.19183 .08417 L
.18848 .0855 L
Mistroke
.18218 .08978 L
.17643 .09581 L
.17024 .10478 L
.16385 .11699 L
.15364 .14373 L
.1482 .16235 L
.14338 .18196 L
.13835 .20629 L
.13333 .23552 L
.12936 .26339 L
.12562 .29501 L
.12247 .32793 L
.1201 .35893 L
.11819 .3909 L
.11684 .42153 L
.11628 .43876 L
.11583 .4577 L
.11553 .47746 L
.11542 .49582 L
.1156 .52832 L
.11635 .56233 L
.11701 .58091 L
.11793 .60062 L
.12008 .63486 L
.12277 .66588 L
.12572 .69224 L
.12876 .714 L
.1323 .73451 L
.13935 .76464 L
.14361 .77761 L
.14774 .78715 L
.15241 .7948 L
.15507 .79778 L
.15751 .7997 L
.16194 .80124 L
.16604 .80051 L
.17051 .79739 L
.17517 .79153 L
.17912 .78438 L
.18272 .77603 L
.19045 .75144 L
.19439 .73474 L
.19836 .71427 L
.20154 .69443 L
.20457 .67164 L
.2072 .64756 L
.20922 .6246 L
.21091 .60058 L
.21216 .57722 L
.2132 .54901 L
Mistroke
.21355 .53456 L
.21379 .51855 L
.21386 .4899 L
.21351 .46297 L
.21309 .44659 L
.21256 .43109 L
.21121 .4022 L
.20923 .37146 L
.20648 .33878 L
.20094 .28976 L
.19341 .24125 L
.18496 .20089 L
.17622 .16971 L
.1712 .15562 L
.16562 .14282 L
.1593 .13166 L
.15327 .12416 L
.14996 .12131 L
.14635 .11922 L
.14293 .11823 L
.13978 .11816 L
.13381 .12033 L
.12757 .12595 L
.12143 .13506 L
.11598 .14644 L
.10993 .16314 L
.1045 .18244 L
.09574 .22455 L
.09139 .25242 L
.08778 .28055 L
.08461 .31077 L
.08173 .34525 L
.08035 .36568 L
.07925 .38481 L
.07831 .40454 L
.0776 .42311 L
.07662 .46086 L
.07636 .48087 L
.07628 .50219 L
.07642 .5244 L
.07674 .54512 L
.0772 .56342 L
.07787 .5829 L
.07942 .61487 L
.08126 .64259 L
.08386 .67245 L
.08677 .6984 L
.09284 .73782 L
.09673 .75603 L
.10057 .77013 L
Mistroke
.10285 .77691 L
.10536 .78321 L
.11005 .79189 L
.11472 .79692 L
.11907 .79858 L
.12379 .79724 L
.12645 .79506 L
.12891 .79211 L
.13148 .78806 L
.13379 .78356 L
.13882 .77071 L
.14319 .75584 L
.14753 .73702 L
.1544 .69624 L
.15762 .67026 L
.16021 .64403 L
.16254 .61353 L
.1636 .59583 L
.16442 .57901 L
.16544 .55004 L
.16579 .53445 L
.16602 .51766 L
.16611 .49987 L
.16603 .48301 L
.16549 .45143 L
.1645 .42197 L
.16319 .39515 L
.16132 .3663 L
.15884 .33667 L
.15612 .31034 L
.15271 .28309 L
.14538 .23828 L
.14147 .21968 L
.13703 .20193 L
.13264 .18739 L
.12844 .17594 L
.1229 .16422 L
.11992 .15939 L
.11673 .15533 L
.1113 .15097 L
.10819 .14993 L
.10529 .14989 L
.09988 .15234 L
.09501 .15742 L
.08951 .16671 L
.08446 .17885 L
.08024 .19201 L
.07582 .20924 L
.07177 .22864 L
.06775 .25226 L
Mistroke
.06434 .27663 L
.06155 .30073 L
.05703 .35217 L
.055 .38477 L
.05358 .41601 L
.05253 .45095 L
.05203 .48849 L
.05213 .52401 L
.05273 .55684 L
.0537 .58545 L
.05516 .61517 L
.05722 .64539 L
.0595 .67102 L
.06256 .69796 L
.06585 .7206 L
.06896 .73765 L
.07249 .75315 L
.0766 .76691 L
.08057 .77655 L
.08496 .78352 L
.08746 .78591 L
.08977 .78714 L
.09404 .78703 L
.09852 .78364 L
.10086 .7805 L
.10334 .77615 L
.10768 .76581 L
.1126 .74953 L
.11677 .73127 L
.12046 .71082 L
.12398 .68643 L
.12665 .66334 L
.12912 .63672 L
.13126 .60643 L
.13277 .57676 L
.13345 .55818 L
.13392 .54027 L
.1342 .52403 L
.13434 .5062 L
.13432 .48929 L
.13416 .47336 L
.13352 .44369 L
.13231 .41214 L
.1314 .39468 L
.13042 .37888 L
.12591 .32597 L
.12305 .30131 L
.1195 .27618 L
.11165 .23499 L
.10669 .21616 L
Mistroke
.10182 .20198 L
.09741 .19231 L
.09239 .18476 L
.08706 .18051 L
.08201 .18004 L
.07739 .18266 L
.07259 .18863 L
.06858 .19633 L
.06434 .20746 L
.05995 .22259 L
.05554 .24218 L
.04853 .28563 L
.04496 .31647 L
.04218 .34739 L
.03974 .38356 L
.03876 .40248 L
.03789 .42367 L
.0373 .44254 L
.0369 .4599 L
.03662 .48001 L
.03653 .49908 L
.03678 .53265 L
.03715 .55132 L
.03764 .56833 L
.03906 .60165 L
.04088 .63125 L
.04289 .65608 L
.04544 .68073 L
.04864 .70484 L
.05242 .72666 L
.05591 .74215 L
.05999 .75565 L
.06434 .76557 L
.06849 .77121 L
.07068 .77281 L
.0731 .7735 L
.07563 .77304 L
.078 .77154 L
.08228 .76611 L
.08611 .75824 L
.09035 .74587 L
.09417 .73104 L
.09735 .71553 L
.10048 .69679 L
.10534 .65804 L
.10776 .63163 L
.10963 .60523 L
.11094 .58053 L
.11196 .55298 L
.11259 .52238 L
Mistroke
.11271 .49349 L
.11258 .47689 L
.11233 .46179 L
.11189 .44446 L
.11133 .4282 L
.10977 .39642 L
.10784 .3681 L
.1052 .33863 L
.10183 .3096 L
.0988 .28872 L
.09521 .26843 L
.09185 .25296 L
.08794 .23843 L
.08338 .22546 L
.0808 .21987 L
.07836 .21564 L
.07392 .21047 L
.06911 .20851 L
.06455 .21012 L
.06197 .21255 L
.05959 .21583 L
.05489 .22536 L
.05233 .23241 L
.05006 .23989 L
.04619 .25559 L
.04227 .27603 L
.03892 .29811 L
.03611 .32124 L
.03308 .35324 L
.03086 .38447 L
.02992 .40151 L
.02908 .4199 L
.02837 .44042 L
.0279 .45952 L
.02751 .49384 L
.02766 .52571 L
.02797 .54377 L
.0284 .55997 L
.02905 .57829 L
.02983 .59519 L
.03143 .62189 L
.03363 .64934 L
.03639 .67535 L
.03935 .69696 L
.04241 .71442 L
.04541 .72801 L
.04891 .74013 L
.05275 .74964 L
.0568 .75585 L
.0591 .75778 L
Mistroke
.06119 .75857 L
.06528 .75754 L
.06909 .7535 L
.07122 .74993 L
.07344 .74517 L
.07729 .7342 L
.08121 .71912 L
.08518 .69894 L
.0883 .67859 L
.09088 .65772 L
.09332 .63287 L
.09544 .60459 L
.09686 .57892 L
.09783 .55402 L
.09846 .52612 L
.09863 .51028 L
.09865 .4957 L
.09841 .47051 L
.09787 .44727 L
.09692 .42223 L
.0955 .39624 L
.09359 .37011 L
.09141 .34681 L
.0864 .30773 L
.08331 .28985 L
.07962 .27277 L
.07548 .25815 L
.0714 .24766 L
.06746 .24083 L
.06378 .23721 L
.05949 .23622 L
.05543 .23852 L
.05113 .24453 L
.04878 .24948 L
.04669 .25493 L
.04277 .26816 L
.03931 .28363 L
.03559 .30522 L
.03254 .3281 L
.02965 .35615 L
.02719 .38855 L
.02567 .4163 L
.02501 .43246 L
.02452 .44764 L
.02395 .47586 L
.02381 .50602 L
.02408 .53274 L
.02468 .55735 L
.0257 .58354 L
.02722 .61045 L
Mistroke
.02916 .63571 L
.03171 .66094 L
.03481 .68422 L
.03804 .70273 L
.04133 .71715 L
.0445 .72762 L
.04831 .73649 L
.05202 .74164 L
.0553 .74358 L
.05891 .743 L
.06264 .73943 L
.06607 .73343 L
.06917 .7256 L
.07191 .71666 L
.07759 .69081 L
.08041 .67335 L
.08276 .65544 L
.08522 .63227 L
.08709 .6098 L
.08854 .58723 L
.0896 .56526 L
.09038 .5415 L
.09083 .51545 L
.09087 .48916 L
.09054 .46539 L
.08973 .43843 L
.08857 .4137 L
.08715 .39174 L
.08556 .37244 L
.08105 .33308 L
.07827 .31543 L
.07542 .30092 L
.07206 .28747 L
.06823 .27609 L
.06625 .27168 L
.06405 .26787 L
.06194 .26526 L
.05996 .2637 L
.05622 .26309 L
.05412 .26409 L
.05224 .26584 L
.04835 .27205 L
.04644 .27648 L
.0444 .28234 L
.04092 .29516 L
.03789 .30987 L
.03463 .33039 L
.032 .35179 L
.02943 .37928 L
.0275 .4076 L
Mistroke
.02625 .43356 L
.02538 .46211 L
.02502 .48693 L
.02503 .51444 L
.02552 .54356 L
.02601 .55961 L
.02659 .57405 L
.02798 .59969 L
.02987 .62502 L
.03201 .6467 L
.03468 .66782 L
.03752 .6852 L
.04037 .69884 L
.04309 .70905 L
.04623 .71792 L
.04963 .72445 L
.05288 .72801 L
.05671 .72906 L
.06034 .72701 L
.06356 .72269 L
.06697 .71543 L
.06885 .71017 L
.07052 .70471 L
.07407 .69024 L
.07711 .67429 L
.07971 .65725 L
.08369 .62209 L
.0853 .6027 L
.08674 .58044 L
.08769 .56077 L
.08841 .53925 L
.0888 .51869 L
.08892 .49991 L
.08874 .47647 L
.08824 .45513 L
.08736 .43233 L
.08603 .4091 L
.08458 .39003 L
.08297 .3732 L
.0785 .33946 L
.07599 .32578 L
.0731 .31336 L
.0702 .30386 L
.06746 .29721 L
.06414 .2919 L
.06223 .29015 L
.06047 .28934 L
.05722 .28989 L
.05381 .29337 L
.05062 .29948 L
Mistroke
.04733 .309 L
.04439 .32071 L
.04189 .33359 L
.03921 .35114 L
.03666 .37298 L
.03464 .39589 L
.03314 .41874 L
.03219 .4387 L
.03146 .46096 L
.03107 .48242 L
.03097 .50231 L
.03116 .5243 L
.03171 .54808 L
.03267 .57223 L
.0339 .59381 L
.03555 .61552 L
.03742 .63457 L
.04163 .66565 L
.04434 .68007 L
.04702 .69131 L
.05013 .70122 L
.05358 .70886 L
.05682 .71322 L
.06041 .71511 L
.0638 .71418 L
.06692 .71101 L
.06995 .70575 L
.07262 .69923 L
.07558 .68975 L
.07822 .67902 L
.08092 .66543 L
.08352 .64919 L
.08747 .61601 L
.08921 .59572 L
.09054 .57588 L
.09163 .55341 L
.09208 .54058 L
.09238 .52881 L
.09265 .50909 L
.09263 .48824 L
.09236 .47067 L
.0918 .4517 L
.0909 .43207 L
.0896 .41194 L
.08807 .39415 L
.08643 .37904 L
.08292 .35493 L
.08066 .34351 L
.07843 .3345 L
.07593 .32675 L
Mistroke
.07358 .32139 L
.07079 .31727 L
.06811 .31546 L
.0654 .31574 L
.06252 .31838 L
.05985 .32311 L
.05748 .32928 L
.05484 .33868 L
.05215 .3515 L
.04984 .36591 L
.04791 .38109 L
.04604 .40012 L
.04458 .4196 L
.04355 .43815 L
.04274 .45908 L
.04245 .47028 L
.04224 .48271 L
.04214 .49579 L
.04216 .50805 L
.04246 .52995 L
.04315 .55305 L
.04415 .57415 L
.04537 .59286 L
.047 .61226 L
.04907 .63128 L
.0532 .65886 L
.05588 .6718 L
.05856 .68193 L
.06111 .68937 L
.06388 .69535 L
.06631 .69895 L
.069 .70128 L
.07193 .70193 L
.07506 .70049 L
.07797 .69718 L
.08056 .69259 L
.08345 .68554 L
.08603 .67732 L
.08894 .66565 L
.09141 .65335 L
.0958 .624 L
.0978 .60585 L
.09939 .58763 L
.10052 .57141 L
.10146 .55372 L
.10205 .53839 L
.10247 .52134 L
.10266 .50314 L
.10255 .48374 L
.10216 .46585 L
Mistroke
.10156 .44996 L
.10066 .43341 L
.09943 .41674 L
.09802 .40215 L
.09655 .38999 L
.09461 .37719 L
.09229 .36531 L
.08991 .35617 L
.0876 .34964 L
.08512 .34492 L
.08275 .34242 L
.08012 .34185 L
.07864 .34254 L
.0773 .34381 L
.07592 .34578 L
.07465 .34818 L
.07318 .35176 L
.07188 .35566 L
.06957 .36454 L
.06729 .37622 L
.06549 .38815 L
.06398 .40063 L
.06253 .41567 L
.06126 .43314 L
.06074 .44238 L
.06026 .45271 L
.05963 .47214 L
.05933 .49162 L
.05934 .50991 L
.0596 .52696 L
.06006 .54284 L
.0608 .55997 L
.06187 .57788 L
.06319 .59489 L
.06487 .61175 L
.0685 .63862 L
.07091 .65185 L
.07328 .66229 L
.0762 .67236 L
.0791 .67981 L
.08188 .68489 L
.0845 .688 L
.08741 .68967 L
.0905 .68946 L
.0936 .68724 L
.09531 .68514 L
.09686 .68269 L
.0998 .67657 L
.10248 .66915 L
.10543 .65872 L
Mistroke
.10799 .64746 L
.11057 .63347 L
.11301 .61716 L
.11478 .60257 L
.11645 .58573 L
.11771 .56964 L
.11863 .55465 L
.11905 .54605 L
.11943 .53667 L
.11973 .52675 L
.11994 .51739 L
.12005 .50867 L
.12008 .49951 L
.11994 .48335 L
.11958 .46885 L
.11896 .45389 L
.11815 .4405 L
.11724 .42899 L
.11598 .41656 L
.11439 .40439 L
.11269 .39438 L
.11098 .38648 L
.10925 .38028 L
.10728 .37511 L
.10535 .37175 L
.10355 .36999 L
.1019 .36952 L
.10009 .37024 L
.09823 .37238 L
.09652 .37564 L
.09459 .38097 L
.09285 .3875 L
.09138 .39453 L
.0899 .40337 L
.08844 .41428 L
.0871 .42724 L
.08613 .4393 L
.08528 .45353 L
.08467 .46809 L
.08431 .48217 L
.08416 .49806 L
.08418 .50708 L
.08427 .51533 L
.08465 .53204 L
.08499 .54143 L
.08538 .55002 L
.08627 .56554 L
.08748 .58147 L
.09023 .60764 L
.09344 .62929 L
Mistroke
.09759 .64913 L
.10015 .65823 L
.10262 .66517 L
.10537 .67111 L
.10695 .67373 L
.1084 .67567 L
.11125 .67826 L
.11397 .67926 L
.11552 .67922 L
.11715 .67869 L
.12006 .67655 L
.12165 .6747 L
.12313 .67257 L
.1264 .66632 L
.12913 .65937 L
.1316 .65161 L
.13586 .63428 L
.13981 .61223 L
.14173 .59852 L
.14326 .58537 L
.14544 .56088 L
.14628 .54776 L
.14696 .53392 L
.14736 .5219 L
.14757 .51087 L
.14765 .499 L
.14753 .4867 L
.14738 .4799 L
.14719 .47379 L
.14693 .46727 L
.14659 .4606 L
.14587 .45 L
.14489 .43929 L
.14387 .4307 L
.14264 .42254 L
.14135 .41593 L
.1401 .41086 L
.13858 .40628 L
.13779 .40445 L
.1369 .40284 L
.13531 .40101 L
.13379 .4005 L
.13292 .40075 L
.13201 .40142 L
.1304 .40369 L
.12952 .40554 L
.12873 .40763 L
.12699 .41369 L
.12558 .42039 L
.12437 .42788 L
Mistroke
.12337 .4356 L
.12245 .44466 L
.12161 .45544 L
.121 .46615 L
.12054 .47838 L
.12037 .4856 L
.12027 .49252 L
.12025 .50518 L
.12033 .51238 L
.12046 .51897 L
.12085 .53188 L
.12141 .54406 L
.1223 .55817 L
.12332 .57091 L
.12477 .58531 L
.12636 .59815 L
.12951 .61808 L
.13359 .63693 L
.13809 .65172 L
.1408 .65831 L
.14336 .66321 L
.14577 .66676 L
.14838 .66951 L
.15063 .67104 L
.15314 .67186 L
.15583 .67172 L
.15734 .6712 L
.15872 .67045 L
.16124 .66838 L
.16385 .66528 L
.1661 .66183 L
.16843 .65742 L
.17246 .64774 L
.17689 .63367 L
.18049 .61891 L
.18374 .60216 L
.18673 .58252 L
.18916 .56132 L
.19007 .55109 L
.19078 .54146 L
.1913 .53272 L
.19173 .52337 L
.192 .51509 L
.19215 .50764 L
.1922 .49911 L
.19213 .49173 L
.19193 .48367 L
.19163 .47659 L
.19122 .46994 L
.19066 .46334 L
Mistroke
.18996 .45725 L
.18921 .45236 L
.18845 .4485 L
.18771 .44561 L
.1868 .44305 L
.18592 .44141 L
.18494 .44048 L
.18444 .44036 L
.18389 .4405 L
.18292 .44142 L
.18204 .44307 L
.18152 .44443 L
.18104 .44598 L
.18018 .44952 L
.17932 .45426 L
.17849 .46046 L
.17788 .4667 L
.17741 .47308 L
.17721 .47665 L
.17702 .48073 L
.17686 .48518 L
.17675 .48948 L
.17664 .49778 L
.17667 .5057 L
.17673 .51021 L
.17684 .51521 L
.17716 .5245 L
.17757 .53293 L
.17816 .54237 L
.17982 .56163 L
.18189 .57924 L
.18431 .59521 L
.1877 .61285 L
.19187 .62961 L
.19586 .64212 L
.20061 .65365 L
.20611 .66337 L
.20932 .66752 L
.2123 .67049 L
.21512 .67256 L
.21673 .67343 L
.21822 .67405 L
.22096 .67474 L
.22387 .67483 L
.22656 .67435 L
.22947 .67325 L
.2322 .67167 L
.23471 .66976 L
.23935 .66508 L
.24414 .65868 L
Mistroke
.25425 .63972 L
.26219 .6191 L
.27391 .57665 L
.28058 .54315 L
.2829 .52989 L
.28376 .52534 L
.28444 .52236 L
.28478 .52123 L
.28509 .52048 L
.2854 .52002 L
.28557 .51992 L
.28574 .51992 L
.28605 .5202 L
.28624 .52052 L
.28641 .52092 L
.28678 .52205 L
.2872 .52371 L
.29827 .58011 L
.31074 .62517 L
.3203 .65178 L
.33083 .67609 L
.35673 .72206 L
.39061 .76605 L
.46779 .84376 L
.51667 .88938 L
.54603 .91537 L
.57518 .93879 L
.60245 .9571 L
.61821 .96545 L
.63282 .97131 L
.63686 .97257 L
.64118 .97373 L
.64895 .97528 L
.65373 .97587 L
.65822 .97616 L
.66226 .97619 L
.66662 .97596 L
.67051 .97552 L
.67476 .97477 L
.6792 .97367 L
.68332 .97235 L
.69067 .96922 L
.69847 .96472 L
.70604 .95909 L
.71293 .95275 L
.72811 .93418 L
.74089 .91261 L
.75363 .88422 L
.76419 .854 L
.77324 .82164 L
Mistroke
.7821 .78192 L
.79028 .73482 L
.79702 .68293 L
.80005 .65266 L
.80232 .62468 L
.80402 .5982 L
.80541 .56942 L
.80628 .5423 L
.80671 .51755 L
.80677 .48904 L
.80639 .46303 L
.80599 .44842 L
.80551 .43535 L
.80405 .40693 L
.80217 .3811 L
.79962 .35484 L
.79677 .33199 L
.79377 .3127 L
.79092 .29749 L
.78761 .28274 L
.78109 .2606 L
.77705 .25053 L
.77263 .24214 L
.76876 .23677 L
.76445 .23279 L
.76207 .23144 L
.75981 .23069 L
.75558 .23066 L
.75322 .23141 L
.75104 .23257 L
.74867 .23437 L
.74618 .23686 L
.74211 .24226 L
.7384 .24871 L
.73442 .25733 L
.73035 .26817 L
.72313 .29337 L
.71725 .32146 L
.7141 .34066 L
.71147 .35996 L
.70938 .37847 L
.7075 .39889 L
.70612 .41779 L
.70494 .43919 L
.70418 .45918 L
.70375 .47823 L
.70358 .50117 L
.70375 .52239 L
.70399 .53424 L
.70435 .54718 L
Mistroke
.70532 .57083 L
.70651 .59197 L
.7079 .61179 L
.71209 .6567 L
.7175 .69955 L
.72476 .74388 L
.73232 .78066 L
.74137 .81627 L
.74996 .84367 L
.76 .86937 L
.76643 .88268 L
.77254 .89322 L
.77841 .90148 L
.78497 .90862 L
.79096 .9132 L
.79659 .91584 L
.80257 .91682 L
.80899 .91572 L
.8159 .91193 L
.81977 .90857 L
.82332 .90464 L
.82973 .89542 L
.83636 .88271 L
.84722 .85369 L
.85298 .83328 L
.85807 .81164 L
.86634 .76677 L
.87357 .7126 L
.87839 .66192 L
.88053 .63185 L
.88212 .60323 L
.88348 .56945 L
.88428 .53736 L
.88459 .50863 L
.88449 .47781 L
.88388 .44493 L
.88267 .41125 L
.8812 .3837 L
.87914 .35493 L
.87652 .32699 L
.8737 .30312 L
.8699 .27758 L
.86608 .25729 L
.86241 .24164 L
.85821 .22739 L
.85355 .21541 L
.84901 .20706 L
.84479 .20196 L
.8401 .19903 L
.83518 .19892 L
Mistroke
.83061 .20146 L
.82638 .20608 L
.82259 .21213 L
.81833 .22118 L
.81444 .23171 L
.8063 .2619 L
.80259 .28024 L
.79886 .30262 L
.79602 .32324 L
.79332 .34694 L
.79115 .37038 L
.78946 .39311 L
.7879 .42087 L
.78726 .43592 L
.78673 .45222 L
.78634 .46959 L
.78613 .48615 L
.78608 .50114 L
.78616 .51746 L
.7867 .5474 L
.78717 .5625 L
.78782 .57907 L
.78936 .60819 L
.79122 .63505 L
.79659 .69074 L
.80315 .73878 L
.81195 .78594 L
.81704 .80726 L
.82291 .82778 L
.82888 .84476 L
.8346 .85781 L
.84025 .86783 L
.84636 .87563 L
.85193 .88007 L
.85717 .88194 L
.86294 .88138 L
.86907 .87767 L
.87499 .87085 L
.88034 .86174 L
.88604 .84863 L
.89183 .83123 L
.90078 .79422 L
.90535 .7691 L
.90925 .74313 L
.91258 .71644 L
.91538 .68948 L
.91759 .66384 L
.91959 .63549 L
.92132 .60392 L
.92251 .57402 L
Mistroke
.92341 .5381 L
.92372 .5055 L
.92355 .47144 L
.92292 .4403 L
.92172 .40722 L
.91988 .37344 L
.91736 .34037 L
.91446 .31163 L
.91146 .28826 L
.90783 .26569 L
.90412 .24746 L
.9004 .233 L
.89633 .22076 L
.89164 .21069 L
.8875 .20493 L
.88365 .20201 L
.8794 .20137 L
.87493 .20354 L
.87006 .20925 L
.86574 .21733 L
.86092 .2299 L
.8566 .24479 L
.84961 .27784 L
.84612 .2998 L
.84324 .32191 L
.84068 .34592 L
.83835 .3733 L
.83722 .38963 L
.83633 .40491 L
.83561 .41968 L
.83497 .43567 L
.83447 .45241 L
.83413 .46811 L
.83391 .48695 L
.83387 .50413 L
.83397 .52048 L
.83424 .53817 L
.83515 .57011 L
.8365 .59988 L
.83813 .6265 L
.84049 .6564 L
.84317 .68363 L
.84896 .72876 L
.85659 .77171 L
.86108 .79111 L
.86636 .80973 L
.87219 .82575 L
.87495 .83183 L
.8779 .83734 L
.88337 .84494 L
Mistroke
.88847 .84906 L
.89401 .85033 L
.89714 .84956 L
.90004 .84786 L
.90584 .84153 L
.90904 .83625 L
.91195 .83029 L
.91714 .81662 L
.92236 .79844 L
.93057 .75834 L
.93466 .73114 L
.93805 .70317 L
.94138 .66846 L
.94395 .63341 L
.94573 .60061 L
.9471 .56392 L
.94757 .54478 L
.94789 .52356 L
.94801 .50143 L
.94793 .48076 L
.94731 .44451 L
.9467 .42461 L
.94598 .40677 L
.9442 .37437 L
.94206 .34568 L
.93978 .32179 L
.93694 .29813 L
.93348 .27529 L
.92943 .2547 L
.92571 .24023 L
.92141 .22773 L
.91724 .21942 L
.91334 .21463 L
.90878 .21243 L
.90444 .21362 L
.90049 .21745 L
.89688 .22329 L
.89302 .23213 L
.88907 .24421 L
.88467 .26174 L
.88092 .28078 L
.87719 .30458 L
.87375 .33262 L
.8712 .35911 L
.86923 .38532 L
.86754 .41542 L
.86683 .43279 L
.86631 .44887 L
.86574 .47908 L
.86564 .50735 L
Mistroke
.86601 .53846 L
.86639 .5541 L
.86695 .57126 L
.86825 .59952 L
.87011 .62918 L
.8723 .65616 L
.87467 .6798 L
.87781 .70552 L
.88113 .72802 L
.88823 .76469 L
.89262 .78169 L
.8969 .79485 L
.9018 .80632 L
.90433 .81086 L
.90715 .81485 L
.91194 .81913 L
.91636 .82032 L
.92145 .81841 L
.92623 .81328 L
.93054 .80569 L
.93443 .79623 L
.93854 .78321 L
.94268 .76642 L
.94723 .74284 L
.95101 .71791 L
.95466 .68731 L
.95789 .65189 L
.96013 .61892 L
.96172 .58686 L
.9624 .56803 L
.96288 .55072 L
.96326 .53061 L
.96345 .51155 L
.96337 .47896 L
.96276 .44501 L
.96181 .4169 L
.96033 .3872 L
.95826 .35726 L
.95551 .3277 L
.95247 .30273 L
.94934 .28265 L
.94563 .26413 L
.94189 .24993 L
.93836 .23998 L
.93441 .23226 L
.92999 .22748 L
.92774 .22651 L
.92527 .22655 L
.92091 .22939 L
.91691 .23518 L
Mistroke
.91299 .24392 L
.90941 .25479 L
.90319 .28141 L
.90006 .29951 L
.89741 .31808 L
.89483 .3401 L
.89243 .36566 L
.89046 .39291 L
.88905 .41904 L
.88808 .44481 L
.88745 .47252 L
.88725 .50335 L
.88753 .53211 L
.88788 .54855 L
.88833 .56339 L
.889 .58033 L
.88978 .5961 L
.8916 .62482 L
.89403 .65381 L
.89959 .70092 L
.90328 .72376 L
.90708 .74259 L
.91156 .76009 L
.91417 .76825 L
.9167 .77488 L
.91896 .77981 L
.92145 .78421 L
.92586 .78948 L
.92839 .79107 L
.93108 .79162 L
.93588 .78968 L
.94027 .78451 L
.94427 .77676 L
.94851 .76506 L
.95282 .74892 L
.95714 .72754 L
.96134 .7 L
.96478 .67033 L
.96745 .6402 L
.9694 .61131 L
.97101 .57795 L
.9716 .56075 L
.97208 .54201 L
.97249 .50786 L
.97235 .47504 L
.97176 .44508 L
.97059 .41328 L
.96971 .39616 L
.96879 .38112 L
.96653 .35236 L
Mistroke
.96357 .32421 L
.96032 .30092 L
.957 .28258 L
.95372 .26857 L
.95048 .25802 L
.94678 .24937 L
.9427 .24354 L
.94062 .24197 L
.93835 .24128 L
.93422 .24272 L
.93025 .24739 L
.92665 .25449 L
.9227 .26571 L
.91876 .28089 L
.91562 .29638 L
.91247 .31577 L
.90944 .33921 L
.90668 .3668 L
.90457 .39479 L
.90309 .42155 L
.90204 .44951 L
.90148 .47585 L
.90133 .50505 L
.90143 .51979 L
.90168 .53596 L
.90244 .56272 L
.90371 .59079 L
.90532 .61633 L
.90714 .63862 L
.90932 .66014 L
.91197 .68141 L
.91752 .71459 L
.92134 .73119 L
.92518 .74395 L
.92878 .75285 L
.93279 .75963 L
.93644 .76305 L
.94047 .7639 L
.94468 .76149 L
.94854 .75617 L
.95207 .74854 L
.95518 .73937 L
.9586 .72625 L
.96165 .71143 L
.96459 .69369 L
.96745 .67213 L
.96963 .65166 L
.97169 .62757 L
.97355 .59913 L
.97436 .58301 L
Mistroke
.97499 .5677 L
.97579 .5397 L
.97618 .50938 L
.97619 .49265 L
.97607 .47729 L
.97579 .46058 L
.97534 .44314 L
.97421 .41467 L
.97338 .39909 L
.97247 .38499 L
.97051 .36058 L
.96832 .33928 L
.96543 .31731 L
.96249 .2999 L
.95943 .28575 L
.95649 .27523 L
.95294 .26592 L
.94949 .25999 L
.94622 .25694 L
.9432 .25623 L
.93988 .25773 L
.93643 .26183 L
.933 .26855 L
.92947 .27846 L
.92629 .29024 L
.92356 .30288 L
.92059 .31986 L
.91768 .34066 L
.91527 .36236 L
.91339 .38368 L
.91186 .40561 L
.9106 .4296 L
.90971 .45438 L
.90917 .48194 L
.90909 .50602 L
.90938 .5316 L
.91002 .55537 L
.91089 .57645 L
.91241 .60243 L
.9142 .62512 L
.91655 .64833 L
.91945 .67061 L
.92208 .68671 L
.92516 .7018 L
.92878 .71553 L
.93236 .72546 L
.93433 .72956 L
.93646 .73297 L
.94034 .73658 L
.94251 .73715 L
Mistroke
.94455 .73676 L
.94678 .73527 L
.94916 .73244 L
.95106 .72921 L
.95311 .72472 L
.9571 .7127 L
.96057 .69815 L
.96356 .68182 L
.96641 .66187 L
.96879 .64074 L
.97063 .62011 L
.97228 .59622 L
.97365 .56881 L
.97417 .55455 L
.9746 .53863 L
.975 .51011 L
.97495 .48333 L
.97447 .45588 L
.97401 .44082 L
.97348 .42743 L
.97215 .40222 L
.97054 .3798 L
.96825 .35558 L
.9658 .33553 L
.96276 .31627 L
.95922 .29938 L
.95613 .28843 L
.95267 .27958 L
.94929 .27402 L
.94616 .27133 L
.94245 .27106 L
.94037 .27227 L
.93845 .27424 L
.935 .27994 L
.93144 .28882 L
.92845 .29896 L
.92585 .31 L
.92322 .32364 L
.92059 .34043 L
.91679 .37262 L
.91509 .39186 L
.91377 .4106 L
.91251 .43398 L
.91168 .45665 L
.91123 .4773 L
.91106 .49978 L
.91125 .52416 L
.9115 .53631 L
.91188 .54951 L
.91285 .57227 L
Mistroke
.91407 .59271 L
.91571 .61354 L
.91782 .63411 L
.9199 .65033 L
.92241 .66604 L
.92566 .68187 L
.92897 .69383 L
.9306 .69845 L
.93236 .70256 L
.93559 .70789 L
.93873 .7105 L
.94211 .71054 L
.94529 .70794 L
.94812 .70335 L
.95136 .6953 L
.95311 .68951 L
.95469 .68338 L
.95741 .67038 L
.9601 .65387 L
.96224 .63725 L
.96397 .62056 L
.9655 .60232 L
.96668 .58439 L
.96776 .56264 L
.96857 .538 L
.96895 .51579 L
.96901 .49189 L
.96869 .46709 L
.96833 .45329 L
.9679 .44077 L
.96684 .41835 L
.96537 .39579 L
.96375 .37679 L
.962 .36029 L
.95987 .34399 L
.95727 .32802 L
.9544 .31426 L
.95114 .30241 L
.94795 .29409 L
.94486 .28866 L
.94306 .28661 L
.94116 .28528 L
.93773 .285 L
.93582 .286 L
.93406 .28767 L
.93215 .29029 L
.93013 .29399 L
.92684 .30221 L
.92345 .31381 L
.92046 .32714 L
Mistroke
.91791 .34129 L
.91373 .37228 L
.91198 .38965 L
.91036 .40982 L
.9091 .43031 L
.90821 .45032 L
.90766 .46856 L
.90735 .48857 L
.90734 .51019 L
.90748 .52215 L
.9077 .53286 L
.90838 .5533 L
.9093 .57183 L
.91041 .58852 L
.91184 .60513 L
.91496 .63179 L
.91698 .64466 L
.91903 .65522 L
.92143 .6651 L
.92414 .67357 L
.92689 .67958 L
.92849 .68199 L
.93 .68358 L
.93308 .68477 L
.93482 .68423 L
.93639 .68299 L
.93902 .67925 L
.94181 .67283 L
.9446 .66361 L
.94704 .65282 L
.94971 .63729 L
.95194 .62023 L
.95368 .60314 L
.95525 .583 L
.95657 .55944 L
.95706 .54707 L
.95747 .53318 L
.9577 .52115 L
.95784 .50811 L
.95786 .49573 L
.95778 .48441 L
.95736 .46228 L
.95701 .45125 L
.95653 .43922 L
.95542 .41858 L
.95409 .40006 L
.95219 .37974 L
.95016 .36264 L
.94763 .34583 L
.94468 .33059 L
Mistroke
.94208 .3202 L
.93914 .31122 L
.93625 .30484 L
.93356 .30084 L
.93034 .29834 L
.92851 .29798 L
.92682 .29832 L
.92373 .30057 L
.92052 .30522 L
.91758 .31161 L
.9145 .32072 L
.91175 .33121 L
.90935 .34246 L
.90533 .36718 L
.90339 .3827 L
.90185 .39763 L
.90039 .4149 L
.89915 .43382 L
.89863 .44392 L
.89816 .45512 L
.89758 .47498 L
.89734 .49373 L
.8974 .51362 L
.89776 .53198 L
.89834 .5482 L
.89914 .56382 L
.90024 .57955 L
.90137 .59215 L
.90279 .60506 L
.90451 .61758 L
.90657 .62943 L
.90869 .63891 L
.91074 .64603 L
.91277 .65133 L
.91472 .65495 L
.9169 .65742 L
.91925 .65831 L
.92172 .65725 L
.92403 .65439 L
.92605 .65028 L
.92817 .64423 L
.93036 .63579 L
.93224 .62647 L
.93423 .61393 L
.93592 .60039 L
.93718 .58761 L
.93834 .57297 L
.93935 .55587 L
.94005 .53922 L
.94035 .52869 L
Mistroke
.94055 .51886 L
.94067 .50794 L
.94069 .49632 L
.94047 .47668 L
.94021 .46558 L
.93987 .45531 L
.93901 .43642 L
.93797 .41977 L
.93647 .40143 L
.93478 .38516 L
.93058 .35595 L
.92812 .34361 L
.9252 .33212 L
.92257 .32416 L
.91961 .31756 L
.91674 .31322 L
.91406 .31089 L
.91251 .31026 L
.91087 .31014 L
.9079 .31137 L
.90611 .31301 L
.90443 .31516 L
.90135 .32071 L
.89822 .32865 L
.89547 .3377 L
.89249 .35011 L
.88991 .36357 L
.88796 .37578 L
.88605 .39005 L
.8833 .41695 L
.88209 .43297 L
.88109 .45038 L
.88048 .46542 L
.88005 .48204 L
.8799 .49729 L
.87996 .51104 L
.88023 .52577 L
.88076 .54072 L
.88141 .55317 L
.88217 .56418 L
.88316 .57553 L
.88438 .58672 L
.88602 .59841 L
.8877 .60776 L
.88971 .6163 L
.89078 .61993 L
.89198 .62325 L
.89404 .62746 L
.89602 .6298 L
.89724 .63045 L
Mistroke
.89841 .63052 L
.90058 .62922 L
.9025 .62645 L
.90449 .62185 L
.90629 .61599 L
.90784 .60945 L
.90953 .60031 L
.91119 .58879 L
.91255 .5765 L
.91362 .56411 L
.91454 .54998 L
.91519 .5358 L
.91559 .52255 L
.91581 .50771 L
.91581 .49124 L
.9157 .48286 L
.91551 .47359 L
.91496 .45729 L
.91421 .4422 L
.91329 .42821 L
.91211 .41398 L
.9095 .39022 L
.90602 .3677 L
.90378 .35663 L
.90155 .34756 L
.89897 .33909 L
.89603 .33167 L
.89464 .32889 L
.89315 .32638 L
.89043 .32303 L
.88778 .32118 L
.88528 .32065 L
.88254 .32141 L
.87963 .32372 L
.87805 .32564 L
.87659 .32782 L
.87338 .33411 L
.87066 .34114 L
.86791 .35003 L
.86314 .37053 L
.85949 .39234 L
.85663 .41553 L
.85532 .42931 L
.85431 .44241 L
.85347 .45638 L
.85291 .46911 L
.85268 .47611 L
.8525 .48366 L
.85234 .49716 L
.85238 .5084 L
Mistroke
.8526 .52036 L
.85303 .53229 L
.8536 .54284 L
.85428 .55207 L
.855 .55993 L
.85699 .57537 L
.85828 .58247 L
.85977 .58877 L
.86126 .59343 L
.86268 .59655 L
.86357 .59793 L
.86439 .59883 L
.86531 .59941 L
.86628 .59956 L
.8679 .59872 L
.86882 .59764 L
.86966 .59625 L
.87124 .5925 L
.87267 .5877 L
.87389 .58238 L
.87511 .57557 L
.87631 .56703 L
.87742 .55674 L
.87822 .54706 L
.87858 .54159 L
.87891 .53553 L
.87938 .5243 L
.87965 .51335 L
.87973 .50647 L
.87976 .49986 L
.87966 .48727 L
.87934 .47377 L
.87885 .46125 L
.87809 .44757 L
.87704 .43331 L
.87478 .41081 L
.8721 .39133 L
.86858 .37231 L
.86422 .3552 L
.86159 .34742 L
.85905 .34133 L
.85615 .33595 L
.85463 .33373 L
.85297 .33174 L
.85136 .33024 L
.84987 .3292 L
.84844 .32851 L
.84693 .32812 L
.8443 .3282 L
.84142 .32942 L
Mistroke
.83861 .33172 L
.8361 .33473 L
.83326 .33925 L
.83065 .34447 L
.82625 .35586 L
.8219 .37084 L
.81829 .38684 L
.81496 .40564 L
.81238 .42433 L
.81053 .44182 L
.80904 .46114 L
.80845 .47186 L
.80808 .48157 L
.80794 .48674 L
.80784 .49153 L
.80778 .5002 L
.80786 .50907 L
.80797 .51384 L
.80811 .51807 L
.80844 .52516 L
.80892 .53214 L
.80947 .53808 L
.81004 .54294 L
.8108 .54789 L
.81172 .55234 L
.81216 .55404 L
.81265 .5556 L
.81355 .55779 L
.8145 .55917 L
.81504 .55957 L
.81554 .5597 L
.81645 .55933 L
.81741 .5581 L
.8179 .5571 L
.81842 .55576 L
.81933 .55267 L
.82032 .5479 L
.82113 .54255 L
.82174 .53735 L
.82223 .53193 L
.82268 .52542 L
.82304 .5178 L
.82317 .51377 L
.82327 .50923 L
.82336 .50057 L
.82329 .49173 L
.82311 .48323 L
.82278 .47432 L
.82235 .46576 L
.82121 .44953 L
Mistroke
.81949 .43201 L
.81707 .41349 L
.81402 .39557 L
.81004 .37753 L
.80525 .36106 L
.80028 .34824 L
.79526 .33871 L
.79046 .33221 L
.78773 .32952 L
.78628 .32836 L
.78472 .32733 L
.78185 .32595 L
.77918 .32526 L
.77665 .32511 L
.77388 .3255 L
.771 .32649 L
.76835 .32793 L
.76587 .32971 L
.76365 .33168 L
.75877 .33719 L
.75372 .34465 L
.74854 .35422 L
.74006 .37442 L
.73328 .39524 L
.72746 .41735 L
.72026 .45206 L
.71777 .46624 L
.71608 .47535 L
.71571 .477 L
.71534 .47838 L
.71513 .47899 L
.71495 .47943 L
.71478 .47977 L
.71461 .47999 L
.7143 .48013 L
.71402 .47996 L
.7137 .47944 L
.71336 .47852 L
.71304 .47738 L
.71273 .4761 L
.71197 .47233 L
.71024 .46267 L
.7038 .42921 L
.69204 .3837 L
.67582 .33879 L
.6521 .29195 L
.62071 .24735 L
.54864 .1719 L
.46329 .09268 L
.43691 .07054 L
Mistroke
.40657 .04847 L
.39222 .03986 L
.37665 .03226 L
.369 .0293 L
.36175 .02703 L
.35521 .02546 L
.34811 .02432 L
.34112 .02381 L
.33458 .02394 L
.32742 .0248 L
.31976 .02662 L
.31593 .02791 L
.31178 .02961 L
.30426 .03355 L
.29702 .03847 L
.29038 .04403 L
.27868 .05664 L
.2662 .07466 L
.25378 .0983 L
.24283 .12511 L
.23177 .15958 L
.2225 .19625 L
.21361 .24112 L
.20575 .29364 L
.20248 .32154 L
.19948 .35261 L
.19731 .3805 L
.1955 .41035 L
.19432 .43733 L
.19384 .45263 L
.19351 .4669 L
.19321 .49173 L
.19328 .51798 L
.19377 .54372 L
.19457 .56689 L
.19583 .59139 L
.19759 .61623 L
.19966 .63858 L
.20192 .65828 L
.20691 .69126 L
.21268 .71852 L
.21861 .73859 L
.2219 .74712 L
.22563 .7549 L
.22963 .76126 L
.23344 .76556 L
.23774 .76851 L
.23992 .76928 L
.24233 .76958 L
.24659 .76871 L
Mistroke
.25056 .7663 L
.25281 .76425 L
.25516 .76157 L
.25929 .7555 L
.26361 .74719 L
.26815 .73609 L
.27526 .71302 L
.28195 .68289 L
.28725 .64989 L
.29111 .61664 L
.2927 .59862 L
.29408 .57888 L
.29502 .56153 L
.29578 .54199 L
.29627 .52049 L
.2964 .50824 L
.29642 .49695 L
.2962 .47479 L
.29567 .45354 L
.29489 .43365 L
.29376 .41241 L
.29094 .37421 L
.28629 .32924 L
.28088 .28956 L
.27402 .24967 L
.26519 .20877 L
.25461 .17025 L
.24366 .13927 L
.23257 .11545 L
.22193 .09894 L
.21587 .09217 L
.20919 .08688 L
.20283 .08397 L
.19692 .08318 L
.19058 .08442 L
.1838 .08828 L
.17748 .09439 L
.17179 .10211 L
.1653 .11375 L
.15847 .12968 L
.14689 .16717 L
.14113 .19208 L
.13632 .21718 L
.13161 .24668 L
.12713 .28115 L
.12358 .31521 L
.12084 .34797 L
.11874 .38025 L
.11706 .41506 L
.116 .44837 L
Mistroke
.11563 .46723 L
.11544 .48462 L
.11544 .51626 L
.11596 .54923 L
.11686 .57781 L
.11806 .60373 L
.11977 .63094 L
.12203 .65859 L
.12472 .68433 L
.12811 .70995 L
.13209 .73363 L
.13614 .75266 L
.14014 .76752 L
.14411 .77911 L
.14887 .78948 L
.15333 .79611 L
.15734 .79976 L
.16179 .8014 L
.16645 .80049 L
.17078 .79729 L
.17477 .7923 L
.17834 .78612 L
.18236 .77713 L
.18604 .76683 L
.19367 .73826 L
.19987 .70548 L
.20554 .66362 L
.20813 .63797 L
.21008 .61357 L
.21163 .58847 L
.21273 .56436 L
.21352 .53726 L
.2139 .5077 L
.2139 .49267 L
.21376 .47628 L
.21312 .44638 L
.21201 .41732 L
.21057 .39067 L
.20696 .34356 L
.20435 .31762 L
.20154 .29403 L
.19488 .24934 L
.18633 .20649 L
.17626 .16966 L
.17007 .15263 L
.16407 .13959 L
.16071 .13368 L
.15749 .12893 L
.15138 .12226 L
.14791 .11983 L
Mistroke
.1447 .11846 L
.14117 .11793 L
.13743 .11849 L
.13171 .12166 L
.12565 .12823 L
.12005 .13746 L
.11508 .14846 L
.10948 .16442 L
.10371 .18547 L
.0986 .20883 L
.09429 .233 L
.08715 .2858 L
.08406 .31647 L
.08133 .35053 L
.07941 .38138 L
.07803 .41081 L
.07696 .44359 L
.07636 .47883 L
.07626 .49875 L
.07632 .51702 L
.07656 .53687 L
.07701 .55758 L
.0782 .59142 L
.07912 .60998 L
.08013 .62685 L
.08237 .65669 L
.08482 .68201 L
.08808 .70861 L
.09157 .73103 L
.09563 .75154 L
.09959 .76704 L
.10188 .77434 L
.10442 .78117 L
.10917 .79071 L
.11374 .7963 L
.11864 .7987 L
.12283 .79794 L
.1274 .79419 L
.13013 .79047 L
.13269 .78597 L
.13735 .77509 L
.14213 .75996 L
.14699 .7398 L
.15088 .71932 L
.15462 .69493 L
.15745 .67206 L
.16013 .64527 L
.16221 .61888 L
.16376 .59329 L
.16499 .56538 L
Mistroke
.16581 .53479 L
.16612 .50576 L
.16601 .47814 L
.16556 .45329 L
.16471 .42649 L
.16335 .39744 L
.16133 .36617 L
.15867 .33457 L
.15569 .30629 L
.14922 .25968 L
.14505 .23638 L
.14084 .21679 L
.1319 .18502 L
.12683 .17199 L
.12123 .16124 L
.11575 .15415 L
.11051 .15046 L
.10578 .14968 L
.10067 .15162 L
.09602 .15598 L
.09101 .16363 L
.08592 .17481 L
.08135 .18811 L
.07372 .21865 L
.06982 .23932 L
.06654 .26018 L
.06028 .31294 L
.05745 .34615 L
.0553 .37889 L
.05361 .41455 L
.05258 .4479 L
.05223 .46643 L
.05201 .48669 L
.0521 .52335 L
.05271 .55692 L
.05372 .58646 L
.05537 .61907 L
.0574 .64798 L
.05966 .67293 L
.06204 .69409 L
.06833 .7347 L
.07205 .7516 L
.0763 .76621 L
.0805 .77656 L
.08445 .78305 L
.08917 .78706 L
.09186 .78762 L
.09434 .78706 L
.09887 .78337 L
.10113 .78023 L
Mistroke
.10359 .7758 L
.10834 .76409 L
.11249 .75013 L
.11676 .73151 L
.12086 .70851 L
.12671 .66297 L
.12936 .634 L
.13135 .60541 L
.13282 .57621 L
.13338 .56113 L
.13385 .54431 L
.13432 .51415 L
.13432 .48567 L
.13411 .46844 L
.13377 .45213 L
.13276 .42177 L
.13199 .40505 L
.13114 .38975 L
.12874 .35602 L
.12613 .32776 L
.12325 .30263 L
.11688 .2604 L
.1128 .23989 L
.10878 .22334 L
.10409 .20794 L
.0989 .1951 L
.09434 .18713 L
.09011 .18232 L
.08516 .17979 L
.08046 .18044 L
.07615 .18373 L
.07222 .18909 L
.068 .19751 L
.06367 .20934 L
.05953 .22407 L
.05534 .24305 L
.0486 .28493 L
.04528 .31314 L
.04231 .34543 L
.04024 .37475 L
.03848 .4082 L
.0378 .42553 L
.03724 .44406 L
.03663 .47758 L
.03656 .51362 L
.03678 .53388 L
.03716 .55256 L
.03827 .58544 L
.03973 .61412 L
.04192 .64519 L
Mistroke
.04447 .67224 L
.04709 .69414 L
.05021 .71483 L
.05314 .73037 L
.05652 .74459 L
.06032 .75672 L
.06405 .76518 L
.06625 .76875 L
.0686 .77146 L
.07285 .77362 L
.0774 .77215 L
.0815 .76751 L
.08373 .76363 L
.08611 .75839 L
.09029 .74625 L
.09399 .73198 L
.09766 .71403 L
.10341 .67538 L
.1061 .65062 L
.10853 .62197 L
.11033 .59333 L
.11155 .56609 L
.11209 .54922 L
.11244 .53337 L
.11268 .51584 L
.11274 .49705 L
.11263 .47912 L
.11236 .46228 L
.11199 .44723 L
.11146 .4311 L
.11015 .40264 L
.10856 .37748 L
.10629 .34968 L
.10373 .32485 L
.09826 .28521 L
.09471 .2658 L
.09117 .25005 L
.08739 .23649 L
.08311 .22469 L
.08058 .21931 L
.07823 .21529 L
.07352 .21004 L
.06889 .20838 L
.06627 .20898 L
.06383 .21055 L
.06127 .21328 L
.05897 .21671 L
.05636 .2218 L
.05394 .2277 L
.04982 .24061 L
Mistroke
.04555 .25842 L
.04145 .28081 L
.038 .30499 L
.03521 .32962 L
.03292 .35488 L
.03076 .3859 L
.02924 .41562 L
.02811 .44933 L
.02772 .46844 L
.02753 .48581 L
.02758 .51958 L
.02812 .55084 L
.02865 .56825 L
.02937 .58621 L
.03108 .61699 L
.03346 .64772 L
.03668 .67793 L
.03984 .70018 L
.04306 .7178 L
.04688 .73368 L
.04893 .74033 L
.05119 .74636 L
.05508 .75379 L
.05881 .75772 L
.06099 .75866 L
.06328 .75859 L
.06737 .75583 L
.07097 .75054 L
.0747 .74209 L
.07809 .73159 L
.08103 .72006 L
.08427 .70419 L
.08749 .68447 L
.09242 .64292 L
.09459 .61731 L
.09621 .59205 L
.09695 .57737 L
.09753 .56321 L
.09806 .54665 L
.0984 .53138 L
.0986 .51621 L
.09868 .50003 L
.09844 .47098 L
.0981 .45499 L
.09765 .4401 L
.09702 .42399 L
.09616 .40694 L
.09452 .38166 L
.09229 .35542 L
.08951 .32998 L
Mistroke
.08653 .30841 L
.08037 .27579 L
.07655 .26137 L
.07288 .25091 L
.06905 .24309 L
.06537 .23834 L
.06128 .23609 L
.05687 .23721 L
.05469 .23917 L
.05232 .24235 L
.04811 .25098 L
.04418 .26281 L
.04072 .2767 L
.03743 .29364 L
.03459 .31195 L
.03005 .35164 L
.02799 .37655 L
.02644 .40079 L
.02514 .42854 L
.02423 .45873 L
.02381 .49012 L
.02388 .51872 L
.0241 .5344 L
.02448 .55123 L
.02557 .581 L
.02702 .60754 L
.02899 .63394 L
.031 .65475 L
.03353 .67558 L
.03687 .69678 L
.04024 .71297 L
.04422 .72695 L
.0463 .73241 L
.04863 .73718 L
.05266 .74232 L
.05494 .7436 L
.05702 .74377 L
.06105 .74144 L
.06479 .73609 L
.06821 .72841 L
.07173 .71744 L
.07488 .70466 L
.07757 .69108 L
.08047 .67307 L
.08329 .65115 L
.08556 .6287 L
.08736 .6062 L
.08819 .59349 L
.08897 .57946 L
.09002 .55438 L
Mistroke
.09044 .53986 L
.09074 .52442 L
.09091 .49664 L
.09066 .47097 L
.09007 .44737 L
.08903 .42212 L
.08827 .40837 L
.08748 .39616 L
.08581 .37503 L
.08371 .35401 L
.07918 .32063 L
.07628 .30488 L
.07337 .29217 L
.06998 .28068 L
.06801 .27545 L
.06615 .27137 L
.06277 .26605 L
.05901 .26314 L
.05568 .26314 L
.05215 .26583 L
.04874 .27116 L
.04561 .2786 L
.04291 .28723 L
.04011 .29859 L
.03706 .31443 L
.03451 .33109 L
.03204 .35119 L
.02974 .37532 L
.02798 .39936 L
.0267 .42282 L
.0258 .44608 L
.02519 .47137 L
.02496 .49876 L
.02501 .51417 L
.02519 .52822 L
.0258 .55374 L
.02684 .57979 L
.02756 .59317 L
.02845 .60702 L
.03036 .63065 L
.0331 .65614 L
.03598 .67645 L
.03907 .69318 L
.04262 .70759 L
.04583 .71706 L
.0495 .72437 L
.05161 .72703 L
.05355 .72855 L
.0558 .72922 L
.05794 .7288 L
Mistroke
.06171 .72556 L
.06382 .72235 L
.06573 .71851 L
.06938 .70865 L
.07263 .69673 L
.07811 .66827 L
.08078 .64921 L
.08294 .63005 L
.08496 .60748 L
.08666 .58228 L
.08776 .55947 L
.08822 .54634 L
.08855 .5341 L
.08889 .51146 L
.08888 .48745 L
.08855 .46623 L
.08798 .4467 L
.08705 .42587 L
.08572 .40437 L
.08405 .38398 L
.08188 .36336 L
.07925 .344 L
.07651 .32826 L
.07372 .31564 L
.07102 .30617 L
.06777 .29773 L
.06459 .29234 L
.06176 .28975 L
.05864 .28922 L
.05538 .29129 L
.05239 .29564 L
.04966 .3018 L
.04725 .30916 L
.0446 .31964 L
.04224 .33146 L
.03988 .34616 L
.03763 .36382 L
.03591 .3806 L
.03432 .40008 L
.03294 .42222 L
.03197 .44402 L
.03155 .45698 L
.03123 .47083 L
.03096 .49589 L
.03109 .52065 L
.03134 .53452 L
.03167 .54719 L
.03255 .56996 L
.03384 .59314 L
.0353 .61276 L
Mistroke
.03692 .62999 L
.04138 .66428 L
.04426 .67985 L
.04722 .69215 L
.05003 .70103 L
.05322 .7083 L
.05507 .71129 L
.05677 .71327 L
.05875 .71471 L
.06063 .71523 L
.06396 .71417 L
.06753 .71023 L
.07056 .70453 L
.07329 .69738 L
.07617 .68763 L
.07908 .67512 L
.08189 .65989 L
.08431 .64371 L
.08627 .62769 L
.08809 .60951 L
.08943 .59301 L
.09065 .57412 L
.09152 .55645 L
.09212 .53959 L
.09255 .5196 L
.09269 .50126 L
.09256 .48129 L
.09211 .46065 L
.09133 .44035 L
.09076 .42926 L
.09014 .41932 L
.08882 .40216 L
.08709 .38461 L
.08347 .358 L
.08119 .34583 L
.0789 .33614 L
.07607 .32703 L
.07327 .32071 L
.07068 .31706 L
.06781 .3153 L
.06617 .31535 L
.06469 .31607 L
.063 .31768 L
.06142 .31996 L
.05866 .32586 L
.05581 .33479 L
.05346 .34468 L
.05142 .35557 L
.04919 .37048 L
.04739 .38575 L
Mistroke
.04575 .40333 L
.04446 .42122 L
.0434 .44119 L
.04293 .45287 L
.0426 .46386 L
.04224 .48231 L
.04212 .49983 L
.04225 .51911 L
.04269 .53971 L
.04346 .56081 L
.0445 .58024 L
.04566 .59696 L
.04718 .61426 L
.04912 .63187 L
.05146 .64871 L
.05433 .66481 L
.05721 .67725 L
.06006 .68666 L
.06285 .69346 L
.066 .69867 L
.0678 .70054 L
.06945 .7016 L
.07252 .70191 L
.07535 .70034 L
.07841 .69661 L
.08159 .69042 L
.08424 .68332 L
.08663 .67526 L
.09162 .6523 L
.09388 .63836 L
.0961 .62168 L
.09797 .60422 L
.09965 .58449 L
.10089 .5652 L
.10175 .54724 L
.10233 .52895 L
.10262 .51164 L
.10264 .4916 L
.10253 .48163 L
.10231 .47081 L
.10167 .4522 L
.10081 .43553 L
.09947 .41707 L
.09797 .40152 L
.09592 .3854 L
.09372 .37212 L
.09161 .36232 L
.08917 .35374 L
.08675 .34768 L
.08446 .34394 L
Mistroke
.08234 .34209 L
.08 .34179 L
.07757 .34342 L
.07534 .34672 L
.07411 .34932 L
.0728 .35274 L
.07051 .36054 L
.06841 .37001 L
.06661 .38031 L
.06485 .39298 L
.06315 .40866 L
.06167 .42671 L
.0606 .44493 L
.05995 .46055 L
.05949 .4782 L
.0593 .49706 L
.05938 .51479 L
.0597 .53145 L
.06018 .54643 L
.06097 .56341 L
.06193 .57895 L
.06321 .59523 L
.06482 .61149 L
.06831 .63759 L
.07055 .65014 L
.0728 .66045 L
.07544 .67008 L
.07842 .67836 L
.08 .68176 L
.08152 .68442 L
.08439 .68798 L
.08753 .68978 L
.0893 .68986 L
.09093 .68935 L
.09365 .68727 L
.09658 .68327 L
.09955 .67725 L
.10222 .67004 L
.10524 .65959 L
.1079 .64801 L
.11229 .6225 L
.11436 .60642 L
.11601 .59068 L
.11751 .57265 L
.11818 .56261 L
.11873 .55295 L
.11944 .5367 L
.11986 .52181 L
.12008 .50587 L
.12009 .49696 L
Mistroke
.12003 .48878 L
.11976 .47416 L
.11932 .46135 L
.1186 .44721 L
.11773 .43463 L
.11656 .42171 L
.1151 .40932 L
.11369 .39989 L
.112 .39086 L
.11003 .3828 L
.10889 .37913 L
.10778 .37618 L
.10673 .37391 L
.10556 .37196 L
.10349 .36988 L
.10147 .3695 L
.09963 .37057 L
.09763 .3733 L
.09558 .37792 L
.09387 .38337 L
.09236 .38959 L
.09081 .39758 L
.08928 .40758 L
.08779 .41999 L
.0866 .43297 L
.08565 .44665 L
.08497 .46002 L
.08445 .47518 L
.08427 .48404 L
.08417 .49246 L
.08415 .50143 L
.08419 .50969 L
.08433 .51927 L
.08454 .52838 L
.08482 .5373 L
.08516 .54565 L
.08598 .56103 L
.08711 .57713 L
.08863 .59376 L
.0902 .60755 L
.09208 .62109 L
.09597 .64233 L
.09842 .6524 L
.10122 .6615 L
.10399 .66842 L
.1066 .67327 L
.10823 .67554 L
.10975 .67717 L
.11143 .67844 L
.11323 .6792 L
Mistroke
.11479 .67937 L
.11625 .67911 L
.11785 .67839 L
.11956 .67709 L
.12238 .67378 L
.12488 .66956 L
.12768 .66334 L
.13021 .65623 L
.13441 .64087 L
.13842 .6209 L
.14209 .59577 L
.1436 .58221 L
.14499 .56686 L
.14595 .55352 L
.14639 .54613 L
.14674 .53912 L
.14726 .52556 L
.14755 .51333 L
.14766 .50081 L
.14764 .49384 L
.14756 .4874 L
.14725 .47486 L
.14698 .46809 L
.14668 .46207 L
.14607 .45241 L
.14524 .44259 L
.14422 .43326 L
.14314 .42549 L
.1417 .41748 L
.14023 .41125 L
.13882 .40682 L
.13723 .4033 L
.13638 .40202 L
.13544 .40104 L
.13445 .40051 L
.13351 .40048 L
.13186 .40151 L
.13094 .40271 L
.13011 .40419 L
.12857 .40803 L
.12718 .41284 L
.12601 .41809 L
.12483 .42474 L
.12366 .43309 L
.12259 .44303 L
.12182 .45236 L
.12113 .46339 L
.12066 .47437 L
.12038 .48485 L
.12023 .49739 L
Mistroke
.12029 .50959 L
.1205 .52104 L
.12084 .53171 L
.12137 .54343 L
.12212 .55578 L
.12424 .58056 L
.12577 .59379 L
.12737 .60531 L
.13078 .62469 L
.13493 .64197 L
.13735 .64969 L
.14006 .65672 L
.14272 .66217 L
.14521 .66608 L
.14665 .66788 L
.1482 .66942 L
.14991 .6707 L
.1515 .67149 L
.15437 .67198 L
.156 .67174 L
.15752 .67118 L
.16024 .66937 L
.16174 .66792 L
.16309 .66635 L
.16805 .65828 L
.17071 .65237 L
.17346 .64499 L
.17806 .62932 L
.18191 .61214 L
.18535 .5923 L
.18775 .5745 L
.18887 .5643 L
.18978 .55463 L
.19052 .54532 L
.19117 .53531 L
.19162 .52638 L
.19192 .51831 L
.19213 .50984 L
.19221 .50085 L
.19215 .49193 L
.19196 .48405 L
.19167 .47716 L
.19131 .47107 L
.19092 .466 L
.19042 .46094 L
.1898 .45603 L
.18907 .45148 L
.18832 .44788 L
.1876 .44519 L
.18674 .44285 L
Mistroke
.18592 .44135 L
.18499 .44046 L
.18399 .4404 L
.18349 .44072 L
.18295 .44133 L
.18199 .44314 L
.18108 .44576 L
.18029 .44893 L
.17961 .45248 L
.17901 .45633 L
.17842 .46112 L
.17786 .46689 L
.1774 .47322 L
.17702 .48047 L
.1768 .4871 L
.17666 .49478 L
.17663 .4993 L
.17665 .50434 L
.17671 .50921 L
.1768 .51378 L
.17708 .52264 L
.17753 .53224 L
.17818 .54271 L
.17896 .55258 L
.18132 .57493 L
.18403 .59361 L
.18702 .6097 L
.19104 .62664 L
.19535 .64072 L
.2002 .65283 L
.2051 .66189 L
.2097 .668 L
.21237 .67059 L
.21484 .67243 L
.21755 .67384 L
.22009 .67463 L
.22288 .67492 L
.22445 .67482 L
.22588 .67458 L
.22874 .67364 L
.23035 .67285 L
.23183 .67197 L
.23735 .66734 L
.24194 .66188 L
.24609 .65567 L
.25486 .6384 L
.26233 .61877 L
.26905 .59642 L
.2782 .55615 L
.28338 .5273 L
Mistroke
.28386 .52489 L
.28434 .52279 L
.28475 .52133 L
.28494 .52081 L
.28511 .52043 L
.28542 .51998 L
.28559 .51989 L
.28577 .51989 L
.28595 .52003 L
.28613 .52027 L
.28647 .52102 L
.28681 .5221 L
.2872 .52364 L
.28797 .52739 L
.29026 .54022 L
.29666 .57295 L
.30847 .61801 L
.31785 .64543 L
.32817 .67035 L
.35303 .71638 L
.38248 .75656 L
.41425 .79156 L
.50173 .87565 L
.55505 .92297 L
.58354 .94487 L
.59649 .9535 L
.61103 .9619 L
.62335 .96776 L
.63021 .97043 L
.63676 .97256 L
.6442 .97444 L
.65103 .97559 L
.65745 .97615 L
.66446 .97613 L
.67216 .97529 L
.67913 .97371 L
.68298 .97249 L
.68713 .97087 L
.69462 .96712 L
.70159 .96257 L
.70887 .95665 L
.72164 .94296 L
.73695 .91994 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.678571 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.499995 0.221787 0.500007 0.443854 [
[.5 1.0125 -3.5 0 ]
[.5 1.0125 3.5 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -64.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.000 15.813 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
[ ] 0 setdash
.82218 .53269 m
.82263 .52651 L
.82295 .52043 L
.82321 .51293 L
.82334 .5054 L
.82337 .49811 L
.8233 .49113 L
.82312 .48324 L
.82281 .47466 L
.82237 .46587 L
.82175 .4563 L
.82024 .43889 L
.8178 .41848 L
.81497 .40061 L
.8115 .3836 L
.80782 .36933 L
.80333 .35568 L
.79808 .34375 L
.79556 .33925 L
.79275 .33508 L
.79022 .33201 L
.78749 .3294 L
.78501 .32759 L
.78225 .3262 L
.77972 .32546 L
.77736 .32522 L
.7759 .32528 L
.77434 .32552 L
.77156 .32639 L
.77002 .32711 L
.76858 .32793 L
.76534 .33031 L
.76004 .33577 L
.75456 .34348 L
.74506 .36203 L
.7375 .38203 L
.72481 .42945 L
.71769 .46715 L
.71679 .47219 L
.71595 .4763 L
.71561 .4777 L
.71527 .47883 L
.71499 .47952 L
.71469 .47997 L
.71451 .48009 L
.71435 .48011 L
.71417 .48 L
.71399 .47979 L
.71366 .47913 L
.71348 .4786 L
Mistroke
.7133 .47801 L
.7126 .47508 L
.71174 .47063 L
.70661 .44249 L
.69817 .40518 L
.68249 .35532 L
.6716 .32905 L
.65819 .30243 L
.63142 .26109 L
.59655 .21983 L
.50994 .13539 L
.4606 .09049 L
.40995 .05085 L
.38286 .03522 L
.36888 .02942 L
.36086 .02695 L
.3533 .02526 L
.34558 .02423 L
.34169 .024 L
.33745 .02398 L
.32992 .02458 L
.32294 .02592 L
.31869 .02713 L
.31469 .02856 L
.30726 .03202 L
.29933 .03695 L
.29085 .04379 L
.27779 .05794 L
.264 .07859 L
.2504 .10612 L
.23861 .13749 L
.22871 .17101 L
.22026 .20674 L
.2118 .25221 L
.20536 .29709 L
.2026 .32082 L
.20001 .347 L
.19811 .37 L
.19638 .39546 L
.1949 .42383 L
.19429 .43932 L
.19385 .4537 L
.19335 .47933 L
.19323 .50636 L
.19335 .52101 L
.19358 .53434 L
.19395 .54875 L
.19448 .56373 L
.19568 .58813 L
.19743 .61373 L
Mistroke
.19936 .63522 L
.20178 .65685 L
.20437 .67562 L
.20703 .69165 L
.21322 .7204 L
.21682 .733 L
.22085 .74438 L
.22486 .75326 L
.22875 .75984 L
.23232 .76427 L
.23624 .76752 L
.23987 .76909 L
.24386 .76929 L
.24802 .76784 L
.25187 .76499 L
.25543 .76105 L
.25862 .75642 L
.26555 .74256 L
.26912 .73317 L
.27234 .72322 L
.27909 .69672 L
.28478 .66628 L
.28732 .64903 L
.28977 .62907 L
.29308 .59313 L
.29442 .57247 L
.29536 .55268 L
.29597 .53362 L
.29629 .51598 L
.29637 .49529 L
.29617 .4755 L
.29563 .45367 L
.29465 .42948 L
.29319 .40411 L
.29142 .38038 L
.2873 .33825 L
.28151 .29405 L
.273 .24471 L
.26331 .20143 L
.25338 .16657 L
.24141 .13406 L
.22905 .10952 L
.22177 .09893 L
.21825 .09479 L
.21494 .09148 L
.20885 .08685 L
.20211 .08396 L
.19552 .08344 L
.19183 .08418 L
.18848 .08551 L
Mistroke
.18218 .08979 L
.17643 .09583 L
.17024 .10479 L
.16385 .117 L
.15365 .14374 L
.1482 .16236 L
.14338 .18197 L
.13835 .2063 L
.13333 .23553 L
.12936 .2634 L
.12563 .29501 L
.12247 .32794 L
.1201 .35893 L
.11819 .39091 L
.11685 .42153 L
.11629 .43876 L
.11583 .4577 L
.11553 .47746 L
.11542 .49582 L
.1156 .52831 L
.11635 .56233 L
.11701 .58091 L
.11793 .60061 L
.12009 .63486 L
.12277 .66588 L
.12572 .69224 L
.12877 .71399 L
.1323 .7345 L
.13935 .76463 L
.14361 .7776 L
.14774 .78714 L
.15241 .79479 L
.15507 .79777 L
.15751 .79969 L
.16194 .80123 L
.16604 .8005 L
.17051 .79738 L
.17517 .79152 L
.17912 .78437 L
.18272 .77602 L
.19045 .75143 L
.19439 .73473 L
.19836 .71426 L
.20154 .69442 L
.20457 .67164 L
.20719 .64755 L
.20922 .6246 L
.2109 .60057 L
.21216 .57722 L
.2132 .54901 L
Mistroke
.21355 .53456 L
.21379 .51855 L
.21386 .4899 L
.2135 .46297 L
.21309 .44659 L
.21256 .43109 L
.21121 .4022 L
.20923 .37147 L
.20648 .33878 L
.20094 .28976 L
.19341 .24125 L
.18496 .2009 L
.17622 .16972 L
.1712 .15563 L
.16562 .14283 L
.1593 .13167 L
.15327 .12417 L
.14996 .12132 L
.14635 .11924 L
.14293 .11824 L
.13978 .11817 L
.13381 .12034 L
.12757 .12596 L
.12143 .13508 L
.11598 .14645 L
.10994 .16315 L
.1045 .18246 L
.09575 .22456 L
.09139 .25243 L
.08778 .28056 L
.08461 .31078 L
.08173 .34525 L
.08035 .36569 L
.07926 .38481 L
.07831 .40454 L
.0776 .42311 L
.07662 .46086 L
.07637 .48087 L
.07629 .50219 L
.07642 .5244 L
.07675 .54511 L
.0772 .56342 L
.07788 .58289 L
.07942 .61486 L
.08126 .64259 L
.08386 .67244 L
.08677 .69839 L
.09284 .73781 L
.09673 .75602 L
.10057 .77012 L
Mistroke
.10285 .7769 L
.10536 .7832 L
.11005 .79188 L
.11472 .7969 L
.11907 .79857 L
.12379 .79723 L
.12645 .79505 L
.12891 .7921 L
.13148 .78805 L
.13379 .78355 L
.13882 .7707 L
.14319 .75583 L
.14753 .73701 L
.1544 .69623 L
.15762 .67025 L
.16021 .64403 L
.16254 .61353 L
.1636 .59583 L
.16442 .579 L
.16544 .55003 L
.16579 .53445 L
.16602 .51766 L
.16611 .49987 L
.16603 .48301 L
.16549 .45143 L
.1645 .42197 L
.16319 .39515 L
.16131 .3663 L
.15884 .33668 L
.15612 .31035 L
.15271 .2831 L
.14538 .23829 L
.14147 .21969 L
.13703 .20194 L
.13264 .1874 L
.12843 .17595 L
.1229 .16423 L
.11992 .1594 L
.11673 .15534 L
.1113 .15099 L
.10819 .14994 L
.10529 .14991 L
.09988 .15235 L
.09501 .15744 L
.08951 .16673 L
.08446 .17886 L
.08025 .19202 L
.07582 .20925 L
.07177 .22866 L
.06775 .25227 L
Mistroke
.06434 .27664 L
.06155 .30073 L
.05703 .35218 L
.05501 .38478 L
.05358 .41602 L
.05253 .45095 L
.05203 .48849 L
.05213 .52401 L
.05274 .55684 L
.0537 .58545 L
.05517 .61517 L
.05722 .64539 L
.0595 .67101 L
.06256 .69795 L
.06585 .72059 L
.06896 .73764 L
.07249 .75314 L
.0766 .7669 L
.08057 .77654 L
.08496 .78351 L
.08746 .7859 L
.08977 .78713 L
.09404 .78702 L
.09852 .78362 L
.10086 .78049 L
.10334 .77614 L
.10768 .7658 L
.1126 .74953 L
.11677 .73126 L
.12046 .71082 L
.12397 .68642 L
.12665 .66333 L
.12911 .63671 L
.13126 .60642 L
.13277 .57675 L
.13345 .55818 L
.13392 .54027 L
.1342 .52403 L
.13434 .50619 L
.13432 .48929 L
.13416 .47336 L
.13352 .44369 L
.13231 .41214 L
.1314 .39468 L
.13042 .37889 L
.12591 .32597 L
.12305 .30132 L
.1195 .27619 L
.11165 .235 L
.10669 .21617 L
Mistroke
.10182 .20198 L
.0974 .19232 L
.09239 .18477 L
.08706 .18052 L
.08201 .18005 L
.07739 .18267 L
.07259 .18865 L
.06858 .19634 L
.06434 .20747 L
.05995 .2226 L
.05554 .24219 L
.04853 .28564 L
.04496 .31648 L
.04218 .3474 L
.03974 .38356 L
.03876 .40248 L
.03789 .42368 L
.0373 .44254 L
.03691 .4599 L
.03663 .48001 L
.03653 .49908 L
.03678 .53265 L
.03715 .55132 L
.03765 .56833 L
.03906 .60165 L
.04088 .63125 L
.04289 .65608 L
.04545 .68073 L
.04864 .70483 L
.05242 .72665 L
.05592 .74214 L
.05999 .75564 L
.06434 .76556 L
.06849 .7712 L
.07068 .7728 L
.0731 .77349 L
.07563 .77303 L
.078 .77153 L
.08228 .7661 L
.08611 .75823 L
.09035 .74586 L
.09417 .73103 L
.09735 .71552 L
.10048 .69678 L
.10534 .65804 L
.10776 .63162 L
.10963 .60523 L
.11094 .58052 L
.11196 .55298 L
.11259 .52238 L
Mistroke
.11271 .49349 L
.11258 .47689 L
.11233 .46179 L
.11189 .44446 L
.11133 .4282 L
.10977 .39642 L
.10784 .36811 L
.10519 .33863 L
.10183 .3096 L
.0988 .28872 L
.0952 .26844 L
.09185 .25297 L
.08794 .23844 L
.08338 .22547 L
.0808 .21988 L
.07836 .21565 L
.07392 .21048 L
.0691 .20852 L
.06454 .21013 L
.06197 .21256 L
.05959 .21584 L
.05489 .22538 L
.05233 .23242 L
.05006 .2399 L
.04619 .2556 L
.04227 .27603 L
.03892 .29812 L
.03611 .32124 L
.03308 .35325 L
.03086 .38447 L
.02992 .40152 L
.02909 .4199 L
.02837 .44043 L
.0279 .45952 L
.02751 .49385 L
.02766 .52571 L
.02798 .54377 L
.0284 .55997 L
.02905 .57829 L
.02983 .59518 L
.03143 .62189 L
.03363 .64933 L
.03639 .67535 L
.03936 .69695 L
.04241 .71442 L
.04542 .728 L
.04891 .74013 L
.05275 .74963 L
.0568 .75584 L
.0591 .75777 L
Mistroke
.06119 .75856 L
.06528 .75753 L
.06909 .7535 L
.07122 .74992 L
.07344 .74516 L
.07729 .7342 L
.08121 .71911 L
.08517 .69894 L
.0883 .67859 L
.09087 .65772 L
.09332 .63287 L
.09544 .60459 L
.09686 .57891 L
.09782 .55401 L
.09846 .52612 L
.09863 .51028 L
.09865 .4957 L
.09841 .47051 L
.09786 .44727 L
.09691 .42223 L
.0955 .39624 L
.09359 .37012 L
.09141 .34682 L
.0864 .30774 L
.08331 .28985 L
.07962 .27278 L
.07548 .25816 L
.0714 .24767 L
.06746 .24084 L
.06378 .23722 L
.05949 .23623 L
.05543 .23853 L
.05113 .24454 L
.04878 .24949 L
.04669 .25494 L
.04278 .26817 L
.03931 .28364 L
.03559 .30523 L
.03254 .32811 L
.02965 .35616 L
.02719 .38856 L
.02567 .41631 L
.02501 .43247 L
.02452 .44764 L
.02395 .47587 L
.02381 .50602 L
.02408 .53274 L
.02468 .55735 L
.02571 .58354 L
.02723 .61044 L
Mistroke
.02916 .6357 L
.03171 .66094 L
.03481 .68422 L
.03804 .70273 L
.04133 .71715 L
.0445 .72762 L
.04831 .73648 L
.05202 .74164 L
.0553 .74357 L
.05891 .74299 L
.06264 .73942 L
.06607 .73342 L
.06917 .72559 L
.07191 .71665 L
.07759 .69081 L
.08041 .67334 L
.08276 .65544 L
.08522 .63226 L
.08708 .6098 L
.08854 .58723 L
.0896 .56526 L
.09038 .5415 L
.09083 .51544 L
.09086 .48916 L
.09054 .46539 L
.08973 .43843 L
.08856 .4137 L
.08714 .39175 L
.08556 .37244 L
.08105 .33308 L
.07827 .31544 L
.07541 .30093 L
.07206 .28747 L
.06823 .2761 L
.06625 .27169 L
.06405 .26788 L
.06194 .26527 L
.05996 .26371 L
.05622 .2631 L
.05412 .2641 L
.05224 .26585 L
.04835 .27206 L
.04644 .27649 L
.0444 .28234 L
.04092 .29517 L
.03789 .30988 L
.03463 .33039 L
.032 .3518 L
.02943 .37929 L
.0275 .40761 L
Mistroke
.02626 .43356 L
.02538 .46211 L
.02502 .48693 L
.02503 .51444 L
.02552 .54356 L
.02601 .55961 L
.02659 .57405 L
.02798 .59969 L
.02988 .62502 L
.03201 .6467 L
.03468 .66782 L
.03752 .6852 L
.04037 .69883 L
.04309 .70905 L
.04623 .71791 L
.04963 .72444 L
.05288 .72801 L
.05671 .72906 L
.06034 .727 L
.06356 .72269 L
.06697 .71543 L
.06885 .71016 L
.07052 .7047 L
.07407 .69024 L
.07711 .67428 L
.07971 .65725 L
.08369 .62208 L
.0853 .60269 L
.08674 .58043 L
.08769 .56076 L
.08841 .53924 L
.0888 .51869 L
.08892 .49991 L
.08873 .47647 L
.08824 .45513 L
.08736 .43233 L
.08603 .40911 L
.08457 .39004 L
.08297 .3732 L
.0785 .33947 L
.07599 .32579 L
.0731 .31336 L
.0702 .30386 L
.06746 .29721 L
.06414 .29191 L
.06223 .29015 L
.06047 .28935 L
.05722 .2899 L
.05381 .29338 L
.05062 .29949 L
Mistroke
.04733 .30901 L
.04439 .32072 L
.04189 .3336 L
.03921 .35114 L
.03666 .37299 L
.03464 .3959 L
.03314 .41875 L
.03219 .43871 L
.03146 .46097 L
.03107 .48243 L
.03097 .50231 L
.03116 .5243 L
.03171 .54808 L
.03267 .57223 L
.0339 .59381 L
.03556 .61552 L
.03742 .63457 L
.04163 .66565 L
.04434 .68007 L
.04702 .6913 L
.05013 .70121 L
.05358 .70886 L
.05682 .71321 L
.06041 .7151 L
.0638 .71417 L
.06692 .711 L
.06995 .70574 L
.07262 .69922 L
.07558 .68974 L
.07822 .67901 L
.08092 .66543 L
.08352 .64919 L
.08747 .61601 L
.08921 .59571 L
.09054 .57588 L
.09163 .5534 L
.09207 .54058 L
.09237 .52881 L
.09265 .50909 L
.09263 .48823 L
.09236 .47067 L
.0918 .4517 L
.0909 .43207 L
.0896 .41195 L
.08807 .39415 L
.08643 .37905 L
.08292 .35493 L
.08066 .34352 L
.07842 .3345 L
.07593 .32675 L
Mistroke
.07358 .32139 L
.07079 .31727 L
.06811 .31547 L
.0654 .31575 L
.06252 .31839 L
.05985 .32311 L
.05748 .32929 L
.05484 .33869 L
.05215 .35151 L
.04984 .36592 L
.04791 .3811 L
.04604 .40013 L
.04458 .4196 L
.04355 .43816 L
.04274 .45908 L
.04245 .47028 L
.04224 .48271 L
.04214 .4958 L
.04216 .50805 L
.04246 .52995 L
.04315 .55305 L
.04415 .57415 L
.04537 .59286 L
.047 .61226 L
.04907 .63128 L
.0532 .65886 L
.05588 .67179 L
.05856 .68193 L
.06111 .68936 L
.06388 .69535 L
.06631 .69894 L
.069 .70127 L
.07193 .70192 L
.07506 .70049 L
.07797 .69718 L
.08056 .69259 L
.08345 .68553 L
.08603 .67732 L
.08894 .66564 L
.09141 .65334 L
.0958 .624 L
.0978 .60585 L
.09939 .58763 L
.10052 .57141 L
.10146 .55372 L
.10205 .53839 L
.10247 .52134 L
.10265 .50314 L
.10255 .48374 L
.10216 .46585 L
Mistroke
.10156 .44996 L
.10066 .43341 L
.09943 .41674 L
.09802 .40216 L
.09655 .39 L
.09461 .3772 L
.09229 .36531 L
.08991 .35617 L
.0876 .34965 L
.08512 .34493 L
.08275 .34242 L
.08011 .34186 L
.07864 .34255 L
.0773 .34382 L
.07592 .34578 L
.07465 .34819 L
.07318 .35176 L
.07188 .35567 L
.06957 .36454 L
.06729 .37622 L
.06549 .38816 L
.06398 .40064 L
.06254 .41568 L
.06126 .43315 L
.06074 .44238 L
.06026 .45271 L
.05963 .47214 L
.05933 .49162 L
.05934 .50991 L
.0596 .52696 L
.06006 .54285 L
.0608 .55997 L
.06187 .57788 L
.0632 .59489 L
.06487 .61175 L
.0685 .63862 L
.07091 .65185 L
.07329 .66229 L
.0762 .67235 L
.0791 .67981 L
.08188 .68489 L
.0845 .688 L
.08741 .68966 L
.0905 .68946 L
.0936 .68724 L
.09531 .68513 L
.09686 .68269 L
.0998 .67656 L
.10248 .66914 L
.10543 .65871 L
Mistroke
.10799 .64746 L
.11057 .63347 L
.11301 .61716 L
.11478 .60257 L
.11644 .58572 L
.11771 .56964 L
.11863 .55465 L
.11905 .54605 L
.11943 .53667 L
.11973 .52675 L
.11993 .51739 L
.12005 .50867 L
.12008 .49951 L
.11994 .48335 L
.11958 .46885 L
.11896 .45389 L
.11815 .4405 L
.11724 .42899 L
.11598 .41657 L
.11439 .4044 L
.11269 .39439 L
.11098 .38649 L
.10925 .38029 L
.10728 .37512 L
.10535 .37175 L
.10354 .36999 L
.1019 .36953 L
.10009 .37025 L
.09822 .37239 L
.09652 .37564 L
.09459 .38098 L
.09285 .38751 L
.09138 .39453 L
.0899 .40337 L
.08844 .41428 L
.0871 .42725 L
.08613 .43931 L
.08528 .45354 L
.08467 .4681 L
.08431 .48218 L
.08416 .49806 L
.08418 .50708 L
.08427 .51533 L
.08465 .53204 L
.08499 .54143 L
.08538 .55002 L
.08627 .56554 L
.08748 .58147 L
.09023 .60764 L
.09344 .62929 L
Mistroke
.09759 .64912 L
.10016 .65823 L
.10262 .66517 L
.10537 .67111 L
.10695 .67373 L
.1084 .67567 L
.11125 .67826 L
.11397 .67926 L
.11552 .67921 L
.11715 .67869 L
.12006 .67654 L
.12165 .6747 L
.12313 .67256 L
.1264 .66631 L
.12913 .65937 L
.1316 .6516 L
.13586 .63427 L
.13981 .61223 L
.14173 .59851 L
.14326 .58536 L
.14543 .56088 L
.14628 .54776 L
.14695 .53392 L
.14736 .5219 L
.14757 .51087 L
.14765 .499 L
.14753 .4867 L
.14738 .4799 L
.14719 .47379 L
.14693 .46727 L
.14658 .46061 L
.14587 .45 L
.14489 .4393 L
.14387 .4307 L
.14264 .42254 L
.14135 .41593 L
.1401 .41087 L
.13858 .40628 L
.13779 .40446 L
.1369 .40284 L
.1353 .40101 L
.13378 .40051 L
.13292 .40075 L
.13201 .40143 L
.1304 .40369 L
.12952 .40554 L
.12873 .40763 L
.12699 .41369 L
.12558 .4204 L
.12437 .42789 L
Mistroke
.12337 .43561 L
.12245 .44466 L
.12161 .45545 L
.121 .46616 L
.12054 .47838 L
.12037 .48561 L
.12027 .49252 L
.12025 .50518 L
.12033 .51238 L
.12046 .51897 L
.12086 .53188 L
.12142 .54406 L
.1223 .55818 L
.12332 .57091 L
.12477 .58531 L
.12636 .59815 L
.12951 .61808 L
.13359 .63693 L
.13809 .65172 L
.1408 .65831 L
.14336 .66321 L
.14577 .66676 L
.14838 .66951 L
.15063 .67104 L
.15314 .67185 L
.15583 .67172 L
.15734 .6712 L
.15872 .67044 L
.16124 .66837 L
.16385 .66528 L
.1661 .66182 L
.16843 .65742 L
.17246 .64774 L
.17689 .63367 L
.18049 .61891 L
.18374 .60216 L
.18673 .58252 L
.18915 .56132 L
.19006 .55109 L
.19078 .54145 L
.1913 .53272 L
.19173 .52337 L
.192 .5151 L
.19215 .50764 L
.1922 .49911 L
.19213 .49173 L
.19193 .48367 L
.19163 .47659 L
.19122 .46995 L
.19066 .46334 L
Mistroke
.18996 .45725 L
.18921 .45236 L
.18845 .4485 L
.1877 .44562 L
.1868 .44306 L
.18592 .44141 L
.18494 .44049 L
.18444 .44037 L
.18389 .4405 L
.18292 .44142 L
.18204 .44308 L
.18152 .44444 L
.18104 .44598 L
.18018 .44953 L
.17932 .45426 L
.17849 .46047 L
.17788 .46671 L
.17741 .47309 L
.17721 .47665 L
.17702 .48074 L
.17686 .48518 L
.17675 .48949 L
.17664 .49778 L
.17667 .50571 L
.17673 .51021 L
.17684 .51521 L
.17716 .52451 L
.17757 .53294 L
.17816 .54237 L
.17982 .56163 L
.18189 .57924 L
.18431 .59521 L
.1877 .61285 L
.19187 .62961 L
.19586 .64212 L
.20061 .65365 L
.20611 .66337 L
.20932 .66752 L
.2123 .67048 L
.21512 .67255 L
.21673 .67343 L
.21822 .67405 L
.22096 .67473 L
.22387 .67482 L
.22656 .67435 L
.22947 .67325 L
.2322 .67167 L
.23471 .66976 L
.23935 .66507 L
.24414 .65868 L
Mistroke
.25425 .63971 L
.26219 .6191 L
.27391 .57665 L
.28057 .54316 L
.2829 .5299 L
.28376 .52534 L
.28444 .52237 L
.28478 .52123 L
.28509 .52048 L
.2854 .52003 L
.28557 .51992 L
.28574 .51992 L
.28605 .5202 L
.28624 .52052 L
.28641 .52093 L
.28678 .52205 L
.2872 .52371 L
.29827 .58011 L
.31074 .62517 L
.3203 .65178 L
.33083 .67609 L
.35673 .72206 L
.39061 .76605 L
.46779 .84375 L
.51667 .88937 L
.54603 .91537 L
.57518 .93878 L
.60245 .9571 L
.61821 .96545 L
.63282 .97131 L
.63686 .97257 L
.64118 .97373 L
.64895 .97528 L
.65373 .97587 L
.65822 .97616 L
.66226 .97619 L
.66662 .97596 L
.67051 .97552 L
.67476 .97477 L
.6792 .97367 L
.68332 .97235 L
.69067 .96922 L
.69847 .96472 L
.70604 .95909 L
.71293 .95276 L
.72811 .93418 L
.74089 .91262 L
.75363 .88423 L
.76419 .854 L
.77323 .82164 L
Mistroke
.7821 .78192 L
.79027 .73483 L
.79702 .68293 L
.80005 .65266 L
.80232 .62468 L
.80402 .5982 L
.80541 .56943 L
.80628 .54231 L
.80671 .51756 L
.80677 .48905 L
.80639 .46303 L
.80599 .44843 L
.80551 .43536 L
.80405 .40694 L
.80217 .38111 L
.79962 .35484 L
.79677 .332 L
.79377 .3127 L
.79092 .29749 L
.78761 .28274 L
.78109 .26061 L
.77705 .25053 L
.77263 .24214 L
.76876 .23678 L
.76445 .23279 L
.76207 .23144 L
.75981 .23069 L
.75558 .23066 L
.75322 .23141 L
.75104 .23257 L
.74867 .23437 L
.74618 .23686 L
.74211 .24226 L
.7384 .24871 L
.73442 .25733 L
.73035 .26817 L
.72313 .29337 L
.71725 .32145 L
.7141 .34065 L
.71147 .35996 L
.70938 .37847 L
.7075 .39889 L
.70612 .41779 L
.70495 .43919 L
.70418 .45918 L
.70375 .47823 L
.70358 .50117 L
.70375 .52239 L
.70399 .53424 L
.70435 .54718 L
Mistroke
.70532 .57083 L
.70651 .59197 L
.7079 .61179 L
.71209 .65669 L
.7175 .69954 L
.72476 .74388 L
.73232 .78066 L
.74137 .81627 L
.74996 .84367 L
.76 .86937 L
.76643 .88268 L
.77254 .89322 L
.77841 .90148 L
.78497 .90862 L
.79096 .9132 L
.79659 .91584 L
.80257 .91682 L
.80899 .91572 L
.8159 .91194 L
.81977 .90857 L
.82332 .90464 L
.82973 .89542 L
.83636 .88271 L
.84722 .8537 L
.85298 .83328 L
.85807 .81164 L
.86634 .76677 L
.87357 .7126 L
.87839 .66192 L
.88053 .63185 L
.88212 .60324 L
.88348 .56946 L
.88428 .53736 L
.88459 .50863 L
.88449 .47781 L
.88388 .44494 L
.88267 .41125 L
.8812 .38371 L
.87914 .35494 L
.87652 .327 L
.8737 .30313 L
.8699 .27758 L
.86608 .2573 L
.86241 .24165 L
.85821 .22739 L
.85355 .21541 L
.84901 .20707 L
.84479 .20196 L
.8401 .19904 L
.83518 .19892 L
Mistroke
.83061 .20146 L
.82638 .20608 L
.82259 .21213 L
.81833 .22118 L
.81444 .23171 L
.8063 .2619 L
.80259 .28024 L
.79886 .30262 L
.79602 .32324 L
.79332 .34694 L
.79115 .37038 L
.78946 .39311 L
.7879 .42087 L
.78726 .43592 L
.78673 .45222 L
.78634 .46959 L
.78613 .48615 L
.78608 .50114 L
.78616 .51746 L
.7867 .5474 L
.78717 .5625 L
.78782 .57907 L
.78936 .60819 L
.79122 .63505 L
.79659 .69074 L
.80315 .73878 L
.81195 .78594 L
.81704 .80726 L
.82291 .82778 L
.82888 .84476 L
.8346 .85781 L
.84025 .86783 L
.84636 .87563 L
.85193 .88007 L
.85717 .88194 L
.86294 .88138 L
.86907 .87767 L
.87499 .87085 L
.88034 .86174 L
.88604 .84863 L
.89183 .83123 L
.90078 .79422 L
.90535 .7691 L
.90925 .74314 L
.91258 .71644 L
.91538 .68948 L
.91759 .66384 L
.91959 .63549 L
.92132 .60392 L
.92251 .57403 L
Mistroke
.92341 .5381 L
.92372 .5055 L
.92355 .47145 L
.92292 .4403 L
.92172 .40723 L
.91988 .37344 L
.91736 .34037 L
.91446 .31163 L
.91146 .28826 L
.90783 .26569 L
.90412 .24746 L
.9004 .233 L
.89633 .22077 L
.89164 .21069 L
.8875 .20493 L
.88365 .20201 L
.8794 .20137 L
.87493 .20355 L
.87006 .20925 L
.86574 .21733 L
.86092 .22991 L
.8566 .24479 L
.84961 .27784 L
.84612 .2998 L
.84324 .32191 L
.84068 .34592 L
.83835 .3733 L
.83722 .38963 L
.83633 .40491 L
.83561 .41968 L
.83497 .43567 L
.83447 .45241 L
.83413 .46811 L
.83391 .48695 L
.83387 .50413 L
.83397 .52048 L
.83424 .53817 L
.83515 .57011 L
.8365 .59988 L
.83813 .6265 L
.84049 .6564 L
.84317 .68363 L
.84896 .72876 L
.85659 .77171 L
.86108 .79111 L
.86636 .80973 L
.87219 .82575 L
.87495 .83183 L
.8779 .83734 L
.88337 .84494 L
Mistroke
.88847 .84906 L
.89401 .85033 L
.89714 .84956 L
.90004 .84786 L
.90584 .84153 L
.90904 .83625 L
.91195 .83029 L
.91714 .81662 L
.92236 .79844 L
.93057 .75834 L
.93466 .73114 L
.93805 .70318 L
.94138 .66846 L
.94395 .63341 L
.94573 .60061 L
.9471 .56392 L
.94757 .54478 L
.94789 .52356 L
.94801 .50143 L
.94793 .48077 L
.94731 .44451 L
.9467 .42462 L
.94598 .40677 L
.9442 .37438 L
.94206 .34569 L
.93978 .3218 L
.93694 .29813 L
.93348 .27529 L
.92943 .2547 L
.92571 .24023 L
.92141 .22773 L
.91724 .21942 L
.91334 .21463 L
.90878 .21244 L
.90444 .21362 L
.90049 .21745 L
.89688 .22329 L
.89302 .23213 L
.88907 .24421 L
.88467 .26174 L
.88092 .28078 L
.87719 .30458 L
.87375 .33262 L
.8712 .35911 L
.86923 .38532 L
.86755 .41542 L
.86683 .43279 L
.86631 .44887 L
.86574 .47908 L
.86564 .50735 L
Mistroke
.86601 .53846 L
.86639 .5541 L
.86695 .57126 L
.86825 .59951 L
.87011 .62918 L
.8723 .65616 L
.87467 .6798 L
.87781 .70552 L
.88113 .72802 L
.88823 .76469 L
.89262 .78169 L
.8969 .79485 L
.9018 .80632 L
.90433 .81086 L
.90715 .81485 L
.91194 .81913 L
.91636 .82032 L
.92145 .81841 L
.92623 .81328 L
.93054 .80569 L
.93443 .79623 L
.93854 .78321 L
.94268 .76642 L
.94723 .74284 L
.95101 .71791 L
.95466 .68731 L
.95789 .65189 L
.96013 .61892 L
.96172 .58686 L
.9624 .56804 L
.96288 .55072 L
.96326 .53061 L
.96345 .51155 L
.96337 .47896 L
.96276 .44501 L
.96181 .4169 L
.96033 .3872 L
.95826 .35727 L
.95551 .32771 L
.95247 .30274 L
.94934 .28265 L
.94563 .26413 L
.94189 .24993 L
.93836 .23998 L
.93441 .23226 L
.92999 .22748 L
.92774 .22651 L
.92527 .22655 L
.92091 .2294 L
.91691 .23518 L
Mistroke
.91299 .24393 L
.90941 .2548 L
.90319 .28141 L
.90006 .29951 L
.89741 .31808 L
.89483 .3401 L
.89243 .36566 L
.89046 .39291 L
.88905 .41904 L
.88808 .44481 L
.88745 .47252 L
.88725 .50335 L
.88753 .53211 L
.88788 .54855 L
.88833 .56339 L
.889 .58033 L
.88978 .5961 L
.8916 .62482 L
.89403 .65381 L
.89959 .70092 L
.90328 .72376 L
.90708 .74259 L
.91156 .76009 L
.91417 .76825 L
.9167 .77488 L
.91896 .77981 L
.92145 .78421 L
.92586 .78948 L
.92839 .79107 L
.93108 .79162 L
.93587 .78968 L
.94027 .78451 L
.94427 .77676 L
.94851 .76506 L
.95282 .74892 L
.95714 .72754 L
.96134 .7 L
.96478 .67033 L
.96745 .64021 L
.9694 .61132 L
.97101 .57795 L
.9716 .56075 L
.97208 .54201 L
.97249 .50786 L
.97235 .47504 L
.97176 .44508 L
.97059 .41329 L
.96972 .39616 L
.96879 .38112 L
.96653 .35237 L
Mistroke
.96357 .32422 L
.96032 .30092 L
.957 .28259 L
.95372 .26857 L
.95048 .25802 L
.94678 .24937 L
.9427 .24354 L
.94062 .24197 L
.93835 .24128 L
.93422 .24272 L
.93025 .24739 L
.92665 .25449 L
.9227 .26571 L
.91876 .28089 L
.91562 .29638 L
.91247 .31577 L
.90944 .33921 L
.90668 .3668 L
.90457 .39479 L
.90309 .42155 L
.90204 .4495 L
.90148 .47585 L
.90133 .50505 L
.90143 .51979 L
.90168 .53596 L
.90244 .56271 L
.90371 .59079 L
.90532 .61633 L
.90714 .63862 L
.90932 .66013 L
.91197 .68141 L
.91752 .71458 L
.92134 .73118 L
.92518 .74395 L
.92878 .75285 L
.93279 .75963 L
.93644 .76305 L
.94047 .7639 L
.94467 .76149 L
.94854 .75618 L
.95207 .74854 L
.95518 .73937 L
.9586 .72625 L
.96165 .71143 L
.96459 .69369 L
.96745 .67213 L
.96963 .65166 L
.97169 .62757 L
.97355 .59913 L
.97436 .58301 L
Mistroke
.97499 .5677 L
.97579 .53971 L
.97618 .50939 L
.97619 .49265 L
.97607 .47729 L
.97579 .46058 L
.97534 .44314 L
.97421 .41468 L
.97338 .39909 L
.97247 .38499 L
.97051 .36058 L
.96832 .33928 L
.96543 .31731 L
.96249 .2999 L
.95943 .28575 L
.95649 .27524 L
.95294 .26593 L
.94949 .25999 L
.94622 .25694 L
.9432 .25623 L
.93989 .25773 L
.93643 .26184 L
.933 .26855 L
.92947 .27846 L
.92629 .29024 L
.92356 .30288 L
.92059 .31986 L
.91768 .34066 L
.91527 .36236 L
.91339 .38368 L
.91186 .40561 L
.9106 .4296 L
.90971 .45438 L
.90917 .48194 L
.90909 .50602 L
.90938 .5316 L
.91002 .55537 L
.91089 .57644 L
.91241 .60243 L
.9142 .62512 L
.91655 .64833 L
.91945 .67061 L
.92208 .68671 L
.92516 .7018 L
.92878 .71553 L
.93236 .72546 L
.93433 .72956 L
.93646 .73297 L
.94034 .73658 L
.94251 .73715 L
Mistroke
.94455 .73676 L
.94678 .73527 L
.94916 .73244 L
.95106 .72921 L
.95311 .72472 L
.9571 .7127 L
.96057 .69815 L
.96355 .68182 L
.96641 .66187 L
.96879 .64074 L
.97063 .62011 L
.97228 .59623 L
.97365 .56881 L
.97417 .55456 L
.9746 .53863 L
.975 .51011 L
.97495 .48333 L
.97447 .45588 L
.97401 .44083 L
.97348 .42743 L
.97215 .40222 L
.97054 .37981 L
.96825 .35558 L
.9658 .33553 L
.96276 .31627 L
.95922 .29938 L
.95613 .28843 L
.95267 .27958 L
.94929 .27402 L
.94616 .27133 L
.94246 .27106 L
.94037 .27227 L
.93845 .27424 L
.935 .27994 L
.93145 .28882 L
.92845 .29896 L
.92585 .31 L
.92322 .32364 L
.92059 .34043 L
.91679 .37262 L
.91509 .39186 L
.91377 .4106 L
.91251 .43398 L
.91168 .45665 L
.91123 .47729 L
.91106 .49978 L
.91125 .52416 L
.9115 .53631 L
.91188 .54951 L
.91285 .57227 L
Mistroke
.91407 .5927 L
.91571 .61354 L
.91782 .63411 L
.9199 .65033 L
.92241 .66604 L
.92566 .68186 L
.92897 .69383 L
.9306 .69845 L
.93236 .70256 L
.93559 .70789 L
.93873 .7105 L
.94211 .71054 L
.94529 .70794 L
.94812 .70335 L
.95136 .6953 L
.95311 .68951 L
.95469 .68338 L
.95741 .67038 L
.9601 .65387 L
.96224 .63725 L
.96397 .62057 L
.9655 .60232 L
.96668 .58439 L
.96776 .56264 L
.96857 .538 L
.96895 .51579 L
.96901 .4919 L
.96869 .46709 L
.96833 .45329 L
.9679 .44077 L
.96684 .41836 L
.96537 .39579 L
.96375 .37679 L
.962 .36029 L
.95987 .34399 L
.95727 .32802 L
.9544 .31427 L
.95114 .30241 L
.94795 .29409 L
.94486 .28866 L
.94306 .28661 L
.94116 .28528 L
.93773 .285 L
.93582 .286 L
.93406 .28767 L
.93215 .29029 L
.93013 .29399 L
.92684 .30221 L
.92345 .31381 L
.92046 .32714 L
Mistroke
.91791 .34129 L
.91373 .37228 L
.91198 .38965 L
.91036 .40982 L
.9091 .43031 L
.90821 .45031 L
.90766 .46855 L
.90735 .48857 L
.90734 .51019 L
.90748 .52215 L
.9077 .53286 L
.90838 .5533 L
.9093 .57183 L
.91041 .58852 L
.91184 .60513 L
.91496 .63179 L
.91698 .64466 L
.91903 .65522 L
.92143 .6651 L
.92414 .67357 L
.92689 .67958 L
.92849 .68199 L
.93 .68358 L
.93308 .68477 L
.93482 .68423 L
.93639 .68299 L
.93902 .67925 L
.94181 .67283 L
.9446 .66361 L
.94704 .65282 L
.94971 .63729 L
.95194 .62023 L
.95368 .60314 L
.95525 .583 L
.95657 .55944 L
.95706 .54707 L
.95747 .53318 L
.9577 .52115 L
.95784 .50811 L
.95786 .49573 L
.95778 .48441 L
.95736 .46229 L
.95701 .45125 L
.95653 .43922 L
.95542 .41858 L
.95409 .40006 L
.95219 .37974 L
.95016 .36264 L
.94763 .34583 L
.94468 .33059 L
Mistroke
.94208 .3202 L
.93914 .31122 L
.93625 .30484 L
.93356 .30084 L
.93034 .29834 L
.92851 .29798 L
.92682 .29832 L
.92373 .30057 L
.92052 .30522 L
.91758 .31161 L
.9145 .32072 L
.91175 .33121 L
.90935 .34246 L
.90533 .36718 L
.90339 .3827 L
.90185 .39763 L
.90039 .4149 L
.89915 .43382 L
.89863 .44392 L
.89816 .45512 L
.89758 .47498 L
.89734 .49373 L
.8974 .51362 L
.89776 .53198 L
.89834 .5482 L
.89914 .56382 L
.90024 .57955 L
.90137 .59215 L
.90279 .60506 L
.90451 .61758 L
.90657 .62943 L
.90869 .63891 L
.91074 .64603 L
.91277 .65133 L
.91472 .65495 L
.9169 .65742 L
.91925 .65831 L
.92172 .65725 L
.92403 .65439 L
.92605 .65028 L
.92817 .64423 L
.93036 .63579 L
.93224 .62647 L
.93423 .61393 L
.93592 .60039 L
.93718 .58761 L
.93834 .57297 L
.93935 .55587 L
.94005 .53922 L
.94035 .52869 L
Mistroke
.94055 .51886 L
.94067 .50794 L
.94069 .49632 L
.94047 .47668 L
.94021 .46558 L
.93987 .45531 L
.93901 .43642 L
.93797 .41977 L
.93647 .40143 L
.93478 .38516 L
.93058 .35595 L
.92812 .34362 L
.9252 .33212 L
.92257 .32416 L
.91961 .31756 L
.91674 .31323 L
.91406 .31089 L
.91251 .31026 L
.91087 .31014 L
.9079 .31137 L
.90611 .31301 L
.90443 .31516 L
.90135 .32071 L
.89822 .32865 L
.89547 .3377 L
.8925 .35011 L
.88991 .36357 L
.88796 .37578 L
.88605 .39004 L
.8833 .41695 L
.88209 .43297 L
.88109 .45038 L
.88048 .46542 L
.88005 .48204 L
.8799 .49728 L
.87996 .51104 L
.88023 .52577 L
.88076 .54072 L
.88141 .55317 L
.88217 .56418 L
.88316 .57553 L
.88438 .58672 L
.88602 .59841 L
.8877 .60776 L
.88971 .6163 L
.89078 .61993 L
.89198 .62325 L
.89404 .62746 L
.89602 .6298 L
.89724 .63045 L
Mistroke
.8984 .63052 L
.90058 .62922 L
.9025 .62645 L
.90449 .62185 L
.90629 .61599 L
.90784 .60945 L
.90953 .60031 L
.91119 .58879 L
.91255 .5765 L
.91362 .56411 L
.91454 .54998 L
.91519 .53581 L
.91559 .52255 L
.91581 .50771 L
.91581 .49125 L
.9157 .48286 L
.91551 .47359 L
.91496 .45729 L
.91421 .4422 L
.91329 .42822 L
.91211 .41398 L
.9095 .39022 L
.90602 .3677 L
.90378 .35664 L
.90155 .34756 L
.89897 .33909 L
.89603 .33167 L
.89464 .32889 L
.89315 .32638 L
.89043 .32303 L
.88778 .32118 L
.88528 .32065 L
.88254 .32141 L
.87963 .32372 L
.87805 .32564 L
.87659 .32782 L
.87338 .33411 L
.87066 .34114 L
.86791 .35003 L
.86314 .37053 L
.85949 .39234 L
.85663 .41553 L
.85532 .42931 L
.85431 .44241 L
.85347 .45638 L
.85291 .46911 L
.85268 .47611 L
.8525 .48366 L
.85234 .49716 L
.85238 .5084 L
Mistroke
.8526 .52036 L
.85303 .53229 L
.8536 .54284 L
.85428 .55207 L
.855 .55993 L
.85699 .57537 L
.85828 .58247 L
.85977 .58877 L
.86126 .59343 L
.86268 .59655 L
.86357 .59793 L
.86439 .59883 L
.86531 .59941 L
.86628 .59956 L
.8679 .59872 L
.86882 .59765 L
.86966 .59625 L
.87124 .5925 L
.87267 .5877 L
.87389 .58238 L
.87511 .57557 L
.87631 .56703 L
.87742 .55674 L
.87822 .54706 L
.87858 .54159 L
.87891 .53554 L
.87938 .5243 L
.87965 .51335 L
.87973 .50647 L
.87976 .49986 L
.87966 .48727 L
.87934 .47377 L
.87885 .46125 L
.87809 .44757 L
.87704 .43331 L
.87478 .41081 L
.8721 .39133 L
.86858 .37231 L
.86422 .3552 L
.86159 .34742 L
.85905 .34133 L
.85615 .33595 L
.85463 .33373 L
.85297 .33174 L
.85136 .33024 L
.84987 .3292 L
.84844 .32851 L
.84693 .32812 L
.8443 .32821 L
.84142 .32942 L
Mistroke
.83861 .33172 L
.8361 .33474 L
.83326 .33925 L
.83065 .34447 L
.82625 .35586 L
.8219 .37084 L
.81829 .38684 L
.81496 .40564 L
.81238 .42433 L
.81053 .44182 L
.80904 .46114 L
.80845 .47186 L
.80808 .48157 L
.80794 .48674 L
.80784 .49153 L
.80778 .5002 L
.80786 .50907 L
.80797 .51384 L
.80811 .51807 L
.80844 .52516 L
.80892 .53214 L
.80947 .53808 L
.81004 .54294 L
.8108 .54789 L
.81172 .55234 L
.81216 .55404 L
.81265 .5556 L
.81355 .55779 L
.8145 .55917 L
.81504 .55957 L
.81554 .5597 L
.81645 .55933 L
.81741 .5581 L
.8179 .5571 L
.81842 .55576 L
.81933 .55267 L
.82032 .5479 L
.82113 .54255 L
.82174 .53735 L
.82223 .53193 L
.82268 .52542 L
.82304 .5178 L
.82317 .51377 L
.82327 .50923 L
.82336 .50057 L
.82329 .49173 L
.82311 .48323 L
.82278 .47432 L
.82235 .46576 L
.82121 .44953 L
Mistroke
.81949 .43201 L
.81707 .41349 L
.81402 .39557 L
.81004 .37753 L
.80525 .36106 L
.80028 .34825 L
.79526 .33871 L
.79046 .33221 L
.78773 .32952 L
.78628 .32836 L
.78472 .32733 L
.78185 .32595 L
.77918 .32526 L
.77665 .32511 L
.77388 .3255 L
.771 .32649 L
.76835 .32793 L
.76587 .32971 L
.76365 .33168 L
.75877 .33719 L
.75372 .34465 L
.74854 .35422 L
.74006 .37442 L
.73328 .39524 L
.72746 .41735 L
.72026 .45206 L
.71777 .46624 L
.71608 .47535 L
.71571 .477 L
.71534 .47838 L
.71513 .47899 L
.71495 .47943 L
.71478 .47977 L
.71461 .47999 L
.7143 .48013 L
.71402 .47996 L
.7137 .47944 L
.71336 .47852 L
.71304 .47739 L
.71273 .4761 L
.71197 .47233 L
.71024 .46267 L
.7038 .42921 L
.69204 .3837 L
.67582 .33879 L
.6521 .29195 L
.62071 .24735 L
.54864 .1719 L
.46329 .09268 L
.43691 .07054 L
Mistroke
.40657 .04847 L
.39222 .03986 L
.37665 .03226 L
.369 .0293 L
.36175 .02703 L
.35521 .02546 L
.34811 .02432 L
.34112 .02381 L
.33458 .02394 L
.32742 .0248 L
.31976 .02662 L
.31593 .02791 L
.31178 .02961 L
.30426 .03355 L
.29702 .03847 L
.29038 .04403 L
.27868 .05664 L
.2662 .07466 L
.25378 .0983 L
.24283 .12511 L
.23177 .15958 L
.2225 .19625 L
.21361 .24112 L
.20575 .29364 L
.20248 .32154 L
.19948 .35261 L
.19731 .3805 L
.1955 .41035 L
.19432 .43733 L
.19384 .45263 L
.19351 .4669 L
.19321 .49173 L
.19328 .51798 L
.19377 .54372 L
.19457 .56689 L
.19583 .59139 L
.19759 .61623 L
.19966 .63858 L
.20192 .65828 L
.20691 .69126 L
.21268 .71852 L
.21861 .73859 L
.2219 .74712 L
.22563 .7549 L
.22963 .76126 L
.23344 .76556 L
.23774 .76851 L
.23992 .76928 L
.24233 .76958 L
.24659 .76871 L
Mistroke
.25056 .7663 L
.25281 .76425 L
.25516 .76157 L
.25929 .7555 L
.26361 .74719 L
.26815 .73609 L
.27526 .71303 L
.28195 .68289 L
.28725 .64989 L
.29111 .61664 L
.2927 .59862 L
.29408 .57888 L
.29502 .56153 L
.29578 .54199 L
.29627 .52049 L
.2964 .50824 L
.29642 .49696 L
.2962 .4748 L
.29567 .45354 L
.29489 .43365 L
.29376 .41241 L
.29094 .37421 L
.28629 .32924 L
.28088 .28956 L
.27402 .24967 L
.26519 .20877 L
.25461 .17025 L
.24366 .13927 L
.23257 .11545 L
.22193 .09894 L
.21587 .09217 L
.20919 .08688 L
.20283 .08397 L
.19692 .08318 L
.19058 .08442 L
.1838 .08828 L
.17748 .09439 L
.17179 .10211 L
.1653 .11375 L
.15847 .12968 L
.14689 .16717 L
.14113 .19208 L
.13632 .21718 L
.13161 .24668 L
.12713 .28115 L
.12358 .31521 L
.12084 .34797 L
.11874 .38025 L
.11706 .41506 L
.116 .44837 L
Mistroke
.11563 .46723 L
.11544 .48462 L
.11544 .51626 L
.11596 .54923 L
.11686 .57781 L
.11806 .60373 L
.11977 .63094 L
.12203 .65859 L
.12472 .68433 L
.12811 .70995 L
.13209 .73363 L
.13614 .75266 L
.14014 .76752 L
.14411 .77911 L
.14887 .78948 L
.15333 .79611 L
.15734 .79976 L
.16179 .8014 L
.16645 .8005 L
.17078 .79729 L
.17477 .79231 L
.17834 .78612 L
.18236 .77713 L
.18604 .76684 L
.19367 .73826 L
.19987 .70548 L
.20554 .66362 L
.20813 .63798 L
.21008 .61357 L
.21163 .58847 L
.21273 .56436 L
.21352 .53726 L
.2139 .5077 L
.2139 .49268 L
.21376 .47628 L
.21312 .44638 L
.21201 .41732 L
.21057 .39067 L
.20696 .34356 L
.20435 .31762 L
.20154 .29404 L
.19488 .24934 L
.18633 .20649 L
.17626 .16966 L
.17007 .15263 L
.16407 .13959 L
.16071 .13368 L
.15749 .12893 L
.15138 .12226 L
.14791 .11983 L
Mistroke
.1447 .11846 L
.14117 .11793 L
.13743 .11849 L
.13171 .12166 L
.12565 .12823 L
.12005 .13746 L
.11508 .14846 L
.10948 .16442 L
.10371 .18547 L
.0986 .20883 L
.09429 .233 L
.08715 .2858 L
.08406 .31647 L
.08133 .35052 L
.07941 .38138 L
.07803 .41081 L
.07696 .44359 L
.07636 .47883 L
.07626 .49875 L
.07632 .51702 L
.07656 .53687 L
.07701 .55758 L
.0782 .59142 L
.07912 .60998 L
.08013 .62685 L
.08237 .65669 L
.08482 .68201 L
.08808 .70862 L
.09157 .73103 L
.09563 .75154 L
.09959 .76705 L
.10188 .77435 L
.10442 .78118 L
.10917 .79071 L
.11374 .79631 L
.11864 .7987 L
.12283 .79794 L
.1274 .79419 L
.13013 .79047 L
.13269 .78598 L
.13734 .77509 L
.14213 .75997 L
.14699 .7398 L
.15088 .71932 L
.15462 .69493 L
.15745 .67206 L
.16013 .64527 L
.16221 .61888 L
.16376 .5933 L
.16499 .56538 L
Mistroke
.16581 .53479 L
.16612 .50576 L
.16601 .47814 L
.16556 .45329 L
.16471 .42649 L
.16335 .39744 L
.16133 .36617 L
.15867 .33457 L
.15569 .30629 L
.14922 .25968 L
.14505 .23638 L
.14084 .21679 L
.1319 .18502 L
.12683 .17199 L
.12123 .16124 L
.11575 .15415 L
.11051 .15046 L
.10578 .14968 L
.10067 .15162 L
.09602 .15598 L
.09101 .16363 L
.08592 .17481 L
.08135 .18811 L
.07372 .21865 L
.06982 .23932 L
.06654 .26018 L
.06028 .31294 L
.05745 .34615 L
.0553 .37889 L
.05361 .41455 L
.05258 .4479 L
.05223 .46643 L
.05201 .48669 L
.0521 .52335 L
.05271 .55692 L
.05372 .58646 L
.05537 .61907 L
.0574 .64798 L
.05966 .67293 L
.06204 .69409 L
.06833 .7347 L
.07205 .7516 L
.0763 .76621 L
.0805 .77657 L
.08445 .78305 L
.08917 .78706 L
.09186 .78762 L
.09434 .78706 L
.09887 .78337 L
.10113 .78023 L
Mistroke
.10359 .7758 L
.10834 .76409 L
.11249 .75013 L
.11676 .73151 L
.12086 .70852 L
.12671 .66297 L
.12936 .634 L
.13135 .60541 L
.13282 .57621 L
.13338 .56113 L
.13385 .54431 L
.13432 .51416 L
.13432 .48567 L
.13411 .46844 L
.13377 .45213 L
.13276 .42177 L
.13199 .40505 L
.13114 .38975 L
.12874 .35602 L
.12613 .32776 L
.12325 .30263 L
.11688 .2604 L
.1128 .23989 L
.10878 .22334 L
.10409 .20794 L
.0989 .1951 L
.09434 .18713 L
.09011 .18232 L
.08516 .17979 L
.08046 .18044 L
.07615 .18373 L
.07222 .18909 L
.068 .19751 L
.06367 .20934 L
.05953 .22407 L
.05534 .24305 L
.0486 .28493 L
.04528 .31314 L
.04231 .34543 L
.04024 .37475 L
.03848 .4082 L
.0378 .42553 L
.03724 .44406 L
.03663 .47758 L
.03656 .51362 L
.03678 .53388 L
.03716 .55256 L
.03827 .58544 L
.03973 .61412 L
.04192 .64519 L
Mistroke
.04447 .67224 L
.04709 .69414 L
.05021 .71483 L
.05314 .73037 L
.05652 .74459 L
.06032 .75673 L
.06405 .76518 L
.06625 .76875 L
.0686 .77146 L
.07285 .77362 L
.0774 .77215 L
.0815 .76751 L
.08373 .76363 L
.08611 .75839 L
.09029 .74625 L
.09399 .73198 L
.09766 .71403 L
.10341 .67538 L
.1061 .65063 L
.10853 .62197 L
.11033 .59333 L
.11155 .56609 L
.11209 .54922 L
.11244 .53337 L
.11268 .51584 L
.11274 .49706 L
.11263 .47912 L
.11236 .46228 L
.11199 .44723 L
.11146 .4311 L
.11015 .40264 L
.10856 .37748 L
.10629 .34968 L
.10373 .32485 L
.09826 .28521 L
.09471 .2658 L
.09117 .25005 L
.08739 .23649 L
.08311 .22469 L
.08058 .21931 L
.07823 .21529 L
.07352 .21004 L
.06889 .20838 L
.06627 .20898 L
.06383 .21055 L
.06127 .21328 L
.05897 .21671 L
.05636 .2218 L
.05394 .2277 L
.04982 .24061 L
Mistroke
.04555 .25842 L
.04145 .28081 L
.038 .30499 L
.03521 .32962 L
.03292 .35488 L
.03076 .3859 L
.02924 .41562 L
.02811 .44933 L
.02772 .46844 L
.02753 .48581 L
.02758 .51958 L
.02812 .55084 L
.02865 .56825 L
.02937 .58621 L
.03108 .61699 L
.03346 .64772 L
.03668 .67793 L
.03984 .70018 L
.04306 .7178 L
.04688 .73368 L
.04893 .74033 L
.05119 .74636 L
.05508 .75379 L
.05881 .75772 L
.06099 .75866 L
.06328 .75859 L
.06737 .75583 L
.07097 .75054 L
.0747 .74209 L
.07809 .73159 L
.08103 .72006 L
.08427 .70419 L
.08749 .68448 L
.09242 .64292 L
.09459 .61731 L
.09621 .59205 L
.09695 .57738 L
.09753 .56322 L
.09806 .54666 L
.0984 .53138 L
.0986 .51621 L
.09868 .50003 L
.09844 .47098 L
.0981 .45499 L
.09765 .44011 L
.09702 .42399 L
.09616 .40694 L
.09452 .38166 L
.09229 .35542 L
.08951 .32998 L
Mistroke
.08653 .30841 L
.08037 .27579 L
.07655 .26137 L
.07288 .25091 L
.06905 .24309 L
.06537 .23834 L
.06128 .23609 L
.05687 .23721 L
.05469 .23917 L
.05232 .24235 L
.04811 .25098 L
.04418 .26281 L
.04072 .2767 L
.03743 .29364 L
.03459 .31195 L
.03004 .35164 L
.02799 .37655 L
.02644 .40079 L
.02514 .42854 L
.02423 .45873 L
.02381 .49012 L
.02388 .51872 L
.0241 .5344 L
.02448 .55123 L
.02557 .581 L
.02702 .60754 L
.02899 .63394 L
.031 .65475 L
.03353 .67558 L
.03687 .69678 L
.04024 .71297 L
.04422 .72695 L
.0463 .73242 L
.04863 .73718 L
.05266 .74232 L
.05494 .7436 L
.05702 .74377 L
.06105 .74144 L
.06479 .73609 L
.06821 .72841 L
.07173 .71744 L
.07488 .70466 L
.07757 .69108 L
.08047 .67307 L
.08329 .65115 L
.08556 .6287 L
.08736 .6062 L
.08819 .5935 L
.08897 .57946 L
.09002 .55438 L
Mistroke
.09044 .53986 L
.09074 .52442 L
.09091 .49665 L
.09066 .47097 L
.09007 .44737 L
.08903 .42212 L
.08827 .40837 L
.08748 .39616 L
.08581 .37503 L
.08371 .35401 L
.07918 .32063 L
.07628 .30488 L
.07337 .29217 L
.06998 .28068 L
.06801 .27545 L
.06615 .27137 L
.06277 .26606 L
.05901 .26315 L
.05568 .26315 L
.05215 .26583 L
.04874 .27116 L
.04561 .2786 L
.04291 .28723 L
.04011 .29859 L
.03706 .31443 L
.03451 .33109 L
.03204 .35119 L
.02974 .37532 L
.02798 .39936 L
.0267 .42283 L
.0258 .44608 L
.02519 .47137 L
.02496 .49876 L
.02501 .51417 L
.02519 .52822 L
.0258 .55374 L
.02684 .57979 L
.02756 .59317 L
.02845 .60702 L
.03036 .63065 L
.0331 .65614 L
.03598 .67645 L
.03907 .69318 L
.04262 .70759 L
.04583 .71706 L
.0495 .72437 L
.05161 .72703 L
.05355 .72855 L
.0558 .72922 L
.05794 .72881 L
Mistroke
.06171 .72557 L
.06382 .72235 L
.06573 .71851 L
.06938 .70865 L
.07263 .69673 L
.07811 .66827 L
.08078 .64921 L
.08294 .63005 L
.08496 .60748 L
.08666 .58228 L
.08776 .55947 L
.08822 .54634 L
.08855 .5341 L
.08889 .51147 L
.08888 .48745 L
.08855 .46623 L
.08798 .4467 L
.08705 .42587 L
.08572 .40437 L
.08405 .38398 L
.08188 .36336 L
.07925 .344 L
.07651 .32826 L
.07372 .31564 L
.07102 .30617 L
.06777 .29773 L
.06459 .29234 L
.06176 .28975 L
.05864 .28922 L
.05538 .29129 L
.05239 .29564 L
.04966 .3018 L
.04725 .30916 L
.0446 .31964 L
.04224 .33146 L
.03988 .34616 L
.03763 .36382 L
.03591 .3806 L
.03432 .40008 L
.03294 .42222 L
.03197 .44403 L
.03155 .45698 L
.03123 .47083 L
.03096 .49589 L
.03109 .52065 L
.03134 .53452 L
.03167 .54719 L
.03255 .56996 L
.03384 .59314 L
.0353 .61276 L
Mistroke
.03692 .62999 L
.04138 .66428 L
.04426 .67985 L
.04722 .69215 L
.05003 .70103 L
.05322 .7083 L
.05507 .71129 L
.05677 .71327 L
.05875 .71471 L
.06063 .71523 L
.06396 .71417 L
.06753 .71023 L
.07056 .70453 L
.07329 .69739 L
.07617 .68764 L
.07908 .67512 L
.08189 .65989 L
.08431 .64371 L
.08627 .62769 L
.08809 .60951 L
.08943 .59301 L
.09065 .57412 L
.09152 .55645 L
.09212 .53959 L
.09255 .5196 L
.09269 .50126 L
.09256 .48129 L
.09211 .46065 L
.09133 .44035 L
.09076 .42926 L
.09014 .41932 L
.08882 .40217 L
.08709 .38461 L
.08347 .358 L
.08119 .34583 L
.0789 .33614 L
.07607 .32703 L
.07327 .32071 L
.07068 .31706 L
.06781 .3153 L
.06617 .31535 L
.06469 .31607 L
.063 .31768 L
.06142 .31996 L
.05866 .32586 L
.05581 .33479 L
.05346 .34468 L
.05142 .35557 L
.04919 .37048 L
.04739 .38575 L
Mistroke
.04575 .40333 L
.04446 .42122 L
.0434 .44119 L
.04293 .45287 L
.0426 .46386 L
.04224 .48231 L
.04212 .49983 L
.04225 .51911 L
.04269 .53971 L
.04346 .56081 L
.0445 .58024 L
.04566 .59696 L
.04718 .61426 L
.04912 .63187 L
.05146 .64871 L
.05433 .66481 L
.05721 .67725 L
.06006 .68666 L
.06285 .69346 L
.066 .69867 L
.0678 .70054 L
.06945 .7016 L
.07252 .70191 L
.07535 .70034 L
.07841 .69661 L
.08159 .69042 L
.08424 .68332 L
.08663 .67526 L
.09162 .6523 L
.09388 .63836 L
.0961 .62169 L
.09797 .60422 L
.09965 .58449 L
.10089 .5652 L
.10175 .54724 L
.10233 .52895 L
.10262 .51164 L
.10264 .4916 L
.10253 .48163 L
.10231 .47081 L
.10167 .4522 L
.10081 .43553 L
.09947 .41707 L
.09797 .40152 L
.09592 .3854 L
.09372 .37212 L
.09161 .36232 L
.08917 .35374 L
.08675 .34768 L
.08446 .34394 L
Mistroke
.08234 .34209 L
.08 .34179 L
.07757 .34342 L
.07534 .34672 L
.07411 .34932 L
.0728 .35274 L
.07051 .36054 L
.06841 .37001 L
.06661 .38031 L
.06485 .39298 L
.06315 .40866 L
.06167 .42671 L
.0606 .44493 L
.05995 .46055 L
.05949 .4782 L
.0593 .49706 L
.05938 .51479 L
.0597 .53145 L
.06018 .54643 L
.06097 .56341 L
.06193 .57895 L
.06321 .59523 L
.06482 .61149 L
.06831 .63759 L
.07055 .65014 L
.0728 .66045 L
.07544 .67008 L
.07842 .67836 L
.08 .68176 L
.08152 .68442 L
.08439 .68798 L
.08753 .68978 L
.0893 .68986 L
.09093 .68935 L
.09365 .68727 L
.09658 .68327 L
.09955 .67725 L
.10222 .67004 L
.10524 .65959 L
.1079 .64801 L
.11229 .6225 L
.11436 .60642 L
.11601 .59068 L
.11751 .57265 L
.11818 .56261 L
.11873 .55295 L
.11944 .53671 L
.11986 .52181 L
.12008 .50587 L
.12009 .49696 L
Mistroke
.12003 .48878 L
.11976 .47416 L
.11932 .46135 L
.1186 .44721 L
.11773 .43463 L
.11656 .42171 L
.1151 .40932 L
.11369 .39989 L
.112 .39086 L
.11003 .3828 L
.10889 .37913 L
.10778 .37618 L
.10673 .37391 L
.10556 .37196 L
.10349 .36988 L
.10147 .3695 L
.09963 .37057 L
.09763 .3733 L
.09558 .37792 L
.09387 .38337 L
.09236 .38959 L
.09081 .39758 L
.08928 .40758 L
.08779 .41999 L
.0866 .43297 L
.08565 .44665 L
.08497 .46002 L
.08445 .47518 L
.08427 .48404 L
.08417 .49246 L
.08415 .50143 L
.08419 .50969 L
.08433 .51927 L
.08454 .52838 L
.08482 .5373 L
.08516 .54565 L
.08598 .56103 L
.08711 .57713 L
.08863 .59377 L
.0902 .60755 L
.09208 .62109 L
.09597 .64233 L
.09842 .6524 L
.10122 .6615 L
.10399 .66842 L
.1066 .67327 L
.10823 .67554 L
.10975 .67717 L
.11143 .67844 L
.11323 .6792 L
Mistroke
.11479 .67937 L
.11625 .67912 L
.11785 .67839 L
.11956 .67709 L
.12238 .67378 L
.12488 .66956 L
.12768 .66334 L
.13021 .65623 L
.13441 .64087 L
.13842 .6209 L
.14209 .59577 L
.1436 .58221 L
.14499 .56686 L
.14595 .55353 L
.14639 .54613 L
.14674 .53912 L
.14726 .52556 L
.14755 .51333 L
.14766 .50082 L
.14764 .49384 L
.14756 .4874 L
.14725 .47486 L
.14698 .46809 L
.14668 .46207 L
.14607 .45241 L
.14524 .44259 L
.14422 .43326 L
.14314 .42549 L
.1417 .41748 L
.14023 .41125 L
.13882 .40682 L
.13723 .4033 L
.13638 .40202 L
.13544 .40104 L
.13445 .40051 L
.13351 .40048 L
.13186 .40151 L
.13094 .40271 L
.13011 .40419 L
.12857 .40803 L
.12718 .41284 L
.12601 .41809 L
.12483 .42474 L
.12366 .43309 L
.12259 .44303 L
.12182 .45236 L
.12113 .46339 L
.12066 .47437 L
.12038 .48485 L
.12023 .49739 L
Mistroke
.12029 .50959 L
.1205 .52104 L
.12084 .53171 L
.12137 .54343 L
.12212 .55578 L
.12424 .58056 L
.12577 .59379 L
.12737 .60531 L
.13078 .62469 L
.13493 .64197 L
.13735 .64969 L
.14006 .65672 L
.14272 .66217 L
.14521 .66608 L
.14665 .66788 L
.1482 .66942 L
.14991 .6707 L
.1515 .67149 L
.15437 .67199 L
.156 .67174 L
.15752 .67118 L
.16024 .66937 L
.16174 .66792 L
.16309 .66635 L
.16805 .65828 L
.17071 .65237 L
.17346 .645 L
.17806 .62932 L
.18191 .61214 L
.18535 .5923 L
.18775 .5745 L
.18887 .5643 L
.18978 .55463 L
.19052 .54532 L
.19117 .53531 L
.19162 .52638 L
.19192 .51831 L
.19213 .50984 L
.19221 .50085 L
.19215 .49193 L
.19196 .48405 L
.19167 .47716 L
.19131 .47107 L
.19092 .466 L
.19042 .46094 L
.1898 .45603 L
.18907 .45148 L
.18832 .44788 L
.1876 .44519 L
.18674 .44285 L
Mistroke
.18592 .44135 L
.18499 .44046 L
.18399 .4404 L
.18349 .44072 L
.18295 .44133 L
.18199 .44314 L
.18108 .44576 L
.18029 .44893 L
.17961 .45248 L
.17901 .45633 L
.17842 .46112 L
.17786 .46689 L
.1774 .47322 L
.17702 .48047 L
.1768 .4871 L
.17666 .49478 L
.17663 .4993 L
.17665 .50434 L
.17671 .50921 L
.1768 .51378 L
.17708 .52264 L
.17753 .53224 L
.17818 .54271 L
.17896 .55258 L
.18132 .57493 L
.18403 .59361 L
.18702 .6097 L
.19104 .62664 L
.19535 .64072 L
.2002 .65283 L
.2051 .66189 L
.2097 .668 L
.21237 .67059 L
.21484 .67243 L
.21755 .67384 L
.22009 .67463 L
.22288 .67492 L
.22445 .67482 L
.22588 .67458 L
.22874 .67364 L
.23035 .67285 L
.23183 .67197 L
.23735 .66734 L
.24194 .66188 L
.24609 .65567 L
.25486 .6384 L
.26233 .61877 L
.26905 .59642 L
.2782 .55615 L
.28338 .52731 L
Mistroke
.28386 .52489 L
.28434 .5228 L
.28475 .52133 L
.28494 .52081 L
.28511 .52043 L
.28542 .51998 L
.28559 .51989 L
.28577 .5199 L
.28595 .52003 L
.28613 .52027 L
.28647 .52102 L
.28681 .5221 L
.2872 .52364 L
.28797 .52739 L
.29026 .54022 L
.29666 .57295 L
.30847 .61801 L
.31785 .64543 L
.32817 .67035 L
.35303 .71638 L
.38248 .75656 L
.41425 .79156 L
.50173 .87565 L
.55505 .92297 L
.58354 .94487 L
.59649 .95351 L
.61103 .96191 L
.62335 .96776 L
.63021 .97044 L
.63676 .97257 L
.6442 .97444 L
.65103 .97559 L
.65745 .97615 L
.66446 .97613 L
.67216 .97529 L
.67913 .97371 L
.68298 .97249 L
.68713 .97087 L
.69462 .96712 L
.70159 .96257 L
.70887 .95665 L
.72164 .94296 L
.73695 .91994 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{403.75, 403.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009M0002GB000`400?l00000o`00003oo`3ooooo
0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo
003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0
ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool0
0?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3o
oomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00
C03oool700000;l0oooo1`00002o0?ooo`L00000OP3oool004X0oooo0P0000070?ooo`<00000^P3o
ool2000000L0oooo0`00002i0?ooo`<000001`3oool3000007/0oooo00180?ooo`8000002`3oool3
00000;H0oooo0P00000;0?ooo`<00000]P3oool2000000/0oooo0`00001i0?ooo`00A`3oool20000
00h0oooo0P00002d0?ooo`8000003P3oool200000;@0oooo0P00000>0?ooo`800000N03oool004H0
oooo0P00000A0?ooo`800000/@3oool00`000000oooo0?ooo`0@0?ooo`800000/@3oool00`000000
oooo0?ooo`0@0?ooo`800000MP3oool004H0oooo00<000000?ooo`3oool04@3oool200000:l0oooo
0P00000C0?ooo`800000[`3oool2000001<0oooo0P00001e0?ooo`00A@3oool00`000000oooo0?oo
o`0D0?ooo`800000[03oool2000001H0oooo0P00002/0?ooo`8000005P3oool2000007<0oooo0014
0?ooo`800000603oool00`000000oooo0?ooo`2Y0?ooo`800000603oool00`000000oooo0?ooo`2Y
0?ooo`800000603oool00`000000oooo0?ooo`1`0?ooo`00@`3oool2000001X0oooo00<000000?oo
o`3oool0Y`3oool2000001X0oooo00<000000?ooo`3oool0Y`3oool2000001X0oooo00<000000?oo
o`3oool0K`3oool003P0oooo0`0000080?ooo`030000003oool0oooo01X0oooo0P00002L0?ooo`<0
0000203oool00`000000oooo0?ooo`0J0?ooo`800000W03oool3000000P0oooo00<000000?ooo`3o
ool06P3oool2000006l0oooo000g0?ooo`040000003oool0oooo0?ooo`8000001@3oool2000001d0
oooo0P00002J0?ooo`040000003oool0oooo0?ooo`8000001@3oool2000001d0oooo0P00002J0?oo
o`040000003oool0oooo0?ooo`8000001@3oool2000001d0oooo0P00001^0?ooo`00=P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool20000
09P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01d0oooo0P00002H0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0M0?ooo`800000K@3oool003D0oooo00<000000?ooo`3oool01@3oool010000000
oooo0?ooo`3oool200000200oooo0P00002F0?ooo`030000003oool0oooo00D0oooo00@000000?oo
o`3oool0oooo0P00000P0?ooo`800000UP3oool00`000000oooo0?ooo`050?ooo`040000003oool0
oooo0?ooo`800000803oool2000006`0oooo000d0?ooo`030000003oool0oooo00L0oooo00@00000
0?ooo`3oool000008P3oool2000009@0oooo00<000000?ooo`3oool01P3oool200000080oooo00<0
00000?ooo`3oool0803oool2000009@0oooo00<000000?ooo`3oool01P3oool200000080oooo00<0
00000?ooo`3oool0803oool2000006/0oooo000d0?ooo`030000003oool0oooo00L0oooo0P000000
0`3oool000000?ooo`0R0?ooo`800000T`3oool00`000000oooo0?ooo`070?ooo`040000003oool0
oooo000002<0oooo0P00002C0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000
8`3oool2000006X0oooo000_0?ooo`D000002`3oool2000002D0oooo0P00002=0?ooo`D000002P3o
ool3000002D0oooo0P00002=0?ooo`D000002P3oool3000002D0oooo0P00001Y0?ooo`00;P3oool0
10000000oooo0?ooo`3oool2000000/0oooo0P00000V0?ooo`800000R`3oool010000000oooo0?oo
o`3oool2000000/0oooo0P00000V0?ooo`800000R`3oool010000000oooo0?ooo`3oool2000000/0
oooo0P00000V0?ooo`800000J03oool002d0oooo00<000000?ooo`3oool00P3oool2000000/0oooo
0P00000W0?ooo`800000R@3oool00`000000oooo0?ooo`020?ooo`8000002`3oool2000002L0oooo
0P0000290?ooo`030000003oool0oooo0080oooo0P00000;0?ooo`8000009`3oool2000006L0oooo
000]0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000002P3oool2000002T0oooo00<0
00000?ooo`3oool0Q@3oool2000000@0oooo00<000000?ooo`0000002P3oool2000002T0oooo00<0
00000?ooo`3oool0Q@3oool2000000@0oooo00<000000?ooo`0000002P3oool2000002T0oooo00<0
00000?ooo`3oool0I03oool002/0oooo0`0000040?ooo`030000003oool0000000X0oooo0`00000Y
0?ooo`030000003oool0oooo08<0oooo0P0000050?ooo`030000003oool0000000X0oooo0`00000Y
0?ooo`030000003oool0oooo08<0oooo0P0000050?ooo`030000003oool0000000X0oooo0`00000Y
0?ooo`030000003oool0oooo06<0oooo000Y0?ooo`80000000<0oooo000000000000103oool01000
0000oooo0?ooo`0000080?ooo`80000000<0oooo0000003oool0:@3oool00`000000oooo0?ooo`20
0?ooo`80000000<0oooo0000000000000`3oool200000080oooo00<000000?ooo`3oool01P3oool2
000000030?ooo`000000oooo02T0oooo00<000000?ooo`3oool0P03oool5000000<0oooo0P000002
0?ooo`030000003oool0oooo00H0oooo0P0000000`3oool000000?ooo`0Y0?ooo`030000003oool0
oooo0680oooo000Y0?ooo`030000003oool0oooo008000000`3oool200000080oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`02000002X0oooo00<000000?ooo`3oool0O`3oool00`00
0000oooo00000002000000<0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0
oooo00800000:P3oool00`000000oooo0?ooo`1o0?ooo`050000003oool000000?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool00P00000Z0?ooo`030000
003oool0oooo0640oooo000X0?ooo`8000000P3oool300000080oooo0P0000030?ooo`030000003o
ool0oooo00D0oooo00D000000?ooo`3oool0oooo0000000[0?ooo`030000003oool0oooo07d0oooo
0P0000000`3oool000000000000200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`050000003oool0oooo0?ooo`000000:`3oool00`000000oooo0?ooo`1m0?ooo`80
000000@0oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo00D000000?ooo`3oool0oooo0000000[0?ooo`030000003oool0oooo0600oooo000X0?oo
o`030000003oool0oooo0080000000D0oooo0000003oool0oooo000000040?ooo`030000003oool0
oooo00D0oooo00D000000?ooo`3oool0oooo0000000/0?ooo`030000003oool0oooo07`0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0
oooo00D000000?ooo`3oool0oooo0000000/0?ooo`030000003oool0oooo07`0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00D0
00000?ooo`3oool0oooo0000000/0?ooo`030000003oool0oooo05l0oooo000W0?ooo`<0000000H0
oooo0000003oool0oooo0000003oool2000000@0oooo00<000000?ooo`3oool0103oool2000000<0
oooo00<000000?ooo`3oool0:`3oool2000007/0oooo0P0000020?ooo`050000003oool0oooo0000
003oool00P0000040?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`030000003oool0oooo
02/0oooo0P00001k0?ooo`8000000P3oool01@000000oooo0?ooo`000000oooo00800000103oool0
0`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo0?ooo`0[0?ooo`800000G`3oool0
02H0oooo0P000000103oool000000?ooo`0000030?ooo`<00000103oool00`000000oooo0?ooo`04
0?ooo`800000103oool00`000000oooo0?ooo`0[0?ooo`800000N@3oool2000000040?ooo`000000
oooo000000<0oooo0`0000040?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`030000003o
ool0oooo02/0oooo0P00001i0?ooo`80000000@0oooo0000003oool000000`3oool3000000@0oooo
00<000000?ooo`3oool0103oool2000000<0oooo0P00000]0?ooo`800000GP3oool002D0oooo0`00
00020?ooo`8000000`3oool2000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo02`0oooo0P00001g0?ooo`<000000P3oool2000000<0oooo0P00
00060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0/0?ooo`800000M`3oool300000080oooo0P0000030?ooo`8000001P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo0P00000^0?ooo`800000G@3oool002D0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`8000001P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool2000002H0oooo0P000005
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`02
0?ooo`8000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0;@3oool2000002H0oooo0P0000050?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`8000001P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool2000002H0oooo0P000005
0?ooo`030000003oool0oooo02`0oooo000T0?ooo`<000000`3oool2000000@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo0P00000_0?oo
o`800000903oool00`000000oooo0?ooo`02000000<0oooo0`0000150?ooo`<000000`3oool20000
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo0P00000_0?ooo`800000903oool00`000000oooo0?ooo`02000000<0oooo0`0000150?oo
o`<000000`3oool2000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;P3oool2000002@0oooo00<000000?oo
o`3oool00P0000030?ooo`<00000;03oool002@0oooo0`0000030?ooo`800000103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0000002<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`050000003oool0oooo0000003oool00`0000110?ooo`<000000`3oool2000000@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0000000S0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01@000000oooo0?ooo`000000oooo00<00000@@3oool3000000<0oooo0P0000040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool2000000D0oooo0P00000_0?ooo`030000
003oool0000002<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0000
003oool00`00000X0?ooo`00903oool01@000000oooo000000000000oooo00<00000103oool00`00
0000oooo0?ooo`040?ooo`8000000`3oool2000000H0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0000000Q0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool20000
00030?ooo`000000oooo0400oooo00D000000?ooo`00000000000?ooo`03000000@0oooo00<00000
0?ooo`3oool0103oool2000000<0oooo0P0000060?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`0000008@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo0P000000
0`3oool000000?ooo`100?ooo`050000003oool000000000003oool00`0000040?ooo`030000003o
ool0oooo00@0oooo0P0000030?ooo`030000003oool0oooo00@0oooo0P00000`0?ooo`030000003o
ool000000240oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`80000000<0
oooo0000003oool09`3oool002<0oooo0P0000001`3oool000000000003oool000000?ooo`000000
0`3oool2000000L0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`0000007`3oool00`000000oooo0?ooo`040?ooo`800000103oool010000000
oooo0?ooo`3oool2000003h0oooo0P0000001`3oool000000000003oool000000?ooo`0000000`3o
ool2000000L0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`0000007`3oool00`000000oooo0?ooo`040?ooo`800000103oool010000000oooo
0?ooo`3oool2000003h0oooo0P0000001`3oool000000000003oool000000?ooo`0000000`3oool2
000000L0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`0000007`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool0oooo0P00000V0?ooo`008P3oool6000000030?ooo`000000oooo008000000P3o
ool00`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo
0?ooo`0`0?ooo`8000005P3oool3000000H0oooo00<000000?ooo`3oool0103oool2000000@0oooo
0P0000020?ooo`030000003oool0000003`0oooo1P0000000`3oool000000?ooo`0200000080oooo
00<000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3o
ool0<03oool2000001H0oooo0`0000060?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`03
0000003oool000000080oooo00<000000?ooo`000000?03oool6000000030?ooo`000000oooo0080
00000P3oool00`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000001`3oool00`00
0000oooo0?ooo`0`0?ooo`8000005@3oool4000000H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000003oool000000080oooo00<000000?ooo`0000009@3oool00280
oooo1@0000000`3oool00000000000020?ooo`060000003oool0oooo0000003oool000001P3oool0
1@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0<03oool2000001@0oooo00@0
00000?ooo`3oool000001P3oool00`000000oooo0?ooo`040?ooo`8000000`3oool02@000000oooo
0000003oool000000?ooo`000000oooo0000000k0?ooo`D0000000<0oooo0000000000000P3oool0
1P000000oooo0?ooo`000000oooo000000H0oooo00D000000?ooo`3oool0oooo000000080?ooo`03
0000003oool0oooo0300oooo0P00000D0?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool0103oool2000000<0oooo00H000000?ooo`000000oooo0000003oool2000003`0oooo1@00
00000`3oool00000000000020?ooo`060000003oool0oooo0000003oool000001P3oool00`000000
oooo0?ooo`02000000L0oooo0P00000b0?ooo`800000503oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo00@0oooo0P0000030?ooo`040000003oool000000?ooo`80000000<0oooo
0000003oool0903oool00280oooo0P000000103oool000000?ooo`3oool200000080oooo00H00000
0?ooo`3oool000000?ooo`0000060?ooo`80000000<0oooo000000000000203oool00`000000oooo
0?ooo`0a0?ooo`8000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool2000000<0oooo00H000000?ooo`000000oooo0000003oool30000
03/0oooo0P000000103oool000000?ooo`3oool200000080oooo00H000000?ooo`3oool000000?oo
o`0000060?ooo`80000000<0oooo000000000000203oool00`000000oooo0?ooo`0a0?ooo`800000
4P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool2000000<0oooo00H000000?ooo`000000oooo0000003oool3000003/0oooo0P000000103o
ool000000?ooo`3oool200000080oooo00H000000?ooo`3oool000000?ooo`0000060?ooo`800000
00<0oooo0000003oool0203oool00`000000oooo0?ooo`0a0?ooo`8000004P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool2000000<0oooo
00@000000?ooo`000000oooo0P0000000`3oool000000000000T0?ooo`008P3oool2000000030?oo
o`00000000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0000000000050?oo
o`80000000<0oooo000000000000203oool00`000000oooo0?ooo`0b0?ooo`8000004@3oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000001`3oool2000000<0oooo00@00000
0?ooo`00000000000P3oool010000000oooo00000000000j0?ooo`80000000<0oooo000000000000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool00000000000D0oooo0P0000000`3o
ool00000000000080?ooo`030000003oool0oooo0380oooo0P00000A0?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`3oool0oooo000000070?ooo`8000000`3oool010000000oooo00000000
00020?ooo`040000003oool00000000003X0oooo0P0000000`3oool00000000000020?ooo`050000
003oool0oooo0000003oool00P0000000`3oool00000000000050?ooo`80000000<0oooo0000003o
ool0203oool00`000000oooo0?ooo`0b0?ooo`8000004@3oool00`000000oooo0?ooo`030?ooo`05
0000003oool0oooo0?ooo`0000001`3oool2000000<0oooo00@000000?ooo`00000000000P3oool0
10000000oooo00000000000S0?ooo`008@3oool3000000040?ooo`00000000000?ooo`8000000P3o
ool2000000030?ooo`000000oooo008000001P3oool00`000000oooo000000090?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`0000001`3oool200000080oooo00<000000?ooo`3oool00P0000020?ooo`040000
003oool00000000003T0oooo0`000000103oool000000000003oool200000080oooo0P0000000`3o
ool000000?ooo`02000000H0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0
000000L0oooo0P0000020?ooo`030000003oool0oooo008000000P3oool010000000oooo00000000
000i0?ooo`<0000000@0oooo000000000000oooo0P0000020?ooo`@0000000<0oooo000000000000
1P3oool00`000000oooo000000090?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001`3oool200000080
oooo00<000000?ooo`3oool00P0000020?ooo`040000003oool00000000002<0oooo000Q0?ooo`H0
000000<0oooo0000000000000`3oool300000080oooo00<000000?ooo`3oool0103oool00`000000
oooo000000090?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo000000020?oo
o`060000003oool0oooo0?ooo`000000oooo0`0000000`3oool000000000000h0?ooo`H0000000<0
oooo0000000000000`3oool300000080oooo00<000000?ooo`3oool0103oool00`000000oooo0000
00090?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`050?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo000000020?ooo`060000
003oool0oooo0?ooo`000000oooo0`0000000`3oool000000000000h0?ooo`H0000000<0oooo0000
000000000`3oool2000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo000000090?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?oo
o`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo000000020?ooo`060000003oool0
oooo0?ooo`000000oooo0`0000000`3oool000000000000R0?ooo`008@3oool200000080oooo1@00
00030?ooo`<000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000T0oooo00<0
00000?ooo`3oool0=03oool2000000d0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?oo
o`3oool0000000H0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`80000000<0oooo0000
003oool01000000h0?ooo`80000000<0oooo000000000000100000030?ooo`<000000P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0=03oool20000
00d0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000H0oooo00H00000
0?ooo`3oool000000?ooo`0000020?ooo`80000000<0oooo0000003oool01000000h0?ooo`800000
00<0oooo000000000000100000030?ooo`8000000`3oool00`000000oooo0?ooo`040?ooo`<00000
2@3oool00`000000oooo0?ooo`0d0?ooo`8000003@3oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000001P3oool01P000000oooo0?ooo`000000oooo00000080oooo0P000000
0`3oool000000?ooo`0400000280oooo000Q0?ooo`8000000P3oool00`000000oooo000000030000
0080oooo0`0000020?ooo`030000003oool0oooo00@0oooo0`00000:0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo
000000H0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`80000000<0oooo000000000000
1000000h0?ooo`80000000@0oooo000000000000oooo100000020?ooo`<000000P3oool00`000000
oooo0?ooo`040?ooo`<000002P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000060?ooo`060000003oool0oooo
0000003oool000000P3oool3000000030?ooo`000000000000<00000>03oool2000000040?ooo`00
000000000?ooo`@000000P3oool2000000<0oooo00<000000?ooo`3oool0103oool2000000/0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`0000001`3oool01P000000oooo0?ooo`000000oooo00000080oooo0`000000103o
ool000000000003oool200000280oooo000Q0?ooo`8000000P3oool01P000000oooo000000000000
oooo00000080oooo0P0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0?ooo`0000060?ooo`060000003oool0oooo0000003oool000000P3oool20000
00030?ooo`000000000000D00000=`3oool2000000040?ooo`00000000000?ooo`80000000@0oooo
0000003oool0oooo0P0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0?ooo`0000060?ooo`060000003oool0oooo0000003oool000000P3oool30000
00030?ooo`000000000000@00000=`3oool2000000040?ooo`00000000000?ooo`80000000@0oooo
0000003oool0oooo0P0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo000000070?ooo`060000003oool0oooo0000003oool000000P3oool300000003
0?ooo`000000000000@000008@3oool00200oooo2@000000103oool000000?ooo`3oool2000000<0
oooo0P0000060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000001@3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000P3oool3000000030?ooo`000000000000@00000=P3o
ool9000000040?ooo`000000oooo0?ooo`8000000`3oool2000000H0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`0000050?ooo`070000003oool0oooo0?ooo`000000oooo00000002
0?ooo`<0000000<0oooo0000000000001000000f0?ooo`D0000000H0oooo00000000000000000?oo
o`0000020?ooo`8000000`3oool2000000H0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
000000060?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`<0000000<0oooo0000
000000001000000Q0?ooo`00803oool9000000030?ooo`000000oooo0080oooo00@000000?ooo`3o
ool0oooo0P0000060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo0P0000060?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool0oooo1P000000103oool0000000000000000f0?ooo`T0000000<0
oooo0000003oool00P3oool010000000oooo0?ooo`3oool2000000H0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
203oool2000000H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool600000004
0?ooo`0000000000000003H0oooo2@000000103oool000000?ooo`3oool2000000<0oooo0P000006
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo0P0000060?ooo`040000003oool0oooo0?ooo`8000000`3o
ool6000000040?ooo`000000000000000240oooo000P0?ooo`<0000000P0oooo0000000000000000
0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00P0oooo0P0000060?ooo`030000003oool0oooo0080oooo00H000000?oo
o`3oool0oooo0000003oool400000080oooo0P00000f0?ooo`<0000000P0oooo0000000000000000
0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00P0oooo0P0000060?ooo`030000003oool0oooo0080oooo00H000000?oo
o`3oool0oooo0000003oool4000000040?ooo`0000000000000003H0oooo0`0000000`3oool00000
00000003000000040?ooo`000000oooo0?ooo`800000103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo0P0000060?ooo`040000003oool0oooo0?ooo`8000000`3oool00`00
0000oooo00000003000000040?ooo`000000000000000240oooo000P0?ooo`040000003oool00000
0?ooo`<0000000<0oooo0000003oool00P0000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`8000001P3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0000003oool01P0000000`3oool000000000000f0?ooo`<0000000L0
oooo00000000000000000?ooo`000000oooo008000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool2000000H0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`000000oooo00T00000=P3oool3000000030?ooo`0000000000
00<0000000@0oooo000000000000oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool02@3oool2000000H0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`030000003o
ool0000000P000008@3oool00200oooo0`0000000`3oool0000000000003000000030?ooo`000000
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00T0oooo0P00000i0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool2
000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0500000080oooo00<00000
0?ooo`0000000P00000e0?ooo`<0000000<0oooo0000000000000`000000103oool000000000003o
ool2000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`800000>@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo0P0000060?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01@0000020?ooo`030000003oool0000000800000=@3o
ool200000080oooo1@000000103oool000000000003oool2000000@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`090?ooo`800000>@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`3oool200000080
oooo1@0000020?ooo`030000003oool0000000800000803oool00200oooo0`0000000`3oool00000
0?ooo`03000000030?ooo`00000000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`8000002`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02@3oool2000000H0oooo00<000000?ooo`3oool00P3oool5000000030?oo
o`00000000000080oooo00<000000?ooo`0000000P00000e0?ooo`<0000000<0oooo0000003oool0
0`000000103oool000000000003oool2000000@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`090?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`P000000P3oool00`000000
oooo00000002000003D0oooo0P0000020?ooo`030000003oool000000080000000@0oooo00000000
0000oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`T000000P3oool00`000000oooo00000002
00000200oooo000P0?ooo`D0000000@0oooo00000000000000000P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00@0oooo0P00000;0?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`@0000000<0oooo0000003oool01@3o
ool2000000<0oooo00D000000?ooo`3oool000000?ooo`0300000080oooo1@00000e0?ooo`D00000
00@0oooo00000000000000000P3oool010000000oooo0000000000040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool4000000030?ooo`000000oooo00D0oooo0P0000030?oo
o`050000003oool0oooo0000003oool00`0000020?ooo`030000003oool0000000800000=@3oool2
000000040?ooo`00000000000?ooo`<000000P3oool010000000oooo0000000000040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool6000000D0oooo0`0000020?ooo`800000
00@0oooo000000000000oooo0`0000020?ooo`030000003oool0000000800000803oool001l0oooo
0`000000103oool000000?ooo`3oool4000000030?ooo`000000oooo00800000103oool00`000000
oooo0?ooo`040?ooo`8000002`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool2000000<0oooo0P0000050?ooo`040000003oool000000000
0080oooo00D000000?ooo`3oool000000?ooo`04000000030?ooo`000000000000<00000=03oool3
000000040?ooo`000000oooo0?ooo`@0000000<0oooo0000003oool00P0000040?ooo`030000003o
ool0oooo00<0oooo0`00000;0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`8000000`3oool2000000D0oooo00D000000?ooo`0000000000
0?ooo`0200000080oooo00<000000?ooo`0000000P0000020?ooo`030000003oool0000000800000
=03oool3000000040?ooo`000000oooo0?ooo`@0000000<0oooo0000003oool00P0000040?ooo`03
0000003oool0oooo00<0oooo0P00000<0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P0000050?ooo`05
0000003oool000000000003oool00P0000020?ooo`030000003oool00000008000000P3oool00`00
0000oooo0000000200000200oooo000O0?ooo`<0000000<0oooo0000003oool00P3oool300000003
0?ooo`000000oooo00800000103oool00`000000oooo0?ooo`030?ooo`<000002`3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`800000103oool200000080oooo00D000000?ooo`00000000000?ooo`020000
00030?ooo`00000000000080000000<0oooo0000000000000`00000d0?ooo`<0000000@0oooo0000
003oool0oooo100000000`3oool000000?ooo`02000000@0oooo00<000000?ooo`3oool00`3oool3
000000/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000020?ooo`050000003oool0
00000000003oool00P0000000`3oool0000000000002000000030?ooo`000000000000<00000=03o
ool3000000040?ooo`000000oooo0?ooo`@0000000<0oooo0000003oool00P0000040?ooo`030000
003oool0oooo00<0oooo0P00000<0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`800000
0P3oool01@000000oooo000000000000oooo0080000000<0oooo0000000000000P0000000`3oool0
00000000000300000200oooo000O0?ooo`<0000000@0oooo0000003oool0oooo100000000`3oool0
00000?ooo`02000000@0oooo00<000000?ooo`3oool00`3oool3000000/0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool2000000@0oooo0P0000030?ooo`<0000000<0oooo0000000000001@000000103oool0
00000000003oool2000003@0oooo0`000000103oool000000?ooo`3oool4000000030?ooo`000000
oooo00800000103oool00`000000oooo0?ooo`030?ooo`<000002`3oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`800000103oool2000000<0oooo0`0000000`3oool0000000000005000000040?ooo`000000
00000?ooo`800000=03oool3000000040?ooo`000000oooo0?ooo`@0000000<0oooo0000003oool0
0P0000040?ooo`030000003oool0oooo00<0oooo0P00000<0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
0P0000040?ooo`8000000`3oool3000000030?ooo`000000000000D0000000@0oooo000000000000
oooo0P00000P0?ooo`007`3oool3000000040?ooo`000000oooo0?ooo`@0000000<0oooo0000003o
ool00P0000050?ooo`030000003oool0oooo0080oooo0`00000;0?ooo`800000>`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool300000080
oooo00<000000?ooo`0000000`3oool3000000030?ooo`000000oooo00D0000000@0oooo00000000
0000oooo0`00000c0?ooo`D000000P3oool4000000030?ooo`000000oooo00800000103oool00`00
0000oooo0?ooo`030?ooo`<000002`3oool00`000000oooo0?ooo`0j0?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`<000000P3oool00`000000oooo00000003
0?ooo`<0000000<0oooo0000003oool01@000000103oool000000000003oool2000003@0oooo1@00
00020?ooo`@0000000<0oooo0000003oool00P0000040?ooo`030000003oool0oooo00<0oooo0P00
000<0?ooo`030000003oool0oooo03X0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000
003oool0oooo00@0oooo0`0000020?ooo`030000003oool0000000<0oooo0`0000000`3oool00000
0?ooo`05000000040?ooo`00000000000?ooo`800000803oool001l0oooo1@0000000`3oool00000
00000003000000030?ooo`000000oooo00<00000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000/0oooo0P00000k0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`<000000P3oool00`000000oooo000000030?ooo`<00000
00<0oooo0000003oool01@000000103oool000000000003oool3000003<0oooo1@0000000`3oool0
00000?ooo`03000000030?ooo`000000oooo00<000000`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000000/0oooo00<000000?ooo`3oool0>P3oool01@000000oooo0?ooo`3oool00000
00D0oooo00<000000?ooo`3oool0103oool300000080oooo00<000000?ooo`0000000`3oool30000
00030?ooo`000000oooo00D0000000@0oooo000000000000oooo0P00000d0?ooo`D0000000<0oooo
0000003oool00`0000000`3oool000000?ooo`03000000<0oooo00<000000?ooo`3oool00`3oool3
000000/0oooo00<000000?ooo`3oool0>P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0
00000?ooo`3oool0103oool300000080oooo00<000000?ooo`0000000`3oool3000000030?ooo`00
0000oooo00D0000000@0oooo000000000000oooo0P00000P0?ooo`007`3oool5000000030?ooo`00
0000oooo00D0000000@0oooo0000000000000000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000`0oooo00<000000?ooo`3oool0>@3oool2000000<0oooo00@000000?ooo`3oool0
oooo0P0000060?ooo`<000000P3oool00`000000oooo000000030?ooo`<0000000<0oooo0000003o
ool01@000000103oool000000000003oool3000003<0oooo1@0000000`3oool000000?ooo`050000
00040?ooo`0000000000000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000;
0?ooo`800000>`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3o
ool300000080oooo00<000000?ooo`0000000`3oool3000000030?ooo`000000oooo00D0000000@0
oooo000000000000oooo0P00000d0?ooo`D0000000<0oooo0000003oool01@000000103oool00000
0000000000030?ooo`030000003oool0oooo00<0oooo0`00000;0?ooo`800000>`3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool3000000050?ooo`000000oooo
0?ooo`0000000`3oool3000000030?ooo`000000oooo00D0000000@0oooo000000000000oooo0P00
000P0?ooo`007`3oool5000000030?ooo`000000oooo00D0000000@0oooo0000000000000000103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0>P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00P000000?ooo`000000
00000?ooo`000000oooo000000<0oooo0P000000103oool000000000003oool4000000040?ooo`00
000000000?ooo`@00000<`3oool5000000030?ooo`000000oooo00D0000000@0oooo000000000000
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000/0oooo0P00000k0?ooo`80
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo10000000103oool0
00000?ooo`0000030?ooo`80000000@0oooo000000000000oooo10000000103oool000000000003o
ool3000003@0oooo1@0000000`3oool000000?ooo`05000000040?ooo`0000000000000000<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0000000;0?ooo`800000>`3oool200000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`D000000P3oool010000000oooo
0?ooo`3oool2000000040?ooo`00000000000?ooo`@0000000@0oooo000000000000oooo0`00000P
0?ooo`007`3oool5000000030?ooo`000000oooo00<0000000H0oooo00000000000000000?ooo`00
00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000303oool00`000000oooo0?oo
o`0j0?ooo`80000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool00000008000000P3oool010000000oooo0?ooo`3oool2000000040?ooo`00000000000?ooo`@0
000000@0oooo000000000000oooo1000000c0?ooo`D0000000<0oooo0000003oool00`0000001P3o
ool00000000000000000oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
000;0?ooo`800000?03oool010000000oooo0?ooo`0000030?ooo`8000001`3oool2000000030?oo
o`00000000000080oooo00@000000?ooo`3oool0oooo0P000000103oool000000000003oool40000
00040?ooo`00000000000?ooo`@00000<`3oool5000000030?ooo`000000oooo00<0000000H0oooo
0000003oool000000?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000
2`3oool2000003`0oooo00@000000?ooo`3oool000000`3oool2000000L0oooo0P0000000`3oool0
0000000000020?ooo`040000003oool0oooo0?ooo`80000000H0oooo000000000000oooo0000003o
ool2000000040?ooo`00000000000?ooo`@000007`3oool001l0oooo1@0000000`3oool000000?oo
o`03000000060?ooo`00000000000000003oool00000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000`0oooo00<000000?ooo`3oool0>P3oool2000000030?ooo`000000oooo0080
oooo0P0000070?ooo`030000003oool00000008000000P3oool01`000000oooo0?ooo`000000oooo
0000003oool00P0000000`3oool0000000000002000000040?ooo`00000000000?ooo`@00000<`3o
ool5000000030?ooo`000000oooo00<0000000H0oooo00000000000000000?ooo`0000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`0000002`3oool2000003`0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`050?ooo`040000003oool000000?ooo`8000000P3oool0
1`000000oooo0?ooo`000000oooo0000003oool00P0000000`3oool0000000000002000000040?oo
o`00000000000?ooo`@00000<`3oool5000000030?ooo`000000oooo00<0000000H0oooo00000000
000000000?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000002`3oool2
000003`0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`050?ooo`040000003o
ool000000?ooo`8000000P3oool01`000000oooo0?ooo`000000oooo0000003oool00P0000000`3o
ool0000000000002000000040?ooo`00000000000?ooo`@000007`3oool001l0oooo1`0000000`3o
ool0000000000005000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0000000<0?ooo`030000003oool0oooo03X0oooo0P0000000`3oool000000?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`0000000P0000020?ooo`070000003oool0oooo
0000003oool000000?ooo`02000000030?ooo`00000000000080000000<0oooo0000003oool01@00
000c0?ooo`L0000000D0oooo00000000000000000?ooo`03000000030?ooo`000000oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0000000;0?ooo`800000?03oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo00D0oooo00@000000?ooo`000000oooo0P0000020?oo
o`070000003oool0oooo0000003oool000000?ooo`02000000030?ooo`00000000000080000000<0
oooo0000003oool01@00000c0?ooo`80000000<0oooo0000000000000P0000001@3oool000000000
00000000oooo00<0000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000/0oooo0P00000l0?ooo`040000003oool0oooo00000080oooo0P0000070?ooo`04
0000003oool000000?ooo`8000000P3oool01`000000oooo0?ooo`000000oooo0000003oool00P00
00000`3oool0000000000002000000030?ooo`000000oooo00D000007`3oool001l0oooo1P000002
0?ooo`@0000000@0oooo000000000000oooo0P0000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`000000303oool00`000000oooo0?ooo`0k0?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0000000200000080oooo00L000000?ooo`3oool00000
0?ooo`000000oooo0080000000<0oooo0000000000000P0000000`3oool000000?ooo`05000003<0
oooo1P0000020?ooo`@0000000@0oooo000000000000oooo0P0000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0k0?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02000000<0oooo00L000000?oo
o`3oool000000?ooo`000000oooo0080000000<0oooo0000000000000P0000000`3oool000000?oo
o`05000003<0oooo0P000000103oool000000000000000020?ooo`L0000000<0oooo000000000000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo000000020?ooo`8000001`3oool00`000000oooo0?ooo`02000000<0oooo
00<000000?ooo`3oool00`000000103oool000000000003oool4000000030?ooo`000000oooo00D0
00007`3oool001l0oooo1P0000020?ooo`@0000000<0oooo0000000000000`0000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0k0?ooo`030000
003oool000000080oooo0P0000070?ooo`030000003oool0oooo00<000000P3oool01@000000oooo
0?ooo`000000oooo00@0000000<0oooo0000000000000P0000000`3oool000000?ooo`05000003<0
oooo1P0000020?ooo`@0000000<0oooo0000000000000`0000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0k0?ooo`030000003oool000000080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0300000080oooo00D000000?ooo`3o
ool000000?ooo`04000000030?ooo`00000000000080000000<0oooo0000003oool01@00000b0?oo
o`<0000000@0oooo00000000000000000P3oool:000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0000000<0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00<000000P3oool00`000000oooo0?ooo`02
000000050?ooo`00000000000000003oool0100000000`3oool000000?ooo`05000001l0oooo000O
0?ooo`<0000000<0oooo0000000000000P3oool4000000030?ooo`000000000000<000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0>`3oool3
00000080oooo0P0000070?ooo`030000003oool0oooo00<000000P3oool01@000000oooo0?ooo`00
0000oooo00@0000000<0oooo0000000000000P0000020?ooo`H00000<`3oool3000000030?ooo`00
000000000080oooo100000000`3oool0000000000003000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0000000<0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`0000000P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<000000P3oool01@000000oooo0?oo
o`000000oooo00@0000000<0oooo0000000000000P0000000`3oool000000?ooo`0500000380oooo
100000000`3oool00000000000020?ooo`X000000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000`0oooo00<000000?ooo`3oool0>`3oool00`000000oooo000000020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`0000020?ooo`030000003oool0oooo00800000
00D0oooo00000000000000000?ooo`04000000030?ooo`000000oooo00D000007`3oool001h0oooo
100000000`3oool00000000000020?ooo`@0000000<0oooo0000000000000`0000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0l0?ooo`800000
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<000000P3oool01@000000oooo
0?ooo`000000oooo00@0000000<0oooo0000000000000P0000020?ooo`H00000<P3oool400000003
0?ooo`00000000000080oooo0P0000000`3oool000000?ooo`05000000<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0000000<0?ooo`030000003oool0oooo03/0oooo0`0000020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00`0000020?ooo`050000003oool0oooo0000
003oool0100000000`3oool0000000000002000000030?ooo`000000oooo00D00000<P3oool40000
00040?ooo`00000000000?ooo`D0000000<0oooo0000000000000`0000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0k0?ooo`<0000000<0oooo
000000000000203oool00`000000oooo0?ooo`0300000080oooo00<000000?ooo`3oool00P000000
1@3oool00000000000000000oooo00@0000000<0oooo0000003oool01@00000O0?ooo`007P3oool4
000000030?ooo`00000000000080oooo100000000`3oool0000000000002000000050?ooo`000000
oooo0?ooo`000000103oool00`000000oooo0000000<0?ooo`030000003oool0oooo03`0oooo0P00
00020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`0000020?ooo`050000003o
ool0oooo0000003oool0100000000`3oool000000000000200000080oooo1P00000b0?ooo`@00000
00<0oooo0000000000000P3oool4000000030?ooo`00000000000080000000D0oooo0000003oool0
oooo000000040?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0?03oool200000080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0300000080oooo00<000000?ooo`3o
ool00P0000000`3oool0000000000006000000030?ooo`000000oooo00D00000<P3oool400000004
0?ooo`00000000000?ooo`D0000000<0oooo0000000000000P0000001@3oool000000?ooo`3oool0
000000@0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0l0?ooo`80000000<0oooo
000000000000203oool00`000000oooo0?ooo`0300000080oooo00<000000?ooo`3oool00P000000
0`3oool0000000000006000000030?ooo`000000oooo00D000007`3oool001h0oooo10000000103o
ool000000000003oool5000000030?ooo`00000000000080000000D0oooo0000003oool0oooo0000
00040?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0?03oool200000080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0300000080oooo00D000000?ooo`3oool00000
0?ooo`04000000030?ooo`0000000000008000000P3oool600000380oooo10000000103oool00000
0000003oool5000000030?ooo`00000000000080000000D0oooo0000003oool0oooo000000040?oo
o`030000003oool0000000`0oooo00<000000?ooo`3oool0?03oool01@000000oooo0?ooo`3oool0
000000P0oooo00<000000?ooo`3oool00`0000020?ooo`030000003oool0oooo0080000000<0oooo
0000000000001P0000020?ooo`H00000<P3oool4000000060?ooo`00000000000?ooo`000000oooo
0`0000000`3oool0000000000002000000050?ooo`000000oooo0?ooo`0000000`3oool200000003
0?ooo`000000oooo00/0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`02000000P0
oooo00<000000?ooo`3oool00`0000000`3oool000000?ooo`020?ooo`80000000<0oooo00000000
00001P0000020?ooo`H000007`3oool001h0oooo10000000103oool000000000003oool500000003
0?ooo`00000000000080000000D0oooo0000003oool0oooo000000020?ooo`040000003oool00000
0?ooo`8000002`3oool00`000000oooo0?ooo`0l0?ooo`80000000<0oooo000000000000203oool0
0`000000oooo0?ooo`0300000080oooo00D000000?ooo`3oool000000?ooo`0900000080oooo1P00
000b0?ooo`@0000000@0oooo000000000000oooo1@0000000`3oool0000000000002000000050?oo
o`000000oooo0?ooo`0000000P3oool01@000000oooo0000003oool0000000`0oooo00<000000?oo
o`3oool0?03oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool00`0000020?oo
o`030000003oool0oooo0080000000<0oooo0000000000001P0000020?ooo`H00000<P3oool40000
00060?ooo`00000000000?ooo`000000oooo0`0000000`3oool0000000000002000000050?ooo`00
0000oooo0?ooo`0000000P3oool3000000030?ooo`000000oooo00/0oooo00<000000?ooo`3oool0
?03oool2000000030?ooo`000000oooo00P0oooo00<000000?ooo`3oool00`000000203oool00000
0?ooo`3oool000000?ooo`000000oooo200000020?ooo`H000007`3oool001h0oooo100000001P3o
ool000000000003oool000000?ooo`<0000000<0oooo0000000000000P0000001@3oool000000?oo
o`3oool000000080oooo0`0000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
?03oool2000000030?ooo`000000oooo00P0oooo00<000000?ooo`3oool00`0000020?ooo`030000
003oool0oooo0080000000<0oooo0000000000001P0000020?ooo`H00000<P3oool4000000060?oo
o`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0l0?ooo`80000000<0oooo0000003oool0203oool00`000000oooo0?ooo`03000000030?ooo`00
0000oooo0080oooo0P0000000`3oool000000000000600000080oooo1P00000b0?ooo`@0000000H0
oooo000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`000000oooo00000002
0?ooo`030000003oool00000008000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo03`0oooo0P0000000`3oool000000?ooo`080?ooo`030000003oool0oooo00<0000000P0oooo
0000003oool0oooo0000003oool000000?ooo`P000000P3oool6000001l0oooo000N0?ooo`@00000
00H0oooo000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`000000oooo0000
00020?ooo`040000003oool000000?ooo`8000000P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo03`0oooo0P0000000`3oool000000?ooo`080?ooo`030000003oool0oooo00@00000
00L0oooo0000003oool000000?ooo`000000oooo00P000000P3oool600000380oooo100000001P3o
ool000000000003oool000000?ooo`<0000000L0oooo000000000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0?03oool2000000030?ooo`000000oooo00P0oooo00<000000?ooo`3oool00`000000203o
ool000000?ooo`3oool000000?ooo`000000oooo200000020?ooo`H00000<P3oool4000000060?oo
o`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0l0?ooo`@000002@3oool00`000000oooo0?ooo`03000000080?ooo`000000oooo0?ooo`00
0000oooo0000003oool800000080oooo1P00000O0?ooo`007P3oool4000000060?ooo`0000000000
0?ooo`000000oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3oool010000000
oooo0000003oool200000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0l0?oo
o`<000002P3oool00`000000oooo0?ooo`04000000070?ooo`000000oooo0000003oool000000?oo
o`0800000080oooo1P00000b0?ooo`@0000000H0oooo000000000000oooo0000003oool300000007
0?ooo`00000000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000P3o
ool2000000/0oooo00<000000?ooo`3oool0?03oool3000000X0oooo00<000000?ooo`3oool00`00
0000203oool000000?ooo`3oool000000?ooo`000000oooo200000020?ooo`H00000<P3oool40000
00060?ooo`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0l0?ooo`<000002P3oool020000000oooo0?ooo`000000oooo0000003oool00000
0P3oool010000000oooo0000003oool800000080oooo1P00000O0?ooo`007P3oool4000000060?oo
o`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3o
ool010000000oooo0000003oool200000080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0l0?ooo`<000002P3oool00`000000oooo0?ooo`02000000030?ooo`00000000000080oooo
00@000000?ooo`000000oooo200000020?ooo`H00000<P3oool4000000060?ooo`00000000000?oo
o`000000oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0l0?ooo`<0
00002P3oool00`000000oooo0?ooo`02000000030?ooo`00000000000080oooo00@000000?ooo`00
0000oooo200000020?ooo`H00000<P3oool4000000060?ooo`00000000000?ooo`000000oooo0`00
00001`3oool000000000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
0080oooo0P00000;0?ooo`030000003oool0oooo03`0oooo0`00000:0?ooo`040000003oool0oooo
00000080oooo0P0000020?ooo`040000003oool000000?ooo`P000000P3oool6000001l0oooo000N
0?ooo`@0000000H0oooo000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`00
0000oooo000000020?ooo`040000003oool000000?ooo`8000000P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`0000002P3oool010000000oooo0?ooo`00
00020?ooo`8000000P3oool010000000oooo0000003oool800000080oooo1P00000b0?ooo`@00000
00H0oooo000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo03`0oooo0`00000:0?ooo`040000003oool0oooo00000080oooo0P0000020?ooo`04
0000003oool000000?ooo`P000000P3oool600000380oooo100000001P3oool000000000003oool0
00000?ooo`<0000000L0oooo000000000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000020?ooo`8000002`3oool00`000000oooo0?ooo`0l0?ooo`<000002P3oool01000
0000oooo0?ooo`0000020?ooo`8000000P3oool010000000oooo0000003oool800000080oooo1P00
000O0?ooo`007P3oool4000000060?ooo`00000000000?ooo`000000oooo0`0000001`3oool00000
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0000000X0oooo00@00000
0?ooo`3oool000000P3oool200000080oooo00@000000?ooo`000000oooo200000020?ooo`800000
00@0oooo0000000000000000<P3oool4000000060?ooo`00000000000?ooo`000000oooo0`000000
1`3oool000000000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0000000X0
oooo00@000000?ooo`3oool000000P3oool200000080oooo00@000000?ooo`000000oooo20000002
0?ooo`H00000<P3oool4000000060?ooo`00000000000?ooo`000000oooo0`0000001`3oool00000
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool000000080oooo0P00000;
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`0000002P3oool010000000oooo0?ooo`00
00020?ooo`8000000P3oool010000000oooo0000003oool800000080oooo1P00000O0?ooo`007P3o
ool4000000060?ooo`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000
0P3oool200000080oooo00@000000?ooo`000000oooo200000020?ooo`80000000@0oooo00000000
00000000<P3oool4000000060?ooo`00000000000?ooo`000000oooo0`0000001`3oool000000000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00X0oooo00@000000?oo
o`3oool000000P3oool200000080oooo00@000000?ooo`000000oooo200000020?ooo`H00000<P3o
ool4000000060?ooo`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000
0P3oool200000080oooo00@000000?ooo`000000oooo200000020?ooo`H000007`3oool001h0oooo
100000001P3oool000000000003oool000000?ooo`<0000000L0oooo000000000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo00000080
oooo0P0000020?ooo`040000003oool000000?ooo`P000000P3oool2000000040?ooo`0000000000
00000380oooo100000001P3oool000000000003oool000000?ooo`<0000000L0oooo000000000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`040000003oool0
oooo00000080oooo0P0000020?ooo`040000003oool000000?ooo`P000000P3oool600000380oooo
10000000103oool000000000003oool5000000070?ooo`00000000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?ooo`800000
0P3oool010000000oooo0000003oool800000080oooo1P00000O0?ooo`007P3oool4000000060?oo
o`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000000P3oool200000080
oooo00@000000?ooo`000000oooo200000020?ooo`80000000@0oooo0000000000000000<P3oool4
000000060?ooo`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000000P3o
ool200000080oooo00@000000?ooo`000000oooo200000020?ooo`80000000@0oooo000000000000
0000<P3oool4000000040?ooo`00000000000?ooo`D0000000L0oooo000000000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo00000080
oooo0P0000020?ooo`040000003oool000000?ooo`P000000P3oool6000001l0oooo000N0?ooo`@0
000000H0oooo000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?oo
o`8000000P3oool00`000000oooo000000020?ooo`L000000P3oool2000000040?ooo`0000000000
00000380oooo100000001P3oool000000000003oool000000?ooo`<0000000L0oooo000000000000
oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`040000003oool0
oooo00000080oooo0P0000020?ooo`040000003oool000000?ooo`P000000P3oool2000000040?oo
o`000000000000000380oooo10000000103oool000000000003oool5000000070?ooo`0000000000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool02P3oool010000000oooo
0?ooo`0000020?ooo`8000000P3oool010000000oooo0000003oool800000080oooo1P00000O0?oo
o`007P3oool4000000060?ooo`00000000000?ooo`000000oooo0`0000001`3oool000000000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3o
ool000000P3oool200000080oooo00<000000?ooo`0000000P3oool700000080oooo0P000000103o
ool0000000000000000b0?ooo`@0000000H0oooo000000000000oooo0000003oool3000000070?oo
o`00000000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`0000020?ooo`8000000P3oool010000000oooo0000003oool800000080oooo
0P000000103oool0000000000000000b0?ooo`@0000000@0oooo000000000000oooo1@0000001`3o
ool000000000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00X0oooo
00@000000?ooo`3oool000000P3oool200000080oooo00@000000?ooo`000000oooo200000020?oo
o`H000007`3oool001h0oooo100000001P3oool000000000003oool000000?ooo`<0000000L0oooo
000000000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo00P0oooo0P00000n0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3o
ool000000P3oool200000080oooo00@000000?ooo`000000oooo200000020?ooo`80000000@0oooo
0000000000000000<P3oool4000000060?ooo`00000000000?ooo`000000oooo0`0000001`3oool0
00000000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool0203oool2000003h0oooo00<000000?ooo`3oool02P3oool010000000oooo0?oo
o`0000020?ooo`8000000P3oool010000000oooo0000003oool800000080oooo1P00000b0?ooo`@0
000000@0oooo000000000000oooo1@0000001`3oool000000000003oool000000?ooo`0000000P3o
ool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0203oool2000003h0oooo
00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool010000000
oooo0000003oool800000080oooo1P00000O0?ooo`007P3oool4000000060?ooo`00000000000?oo
o`000000oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`3oool01`3oool3000003h0oooo00<000000?ooo`3o
ool02P3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool010000000oooo0000003oool8
00000080oooo0P000000103oool0000000000000000b0?ooo`@0000000H0oooo000000000000oooo
0000003oool3000000070?ooo`00000000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`070?ooo`<00000?P3oool00`000000oooo0?oo
o`0:0?ooo`040000003oool0oooo00000080oooo0P0000020?ooo`040000003oool000000?ooo`P0
00000P3oool600000380oooo100000001P3oool000000000003oool000000?ooo`<0000000L0oooo
000000000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000020?ooo`80
00002@3oool3000003h0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?oo
o`8000000P3oool010000000oooo0000003oool800000080oooo1P00000O0?ooo`007P3oool40000
00060?ooo`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool01`3oool30000
03h0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool0
10000000oooo0000003oool800000080oooo0P000000103oool0000000000000000b0?ooo`@00000
00H0oooo000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`070?ooo`<00000
?P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo00000080oooo0P0000020?ooo`04
0000003oool000000?ooo`P000000P3oool600000380oooo100000001P3oool000000000003oool0
00000?ooo`<0000000L0oooo000000000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000020?ooo`030000003oool0oooo00P0oooo0`00000n0?ooo`030000003oool0oooo
00X0oooo00D000000?ooo`3oool000000?ooo`0300000080oooo00@000000?ooo`000000oooo2000
00020?ooo`H000007`3oool001h0oooo100000001P3oool000000000003oool000000?ooo`<00000
00L0oooo000000000000oooo0000003oool000000080oooo00@000000?ooo`000000oooo0P000002
0?ooo`030000003oool0oooo00L0oooo0`00000n0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P0000000`3oool00000000000020?ooo`040000003oool000000?ooo`P000000P3o
ool2000000040?ooo`000000000000000380oooo100000001P3oool000000000003oool000000?oo
o`<0000000L0oooo000000000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo00L0oooo0`00000n0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool01@0000020?ooo`040000003oool000000?ooo`P000000P3oool600000380
oooo100000001P3oool000000000003oool000000?ooo`<0000000L0oooo000000000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0
oooo0`00000n0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`000000203oool0
00000?ooo`3oool000000?ooo`000000oooo200000020?ooo`H000007`3oool001h0oooo10000000
1P3oool000000000003oool000000?ooo`<0000000L0oooo000000000000oooo0000003oool00000
0080oooo00@000000?ooo`000000oooo0P0000020?ooo`030000003oool0oooo00L0oooo0`00000n
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`000000203oool000000?ooo`3o
ool000000?ooo`000000oooo200000020?ooo`H00000<P3oool4000000060?ooo`00000000000?oo
o`000000oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3oool01@000000oooo
0000003oool000000080oooo0P0000090?ooo`<00000?P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00<0000000P0oooo0000003oool0oooo0000003oool000000?ooo`P000000P3o
ool600000380oooo100000001P3oool000000000003oool000000?ooo`<0000000L0oooo00000000
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo00L0oooo1000000n0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`00
0000203oool000000?ooo`3oool000000?ooo`000000oooo200000020?ooo`H000007`3oool001h0
oooo10000000103oool000000000003oool5000000070?ooo`00000000000?ooo`000000oooo0000
00020?ooo`040000003oool000000?ooo`80000000<0oooo0000000000002@3oool3000003h0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`03000000080?ooo`000000oooo0?ooo`00
0000oooo0000003oool800000080oooo1P00000b0?ooo`@0000000H0oooo000000000000oooo0000
003oool3000000070?ooo`00000000000?ooo`000000oooo000000020?ooo`040000003oool00000
0?ooo`80000000<0oooo0000003oool02@3oool3000003h0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`03000000080?ooo`000000oooo0?ooo`000000oooo0000003oool800000080
oooo1P00000b0?ooo`@0000000H0oooo000000000000oooo0000003oool3000000070?ooo`000000
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000P3oool00`000000
oooo0?ooo`070?ooo`@00000?P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0
000000P0oooo0000003oool0oooo0000003oool000000?ooo`P000000P3oool6000001l0oooo000N
0?ooo`@0000000@0oooo000000000000oooo1@0000000`3oool0000000000002000000080?ooo`00
0000oooo0?ooo`000000oooo0000003oool2000000030?ooo`000000000000T0oooo0`00000n0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`0000020?ooo`030000003oool0oooo
0080000000<0oooo0000000000001P0000020?ooo`H00000<P3oool4000000060?ooo`0000000000
0?ooo`000000oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3oool010000000
oooo0000003oool2000000030?ooo`000000oooo00T0oooo0`00000n0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00`0000020?ooo`030000003oool0oooo0080000000<0oooo0000
000000001P0000020?ooo`H00000<P3oool4000000060?ooo`00000000000?ooo`000000oooo0`00
00001`3oool000000000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
0080oooo00<000000?ooo`3oool01`3oool4000003h0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`03000000080?ooo`000000oooo0?ooo`000000oooo0000003oool800000080oooo
1P00000O0?ooo`007P3oool4000000030?ooo`00000000000080oooo100000000`3oool000000000
0002000000080?ooo`000000oooo0?ooo`000000oooo0000003oool2000000030?ooo`000000oooo
00P0oooo0P0000000`3oool000000?ooo`0n0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool00`0000020?ooo`030000003oool0oooo0080000000D0oooo00000000000000000?ooo`04
00000080oooo1P00000b0?ooo`@0000000H0oooo000000000000oooo0000003oool3000000070?oo
o`00000000000?ooo`000000oooo000000020?ooo`040000003oool000000?ooo`80000000<0oooo
0000003oool0203oool2000000030?ooo`000000oooo03d0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0300000080oooo00<000000?ooo`3oool00P0000000`3oool0000000000006
00000080oooo1P00000b0?ooo`@0000000H0oooo000000000000oooo0000003oool3000000070?oo
o`00000000000?ooo`000000oooo000000020?ooo`040000003oool000000?ooo`80000000<0oooo
0000003oool0203oool010000000oooo0?ooo`00000n0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00`0000000`3oool000000?ooo`020?ooo`80000000<0oooo0000000000001P00
00020?ooo`H000007`3oool001h0oooo100000000`3oool00000000000020?ooo`@0000000<0oooo
0000000000000P0000001P3oool000000?ooo`3oool000000?ooo`@0000000<0oooo0000003oool0
203oool00`000000oooo0?ooo`02000003h0oooo00<000000?ooo`3oool02@3oool010000000oooo
0?ooo`0000040?ooo`050000003oool0oooo0000003oool0100000000`3oool00000000000020000
0080oooo1P00000b0?ooo`@0000000H0oooo000000000000oooo0000003oool3000000030?ooo`00
000000000080000000H0oooo0000003oool0oooo0000003oool4000000030?ooo`000000oooo00P0
oooo00<000000?ooo`3oool00P00000m0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`02000000030?ooo`000000000000H0000000<0oooo0000
003oool01@00000b0?ooo`@0000000H0oooo000000000000oooo0000003oool3000000030?ooo`00
000000000080000000H0oooo0000003oool0oooo0000003oool4000000030?ooo`000000oooo00P0
oooo00<000000?ooo`3oool00P00000m0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3o
ool000000`3oool010000000oooo0?ooo`3oool2000000030?ooo`000000000000@0000000D0oooo
0000003oool000000?ooo`05000001l0oooo000O0?ooo`<0000000<0oooo0000000000000P3oool4
000000030?ooo`00000000000080000000D0oooo0000003oool0oooo000000020?ooo`<0000000<0
oooo0000003oool0203oool00`000000oooo0?ooo`02000003h0oooo00<000000?ooo`3oool02@3o
ool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0000003oool0100000000`3oool0
00000000000200000080oooo1P00000b0?ooo`@0000000@0oooo000000000000oooo1@0000000`3o
ool0000000000002000000050?ooo`000000oooo0?ooo`0000000P3oool3000000030?ooo`000000
oooo00P0oooo00<000000?ooo`3oool00P00000m0?ooo`030000003oool0oooo00X0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`02000000050?ooo`00000000000000003oool0
100000000`3oool000000?ooo`0500000380oooo10000000103oool000000000003oool500000003
0?ooo`00000000000080000000H0oooo0000003oool0oooo0000003oool2000000040?ooo`000000
oooo000000P0oooo0P0000020?ooo`800000?@3oool00`000000oooo0?ooo`0:0?ooo`040000003o
ool0oooo000000<0oooo00@000000?ooo`3oool0oooo0P0000001@3oool00000000000000000oooo
0080000000D0oooo0000003oool000000?ooo`05000001l0oooo000O0?ooo`<0000000<0oooo0000
000000000P3oool4000000030?ooo`00000000000080000000D0oooo0000003oool0oooo00000002
0?ooo`<0000000<0oooo0000003oool0203oool00`000000oooo0?ooo`02000003h0oooo00<00000
0?ooo`3oool02@3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0000003oool0
100000000`3oool0000000000002000000030?ooo`000000oooo00D00000<P3oool4000000030?oo
o`00000000000080oooo100000000`3oool0000000000002000000050?ooo`000000oooo0?ooo`00
00000P3oool3000000030?ooo`000000oooo00P0oooo00<000000?ooo`3oool00P00000m0?ooo`03
0000003oool0oooo00X0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020000
00050?ooo`00000000000000003oool0100000000`3oool000000?ooo`0500000380oooo10000000
0`3oool00000000000020?ooo`@0000000<0oooo0000000000000P0000001P3oool000000?ooo`3o
ool000000?ooo`80000000@0oooo0000003oool00000203oool200000080oooo0P00000m0?ooo`03
0000003oool0oooo00X0oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`3oool3
000000040?ooo`00000000000?ooo`80000000D0oooo0000003oool000000?ooo`05000001l0oooo
000O0?ooo`H000000P3oool4000000030?ooo`00000000000080000000D0oooo0000003oool0oooo
000000020?ooo`050000003oool000000?ooo`000000203oool010000000oooo0?ooo`3oool20000
03h0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`0000040?ooo`070000003oool0
oooo0000003oool000000?ooo`02000000030?ooo`00000000000080000000<0oooo0000003oool0
1@00000b0?ooo`L000000P3oool4000000030?ooo`000000000000@000000P3oool020000000oooo
0?ooo`000000oooo0000003oool00000203oool010000000oooo0?ooo`3oool2000003h0oooo00<0
00000?ooo`3oool02@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<00000
00@0oooo000000000000oooo100000000`3oool000000?ooo`0500000380oooo100000000`3oool0
0000000000020?ooo`@0000000<0oooo000000000000100000020?ooo`080000003oool0oooo0000
003oool000000?ooo`0000080?ooo`040000003oool0oooo0?ooo`800000?P3oool00`000000oooo
0?ooo`090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`000000103oool0
00000000003oool4000000030?ooo`000000oooo00D000007`3oool001l0oooo1P0000020?ooo`@0
000000<0oooo0000000000000P0000001@3oool000000?ooo`3oool000000080oooo00D000000?oo
o`000000oooo000000080?ooo`040000003oool0oooo0?ooo`<00000?@3oool00`000000oooo0?oo
o`090?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0oooo0P000000103oool0
00000000003oool4000000030?ooo`000000oooo00D00000<P3oool700000080oooo2P0000030?oo
o`080000003oool0oooo0000003oool000000?ooo`0000080?ooo`040000003oool0oooo0?ooo`<0
0000?@3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`3oool0oooo0P000000103oool000000000003oool4000000030?ooo`000000oooo00D00000<P3o
ool700000080oooo2P0000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000080?oo
o`040000003oool0oooo0?ooo`800000?P3oool00`000000oooo0?ooo`090?ooo`040000003oool0
oooo000000@0oooo00@000000?ooo`3oool0oooo0P000000103oool000000000003oool400000003
0?ooo`000000oooo00D000007`3oool001l0oooo1P0000020?ooo`@0000000<0oooo000000000000
0P0000001@3oool000000?ooo`3oool000000080oooo00D000000?ooo`000000oooo000000080?oo
o`040000003oool0oooo0?ooo`<00000?@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
000000@0oooo00@000000?ooo`3oool0oooo0P000000103oool000000000003oool4000000030?oo
o`000000oooo00D00000<`3oool600000080oooo2P0000030?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000080?ooo`040000003oool0oooo0?ooo`<00000?@3oool00`000000oooo0?oo
o`090?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0oooo0P000000103oool0
00000000003oool4000000030?ooo`000000oooo00D00000<`3oool600000080oooo2P0000030?oo
o`080000003oool0oooo0000003oool000000?ooo`0000080?ooo`040000003oool0oooo0?ooo`80
0000?P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`3oool0oooo0P000000103oool000000000003oool4000000030?ooo`000000oooo00D000007`3o
ool001l0oooo1@0000000`3oool000000?ooo`0:000000<0oooo00<000000?ooo`3oool00`000000
0`3oool000000?ooo`060?ooo`8000000`3oool3000003d0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`00000000000?oo
o`04000000030?ooo`000000oooo00D00000<`3oool5000000030?ooo`000000oooo00X000000`3o
ool00`000000oooo0?ooo`03000000030?ooo`000000oooo00H0oooo0P0000030?ooo`<00000?@3o
ool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo000000000000oooo00@0000000<0oooo0000003oool01@00000c0?ooo`L0
000000<0oooo000000000000200000030?ooo`080000003oool0oooo0000003oool000000?ooo`00
00070?ooo`8000000`3oool3000003d0oooo00<000000?ooo`3oool02@3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`00000000000?ooo`0400000003
0?ooo`000000oooo00D000007`3oool001l0oooo1@0000000`3oool000000?ooo`0:000000<0oooo
00<000000?ooo`0000000`0000000`3oool000000?ooo`060?ooo`040000003oool0oooo0?ooo`80
000000<0oooo0000003oool0?03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000@0
oooo00<000000?ooo`3oool00P3oool01@000000oooo000000000000oooo00@0000000<0oooo0000
003oool01@00000c0?ooo`D0000000<0oooo0000003oool02P0000030?ooo`030000003oool00000
00<0000000<0oooo0000003oool01P3oool010000000oooo0?ooo`3oool2000000030?ooo`000000
oooo03`0oooo00<000000?ooo`3oool02@3oool00`000000oooo000000050?ooo`030000003oool0
oooo0080oooo00D000000?ooo`00000000000?ooo`04000000030?ooo`000000oooo00D00000<`3o
ool7000000030?ooo`000000000000P000000`3oool020000000oooo000000000000oooo0000003o
ool000001`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo000000000000oooo00@0000000<0oooo0000003oool01@00000O0?ooo`007`3oool5
000000030?ooo`000000oooo00<0000000D0oooo00000000000000000?ooo`02000000<0oooo00<0
00000?ooo`0000000`0000000`3oool000000?ooo`060?ooo`040000003oool0oooo0?ooo`800000
00<0oooo000000000000?03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000@0oooo
00<000000?ooo`3oool00P3oool01@000000oooo000000000000oooo00@0000000@0oooo00000000
0000oooo1000000c0?ooo`D0000000<0oooo0000003oool00`0000001@3oool00000000000000000
oooo008000000`3oool00`000000oooo00000003000000030?ooo`000000oooo00H0oooo00@00000
0?ooo`3oool0oooo0P0000000`3oool000000000000l0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`050000003oool000000000003oool0
10000000103oool000000000003oool4000003<0oooo1`0000001@3oool00000000000000000oooo
00H000000`3oool00`000000oooo00000003000000030?ooo`000000oooo00H0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo000000050?ooo`030000003oool0oooo0080oooo00D000000?ooo`00000000000?oo
o`05000000030?ooo`000000oooo00@000007`3oool001l0oooo1@0000000`3oool000000?ooo`03
000000050?ooo`00000000000000003oool00P0000030?ooo`040000003oool000000?ooo`800000
00<0oooo0000003oool01P3oool010000000oooo0?ooo`3oool2000000030?ooo`000000000003`0
oooo00<000000?ooo`3oool02P3oool00`000000oooo000000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000000`000000103oool000000000003oool2000000030?ooo`0000000000
00800000<`3oool5000000030?ooo`000000oooo00<0000000<0oooo000000000000100000030?oo
o`040000003oool000000?ooo`80000000<0oooo0000003oool01P3oool010000000oooo0?ooo`3o
ool2000000030?ooo`000000000003`0oooo00<000000?ooo`3oool02P3oool2000000D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo00000003000000040?ooo`00000000000?ooo`800000
00<0oooo0000000000000P00000c0?ooo`L0000000D0oooo00000000000000000?ooo`06000000<0
oooo00@000000?ooo`000000oooo0P0000000`3oool000000?ooo`060?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00X0oooo0P000005
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`0000001`3oool0000000000000
0000oooo0000003oool01000000O0?ooo`007`3oool5000000030?ooo`000000oooo00<0000000D0
oooo00000000000000000?ooo`0200000080oooo00D000000?ooo`3oool000000?ooo`0200000003
0?ooo`000000oooo00D0oooo00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo00000007000000040?ooo`00000000000?ooo`<00000<`3oool50000
00030?ooo`000000oooo00<0000000<0oooo000000000000100000020?ooo`050000003oool0oooo
0000003oool00P0000000`3oool000000?ooo`050?ooo`030000003oool0oooo0080oooo0P000002
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool02P3oool2000000D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo00000007000000040?ooo`00000000000?ooo`<00000<`3o
ool5000000030?ooo`000000oooo00<0000000<0oooo0000000000000`0000030?ooo`050000003o
ool0oooo0000003oool00P0000000`3oool000000?ooo`050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P00000l0?ooo`030000003oool0oooo00X0oooo0P0000050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000001`000000103oool000000000003oool3000001l0
oooo000O0?ooo`D0000000<0oooo0000003oool00`0000001@3oool000000?ooo`000000oooo0080
00000P3oool00`000000oooo000000020?ooo`80000000<0oooo0000003oool01@3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000?@3oool00`000000oooo0?ooo`090?oo
o`8000001@3oool00`000000oooo0?ooo`020?ooo`040000003oool0000000000080oooo10000000
103oool000000000003oool2000003@0oooo1@0000000`3oool000000?ooo`03000000030?ooo`00
0000oooo00@000000P3oool00`000000oooo000000020?ooo`80000000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000?@3oool00`000000oooo
0?ooo`090?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`040000003oool0000000000080
oooo10000000103oool000000000003oool2000003@0oooo1@0000000`3oool000000?ooo`030000
00030?ooo`000000oooo00<000000`3oool00`000000oooo000000020?ooo`@000001P3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000?03oool00`000000oooo0?ooo`0:
0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`040000003oool0000000000080oooo1000
00000`3oool000000000000300000200oooo000O0?ooo`D0000000<0oooo0000003oool01@000000
103oool000000?ooo`0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001@3o
ool2000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo00T0oooo0P0000050?ooo`030000003oool0oooo0080oooo00H000000?ooo`000000oooo
0000003oool4000000040?ooo`00000000000?ooo`800000=03oool5000000030?ooo`000000oooo
00D0000000@0oooo00000000000000000`3oool00`000000oooo000000030?ooo`030000003oool0
000000D0oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`090?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`060000003oool0
00000?ooo`000000oooo10000000103oool000000000003oool2000003@0oooo1@0000000`3oool0
00000?ooo`05000000040?ooo`0000000000000000<0oooo00<000000?ooo`0000000`3oool30000
00D0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool2000003/0oooo00<00000
0?ooo`3oool02P3oool2000000D0oooo00<000000?ooo`3oool00P3oool01P000000oooo0000003o
ool000000?ooo`@0000000<0oooo0000000000000`00000P0?ooo`007`3oool3000000040?ooo`00
0000oooo0?ooo`H0000000<0oooo0000000000000P0000020?ooo`030000003oool0000000@0oooo
0P0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo00T0oooo0P0000050?ooo`030000003oool0oooo0080oooo
0P0000020?ooo`030000003oool0000000<0000000@0oooo000000000000oooo0P00000d0?ooo`D0
000000D0oooo00000000000000000?ooo`03000000030?ooo`0000000000008000000P3oool00`00
0000oooo000000030?ooo`<000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`090?ooo`8000001@3oool00`00
0000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo00000003000000040?ooo`0000000000
0?ooo`800000=03oool5000000050?ooo`000000oooo0000003oool00`0000000`3oool000000000
000200000080oooo00<000000?ooo`0000000`3oool2000000H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool02P3o
ool2000000D0oooo00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`0000000`00
00000`3oool000000000000300000200oooo000O0?ooo`<0000000@0oooo0000003oool0oooo1P00
00000`3oool000000000000200000080oooo00<000000?ooo`000000103oool00`000000oooo0?oo
o`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool02@3oool2000000D0oooo00<000000?ooo`3oool00P3oool200000080oooo00<0
00000?ooo`0000000P0000020?ooo`80000000<0oooo000000000000=03oool500000080oooo1P00
00000`3oool000000000000200000080oooo00<000000?ooo`0000000`3oool2000000D0oooo0P00
00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`090?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo0000
000200000080oooo00<000000?ooo`3oool00P00000d0?ooo`D0000000<0oooo0000000000001@00
00000`3oool000000000000200000080oooo0`0000030?ooo`8000001@3oool00`000000oooo0?oo
o`030?ooo`800000103oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00X0oooo0P00
00050?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool00000008000000P3o
ool00`000000oooo0000000200000200oooo000O0?ooo`<0000000@0oooo000000000000oooo1P00
00000`3oool00000000000020?ooo`040000003oool00000000000D0oooo0P0000030?ooo`800000
1P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000
003oool00000008000000P3oool2000000030?ooo`000000000003@0oooo0`000000103oool00000
0000003oool6000000030?ooo`00000000000080oooo00@000000?ooo`00000000001@3oool20000
00<0oooo0P0000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool20000
0080oooo00<000000?ooo`0000000P0000020?ooo`030000003oool0000000800000=03oool30000
00040?ooo`00000000000?ooo`H0000000<0oooo0000000000000P3oool010000000oooo00000000
00050?ooo`8000000`3oool2000000D0oooo0P0000050?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P00
00020?ooo`030000003oool00000008000000P3oool01@000000oooo0000003oool000000200oooo
000P0?ooo`D0000000D0oooo00000000000000000?ooo`02000000030?ooo`000000000000<0oooo
0`0000050?ooo`<0000000<0oooo0000000000001P3oool2000000D0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool01@000000oooo0?ooo`000000oooo00<000000P3oool00`000000oooo00000002000003@0
oooo1P0000001@3oool00000000000000000oooo0080000000<0oooo0000000000000P3oool30000
00H0oooo0`0000000`3oool00000000000060?ooo`8000001@3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`050000003oool0oooo0000003oool00`0000020?ooo`050000003oool000000?ooo`000000=03o
ool6000000050?ooo`00000000000000003oool00P0000000`3oool00000000000020?ooo`<00000
1P3oool6000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0000003oool00`0000020?ooo`050000003oool000000?ooo`000000803oool00200
oooo1@0000020?ooo`80000000<0oooo0000000000000`0000040?ooo`030000003oool0oooo00@0
oooo0P0000000`3oool00000000000070?ooo`8000001P3oool00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0000003oool0100000000`3oool000000?ooo`03000003D0oooo1@0000001@3o
ool00000000000000000oooo00D00000103oool00`000000oooo0?ooo`040?ooo`80000000<0oooo
0000003oool01`3oool2000000H0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`00
0000oooo00@0000000<0oooo0000003oool00`00000e0?ooo`D0000000D0oooo0000000000000000
0?ooo`05000000@0oooo00<000000?ooo`3oool0103oool010000000oooo0000000000080?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`000000oooo
00@0000000<0oooo0000003oool00`00000P0?ooo`00803oool3000000030?ooo`000000oooo00H0
00000P3oool01@000000oooo0?ooo`3oool0000000H0oooo0`00000:0?ooo`030000003oool0oooo
00D0oooo0P00000i0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`L0000000@0oooo0000000000000000=@3o
ool3000000030?ooo`000000oooo00H000000P3oool01@000000oooo0?ooo`3oool0000000H0oooo
0`00000:0?ooo`030000003oool0oooo00D0oooo0P00000i0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`L0
000000@0oooo0000000000000000=@3oool3000000030?ooo`000000oooo00D000000`3oool01@00
0000oooo0?ooo`3oool0000000H0oooo0P00000;0?ooo`030000003oool0oooo00D0oooo0P00000i
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0000003oool01P0000000`3oool000000000000Q0?ooo`00803oool3
000000030?ooo`000000oooo00H0000000<0oooo0000000000000`3oool00`000000oooo0?ooo`04
0?ooo`<000002P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool0oooo1@0000000`3oool000000?ooo`03000003D0oooo0`0000000`3oool000000?oo
o`06000000030?ooo`000000000000<0oooo00<000000?ooo`3oool0103oool3000000X0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`3oool2000000<0oooo1P0000020?ooo`<00000
=@3oool3000000030?ooo`000000oooo00D000000P3oool2000000<0oooo00<000000?ooo`3oool0
103oool2000000/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool200000080
oooo00<000000?ooo`000000100000020?ooo`8000008@3oool00200oooo0`0000000`3oool00000
00000003000000040?ooo`000000oooo0?ooo`8000000`3oool00`000000oooo0?ooo`040?ooo`<0
00002@3oool2000000P0oooo0P00000h0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<0000000D0oooo0000
003oool000000?ooo`03000003D0oooo0`0000000`3oool0000000000003000000040?ooo`000000
oooo0?ooo`8000000`3oool00`000000oooo0?ooo`040?ooo`<000002@3oool2000000P0oooo0P00
000h0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`3oool2000000<0oooo1P0000020?ooo`<00000=@3oool3000000030?ooo`000000000000<00000
00@0oooo0000003oool0oooo0P0000030?ooo`030000003oool0oooo00@0oooo0P00000:0?ooo`80
0000203oool2000003P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`04
0000003oool0oooo0?ooo`8000000P3oool00`000000oooo00000004000000040?ooo`0000000000
00000240oooo000P0?ooo`<0000000P0oooo00000000000000000?ooo`000000oooo00000080oooo
0P0000030?ooo`030000003oool0oooo00@0oooo0`0000090?ooo`8000002@3oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`080000003oool0oooo0?ooo`000000oooo0000003oool6000003H0oooo0`000000
203oool00000000000000000oooo0000003oool000000P3oool2000000<0oooo00<000000?ooo`3o
ool0103oool3000000T0oooo0P0000090?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`8000000`3oool01`00
0000oooo000000000000oooo0000003oool00`00000f0?ooo`<0000000P0oooo0000000000000000
0?ooo`000000oooo00000080oooo0P0000030?ooo`030000003oool0oooo00@0oooo0P00000:0?oo
o`8000002@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0103oool010000000oooo0?ooo`3oool200000080oooo00<000000?ooo`0000000P000000
0`3oool000000?ooo`0300000240oooo000P0?ooo`T0000000@0oooo0000003oool0oooo0P000003
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`0000000000203oool00`000000oooo0?oo
o`080?ooo`800000>03oool00`000000oooo0?ooo`080?ooo`8000001`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00@000000?ooo`000000oooo1P00000f0?ooo`T0000000@0oooo0000003o
ool0oooo0P0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000002@3oool00`00
0000oooo0?ooo`080?ooo`800000>03oool00`000000oooo0?ooo`080?ooo`8000001`3oool00`00
0000oooo0?ooo`02000000<0oooo00D000000?ooo`00000000000?ooo`05000003H0oooo2@000000
103oool000000?ooo`3oool2000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0000
00090?ooo`030000003oool0oooo00P0oooo0P00000g0?ooo`030000003oool0oooo00T0oooo0P00
00070?ooo`030000003oool0oooo008000000P3oool00`000000oooo00000002000000030?ooo`00
0000000000<000008@3oool00240oooo0P0000000`3oool0000000000003000000040?ooo`000000
oooo0?ooo`8000000P3oool2000000H0oooo00@000000?ooo`0000000000203oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0203oool00`000000oooo
000000060?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0000003oool20000
0080oooo0P00000g0?ooo`80000000<0oooo0000000000000`000000103oool000000?ooo`3oool2
00000080oooo0P0000060?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000001P3oool0
0`000000oooo0?ooo`02000000<0oooo00@000000?ooo`000000oooo0P000000103oool000000000
0000000g0?ooo`80000000<0oooo0000000000000`000000103oool000000?ooo`3oool200000080
oooo0P0000060?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000001P3oool00`000000
oooo0?ooo`02000000<0oooo0`000000103oool000000000003oool300000240oooo000Q0?ooo`D0
000000@0oooo0000003oool000000`3oool200000080oooo0P0000060?ooo`040000003oool00000
000000L0oooo0P00000<0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo000000060?ooo`040000003oool0oooo0?ooo`8000000P3oool00`000000oooo0000
00020?ooo`030000003oool0oooo00800000=`3oool5000000040?ooo`000000oooo000000<0oooo
0P0000020?ooo`8000001@3oool2000000030?ooo`000000oooo00L0oooo0P00000<0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool0203oool00`000000oooo000000060?ooo`060000
003oool0oooo0000003oool000000P3oool00`000000oooo000000020?ooo`030000003oool00000
00800000=`3oool5000000040?ooo`000000oooo000000<0oooo0P0000020?ooo`8000001@3oool2
000000030?ooo`000000oooo00L0oooo0P00000<0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool0203oool00`000000oooo000000060?ooo`060000003oool0oooo0000003oool00000
0P3oool300000080oooo00<000000?ooo`0000000P00000Q0?ooo`008@3oool5000000040?ooo`00
0000oooo000000<0oooo00D000000?ooo`000000oooo000000070?ooo`040000003oool0oooo0000
00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`0000001P3oool01P000000oooo0?ooo`000000oooo00000080oooo0P00
00001@3oool000000?ooo`000000oooo00<00000=`3oool7000000030?ooo`000000oooo0080oooo
00D000000?ooo`000000oooo000000060?ooo`80000000<0oooo0000000000001`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0203oool00`000000
oooo000000060?ooo`060000003oool0oooo0000003oool000000P3oool2000000050?ooo`000000
oooo0000003oool00`00000g0?ooo`L0000000<0oooo0000003oool00P3oool01@000000oooo0000
003oool0000000H0oooo0P0000000`3oool00000000000070?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`080?ooo`030000003oool0000000H0oooo
00H000000?ooo`3oool000000?ooo`0000020?ooo`80000000D0oooo0000003oool000000?ooo`03
00000240oooo000R0?ooo`80000000H0oooo00000000000000000?ooo`0000030?ooo`050000003o
ool000000?ooo`0000001`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000H0
oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003oool000000?ooo`@00000>@3o
ool2000000030?ooo`00000000000080oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000001P3oool200000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo03D0oooo00<000000?ooo`3oool01`3oool00`000000oooo000000060?oo
o`060000003oool0oooo0000003oool000000`3oool010000000oooo0000003oool4000003P0oooo
1P0000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000H0oooo0P000002
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000001P3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00@000000?ooo`000000oooo1000000R0?ooo`008P3oool500000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo000000060?ooo`8000000P3oool2000000D0
oooo0P00000?0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool01`3oool00`000000
oooo000000060?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`00
00020?ooo`800000>@3oool5000000030?ooo`00000000000080oooo00H000000?ooo`3oool00000
0?ooo`0000060?ooo`040000003oool0oooo0?ooo`8000001@3oool2000000l0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`070?ooo`030000003oool0000000H0oooo00<000000?oo
o`0000000P3oool01P000000oooo0?ooo`3oool000000?ooo`8000000P3oool2000003T0oooo1@00
00000`3oool00000000000020?ooo`060000003oool0oooo0000003oool000001P3oool010000000
oooo0?ooo`3oool2000000D0oooo0P00000?0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool0203oool00`000000oooo000000060?ooo`030000003oool000000080oooo00H000000?oo
o`3oool0oooo0000003oool200000080oooo0P00000R0?ooo`008`3oool010000000oooo0?ooo`00
00020?ooo`80000000@0oooo0000003oool0oooo0`0000060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000060?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02000003T0oooo0P000002
0?ooo`040000003oool0000000000080oooo00<000000?ooo`3oool00`0000060?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000060?ooo`030000
003oool0000000<0oooo00D000000?ooo`3oool000000?ooo`0200000080oooo0P00000i0?ooo`80
000000@0oooo000000000000oooo0P0000020?ooo`030000003oool0oooo00<000001P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000001P3oool0
0`000000oooo000000030?ooo`050000003oool0oooo0000003oool00P0000020?ooo`8000008P3o
ool002<0oooo100000000`3oool0000000000003000000<0oooo0P0000060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000070?ooo`8000000`3o
ool010000000oooo0000000000020?ooo`040000003oool00000000003/0oooo10000000103oool0
00000000003oool2000000<0oooo0P0000050?ooo`800000103oool00`000000oooo0?ooo`020?oo
o`8000004P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00H0oooo00@000000?oo
o`3oool000001`3oool2000000<0oooo00@000000?ooo`00000000000P3oool010000000oooo0000
0000000k0?ooo`@0000000@0oooo000000000000oooo0P0000030?ooo`8000001@3oool2000000@0
oooo00<000000?ooo`3oool00P3oool200000180oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`060?ooo`040000003oool0oooo000000L0oooo0P0000030?ooo`040000003oool00000
00000080oooo00@000000?ooo`00000000008`3oool002@0oooo00<000000?ooo`0000000P000000
0`3oool00000000000040?ooo`8000001@3oool00`000000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`0000004`3oool2000003<0oooo00<000000?ooo`3oool01P3oool010000000oooo0?oo
o`0000070?ooo`8000000`3oool010000000oooo0000000000020?ooo`@00000?03oool01@000000
oooo000000000000oooo00<00000103oool2000000D0oooo00<000000?ooo`3oool0103oool01@00
0000oooo0?ooo`3oool0000001<0oooo0P00000c0?ooo`030000003oool0oooo00H0oooo00@00000
0?ooo`3oool000001`3oool2000000<0oooo00@000000?ooo`00000000000P3oool4000003`0oooo
00D000000?ooo`00000000000?ooo`03000000@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo008000004`3oool2000003<0oooo00<000000?ooo`3o
ool01P3oool010000000oooo0?ooo`0000070?ooo`8000000`3oool010000000oooo000000000002
0?ooo`@000008`3oool002D0oooo0`0000020?ooo`800000103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo1000000D0?ooo`800000<`3oool00`000000oooo0?ooo`050?oo
o`050000003oool0oooo0?ooo`0000001P3oool2000000<0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000?@3oool400000080oooo0P0000040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool3000001D0oooo0P00000c0?ooo`030000003oool0oooo00D0
oooo00D000000?ooo`3oool0oooo000000060?ooo`8000000`3oool02@000000oooo0000003oool0
00000?ooo`000000oooo0000000m0?ooo`@000000P3oool2000000@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`<000005@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000060?ooo`8000000`3oool02@000000
oooo0000003oool000000?ooo`000000oooo0000000T0?ooo`009P3oool200000080oooo0P000003
0?ooo`<000001@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo0P000003
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000003h0oooo0`0000020?ooo`80
00000`3oool3000000D0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`80
00000`3oool02@000000oooo0000003oool000000?ooo`000000oooo0000000n0?ooo`<000000P3o
ool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00@0oooo0P0000030?ooo`060000003oool000000?ooo`000000oooo0`00000T0?ooo`00
:03oool010000000oooo0000000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo000000020?ooo`04
0000003oool0oooo00000440oooo00@000000?ooo`00000000000`3oool00`000000oooo00000004
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool2000000<0oooo00<00000
0?ooo`0000000P3oool010000000oooo0?ooo`0000110?ooo`040000003oool00000000000<0oooo
00<000000?ooo`000000103oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
0P0000030?ooo`040000003oool000000?ooo`80000000<0oooo000000000000903oool002P0oooo
0P0000000`3oool000000?ooo`020?ooo`040000003oool00000000000<0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`070000003oool0oooo0?ooo`000000oooo00000002
0?ooo`<00000@P3oool2000000030?ooo`000000oooo0080oooo00@000000?ooo`00000000000`3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo0`0000120?ooo`80000000<0oooo0000003oool00P3oool00`000000
oooo000000040?ooo`030000003oool0oooo0200oooo0P00000a0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000
oooo000000020?ooo`<000009@3oool002`0oooo00@000000?ooo`00000000000P3oool00`000000
oooo0?ooo`02000002@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0103oool2000000@0oooo0P0000020?ooo`<0
0000AP3oool00`000000oooo000000030?ooo`030000003oool0oooo00800000903oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`800000103oool200000080oooo0`0000150?ooo`80000000<0oooo0000003o
ool00P3oool00`000000oooo0?ooo`02000002<0oooo0P00000`0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo0P0000020?ooo`<000009@3oool002d0oooo0P0000040?ooo`<000009P3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`800000103oool200000080oooo0P0000180?ooo`800000103oool3000002H0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool2000000@0oooo0P0000020?ooo`800000B03oool00`000000oooo
0?ooo`020?ooo`@000009@3oool200000300oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool200000080oooo
0P00000V0?ooo`00G@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`800000103oool2000000040?ooo`00
0000oooo000007P0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P000000103oool00000
0?ooo`00001g0?ooo`800000;`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P000000103oool000000?ooo`00000V0?oo
o`00GP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`800000103oool4000000030?ooo`000000oooo07P0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool2000000@0oooo100000000`3oool000000?ooo`1g0?ooo`80
0000;P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool2000000@0oooo100000000`3oool000000?ooo`0U0?ooo`00G`3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P00001k0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo00000002000007X0oooo
0P00000]0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P00000W0?ooo`00H03o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`1l0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo07/0oooo0P00000/0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0W0?ooo`00H@3oool00`000000oooo0?ooo`0Z0?ooo`050000003o
ool0oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo02X0oooo00D000000?ooo`3o
ool0oooo000000070?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo00000002
0?ooo`030000003oool0oooo07`0oooo0P00000/0?ooo`050000003oool0oooo0?ooo`0000001`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`0W0?ooo`00HP3oool00`000000oooo0?ooo`0Y0?ooo`040000003oool0oooo000000T0oooo
00@000000?ooo`3oool000000`3oool2000000<0oooo00<000000?ooo`3oool0OP3oool00`000000
oooo0?ooo`0Y0?ooo`040000003oool0oooo000000T0oooo00@000000?ooo`3oool000000`3oool2
00000080oooo00<000000?ooo`3oool0OP3oool2000002/0oooo00@000000?ooo`3oool000002@3o
ool010000000oooo0?ooo`0000030?ooo`8000000P3oool00`000000oooo0?ooo`0X0?ooo`00H`3o
ool00`000000oooo0?ooo`0X0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`000000
1@3oool2000000030?ooo`000000oooo0840oooo00<000000?ooo`3oool0:03oool010000000oooo
0?ooo`0000090?ooo`030000003oool0000000D0oooo0P0000000`3oool000000?ooo`210?ooo`03
0000003oool0oooo02P0oooo00@000000?ooo`3oool000002@3oool00`000000oooo000000050?oo
o`80000000<0oooo0000003oool0:@3oool006@0oooo00<000000?ooo`3oool09`3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0000000D0oooo00<000000?ooo`000000Q03oool00`00
0000oooo0?ooo`0W0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`0000001@3oool0
0`000000oooo000000240?ooo`030000003oool0oooo02L0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo000000040?ooo`040000003oool0oooo000002/0oooo001U0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`0000002P3oool2000000D0oooo00<000000?ooo`3oool0Q@3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0000000T0oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`250?ooo`030000003oool0oooo02L0oooo00<000000?ooo`0000002@3o
ool00`000000oooo000000040?ooo`030000003oool0oooo02`0oooo001V0?ooo`030000003oool0
oooo02H0oooo0P00000;0?ooo`800000103oool00`000000oooo0?ooo`270?ooo`030000003oool0
oooo02H0oooo0P00000;0?ooo`800000103oool00`000000oooo0?ooo`270?ooo`030000003oool0
oooo02H0oooo0P00000;0?ooo`800000103oool00`000000oooo0?ooo`0/0?ooo`00I`3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`280?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;03oool006P0
oooo00<000000?ooo`3oool0903oool2000000/0oooo0`0000000`3oool000000000002<0?ooo`03
0000003oool0oooo02@0oooo0P00000;0?ooo`<0000000<0oooo000000000000S03oool00`000000
oooo0?ooo`0T0?ooo`8000002`3oool3000000030?ooo`000000000002l0oooo001Y0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`0000002P3oool010000000oooo0?ooo`00002?0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`0000002P3oool010000000oooo0?ooo`00002?0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`0000002P3oool010000000oooo0?ooo`00000a
0?ooo`00JP3oool00`000000oooo0?ooo`0Q0?ooo`050000003oool0oooo0?ooo`000000203oool0
0`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo00D000000?ooo`3oool0oooo0000
00080?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool08@3oool01@000000oooo0?oo
o`3oool0000000P0oooo00<000000?ooo`3oool0<`3oool006/0oooo00<000000?ooo`3oool0803o
ool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo
0?ooo`0P0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`2C0?ooo`03
0000003oool0oooo0200oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo
03<0oooo001/0?ooo`8000007`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0U@3oool2000001l0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo09D0oooo0P00000O0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0d0?ooo`00KP3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`030000003oool0oooo09P0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo
0?ooo`2H0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0103oool2000000<0oooo
00<000000?ooo`3oool0=@3oool006l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`070?ooo`<00000W03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00L0oooo0`00
002L0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01`3oool3000003P0oooo001`
0?ooo`030000003oool0oooo01P0oooo0P00002Y0?ooo`030000003oool0oooo01P0oooo0P00002Y
0?ooo`030000003oool0oooo01P0oooo0P0000140?ooo`00L@3oool2000001P0oooo00<000000?oo
o`3oool0Z@3oool2000001P0oooo00<000000?ooo`3oool0Z@3oool2000001P0oooo00<000000?oo
o`3oool0@`3oool007<0oooo0P00000E0?ooo`800000[@3oool2000001D0oooo0P00002]0?ooo`80
00005@3oool2000004D0oooo001d0?ooo`800000503oool00`000000oooo0?ooo`2]0?ooo`800000
503oool00`000000oooo0?ooo`2]0?ooo`800000503oool00`000000oooo0?ooo`140?ooo`00MP3o
ool200000140oooo00<000000?ooo`3oool0/03oool200000140oooo00<000000?ooo`3oool0/03o
ool200000140oooo00<000000?ooo`3oool0A@3oool007L0oooo0P00000?0?ooo`030000003oool0
oooo0;80oooo0P00000?0?ooo`030000003oool0oooo0;80oooo0P00000?0?ooo`030000003oool0
oooo04H0oooo001h0?ooo`<00000303oool00`000000oooo0?ooo`2d0?ooo`<000002`3oool20000
0;H0oooo0`00000;0?ooo`800000B@3oool007X0oooo0`0000080?ooo`800000^@3oool3000000P0
oooo0P00002i0?ooo`<00000203oool2000004X0oooo001m0?ooo`P00000_P3oool800000;h0oooo
2000001<0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?oo
o`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo
0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo
003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0
ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool0
0?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3o
oomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00
o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oo
oel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o
0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0oooo
G`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0
ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO
0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3o
oooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0
oooo003o0?ooool0ooooG`3oool004`0oooo1`00002o0?ooo`L00000_`3oool7000007h0oooo001:
0?ooo`8000001`3oool300000;X0oooo0P0000070?ooo`<00000^P3oool2000000L0oooo0`00001k
0?ooo`00B@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0;H0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0N03oool004P0oooo00<000000?ooo`3oool0303oool200000;@0oooo0P00000>0?ooo`80
0000]03oool2000000h0oooo0P00001h0?ooo`00AP3oool200000140oooo0P00002a0?ooo`800000
4@3oool200000;40oooo0P00000A0?ooo`800000MP3oool004D0oooo0P00000D0?ooo`030000003o
ool0oooo0:d0oooo0P00000D0?ooo`030000003oool0oooo0:d0oooo0P00000D0?ooo`030000003o
ool0oooo07<0oooo00150?ooo`030000003oool0oooo01@0oooo0P00002]0?ooo`030000003oool0
oooo01@0oooo0P00002]0?ooo`030000003oool0oooo01@0oooo0P00001c0?ooo`00A03oool00`00
0000oooo0?ooo`0F0?ooo`800000Z`3oool00`000000oooo0?ooo`0F0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0F0?ooo`800000LP3oool004@0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`2X0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0Z03oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo06l0oooo000h0?ooo`<00000203oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo09/0oooo0`0000080?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0V`3oool3000000P0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`1^0?ooo`00=P3oool300000080oooo0P0000060?ooo`030000003oool0oooo01/0oooo0P00
002I0?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01/0oooo0P00
002I0?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01/0oooo0P00
001^0?ooo`00=P3oool00`000000oooo0?ooo`030?ooo`800000103oool00`000000oooo0?ooo`0M
0?ooo`800000V03oool00`000000oooo0?ooo`030?ooo`800000103oool00`000000oooo0?ooo`0M
0?ooo`800000V03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool07@3oool2000006d0oooo000e0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0N0?ooo`800000UP3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool2000009H0oooo00<000000?oo
o`3oool0103oool2000000@0oooo00<000000?ooo`3oool07P3oool2000006`0oooo000d0?ooo`80
0000203oool00`000000oooo0?ooo`0200000280oooo00<000000?ooo`3oool0TP3oool2000000P0
oooo00<000000?ooo`3oool00P00000R0?ooo`030000003oool0oooo0980oooo0P0000070?ooo`80
00000P3oool200000280oooo00<000000?ooo`3oool0J@3oool00300oooo0P0000020?ooo`030000
003oool0oooo00L0oooo0P0000000`3oool000000?ooo`0S0?ooo`030000003oool0oooo08d0oooo
0P0000020?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000903oool00`000000
oooo0?ooo`2=0?ooo`8000000P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0000
02@0oooo00<000000?ooo`3oool0J03oool002l0oooo100000000`3oool000000?ooo`090?ooo`03
0000003oool0000002D0oooo00<000000?ooo`3oool0R`3oool4000000030?ooo`000000oooo00T0
oooo00<000000?ooo`0000009@3oool00`000000oooo0?ooo`2;0?ooo`@0000000<0oooo0000003o
ool0203oool2000000030?ooo`000000oooo02@0oooo00<000000?ooo`3oool0I`3oool002h0oooo
00<000000?ooo`3oool00P3oool2000000X0oooo0P00000W0?ooo`030000003oool0oooo08T0oooo
00<000000?ooo`3oool00P3oool2000000X0oooo0P00000W0?ooo`030000003oool0oooo08T0oooo
00<000000?ooo`3oool00P3oool2000000X0oooo0P00000W0?ooo`030000003oool0oooo06H0oooo
000]0?ooo`030000003oool0oooo00<0oooo0P00000;0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0Q`3oool00`000000oooo0?ooo`030?ooo`8000002P3oool2000002P0oooo00<0
00000?ooo`3oool0Q`3oool00`000000oooo0?ooo`030?ooo`8000002P3oool2000002P0oooo00<0
00000?ooo`3oool0I@3oool002`0oooo0P0000040?ooo`<000002P3oool2000002T0oooo00<00000
0?ooo`3oool0Q@3oool2000000@0oooo0`00000:0?ooo`800000:@3oool00`000000oooo0?ooo`25
0?ooo`800000103oool3000000X0oooo0P00000Y0?ooo`030000003oool0oooo06@0oooo000[0?oo
o`8000001@3oool00`000000oooo0000000:0?ooo`030000003oool0000002T0oooo00<000000?oo
o`3oool0P`3oool2000000D0oooo00<000000?ooo`0000002P3oool3000002T0oooo00<000000?oo
o`3oool0P`3oool2000000D0oooo00<000000?ooo`0000002P3oool3000002T0oooo00<000000?oo
o`3oool0H`3oool002T0oooo0P0000000`3oool00000000000040?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`200?ooo`80000000<0oooo0000
00000000103oool010000000oooo0?ooo`0000090?ooo`030000003oool0000002X0oooo00<00000
0?ooo`3oool0P03oool2000000030?ooo`000000oooo00@0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0000000Z0?ooo`030000003oool0oooo0680oooo000Y0?ooo`030000003oool0
oooo00800000103oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00800000:P3o
ool2000007l0oooo0P0000020?ooo`800000103oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo00800000:P3oool2000007l0oooo0P0000020?ooo`800000103oool010000000oooo
0?ooo`0000080?ooo`030000003oool0oooo00800000:P3oool200000680oooo000X0?ooo`800000
00D0oooo000000000000oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01@3oool01@000000oooo0?ooo`3oool0000002/0oooo0P00001n0?ooo`030000003oool0oooo
0080000000D0oooo0000003oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00D00000
0?ooo`3oool0oooo0000000[0?ooo`800000OP3oool00`000000oooo0?ooo`02000000050?ooo`00
0000oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`00
0000:`3oool200000640oooo000X0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000;03oool2
000007d0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000000/0?ooo`800000O@3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool0
1@000000oooo0?ooo`3oool0000002`0oooo0P00001P0?ooo`009`3oool200000080oooo00<00000
0?ooo`3oool00P0000000`3oool000000?ooo`030?ooo`030000003oool0oooo00@0oooo0P000003
0?ooo`800000;03oool2000007/0oooo0P0000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`8000000`3oool2000002`0oooo0P00
001k0?ooo`8000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`800000;03oool2000005l0oooo
000V0?ooo`80000000@0oooo00000000000000000`3oool3000000@0oooo0P0000050?ooo`030000
003oool0oooo0080oooo0P00000]0?ooo`800000N@3oool2000000040?ooo`000000000000000080
oooo100000040?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`800000;@3oool2000007T0
oooo0P000000103oool000000000000000020?ooo`@00000103oool2000000D0oooo00<000000?oo
o`3oool00P3oool2000002d0oooo0P00001N0?ooo`009@3oool00`000000oooo000000020?ooo`03
0000003oool0oooo0080oooo0P0000050?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0M@3oool00`000000oooo000000020?ooo`03
0000003oool0oooo0080oooo0P0000050?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0M@3oool00`000000oooo000000020?ooo`03
0000003oool0oooo0080oooo0P0000050?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0F`3oool002D0oooo0`0000020?ooo`030000
003oool0oooo0080oooo0P0000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02@0oooo0`0000050?ooo`030000
003oool0oooo04D0oooo0`0000020?ooo`030000003oool0oooo0080oooo0P0000060?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo02@0oooo0`0000050?ooo`030000003oool0oooo04D0oooo0`0000020?ooo`030000
003oool0oooo0080oooo0P0000060?ooo`030000003oool0oooo0080oooo0P0000050?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool0903oool3000000@0oooo00<000000?ooo`3oool0
;03oool002D0oooo0P0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0R0?ooo`040000003oool0oooo000000<0oooo100000150?ooo`<00000
0`3oool00`000000oooo0?ooo`020?ooo`8000001P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0R0?ooo`040000
003oool0oooo000000<0oooo100000150?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`80
00001P3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo0280oooo00@000000?ooo`3oool000000`3oool4000002`0oooo000T0?ooo`<0
00000P3oool3000000@0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`3oool20000
00D0oooo0P00000a0?ooo`030000003oool0oooo0240oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo0?ooo`<00000@P3oool300000080oooo0`0000030?ooo`8000001P3o
ool2000000<0oooo0P0000050?ooo`800000<@3oool00`000000oooo0?ooo`0Q0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`000000oooo00800000@P3oool300000080
oooo0`0000030?ooo`8000001P3oool2000000<0oooo00<000000?ooo`3oool0103oool200000340
oooo00<000000?ooo`3oool08@3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool000000?ooo`02000002T0oooo000S0?ooo`80000000L0oooo000000000000oooo0000003o
ool0000000<0oooo0`0000060?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool00`3oool2000000@0oooo
0P0000000`3oool000000?ooo`0o0?ooo`80000000L0oooo000000000000oooo0000003oool00000
00<0oooo0`0000050?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`030?ooo`800000103oool20000
00030?ooo`000000oooo03l0oooo1@000000103oool000000?ooo`0000030?ooo`<000001@3oool2
000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000000`3oool000000?ooo`0W
0?ooo`008`3oool2000000060?ooo`00000000000?ooo`000000oooo0P0000020?ooo`<000001P3o
ool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0<03oool200000200oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`80
0000?P3oool2000000070?ooo`00000000000?ooo`000000oooo000000030?ooo`<000001P3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0<03oool200000200oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<00000?P3o
ool5000000040?ooo`000000oooo000000<0oooo0`0000060?ooo`050000003oool0oooo0?ooo`00
00001`3oool00`000000oooo0?ooo`0`0?ooo`800000803oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`00000V0?ooo`008`3oool2000000030?oo
o`0000000000008000000P3oool00`000000oooo0?ooo`03000000H0oooo00D000000?ooo`3oool0
oooo000000070?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool04`3oool4000000H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`8000000P3oool00`000000
oooo0000000m0?ooo`80000000<0oooo0000000000000P0000000`3oool00000000000020?ooo`03
0000003oool0000000H0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool04`3oool4000000H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000003oool000000080oooo00<000000?ooo`000000?@3oool70000
00030?ooo`00000000000080oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`020000
00L0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0C0?ooo`@000001P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P0000030?ooo`8000009P3oool00280
oooo1@0000000`3oool00000000000020?ooo`060000003oool0oooo0000003oool000001P3oool2
00000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool00P0000050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0000003oool2000000030?ooo`000000oooo03/0oooo1@00
00000`3oool00000000000020?ooo`060000003oool0oooo0000003oool000001P3oool01@000000
oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo008000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo00@000000?ooo`000000oooo0P0000000`3oool000000?ooo`0k0?ooo`@000000P3oool2
00000080oooo00H000000?ooo`3oool000000?ooo`0000060?ooo`030000003oool0oooo00800000
1`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P0000020?ooo`80
000000<0oooo0000003oool0903oool00280oooo0P000000103oool000000000003oool200000080
oooo00H000000?ooo`3oool000000?ooo`0000060?ooo`80000000<0oooo0000000000001`3oool2
000003@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool2000000<0oooo00H000000?ooo`000000oooo0000
003oool3000003/0oooo0P000000103oool000000?ooo`3oool200000080oooo00H000000?ooo`3o
ool000000?ooo`0000060?ooo`030000003oool0oooo008000001`3oool2000003@0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool2000000<0oooo00@000000?ooo`00000000000P3oool3000003/0oooo0P00
0000103oool000000?ooo`3oool200000080oooo00H000000?ooo`3oool000000?ooo`0000060?oo
o`030000003oool0oooo008000001`3oool2000003@0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool20000
00<0oooo00@000000?ooo`00000000000P3oool3000002@0oooo000R0?ooo`80000000@0oooo0000
00000000oooo0P0000020?ooo`060000003oool0oooo0000003oool000001`3oool010000000oooo
0000000000080?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool2000000<0
oooo00@000000?ooo`00000000000P3oool010000000oooo00000000000j0?ooo`80000000@0oooo
000000000000oooo0P0000020?ooo`060000003oool0oooo0000003oool000001P3oool200000003
0?ooo`000000000000P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`80
00000`3oool010000000oooo0000000000020?ooo`040000003oool00000000003X0oooo0P000000
103oool000000000003oool200000080oooo00H000000?ooo`3oool000000?ooo`0000060?ooo`80
000000<0oooo000000000000203oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo0P0000030?ooo`040000003oool0000000000080oooo00@000000?ooo`00000000008`3oool0
0240oooo0`000000103oool000000000003oool200000080oooo100000000`3oool000000?ooo`06
0?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0<`3oool2000000l0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00H00000
0?ooo`3oool000000?ooo`0000030?ooo`050000003oool0oooo0000003oool00P00000i0?ooo`<0
000000@0oooo000000000000oooo0P0000020?ooo`@0000000<0oooo0000003oool01P3oool00`00
0000oooo000000090?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo00000000
000i0?ooo`<0000000@0oooo000000000000oooo0P0000020?ooo`@0000000<0oooo0000003oool0
1P3oool00`000000oooo000000090?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo00000000000S0?ooo`008@3oool6000000030?ooo`00000000000080oooo100000000`3oool0
00000?ooo`060?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000060?oo
o`060000003oool0oooo0000003oool000000`3oool00`000000oooo00000005000003P0oooo1P00
00000`3oool00000000000020?ooo`@0000000<0oooo0000003oool01P3oool00`000000oooo0000
00090?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo000000020?ooo`060000
003oool0oooo0?ooo`000000oooo1P00000h0?ooo`H0000000<0oooo0000000000000P3oool40000
00030?ooo`000000oooo00H0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0
000000H0oooo00<000000?ooo`0000000P3oool01P000000oooo0?ooo`3oool000000?ooo`H00000
8P3oool00240oooo0`0000000`3oool0000000000003000000<0oooo0P0000030?ooo`030000003o
ool0oooo00@0oooo0`0000090?ooo`800000=P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00D0oooo00D000000?ooo`3oool0oooo000000060?ooo`060000003oool0oooo0000003o
ool000000P3oool2000000030?ooo`000000oooo00@00000>03oool3000000030?ooo`0000000000
00<000000`3oool2000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo000000090?oo
o`800000=P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo000000060?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P000000
0`3oool000000?ooo`04000003P0oooo0`0000000`3oool0000000000003000000<0oooo0P000003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000002@3oool2000003H0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000001P3o
ool00`000000oooo000000020?ooo`030000003oool0oooo00<000000P3oool400000280oooo000Q
0?ooo`80000000@0oooo000000000000oooo0`0000030?ooo`8000000`3oool00`000000oooo0?oo
o`040?ooo`<000002P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01P3oool010000000oooo0?ooo`0000060?ooo`060000003oool0oooo0000003o
ool000000P3oool2000000030?ooo`000000000000@00000>03oool2000000040?ooo`0000000000
0?ooo`<000000`3oool2000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000:
0?ooo`030000003oool0oooo03@0oooo0P00000<0?ooo`030000003oool0oooo00D0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`060000003oool0oooo0000003oool000000P3oool200000003
0?ooo`000000000000@00000>03oool2000000040?ooo`00000000000?ooo`<000000`3oool20000
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000:0?ooo`030000003oool0oooo
03@0oooo0P00000<0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`060000003oool0oooo0000003oool000000P3oool3000000030?ooo`000000000000<00000
8P3oool00240oooo0P000000103oool000000000003oool2000000040?ooo`000000oooo0?ooo`80
00000`3oool00`000000oooo0?ooo`040?ooo`<000002P3oool00`000000oooo0?ooo`0e0?ooo`80
00002`3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000D0oooo00@000000?oo
o`3oool0oooo0P0000030?ooo`80000000<0oooo0000000000001@00000g0?ooo`80000000@0oooo
000000000000oooo0P000000103oool000000?ooo`3oool2000000<0oooo00<000000?ooo`3oool0
103oool3000000X0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00H0oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`3oool20000
00<0oooo0P0000000`3oool0000000000005000003L0oooo0P000000103oool000000000003oool2
000000040?ooo`000000oooo0?ooo`8000000`3oool00`000000oooo0?ooo`040?ooo`<000002P3o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3o
ool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo0?ooo`8000000`3oool300000003
0?ooo`000000000000@000008@3oool00200oooo2@000000103oool000000?ooo`3oool2000000<0
oooo00<000000?ooo`3oool0103oool3000000X0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo0P0000060?ooo`040000003oool0oooo0?oo
o`8000000`3oool3000000030?ooo`000000000000@00000=P3oool9000000040?ooo`000000oooo
0?ooo`8000000`3oool00`000000oooo0?ooo`040?ooo`<000002P3oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo00000006
0?ooo`040000003oool0oooo0?ooo`8000000`3oool:000003H0oooo1@0000001P3oool000000000
00000000oooo00000080oooo0P0000030?ooo`030000003oool0oooo00@0oooo0`00000:0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`03
0000003oool0000000H0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`X000008@3oool00200
oooo2@000000103oool000000?ooo`3oool2000000<0oooo00<000000?ooo`3oool0103oool20000
00/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo0P0000060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0`000000
103oool000000000003oool3000003H0oooo2@000000103oool000000?ooo`3oool2000000<0oooo
00<000000?ooo`3oool0103oool2000000/0oooo00<000000?ooo`3oool0=P3oool2000000T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo000000060?ooo`040000003oool0oooo0?ooo`80
00000`3oool6000000040?ooo`0000000000000003H0oooo2@000000103oool000000?ooo`3oool2
000000<0oooo00<000000?ooo`3oool0103oool2000000/0oooo00<000000?ooo`3oool0=P3oool2
000000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo000000060?ooo`040000003oool0
oooo0?ooo`8000000`3oool6000000040?ooo`000000000000000240oooo000P0?ooo`<0000000<0
oooo0000000000000`000000103oool000000?ooo`3oool2000000<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`090?ooo`800000>03oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo0P0000060?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool0
oooo0000003oool400000080oooo0P00000f0?ooo`<0000000<0oooo0000000000000`000000103o
ool000000?ooo`3oool2000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`09
0?ooo`800000>03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo0P000006
0?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo0000000300000080oooo0P00
000f0?ooo`<0000000<0oooo0000000000000`000000103oool000000?ooo`3oool2000000<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`800000>03oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo0P0000060?ooo`040000003oool0oooo0?ooo`80
00000`3oool00`000000oooo0000000300000080oooo0P00000Q0?ooo`00803oool3000000030?oo
o`000000000000<0000000@0oooo0000003oool0oooo0P0000040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0203oool2000000H0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`000000oooo00D000000P3oool2000003H0oooo0`0000000`3oool00000000000030000
00040?ooo`000000oooo0?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0=P3oool2000000P0oooo00<000000?ooo`3oool0203oool2
000000H0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`030000003oool000000080000000@0
oooo0000003oool0oooo0P00000f0?ooo`<0000000<0oooo0000000000000`000000103oool00000
0?ooo`3oool2000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`80
00001P3oool010000000oooo0?ooo`3oool200000080oooo00<000000?ooo`0000000P000000103o
ool000000?ooo`3oool200000240oooo000O0?ooo`@0000000<0oooo0000000000000`0000000`3o
ool000000?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`090?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0000000@0oooo000000000000oooo0`00000d0?ooo`@0000000<0oooo0000000000000`000000
0`3oool000000?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`090?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00D0000000@0oooo000000000000oooo0`00000d0?ooo`@0000000<0oooo0000000000000`00
00000`3oool000000?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`090?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0000000@0oooo000000000000oooo0`00000P0?ooo`007`3oool4000000030?ooo`00
0000oooo00<0000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00@0oooo0P00000;0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`80000000<0oooo0000000000001P3oool00`000000oooo0?oo
o`020?ooo`P000000P3oool00`000000oooo00000002000003@0oooo100000000`3oool000000?oo
o`03000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`8000002`3oool00`000000oooo0?ooo`0g0?ooo`8000001P3oool00`000000oooo0?oo
o`060?ooo`80000000<0oooo0000000000001P3oool00`000000oooo0?ooo`020?ooo`@0000000@0
oooo00000000000000000P3oool00`000000oooo00000002000003@0oooo0`0000020?ooo`030000
003oool000000080000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool2000000030?ooo`000000000000H0oooo
00@000000?ooo`3oool0oooo1@000000103oool000000000000000020?ooo`030000003oool00000
00800000803oool001l0oooo0`000000103oool000000000003oool3000000040?ooo`000000oooo
0?ooo`800000103oool00`000000oooo0?ooo`040?ooo`8000002`3oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool6000000D0oooo0`000003
0?ooo`050000003oool0oooo0000003oool00`0000020?ooo`030000003oool0oooo00800000=03o
ool3000000040?ooo`00000000000?ooo`<0000000@0oooo0000003oool0oooo0P0000040?ooo`03
0000003oool0oooo00@0oooo0P00000;0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`H000001@3oool3000000<0oooo00D000000?ooo`3o
ool000000?ooo`0300000080oooo00<000000?ooo`0000000P00000d0?ooo`<0000000@0oooo0000
00000000oooo0`000000103oool000000?ooo`3oool2000000@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03L0oooo0P0000060?ooo`030000003o
ool0oooo00D0oooo1P0000050?ooo`<000000P3oool200000080oooo00<000000?ooo`0000000P00
00020?ooo`030000003oool0000000800000803oool001l0oooo0`000000103oool000000000003o
ool500000080oooo0P0000040?ooo`030000003oool0oooo00<0oooo0`00000;0?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo0P0000050?ooo`80000000<0oooo0000003oool00P0000020?ooo`030000003o
ool0000000<0000000@0oooo0000003oool0oooo0P00000d0?ooo`<0000000@0oooo000000000000
oooo1@0000020?ooo`800000103oool00`000000oooo0?ooo`030?ooo`<000002`3oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`8000001@3oool2000000030?ooo`000000oooo008000000P3oool00`000000
oooo00000003000000030?ooo`000000oooo00<00000=03oool3000000040?ooo`00000000000?oo
o`D000000P3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000`0oooo00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool2000000D0oooo100000000`3oool00000000000020?ooo`030000003oool00000
008000000P3oool00`000000oooo0000000200000200oooo000O0?ooo`<0000000<0oooo0000003o
ool00P3oool5000000030?ooo`000000000000@0oooo00<000000?ooo`3oool00`3oool3000000/0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000020?ooo`040000003oool000000000
0080oooo00<000000?ooo`0000000`000000103oool000000000003oool2000003@0oooo0`000000
103oool000000?ooo`3oool6000000030?ooo`000000000000@0oooo00<000000?ooo`3oool00`3o
ool3000000/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000020?ooo`040000003o
ool0000000000080oooo00<000000?ooo`0000000`0000000`3oool0000000000003000003@0oooo
0`000000103oool000000?ooo`3oool6000000030?ooo`000000000000@0oooo00<000000?ooo`3o
ool00`3oool2000000`0oooo00<000000?ooo`3oool0>03oool2000000D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`800000103oool200000080oooo00@000000?ooo`00
000000000P3oool00`000000oooo00000003000000030?ooo`000000000000<00000803oool001l0
oooo0`000000103oool000000?ooo`3oool4000000030?ooo`000000oooo00<000000`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P0000050?ooo`800000103oool20000
0080oooo00D000000?ooo`00000000000?ooo`07000000040?ooo`00000000000?ooo`800000=03o
ool3000000040?ooo`000000oooo0?ooo`@0000000<0oooo0000003oool00P0000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000D0oooo0P0000040?ooo`800000
0P3oool01@000000oooo000000000000oooo00D0000000<0oooo0000003oool01@00000d0?ooo`<0
000000@0oooo0000003oool0oooo100000000`3oool000000?ooo`02000000@0oooo00<000000?oo
o`3oool00`3oool3000000/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo0P0000050?ooo`800000103oool200000080oooo00D000000?oo
o`00000000000?ooo`05000000030?ooo`000000oooo00D00000803oool001l0oooo1@0000020?oo
o`@0000000H0oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`0000002`3oool2000003X0oooo0P0000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool300000080oooo00<000000?ooo`0000000`3oool3000000030?ooo`00
0000oooo00D0000000@0oooo000000000000oooo0P00000d0?ooo`D000000P3oool4000000030?oo
o`000000oooo00<000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000/0oooo
00<000000?ooo`3oool0>@3oool2000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`<000000P3oool00`000000oooo000000030?ooo`<0000000<0oooo0000003oool0
1@0000000`3oool0000000000003000003@0oooo1@0000000`3oool0000000000003000000030?oo
o`000000oooo00800000103oool00`000000oooo0?ooo`030?ooo`<000002`3oool00`000000oooo
0?ooo`0i0?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
0`0000020?ooo`030000003oool0000000<0oooo0`0000000`3oool000000?ooo`05000000030?oo
o`000000000000<00000803oool001l0oooo1@0000000`3oool0000000000003000000060?ooo`00
0000oooo0000003oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000/0
oooo0P00000k0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`<000000P3oool00`000000oooo000000030?ooo`<0000000@0oooo0000003o
ool0oooo10000000103oool000000000003oool2000003@0oooo1@0000000`3oool0000000000003
000000030?ooo`000000oooo00<000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000/0oooo00<000000?ooo`3oool0>P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0
00000?ooo`3oool0103oool300000080oooo00<000000?ooo`0000000`3oool3000000040?ooo`00
0000oooo0?ooo`@0000000<0oooo0000000000000`00000d0?ooo`D0000000<0oooo0000003oool0
0`0000000`3oool000000?ooo`02000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0000000;0?ooo`030000003oool0oooo03X0oooo00D000000?ooo`3oool0oooo000000050?ooo`03
0000003oool0oooo00@0oooo0`0000020?ooo`030000003oool0000000<0oooo0`0000000`3oool0
00000?ooo`05000000030?ooo`000000000000<00000803oool001l0oooo1@0000000`3oool00000
0?ooo`05000000040?ooo`000000oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0000000;0?ooo`800000>`3oool2000000<0oooo00@000000?ooo`3oool0oooo0P0000060?oo
o`<0000000D0oooo0000003oool0oooo000000030?ooo`<0000000@0oooo0000003oool0oooo0`00
00001@3oool00000000000000000oooo00<00000<`3oool5000000030?ooo`000000oooo00D00000
00@0oooo0000000000000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0000000/0
oooo00<000000?ooo`3oool0>P3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`<0000000D0oooo0000003oool0oooo000000030?ooo`<0000000<0oooo0000
003oool0100000001@3oool00000000000000000oooo00<00000<`3oool5000000030?ooo`000000
oooo00D0000000<0oooo0000000000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000/0oooo00<000000?ooo`3oool0>P3oool200000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`050?ooo`<0000000D0oooo0000003oool0oooo000000030?ooo`<0000000<0
oooo0000003oool0100000001@3oool00000000000000000oooo00<000007`3oool001l0oooo1@00
00000`3oool000000?ooo`05000000040?ooo`000000oooo000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0000000;0?ooo`800000?03oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00D0oooo00D000000?ooo`000000oooo000000020?ooo`040000003oool0oooo
0?ooo`80000000@0oooo000000000000oooo100000000`3oool000000?ooo`05000003<0oooo1@00
00000`3oool000000?ooo`05000000040?ooo`0000000000000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0000000;0?ooo`030000003oool0oooo03/0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`050?ooo`<0000000D0oooo0000003oool0oooo000000030?oo
o`80000000@0oooo000000000000oooo10000000103oool000000000003oool4000003<0oooo1@00
00000`3oool000000?ooo`05000000030?ooo`000000000000D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0000000;0?ooo`030000003oool0oooo03/0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`050?ooo`<0000000D0oooo0000003oool0oooo000000020?ooo`04
0000003oool000000?ooo`80000000<0oooo0000003oool00P000000103oool000000000003oool4
000001l0oooo000O0?ooo`D0000000<0oooo0000003oool00`0000001P3oool00000000000000000
oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000;0?ooo`800000?03o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000
0P0000020?ooo`040000003oool0oooo0?ooo`80000000@0oooo000000000000oooo100000000`3o
ool000000?ooo`05000003<0oooo1@0000000`3oool000000?ooo`03000000060?ooo`0000000000
0000003oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0000000/0oooo00<0
00000?ooo`3oool0>`3oool010000000oooo0?ooo`0000030?ooo`8000001`3oool2000000030?oo
o`00000000000080oooo00@000000?ooo`3oool0oooo0P000000103oool000000000003oool40000
00040?ooo`00000000000?ooo`@00000<`3oool5000000030?ooo`000000oooo00<0000000H0oooo
00000000000000000?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
2`3oool00`000000oooo0?ooo`0k0?ooo`040000003oool0oooo000000<0oooo0P0000070?ooo`80
000000<0oooo0000000000000P3oool01`000000oooo0?ooo`000000oooo0000003oool00P000000
0`3oool0000000000002000000040?ooo`00000000000?ooo`@000007`3oool001l0oooo1@000000
0`3oool000000?ooo`03000000060?ooo`00000000000000003oool00000103oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
000000030?ooo`8000001`3oool00`000000oooo0000000200000080oooo00@000000?ooo`3oool0
oooo0P000000103oool000000000003oool4000000030?ooo`000000oooo00D00000<`3oool50000
00030?ooo`000000oooo00<0000000H0oooo00000000000000000?ooo`0000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000002`3oool2000003d0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`060?ooo`80000000<0oooo0000000000000P3oool010000000oooo0?oo
o`3oool2000000040?ooo`00000000000?ooo`@0000000@0oooo000000000000oooo1000000c0?oo
o`D0000000<0oooo0000003oool00`0000001P3oool00000000000000000oooo000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0000000;0?ooo`800000?@3oool00`000000oooo0000
00030?ooo`030000003oool0oooo00H0oooo0P0000000`3oool00000000000020?ooo`070000003o
ool0oooo0000003oool000000?ooo`02000000030?ooo`00000000000080000000@0oooo00000000
0000oooo1000000O0?ooo`007`3oool7000000030?ooo`000000000000D0000000<0oooo0000003o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000`0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`00
00000P0000020?ooo`070000003oool0oooo0000003oool000000?ooo`02000000030?ooo`000000
00000080000000<0oooo0000003oool01@00000c0?ooo`H000000P3oool3000000060?ooo`000000
00000000003oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0000000/0oooo
0P00000m0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0000000200000080oooo00L000000?ooo`3oool000000?ooo`000000oooo0080000000<0oooo0000
000000000P000000103oool000000000003oool4000003<0oooo1P0000020?ooo`<0000000H0oooo
00000000000000000?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
2`3oool2000003d0oooo00<000000?ooo`0000000P3oool2000000P0oooo00<000000?ooo`000000
0P0000020?ooo`070000003oool0oooo0000003oool000000?ooo`02000000030?ooo`0000000000
0080000000@0oooo000000000000oooo1000000O0?ooo`007`3oool7000000030?ooo`0000000000
00D0000000<0oooo0000000000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00`0oooo00<000000?ooo`3oool0>`3oool00`000000oooo000000030?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00`0000020?ooo`070000003oool0oooo0000003oool000000?oo
o`02000000030?ooo`00000000000080000000<0oooo0000003oool01@00000c0?ooo`H000000P3o
ool7000000030?ooo`000000000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
000<0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<000000P3oool01`000000oooo0?ooo`000000oooo0000003o
ool00P0000000`3oool0000000000002000000030?ooo`000000oooo00D00000<`3oool600000003
0?ooo`000000000000H0000000<0oooo0000000000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000`0oooo00<000000?ooo`3oool0>`3oool00`000000oooo000000020?ooo`80
00001`3oool00`000000oooo0?ooo`0300000080oooo00L000000?ooo`3oool000000?ooo`000000
oooo0080000000<0oooo0000000000000P0000000`3oool000000?ooo`05000001l0oooo000O0?oo
o`L0000000<0oooo0000000000000P0000000`3oool0000000000003000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0000000<0?ooo`030000003oool0oooo03/0oooo0`0000020?oo
o`8000001`3oool00`000000oooo0?ooo`0300000080oooo00D000000?ooo`3oool000000?ooo`04
000000030?ooo`00000000000080000000<0oooo0000003oool01@00000c0?ooo`H000000P3oool4
000000030?ooo`000000000000<000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000`0oooo00<000000?ooo`3oool0>`3oool300000080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0300000080oooo00D000000?ooo`3oool000000?ooo`04000000030?ooo`00
000000000080000000<0oooo0000003oool01@00000b0?ooo`L0000000<0oooo0000000000000`00
00000`3oool0000000000003000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
000<0?ooo`030000003oool0oooo03/0oooo0`0000020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00`0000020?ooo`050000003oool0oooo0000003oool0100000000`3oool00000
00000002000000030?ooo`000000oooo00D000007`3oool001l0oooo1P0000020?ooo`@0000000<0
oooo0000000000000`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000303o
ool00`000000oooo0?ooo`0l0?ooo`8000000P3oool2000000L0oooo00<000000?ooo`3oool00`00
00020?ooo`050000003oool0oooo0000003oool0100000000`3oool0000000000002000000030?oo
o`000000oooo00D00000<`3oool3000000030?ooo`00000000000080oooo100000000`3oool00000
00000003000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000<0?ooo`030000
003oool0oooo03`0oooo0P0000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0`0000020?ooo`050000003oool0oooo0000003oool0100000000`3oool000000000000200000003
0?ooo`000000oooo00D00000<P3oool4000000040?ooo`00000000000?ooo`D0000000<0oooo0000
000000000`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000303oool00`00
0000oooo0?ooo`0l0?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00<000000P3oool00`000000oooo0?ooo`02000000050?ooo`00000000000000003oool010000000
0`3oool000000?ooo`05000001l0oooo000O0?ooo`H000000P3oool4000000030?ooo`0000000000
0080000000D0oooo0000003oool0oooo000000040?ooo`030000003oool0000000`0oooo00<00000
0?ooo`3oool0?03oool200000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`03
00000080oooo00D000000?ooo`3oool000000?ooo`04000000030?ooo`0000000000008000000P3o
ool600000380oooo100000000`3oool00000000000020?ooo`@0000000<0oooo0000000000000`00
00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000303oool00`000000oooo0?oo
o`0l0?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<000000P3o
ool01@000000oooo0?ooo`000000oooo00@0000000<0oooo0000000000000P0000000`3oool00000
0?ooo`0500000380oooo10000000103oool000000000003oool5000000030?ooo`000000000000<0
00000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000`0oooo00<000000?ooo`3o
ool0?03oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool00`0000020?ooo`03
0000003oool0oooo0080000000D0oooo00000000000000000?ooo`04000000030?ooo`000000oooo
00D000007`3oool001h0oooo1`0000020?ooo`@0000000<0oooo0000000000000P0000001@3oool0
00000?ooo`3oool0000000@0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0l0?oo
o`8000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<000000P3oool01@00
0000oooo0?ooo`000000oooo00@0000000<0oooo0000000000000P0000020?ooo`H00000<P3oool4
000000030?ooo`00000000000080oooo100000000`3oool0000000000002000000050?ooo`000000
oooo0?ooo`000000103oool00`000000oooo0000000<0?ooo`030000003oool0oooo03`0oooo00D0
00000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00<000000P3oool01@000000oooo
0?ooo`000000oooo00@0000000<0oooo0000000000000P0000000`3oool000000?ooo`0500000380
oooo10000000103oool000000000003oool5000000030?ooo`00000000000080000000D0oooo0000
003oool0oooo000000040?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`02000000P0oooo00<000000?ooo`3oool00`0000000`3oool000000?ooo`02
0?ooo`80000000D0oooo00000000000000000?ooo`04000000030?ooo`000000oooo00D000007`3o
ool001h0oooo10000000103oool000000000003oool5000000030?ooo`00000000000080000000D0
oooo0000003oool0oooo000000040?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0
?03oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool00`0000020?ooo`030000
003oool0oooo0080000000<0oooo0000000000001P0000020?ooo`H00000<P3oool4000000040?oo
o`00000000000?ooo`D0000000<0oooo0000000000000P0000001@3oool000000?ooo`3oool00000
00@0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0l0?ooo`80000000<0oooo0000
00000000203oool00`000000oooo0?ooo`0300000080oooo00<000000?ooo`3oool00P0000000`3o
ool000000000000600000080oooo1P00000b0?ooo`@0000000H0oooo000000000000oooo0000003o
ool3000000030?ooo`00000000000080000000D0oooo0000003oool0oooo000000040?ooo`030000
003oool0000000`0oooo00<000000?ooo`3oool0?03oool2000000030?ooo`000000oooo00P0oooo
00<000000?ooo`3oool00`0000000`3oool000000?ooo`020?ooo`80000000<0oooo000000000000
1P0000020?ooo`H000007`3oool001h0oooo100000001P3oool000000000003oool000000?ooo`<0
000000<0oooo0000000000000P0000001@3oool000000?ooo`3oool000000080oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03d0oooo00@000000?oo
o`0000000000203oool00`000000oooo0?ooo`0300000080oooo00<000000?ooo`3oool00P000000
0`3oool000000000000600000080oooo1P00000b0?ooo`@0000000H0oooo000000000000oooo0000
003oool3000000030?ooo`00000000000080000000D0oooo0000003oool0oooo000000020?ooo`05
0000003oool000000?ooo`000000303oool00`000000oooo0?ooo`0l0?ooo`80000000<0oooo0000
00000000203oool00`000000oooo0?ooo`0300000080oooo00<000000?ooo`3oool00P0000000`3o
ool000000000000600000080oooo1P00000b0?ooo`@0000000H0oooo000000000000oooo0000003o
ool3000000070?ooo`00000000000?ooo`000000oooo000000020?ooo`030000003oool0oooo0080
00000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03`0oooo0P0000000`3oool0
00000?ooo`080?ooo`030000003oool0oooo00<0000000<0oooo0000003oool00P3oool200000003
0?ooo`000000000000H000000P3oool6000001l0oooo000N0?ooo`@0000000H0oooo000000000000
oooo0000003oool3000000030?ooo`00000000000080000000D0oooo0000003oool0oooo00000002
0?ooo`<000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03`0oooo0P000000
0`3oool000000?ooo`080?ooo`030000003oool0oooo00<000000P3oool00`000000oooo0?ooo`02
000000030?ooo`000000000000H000000P3oool600000380oooo100000001P3oool000000000003o
ool000000?ooo`<0000000L0oooo000000000000oooo0000003oool000000080oooo00<000000?oo
o`0000000`0000000`3oool000000?ooo`0;0?ooo`030000003oool0oooo03`0oooo0P0000000`3o
ool000000?ooo`080?ooo`030000003oool0oooo00<000000P3oool01P000000oooo0000003oool0
00000?ooo`P000000P3oool600000380oooo100000001P3oool000000000003oool000000?ooo`<0
000000L0oooo000000000000oooo0000003oool000000080oooo00<000000?ooo`0000000P000002
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0?03oool2000000030?ooo`000000
oooo00P0oooo00<000000?ooo`3oool00`000000203oool000000?ooo`3oool000000?ooo`000000
oooo200000020?ooo`H000007`3oool001h0oooo100000001P3oool000000000003oool000000?oo
o`<0000000L0oooo000000000000oooo0000003oool000000080oooo00@000000?ooo`000000oooo
0P0000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0?03oool2000000030?oo
o`000000oooo00P0oooo00<000000?ooo`3oool01@0000020?ooo`040000003oool000000?ooo`P0
00000P3oool600000380oooo100000001P3oool000000000003oool000000?ooo`<0000000L0oooo
000000000000oooo0000003oool000000080oooo00@000000?ooo`000000oooo0P0000000`3oool0
00000?ooo`0;0?ooo`030000003oool0oooo03`0oooo0P0000000`3oool000000?ooo`080?ooo`03
0000003oool0oooo00<0000000P0oooo0000003oool0oooo0000003oool000000?ooo`P000000P3o
ool600000380oooo100000001P3oool000000000003oool000000?ooo`<0000000L0oooo00000000
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0?03oool2000000030?ooo`000000oooo00P0oooo00P0
00000?ooo`3oool000000?ooo`000000oooo00000080oooo00@000000?ooo`000000oooo20000002
0?ooo`H000007`3oool001h0oooo100000001P3oool000000000003oool000000?ooo`<0000000L0
oooo000000000000oooo0000003oool000000080oooo00@000000?ooo`000000oooo0P0000020?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0?03oool4000000T0oooo00<000000?oo
o`3oool00P0000000`3oool00000000000020?ooo`040000003oool000000?ooo`P000000P3oool6
00000380oooo100000001P3oool000000000003oool000000?ooo`<0000000L0oooo000000000000
oooo0000003oool000000080oooo00@000000?ooo`000000oooo0P0000000`3oool000000000000;
0?ooo`030000003oool0oooo03`0oooo100000090?ooo`030000003oool0oooo00D000000P3oool0
10000000oooo0000003oool800000080oooo1P00000b0?ooo`@0000000H0oooo000000000000oooo
0000003oool3000000070?ooo`00000000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03`0oooo1000
00090?ooo`080000003oool0oooo0000003oool000000?ooo`0000020?ooo`040000003oool00000
0?ooo`P000000P3oool6000001l0oooo000N0?ooo`@0000000H0oooo000000000000oooo0000003o
ool3000000070?ooo`00000000000?ooo`000000oooo000000020?ooo`050000003oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`0000002P3oool00`000000oooo0?ooo`02000000030?ooo`00000000000080oooo00@000000?oo
o`000000oooo200000020?ooo`80000000@0oooo0000000000000000<P3oool4000000060?ooo`00
000000000?ooo`000000oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0l0?ooo`<000002P3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool010000000oooo
0000003oool800000080oooo1P00000b0?ooo`@0000000H0oooo000000000000oooo0000003oool3
000000070?ooo`00000000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03`0oooo0`00000:0?ooo`05
0000003oool0oooo0000003oool00`0000020?ooo`040000003oool000000?ooo`P000000P3oool6
000001l0oooo000N0?ooo`@0000000H0oooo000000000000oooo0000003oool3000000070?ooo`00
000000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo03`0oooo00<000000?ooo`0000002P3oool00`00
0000oooo0?ooo`02000000030?ooo`00000000000080oooo00@000000?ooo`000000oooo20000002
0?ooo`80000000@0oooo0000000000000000<P3oool4000000060?ooo`00000000000?ooo`000000
oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0l0?ooo`<000002P3o
ool010000000oooo0?ooo`0000020?ooo`8000000P3oool010000000oooo0000003oool800000080
oooo1P00000b0?ooo`@0000000H0oooo000000000000oooo0000003oool3000000070?ooo`000000
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo03`0oooo0`00000:0?ooo`040000003oool0oooo0000
0080oooo0P0000020?ooo`040000003oool000000?ooo`P000000P3oool6000001l0oooo000N0?oo
o`@0000000H0oooo000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`0000002P3oool010000000oooo0?ooo`000002
0?ooo`8000000P3oool010000000oooo0000003oool800000080oooo0P000000103oool000000000
0000000b0?ooo`@0000000H0oooo000000000000oooo0000003oool3000000070?ooo`0000000000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo03`0oooo00<000000?ooo`0000002P3oool010000000oooo
0?ooo`0000020?ooo`8000000P3oool010000000oooo0000003oool800000080oooo1P00000b0?oo
o`@0000000H0oooo000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000P3oool2000000/0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0000000:0?ooo`040000003oool0oooo00000080oooo0P000002
0?ooo`040000003oool000000?ooo`P000000P3oool6000001l0oooo000N0?ooo`@0000000H0oooo
000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?ooo`8000000P3o
ool010000000oooo0000003oool800000080oooo0P000000103oool0000000000000000b0?ooo`@0
000000H0oooo000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?oo
o`8000000P3oool010000000oooo0000003oool800000080oooo0P000000103oool0000000000000
000b0?ooo`@0000000H0oooo000000000000oooo0000003oool3000000070?ooo`00000000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000P3oool2000000/0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo00000080oooo
0P0000020?ooo`040000003oool000000?ooo`P000000P3oool6000001l0oooo000N0?ooo`@00000
00H0oooo000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo03`0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?ooo`80
00000P3oool00`000000oooo000000020?ooo`L000000P3oool2000000040?ooo`00000000000000
0380oooo100000001P3oool000000000003oool000000?ooo`<0000000L0oooo000000000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo
00000080oooo0P0000020?ooo`040000003oool000000?ooo`P000000P3oool2000000040?ooo`00
0000000000000380oooo10000000103oool000000000003oool5000000070?ooo`00000000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool02P3oool010000000oooo0?oo
o`0000020?ooo`8000000P3oool010000000oooo0000003oool800000080oooo1P00000O0?ooo`00
7P3oool4000000060?ooo`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool0
00000P3oool200000080oooo00<000000?ooo`0000000P3oool700000080oooo0P000000103oool0
000000000000000b0?ooo`@0000000H0oooo000000000000oooo0000003oool3000000070?ooo`00
000000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool02P3oool01000
0000oooo0?ooo`0000020?ooo`8000000P3oool010000000oooo0000003oool800000080oooo0P00
0000103oool0000000000000000b0?ooo`@0000000@0oooo000000000000oooo1@0000001`3oool0
00000000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00X0oooo00@0
00000?ooo`3oool000000P3oool200000080oooo00@000000?ooo`000000oooo200000020?ooo`H0
00007`3oool001h0oooo100000001P3oool000000000003oool000000?ooo`<0000000L0oooo0000
00000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`040000
003oool0oooo00000080oooo0P0000020?ooo`030000003oool000000080oooo1`0000020?ooo`80
000000@0oooo0000000000000000<P3oool4000000060?ooo`00000000000?ooo`000000oooo0`00
00001`3oool000000000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
00X0oooo00@000000?ooo`3oool000000P3oool200000080oooo00@000000?ooo`000000oooo2000
00020?ooo`80000000@0oooo0000000000000000<P3oool4000000040?ooo`00000000000?ooo`D0
000000L0oooo000000000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0:0?ooo`040000003oool0oooo00000080oooo0P0000020?ooo`040000003oool000000?ooo`P0
00000P3oool6000001l0oooo000N0?ooo`@0000000H0oooo000000000000oooo0000003oool30000
00070?ooo`00000000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
2P3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool010000000oooo0000003oool80000
0080oooo0P000000103oool0000000000000000b0?ooo`@0000000H0oooo000000000000oooo0000
003oool3000000070?ooo`00000000000?ooo`000000oooo000000020?ooo`050000003oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool02P3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool010000000oooo0000
003oool800000080oooo0P000000103oool0000000000000000b0?ooo`@0000000@0oooo00000000
0000oooo1@0000001`3oool000000000003oool000000?ooo`0000000P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo00X0oooo00@000000?ooo`3oool000000P3oool200000080oooo00@000000?ooo`00
0000oooo200000020?ooo`H000007`3oool001h0oooo100000001P3oool000000000003oool00000
0?ooo`<0000000L0oooo000000000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`0:0?ooo`040000003oool0oooo00000080oooo0P0000020?ooo`040000003oool00000
0?ooo`P000000P3oool2000000040?ooo`000000000000000380oooo100000001P3oool000000000
003oool000000?ooo`<0000000L0oooo000000000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo00000080oooo0P0000020?ooo`040000
003oool000000?ooo`P000000P3oool2000000040?ooo`000000000000000380oooo100000001P3o
ool000000000003oool000000?ooo`<0000000L0oooo000000000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo00000080oooo0P000002
0?ooo`040000003oool000000?ooo`P000000P3oool6000001l0oooo000N0?ooo`@0000000H0oooo
000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`070?ooo`<00000?P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080000000<0oooo0000000000000P3oool0
10000000oooo0000003oool800000080oooo0P000000103oool0000000000000000b0?ooo`@00000
00H0oooo000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`070?ooo`<00000
?P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo00000080oooo0P0000020?ooo`04
0000003oool000000?ooo`P000000P3oool600000380oooo100000001P3oool000000000003oool0
00000?ooo`<0000000L0oooo000000000000oooo0000003oool000000080oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo00L0oooo0`00000n0?ooo`030000003oool0oooo
00X0oooo00@000000?ooo`3oool000000P3oool200000080oooo00@000000?ooo`000000oooo2000
00020?ooo`H000007`3oool001h0oooo100000001P3oool000000000003oool000000?ooo`<00000
00L0oooo000000000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool0oooo00L0oooo0`00000n0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P0000000`3oool00000000000020?ooo`040000003oool000000?ooo`P000000P3o
ool2000000040?ooo`000000000000000380oooo100000001P3oool000000000003oool000000?oo
o`<0000000L0oooo000000000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool0oooo00L0oooo0`00000n0?ooo`030000003oool0oooo00X0oooo
00@000000?ooo`3oool000000P3oool200000080oooo00@000000?ooo`000000oooo200000020?oo
o`H00000<P3oool4000000060?ooo`00000000000?ooo`000000oooo0`0000001`3oool000000000
003oool000000?ooo`0000000P3oool01@000000oooo0000003oool000000080oooo00<000000?oo
o`3oool0203oool3000003h0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000002
0?ooo`8000000P3oool010000000oooo0000003oool800000080oooo1P00000O0?ooo`007P3oool4
000000060?ooo`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool01`3oool3
000003h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02000000030?ooo`000000
00000080oooo00@000000?ooo`000000oooo200000020?ooo`80000000@0oooo0000000000000000
<P3oool4000000060?ooo`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
1`3oool3000003h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02000000030?oo
o`00000000000080oooo00@000000?ooo`000000oooo200000020?ooo`H00000<P3oool400000006
0?ooo`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool0203oool3000003h0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`03000000080?ooo`000000oooo0?oo
o`000000oooo0000003oool800000080oooo1P00000O0?ooo`007P3oool4000000060?ooo`000000
00000?ooo`000000oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3oool01000
0000oooo0000003oool200000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000n
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`0000020?ooo`060000003oool0
00000?ooo`000000oooo200000020?ooo`80000000@0oooo0000000000000000<P3oool400000006
0?ooo`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool000000?ooo`000000
0P3oool01@000000oooo0000003oool000000080oooo0P0000090?ooo`030000003oool0000003h0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`03000000080?ooo`000000oooo0?oo
o`000000oooo0000003oool800000080oooo1P00000b0?ooo`@0000000H0oooo000000000000oooo
0000003oool3000000070?ooo`00000000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0000003h0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`03000000080?ooo`000000oooo0?ooo`000000
oooo0000003oool800000080oooo1P00000O0?ooo`007P3oool4000000030?ooo`00000000000080
oooo100000001`3oool000000000003oool000000?ooo`0000000P3oool010000000oooo0000003o
ool200000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000n0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00`0000020?ooo`030000003oool0oooo0080000000<0
oooo0000000000001P0000020?ooo`H00000<P3oool4000000060?ooo`00000000000?ooo`000000
oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3oool010000000oooo0000003o
ool2000000030?ooo`000000000000T0oooo00<000000?ooo`000000?P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00<0000000P0oooo0000003oool0oooo0000003oool000000?oo
o`P000000P3oool600000380oooo100000001P3oool000000000003oool000000?ooo`<0000000L0
oooo000000000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo000000020?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`000000?P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00<0000000P0oooo0000003oool0oooo0000003oool000000?ooo`P00000
0P3oool6000001l0oooo000N0?ooo`@0000000<0oooo0000000000000P3oool4000000070?ooo`00
000000000?ooo`000000oooo000000020?ooo`040000003oool000000?ooo`80000000<0oooo0000
003oool0203oool2000000030?ooo`000000oooo03d0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0300000080oooo00<000000?ooo`3oool00P0000000`3oool00000000000060000
0080oooo1P00000b0?ooo`@0000000H0oooo000000000000oooo0000003oool3000000070?ooo`00
000000000?ooo`000000oooo000000020?ooo`040000003oool000000?ooo`80000000<0oooo0000
003oool0203oool2000000030?ooo`000000oooo03d0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`03000000080?ooo`000000oooo0?ooo`000000oooo0000003oool800000080oooo
1P00000b0?ooo`@0000000H0oooo000000000000oooo0000003oool3000000070?ooo`0000000000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo
0?ooo`070?ooo`80000000<0oooo0000003oool0?@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00<0000000P0oooo0000003oool0oooo0000003oool000000?ooo`P000000P3oool6
000001l0oooo000N0?ooo`@0000000<0oooo0000000000000P3oool4000000030?ooo`0000000000
0080000000P0oooo0000003oool0oooo0000003oool000000?ooo`80000000<0oooo0000003oool0
203oool010000000oooo0?ooo`00000n0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00`0000020?ooo`030000003oool0oooo0080000000D0oooo00000000000000000?ooo`040000
0080oooo1P00000b0?ooo`@0000000H0oooo000000000000oooo0000003oool3000000030?ooo`00
000000000080000000P0oooo0000003oool0oooo0000003oool000000?ooo`80000000<0oooo0000
003oool0203oool010000000oooo0?ooo`00000n0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00`0000000`3oool000000?ooo`020?ooo`80000000<0oooo0000000000001P000002
0?ooo`H00000<P3oool4000000060?ooo`00000000000?ooo`000000oooo0`0000001`3oool00000
0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool01`3oool010000000oooo0?ooo`00000n0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00`0000000`3oool000000?ooo`020?ooo`80000000<0oooo0000000000001P00
00020?ooo`H000007`3oool001h0oooo100000000`3oool00000000000020?ooo`@0000000<0oooo
0000000000000P000000203oool000000?ooo`3oool000000?ooo`000000oooo0P0000000`3oool0
00000?ooo`080?ooo`040000003oool0oooo000003h0oooo00<000000?ooo`3oool02P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0080000000D0oooo00000000000000000?oo
o`0400000080oooo1P00000b0?ooo`@0000000H0oooo000000000000oooo0000003oool300000003
0?ooo`00000000000080000000P0oooo0000003oool0oooo0000003oool000000?ooo`80000000<0
oooo0000003oool0203oool010000000oooo0?ooo`00000n0?ooo`030000003oool0oooo00X0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`02000000030?ooo`000000000000H0
00000P3oool600000380oooo100000001P3oool000000000003oool000000?ooo`<0000000L0oooo
000000000000oooo0000003oool000000080oooo00@000000?ooo`000000oooo0P0000000`3oool0
00000?ooo`080?ooo`040000003oool0oooo000003h0oooo00<000000?ooo`3oool02P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0080000000<0oooo0000000000001P000000
0`3oool000000?ooo`05000001l0oooo000N0?ooo`@0000000<0oooo0000000000000P3oool40000
00030?ooo`00000000000080000000D0oooo0000003oool0oooo000000020?ooo`<0000000<0oooo
0000003oool0203oool00`000000oooo0?ooo`02000003h0oooo00<000000?ooo`3oool02@3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080000000D0oooo0000000000000000
0?ooo`0400000080oooo1P00000b0?ooo`@0000000H0oooo000000000000oooo0000003oool30000
00030?ooo`00000000000080000000D0oooo0000003oool0oooo000000020?ooo`<0000000<0oooo
0000003oool0203oool00`000000oooo0?ooo`02000003h0oooo00<000000?ooo`3oool02@3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080000000D0oooo0000000000000000
0?ooo`04000000030?ooo`000000oooo00D00000<P3oool4000000060?ooo`00000000000?ooo`00
0000oooo0`0000000`3oool0000000000002000000050?ooo`000000oooo0?ooo`0000000P3oool3
000000030?ooo`000000oooo00P0oooo00<000000?ooo`3oool00P00000n0?ooo`030000003oool0
oooo00T0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`02000000050?ooo`00
000000000000003oool0100000000`3oool000000?ooo`05000001l0oooo000O0?ooo`H000000P3o
ool4000000030?ooo`00000000000080000000D0oooo0000003oool0oooo000000020?ooo`050000
003oool000000?ooo`000000203oool200000080oooo0P00000n0?ooo`030000003oool0oooo00T0
oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`000000oooo00@0000000<0oooo
0000000000000P0000020?ooo`H00000<P3oool700000080oooo100000000`3oool0000000000002
000000050?ooo`000000oooo0?ooo`0000000P3oool01@000000oooo0000003oool0000000P0oooo
0P0000020?ooo`800000?P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000@0
oooo00D000000?ooo`3oool000000?ooo`04000000030?ooo`00000000000080000000<0oooo0000
003oool01@00000b0?ooo`@0000000<0oooo0000000000000P3oool4000000030?ooo`0000000000
0080000000D0oooo0000003oool0oooo000000020?ooo`050000003oool000000?ooo`000000203o
ool200000080oooo0P00000n0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
103oool01`000000oooo0?ooo`000000oooo0000003oool00P000000203oool000000000003oool0
00000?ooo`000000oooo1@00000O0?ooo`007`3oool600000080oooo100000000`3oool000000000
0002000000050?ooo`000000oooo0?ooo`0000000P3oool01@000000oooo0000003oool0000000P0
oooo00@000000?ooo`3oool0oooo0P00000n0?ooo`030000003oool0oooo00T0oooo00@000000?oo
o`3oool00000103oool01`000000oooo0?ooo`000000oooo0000003oool00P0000000`3oool00000
00000002000000030?ooo`000000oooo00D00000<`3oool600000080oooo100000000`3oool00000
00000002000000050?ooo`000000oooo0?ooo`0000000P3oool01@000000oooo0000003oool00000
00P0oooo00@000000?ooo`3oool0oooo0P00000n0?ooo`030000003oool0oooo00T0oooo00@00000
0?ooo`3oool00000103oool01`000000oooo0?ooo`000000oooo0000003oool00P0000000`3oool0
000000000002000000030?ooo`000000oooo00D00000<P3oool4000000030?ooo`00000000000080
oooo100000000`3oool0000000000002000000050?ooo`000000oooo0?ooo`0000000P3oool01@00
0000oooo0000003oool0000000P0oooo00@000000?ooo`3oool0oooo0P00000n0?ooo`030000003o
ool0oooo00T0oooo00@000000?ooo`3oool00000103oool01`000000oooo0?ooo`000000oooo0000
003oool00P0000000`3oool0000000000002000000030?ooo`000000oooo00D000007`3oool001l0
oooo1P0000020?ooo`@0000000<0oooo0000000000000P0000001@3oool000000?ooo`3oool00000
0080oooo00D000000?ooo`000000oooo000000080?ooo`040000003oool0oooo0?ooo`800000?P3o
ool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0
oooo0P000000103oool000000000003oool4000000030?ooo`000000oooo00D00000<`3oool60000
0080oooo2`0000020?ooo`080000003oool0oooo0000003oool000000?ooo`0000080?ooo`040000
003oool0oooo0?ooo`800000?P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00`000000103oool000000000003oool4000000030?ooo`000000
oooo00D00000<P3oool4000000030?ooo`00000000000080oooo2`0000020?ooo`080000003oool0
oooo0000003oool000000?ooo`0000080?ooo`040000003oool0oooo0?ooo`800000?P3oool00`00
0000oooo0?ooo`090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`000000
103oool000000000003oool4000000030?ooo`000000oooo00D000007`3oool001l0oooo1`000000
0`3oool0000000000002000000030?ooo`00000000000080000000D0oooo0000003oool0oooo0000
00020?ooo`050000003oool000000?ooo`000000203oool010000000oooo0?ooo`3oool3000003d0
oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
0?ooo`80000000@0oooo000000000000oooo100000000`3oool000000?ooo`05000003<0oooo1P00
00020?ooo`X000000`3oool020000000oooo0?ooo`000000oooo0000003oool00000203oool01000
0000oooo0?ooo`3oool3000003d0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00
00040?ooo`040000003oool0oooo0?ooo`80000000@0oooo000000000000oooo100000000`3oool0
00000?ooo`0500000380oooo100000000`3oool00000000000020?ooo`X000000`3oool020000000
oooo0?ooo`000000oooo0000003oool00000203oool010000000oooo0?ooo`3oool3000003d0oooo
00<000000?ooo`3oool02@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0?oo
o`80000000@0oooo000000000000oooo100000000`3oool000000?ooo`05000001l0oooo000O0?oo
o`L0000000<0oooo000000000000200000030?ooo`030000003oool0oooo00<0000000<0oooo0000
003oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000003d0oooo00<000000?oo
o`3oool02P3oool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?oo
o`00000000000?ooo`04000000030?ooo`000000oooo00D00000<`3oool600000080oooo2P000003
0?ooo`030000003oool0oooo00<0000000<0oooo0000003oool01P3oool00`000000oooo0?ooo`02
0?ooo`<00000?@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000@0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo000000000000oooo00@0000000<0oooo0000003oool01@00
000c0?ooo`H000000P3oool:000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo0000
00L0oooo00<000000?ooo`3oool00P3oool3000003d0oooo00<000000?ooo`3oool02@3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`00000000000?oo
o`04000000030?ooo`000000oooo00D000007`3oool001l0oooo1@0000000`3oool000000?ooo`07
000000030?ooo`000000000000<0oooo00<000000?ooo`0000000`0000000`3oool000000?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000?@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo00000000
0000oooo00@0000000<0oooo0000003oool01@00000c0?ooo`L0000000<0oooo0000000000001@00
00000`3oool00000000000030?ooo`030000003oool0000000<0000000<0oooo0000003oool01P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000003d0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`0000000000
0?ooo`04000000030?ooo`000000oooo00D00000<`3oool7000000030?ooo`000000000000P00000
0P3oool2000000030?ooo`00000000000080000000<0oooo0000003oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000003d0oooo00<000000?ooo`3oool02@3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`00000000000?ooo`040000
00030?ooo`000000oooo00D000007`3oool001l0oooo1@0000000`3oool000000?ooo`0300000005
0?ooo`00000000000000003oool00P0000030?ooo`040000003oool000000?ooo`80000000<0oooo
0000003oool01P3oool010000000oooo0?ooo`3oool2000000030?ooo`000000oooo03`0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`00000000000?ooo`04000000040?ooo`00000000000?ooo`@00000<`3oool500000003
0?ooo`000000oooo00<0000000D0oooo00000000000000000?ooo`02000000<0oooo00@000000?oo
o`000000oooo0P0000000`3oool000000?ooo`060?ooo`040000003oool0oooo0?ooo`80000000<0
oooo0000003oool0?03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo000000000000oooo00@0000000@0oooo000000000000
oooo1000000c0?ooo`D0000000<0oooo0000003oool00`0000000`3oool000000000000400000080
oooo0P0000000`3oool0000000000002000000030?ooo`000000oooo00H0oooo00@000000?ooo`3o
ool0oooo0P0000000`3oool000000?ooo`0l0?ooo`030000003oool0oooo00T0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`020?ooo`070000003oool000000000003oool00000
0?ooo`02000000040?ooo`00000000000?ooo`@000007`3oool001l0oooo1@0000000`3oool00000
0?ooo`03000000030?ooo`000000000000@000000`3oool010000000oooo0000003oool200000003
0?ooo`000000oooo00D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
03`0oooo00<000000?ooo`3oool02P3oool00`000000oooo000000040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`0000001`000000103oool000000000003oool3000003<0oooo1@000000
0`3oool000000?ooo`03000000030?ooo`000000000000@000000`3oool010000000oooo0000003o
ool2000000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000003`0oooo00<000000?ooo`3oool02P3oool00`000000oooo000000040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000001`000000103oool000000000003oool3000003<0
oooo1@0000000`3oool000000?ooo`03000000030?ooo`000000000000@000000P3oool200000003
0?ooo`000000oooo0080000000<0oooo0000003oool01@3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000?03oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000003000000050?ooo`000000
00000000003oool00P000000103oool0000000000000000O0?ooo`007`3oool5000000030?ooo`00
0000oooo00<0000000<0oooo0000003oool0100000030?ooo`040000003oool000000?ooo`800000
00<0oooo0000003oool01@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
0000?03oool00`000000oooo0?ooo`0:0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`80
00000P3oool6000000040?ooo`00000000000?ooo`<00000<`3oool5000000030?ooo`000000oooo
00<0000000<0oooo0000003oool0100000030?ooo`040000003oool000000?ooo`80000000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000?03o
ool00`000000oooo0?ooo`0:0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`80000000<0
oooo0000000000000`0000000`3oool000000?ooo`02000000040?ooo`0000000000000003<0oooo
1@0000000`3oool000000?ooo`03000000030?ooo`000000oooo00@000000P3oool2000000030?oo
o`000000oooo0080000000<0oooo0000003oool01@3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000?03oool00`000000oooo0?ooo`0:0?ooo`8000001@3oool00`000000
oooo0?ooo`020?ooo`80000000T0oooo00000000000000000?ooo`000000oooo0000003oool00P00
0000103oool0000000000000000O0?ooo`007`3oool5000000030?ooo`000000oooo00<0000000<0
oooo0000003oool0100000020?ooo`050000003oool000000000003oool0100000060?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P00000k0?ooo`030000003oool0oooo00X0
oooo0P0000050?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0000000<0
000000@0oooo000000000000oooo0`00000c0?ooo`D0000000<0oooo0000003oool00`0000000`3o
ool000000?ooo`0400000080oooo00D000000?ooo`00000000000?ooo`04000000H0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000003/0oooo00<000000?ooo`3oool02P3o
ool2000000D0oooo00<000000?ooo`3oool00P3oool2000000040?ooo`000000oooo0?ooo`800000
00<0oooo0000003oool00P000000103oool0000000000000000c0?ooo`D0000000<0oooo0000003o
ool00`0000000`3oool000000?ooo`0400000080oooo00D000000?ooo`00000000000?ooo`020000
00030?ooo`000000oooo00D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2
000003/0oooo00<000000?ooo`3oool02P3oool2000000D0oooo00<000000?ooo`3oool00P3oool2
000000030?ooo`000000oooo00<0000000<0oooo0000003oool00P000000103oool0000000000000
000O0?ooo`007`3oool5000000030?ooo`000000oooo00D0000000<0oooo0000000000000P000002
0?ooo`030000003oool0000000<0oooo0`0000060?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00X0oooo0P000005
0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0000000<0000000@0oooo
000000000000oooo0P00000d0?ooo`D0000000<0oooo0000003oool01@0000000`3oool000000000
000200000080oooo00<000000?ooo`0000000`3oool3000000D0oooo0P0000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0:0?ooo`8000001@3o
ool00`000000oooo0?ooo`020?ooo`80000000@0oooo0000003oool0oooo0P0000000`3oool00000
0?ooo`02000000030?ooo`000000000003@0oooo1@0000000`3oool000000?ooo`03000000030?oo
o`000000oooo00@000000P3oool00`000000oooo000000030?ooo`030000003oool0000000D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool02P3oool2000000D0oooo00<000000?ooo`3oool00P3oool2000000040?oo
o`000000oooo0?ooo`80000000<0oooo0000003oool00P0000000`3oool000000000000P0?ooo`00
7`3oool9000000050?ooo`00000000000000003oool0100000020?ooo`030000003oool0000000<0
oooo0P0000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo00X0oooo0P0000050?ooo`030000003oool0oooo0080
oooo0P0000020?ooo`030000003oool0000000<0000000<0oooo0000000000000`00000d0?ooo`d0
000000<0oooo0000000000000P0000020?ooo`030000003oool0000000<0oooo0P0000060?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo00X0oooo0P0000050?ooo`030000003oool0oooo0080oooo0P000000103oool0
00000?ooo`3oool4000000030?ooo`000000000000<00000=03oool=000000030?ooo`0000000000
008000000P3oool00`000000oooo000000030?ooo`8000001P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0:0?oo
o`8000001@3oool00`000000oooo0?ooo`020?ooo`80000000@0oooo0000003oool0oooo0`000002
0?ooo`D00000803oool001l0oooo0`000000103oool000000000003oool6000000030?ooo`000000
000000<0000000@0oooo0000000000000000103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo00X0oooo0P0000050?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003o
ool00000008000000P3oool00`000000oooo00000002000003@0oooo0`000000103oool000000000
003oool6000000050?ooo`00000000000?ooo`0000000P3oool3000000@0oooo00<000000?ooo`3o
ool00`3oool2000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo00X0oooo0P0000050?ooo`030000003oool0oooo0080oooo0P000000103oool0
00000?ooo`3oool300000080oooo00<000000?ooo`0000000P00000d0?ooo`<0000000@0oooo0000
00000000oooo1P0000001@3oool000000000003oool000000080oooo0`0000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool02P3oool2000000D0oooo00<000000?ooo`3oool00P3o
ool2000000040?ooo`000000oooo0?ooo`<000000P3oool01@000000oooo0000003oool000000200
oooo000O0?ooo`<0000000@0oooo000000000000oooo1P0000000`3oool00000000000020?ooo`04
0000003oool00000000000D0oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00X0oooo0P0000050?oo
o`030000003oool0oooo00<0oooo00P000000?ooo`3oool000000?ooo`000000oooo00000080oooo
00<000000?ooo`0000000P00000d0?ooo`<0000000@0oooo000000000000oooo0`000000103oool0
00000000003oool200000080oooo00@000000?ooo`00000000001@3oool2000000@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool02P3oool2000000D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`00
0000oooo00<000000P3oool00`000000oooo00000002000003@0oooo0`000000103oool000000000
003oool3000000040?ooo`00000000000?ooo`8000000P3oool010000000oooo0000000000050?oo
o`800000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`0:0?ooo`8000001@3oool00`000000oooo0?ooo`030?oo
o`050000003oool0oooo0000003oool00`0000020?ooo`050000003oool000000?ooo`000000803o
ool00200oooo0P000000103oool000000000003oool600000080oooo00<000000?ooo`3oool00`00
00060?ooo`H000001P3oool2000000H0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`090?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0000003oool0
0`0000020?ooo`030000003oool0000000800000=@3oool2000000040?ooo`00000000000?ooo`<0
000000<0oooo0000000000000P3oool00`000000oooo0?ooo`03000000H0oooo1P0000060?ooo`80
00001P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00T0oooo0P0000050?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`3oool000000?ooo`0300000080oooo00<000000?oo
o`0000000P00000d0?ooo`<0000000@0oooo000000000000oooo0`000000103oool000000000003o
ool200000080oooo0`0000060?ooo`H000001P3oool2000000H0oooo00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`090?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`050000003o
ool0oooo0000003oool00`0000020?ooo`030000003oool0000000800000803oool00200oooo1@00
00001@3oool00000000000000000oooo00D000000`3oool2000000H0oooo00@000000?ooo`3oool0
0000203oool2000000H0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`090?ooo`80
00001P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo0`0000000`3o
ool000000?ooo`03000003D0oooo1@0000001@3oool00000000000000000oooo00D000000`3oool2
000000H0oooo00<000000?ooo`3oool02@3oool2000000H0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`090?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo00000080oooo0`0000000`3oool000000?ooo`03000003D0oooo1@0000001@3oool000000000
00000000oooo00D000000`3oool2000000H0oooo00<000000?ooo`3oool02@3oool2000000H0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`090?ooo`8000001P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000080oooo0`0000000`3oool000000?ooo`0300000200
oooo000P0?ooo`<0000000<0oooo0000003oool01@0000030?ooo`050000003oool0oooo0?ooo`00
00001P3oool3000000X0oooo00<000000?ooo`3oool01@3oool2000003T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool5000000030?ooo`000000000003H0oooo0`0000000`3oool000000?ooo`050000
0080oooo0P0000030?ooo`030000003oool0oooo00@0oooo0`00000:0?ooo`030000003oool0oooo
00D0oooo0P00000i0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo1@0000000`3oool000000000000f
0?ooo`<0000000<0oooo0000003oool01@0000020?ooo`8000000`3oool00`000000oooo0?ooo`04
0?ooo`<000002P3oool00`000000oooo0?ooo`050?ooo`800000>@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`D0000000<0oooo0000000000008@3oool00200oooo0`0000000`3oool000000?ooo`05
000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`<000002P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool02@3oool2000000H0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`@000000P3oool2000003H0oooo
0`0000000`3oool000000?ooo`0500000080oooo0P0000030?ooo`030000003oool0oooo00@0oooo
0`00000:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`090?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080
oooo100000020?ooo`800000=P3oool3000000030?ooo`000000oooo00D000000P3oool2000000<0
oooo00<000000?ooo`3oool0103oool3000000X0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo00T0oooo0P0000060?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool400000080oooo0P00000Q0?ooo`00803oool300000003
0?ooo`000000000000<0000000<0oooo0000003oool00P3oool01@000000oooo0?ooo`3oool00000
00H0oooo0`0000090?ooo`800000203oool2000003P0oooo00<000000?ooo`3oool02@3oool20000
00H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`@0000000@0oooo
0000000000000000=P3oool3000000030?ooo`000000000000<0000000@0oooo0000003oool0oooo
0P0000030?ooo`030000003oool0oooo00@0oooo0`0000090?ooo`800000203oool2000003P0oooo
00<000000?ooo`3oool02@3oool2000000H0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000020?ooo`@0000000@0oooo0000000000000000=P3oool3000000030?ooo`0000000000
00<0000000@0oooo0000003oool0oooo0P0000030?ooo`030000003oool0oooo00@0oooo0`000009
0?ooo`800000203oool2000003P0oooo00<000000?ooo`3oool02@3oool2000000H0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`@0000000@0oooo0000000000000000
8@3oool00200oooo2@000000103oool000000?ooo`3oool2000000<0oooo00<000000?ooo`3oool0
103oool00`000000oooo000000090?ooo`8000002@3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo00T0oooo0P0000060?ooo`040000003oool0oooo0?ooo`8000000`3oool01`000000
oooo000000000000oooo0000003oool00`00000f0?ooo`T0000000@0oooo0000003oool0oooo0P00
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000002@3oool2000000T0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`090?ooo`8000001P3oool010000000oooo0?oo
o`3oool2000000<0oooo00X000000?ooo`00000000000?ooo`000000oooo0000003oool00000=P3o
ool3000000030?ooo`000000000000<0000000@0oooo0000003oool0oooo0P0000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`0000002@3oool2000000T0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`090?ooo`8000001P3oool010000000oooo0?ooo`3oool2000000<0
oooo00X000000?ooo`00000000000?ooo`000000oooo0000003oool000008@3oool00200oooo2@00
0000103oool000000?ooo`3oool2000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
000000090?ooo`030000003oool0oooo00P0oooo0P00000h0?ooo`030000003oool0oooo00P0oooo
0P0000060?ooo`040000003oool0oooo0?ooo`8000000`3oool010000000oooo0000003oool60000
03H0oooo2@000000103oool000000?ooo`3oool2000000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo000000090?ooo`030000003oool0oooo00P0oooo0P00000h0?ooo`030000003oool0
oooo00P0oooo0P0000060?ooo`040000003oool0oooo0?ooo`8000000`3oool010000000oooo0000
003oool6000003H0oooo2@000000103oool000000?ooo`3oool2000000<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo000000090?ooo`030000003oool0oooo00P0oooo0P00000h0?ooo`03
0000003oool0oooo00P0oooo0P0000060?ooo`040000003oool0oooo0?ooo`8000000`3oool01000
0000oooo0000003oool600000240oooo000Q0?ooo`X000000P3oool200000080oooo0P0000060?oo
o`040000003oool00000000000P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo00P0oooo0P0000060?ooo`040000003oool0oooo0?ooo`8000000`3o
ool3000000030?ooo`00000000000080oooo0P00000g0?ooo`D0000000<0oooo0000000000000P00
0000103oool000000000000000020?ooo`8000001P3oool010000000oooo0000000000080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`080?ooo`80
00001P3oool010000000oooo0?ooo`3oool2000000<0oooo0`000000103oool000000000003oool3
000003L0oooo1@0000000`3oool0000000000002000000040?ooo`000000000000000080oooo0P00
00060?ooo`040000003oool00000000000P0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo00P0oooo0P0000060?ooo`040000003oool0oooo0?ooo`80
00000`3oool3000000040?ooo`00000000000?ooo`<000008@3oool00240oooo2@0000030?ooo`04
0000003oool000000?ooo`8000001P3oool010000000oooo0000000000070?ooo`8000002`3oool2
000003L0oooo00<000000?ooo`3oool0203oool2000000L0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`80000000@0oooo00000000000000000P3oool00`000000oooo0?ooo`0f0?ooo`D0
000000@0oooo00000000000000000P3oool2000000030?ooo`000000oooo008000001P3oool01000
0000oooo0000000000070?ooo`8000002`3oool2000003L0oooo00<000000?ooo`3oool0203oool2
000000L0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`80000000D0oooo000000000000
00000?ooo`02000003P0oooo1@000000103oool000000000000000020?ooo`80000000<0oooo0000
003oool00P0000060?ooo`040000003oool00000000000L0oooo0P00000;0?ooo`800000=`3oool0
0`000000oooo0?ooo`080?ooo`8000001`3oool01P000000oooo0?ooo`000000oooo00000080oooo
0P0000001@3oool00000000000000000oooo008000008P3oool00280oooo10000000103oool00000
0000000000030?ooo`040000003oool000000?ooo`8000001P3oool010000000oooo0?ooo`000007
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0000000L0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`800000
00D0oooo0000003oool000000?ooo`02000003P0oooo1@000000103oool000000000000000020?oo
o`80000000<0oooo0000003oool00P0000060?ooo`040000003oool0oooo000000L0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`0000001`3oool01P000000oooo0?ooo`000000oooo00000080oooo0P0000001@3oool00000
0?ooo`000000oooo00800000>03oool900000080oooo00D000000?ooo`3oool000000?ooo`020000
00H0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool01`3oool00`000000oooo000000070?ooo`060000003oool0
oooo0000003oool000000P3oool2000000050?ooo`000000oooo0000003oool00P00000R0?ooo`00
8P3oool2000000030?ooo`00000000000080oooo00T000000?ooo`3oool0oooo0000003oool00000
0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000
1P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`000000oooo1000000i
0?ooo`D000000P3oool00`000000oooo0?ooo`02000000040?ooo`000000oooo000000H0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000H0oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`040000003oool000000?ooo`@00000>@3oool500000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo000000060?ooo`050000003oool0oooo0?ooo`00
00001`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool01`3oool010000000oooo0?ooo`0000060?ooo`060000003oool0oooo0000003oool000000`3o
ool010000000oooo0000003oool400000280oooo000R0?ooo`D000000P3oool00`000000oooo0?oo
o`02000000040?ooo`0000000000000000H0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`80
00003`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3o
ool000001P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00H000000?ooo`000000oooo
0000003oool2000003T0oooo1@0000000`3oool00000000000020?ooo`030000003oool0oooo00<0
00001P3oool010000000oooo0?ooo`3oool2000000D0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000001P3oool0
1P000000oooo0?ooo`000000oooo000000<0oooo00H000000?ooo`000000oooo0000003oool20000
03T0oooo1@0000000`3oool00000000000020?ooo`060000003oool0oooo0000003oool000001P3o
ool010000000oooo0?ooo`3oool2000000D0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000001P3oool01P000000
oooo0?ooo`000000oooo000000<0oooo00H000000?ooo`000000oooo0000003oool200000280oooo
000S0?ooo`@0000000<0oooo0000000000000P3oool00`000000oooo0?ooo`03000000H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo0P00
000e0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000001P3oool01P000000oooo
0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P0000000`3oool000000000000j0?oo
o`@0000000<0oooo0000000000000P3oool00`000000oooo0?ooo`03000000H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo0P00000d0?oo
o`030000003oool0oooo00L0oooo00@000000?ooo`3oool000001P3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00<000000?ooo`3oool00P0000000`3oool000000000000j0?ooo`@00000
00<0oooo0000000000000P3oool01P000000oooo0?ooo`000000oooo000000H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo0P00000d0?oo
o`030000003oool0oooo00L0oooo00@000000?ooo`3oool000001P3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00<000000?ooo`3oool00P0000000`3oool000000000000R0?ooo`008`3o
ool4000000060?ooo`00000000000000003oool000000P3oool3000000H0oooo00<000000?ooo`3o
ool00P3oool2000000<0oooo0P00000A0?ooo`800000=03oool00`000000oooo0?ooo`060?ooo`04
0000003oool0oooo000000L0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0
oooo00D00000>P3oool4000000030?ooo`000000000000<000000P3oool3000000H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`8000004@3oool2000003@0oooo00<00000
0?ooo`3oool01P3oool010000000oooo0?ooo`0000070?ooo`050000003oool000000?ooo`000000
0`3oool01@000000oooo0?ooo`000000oooo00<00000>P3oool4000000030?ooo`000000000000<0
00000P3oool3000000D0oooo0P0000040?ooo`030000003oool0oooo0080oooo0P00000A0?ooo`80
0000=03oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000L0oooo00D000000?oo
o`000000oooo000000030?ooo`050000003oool0oooo0000003oool00`00000R0?ooo`00903oool0
0`000000oooo00000002000000040?ooo`0000000000000000<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`030?ooo`8000000P3oool00`000000oooo0?ooo`0A0?ooo`800000<`3o
ool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`000000
oooo000000020?ooo`040000003oool000000?ooo`@00000?03oool00`000000oooo000000020000
00030?ooo`000000000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo008000004`3oool2000003<0oooo00<000000?ooo`3oool01P3oool01000
0000oooo0?ooo`0000070?ooo`050000003oool000000?ooo`0000000P3oool200000080oooo1000
000l0?ooo`030000003oool000000080000000<0oooo000000000000103oool00`000000oooo0?oo
o`040?ooo`8000001@3oool00`000000oooo0?ooo`02000001<0oooo0P00000c0?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`3oool000001`3oool200000080oooo00<000000?ooo`3oool0
0P0000020?ooo`@000008`3oool002D0oooo0`0000020?ooo`800000103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo0`00000E0?ooo`800000<`3oool00`000000oooo0?oo
o`050?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`0000000P3oool020000000oooo
0000003oool000000?ooo`000000oooo0P00000m0?ooo`<000000P3oool2000000@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`<000005@3oool200000380oooo00<00000
0?ooo`3oool01P3oool010000000oooo0?ooo`0000070?ooo`030000003oool000000080oooo00@0
00000?ooo`00000000000P3oool010000000oooo00000000000m0?ooo`<000000P3oool2000000@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`<000005@3oool200000380
oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000070?ooo`8000000`3oool01000
0000oooo0000000000020?ooo`040000003oool00000000002<0oooo000U0?ooo`<000000P3oool2
000000<0oooo0`0000050?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`050?ooo`040000003oool0oooo000000L0oooo0P0000030?ooo`080000003o
ool000000?ooo`000000oooo0000003oool2000003d0oooo0`0000020?ooo`8000000`3oool30000
00D0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
00H0oooo00@000000?ooo`3oool000001`3oool2000000<0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`000000?P3oool300000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000050?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`060?ooo`040000003oool0oooo000000L0oooo0P0000030?ooo`060000003oool00000
0?ooo`000000oooo0`00000T0?ooo`009`3oool2000000030?ooo`000000000000<0oooo0`000004
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool2000000<0oooo00<00000
0?ooo`0000000P3oool010000000oooo0?ooo`0000100?ooo`030000003oool0oooo008000000`3o
ool3000000@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`8000000`3o
ool00`000000oooo000000020?ooo`040000003oool0oooo00000400oooo00<000000?ooo`3oool0
0P0000030?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`8000000`3oool00`000000oooo000000020?ooo`040000003oool00000000002@0
oooo000X0?ooo`@000000`3oool00`000000oooo000000040?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool2000000@0oooo0P0000020?ooo`@00000@@3oool4000000<0oooo
00<000000?ooo`000000103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
0P0000040?ooo`040000003oool0oooo0?ooo`@00000@@3oool2000000030?ooo`000000oooo0080
oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool3000002D0oooo000/0?ooo`03
0000003oool0000000<0oooo00@000000?ooo`3oool000009@3oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0000004D0oooo0P0000000`3o
ool000000?ooo`020?ooo`040000003oool0oooo000002D0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<00000A@3oool2000000030?ooo`00
0000oooo0080oooo00@000000?ooo`3oool000009@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`800000
103oool010000000oooo0?ooo`3oool3000002D0oooo000]0?ooo`030000003oool0oooo00<0oooo
0`00000V0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool01P000000oooo
0?ooo`000000oooo000004L0oooo00<000000?ooo`3oool00`3oool3000002H0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo000000170?oo
o`030000003oool0oooo00<0oooo0`00000V0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo0P0000040?oo
o`070000003oool0oooo0?ooo`000000oooo0000000U0?ooo`00G@3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04
0?ooo`8000001@3oool00`000000oooo0?ooo`02000007P0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool2
000000@0oooo0P000000103oool000000?ooo`00001h0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo0P00
00040?ooo`80000000@0oooo0000003oool000009P3oool005h0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000NP3oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P00001j0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`0000000`3oool00`000000oooo00000002000002L0oooo
001O0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool010000000oooo0?oo
o`00001l0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000007`0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`05
0000003oool0oooo0?ooo`000000:03oool00600oooo00<000000?ooo`3oool0:`3oool01@000000
oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0[0?ooo`050000003o
ool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003o
ool000000`3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo02/0oooo00D000000?oo
o`3oool0oooo000000070?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`030000003oool0oooo02H0oooo001Q0?ooo`030000003oool0oooo02X0oooo00@0
00000?ooo`3oool00000203oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3o
ool00000203oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000203o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`0W0?ooo`00HP3oool00`000000oooo0?ooo`0Y0?ooo`040000003oool0oooo000000P0oooo
00D000000?ooo`3oool0oooo000000040?ooo`8000000P3oool00`000000oooo0?ooo`1n0?ooo`03
0000003oool0oooo02T0oooo00@000000?ooo`3oool00000203oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0
oooo02T0oooo00@000000?ooo`3oool00000203oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0W0?ooo`00H`3oool00`000000oooo0?oo
o`0X0?ooo`040000003oool0oooo000000T0oooo00@000000?ooo`3oool00000103oool400000880
oooo00<000000?ooo`3oool0:03oool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo
0?ooo`000000103oool400000880oooo00<000000?ooo`3oool0:03oool010000000oooo0?ooo`00
00080?ooo`050000003oool0oooo0?ooo`000000103oool4000002X0oooo001T0?ooo`800000:@3o
ool00`000000oooo000000090?ooo`030000003oool0000000D0oooo0`0000240?ooo`800000:@3o
ool00`000000oooo000000090?ooo`030000003oool0000000D0oooo0`0000240?ooo`800000:@3o
ool2000000X0oooo00<000000?ooo`0000001@3oool3000002/0oooo001U0?ooo`800000:03oool2
000000/0oooo0P0000050?ooo`030000003oool0oooo08D0oooo0P00000X0?ooo`8000002P3oool0
0`000000oooo000000050?ooo`030000003oool0oooo08D0oooo0P00000X0?ooo`8000002P3oool0
0`000000oooo000000050?ooo`030000003oool0oooo02/0oooo001V0?ooo`800000:03oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0Q`3oool20000
02P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
08L0oooo0P00000W0?ooo`8000002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
02`0oooo001W0?ooo`8000009`3oool00`000000oooo0?ooo`090?ooo`800000103oool00`000000
oooo0?ooo`280?ooo`8000009`3oool00`000000oooo0?ooo`090?ooo`800000103oool00`000000
oooo0?ooo`280?ooo`8000009P3oool2000000/0oooo0P0000040?ooo`030000003oool0oooo02`0
oooo001X0?ooo`8000009P3oool2000000X0oooo0`0000000`3oool000000000002<0?ooo`800000
9@3oool00`000000oooo000000090?ooo`030000003oool0000000@00000S03oool2000002D0oooo
00<000000?ooo`0000002@3oool00`000000oooo00000004000002l0oooo001Y0?ooo`800000903o
ool00`000000oooo0000000:0?ooo`040000003oool0oooo000008l0oooo0P00000T0?ooo`030000
003oool0000000T0oooo00<000000?ooo`3oool0T@3oool2000002<0oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`0c0?ooo`00JP3oool2000002<0oooo00@000000?ooo`3oool0
0000203oool00`000000oooo0?ooo`2B0?ooo`8000008P3oool01@000000oooo0?ooo`3oool00000
00P0oooo00<000000?ooo`3oool0TP3oool200000280oooo00D000000?ooo`3oool0oooo00000008
0?ooo`030000003oool0oooo03<0oooo001[0?ooo`8000008@3oool01@000000oooo0?ooo`3oool0
000000P0oooo00<000000?ooo`3oool0T`3oool200000240oooo00D000000?ooo`3oool0oooo0000
00080?ooo`030000003oool0oooo09<0oooo0P00000P0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0c0?ooo`00K@3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0=03oool006h0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`040?ooo`8000000P3oool2000009X0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`040?ooo`8000000P3oool2000009X0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`040?ooo`8000000P3oool2000003L0oooo001_0?ooo`80
00006`3oool2000000L0oooo1000002L0?ooo`8000006`3oool00`000000oooo0?ooo`060?ooo`@0
0000W03oool2000001/0oooo00<000000?ooo`3oool01P3oool3000003T0oooo001a0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo0:P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`120?ooo`00LP3o
ool00`000000oooo0?ooo`0F0?ooo`800000Z`3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0:X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`130?ooo`00L`3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`2[0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0@`3oool0
07@0oooo0P00000D0?ooo`030000003oool0oooo0:d0oooo0P00000D0?ooo`030000003oool0oooo
0:d0oooo0P00000D0?ooo`030000003oool0oooo04@0oooo001f0?ooo`8000004@3oool00`000000
oooo0?ooo`2`0?ooo`8000004@3oool00`000000oooo0?ooo`2`0?ooo`8000004@3oool00`000000
oooo0?ooo`150?ooo`00M`3oool2000000l0oooo00<000000?ooo`3oool0/P3oool2000000l0oooo
00<000000?ooo`3oool0/P3oool2000000l0oooo00<000000?ooo`3oool0AP3oool007P0oooo0`00
000<0?ooo`030000003oool0oooo0;@0oooo0`00000;0?ooo`800000]P3oool2000000`0oooo0P00
00190?ooo`00NP3oool4000000H0oooo0`00002i0?ooo`@000001P3oool300000;T0oooo10000006
0?ooo`<00000BP3oool007d0oooo2000002n0?ooo`P00000_P3oool7000004d0oooo003o0?ooool0
ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool0
0?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3o
oomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00
o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oo
oel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o
0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0oooo
G`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0
ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO
0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3o
oooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0
oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?oo
ool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3o
ool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0oooo
o`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?oo
o`00B`3oool800000;h0oooo2000002n0?ooo`P00000OP3oool004X0oooo0P0000070?ooo`<00000
^P3oool2000000L0oooo0`00002i0?ooo`<000001`3oool3000007/0oooo00180?ooo`8000002`3o
ool300000;H0oooo0P00000;0?ooo`<00000]P3oool2000000/0oooo0`00001i0?ooo`00A`3oool2
000000h0oooo0P00002d0?ooo`8000003P3oool200000;@0oooo0P00000>0?ooo`800000N03oool0
04H0oooo0P00000A0?ooo`800000/@3oool00`000000oooo0?ooo`0@0?ooo`800000/@3oool00`00
0000oooo0?ooo`0@0?ooo`800000MP3oool004H0oooo00<000000?ooo`3oool04@3oool200000:l0
oooo0P00000C0?ooo`800000[`3oool2000001<0oooo0P00001e0?ooo`00A@3oool00`000000oooo
0?ooo`0D0?ooo`800000[03oool2000001H0oooo0P00002/0?ooo`8000005P3oool2000007<0oooo
00140?ooo`800000603oool00`000000oooo0?ooo`2Y0?ooo`800000603oool00`000000oooo0?oo
o`2Y0?ooo`800000603oool00`000000oooo0?ooo`1`0?ooo`00@`3oool2000001X0oooo00<00000
0?ooo`3oool0Y`3oool2000001X0oooo00<000000?ooo`3oool0Y`3oool2000001X0oooo00<00000
0?ooo`3oool0K`3oool003P0oooo0`0000080?ooo`030000003oool0oooo01X0oooo0P00002L0?oo
o`<00000203oool00`000000oooo0?ooo`0J0?ooo`800000W03oool3000000P0oooo00<000000?oo
o`3oool06P3oool2000006l0oooo000g0?ooo`040000003oool0oooo0?ooo`8000001@3oool20000
01d0oooo0P00002J0?ooo`040000003oool0oooo0?ooo`8000001@3oool2000001d0oooo0P00002J
0?ooo`040000003oool0oooo0?ooo`8000001@3oool2000001d0oooo0P00001^0?ooo`00=P3oool0
0`000000oooo0?ooo`030?ooo`800000103oool00`000000oooo0?ooo`0M0?ooo`800000V03oool0
0`000000oooo0?ooo`030?ooo`800000103oool00`000000oooo0?ooo`0M0?ooo`800000V03oool0
0`000000oooo0?ooo`030?ooo`800000103oool00`000000oooo0?ooo`0M0?ooo`800000K@3oool0
03D0oooo00<000000?ooo`3oool01@3oool200000080oooo0P00000P0?ooo`800000UP3oool00`00
0000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`800000803oool2000009H0oooo00<00000
0?ooo`3oool01@3oool010000000oooo0?ooo`3oool200000200oooo0P00001/0?ooo`00=03oool0
0`000000oooo0?ooo`070?ooo`040000003oool0oooo00000280oooo0P00002D0?ooo`030000003o
ool0oooo00L0oooo00@000000?ooo`3oool000008P3oool2000009@0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`00000R0?ooo`800000J`3oool00300oooo0P0000020?ooo`030000
003oool0oooo00L0oooo1000000S0?ooo`800000S`3oool200000080oooo00<000000?ooo`3oool0
1`3oool010000000oooo00000000000S0?ooo`800000S`3oool200000080oooo00<000000?ooo`3o
ool01`3oool010000000oooo00000000000S0?ooo`800000JP3oool002l0oooo00<000000?ooo`00
00000P00000;0?ooo`8000009@3oool2000008d0oooo00<000000?ooo`0000000P00000:0?ooo`<0
00009@3oool2000008d0oooo00<000000?ooo`0000000P00000:0?ooo`<000009@3oool2000006T0
oooo000^0?ooo`040000003oool0oooo0?ooo`8000002`3oool2000002H0oooo0P00002;0?ooo`04
0000003oool0oooo0?ooo`8000002`3oool2000002H0oooo0P00002;0?ooo`040000003oool0oooo
0?ooo`8000002`3oool2000002H0oooo0P00001X0?ooo`00;@3oool00`000000oooo0?ooo`020?oo
o`8000002`3oool2000002L0oooo0P0000290?ooo`030000003oool0oooo0080oooo0P00000;0?oo
o`8000009`3oool2000008T0oooo00<000000?ooo`3oool00P3oool2000000/0oooo0P00000W0?oo
o`800000I`3oool002`0oooo0P0000040?ooo`030000003oool0000000X0oooo0P00000Y0?ooo`03
0000003oool0oooo08D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000:0?ooo`80
0000:@3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00002P3oool2000002T0oooo00<000000?ooo`3oool0I03oool002/0oooo0`0000040?ooo`030000
003oool0000000X0oooo0`00000Y0?ooo`030000003oool0oooo08<0oooo0P0000050?ooo`030000
003oool0000000X0oooo0`00000Y0?ooo`030000003oool0oooo08<0oooo0P0000050?ooo`030000
003oool0000000X0oooo0`00000Y0?ooo`030000003oool0oooo06<0oooo000Y0?ooo`80000000<0
oooo000000000000103oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000002X0
oooo00<000000?ooo`3oool0P03oool2000000030?ooo`000000000000<0oooo0P0000020?ooo`03
0000003oool0oooo00H0oooo00@000000?ooo`3oool00000:P3oool00`000000oooo0?ooo`200?oo
o`D000000`3oool200000080oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00000Z
0?ooo`030000003oool0oooo0680oooo000Y0?ooo`030000003oool0oooo008000000`3oool20000
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02000002X0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo00000002000000<0oooo00D000000?ooo`3oool0oooo00000008
0?ooo`030000003oool0oooo00800000:P3oool00`000000oooo0?ooo`1o0?ooo`050000003oool0
00000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0
0P00000Z0?ooo`030000003oool0oooo0640oooo000X0?ooo`040000003oool0oooo0?ooo`<00000
0P3oool2000000<0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000002/0
oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0400000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000:`3oool00`00
0000oooo0?ooo`1m0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000000[0?ooo`030000
003oool0oooo0600oooo000X0?ooo`030000003oool0oooo0080000000D0oooo0000003oool0oooo
000000040?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000000/0?ooo`03
0000003oool0oooo07`0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000000/0?ooo`030000003o
ool0oooo07`0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000000/0?ooo`030000003oool0oooo
05l0oooo000W0?ooo`<0000000H0oooo0000003oool0oooo0000003oool2000000@0oooo00<00000
0?ooo`3oool0103oool2000000<0oooo0P00000/0?ooo`800000N`3oool200000080oooo00D00000
0?ooo`3oool000000?ooo`02000000@0oooo00<000000?ooo`3oool0103oool2000000<0oooo0P00
000/0?ooo`800000NP3oool300000080oooo00D000000?ooo`3oool000000?ooo`02000000@0oooo
00<000000?ooo`3oool0103oool2000000<0oooo00<000000?ooo`3oool0:`3oool2000005l0oooo
000V0?ooo`80000000@0oooo0000003oool000000`3oool3000000@0oooo0P0000050?ooo`800000
103oool00`000000oooo0?ooo`0[0?ooo`800000N@3oool2000000040?ooo`000000oooo000000<0
oooo0`0000040?ooo`8000001@3oool2000000@0oooo00<000000?ooo`3oool0:`3oool2000007T0
oooo0P000000103oool000000?ooo`0000030?ooo`<00000103oool2000000D0oooo0P0000030?oo
o`800000;@3oool2000005h0oooo000U0?ooo`030000003oool000000080oooo0P0000030?ooo`80
00001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0;03oool2000007L0oooo00<000000?ooo`0000000P3oool2000000<0oooo0P0000060?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0/0?ooo`80
0000M`3oool00`000000oooo000000020?ooo`8000000`3oool2000000H0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02`0oooo0P00001M0?ooo`00
9@3oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo0P0000060?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool2000002h0oooo0P00000V0?ooo`<00000
103oool2000004L0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`800000
1P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo0P00000^0?ooo`800000
9P3oool3000000@0oooo0P0000170?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
0P3oool2000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo02d0oooo0P00000V0?ooo`<00000103oool2000002d0oooo000T0?ooo`<000000`3o
ool2000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo0P00000_0?ooo`800000903oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`000000A@3oool3000000<0oooo0P0000040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`800000;`3oool2000002@0oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000004D0oooo0`0000030?ooo`80
0000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0^0?ooo`800000903oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`000000;03oool002@0oooo100000020?ooo`800000103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0^0?ooo`8000008`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool000000?ooo`0300000440oooo100000020?ooo`800000103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0^
0?ooo`8000008`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool00000
0?ooo`0300000440oooo00@000000?ooo`00000000000P3oool2000000@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`8000001@3oool200000300oooo0P00000S0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`000000oooo00<00000:03oool0
02<0oooo0P0000001`3oool000000000003oool000000?ooo`000000103oool00`000000oooo0?oo
o`040?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02l0oooo0P00
000Q0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool2000000030?ooo`00
0000oooo03l0oooo0P0000001`3oool000000000003oool000000?ooo`000000103oool00`000000
oooo0?ooo`040?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02l0
oooo0P00000Q0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool200000003
0?ooo`000000oooo03l0oooo0P0000001`3oool000000000003oool000000?ooo`000000103oool0
0`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo02l0oooo0P00000Q0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool2
000000030?ooo`000000oooo02L0oooo000S0?ooo`80000000L0oooo000000000000oooo0000003o
ool0000000<0oooo0P0000070?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo
0?ooo`0`0?ooo`8000007`3oool00`000000oooo0?ooo`040?ooo`800000103oool010000000oooo
0?ooo`3oool2000003h0oooo0P0000001`3oool000000000003oool000000?ooo`0000000`3oool2
000000L0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo0300oooo0P00
000O0?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`040000003oool0oooo0?ooo`800000
?P3oool2000000070?ooo`00000000000?ooo`000000oooo000000030?ooo`8000001`3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0<03oool2000001l0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`8000009P3o
ool00280oooo1P0000000`3oool000000?ooo`0200000080oooo00<000000?ooo`0000001P3oool0
1@000000oooo0?ooo`3oool0000000L0oooo0P00000b0?ooo`030000003oool0oooo01<0oooo1000
00060?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`8000000P3oool00`000000oooo0000
000l0?ooo`H0000000<0oooo0000003oool00P0000020?ooo`030000003oool0000000H0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`800000<P3oool00`000000oooo0?ooo`0C0?ooo`@00000
1P3oool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo000000020?ooo`030000
003oool0000003`0oooo1P0000000`3oool000000?ooo`0200000080oooo00<000000?ooo`000000
1P3oool00`000000oooo0?ooo`02000000L0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0C0?ooo`@000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000000P3oool00`000000oooo0000000U0?ooo`008P3oool5000000030?ooo`00
000000000080oooo00H000000?ooo`3oool000000?ooo`0000060?ooo`050000003oool0oooo0?oo
o`000000203oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0180oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`040?ooo`8000000`3oool02@000000oooo0000003o
ool000000?ooo`000000oooo0000000k0?ooo`D0000000<0oooo0000000000000P3oool01P000000
oooo0?ooo`000000oooo000000H0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`0000060?ooo`030000
003oool0oooo00@0oooo0P0000030?ooo`060000003oool000000?ooo`000000oooo0P00000l0?oo
o`D0000000<0oooo0000000000000P3oool01P000000oooo0?ooo`000000oooo000000H0oooo00<0
00000?ooo`3oool00P0000070?ooo`800000<`3oool00`000000oooo0?ooo`0B0?ooo`040000003o
ool0oooo000000H0oooo00<000000?ooo`3oool0103oool2000000<0oooo00@000000?ooo`000000
oooo0P0000000`3oool000000?ooo`0T0?ooo`008P3oool2000000040?ooo`00000000000?ooo`80
00000P3oool01P000000oooo0?ooo`000000oooo000000H0oooo0P0000000`3oool0000000000008
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool2000000<0oooo00H00000
0?ooo`000000oooo0000003oool3000003/0oooo0P000000103oool000000000003oool200000080
oooo00H000000?ooo`3oool000000?ooo`0000060?ooo`80000000<0oooo000000000000203oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`060000003oool0
00000?ooo`000000oooo0`00000k0?ooo`80000000@0oooo000000000000oooo0P0000020?ooo`06
0000003oool0oooo0000003oool000001P3oool2000000030?ooo`000000oooo00P0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`8000000`3oool010000000oooo0000003o
ool5000002@0oooo000R0?ooo`80000000<0oooo0000000000000P3oool00`000000oooo0?ooo`02
000000030?ooo`000000oooo008000001@3oool2000000030?ooo`000000000000P0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`3oool0oooo000000070?ooo`8000000`3oool010000000oooo0000000000020?ooo`040000
003oool00000000003X0oooo0P0000000`3oool00000000000020?ooo`030000003oool0oooo0080
000000<0oooo0000003oool00P0000050?ooo`80000000<0oooo000000000000203oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool01@000000
oooo0?ooo`3oool0000000L0oooo0P0000030?ooo`040000003oool0000000000080oooo00@00000
0?ooo`0000000000>P3oool2000000030?ooo`00000000000080oooo00<000000?ooo`3oool01000
00000`3oool00000000000050?ooo`80000000<0oooo0000003oool0203oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?oo
o`3oool0000000L0oooo0P0000030?ooo`040000003oool0000000000080oooo00@000000?ooo`00
000000008`3oool00240oooo0`000000103oool000000000003oool2000000<0oooo00@000000?oo
o`000000oooo0P0000060?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000
00070?ooo`8000000P3oool01P000000oooo0?ooo`3oool000000?ooo`80000000<0oooo00000000
0000>@3oool3000000040?ooo`00000000000?ooo`8000000`3oool010000000oooo0000003oool2
000000H0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000L0oooo0P00
00020?ooo`060000003oool0oooo0?ooo`000000oooo0P0000000`3oool000000000000i0?ooo`<0
000000@0oooo000000000000oooo0P0000030?ooo`<0000000<0oooo0000000000001P3oool00`00
0000oooo000000090?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001`3oool200000080oooo00H00000
0?ooo`3oool0oooo0000003oool2000000030?ooo`000000000002<0oooo000Q0?ooo`H0000000<0
oooo0000000000000`3oool300000080oooo00<000000?ooo`3oool0103oool00`000000oooo0000
00090?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`050?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo000000020?ooo`060000
003oool0oooo0?ooo`000000oooo0`0000000`3oool000000000000h0?ooo`H0000000<0oooo0000
000000000`3oool300000080oooo00<000000?ooo`3oool0103oool00`000000oooo000000090?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?oo
o`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo000000020?ooo`060000003oool0
oooo0?ooo`000000oooo0`0000000`3oool000000000000h0?ooo`H0000000<0oooo000000000000
0`3oool2000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo000000090?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000001P3oool00`000000oooo000000020?ooo`060000003oool0oooo0?oo
o`000000oooo0`0000000`3oool000000000000R0?ooo`008@3oool200000080oooo1@0000030?oo
o`<000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000T0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo000000060?ooo`060000003oool0oooo0000003oool000000P3oool2000000030?oo
o`000000oooo00@00000>03oool2000000030?ooo`000000000000@000000`3oool300000080oooo
00<000000?ooo`3oool0103oool00`000000oooo000000090?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`00
00001P3oool01P000000oooo0?ooo`000000oooo00000080oooo0P0000000`3oool000000?ooo`04
000003P0oooo0P0000000`3oool0000000000004000000<0oooo0P0000030?ooo`030000003oool0
oooo00@0oooo0`0000090?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`050?ooo`040000003oool0oooo000000L0oooo00H000000?ooo`3oool00000
0?ooo`0000020?ooo`80000000<0oooo0000003oool01000000R0?ooo`008@3oool200000080oooo
00<000000?ooo`0000000`0000020?ooo`<000000P3oool00`000000oooo0?ooo`040?ooo`<00000
2P3oool00`000000oooo0?ooo`0d0?ooo`800000303oool00`000000oooo0?ooo`060?ooo`040000
003oool0oooo000000H0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`80000000<0oooo
0000000000001000000h0?ooo`80000000@0oooo000000000000oooo100000020?ooo`<000000P3o
ool00`000000oooo0?ooo`040?ooo`<000002P3oool00`000000oooo0?ooo`0d0?ooo`800000303o
ool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000H0oooo00H000000?ooo`3oool0
00000?ooo`0000020?ooo`<0000000<0oooo0000000000000`00000h0?ooo`80000000@0oooo0000
00000000oooo100000020?ooo`8000000`3oool00`000000oooo0?ooo`040?ooo`8000002`3oool0
0`000000oooo0?ooo`0d0?ooo`800000303oool00`000000oooo0?ooo`060?ooo`030000003oool0
000000L0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`<0000000@0oooo000000000000
oooo0P00000R0?ooo`008@3oool200000080oooo00H000000?ooo`00000000000?ooo`0000020?oo
o`8000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00@000000?oo
o`3oool000001P3oool01P000000oooo0?ooo`000000oooo00000080oooo0P0000000`3oool00000
00000005000003L0oooo0P000000103oool000000000003oool2000000040?ooo`000000oooo0?oo
o`8000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00@000000?oo
o`3oool000001P3oool01P000000oooo0?ooo`000000oooo00000080oooo0`0000000`3oool00000
00000004000003L0oooo0P000000103oool000000000003oool2000000040?ooo`000000oooo0?oo
o`8000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`0000001`3oool01P000000oooo0?ooo`000000oooo00000080oooo0`0000000`3oool000000000
000400000240oooo000P0?ooo`T0000000@0oooo0000003oool0oooo0P0000030?ooo`8000001P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`030000003oool0000000H0oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo0`000000103oool000000000003oool3000003H0oooo2@000000103o
ool000000?ooo`3oool2000000<0oooo0P0000060?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool3000000040?oo
o`00000000000?ooo`<00000=P3oool5000000060?ooo`00000000000000003oool000000P3oool2
000000<0oooo0P0000060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000001P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000P3oool3000000030?ooo`000000000000@00000
8@3oool00200oooo2@0000000`3oool000000?ooo`020?ooo`040000003oool0oooo0?ooo`800000
1P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`080?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo0?ooo`H0000000@0oooo0000000000000000=P3oool9000000030?ooo`000000oooo
0080oooo00@000000?ooo`3oool0oooo0P0000060?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo0P000006
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo1P000000103oool000000000
0000000f0?ooo`T0000000@0oooo0000003oool0oooo0P0000030?ooo`8000001P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`8000001P3oool010000000oooo0?ooo`3oool2000000<0oooo1P000000103o
ool0000000000000000Q0?ooo`00803oool3000000080?ooo`00000000000000003oool000000?oo
o`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0?ooo`00
0000oooo100000020?ooo`800000=P3oool3000000080?ooo`00000000000000003oool000000?oo
o`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0?ooo`00
0000oooo10000000103oool0000000000000000f0?ooo`<0000000<0oooo0000000000000`000000
103oool000000?ooo`3oool2000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`080?ooo`8000001P3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`000000
0`000000103oool0000000000000000Q0?ooo`00803oool010000000oooo0000003oool300000003
0?ooo`000000oooo008000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool02@3oool2000000H0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`000000oooo00H0000000<0oooo000000000000=P3oool3000000070?ooo`0000000000
0000003oool000000?ooo`0200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00T0oooo0P0000060?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool000000?ooo`09000003H0oooo0`0000000`3oool0000000000003000000040?oo
o`00000000000?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0
oooo0P0000060?ooo`040000003oool0oooo0?ooo`8000000P3oool00`000000oooo000000080000
0240oooo000P0?ooo`<0000000<0oooo0000000000000`0000000`3oool00000000000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`80
0000>@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo0P0000060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@0000020?ooo`030000003oool000000080
0000=@3oool3000000030?ooo`000000000000<0000000@0oooo000000000000oooo0P0000040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool2000003T0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`090?ooo`8000001P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00D000000P3oool00`000000oooo00000002000003D0oooo0P0000020?oo
o`D0000000@0oooo000000000000oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02@3oool2000003T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`D000000P3o
ool00`000000oooo0000000200000200oooo000P0?ooo`<0000000<0oooo0000003oool00`000000
0`3oool00000000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool2
000000/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo0P0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool5
000000030?ooo`00000000000080oooo00<000000?ooo`0000000P00000e0?ooo`<0000000<0oooo
0000003oool00`000000103oool000000000003oool2000000@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo200000020?ooo`030000003oool0000000800000=@3oool200000080oooo00<0
00000?ooo`0000000P000000103oool000000000003oool2000000@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`80000000<0oooo0000000000001P3oool010000000oooo
0?ooo`3oool900000080oooo00<000000?ooo`0000000P00000P0?ooo`00803oool5000000040?oo
o`000000000000000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`040?oo
o`8000002`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool6000000D0oooo0`0000030?ooo`050000003oool0oooo0000003oool010000000
0`3oool0000000000003000003D0oooo1@000000103oool000000000000000020?ooo`040000003o
ool00000000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`H00000
1@3oool3000000<0oooo00D000000?ooo`3oool000000?ooo`0300000080oooo00<000000?ooo`00
00000P00000e0?ooo`80000000@0oooo000000000000oooo0`0000020?ooo`040000003oool00000
000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`L000001@3oool3
00000080oooo0P000000103oool000000000003oool300000080oooo00<000000?ooo`0000000P00
000P0?ooo`007`3oool3000000040?ooo`000000oooo0?ooo`@0000000<0oooo0000003oool00P00
00040?ooo`030000003oool0oooo00@0oooo0P00000;0?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P00
00050?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool000000?ooo`0400000003
0?ooo`000000000000<00000=03oool3000000040?ooo`000000oooo0?ooo`@0000000<0oooo0000
003oool00P0000040?ooo`030000003oool0oooo00<0oooo0`00000;0?ooo`030000003oool0oooo
03P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo0P0000050?ooo`050000003oool0oooo0000003oool00P0000020?ooo`030000003oool0
0000008000000P3oool00`000000oooo00000002000003@0oooo0`000000103oool000000?ooo`3o
ool4000000030?ooo`000000oooo00800000103oool00`000000oooo0?ooo`030?ooo`800000303o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`8000001@3oool01@000000oooo0?ooo`000000oooo00800000
0P3oool00`000000oooo0000000200000080oooo00<000000?ooo`0000000P00000P0?ooo`007`3o
ool3000000030?ooo`000000oooo0080oooo0`0000000`3oool000000?ooo`02000000@0oooo00<0
00000?ooo`3oool00`3oool3000000/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P00
00020?ooo`050000003oool000000000003oool00P0000000`3oool0000000000002000000030?oo
o`000000000000<00000=03oool3000000040?ooo`000000oooo0?ooo`@0000000<0oooo0000003o
ool00P0000040?ooo`030000003oool0oooo00<0oooo0`00000;0?ooo`030000003oool0oooo03T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo0P0000040?ooo`8000000P3oool01@000000oooo000000000000oooo0080000000<0oooo0000
000000000P0000000`3oool0000000000003000003@0oooo0`000000103oool000000?ooo`3oool4
000000030?ooo`000000oooo00800000103oool00`000000oooo0?ooo`030?ooo`800000303oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`800000103oool200000080oooo00D000000?ooo`00000000000?oo
o`02000000030?ooo`00000000000080000000<0oooo0000000000000`00000P0?ooo`007`3oool3
000000040?ooo`000000oooo0?ooo`@0000000<0oooo0000003oool00P0000040?ooo`030000003o
ool0oooo00<0oooo0`00000;0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`8000001@3oool2000000<0oooo00<000000?ooo`0000000`3o
ool3000000030?ooo`000000000000D0000000@0oooo000000000000oooo0P00000d0?ooo`D00000
0P3oool4000000030?ooo`000000oooo00800000103oool00`000000oooo0?ooo`030?ooo`<00000
2`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool2000000D0oooo0P0000030?ooo`030000003oool0000000<0oooo0`0000000`3oool00000
00000005000000040?ooo`00000000000?ooo`800000=03oool500000080oooo100000000`3oool0
00000?ooo`02000000@0oooo00<000000?ooo`3oool00`3oool2000000`0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P0000050?ooo`80
00000`3oool00`000000oooo000000030?ooo`<0000000<0oooo0000000000001@000000103oool0
00000000003oool200000200oooo000O0?ooo`<0000000@0oooo0000003oool0oooo100000000`3o
ool000000?ooo`02000000D0oooo00<000000?ooo`3oool00P3oool3000000/0oooo0P00000k0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`<000000P3oool00`000000oooo000000030?ooo`<0000000<0oooo0000003oool01@000000103o
ool000000000003oool3000003<0oooo1@0000020?ooo`@0000000<0oooo0000003oool00P000004
0?ooo`030000003oool0oooo00<0oooo0`00000;0?ooo`030000003oool0oooo03X0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00@0oooo0`0000020?ooo`030000003o
ool0000000<0oooo0`0000000`3oool000000?ooo`05000000040?ooo`00000000000?ooo`800000
=03oool500000080oooo100000000`3oool000000?ooo`02000000@0oooo00<000000?ooo`3oool0
0`3oool2000000`0oooo00<000000?ooo`3oool0>P3oool01@000000oooo0?ooo`3oool0000000D0
oooo00<000000?ooo`3oool0103oool300000080oooo00<000000?ooo`0000000`3oool300000003
0?ooo`000000oooo00D0000000@0oooo000000000000oooo0P00000P0?ooo`007`3oool500000003
0?ooo`000000000000<0000000<0oooo0000003oool00`0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`<000000P3oool00`000000
oooo000000030?ooo`<0000000<0oooo0000003oool01@000000103oool000000000003oool30000
03<0oooo1@0000000`3oool000000?ooo`03000000030?ooo`000000oooo00<000000`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000000/0oooo0P00000k0?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`<000000P3oool00`000000oooo00000003
0?ooo`<0000000<0oooo0000003oool01@000000103oool000000000003oool2000003@0oooo1@00
00000`3oool000000?ooo`03000000030?ooo`000000oooo00<000000`3oool00`000000oooo0?oo
o`030?ooo`<000002`3oool2000003/0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000
003oool0oooo00@0oooo0`0000001@3oool000000?ooo`3oool0000000<0oooo0`0000000`3oool0
00000?ooo`05000000040?ooo`00000000000?ooo`800000803oool001l0oooo1@0000000`3oool0
00000?ooo`05000000040?ooo`0000000000000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0000000<0?ooo`030000003oool0oooo03T0oooo0P0000030?ooo`040000003oool0oooo
0?ooo`8000001P3oool300000080oooo00<000000?ooo`0000000`3oool3000000030?ooo`000000
oooo00D0000000@0oooo000000000000oooo0`00000c0?ooo`D0000000<0oooo0000003oool01@00
0000103oool000000000000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000
2`3oool2000003/0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0
oooo0`0000020?ooo`030000003oool0000000<0oooo0`0000000`3oool000000?ooo`0500000004
0?ooo`00000000000?ooo`800000=03oool5000000030?ooo`000000oooo00D0000000@0oooo0000
0000000000000`3oool00`000000oooo0?ooo`030?ooo`<000002`3oool2000003/0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo0`0000001@3oool000000?oo
o`3oool0000000<0oooo0`0000000`3oool000000?ooo`05000000040?ooo`00000000000?ooo`80
0000803oool001l0oooo1@0000000`3oool000000?ooo`05000000040?ooo`000000oooo000000@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000<0?ooo`030000003oool0oooo03X0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`080000003oool00000
0000003oool000000?ooo`0000030?ooo`80000000@0oooo000000000000oooo10000000103oool0
00000000003oool4000003<0oooo1@0000000`3oool000000?ooo`05000000040?ooo`000000oooo
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000;0?ooo`800000?03oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo10000000103oool000000?oo
o`0000030?ooo`80000000@0oooo000000000000oooo10000000103oool000000000003oool30000
03@0oooo1@0000000`3oool000000?ooo`05000000040?ooo`000000oooo000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0000000;0?ooo`800000?03oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00D0oooo1@0000020?ooo`040000003oool0oooo0?ooo`800000
00@0oooo000000000000oooo10000000103oool000000000003oool300000200oooo000O0?ooo`D0
000000<0oooo0000003oool00`0000001P3oool00000000000000000oooo000000@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0000000<0?ooo`030000003oool0oooo03X0oooo0P000000
0`3oool000000?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000000P000002
0?ooo`070000003oool0oooo0000003oool000000?ooo`02000000030?ooo`000000000000800000
00@0oooo000000000000oooo1000000c0?ooo`D0000000<0oooo0000003oool00`0000001P3oool0
0000000000000000oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000;
0?ooo`800000?03oool010000000oooo0?ooo`0000030?ooo`8000001P3oool010000000oooo0000
003oool200000080oooo00L000000?ooo`3oool000000?ooo`000000oooo0080000000<0oooo0000
000000000P000000103oool000000000003oool4000003<0oooo1@0000000`3oool000000?ooo`03
000000060?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000/0oooo0P00000l0?ooo`040000003oool0oooo000000<0oooo0P0000060?ooo`04
0000003oool000000?ooo`8000000P3oool01`000000oooo0?ooo`000000oooo0000003oool00P00
00000`3oool0000000000002000000040?ooo`00000000000?ooo`@000007`3oool001l0oooo1@00
00000`3oool000000?ooo`07000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0000000<0?ooo`030000003oool0oooo03X0oooo0P0000000`3oool000000?oo
o`020?ooo`8000001`3oool00`000000oooo0000000200000080oooo00L000000?ooo`3oool00000
0?ooo`000000oooo0080000000<0oooo0000000000000P000000103oool000000000003oool40000
03<0oooo1@0000000`3oool000000?ooo`03000000060?ooo`00000000000000003oool00000103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000/0oooo0P00000l0?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool01@3oool010000000oooo0000003oool200000080
oooo00L000000?ooo`3oool000000?ooo`000000oooo0080000000<0oooo0000000000000P000000
103oool000000000003oool4000003<0oooo1@0000000`3oool000000?ooo`03000000060?ooo`00
000000000000003oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0000000/0
oooo0P00000l0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01@3oool01000
0000oooo0000003oool200000080oooo00L000000?ooo`3oool000000?ooo`000000oooo00800000
00<0oooo0000000000000P000000103oool000000000003oool4000001l0oooo000O0?ooo`L00000
00<0oooo0000000000000P0000001@3oool000000000003oool0000000@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0000000<0?ooo`030000003oool0oooo03X0oooo0P0000000`3oool0
00000?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000000P0000020?ooo`07
0000003oool0oooo0000003oool000000?ooo`02000000030?ooo`00000000000080000000<0oooo
0000003oool01@00000c0?ooo`L0000000@0oooo00000000000000000P3oool2000000030?ooo`00
0000oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000;0?ooo`800000?03o
ool2000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool01@3oool010000000oooo0000
003oool200000080oooo00L000000?ooo`3oool000000?ooo`000000oooo0080000000<0oooo0000
000000000P0000000`3oool000000?ooo`05000003<0oooo0P0000000`3oool00000000000020000
00050?ooo`00000000000000003oool00`0000000`3oool000000?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000002`3oool2000003`0oooo0P000000103oool000000?ooo`3o
ool2000000L0oooo00@000000?ooo`000000oooo0P0000020?ooo`070000003oool0oooo0000003o
ool000000?ooo`02000000030?ooo`00000000000080000000<0oooo0000003oool01@00000O0?oo
o`007`3oool600000080oooo10000000103oool000000000003oool2000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0000000<0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool00000008000000P3oool01`00
0000oooo0?ooo`000000oooo0000003oool00P0000000`3oool0000000000002000000030?ooo`00
0000oooo00D00000<`3oool600000080oooo10000000103oool000000000003oool2000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0000000<0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00800000
0`3oool01`000000oooo0?ooo`000000oooo0000003oool00P0000000`3oool00000000000020000
00030?ooo`000000oooo00D00000<P3oool3000000040?ooo`000000000000000080oooo1`000000
0`3oool00000000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000303oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool000000080oooo0P0000070?ooo`030000003oool0
oooo008000000`3oool00`000000oooo0?ooo`03000000040?ooo`00000000000?ooo`@0000000<0
oooo0000003oool01@00000O0?ooo`007`3oool600000080oooo100000000`3oool0000000000003
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000<0?ooo`030000003oool0
oooo03/0oooo0`0000020?ooo`8000001`3oool00`000000oooo0?ooo`0300000080oooo00D00000
0?ooo`3oool000000?ooo`04000000030?ooo`00000000000080000000<0oooo0000003oool01@00
000c0?ooo`H000000P3oool4000000030?ooo`000000000000<000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0000
00020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`0000020?ooo`050000003o
ool0oooo0000003oool0100000000`3oool0000000000002000000030?ooo`000000oooo00D00000
<P3oool3000000040?ooo`000000000000000080oooo2P0000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0k0?ooo`030000003oool000000080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0300000080oooo00<000000?ooo`3o
ool00P0000001@3oool00000000000000000oooo00@0000000<0oooo0000003oool01@00000O0?oo
o`007P3oool4000000030?ooo`00000000000080oooo100000000`3oool0000000000003000000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000<0?ooo`030000003oool0oooo03/0
oooo0`0000020?ooo`8000001`3oool00`000000oooo0?ooo`0300000080oooo00D000000?ooo`3o
ool000000?ooo`04000000030?ooo`0000000000008000000P3oool600000380oooo100000000`3o
ool00000000000020?ooo`@0000000<0oooo0000000000000`0000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0k0?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0300000080oooo00D000000?oo
o`3oool000000?ooo`04000000030?ooo`00000000000080000000<0oooo0000003oool01@00000b
0?ooo`@0000000<0oooo0000000000000P3oool:000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0000000<0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00<000000P3oool00`000000oooo0?ooo`02
000000050?ooo`00000000000000003oool0100000000`3oool000000?ooo`05000001l0oooo000N
0?ooo`@0000000<0oooo0000000000000P3oool4000000030?ooo`000000000000@000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0?03oool2
00000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0300000080oooo00D00000
0?ooo`3oool000000?ooo`04000000030?ooo`0000000000008000000P3oool600000380oooo1000
00000`3oool00000000000020?ooo`80000000<0oooo0000003oool01P0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0l0?ooo`8000000P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<000000P3oool01@000000oooo0?oo
o`000000oooo00@0000000<0oooo0000000000000P0000000`3oool000000?ooo`0500000380oooo
10000000103oool000000000003oool5000000030?ooo`000000000000@000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0?03oool200000003
0?ooo`000000000000P0oooo00<000000?ooo`3oool00`0000020?ooo`030000003oool0oooo0080
000000D0oooo00000000000000000?ooo`04000000030?ooo`000000oooo00D000007`3oool001h0
oooo100000000`3oool00000000000020?ooo`@0000000<0oooo0000000000000P0000001@3oool0
00000?ooo`3oool0000000@0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0l0?oo
o`8000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<000000P3oool01@00
0000oooo0?ooo`000000oooo00@0000000<0oooo0000000000000P0000020?ooo`H00000<P3oool4
000000030?ooo`00000000000080oooo100000000`3oool0000000000002000000050?ooo`000000
oooo0?ooo`000000103oool00`000000oooo0000000<0?ooo`030000003oool0oooo03`0oooo0P00
00020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`0000020?ooo`030000003o
ool0oooo0080000000<0oooo0000000000001P0000000`3oool000000?ooo`0500000380oooo1000
0000103oool000000000003oool5000000030?ooo`00000000000080000000D0oooo0000003oool0
oooo000000040?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0?03oool200000003
0?ooo`000000000000P0oooo00<000000?ooo`3oool00`0000000`3oool000000?ooo`020?ooo`80
000000<0oooo0000000000001P0000000`3oool000000?ooo`05000001l0oooo000N0?ooo`@00000
00@0oooo000000000000oooo1@0000000`3oool0000000000002000000050?ooo`000000oooo0?oo
o`000000103oool00`000000oooo0000000<0?ooo`030000003oool0oooo03`0oooo0P0000020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`0000020?ooo`050000003oool0oooo
0000003oool0100000000`3oool000000000000200000080oooo1P00000b0?ooo`@0000000@0oooo
000000000000oooo1@0000000`3oool0000000000002000000050?ooo`000000oooo0?ooo`000000
103oool00`000000oooo0000000<0?ooo`030000003oool0oooo03`0oooo00D000000?ooo`3oool0
oooo000000080?ooo`030000003oool0oooo00<000000P3oool00`000000oooo0?ooo`0200000003
0?ooo`000000000000H000000P3oool600000380oooo100000001P3oool000000000003oool00000
0?ooo`<0000000<0oooo0000000000000P0000001@3oool000000?ooo`3oool0000000<0oooo0P00
00000`3oool000000?ooo`0;0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool00P00
00080?ooo`030000003oool0oooo00<0000000<0oooo0000003oool00P3oool2000000030?ooo`00
0000000000H000000P3oool6000001l0oooo000N0?ooo`@0000000@0oooo000000000000oooo1@00
00000`3oool0000000000002000000050?ooo`000000oooo0?ooo`0000000P3oool010000000oooo
0000003oool2000000/0oooo00<000000?ooo`3oool0?03oool2000000030?ooo`000000000000P0
oooo00<000000?ooo`3oool00`0000020?ooo`050000003oool0oooo0000003oool02@0000020?oo
o`H00000<P3oool4000000040?ooo`00000000000?ooo`D0000000L0oooo000000000000oooo0000
003oool000000080oooo00P000000?ooo`3oool000000?ooo`000000oooo000000`0oooo00<00000
0?ooo`3oool0?03oool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool00`000002
0?ooo`030000003oool0oooo0080000000<0oooo0000000000001P0000020?ooo`H00000<P3oool4
000000060?ooo`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool000000?oo
o`0000000P3oool00`000000oooo0?ooo`03000000030?ooo`000000oooo00/0oooo00<000000?oo
o`3oool0?03oool2000000030?ooo`000000oooo00P0oooo00<000000?ooo`3oool00`000000203o
ool000000?ooo`3oool000000?ooo`000000oooo200000020?ooo`H000007`3oool001h0oooo1000
00001P3oool000000000003oool000000?ooo`<0000000<0oooo0000000000000P0000001@3oool0
00000?ooo`3oool000000080oooo0`0000020?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0?03oool2000000030?ooo`000000oooo00P0oooo00<000000?ooo`3oool00`0000020?oo
o`030000003oool0oooo0080000000<0oooo0000000000001P0000020?ooo`H00000<P3oool40000
00060?ooo`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0l0?ooo`80000000<0oooo0000003oool0203oool00`000000oooo0?ooo`0300000003
0?ooo`000000oooo0080oooo0P0000000`3oool000000000000600000080oooo1P00000b0?ooo`@0
000000H0oooo000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`000000oooo
000000020?ooo`030000003oool00000008000000P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo03`0oooo0P0000000`3oool000000?ooo`080?ooo`030000003oool0oooo00<00000
00P0oooo0000003oool0oooo0000003oool000000?ooo`P000000P3oool6000001l0oooo000N0?oo
o`@0000000H0oooo000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`000000
oooo000000020?ooo`040000003oool000000?ooo`8000000P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo03`0oooo0P0000000`3oool000000?ooo`080?ooo`030000003oool0oooo
00@0000000L0oooo0000003oool000000?ooo`000000oooo00P000000P3oool600000380oooo1000
00001P3oool000000000003oool000000?ooo`<0000000L0oooo000000000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0?03oool2000000030?ooo`000000oooo00P0oooo00<000000?ooo`3oool00`00
0000203oool000000?ooo`3oool000000?ooo`000000oooo200000020?ooo`H00000<P3oool40000
00060?ooo`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0l0?ooo`@000002@3oool020000000oooo0?ooo`000000oooo0000003oool00000
0P3oool010000000oooo0000003oool800000080oooo1P00000O0?ooo`007P3oool4000000060?oo
o`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3o
ool010000000oooo0000003oool200000080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0l0?ooo`<000002P3oool00`000000oooo0?ooo`0500000080oooo00@000000?ooo`000000
oooo200000020?ooo`H00000<P3oool4000000060?ooo`00000000000?ooo`000000oooo0`000000
1`3oool000000000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool000000080
oooo0P00000;0?ooo`030000003oool0oooo03`0oooo0`00000:0?ooo`030000003oool0oooo00<0
000000P0oooo0000003oool0oooo0000003oool000000?ooo`P000000P3oool600000380oooo1000
00001P3oool000000000003oool000000?ooo`<0000000L0oooo000000000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0?03oool3000000X0oooo00P000000?ooo`3oool000000?ooo`000000oooo0000
0080oooo00@000000?ooo`000000oooo200000020?ooo`H000007`3oool001h0oooo100000001P3o
ool000000000003oool000000?ooo`<0000000L0oooo000000000000oooo0000003oool000000080
oooo00@000000?ooo`000000oooo0P0000020?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0?03oool3000000X0oooo00@000000?ooo`3oool000000P3oool200000080oooo00@00000
0?ooo`000000oooo200000020?ooo`H00000<P3oool4000000060?ooo`00000000000?ooo`000000
oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0l0?ooo`<000002P3o
ool010000000oooo0?ooo`0000020?ooo`8000000P3oool010000000oooo0000003oool800000080
oooo1P00000b0?ooo`@0000000H0oooo000000000000oooo0000003oool3000000070?ooo`000000
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000P3oool2000000/0
oooo00<000000?ooo`3oool0?03oool3000000X0oooo00@000000?ooo`3oool000000P3oool20000
0080oooo00@000000?ooo`000000oooo200000020?ooo`H000007`3oool001h0oooo100000001P3o
ool000000000003oool000000?ooo`<0000000L0oooo000000000000oooo0000003oool000000080
oooo00@000000?ooo`000000oooo0P0000020?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0000000:0?ooo`040000003oool0oooo00000080oooo0P000002
0?ooo`040000003oool000000?ooo`P000000P3oool600000380oooo100000001P3oool000000000
003oool000000?ooo`<0000000L0oooo000000000000oooo0000003oool000000080oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0?03o
ool3000000X0oooo00@000000?ooo`3oool000000P3oool200000080oooo00@000000?ooo`000000
oooo200000020?ooo`H00000<P3oool4000000060?ooo`00000000000?ooo`000000oooo0`000000
1`3oool000000000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool000000080
oooo0P00000;0?ooo`030000003oool0oooo03`0oooo0`00000:0?ooo`040000003oool0oooo0000
0080oooo0P0000020?ooo`040000003oool000000?ooo`P000000P3oool6000001l0oooo000N0?oo
o`@0000000H0oooo000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`0000002P3oool010000000oooo0?ooo`000002
0?ooo`8000000P3oool010000000oooo0000003oool800000080oooo0P000000103oool000000000
0000000b0?ooo`@0000000H0oooo000000000000oooo0000003oool3000000070?ooo`0000000000
0?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo03`0oooo00<000000?ooo`0000002P3oool010000000oooo
0?ooo`0000020?ooo`8000000P3oool010000000oooo0000003oool800000080oooo1P00000b0?oo
o`@0000000H0oooo000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`0000000P3oool2000000/0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0000000:0?ooo`040000003oool0oooo00000080oooo0P000002
0?ooo`040000003oool000000?ooo`P000000P3oool6000001l0oooo000N0?ooo`@0000000H0oooo
000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?ooo`8000000P3o
ool010000000oooo0000003oool800000080oooo0P000000103oool0000000000000000b0?ooo`@0
000000H0oooo000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?oo
o`8000000P3oool010000000oooo0000003oool800000080oooo1P00000b0?ooo`@0000000H0oooo
000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?ooo`8000000P3o
ool010000000oooo0000003oool800000080oooo1P00000O0?ooo`007P3oool4000000060?ooo`00
000000000?ooo`000000oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000000P3oool200000080oooo
00@000000?ooo`000000oooo200000020?ooo`80000000@0oooo0000000000000000<P3oool40000
00060?ooo`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool000000?ooo`00
00000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000000P3oool2
00000080oooo00@000000?ooo`000000oooo200000020?ooo`H00000<P3oool4000000040?ooo`00
000000000?ooo`D0000000L0oooo000000000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0:0?ooo`040000003oool0oooo00000080oooo0P0000020?ooo`040000003o
ool000000?ooo`P000000P3oool6000001l0oooo000N0?ooo`@0000000H0oooo000000000000oooo
0000003oool3000000070?ooo`00000000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool00`000000oooo
000000020?ooo`L000000P3oool2000000040?ooo`000000000000000380oooo100000001P3oool0
00000000003oool000000?ooo`<0000000L0oooo000000000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo00000080oooo0P0000020?oo
o`040000003oool000000?ooo`P000000P3oool2000000040?ooo`000000000000000380oooo1000
0000103oool000000000003oool5000000070?ooo`00000000000?ooo`000000oooo000000020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?ooo`8000000P3o
ool010000000oooo0000003oool800000080oooo1P00000O0?ooo`007P3oool4000000060?ooo`00
000000000?ooo`000000oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3oool0
1@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000000P3oool200000080oooo
00<000000?ooo`0000000P3oool700000080oooo0P000000103oool0000000000000000b0?ooo`@0
000000H0oooo000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?oo
o`8000000P3oool010000000oooo0000003oool800000080oooo0P000000103oool0000000000000
000b0?ooo`@0000000@0oooo000000000000oooo1@0000001`3oool000000000003oool000000?oo
o`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000000P3o
ool200000080oooo00@000000?ooo`000000oooo200000020?ooo`H000007`3oool001h0oooo1000
00001P3oool000000000003oool000000?ooo`<0000000L0oooo000000000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo00000080oooo
0P0000020?ooo`040000003oool000000?ooo`P000000P3oool2000000040?ooo`00000000000000
0380oooo100000001P3oool000000000003oool000000?ooo`<0000000L0oooo000000000000oooo
0000003oool000000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo
00000080oooo0P0000020?ooo`040000003oool000000?ooo`P000000P3oool2000000040?ooo`00
0000000000000380oooo10000000103oool000000000003oool5000000070?ooo`00000000000?oo
o`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool02P3oool010000000oooo0?oo
o`0000020?ooo`8000000P3oool010000000oooo0000003oool800000080oooo1P00000O0?ooo`00
7P3oool4000000060?ooo`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
203oool2000003h0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000020?ooo`80
00000P3oool010000000oooo0000003oool800000080oooo0P000000103oool0000000000000000b
0?ooo`@0000000H0oooo000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`08
0?ooo`800000?P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo00000080oooo0P00
00020?ooo`040000003oool000000?ooo`P000000P3oool600000380oooo100000001P3oool00000
0000003oool000000?ooo`<0000000L0oooo000000000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo00P0oooo0P00000n0?ooo`030000
003oool0oooo00X0oooo00@000000?ooo`3oool000000P3oool200000080oooo00@000000?ooo`00
0000oooo200000020?ooo`H000007`3oool001h0oooo100000001P3oool000000000003oool00000
0?ooo`<0000000L0oooo000000000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo000000030?ooo`030000003oool0oooo00L0oooo0`00000n0?ooo`030000003oool0oooo00X0
oooo00@000000?ooo`3oool000000P3oool200000080oooo00@000000?ooo`000000oooo20000002
0?ooo`80000000@0oooo0000000000000000<P3oool4000000060?ooo`00000000000?ooo`000000
oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool01`3oool3000003h0oooo00<000000?ooo`3oool02P3o
ool010000000oooo0?ooo`0000020?ooo`8000000P3oool010000000oooo0000003oool800000080
oooo1P00000b0?ooo`@0000000H0oooo000000000000oooo0000003oool3000000070?ooo`000000
00000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000000P3oool2000000T0
oooo0`00000n0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000000P3oool20000
0080oooo00@000000?ooo`000000oooo200000020?ooo`H000007`3oool001h0oooo100000001P3o
ool000000000003oool000000?ooo`<0000000L0oooo000000000000oooo0000003oool000000080
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00L0oooo0`00000n0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P0000000`3oool00000000000020?oo
o`040000003oool000000?ooo`P000000P3oool2000000040?ooo`000000000000000380oooo1000
00001P3oool000000000003oool000000?ooo`<0000000L0oooo000000000000oooo0000003oool0
00000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00L0oooo0`00
000n0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P0000000`3oool000000000
00020?ooo`040000003oool000000?ooo`P000000P3oool600000380oooo100000001P3oool00000
0000003oool000000?ooo`<0000000L0oooo000000000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000020?ooo`030000003oool0oooo00P0oooo0`00000n0?ooo`030000
003oool0oooo00X0oooo00D000000?ooo`3oool000000?ooo`0300000080oooo00@000000?ooo`00
0000oooo200000020?ooo`H000007`3oool001h0oooo100000001P3oool000000000003oool00000
0?ooo`<0000000L0oooo000000000000oooo0000003oool000000080oooo00@000000?ooo`000000
oooo0P0000020?ooo`030000003oool0oooo00L0oooo0`00000n0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00P0000000`3oool00000000000020?ooo`040000003oool000000?oo
o`P000000P3oool2000000040?ooo`000000000000000380oooo100000001P3oool000000000003o
ool000000?ooo`<0000000L0oooo000000000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo000000030?ooo`030000003oool0oooo00L0oooo0`00000n0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00`000000203oool000000?ooo`3oool000000?ooo`000000
oooo200000020?ooo`H00000<P3oool4000000060?ooo`00000000000?ooo`000000oooo0`000000
1`3oool000000000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool000000080
oooo00<000000?ooo`3oool0203oool3000003h0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`03000000080?ooo`000000oooo0?ooo`000000oooo0000003oool800000080oooo1P00
000O0?ooo`007P3oool4000000060?ooo`00000000000?ooo`000000oooo0`0000001`3oool00000
0000003oool000000?ooo`0000000P3oool010000000oooo0000003oool200000080oooo00<00000
0?ooo`3oool01`3oool3000003h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`03
000000080?ooo`000000oooo0?ooo`000000oooo0000003oool800000080oooo1P00000b0?ooo`@0
000000H0oooo000000000000oooo0000003oool3000000070?ooo`00000000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000000P3oool2000000T0oooo0`00000n0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00`000000203oool000000?ooo`3oool00000
0?ooo`000000oooo200000020?ooo`H00000<P3oool4000000060?ooo`00000000000?ooo`000000
oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3oool01@000000oooo0000003o
ool000000080oooo00<000000?ooo`3oool01`3oool4000003h0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`03000000080?ooo`000000oooo0?ooo`000000oooo0000003oool80000
0080oooo1P00000O0?ooo`007P3oool4000000040?ooo`00000000000?ooo`D0000000L0oooo0000
00000000oooo0000003oool000000080oooo00@000000?ooo`000000oooo0P0000000`3oool00000
000000090?ooo`<00000?P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<00000
00<0oooo0000003oool00P3oool2000000030?ooo`000000000000H000000P3oool600000380oooo
100000001P3oool000000000003oool000000?ooo`<0000000L0oooo000000000000oooo0000003o
ool000000080oooo00@000000?ooo`000000oooo0P0000000`3oool000000?ooo`090?ooo`<00000
?P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0000000<0oooo0000003oool0
0P3oool2000000030?ooo`000000000000H000000P3oool600000380oooo100000001P3oool00000
0000003oool000000?ooo`<0000000L0oooo000000000000oooo0000003oool000000080oooo00D0
00000?ooo`000000oooo000000020?ooo`030000003oool0oooo00L0oooo1000000n0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00`000000203oool000000?ooo`3oool000000?oo
o`000000oooo200000020?ooo`H000007`3oool001h0oooo100000000`3oool00000000000020?oo
o`@0000000<0oooo0000000000000P000000203oool000000?ooo`3oool000000?ooo`000000oooo
0P0000000`3oool00000000000090?ooo`<00000?P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00<000000P3oool00`000000oooo0?ooo`02000000030?ooo`000000000000H00000
0P3oool600000380oooo100000001P3oool000000000003oool000000?ooo`<0000000L0oooo0000
00000000oooo0000003oool000000080oooo00@000000?ooo`000000oooo0P0000000`3oool00000
0?ooo`090?ooo`<00000?P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<00000
0P3oool00`000000oooo0?ooo`02000000030?ooo`000000000000H000000P3oool600000380oooo
100000001P3oool000000000003oool000000?ooo`<0000000L0oooo000000000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00L0oooo
1000000n0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`000000203oool00000
0?ooo`3oool000000?ooo`000000oooo200000020?ooo`H000007`3oool001h0oooo100000000`3o
ool00000000000020?ooo`@0000000<0oooo0000000000000P000000203oool000000?ooo`3oool0
00000?ooo`000000oooo0P0000000`3oool000000?ooo`080?ooo`80000000<0oooo0000003oool0
?P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<000000P3oool00`000000oooo
0?ooo`02000000050?ooo`00000000000000003oool0100000020?ooo`H00000<P3oool400000006
0?ooo`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool000000?ooo`000000
0P3oool010000000oooo0000003oool2000000030?ooo`000000oooo00P0oooo0P0000000`3oool0
00000?ooo`0m0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`0000020?ooo`03
0000003oool0oooo0080000000<0oooo0000000000001P0000020?ooo`H00000<P3oool400000006
0?ooo`00000000000?ooo`000000oooo0`0000001`3oool000000000003oool000000?ooo`000000
0P3oool010000000oooo0000003oool2000000030?ooo`000000oooo00P0oooo00@000000?ooo`3o
ool00000?P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0000000<0oooo0000
003oool00P3oool2000000030?ooo`000000000000H000000P3oool6000001l0oooo000N0?ooo`@0
000000<0oooo0000000000000P3oool4000000030?ooo`00000000000080000000H0oooo0000003o
ool0oooo0000003oool4000000030?ooo`000000oooo00P0oooo00<000000?ooo`3oool00P00000n
0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000103oool01@000000oooo0?oo
o`000000oooo00@0000000<0oooo0000000000000P0000020?ooo`H00000<P3oool4000000060?oo
o`00000000000?ooo`000000oooo0`0000000`3oool0000000000002000000060?ooo`000000oooo
0?ooo`000000oooo100000000`3oool000000?ooo`080?ooo`030000003oool0oooo00800000?@3o
ool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0P0000000`3oool0000000000006000000030?ooo`000000oooo00D00000<P3oool4000000060?oo
o`00000000000?ooo`000000oooo0`0000000`3oool0000000000002000000060?ooo`000000oooo
0?ooo`000000oooo100000000`3oool000000?ooo`080?ooo`030000003oool0oooo00800000?@3o
ool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool0
oooo0P0000000`3oool0000000000004000000050?ooo`000000oooo0000003oool01@00000O0?oo
o`007`3oool3000000030?ooo`00000000000080oooo100000000`3oool000000000000200000005
0?ooo`000000oooo0?ooo`0000000P3oool3000000030?ooo`000000oooo00P0oooo00<000000?oo
o`3oool00P00000n0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000103oool0
1@000000oooo0?ooo`000000oooo00@0000000<0oooo0000000000000P0000020?ooo`H00000<P3o
ool4000000040?ooo`00000000000?ooo`D0000000<0oooo0000000000000P0000001@3oool00000
0?ooo`3oool000000080oooo0`0000000`3oool000000?ooo`080?ooo`030000003oool0oooo0080
0000?@3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00P0000001@3oool00000000000000000oooo00@0000000<0oooo0000003oool01@00000b
0?ooo`@0000000@0oooo000000000000oooo1@0000000`3oool0000000000002000000060?ooo`00
0000oooo0?ooo`000000oooo0P000000103oool000000?ooo`0000080?ooo`8000000P3oool20000
03d0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0
oooo0?ooo`80000000D0oooo00000000000000000?ooo`02000000050?ooo`000000oooo0000003o
ool01@00000O0?ooo`007`3oool3000000030?ooo`00000000000080oooo100000000`3oool00000
00000002000000050?ooo`000000oooo0?ooo`0000000P3oool3000000030?ooo`000000oooo00P0
oooo00<000000?ooo`3oool00P00000n0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3o
ool00000103oool01@000000oooo0?ooo`000000oooo00@0000000<0oooo0000000000000P000000
0`3oool000000?ooo`0500000380oooo100000000`3oool00000000000020?ooo`@0000000<0oooo
0000000000000P0000001@3oool000000?ooo`3oool000000080oooo0`0000000`3oool000000?oo
o`080?ooo`030000003oool0oooo00800000?@3oool00`000000oooo0?ooo`0:0?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00P0000001@3oool00000000000000000oooo00@0
000000<0oooo0000003oool01@00000b0?ooo`@0000000<0oooo0000000000000P3oool400000003
0?ooo`00000000000080000000H0oooo0000003oool0oooo0000003oool2000000040?ooo`000000
oooo000000P0oooo0P0000020?ooo`800000?@3oool00`000000oooo0?ooo`0:0?ooo`040000003o
ool0oooo000000<0oooo00@000000?ooo`3oool0oooo0`000000103oool000000000003oool20000
00050?ooo`000000oooo0000003oool01@00000O0?ooo`007`3oool600000080oooo100000000`3o
ool0000000000002000000050?ooo`000000oooo0?ooo`0000000P3oool01@000000oooo0000003o
ool0000000P0oooo00@000000?ooo`3oool0oooo0P00000n0?ooo`030000003oool0oooo00T0oooo
00@000000?ooo`3oool00000103oool01`000000oooo0?ooo`000000oooo0000003oool00P000000
0`3oool0000000000002000000030?ooo`000000oooo00D00000<P3oool700000080oooo10000000
0`3oool000000000000400000080oooo00P000000?ooo`3oool000000?ooo`000000oooo000000P0
oooo00@000000?ooo`3oool0oooo0P00000n0?ooo`030000003oool0oooo00T0oooo00@000000?oo
o`3oool00000103oool01`000000oooo0?ooo`000000oooo0000003oool00P0000000`3oool00000
00000002000000030?ooo`000000oooo00D00000<P3oool4000000030?ooo`00000000000080oooo
100000000`3oool000000000000400000080oooo00P000000?ooo`3oool000000?ooo`000000oooo
000000P0oooo00@000000?ooo`3oool0oooo0P00000n0?ooo`030000003oool0oooo00T0oooo00@0
00000?ooo`3oool00000103oool01`000000oooo0?ooo`000000oooo0000003oool00P0000000`3o
ool0000000000002000000030?ooo`000000oooo00D000007`3oool001l0oooo1P0000020?ooo`@0
000000<0oooo0000000000000P0000001@3oool000000?ooo`3oool000000080oooo00D000000?oo
o`000000oooo000000080?ooo`040000003oool0oooo0?ooo`<00000?@3oool00`000000oooo0?oo
o`090?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0oooo0P000000103oool0
00000000003oool4000000030?ooo`000000oooo00D00000<P3oool700000080oooo2P0000030?oo
o`080000003oool0oooo0000003oool000000?ooo`0000080?ooo`040000003oool0oooo0?ooo`<0
0000?@3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`3oool0oooo0P000000103oool000000000003oool4000000030?ooo`000000oooo00D00000<P3o
ool700000080oooo2P0000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000080?oo
o`040000003oool0oooo0?ooo`800000?P3oool00`000000oooo0?ooo`090?ooo`040000003oool0
oooo000000@0oooo00@000000?ooo`3oool0oooo0P000000103oool000000000003oool400000003
0?ooo`000000oooo00D000007`3oool001l0oooo1P0000020?ooo`@0000000<0oooo000000000000
0P0000001@3oool000000?ooo`3oool000000080oooo00D000000?ooo`000000oooo000000080?oo
o`040000003oool0oooo0?ooo`<00000?@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
000000@0oooo00@000000?ooo`3oool0oooo0P000000103oool000000000003oool4000000030?oo
o`000000oooo00D00000<`3oool600000080oooo2P0000030?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000080?ooo`040000003oool0oooo0?ooo`<00000?@3oool00`000000oooo0?oo
o`090?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0oooo0P000000103oool0
00000000003oool4000000030?ooo`000000oooo00D00000<`3oool600000080oooo2P0000030?oo
o`080000003oool0oooo0000003oool000000?ooo`0000080?ooo`040000003oool0oooo0?ooo`80
0000?P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`3oool0oooo0P000000103oool000000000003oool4000000030?ooo`000000oooo00D000007`3o
ool001l0oooo1@0000000`3oool000000?ooo`0:000000<0oooo00<000000?ooo`3oool00`000000
0`3oool000000?ooo`060?ooo`8000000`3oool3000003d0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`00000000000?oo
o`04000000030?ooo`000000oooo00D00000<`3oool5000000030?ooo`000000oooo00X000000`3o
ool00`000000oooo0?ooo`03000000030?ooo`000000oooo00H0oooo0P0000030?ooo`<00000?@3o
ool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo000000000000oooo00@0000000<0oooo0000003oool01@00000c0?ooo`L0
000000<0oooo000000000000200000030?ooo`080000003oool0oooo0000003oool000000?ooo`00
00070?ooo`8000000P3oool4000003d0oooo00<000000?ooo`3oool02@3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`00000000000?ooo`0400000003
0?ooo`000000oooo00D000007`3oool001l0oooo1@0000000`3oool000000?ooo`0:000000<0oooo
00<000000?ooo`0000000`0000000`3oool000000?ooo`060?ooo`040000003oool0oooo0?ooo`80
000000<0oooo0000003oool0?03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000@0
oooo00<000000?ooo`3oool00P3oool01@000000oooo000000000000oooo00@0000000<0oooo0000
003oool01@00000c0?ooo`D0000000<0oooo0000003oool02P0000030?ooo`030000003oool00000
00<0000000<0oooo0000003oool01P3oool010000000oooo0?ooo`3oool2000000030?ooo`000000
oooo03`0oooo00<000000?ooo`3oool02@3oool00`000000oooo000000050?ooo`030000003oool0
oooo0080oooo00D000000?ooo`00000000000?ooo`04000000030?ooo`000000oooo00D00000<`3o
ool7000000030?ooo`000000000000P000000`3oool020000000oooo000000000000oooo0000003o
ool000001`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo000000000000oooo00@0000000<0oooo0000003oool01@00000O0?ooo`007`3oool5
000000030?ooo`000000oooo00<0000000D0oooo00000000000000000?ooo`02000000<0oooo00@0
00000?ooo`000000oooo0P0000000`3oool000000?ooo`060?ooo`040000003oool0oooo0?ooo`80
000000<0oooo000000000000?03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000@0
oooo00<000000?ooo`3oool00P3oool01@000000oooo000000000000oooo00@0000000@0oooo0000
00000000oooo1000000c0?ooo`D0000000<0oooo0000003oool00`0000001@3oool0000000000000
0000oooo008000000`3oool010000000oooo0000003oool2000000030?ooo`000000oooo00H0oooo
00@000000?ooo`3oool0oooo0P0000000`3oool000000000000l0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`050000003oool000000000
003oool010000000103oool000000000003oool4000003<0oooo1`0000001@3oool0000000000000
0000oooo00H000000`3oool00`000000oooo00000003000000030?ooo`000000oooo00H0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000
00000?ooo`05000000030?ooo`000000oooo00@000007`3oool001l0oooo1@0000000`3oool00000
0?ooo`03000000050?ooo`00000000000000003oool00P0000030?ooo`040000003oool000000?oo
o`80000000<0oooo0000003oool01P3oool010000000oooo0?ooo`3oool2000000030?ooo`000000
000003`0oooo00<000000?ooo`3oool02P3oool00`000000oooo000000040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000001P000000103oool000000000003oool4000003<0oooo1@00
00000`3oool000000?ooo`03000000030?ooo`000000000000@000000`3oool010000000oooo0000
003oool2000000030?ooo`000000oooo00H0oooo00@000000?ooo`3oool0oooo0P0000000`3oool0
00000000000l0?ooo`030000003oool0oooo00X0oooo0P0000050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000001P000000103oool000000000003oool4000003<0oooo1`0000001@3o
ool00000000000000000oooo00H000000`3oool010000000oooo0000003oool2000000030?ooo`00
0000oooo00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool02P3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
00000007000000030?ooo`000000oooo00@000007`3oool001l0oooo1@0000000`3oool000000?oo
o`03000000050?ooo`00000000000000003oool00P0000020?ooo`050000003oool0oooo0000003o
ool00P0000000`3oool000000?ooo`050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000000l0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`000000103oool00`00
0000oooo0?ooo`020?ooo`030000003oool000000080000000<0oooo0000000000000P000000103o
ool000000000003oool3000003<0oooo1@0000000`3oool000000?ooo`03000000030?ooo`000000
000000@000000P3oool01@000000oooo0?ooo`000000oooo0080000000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000?03oool00`000000oooo
0?ooo`0:0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000800000
00<0oooo0000000000000P000000103oool000000000003oool3000003<0oooo1@0000000`3oool0
00000?ooo`03000000030?ooo`000000000000<000000`3oool01@000000oooo0?ooo`000000oooo
0080000000<0oooo0000003oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00800000?03oool00`000000oooo0?ooo`0:0?ooo`8000001@3oool00`000000oooo0?ooo`020?oo
o`030000003oool000000080000000<0oooo0000000000000P000000103oool000000000003oool3
000001l0oooo000O0?ooo`D0000000<0oooo0000003oool01@0000000`3oool000000?ooo`020000
0080oooo00<000000?ooo`0000000`3oool00`000000oooo000000060?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo0000000m0?ooo`030000003oool0oooo00T0oooo0P000005
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`00000000000P3oool4000000040?ooo`00
000000000?ooo`800000=03oool5000000030?ooo`000000oooo00D0000000<0oooo000000000000
0P0000020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001P3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000?@3oool00`000000oooo0?ooo`090?ooo`80
00001@3oool00`000000oooo0?ooo`020?ooo`040000003oool0000000000080oooo10000000103o
ool000000000003oool2000003@0oooo1@0000000`3oool000000?ooo`05000000040?ooo`000000
0000000000<0oooo00<000000?ooo`0000000`3oool3000000H0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000003`0oooo00<000000?ooo`3oool02P3oool2000000D0oooo
00<000000?ooo`3oool00P3oool010000000oooo0000000000020?ooo`@0000000<0oooo00000000
00000`00000P0?ooo`007`3oool5000000030?ooo`000000oooo00D0000000@0oooo0000003oool0
00000`3oool00`000000oooo000000030?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool02@3oool2000000D0oooo00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`00
00000`000000103oool000000000003oool2000003@0oooo1@0000000`3oool000000?ooo`050000
00040?ooo`0000000000000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo00000005
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo00T0oooo0P0000050?ooo`030000003oool0oooo0080oooo0P000002
0?ooo`030000003oool0000000<0000000@0oooo000000000000oooo0P00000d0?ooo`D0000000<0
oooo0000003oool01@000000103oool000000000000000030?ooo`030000003oool0000000<0oooo
0`0000050?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P00000k0?ooo`03
0000003oool0oooo00X0oooo0P0000050?ooo`030000003oool0oooo0080oooo0P0000020?ooo`03
0000003oool0000000<0000000<0oooo0000000000000`00000P0?ooo`007`3oool3000000040?oo
o`000000oooo0?ooo`H0000000<0oooo0000000000000P0000020?ooo`030000003oool0000000@0
oooo0P0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo00T0oooo0P0000050?ooo`030000003oool0oooo0080
oooo0P0000020?ooo`030000003oool0000000<0000000@0oooo000000000000oooo0P00000d0?oo
o`D0000000D0oooo00000000000000000?ooo`03000000030?ooo`0000000000008000000P3oool0
0`000000oooo000000030?ooo`<000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`090?ooo`8000001@3oool0
0`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo00000003000000040?ooo`000000
00000?ooo`800000=03oool5000000050?ooo`000000oooo0000003oool00`0000000`3oool00000
0000000200000080oooo00<000000?ooo`0000000`3oool2000000D0oooo0P0000050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0:0?ooo`800000
1@3oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo00000003000000030?oo
o`000000000000<00000803oool001l0oooo0`000000103oool000000?ooo`3oool6000000030?oo
o`000000000000<0000000@0oooo0000000000000000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo00T0oooo0P0000050?ooo`030000003oool0oooo0080oooo0P0000020?ooo`03
0000003oool00000008000000P3oool2000000030?ooo`000000000003@0oooo0`000000103oool0
00000?ooo`3oool6000000030?ooo`000000000000<0000000@0oooo0000000000000000103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00T0oooo0P0000050?ooo`030000003oool0
oooo0080oooo0P0000020?ooo`030000003oool00000008000000P3oool00`000000oooo0?ooo`02
000003@0oooo0`000000103oool000000?ooo`3oool6000000030?ooo`000000000000<0000000@0
oooo00000000000000000`3oool2000000D0oooo00<000000?ooo`3oool00`3oool2000000@0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0:0?ooo`8000001@3oool00`000000oooo
0?ooo`020?ooo`8000000P3oool00`000000oooo0000000200000080oooo00<000000?ooo`000000
0P00000P0?ooo`007`3oool3000000040?ooo`00000000000?ooo`H0000000<0oooo000000000000
0P3oool010000000oooo0000000000050?ooo`8000000`3oool2000000H0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo0000000200000080
oooo0P0000000`3oool000000000000d0?ooo`<0000000@0oooo000000000000oooo1P0000000`3o
ool00000000000020?ooo`040000003oool00000000000D0oooo0P0000030?ooo`8000001P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0
0000008000000P3oool00`000000oooo00000002000003@0oooo0`000000103oool000000000003o
ool6000000030?ooo`00000000000080oooo00@000000?ooo`00000000001@3oool2000000<0oooo
00<000000?ooo`3oool0103oool2000000D0oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool200000080oooo
00<000000?ooo`0000000P0000020?ooo`050000003oool000000?ooo`000000803oool00200oooo
1@0000001@3oool00000000000000000oooo0080000000<0oooo0000000000000`3oool2000000H0
oooo1P0000060?ooo`8000001@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0000
003oool00`0000020?ooo`030000003oool0000000800000=03oool6000000050?ooo`0000000000
0000003oool00P0000000`3oool00000000000020?ooo`<000001P3oool6000000H0oooo0P000005
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool000000?ooo`0300000080oooo00<0
00000?ooo`0000000P00000d0?ooo`H0000000D0oooo00000000000000000?ooo`02000000030?oo
o`00000000000080oooo0`0000060?ooo`H000001P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool000000?ooo`0300000080oooo00<000000?ooo`00
00000P00000P0?ooo`00803oool5000000050?ooo`00000000000000003oool01@0000040?ooo`03
0000003oool0oooo00@0oooo0P00000:0?ooo`8000001P3oool00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo0?ooo`D0000000<0oooo0000003oool00`00000e0?ooo`D0000000D0oooo0000
0000000000000?ooo`05000000@0oooo00<000000?ooo`3oool0103oool2000000X0oooo0P000006
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo1@0000000`3oool000000?oo
o`03000003D0oooo1@0000001@3oool00000000000000000oooo00D00000103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0000003oool0100000000`3oool000000?ooo`0300000200
oooo000P0?ooo`<0000000<0oooo0000003oool01P0000020?ooo`050000003oool0oooo0?ooo`00
00001P3oool3000000X0oooo00<000000?ooo`3oool01@3oool2000003T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool0oooo1`000000103oool0000000000000000e0?ooo`<0000000<0oooo0000003oool01P000002
0?ooo`050000003oool0oooo0?ooo`0000001P3oool3000000X0oooo00<000000?ooo`3oool01@3o
ool2000003T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`040000003o
ool0oooo0?ooo`8000000`3oool600000080oooo0`00000e0?ooo`<0000000<0oooo0000003oool0
1@0000030?ooo`050000003oool0oooo0?ooo`0000001P3oool2000000/0oooo00<000000?ooo`3o
ool01@3oool2000003T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`04
0000003oool0oooo0?ooo`8000000P3oool00`000000oooo0000000400000080oooo0P00000Q0?oo
o`00803oool3000000030?ooo`000000oooo00H0000000<0oooo0000000000000`3oool00`000000
oooo0?ooo`040?ooo`<000002P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool0oooo1@0000000`3oool000000?ooo`03000003D0oooo0`0000000`3o
ool000000?ooo`06000000030?ooo`000000000000<0oooo00<000000?ooo`3oool0103oool30000
00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool2000000<0oooo1P000002
0?ooo`<00000=@3oool3000000030?ooo`000000oooo00D000000P3oool2000000<0oooo00<00000
0?ooo`3oool0103oool2000000/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3o
ool200000080oooo00<000000?ooo`000000100000020?ooo`8000008@3oool00200oooo0`000000
0`3oool0000000000003000000040?ooo`000000oooo0?ooo`8000000`3oool00`000000oooo0?oo
o`040?ooo`<000002@3oool2000000P0oooo0P00000h0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<00000
00D0oooo0000003oool000000?ooo`03000003D0oooo0`0000000`3oool000000000000300000004
0?ooo`000000oooo0?ooo`8000000`3oool00`000000oooo0?ooo`040?ooo`<000002@3oool20000
00P0oooo0P00000h0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`3oool2000000<0oooo1P0000020?ooo`<00000=@3oool3000000030?ooo`000000
000000<0000000@0oooo0000003oool0oooo0P0000030?ooo`030000003oool0oooo00@0oooo0P00
000:0?ooo`800000203oool2000003P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo0?ooo`8000000P3oool00`000000oooo00000004000000040?oo
o`000000000000000240oooo000P0?ooo`<0000000P0oooo00000000000000000?ooo`000000oooo
00000080oooo0P0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000002@3oool2
000000T0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool020000000oooo0?ooo`3oool000000?ooo`000000
oooo1P00000f0?ooo`<0000000P0oooo00000000000000000?ooo`000000oooo00000080oooo0P00
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000002@3oool2000000T0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00@0
00000?ooo`3oool0oooo0P0000030?ooo`070000003oool000000000003oool000000?ooo`030000
03H0oooo0`000000203oool00000000000000000oooo0000003oool000000P3oool2000000<0oooo
00<000000?ooo`3oool0103oool2000000X0oooo0P0000090?ooo`030000003oool0oooo03H0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`80
00000P3oool00`000000oooo00000002000000030?ooo`000000oooo00<000008@3oool00200oooo
2@000000103oool000000?ooo`3oool2000000<0oooo00<000000?ooo`3oool0103oool010000000
oooo0000000000080?ooo`030000003oool0oooo00P0oooo0P00000h0?ooo`030000003oool0oooo
00P0oooo0P0000070?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0000003o
ool6000003H0oooo2@000000103oool000000?ooo`3oool2000000<0oooo00<000000?ooo`3oool0
103oool00`000000oooo000000090?ooo`030000003oool0oooo00P0oooo0P00000h0?ooo`030000
003oool0oooo00P0oooo0P0000070?ooo`030000003oool0oooo008000000`3oool01@000000oooo
000000000000oooo00D00000=P3oool9000000040?ooo`000000oooo0?ooo`8000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0203oool20000
03L0oooo00<000000?ooo`3oool02@3oool2000000L0oooo00<000000?ooo`3oool00P0000020?oo
o`030000003oool000000080000000<0oooo0000000000000`00000Q0?ooo`008@3oool800000004
0?ooo`000000oooo0?ooo`8000000P3oool2000000H0oooo00@000000?ooo`0000000000203oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0203oool0
0`000000oooo000000060?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0000
003oool200000080oooo0P00000g0?ooo`P0000000@0oooo0000003oool0oooo0P0000020?ooo`80
00001P3oool00`000000oooo000000090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000H0oooo00<000000?ooo`3o
ool00P0000030?ooo`040000003oool000000?ooo`80000000@0oooo0000000000000000=`3oool8
000000040?ooo`000000oooo0?ooo`8000000P3oool2000000H0oooo00<000000?ooo`0000002@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo000000060?ooo`030000003oool0oooo008000000`3oool3000000040?ooo`00
000000000?ooo`<000008@3oool00240oooo1@000000103oool000000?ooo`0000030?ooo`800000
0P3oool2000000H0oooo00@000000?ooo`00000000001`3oool2000000`0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000H0oooo00@000000?ooo`3o
ool0oooo0P0000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P00000g0?oo
o`D0000000@0oooo0000003oool000000`3oool200000080oooo0P0000050?ooo`80000000<0oooo
0000003oool01`3oool2000000`0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0000000H0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000
003oool000000080oooo00<000000?ooo`0000000P00000g0?ooo`D0000000@0oooo0000003oool0
00000`3oool200000080oooo0P0000050?ooo`80000000<0oooo0000003oool01`3oool2000000`0
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000H0
oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`<000000P3oool00`000000oooo00000002
00000240oooo000Q0?ooo`D0000000@0oooo0000003oool000000`3oool01@000000oooo0000003o
ool0000000L0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0203oool00`000000oooo000000060?ooo`060000
003oool0oooo0000003oool000000P3oool2000000050?ooo`000000oooo0000003oool00P00000h
0?ooo`<0000000H0oooo00000000000000000?ooo`0000030?ooo`050000003oool000000?ooo`00
00001P3oool200000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0203oool00`000000oooo000000060?ooo`06
0000003oool0oooo0000003oool000000P3oool2000000050?ooo`000000oooo0000003oool00P00
000h0?ooo`<0000000H0oooo00000000000000000?ooo`0000030?ooo`050000003oool000000?oo
o`0000001P3oool200000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0203oool00`000000oooo000000060?oo
o`060000003oool0oooo0000003oool000000P3oool2000000050?ooo`000000oooo0000003oool0
0P00000R0?ooo`008P3oool6000000030?ooo`000000oooo0080oooo00D000000?ooo`000000oooo
000000070?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000001P3oool01P000000
oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`000000oooo1000000i0?ooo`D0000000<0
oooo0000000000000`3oool01@000000oooo0000003oool0000000H0oooo0P0000020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`0000001P3oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00@000000?ooo`000000oooo1000000i0?ooo`D0000000<0oooo0000000000000`3oool0
1@000000oooo0000003oool0000000H0oooo0P0000020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`0000001P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`00
0000oooo1000000R0?ooo`008P3oool500000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo000000060?ooo`8000000P3oool2000000D0oooo0P00000?0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool01`3oool00`000000oooo000000060?ooo`060000003oool0oooo
0000003oool000000`3oool010000000oooo0?ooo`0000020?ooo`800000>@3oool5000000030?oo
o`00000000000080oooo00H000000?ooo`3oool000000?ooo`0000060?ooo`040000003oool0oooo
0?ooo`8000001@3oool2000000l0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`07
0?ooo`030000003oool0000000H0oooo00<000000?ooo`0000000P3oool01P000000oooo0?ooo`3o
ool000000?ooo`8000000P3oool2000003T0oooo1@0000000`3oool00000000000020?ooo`060000
003oool0oooo0000003oool000001P3oool010000000oooo0?ooo`3oool2000000D0oooo0P00000?
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0203oool00`000000oooo00000006
0?ooo`030000003oool000000080oooo00H000000?ooo`3oool0oooo0000003oool200000080oooo
0P00000R0?ooo`008`3oool01@000000oooo0?ooo`000000oooo00<0000000@0oooo0000003oool0
oooo0`0000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool01P3oool010000000
oooo0?ooo`0000060?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`02000003T0oooo0P0000020?ooo`040000003oool0000000000080oooo
00<000000?ooo`3oool00`0000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
1P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0000000<0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`02000003T0oooo0P000000103oool000000000003oool2
00000080oooo00<000000?ooo`3oool00`0000060?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool01`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0000000<0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0200000280oooo000S0?ooo`@0000000<0
oooo0000000000000P0000040?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`3oool000001`3oool2000000<0oooo00@000000?ooo`000000
00000P3oool010000000oooo00000000000k0?ooo`@0000000D0oooo000000000000oooo00000004
0?ooo`8000001@3oool2000000@0oooo00<000000?ooo`3oool00P3oool200000180oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000L0oooo0P00
00030?ooo`040000003oool0000000000080oooo00@000000?ooo`0000000000>`3oool400000005
0?ooo`00000000000?ooo`000000103oool2000000D0oooo0P0000040?ooo`030000003oool0oooo
0080oooo0P00000B0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool01P3oool01000
0000oooo0?ooo`0000070?ooo`8000000`3oool010000000oooo0000000000020?ooo`040000003o
ool00000000002<0oooo000U0?ooo`@0000000<0oooo000000000000103oool2000000D0oooo00<0
00000?ooo`3oool0103oool200000080oooo00<000000?ooo`3oool04@3oool2000003<0oooo00<0
00000?ooo`3oool01P3oool010000000oooo0?ooo`0000070?ooo`8000000`3oool010000000oooo
0000000000020?ooo`@00000?03oool01@000000oooo000000000000oooo00<00000103oool20000
00D0oooo00<000000?ooo`3oool0103oool2000000030?ooo`000000000001<0oooo0P00000c0?oo
o`030000003oool0oooo00H0oooo00@000000?ooo`3oool000001`3oool2000000<0oooo00@00000
0?ooo`00000000000P3oool4000003`0oooo00D000000?ooo`00000000000?ooo`03000000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`80000000<0oooo000000000000
4`3oool2000003<0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000070?ooo`80
00000`3oool010000000oooo0000000000020?ooo`@000008`3oool002D0oooo0`0000020?ooo`80
0000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo0`00000E0?ooo`80
0000<`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000001P3oool20000
00<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000?P3oool300000080oooo
0P0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool3000001D0oooo
0P00000c0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000060?ooo`80
00000`3oool02@000000oooo0000003oool000000?ooo`000000oooo0000000n0?ooo`<000000P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool3000001D0oooo0P00000b0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo
000000060?ooo`8000000`3oool02@000000oooo0000003oool000000?ooo`000000oooo0000000T
0?ooo`009P3oool200000080oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`0N0?oo
o`800000<P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool2000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
?P3oool300000080oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`0N0?ooo`800000
<P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
103oool2000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000?P3oool3
00000080oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`8000000`3oool01P000000oooo0000003oool000000?ooo`<00000
903oool002P0oooo00@000000?ooo`00000000000`3oool00`000000oooo000000040?ooo`030000
003oool0oooo0200oooo0P00000a0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`070000003oool0oooo0?ooo`000000oooo000000020?oo
o`040000003oool0oooo00000440oooo00@000000?ooo`00000000000`3oool00`000000oooo0000
00040?ooo`030000003oool0oooo0200oooo0P00000a0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`070000003oool0oooo0?ooo`000000
oooo000000020?ooo`040000003oool0oooo00000440oooo00@000000?ooo`00000000000`3oool0
0`000000oooo000000040?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool2
000000<0oooo00@000000?ooo`000000oooo0P0000000`3oool000000000000T0?ooo`00:03oool2
000000030?ooo`000000oooo0080oooo00@000000?ooo`00000000000`3oool00`000000oooo0?oo
o`0Q0?ooo`800000<03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool300000480
oooo0P0000000`3oool000000?ooo`020?ooo`040000003oool00000000000<0oooo00<000000?oo
o`3oool08@3oool200000300oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00D0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo0`00
00120?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo000000040?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool2000000<0oooo00<000000?ooo`0000000P3o
ool3000002D0oooo000/0?ooo`040000003oool0000000000080oooo0P0000000`3oool000000000
000T0?ooo`800000;`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool2000000@0oooo0P0000020?ooo`030000003oool0000004H0oooo00<0
00000?ooo`0000000`3oool2000000030?ooo`000000000002@0oooo0P00000_0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`800000103o
ool200000080oooo00<000000?ooo`000000A@3oool4000000<0oooo00@000000?ooo`3oool00000
9@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`030000
003oool0000002D0oooo000]0?ooo`030000003oool0oooo00<0oooo0P00000W0?ooo`800000;`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool2000000@0oooo0P0000020?ooo`800000B03oool00`000000oooo0?ooo`030?ooo`8000009`3o
ool2000002l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo0P0000040?ooo`8000000P3oool2000004P0oooo00<000000?ooo`3oool00`3o
ool2000002L0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000020?ooo`8000009P3o
ool005d0oooo0P00000^0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`800000103oool2000000040?ooo`000000oooo000007P0oooo0P00
000^0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`800000103oool2000000040?ooo`000000oooo000007P0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool2000000@0oooo0P000000103oool000000?ooo`00000V0?ooo`00GP3oool2000002d0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
0P0000040?ooo`060000003oool000000000003oool00000N@3oool2000002d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`060000003oool000000000003oool00000N@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`800000103o
ool01P000000oooo000000000000oooo000002H0oooo001O0?ooo`800000;03oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000030?ooo`030000003oool0000000800000N`3oool2000002`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
0`3oool00`000000oooo00000002000007/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000030?ooo`030000003oool00000008000009`3oool00600oooo0P00000[0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`1l0?ooo`800000:`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0W0?ooo`00H@3o
ool2000002/0oooo00D000000?ooo`3oool0oooo000000070?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo000000020?ooo`030000003oool0oooo07d0oooo0P00000[0?ooo`05
0000003oool0oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`1m0?ooo`800000:`3oool01@000000oooo0?ooo`3o
ool0000000L0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool000000080oooo
00<000000?ooo`3oool09`3oool00680oooo0P00000Z0?ooo`040000003oool0oooo000000T0oooo
00@000000?ooo`3oool000000`3oool2000000<0oooo00<000000?ooo`3oool0OP3oool2000002X0
oooo00@000000?ooo`3oool000002@3oool010000000oooo0?ooo`0000030?ooo`8000000P3oool0
0`000000oooo0?ooo`1o0?ooo`800000:P3oool010000000oooo0?ooo`0000090?ooo`040000003o
ool0oooo000000<0oooo0P0000020?ooo`030000003oool0oooo02P0oooo001S0?ooo`800000:@3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0000000D0oooo100000220?ooo`800000
:@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0000000D0oooo100000220?ooo`80
0000:@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0000000D0oooo1000000Z0?oo
o`00I03oool2000002T0oooo00<000000?ooo`0000002@3oool00`000000oooo000000050?ooo`03
0000003oool0000008@0oooo0P00000Y0?ooo`030000003oool0000000T0oooo00<000000?ooo`00
00001@3oool00`000000oooo000000240?ooo`800000:@3oool00`000000oooo000000090?ooo`03
0000003oool0000000@0oooo00@000000?ooo`3oool00000:`3oool006D0oooo0P00000X0?ooo`03
0000003oool0000000X0oooo0P0000050?ooo`030000003oool0oooo08D0oooo0P00000X0?ooo`03
0000003oool0000000T0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`250?ooo`80
0000:03oool00`000000oooo000000090?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool0;03oool006H0oooo0P00000X0?ooo`030000003oool0oooo00T0oooo0P0000040?ooo`030000
003oool0oooo08L0oooo0P00000X0?ooo`030000003oool0oooo00T0oooo0P0000040?ooo`030000
003oool0oooo08L0oooo0P00000X0?ooo`030000003oool0oooo00T0oooo0P0000040?ooo`030000
003oool0oooo02`0oooo001W0?ooo`8000009`3oool00`000000oooo0?ooo`090?ooo`800000103o
ool00`000000oooo0?ooo`280?ooo`8000009`3oool00`000000oooo0?ooo`090?ooo`800000103o
ool00`000000oooo0?ooo`280?ooo`8000009`3oool00`000000oooo0?ooo`090?ooo`800000103o
ool00`000000oooo0?ooo`0/0?ooo`00J03oool2000002D0oooo00<000000?ooo`0000002P3oool0
0`000000oooo00000003000008`0oooo0P00000U0?ooo`030000003oool0000000X0oooo00<00000
0?ooo`0000000`00002<0?ooo`8000009@3oool00`000000oooo0000000:0?ooo`030000003oool0
000000<00000;`3oool006T0oooo0P00000T0?ooo`030000003oool0000000X0oooo00<000000?oo
o`3oool0T03oool2000002@0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`2@0?oo
o`800000903oool00`000000oooo0000000:0?ooo`030000003oool0oooo0380oooo001Z0?ooo`80
00008P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0TP3oool20000
0280oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo0980oooo0P00000R
0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0c0?ooo`00J`3oool2
00000240oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo09<0oooo0P00000Q0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`2C0?ooo`8000008@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0<`3oool006`0oooo0P00000O0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2E0?ooo`8000007`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0U@3oool20000
01l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03@0oooo001^0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0103oool2000000<0
oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00@0
oooo0P0000030?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`040?ooo`8000000`3oool00`000000oooo0?ooo`0e0?ooo`00K`3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00L0oooo0`00002L0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool01`3oool3000009`0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`070?ooo`<00000>03oool00700oooo00<000000?ooo`3oool0603oool200000:T0oooo00<0
00000?ooo`3oool0603oool200000:T0oooo00<000000?ooo`3oool0603oool2000004@0oooo001a
0?ooo`800000603oool00`000000oooo0?ooo`2Y0?ooo`800000603oool00`000000oooo0?ooo`2Y
0?ooo`800000603oool00`000000oooo0?ooo`130?ooo`00L`3oool2000001D0oooo00<000000?oo
o`3oool0[03oool2000001D0oooo00<000000?ooo`3oool0[03oool2000001D0oooo00<000000?oo
o`3oool0A03oool007@0oooo0P00000D0?ooo`030000003oool0oooo0:d0oooo0P00000D0?ooo`03
0000003oool0oooo0:d0oooo0P00000D0?ooo`030000003oool0oooo04@0oooo001f0?ooo`800000
4@3oool00`000000oooo0?ooo`2`0?ooo`8000004@3oool00`000000oooo0?ooo`2`0?ooo`800000
4@3oool00`000000oooo0?ooo`150?ooo`00N03oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0;<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2c0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0AP3oool007T0oooo0P00000<0?ooo`030000003oool0
oooo0;D0oooo0P00000;0?ooo`800000]`3oool2000000/0oooo0P0000190?ooo`00NP3oool40000
00H0oooo0`00002i0?ooo`@000001P3oool300000;T0oooo100000060?ooo`<00000BP3oool007h0
oooo1`00002o0?ooo`H00000`03oool6000004d0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3o
oomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00
o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oo
oel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o
0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0oooo
G`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0
ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO
0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3o
oooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0
oooo003o0?ooool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?oo
ool0ooooG`3oool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3o
ool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0oooo
o`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00001\
\>"],
  ImageRangeCache->{{{0, 604.625}, {604.625, 0}} -> {-0.0750158, -0.0750158, \
0.00781485, 0.00781485}, {{14.375, 194.313}, {590.188, 410.25}} -> {-3.04566, \
-1.3371, 0.0437831, 0.0218778}, {{212.313, 392.25}, {590.188, 410.25}} -> \
{-8.82325, -1.3371, 0.0437833, 0.0218779}, {{410.25, 590.188}, {590.188, \
410.25}} -> {-14.6007, -1.3371, 0.0437831, 0.0218779}, {{14.375, 194.313}, \
{392.25, 212.313}} -> {-3.04565, -4.22424, 0.0437815, 0.0218787}, {{212.313, \
392.25}, {392.25, 212.313}} -> {-8.82294, -4.22424, 0.0437813, 0.0218787}, \
{{410.25, 590.188}, {392.25, 212.313}} -> {-14.6002, -4.22424, 0.0437813, \
0.0218787}, {{14.375, 194.313}, {194.313, 14.375}} -> {-3.04562, -7.11093, \
0.0437827, 0.0218775}, {{212.313, 392.25}, {194.313, 14.375}} -> {-8.82306, \
-7.11091, 0.0437825, 0.0218774}, {{410.25, 590.188}, {194.313, 14.375}} -> \
{-14.6005, -7.11091, 0.0437825, 0.0218774}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Double-well potential with strong driving force and weak damping\
\>", "Subsection"],

Cell["\<\
Next, consider a double-well potential including both damping and driving \
forces.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(duffingPlot[\(-1\), 0.5, 0.1, 1, 0.5, 0. , 0.2, 0, 500, 
        MaxSteps \[Rule] 10\^6, PlotRange \[Rule] All, 
        PlotPoints \[Rule] 100];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.502188 0.180611 0.509068 0.216915 [
[.14097 -0.0125 -9.34375 -15.6875 ]
[.14097 -0.0125 9.34375 0 ]
[.32158 -0.0125 -9.34375 -15.6875 ]
[.32158 -0.0125 9.34375 0 ]
[.50219 -0.0125 -5 -15.6875 ]
[.50219 -0.0125 5 0 ]
[.6828 -0.0125 -5 -15.6875 ]
[.6828 -0.0125 5 0 ]
[.86341 -0.0125 -5 -15.6875 ]
[.86341 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.9688 -31.375 ]
[.5 -0.0125 21.9688 -15.6875 ]
[-0.0125 .07524 -18.6875 -7.84375 ]
[-0.0125 .07524 0 7.84375 ]
[-0.0125 .29215 -18.6875 -7.84375 ]
[-0.0125 .29215 0 7.84375 ]
[-0.0125 .50907 -10 -7.84375 ]
[-0.0125 .50907 0 7.84375 ]
[-0.0125 .72598 -10 -7.84375 ]
[-0.0125 .72598 0 7.84375 ]
[-0.0125 .9429 -10 -7.84375 ]
[-0.0125 .9429 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -34.375 -20.4688 ]
[-0.01875 .5 -18.6875 20.4688 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -43.9375 0 ]
[.5 1.0125 43.9375 15.6875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14097 0 m
.14097 .00625 L
s
gsave
.14097 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.32158 0 m
.32158 .00625 L
s
gsave
.32158 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.50219 0 m
.50219 .00625 L
s
gsave
.50219 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.6828 0 m
.6828 .00625 L
s
gsave
.6828 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.86341 0 m
.86341 .00625 L
s
gsave
.86341 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.17709 0 m
.17709 .00375 L
s
.21321 0 m
.21321 .00375 L
s
.24933 0 m
.24933 .00375 L
s
.28546 0 m
.28546 .00375 L
s
.3577 0 m
.3577 .00375 L
s
.39382 0 m
.39382 .00375 L
s
.42994 0 m
.42994 .00375 L
s
.46607 0 m
.46607 .00375 L
s
.53831 0 m
.53831 .00375 L
s
.57443 0 m
.57443 .00375 L
s
.61055 0 m
.61055 .00375 L
s
.64668 0 m
.64668 .00375 L
s
.71892 0 m
.71892 .00375 L
s
.75504 0 m
.75504 .00375 L
s
.79117 0 m
.79117 .00375 L
s
.82729 0 m
.82729 .00375 L
s
.10484 0 m
.10484 .00375 L
s
.06872 0 m
.06872 .00375 L
s
.0326 0 m
.0326 .00375 L
s
.89953 0 m
.89953 .00375 L
s
.93565 0 m
.93565 .00375 L
s
.97178 0 m
.97178 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.9688 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
64.313 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
102.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07524 m
.00625 .07524 L
s
gsave
-0.0125 .07524 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .29215 m
.00625 .29215 L
s
gsave
-0.0125 .29215 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .50907 m
.00625 .50907 L
s
gsave
-0.0125 .50907 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .72598 m
.00625 .72598 L
s
gsave
-0.0125 .72598 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .9429 m
.00625 .9429 L
s
gsave
-0.0125 .9429 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .11862 m
.00375 .11862 L
s
0 .162 m
.00375 .162 L
s
0 .20539 m
.00375 .20539 L
s
0 .24877 m
.00375 .24877 L
s
0 .33554 m
.00375 .33554 L
s
0 .37892 m
.00375 .37892 L
s
0 .4223 m
.00375 .4223 L
s
0 .46568 m
.00375 .46568 L
s
0 .55245 m
.00375 .55245 L
s
0 .59583 m
.00375 .59583 L
s
0 .63922 m
.00375 .63922 L
s
0 .6826 m
.00375 .6826 L
s
0 .76937 m
.00375 .76937 L
s
0 .81275 m
.00375 .81275 L
s
0 .85613 m
.00375 .85613 L
s
0 .89952 m
.00375 .89952 L
s
0 .03185 m
.00375 .03185 L
s
0 .98628 m
.00375 .98628 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -108 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
81.4688 11.8438 translate
90 rotate
-81.4688 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(velocity) show
99.938 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.14097 .99375 m
.14097 1 L
s
.32158 .99375 m
.32158 1 L
s
.50219 .99375 m
.50219 1 L
s
.6828 .99375 m
.6828 1 L
s
.86341 .99375 m
.86341 1 L
s
.125 Mabswid
.17709 .99625 m
.17709 1 L
s
.21321 .99625 m
.21321 1 L
s
.24933 .99625 m
.24933 1 L
s
.28546 .99625 m
.28546 1 L
s
.3577 .99625 m
.3577 1 L
s
.39382 .99625 m
.39382 1 L
s
.42994 .99625 m
.42994 1 L
s
.46607 .99625 m
.46607 1 L
s
.53831 .99625 m
.53831 1 L
s
.57443 .99625 m
.57443 1 L
s
.61055 .99625 m
.61055 1 L
s
.64668 .99625 m
.64668 1 L
s
.71892 .99625 m
.71892 1 L
s
.75504 .99625 m
.75504 1 L
s
.79117 .99625 m
.79117 1 L
s
.82729 .99625 m
.82729 1 L
s
.10484 .99625 m
.10484 1 L
s
.06872 .99625 m
.06872 1 L
s
.0326 .99625 m
.0326 1 L
s
.89953 .99625 m
.89953 1 L
s
.93565 .99625 m
.93565 1 L
s
.97178 .99625 m
.97178 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .07524 m
1 .07524 L
s
.99375 .29215 m
1 .29215 L
s
.99375 .50907 m
1 .50907 L
s
.99375 .72598 m
1 .72598 L
s
.99375 .9429 m
1 .9429 L
s
.125 Mabswid
.99625 .11862 m
1 .11862 L
s
.99625 .162 m
1 .162 L
s
.99625 .20539 m
1 .20539 L
s
.99625 .24877 m
1 .24877 L
s
.99625 .33554 m
1 .33554 L
s
.99625 .37892 m
1 .37892 L
s
.99625 .4223 m
1 .4223 L
s
.99625 .46568 m
1 .46568 L
s
.99625 .55245 m
1 .55245 L
s
.99625 .59583 m
1 .59583 L
s
.99625 .63922 m
1 .63922 L
s
.99625 .6826 m
1 .6826 L
s
.99625 .76937 m
1 .76937 L
s
.99625 .81275 m
1 .81275 L
s
.99625 .85613 m
1 .85613 L
s
.99625 .89952 m
1 .89952 L
s
.99625 .03185 m
1 .03185 L
s
.99625 .98628 m
1 .98628 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .50907 m
1 .50907 L
s
.50219 0 m
.50219 1 L
s
gsave
.5 1.0125 -104.938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.063 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Duffing) show
102.938 15.813 moveto
(Equation) show
146.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.50219 .55245 m
.50954 .58371 L
.51963 .61261 L
.53541 .647 L
.55455 .68089 L
.59931 .74493 L
.66421 .81621 L
.70477 .84917 L
.75356 .87435 L
.77911 .87953 L
.80671 .8772 L
.85468 .84606 L
.89547 .77415 L
.92283 .66853 L
.93454 .55247 L
.93171 .42114 L
.92338 .35459 L
.90954 .29138 L
.8742 .20686 L
.8315 .1635 L
.78905 .15188 L
.74285 .15993 L
.71738 .17012 L
.69435 .18146 L
.64766 .20691 L
.62603 .2182 L
.6067 .2272 L
.57301 .23892 L
.53749 .24385 L
.50745 .24108 L
.47478 .23105 L
.438 .21255 L
.40091 .18881 L
.35302 .15537 L
.30409 .12372 L
.2539 .10027 L
.19811 .09376 L
.1665 .10414 L
.13784 .12642 L
.0907 .20609 L
.07161 .26653 L
.05646 .34281 L
.04459 .49827 L
.04703 .58546 L
.05494 .66114 L
.06922 .73292 L
.08995 .79317 L
.13171 .85032 L
.15767 .86175 L
.18209 .86107 L
Mistroke
.22549 .83842 L
.26713 .7949 L
.30166 .74285 L
.32765 .69151 L
.34554 .6461 L
.35926 .59912 L
.36466 .57317 L
.36845 .54644 L
.37039 .50098 L
.36864 .47487 L
.36504 .4513 L
.36027 .43108 L
.35352 .41015 L
.34544 .39082 L
.33492 .3709 L
.32317 .35311 L
.30901 .33609 L
.29458 .32265 L
.28052 .31285 L
.26649 .30616 L
.25136 .30245 L
.22397 .30604 L
.20916 .31468 L
.19644 .32703 L
.17474 .36365 L
.1596 .41221 L
.15391 .44458 L
.15047 .48128 L
.15129 .54912 L
.15562 .58557 L
.16204 .61735 L
.17149 .64873 L
.18409 .67755 L
.20813 .71196 L
.22353 .72569 L
.2388 .73513 L
.27097 .74586 L
.28953 .74835 L
.30669 .74923 L
.33558 .74922 L
.36721 .74939 L
.4004 .75233 L
.43195 .7594 L
.45048 .76583 L
.47121 .77504 L
.5111 .79822 L
.59735 .86405 L
.65513 .91026 L
.68975 .93506 L
.72395 .95544 L
Mistroke
.78742 .97619 L
.82168 .9739 L
.85779 .95652 L
.88751 .92613 L
.91627 .8762 L
.95623 .74096 L
.97072 .63495 L
.97619 .52693 L
.97409 .42988 L
.96459 .33187 L
.92963 .18747 L
.9056 .13905 L
.87609 .10504 L
.82003 .087 L
.76794 .10481 L
.71693 .143 L
.6738 .18589 L
.60724 .26174 L
.5772 .29575 L
.54924 .32419 L
.526 .34318 L
.5065 .35413 L
.48927 .35903 L
.47072 .35887 L
.45097 .35286 L
.43158 .34221 L
.40774 .32474 L
.38374 .30452 L
.35227 .27707 L
.31962 .2503 L
.28424 .22608 L
.2438 .20805 L
.20167 .20537 L
.17804 .21402 L
.15687 .23037 L
.12292 .28246 L
.09955 .35466 L
.09077 .40254 L
.08502 .45863 L
.08523 .56197 L
.09846 .65189 L
.12037 .71266 L
.14516 .74371 L
.17439 .75335 L
.20616 .74068 L
.23648 .70886 L
.25822 .67248 L
.27669 .62759 L
.28856 .58354 L
.29465 .54356 L
Mistroke
.29619 .49886 L
.29249 .45905 L
.2849 .42524 L
.27467 .39735 L
.26035 .37151 L
.24234 .35111 L
.22134 .3396 L
.19768 .34139 L
.17661 .35891 L
.15999 .38937 L
.14796 .43144 L
.1419 .477 L
.1414 .53335 L
.1474 .5847 L
.16054 .63329 L
.18048 .6718 L
.20099 .69312 L
.22567 .70522 L
.25323 .70776 L
.26866 .70576 L
.28254 .70251 L
.30871 .69397 L
.33235 .68525 L
.35315 .67825 L
.37202 .67352 L
.39127 .67116 L
.41243 .67223 L
.43092 .67662 L
.44847 .68371 L
.46878 .69514 L
.49181 .71155 L
.54807 .76147 L
.62618 .83762 L
.66932 .87626 L
.72005 .91343 L
.76673 .93532 L
.8198 .93868 L
.8747 .90447 L
.90255 .86337 L
.92483 .81096 L
.95587 .67281 L
.96654 .51427 L
.95806 .36465 L
.93542 .2501 L
.89834 .16571 L
.85075 .12532 L
.82248 .12161 L
.79659 .12755 L
.76893 .14184 L
.74112 .16303 L
Mistroke
.69853 .2063 L
.65863 .25646 L
.568 .39455 L
.54432 .43077 L
.53542 .44189 L
.52821 .44859 L
.5206 .45228 L
.5167 .45258 L
.51255 .45167 L
.50557 .44761 L
.49708 .43944 L
.4545 .38092 L
.36469 .26229 L
.32991 .22465 L
.28748 .18732 L
.24318 .16118 L
.20083 .15263 L
.15328 .1706 L
.12833 .19742 L
.10758 .23395 L
.07775 .3295 L
.06183 .45954 L
.06287 .57581 L
.07836 .68576 L
.10402 .76154 L
.13368 .80224 L
.172 .81747 L
.21372 .80305 L
.24991 .77018 L
.27901 .73068 L
.30413 .68533 L
.32476 .63589 L
.33816 .59094 L
.3455 .55203 L
.34846 .512 L
.34789 .4908 L
.34598 .47203 L
.33833 .43714 L
.33201 .41946 L
.32511 .40465 L
.31722 .39117 L
.30787 .37849 L
.28897 .36054 L
.27757 .35372 L
.26651 .3497 L
.25416 .34827 L
.24091 .35057 L
.22984 .35596 L
.21835 .36566 L
.20831 .37854 L
Mistroke
.19995 .39368 L
.1874 .42986 L
.17972 .47691 L
.17873 .52647 L
.18108 .55458 L
.18515 .57986 L
.1913 .60489 L
.19844 .62575 L
.20833 .6471 L
.21912 .66443 L
.24096 .68821 L
.26346 .70311 L
.28981 .7134 L
.30354 .71691 L
.31895 .71994 L
.34938 .72483 L
.3822 .73096 L
.39982 .73544 L
.41954 .74184 L
.4558 .75787 L
.49287 .77989 L
.53656 .81165 L
.62989 .88817 L
.68356 .9285 L
.71511 .94798 L
.74579 .96239 L
.77984 .97141 L
.81764 .96995 L
.84919 .9563 L
.88146 .92601 L
.90908 .88106 L
.93492 .81318 L
.96599 .64597 L
.97171 .45619 L
.95465 .29379 L
.91685 .16696 L
.86935 .10225 L
.82222 .08419 L
.77095 .0949 L
.71781 .12693 L
.66709 .16897 L
.5906 .23676 L
.55693 .26157 L
.53917 .27188 L
.52335 .27898 L
.49525 .28606 L
.46587 .28541 L
.43914 .27822 L
.41302 .26638 L
.34713 .22587 L
Mistroke
.30601 .20082 L
.26391 .18151 L
.22447 .17385 L
.18142 .18358 L
.15805 .20048 L
.13821 .22417 L
.11765 .26189 L
.10131 .30732 L
.08148 .40755 L
.07576 .52923 L
.08433 .62791 L
.10218 .70154 L
.12968 .754 L
.16419 .77631 L
.20126 .76803 L
.23381 .73903 L
.25902 .70212 L
.28103 .65566 L
.29502 .61333 L
.30496 .5662 L
.30919 .51803 L
.30763 .47472 L
.30161 .4368 L
.29248 .40465 L
.27883 .37316 L
.26091 .34567 L
.23809 .32453 L
.22423 .31784 L
.21114 .31565 L
.1873 .323 L
.16418 .34848 L
.1473 .3867 L
.13627 .43368 L
.13068 .49327 L
.13296 .5595 L
.14446 .62316 L
.15461 .65329 L
.16596 .67648 L
.1904 .70637 L
.20547 .71628 L
.21963 .72153 L
.24698 .72349 L
.27622 .71731 L
.30272 .70722 L
.32584 .69683 L
.34648 .68766 L
.36754 .67967 L
.38667 .67465 L
.40375 .67268 L
.42372 .67394 L
Mistroke
.44591 .68007 L
.46793 .69078 L
.48973 .70519 L
.54516 .75292 L
.61964 .82571 L
.65648 .85978 L
.69991 .89479 L
.75188 .92497 L
.80276 .9359 L
.85845 .9151 L
.90578 .85182 L
.93919 .75508 L
.96092 .6155 L
.96378 .44523 L
.95669 .36417 L
.94294 .28556 L
.90636 .18418 L
.86312 .13685 L
.81613 .12904 L
.77234 .14781 L
.7357 .17768 L
.69981 .217 L
.59691 .37723 L
.5683 .43837 L
.55487 .47399 L
.54837 .4952 L
.54743 .49834 L
.54666 .5005 L
.5461 .50147 L
.54554 .50161 L
.54442 .49959 L
.54362 .49722 L
.5427 .49431 L
.53679 .47678 L
.50556 .41131 L
.42791 .29356 L
.36207 .21314 L
.31514 .16656 L
.26536 .13002 L
.2164 .11164 L
.16901 .11743 L
.12853 .15 L
.09029 .22086 L
.06079 .33765 L
.04784 .49159 L
.05505 .63726 L
.07649 .74686 L
.1158 .83248 L
.13915 .85578 L
.16613 .86762 L
Mistroke
.2144 .86059 L
.25709 .83258 L
.28096 .81003 L
.3019 .78676 L
.33652 .74188 L
.39322 .65212 L
.43974 .56143 L
.44577 .54907 L
.45064 .54025 L
.45279 .53722 L
.45493 .53511 L
.45845 .53429 L
.46191 .53677 L
.46406 .5395 L
.46621 .54281 L
.47704 .56243 L
.5195 .63535 L
.56128 .69727 L
.62805 .78284 L
.6674 .82538 L
.6913 .84778 L
.71509 .86704 L
.75995 .89333 L
.8118 .90218 L
.8583 .88135 L
.90356 .81711 L
.93585 .71448 L
.95261 .59135 L
.95448 .45964 L
.94351 .3488 L
.91799 .24754 L
.88487 .18674 L
.84302 .15815 L
.79736 .16256 L
.76003 .18521 L
.72272 .22119 L
.68782 .26535 L
.65694 .31276 L
.61714 .38849 L
.60268 .42317 L
.59323 .45087 L
.58695 .47514 L
.58489 .48626 L
.58352 .49698 L
.58297 .51224 L
.58433 .52494 L
.58673 .53334 L
.59034 .54018 L
.59294 .54325 L
.59559 .5454 L
Mistroke
.60086 .54761 L
.6039 .54785 L
.60669 .54747 L
.6097 .54641 L
.61277 .54457 L
.61741 .53997 L
.62107 .53402 L
.62278 .52993 L
.62406 .52578 L
.62517 .52053 L
.62583 .51512 L
.62599 .50541 L
.62471 .49357 L
.62344 .48723 L
.62159 .48011 L
.61687 .46654 L
.61073 .45301 L
.60238 .43795 L
.58229 .40867 L
.49821 .31368 L
.44145 .25555 L
.40521 .22046 L
.36154 .1818 L
.31733 .14888 L
.29042 .13317 L
.2643 .12198 L
.21723 .11513 L
.16729 .13479 L
.12152 .19371 L
.08776 .28972 L
.06936 .40342 L
.06483 .54139 L
.07019 .62208 L
.08042 .69164 L
.11105 .79535 L
.15594 .86197 L
.18432 .88026 L
.21131 .88714 L
.25679 .88316 L
.3052 .86592 L
.35261 .84393 L
.39485 .82583 L
.43267 .81466 L
.47278 .81091 L
.50931 .81585 L
.54404 .82756 L
.58338 .84726 L
.62999 .87569 L
.6836 .90887 L
.73662 .93489 L
Mistroke
.78578 .94598 L
.83765 .93479 L
.88639 .88885 L
.93034 .79055 L
.95569 .66771 L
.96579 .51481 L
.9582 .37354 L
.93825 .26662 L
.9015 .17915 L
.85983 .14191 L
.81178 .14237 L
.76265 .1754 L
.74016 .19956 L
.71772 .22911 L
.68291 .2868 L
.65675 .34319 L
.63918 .39319 L
.62746 .44116 L
.62186 .48318 L
.62099 .5185 L
.62419 .55426 L
.63232 .59077 L
.64574 .62632 L
.66083 .65403 L
.68082 .6809 L
.69351 .69401 L
.70827 .70612 L
.72298 .71508 L
.73706 .7208 L
.76433 .72336 L
.79269 .71161 L
.8064 .69883 L
.81997 .67969 L
.84004 .63135 L
.84866 .59439 L
.85386 .55545 L
.85585 .51865 L
.85501 .47798 L
.84568 .40807 L
.82934 .35454 L
.8176 .33036 L
.80315 .30894 L
.7735 .28217 L
.74312 .26888 L
.70976 .26338 L
.68095 .26243 L
.64926 .26231 L
.61512 .26039 L
.58306 .25484 L
.54667 .24279 L
Mistroke
.52752 .2339 L
.50555 .22171 L
.42621 .16481 L
.37794 .12612 L
.32137 .08388 L
.26542 .05211 L
.20082 .03842 L
.14256 .06159 L
.09348 .12704 L
.0539 .24426 L
.03241 .38716 L
.02851 .56994 L
.04556 .7278 L
.08202 .85148 L
.10864 .89617 L
.13592 .92163 L
.19379 .93291 L
.22606 .92196 L
.25454 .90496 L
.30169 .86549 L
.34711 .81829 L
.41408 .74241 L
.44625 .70864 L
.47258 .68582 L
.48596 .67685 L
.49975 .66999 L
.51189 .66624 L
.52287 .6648 L
.54299 .66697 L
.55465 .67084 L
.56584 .67611 L
.5898 .69132 L
.61822 .71363 L
.68075 .76508 L
.71771 .79027 L
.74017 .80185 L
.76195 .80949 L
.80143 .81151 L
.83677 .79524 L
.87177 .7521 L
.90043 .67689 L
.91096 .62619 L
.91714 .57603 L
.92 .51603 L
.91846 .46037 L
.90623 .37239 L
.89475 .33295 L
.88188 .30462 L
.86604 .28293 L
.85008 .27113 L
Mistroke
.83197 .26689 L
.81254 .2712 L
.79291 .2838 L
.77553 .30171 L
.7613 .32147 L
.74754 .34583 L
.72899 .39068 L
.71709 .43483 L
.71032 .48313 L
.70935 .50959 L
.71022 .53316 L
.71625 .57524 L
.72206 .59718 L
.7289 .61607 L
.73751 .6341 L
.74644 .64847 L
.75784 .66222 L
.76949 .67196 L
.79033 .6799 L
.81263 .67458 L
.83038 .65756 L
.8469 .6254 L
.8593 .57736 L
.86324 .54597 L
.86473 .51573 L
.86169 .4568 L
.85182 .40583 L
.83524 .36286 L
.82367 .34443 L
.81196 .33129 L
.78854 .31615 L
.76247 .3109 L
.73894 .31306 L
.71744 .31878 L
.69472 .3271 L
.67153 .33637 L
.64807 .34478 L
.63528 .34831 L
.62366 .35056 L
.6026 .35177 L
.59196 .35079 L
.58009 .34835 L
.55904 .34064 L
.53489 .32697 L
.48475 .28677 L
.42011 .22394 L
.3435 .1511 L
.29822 .11556 L
.24562 .08716 L
.21432 .07957 L
Mistroke
.18456 .08103 L
.13073 .11416 L
.08959 .18269 L
.05696 .2967 L
.0414 .4196 L
.03949 .5644 L
.05501 .70648 L
.08847 .8192 L
.13052 .8782 L
.17306 .89525 L
.22536 .88098 L
.27123 .84648 L
.30808 .80768 L
.34268 .76406 L
.4371 .6195 L
.4596 .58462 L
.46823 .57365 L
.47644 .56624 L
.48289 .5635 L
.48965 .56408 L
.4963 .56785 L
.50288 .57398 L
.55426 .64557 L
.6022 .71183 L
.63722 .75526 L
.67639 .79767 L
.71533 .83191 L
.76159 .85942 L
.78786 .8669 L
.81579 .86657 L
.86403 .83828 L
.90225 .77498 L
.92856 .68413 L
.94336 .55952 L
.94068 .42124 L
.92153 .31017 L
.90486 .26279 L
.88651 .23044 L
.86517 .20876 L
.84467 .19931 L
.82063 .19908 L
.79816 .20755 L
.76082 .23745 L
.73042 .27555 L
.7027 .32244 L
.68012 .3733 L
.66467 .42186 L
.65888 .44783 L
.65532 .47067 L
.65289 .51014 L
Mistroke
.65572 .54797 L
.65928 .56646 L
.66455 .58496 L
.67082 .60116 L
.67753 .61474 L
.68654 .62919 L
.69753 .64278 L
.7089 .65332 L
.72006 .6608 L
.7392 .66757 L
.76015 .66599 L
.77913 .65478 L
.79475 .63568 L
.80957 .60294 L
.8158 .58005 L
.81996 .55661 L
.82311 .51016 L
.8198 .45969 L
.81514 .43353 L
.8092 .41105 L
.80099 .38862 L
.7906 .36786 L
.76982 .34011 L
.75656 .32825 L
.74347 .31945 L
.71761 .30782 L
.69298 .30108 L
.6637 .29549 L
.63528 .29019 L
.60844 .28366 L
.57845 .27345 L
.54866 .25967 L
.51964 .24278 L
.44469 .18729 L
.39849 .14911 L
.34316 .10525 L
.31246 .08391 L
.28213 .06632 L
.22275 .04677 L
.16632 .05612 L
.10933 .11274 L
.08433 .16359 L
.06142 .23685 L
.04393 .33017 L
.03453 .42823 L
.03586 .60959 L
.06188 .77651 L
.10405 .88027 L
.15203 .92635 L
.20806 .93249 L
Mistroke
.23901 .92207 L
.26616 .90728 L
.31314 .87299 L
.3589 .83381 L
.39441 .80308 L
.42961 .77557 L
.46098 .75623 L
.48847 .74512 L
.51656 .74058 L
.54651 .74353 L
.57517 .75298 L
.60361 .7671 L
.66212 .8029 L
.69916 .82465 L
.74173 .84343 L
.78358 .8504 L
.82178 .84127 L
.86352 .80438 L
.88432 .76897 L
.90092 .72661 L
.92258 .62897 L
.93078 .50912 L
.92839 .44475 L
.92216 .38996 L
.9113 .33757 L
.89602 .29333 L
.86412 .24759 L
.84406 .23717 L
.82495 .2364 L
.7902 .25366 L
.76149 .28459 L
.73369 .33088 L
.71362 .37985 L
.70157 .42319 L
.6939 .47069 L
.69207 .51872 L
.69586 .56152 L
.70391 .59868 L
.71482 .62979 L
.73029 .65967 L
.74989 .68474 L
.77239 .70129 L
.79787 .70603 L
.82157 .69556 L
.84119 .67204 L
.85985 .62756 L
.86747 .59557 L
.87227 .5628 L
.87499 .49822 L
.86902 .431 L
Mistroke
.8553 .37502 L
.8332 .32971 L
.80763 .30367 L
.78171 .29272 L
.75532 .29164 L
.73166 .29648 L
.70528 .306 L
.68166 .3164 L
.65717 .32725 L
.63272 .33624 L
.61265 .34093 L
.59103 .34218 L
.56757 .33838 L
.55407 .33373 L
.5414 .32782 L
.51528 .31158 L
.4881 .29018 L
.36524 .17363 L
.32661 .14005 L
.28107 .10768 L
.22738 .08486 L
.17565 .08656 L
.12146 .12846 L
.09719 .16905 L
.07435 .22899 L
.04666 .36988 L
.03899 .52272 L
.05006 .67181 L
.07459 .77997 L
.11517 .85885 L
.1599 .88835 L
.20641 .88339 L
.25389 .8531 L
.29418 .81234 L
.32627 .77162 L
.38628 .67706 L
.42066 .60916 L
.44048 .56003 L
.44624 .5419 L
.45006 .52687 L
.45178 .51765 L
.45246 .51189 L
.45259 .50865 L
.45253 .50802 L
.45246 .50818 L
.45244 .50995 L
.45276 .51387 L
.45362 .51945 L
.45504 .52609 L
.4577 .53581 L
Mistroke
.4621 .54873 L
.47516 .57888 L
.53546 .67927 L
.58564 .74745 L
.65032 .8225 L
.69142 .86144 L
.74135 .89654 L
.78999 .91325 L
.83576 .9066 L
.88672 .85911 L
.92464 .77245 L
.94036 .70746 L
.952 .62677 L
.95715 .46809 L
.94469 .33842 L
.91554 .22854 L
.87327 .16166 L
.82853 .14084 L
.78602 .14887 L
.74897 .17118 L
.70976 .20637 L
.67683 .24302 L
.57817 .37399 L
.56274 .3933 L
.54842 .40854 L
.54101 .41478 L
.53459 .41897 L
.52259 .4231 L
.51073 .42196 L
.50384 .41903 L
.49716 .41484 L
.48247 .40205 L
.46422 .38198 L
.36511 .26204 L
.32729 .22287 L
.287 .18886 L
.24074 .16301 L
.21507 .15661 L
.18729 .15795 L
.13988 .18778 L
.1013 .25492 L
.07626 .34671 L
.06301 .46946 L
.063 .54832 L
.06864 .61864 L
.078 .6751 L
.09205 .72626 L
.11119 .76862 L
.13438 .79727 L
.15561 .80938 L
Mistroke
.17943 .81117 L
.20159 .80377 L
.22106 .79099 L
.24226 .77087 L
.26072 .74808 L
.28907 .70238 L
.31285 .65002 L
.3283 .60199 L
.33713 .55902 L
.34089 .51491 L
.34044 .49166 L
.3385 .4714 L
.33056 .43396 L
.32384 .41476 L
.31628 .39837 L
.29955 .37253 L
.2888 .36085 L
.27836 .3523 L
.2569 .34227 L
.23653 .34204 L
.21486 .35345 L
.20475 .3642 L
.19461 .37991 L
.18065 .41499 L
.17119 .46246 L
.16846 .51267 L
.17154 .55904 L
.18075 .60589 L
.19435 .64348 L
.21379 .67567 L
.23864 .69952 L
.26586 .7136 L
.28015 .71791 L
.29606 .72111 L
.32472 .72439 L
.35171 .72663 L
.37942 .73002 L
.40612 .73565 L
.43082 .74362 L
.4588 .75614 L
.49126 .77509 L
.52869 .80176 L
.60652 .86582 L
.65694 .90681 L
.70982 .94319 L
.74079 .95904 L
.77561 .96993 L
.83727 .96328 L
.89233 .91247 L
.94 .79922 L
Mistroke
.96746 .6421 L
.97348 .47891 L
.96766 .37957 L
.9541 .28542 L
.91428 .16028 L
.88602 .11821 L
.8574 .09583 L
.82479 .08732 L
.78975 .09278 L
.76023 .10619 L
.72948 .12668 L
.67822 .17119 L
.59919 .25026 L
.56964 .27748 L
.54166 .29885 L
.51351 .31359 L
.48901 .31937 L
.46633 .31839 L
.44484 .31227 L
.42015 .30023 L
.39183 .282 L
.35777 .25727 L
.31667 .22819 L
.29633 .21559 L
.2739 .20398 L
.23195 .19137 L
.19105 .1956 L
.15455 .22059 L
.11975 .27631 L
.10407 .32062 L
.09288 .36808 L
.08088 .47754 L
.08088 .54044 L
.08497 .5945 L
.10285 .68289 L
.1288 .7372 L
.14608 .75448 L
.16526 .76254 L
.19979 .75484 L
.21808 .74087 L
.23398 .7233 L
.24984 .70027 L
.26468 .67261 L
.28408 .62239 L
.29188 .59314 L
.29702 .56611 L
.30138 .5174 L
.30114 .49364 L
.29904 .46833 L
.29114 .42736 L
Mistroke
.27708 .38842 L
.2593 .35838 L
.24005 .33859 L
.21591 .3278 L
.19272 .3319 L
.17315 .3491 L
.15512 .38248 L
.14124 .43434 L
.13715 .46492 L
.13515 .50038 L
.13823 .56357 L
.14844 .61708 L
.16485 .66053 L
.18472 .68969 L
.20495 .70585 L
.22837 .71397 L
.25432 .71409 L
.28143 .70764 L
.3037 .6993 L
.3271 .68927 L
.35135 .67933 L
.36404 .67496 L
.37558 .6718 L
.39562 .66873 L
.41737 .6696 L
.42975 .67223 L
.44168 .67623 L
.46501 .68786 L
.49235 .70682 L
.52571 .73538 L
.59512 .80308 L
.64159 .84784 L
.6911 .88982 L
.73753 .91978 L
.7905 .93691 L
.84976 .92286 L
.89941 .8656 L
.94094 .74974 L
.96256 .59899 L
.96439 .45079 L
.94773 .30571 L
.91149 .19181 L
.88834 .15622 L
.86075 .13338 L
.80972 .12766 L
.7634 .15044 L
.72052 .18848 L
.68476 .23001 L
.63113 .30621 L
.56273 .42569 L
Mistroke
.54535 .45842 L
.542 .46405 L
.5388 .46882 L
.53372 .47426 L
.52948 .47582 L
.52561 .47446 L
.52087 .46986 L
.51502 .46156 L
.46593 .38019 L
.42462 .31919 L
.35954 .23684 L
.32091 .1966 L
.27455 .15905 L
.2314 .13769 L
.1823 .13535 L
.13779 .1631 L
.09638 .23326 L
.06823 .33743 L
.05529 .45483 L
.05811 .6027 L
.07784 .71898 L
.09344 .7654 L
.11381 .80351 L
.13752 .82858 L
.16107 .8395 L
.20465 .83365 L
.24257 .80761 L
.27965 .7664 L
.31232 .71722 L
.33468 .67491 L
.35124 .63659 L
.36514 .59549 L
.37332 .56133 L
.3775 .53195 L
.37856 .50718 L
.37693 .48245 L
.37229 .45888 L
.36494 .43784 L
.3544 .41815 L
.34229 .40251 L
.32969 .39098 L
.31356 .38136 L
.30398 .37803 L
.29491 .37647 L
.27826 .3779 L
.26115 .38617 L
.24588 .4016 L
.23828 .4136 L
.23207 .4268 L
.22657 .44265 L
Mistroke
.22264 .45859 L
.21949 .4784 L
.21795 .49814 L
.21887 .53407 L
.22384 .56654 L
.23364 .59926 L
.24015 .61411 L
.24843 .62898 L
.25787 .64236 L
.26881 .65464 L
.2905 .67237 L
.30358 .68029 L
.31625 .68668 L
.34658 .69904 L
.46849 .75382 L
.53665 .80153 L
.62708 .87296 L
.67549 .90752 L
.73112 .93716 L
.78103 .94838 L
.83586 .93389 L
.86694 .90659 L
.89303 .8672 L
.91908 .80381 L
.9385 .72703 L
.95693 .56225 L
.9572 .46307 L
.95084 .37472 L
.92293 .233 L
.88395 .14781 L
.82969 .10157 L
.77557 .09715 L
.72542 .1136 L
.67472 .14041 L
.63385 .16395 L
.59229 .18507 L
.56806 .19447 L
.54622 .2004 L
.50395 .20382 L
.46531 .19735 L
.42284 .18124 L
.33485 .13327 L
.30716 .11866 L
.2799 .10646 L
.22692 .09342 L
.19642 .09554 L
.16852 .10637 L
.13919 .13027 L
.11049 .17158 L
.08713 .22598 L
Mistroke
.06933 .29026 L
.04974 .43536 L
.04897 .56862 L
.06482 .69912 L
.09642 .79664 L
.13472 .84452 L
.17377 .85486 L
.20914 .84182 L
.24719 .8088 L
.27892 .76707 L
.30753 .71666 L
.33103 .66159 L
.34543 .6154 L
.35547 .56634 L
.3597 .51655 L
.35926 .48983 L
.35714 .46613 L
.34914 .42457 L
.33529 .38401 L
.31654 .34784 L
.30398 .32971 L
.29127 .31486 L
.26559 .29354 L
.23619 .28221 L
.20937 .28504 L
.18532 .30121 L
.16196 .33549 L
.14272 .39086 L
.13137 .46541 L
.12974 .51126 L
.13145 .55382 L
.14235 .6263 L
.15239 .66114 L
.16358 .68815 L
.18907 .72645 L
.22088 .74975 L
.2529 .7579 L
.28273 .75737 L
.31052 .75299 L
.33963 .74694 L
.36646 .74206 L
.39052 .73961 L
.41863 .74035 L
.44962 .7467 L
.48005 .7588 L
.50985 .77569 L
.58296 .8311 L
.66642 .89971 L
.71443 .93253 L
.76986 .95665 L
Mistroke
.80076 .96054 L
.83321 .95438 L
.88824 .9088 L
.93471 .80813 L
.95396 .72783 L
.96601 .64232 L
.97209 .47192 L
.95575 .305 L
.92446 .19358 L
.88562 .13159 L
.83776 .10736 L
.78571 .11951 L
.73406 .15808 L
.70756 .18564 L
.685 .21255 L
.61714 .30993 L
.54911 .42982 L
.53503 .45565 L
.52951 .46444 L
.52457 .47045 L
.51967 .47347 L
.51532 .47298 L
.51103 .46978 L
.50572 .46327 L
.47244 .40844 L
.39167 .28996 L
.3579 .24869 L
.31567 .20467 L
.27465 .17159 L
.24962 .15718 L
.22538 .14827 L
.17722 .14945 L
.13506 .17991 L
.11397 .21118 L
.09379 .25752 L
.06745 .37086 L
.05797 .50315 L
.06436 .62135 L
.08762 .73229 L
.12091 .79827 L
.15721 .82455 L
.1919 .82369 L
.22863 .80274 L
.26373 .76647 L
.29607 .71899 L
.31965 .67365 L
.33024 .64887 L
.33983 .62259 L
.3523 .5773 L
.35854 .53832 L
Mistroke
.35991 .50058 L
.35719 .47132 L
.35042 .44217 L
.34496 .42709 L
.33807 .41246 L
.32313 .38978 L
.31355 .37931 L
.30397 .37119 L
.29287 .36429 L
.28051 .35955 L
.26957 .35792 L
.25768 .35903 L
.24665 .36307 L
.23684 .36953 L
.21987 .3892 L
.2054 .42031 L
.19632 .45735 L
.19226 .50341 L
.19449 .54847 L
.20179 .58816 L
.21356 .623 L
.22758 .64939 L
.24697 .67327 L
.26761 .68973 L
.29215 .70236 L
.31954 .71155 L
.37123 .72462 L
.39946 .73305 L
.43109 .74546 L
.46815 .76473 L
.50578 .78922 L
.583 .84951 L
.63042 .88801 L
.68633 .92876 L
.73943 .95707 L
.80078 .96791 L
.85593 .94497 L
.90283 .88352 L
.93982 .78023 L
.96367 .63299 L
.96912 .49148 L
.95874 .34271 L
.93048 .21234 L
.88616 .12399 L
.83694 .08799 L
.79036 .08614 L
.73776 .10689 L
.69175 .13699 L
.64194 .17509 L
.60096 .20564 L
Mistroke
.56173 .22981 L
.52698 .24393 L
.49163 .24918 L
.47175 .24787 L
.45316 .24403 L
.38583 .21438 L
.34691 .19176 L
.30271 .16743 L
.26141 .15067 L
.21464 .1448 L
.17253 .15862 L
.136 .1941 L
.09988 .26809 L
.07704 .36316 L
.06595 .49235 L
.07163 .61279 L
.09402 .71905 L
.12547 .77982 L
.14436 .79646 L
.16605 .80378 L
.18886 .80078 L
.20969 .78989 L
.22885 .77355 L
.24825 .75086 L
.27859 .70124 L
.30108 .64792 L
.31538 .59745 L
.32101 .56691 L
.32418 .53867 L
.32471 .48776 L
.32205 .46048 L
.3178 .43636 L
.31125 .4111 L
.30228 .38608 L
.28398 .35048 L
.27174 .33344 L
.2594 .32014 L
.2348 .30345 L
.20727 .29955 L
.18314 .3109 L
.16251 .33579 L
.14398 .37886 L
.13089 .44061 L
.12653 .51175 L
.12825 .55263 L
.13252 .58912 L
.14835 .65353 L
.16077 .68208 L
.17379 .70271 L
.20016 .72727 L
Mistroke
.23114 .73801 L
.26097 .73699 L
.28793 .73009 L
.31222 .72112 L
.33713 .71101 L
.35772 .70321 L
.37933 .69678 L
.40393 .69296 L
.42708 .69381 L
.45 .69935 L
.4721 .70896 L
.49932 .72574 L
.52727 .74728 L
.58801 .80215 L
.62814 .83962 L
.67658 .88139 L
.72738 .91639 L
.77693 .93639 L
.82931 .93436 L
.88345 .89217 L
.92646 .80463 L
.954 .68427 L
.96628 .52715 L
.9567 .35599 L
.94344 .28262 L
.92401 .21854 L
.87924 .14665 L
.82648 .12687 L
.79639 .13447 L
.76932 .14996 L
.72352 .19129 L
.68152 .24328 L
.622 .33861 L
.58854 .40753 L
.5778 .4347 L
.56977 .4589 L
.5652 .47624 L
.56221 .49208 L
.56092 .50577 L
.56091 .51205 L
.56128 .51698 L
.56282 .52449 L
.56504 .52928 L
.56752 .53188 L
.57038 .53278 L
.57282 .53213 L
.57536 .52996 L
.5777 .52602 L
.57957 .51996 L
.58048 .51258 L
Mistroke
.58043 .50441 L
.57906 .49311 L
.57625 .48077 L
.5723 .4683 L
.56631 .45323 L
.54533 .41293 L
.51478 .36609 L
.42174 .24779 L
.3512 .17358 L
.30333 .13366 L
.25417 .10557 L
.19853 .09652 L
.16719 .10657 L
.13927 .12864 L
.09418 .20563 L
.06075 .3384 L
.04839 .50146 L
.05739 .65409 L
.08092 .76685 L
.11861 .84873 L
.16864 .88976 L
.19856 .8941 L
.22642 .88903 L
.25518 .87685 L
.2804 .86174 L
.33274 .82186 L
.47184 .72678 L
.49747 .72317 L
.52441 .72642 L
.55495 .73793 L
.58474 .75518 L
.65104 .80315 L
.68794 .82919 L
.72403 .85035 L
.76413 .8654 L
.808 .86644 L
.85427 .84047 L
.89267 .78279 L
.92365 .68266 L
.93831 .56577 L
.93683 .43229 L
.92933 .37137 L
.91652 .31396 L
.89978 .2689 L
.88117 .23862 L
.84219 .21339 L
.81969 .21486 L
.79925 .22412 L
.77783 .24113 L
.75674 .26502 L
Mistroke
.72684 .31248 L
.70493 .36153 L
.68816 .41628 L
.68207 .4466 L
.67856 .47383 L
.67704 .52007 L
.68077 .56061 L
.69019 .60175 L
.70586 .64085 L
.71571 .65813 L
.72768 .67461 L
.7522 .69694 L
.77824 .70653 L
.80259 .70184 L
.82685 .6801 L
.84618 .64283 L
.85879 .59707 L
.86605 .53785 L
.86535 .46981 L
.86104 .43316 L
.85486 .40227 L
.83729 .35141 L
.81547 .31704 L
.79173 .29679 L
.76479 .28644 L
.74118 .28444 L
.71532 .28705 L
.688 .29278 L
.65959 .29952 L
.63352 .30435 L
.61014 .30616 L
.58256 .30398 L
.56842 .3008 L
.55251 .2955 L
.52316 .28123 L
.4935 .26175 L
.40784 .18952 L
.3625 .14947 L
.30673 .10591 L
.25256 .07594 L
.19968 .0659 L
.14439 .08755 L
.09163 .16166 L
.06898 .22417 L
.05011 .30846 L
.03874 .39996 L
.03441 .48968 L
.04268 .65522 L
.07239 .79476 L
.11481 .875 L
Mistroke
.16874 .9051 L
.2206 .89265 L
.26574 .86004 L
.30589 .81838 L
.33771 .77856 L
.39367 .6966 L
.45874 .58813 L
.46878 .57285 L
.47346 .56678 L
.47746 .56248 L
.48394 .55794 L
.49066 .55727 L
.4971 .56053 L
.50379 .56699 L
.51932 .58798 L
.58111 .67981 L
.6246 .73732 L
.68534 .80411 L
.72304 .83562 L
.76843 .86021 L
.81159 .8655 L
.85139 .84813 L
.8929 .7934 L
.91217 .74549 L
.92624 .69221 L
.94228 .56915 L
.94207 .44615 L
.93538 .38121 L
.92367 .32101 L
.8932 .24239 L
.87258 .21645 L
.85199 .20323 L
.82876 .19959 L
.80397 .20624 L
.765 .23491 L
.74502 .25754 L
.72815 .28093 L
.70167 .32689 L
.68012 .37649 L
.66655 .41922 L
.65844 .45718 L
.65438 .496 L
.65525 .53436 L
.66035 .56597 L
.66843 .5925 L
.68059 .61811 L
.69685 .64076 L
.70611 .64999 L
.71679 .65809 L
.73737 .66679 L
Mistroke
.75797 .66645 L
.77639 .65717 L
.79211 .64006 L
.80469 .61668 L
.81525 .58367 L
.82194 .54165 L
.82309 .49398 L
.81845 .44905 L
.80974 .4119 L
.79589 .37709 L
.78623 .36039 L
.77488 .34539 L
.75222 .32494 L
.72541 .31073 L
.70945 .30535 L
.69424 .30152 L
.66419 .29583 L
.63502 .29045 L
.60813 .28394 L
.57781 .27359 L
.5486 .26003 L
.51549 .24049 L
.44831 .19055 L
.35288 .11278 L
.30441 .07901 L
.24742 .05212 L
.18836 .04835 L
.12831 .08659 L
.09977 .12951 L
.07337 .19421 L
.04082 .35442 L
.0327 .54774 L
.04919 .71853 L
.08089 .83472 L
.12739 .90893 L
.15723 .92855 L
.18597 .93439 L
.21755 .92989 L
.25068 .91594 L
.28389 .89497 L
.31364 .87205 L
.36439 .82824 L
.40353 .79459 L
.4409 .76676 L
.45902 .756 L
.47826 .74718 L
.49526 .74197 L
.51099 .73947 L
.62909 .78093 L
.66175 .80151 L
Mistroke
.69902 .82352 L
.73284 .83931 L
.77162 .84898 L
.81597 .84297 L
.85539 .81358 L
.89195 .75034 L
.90813 .70054 L
.9194 .64748 L
.92977 .54503 L
.92706 .43238 L
.91199 .34158 L
.88942 .2809 L
.87264 .25656 L
.85299 .2413 L
.81598 .23948 L
.78147 .26231 L
.75335 .29723 L
.72828 .34358 L
.71689 .37191 L
.7082 .39893 L
.7011 .42762 L
.69647 .45365 L
.69331 .48326 L
.69242 .51068 L
.69541 .55502 L
.70442 .59876 L
.71649 .63244 L
.73392 .66433 L
.75648 .69011 L
.77046 .69968 L
.78377 .70466 L
.80862 .7027 L
.83337 .68284 L
.85409 .64408 L
.8675 .59425 L
.87466 .52534 L
.87232 .45751 L
.86245 .39999 L
.84765 .35631 L
.82652 .32149 L
.80047 .29991 L
.77234 .29186 L
.75631 .29203 L
.74176 .29437 L
.7142 .30292 L
.68925 .31347 L
.66375 .32494 L
.63815 .335 L
.62399 .33913 L
.61142 .34158 L
Mistroke
.59891 .34268 L
.58716 .34236 L
.56528 .33808 L
.55251 .33341 L
.54024 .32751 L
.51396 .31087 L
.48274 .28572 L
.42087 .22717 L
.33479 .1468 L
.30535 .12377 L
.27226 .10263 L
.24278 .08929 L
.20945 .08228 L
.17819 .08575 L
.14534 .1034 L
.11619 .13578 L
.09213 .18009 L
.05704 .30079 L
.0449 .38633 L
.03946 .47189 L
.04627 .64271 L
.05978 .72544 L
.07707 .78716 L
.11765 .86172 L
.16147 .88874 L
.21078 .88163 L
.26065 .84728 L
.28355 .82444 L
.30659 .79762 L
.34315 .74778 L
.3939 .66365 L
.424 .60255 L
.44207 .55694 L
.44969 .5314 L
.45187 .52156 L
.45295 .51508 L
.45342 .51088 L
.45351 .5097 L
.45353 .50934 L
.45364 .51074 L
.45383 .51272 L
.45417 .51524 L
.45531 .52147 L
.4576 .5307 L
.46564 .5541 L
.48399 .59328 L
.51816 .65112 L
.56777 .72233 L
.6357 .80541 L
.67385 .84446 L
Mistroke
.71949 .88192 L
.74775 .89877 L
.77428 .90911 L
.82701 .90908 L
.87267 .87704 L
.91519 .79988 L
.94379 .68721 L
.95662 .5602 L
.9533 .40778 L
.93347 .28541 L
.89734 .19275 L
.87273 .16222 L
.84879 .14691 L
.79918 .14564 L
.77175 .15781 L
.74742 .17444 L
.70631 .21264 L
.66842 .25676 L
.58436 .37304 L
.55717 .40892 L
.54616 .42052 L
.53538 .42861 L
.52995 .43107 L
.52429 .43228 L
.51411 .4309 L
.50349 .42506 L
.49295 .41593 L
.4657 .38439 L
.43077 .33914 L
.3838 .28033 L
.31657 .20908 L
.29337 .18957 L
.27009 .17335 L
.22385 .15354 L
.1793 .15528 L
.13309 .19013 L
.11068 .22648 L
.09249 .27211 L
.0685 .38287 L
.06187 .45472 L
.0605 .52254 L
.06419 .59482 L
.07361 .66403 L
.0999 .75349 L
.13269 .80176 L
.17293 .81759 L
.19571 .81258 L
.21588 .8014 L
.24964 .76994 L
.28059 .72708 L
Mistroke
.30241 .68716 L
.32131 .64264 L
.33565 .59629 L
.34454 .54934 L
.34712 .50835 L
.34491 .47383 L
.33873 .44237 L
.32974 .41602 L
.31669 .39068 L
.29964 .36858 L
.28104 .35338 L
.26216 .34558 L
.24477 .34508 L
.22634 .35253 L
.20693 .37226 L
.19215 .40073 L
.18007 .44444 L
.17474 .49321 L
.17568 .54051 L
.18159 .58278 L
.19326 .62424 L
.21073 .6601 L
.23224 .68652 L
.24567 .69744 L
.25861 .70525 L
.28358 .71514 L
.31091 .72118 L
.34182 .72549 L
.37157 .72987 L
.38832 .7332 L
.40681 .73801 L
.44028 .75033 L
.47512 .76839 L
.51529 .79508 L
.59948 .86274 L
.64328 .89855 L
.69504 .93599 L
.75672 .96642 L
.81685 .97074 L
.85216 .95518 L
.88327 .92494 L
.91415 .87196 L
.94147 .79226 L
.96046 .69645 L
.97079 .59393 L
.97328 .4975 L
.96866 .3955 L
.95806 .30952 L
.94025 .22899 L
.91602 .16383 L
Mistroke
.88957 .12152 L
.83689 .08659 L
.77867 .09311 L
.72656 .12306 L
.69891 .14487 L
.67447 .16635 L
.58763 .24648 L
.55717 .27014 L
.52775 .2872 L
.51306 .29292 L
.49737 .29669 L
.47017 .29724 L
.45324 .29391 L
.43693 .28836 L
.40498 .27233 L
.36422 .2462 L
.32257 .21869 L
.28275 .19654 L
.23797 .18197 L
.19213 .18565 L
.1669 .19975 L
.14468 .22252 L
.11077 .28768 L
.09604 .33774 L
.08599 .39086 L
.07769 .49754 L
.08373 .60782 L
.10065 .68793 L
.12401 .73949 L
.15461 .76743 L
.18951 .76773 L
.22279 .74474 L
.23993 .72456 L
.2544 .70259 L
.27851 .65246 L
.28879 .62261 L
.29605 .59509 L
.30405 .54604 L
.30577 .51895 L
.30561 .49456 L
.3011 .45177 L
.29074 .41018 L
.27579 .37499 L
.25486 .34441 L
.23182 .32576 L
.20894 .32011 L
.1864 .328 L
.16752 .34806 L
.1494 .3865 L
.1376 .43552 L
Mistroke
.13203 .49822 L
.13526 .56628 L
.14517 .61896 L
.16253 .66545 L
.18684 .69919 L
.20216 .71071 L
.21676 .71704 L
.24584 .72001 L
.27317 .71468 L
.31894 .69639 L
.35788 .67955 L
.3762 .67367 L
.39538 .67013 L
.41643 .67015 L
.43598 .67423 L
.45662 .68269 L
.48073 .69725 L
.53721 .74468 L
.60471 .81098 L
.68332 .88228 L
.73443 .9167 L
.7924 .93569 L
.85107 .92062 L
.88246 .89028 L
.90902 .84516 L
.94621 .72295 L
.96359 .57695 L
.96526 .49083 L
.96055 .39963 L
.93608 .25865 L
.89696 .16901 L
.8542 .1321 L
.80232 .13194 L
.75546 .1591 L
.71589 .19679 L
.68378 .23548 L
.6268 .31976 L
.56083 .44643 L
.54824 .47652 L
.54486 .48437 L
.54205 .48966 L
.53961 .49182 L
.53738 .49089 L
.53603 .48916 L
.53444 .4864 L
.53092 .47909 L
.49536 .40897 L
.4618 .35467 L
.41448 .28765 L
.35536 .21611 L
Mistroke
.31578 .1766 L
.27413 .14417 L
.22143 .12085 L
.17227 .12419 L
.12836 .15861 L
.08797 .23709 L
.07151 .29536 L
.05838 .3703 L
.05094 .45653 L
.05014 .53935 L
.06321 .67683 L
.09469 .78668 L
.13474 .84302 L
.17598 .85833 L
.22129 .84468 L
.26588 .80888 L
.29978 .76951 L
.32714 .73055 L
.37344 .64742 L
.38727 .61603 L
.39822 .58663 L
.40502 .56418 L
.40989 .54304 L
.41272 .52328 L
.4134 .50749 L
.41212 .49166 L
.40931 .47977 L
.40494 .46958 L
.39982 .46206 L
.39331 .45591 L
.38558 .45163 L
.38153 .45036 L
.37704 .44963 L
.36882 .45002 L
.36102 .45252 L
.35419 .45667 L
.34787 .46267 L
.34272 .46987 L
.3389 .47752 L
.33576 .48691 L
.33365 .49832 L
.33307 .51137 L
.33401 .52308 L
.3366 .53628 L
.33879 .54377 L
.34178 .55191 L
.34881 .56658 L
.35761 .58058 L
.36742 .59325 L
.39555 .62158 L
Mistroke
.43445 .65358 L
.53513 .73411 L
.59561 .78324 L
.63261 .81111 L
.67599 .83906 L
.72086 .8593 L
.76326 .86615 L
.80572 .85512 L
.8433 .82223 L
.87924 .75467 L
.90302 .66484 L
.91554 .54532 L
.91148 .41437 L
.8924 .30758 L
.85878 .224 L
.81873 .17786 L
.77848 .15937 L
.72997 .15726 L
.70271 .16144 L
.67781 .16685 L
.63355 .1768 L
.60915 .18088 L
.58697 .18294 L
.54661 .18135 L
.5033 .17096 L
.46387 .15414 L
.418 .128 L
.37044 .09718 L
.32195 .06647 L
.27557 .04234 L
.22297 .02727 L
.16066 .03814 L
.10684 .09038 L
.05921 .20333 L
.02879 .38029 L
.02381 .55428 L
.03747 .70613 L
.0697 .83359 L
.11792 .91088 L
.1478 .92817 L
.1766 .93065 L
.22938 .90871 L
.28134 .86204 L
.32942 .80149 L
.39348 .69667 L
.42983 .61913 L
.4427 .58374 L
.45059 .55569 L
.45355 .54153 L
.45536 .52975 L
Mistroke
.45649 .51738 L
.45671 .50678 L
.45621 .49749 L
.45497 .48857 L
.45115 .4748 L
.44827 .46828 L
.44513 .46282 L
.44126 .45754 L
.43666 .4526 L
.42866 .44635 L
.42057 .44209 L
.4112 .43905 L
.4058 .43809 L
.40085 .43766 L
.39563 .43769 L
.39083 .43814 L
.38561 .43912 L
.38018 .44071 L
.37142 .44468 L
.36671 .44767 L
.36252 .45095 L
.35535 .45834 L
.34952 .4668 L
.34526 .47551 L
.3418 .48608 L
.33957 .49859 L
.33906 .50596 L
.33908 .51282 L
.34047 .52653 L
.34342 .53965 L
.34802 .55284 L
.35474 .56679 L
.37146 .59125 L
.39882 .61963 L
.43084 .64671 L
.52043 .7183 L
.58533 .77097 L
.6274 .80293 L
.67118 .83146 L
.71102 .8505 L
.75584 .85999 L
.78029 .85772 L
.80556 .84789 L
.84766 .80707 L
.87965 .74066 L
.90087 .65558 L
.91211 .54472 L
.90873 .42243 L
.8915 .31974 L
.86028 .23637 L
Mistroke
.82253 .188 L
.7838 .16643 L
.74746 .16089 L
.70745 .16419 L
.6664 .1722 L
.62893 .17949 L
.5854 .18382 L
.56351 .18325 L
.53918 .18003 L
.49527 .16709 L
.45191 .14633 L
.39645 .11218 L
.33204 .07016 L
.27206 .03826 L
.23645 .02679 L
.20277 .02381 L
.14189 .04741 L
.09167 .11309 L
.04699 .24842 L
.0247 .42273 L
.02666 .62271 L
.05115 .77925 L
.09672 .89013 L
.12426 .9196 L
.15625 .93379 L
.21161 .92343 L
.26114 .88756 L
.3011 .84489 L
.339 .79498 L
.3991 .69808 L
.4389 .61764 L
.45126 .58697 L
.45947 .56276 L
.46446 .54448 L
.46773 .52801 L
.46916 .51518 L
.46922 .50434 L
.46833 .49708 L
.46659 .49105 L
.46374 .48627 L
.46066 .48409 L
.45898 .48376 L
.45712 .48401 L
.45522 .48496 L
.45353 .48646 L
.4508 .49073 L
.4489 .49633 L
.44772 .50433 L
.44777 .51484 L
.44906 .5254 L
Mistroke
.45192 .53843 L
.45623 .55248 L
.46168 .56679 L
.48233 .6089 L
.51339 .65956 L
.5628 .72864 L
.63767 .8175 L
.67604 .85519 L
.72193 .89099 L
.77663 .91581 L
.82933 .9132 L
.85973 .89436 L
.88612 .86288 L
.91186 .81166 L
.9341 .73854 L
.94903 .65374 L
.95656 .5653 L
.9526 .39773 L
.92722 .25945 L
.88984 .17629 L
.84019 .13605 L
.81391 .13272 L
.78523 .13884 L
.62819 .27288 L
.57291 .33005 L
.54992 .34833 L
.53779 .35551 L
.52686 .36016 L
.50754 .36358 L
.48991 .36116 L
.46877 .35198 L
.44706 .33711 L
.34269 .2405 L
.30298 .20789 L
.27933 .19206 L
.25603 .17996 L
.20892 .16939 L
.16629 .18246 L
.14291 .20314 L
.12032 .23684 L
.08822 .32732 L
.07655 .39151 L
.07037 .45682 L
.06914 .53015 L
.07419 .60528 L
.09436 .70451 L
.11101 .74482 L
.12875 .77082 L
.16459 .79146 L
.20336 .78164 L
Mistroke
.23546 .7537 L
.26182 .71747 L
.28549 .67195 L
.30433 .62047 L
.31584 .57103 L
.32069 .52775 L
.31997 .48068 L
.3135 .43976 L
.30293 .40564 L
.28971 .37815 L
.27196 .35358 L
.25037 .33582 L
.22701 .32897 L
.21376 .33092 L
.20192 .33677 L
.1807 .35986 L
.16425 .39593 L
.15723 .42151 L
.15183 .45207 L
.14819 .51223 L
.14999 .54977 L
.15445 .58375 L
.16062 .6121 L
.16938 .63957 L
.19064 .68025 L
.21472 .705 L
.22975 .71391 L
.24392 .71914 L
.26061 .72234 L
.27654 .72316 L
.292 .72249 L
.3083 .72077 L
.33717 .71673 L
.35192 .71488 L
.36767 .71354 L
.38488 .7132 L
.40105 .71428 L
.42805 .7196 L
.44375 .72486 L
.45875 .73136 L
.49073 .7496 L
.52823 .77705 L
.60084 .83981 L
.64612 .87923 L
.7004 .92059 L
.7317 .93918 L
.76134 .9517 L
.82079 .95581 L
.85231 .94199 L
.8849 .91039 L
Mistroke
.91276 .86279 L
.9349 .80294 L
.96226 .66533 L
.97127 .48676 L
.95562 .31087 L
.9213 .18888 L
.8978 .14686 L
.8694 .11834 L
.83815 .1059 L
.80867 .10738 L
.75744 .1322 L
.70759 .17606 L
.61874 .28452 L
.56475 .35753 L
.54619 .38028 L
.52933 .39751 L
.51653 .40695 L
.50339 .41205 L
.49622 .41258 L
.48964 .41165 L
.4819 .40891 L
.47429 .40468 L
.4598 .39333 L
.44187 .3754 L
.35209 .27376 L
.31763 .24015 L
.2969 .22281 L
.27644 .20828 L
.23811 .18954 L
.1944 .18585 L
.17106 .19438 L
.14981 .21084 L
.11438 .26601 L
.08662 .35961 L
.07734 .42418 L
.07345 .48753 L
.07727 .59175 L
.09523 .68787 L
.10864 .72417 L
.12549 .75296 L
.15979 .7782 L
.19222 .7752 L
.22586 .75121 L
.25655 .71163 L
.27969 .66784 L
.29616 .62433 L
.30657 .5847 L
.31328 .54017 L
.31458 .50018 L
.31082 .45996 L
Mistroke
.30645 .43873 L
.30101 .4201 L
.28641 .38685 L
.27635 .37121 L
.26619 .35921 L
.24634 .34433 L
.22331 .33958 L
.20181 .34824 L
.18365 .36882 L
.17408 .38722 L
.16543 .4117 L
.15918 .43857 L
.15529 .46576 L
.15323 .52098 L
.15884 .57867 L
.16478 .60627 L
.17321 .63286 L
.19299 .67136 L
.20735 .68848 L
.22207 .70037 L
.23598 .7078 L
.25156 .71289 L
.27872 .71604 L
.30404 .71495 L
.33019 .71214 L
.35835 .70951 L
.37324 .70903 L
.38675 .70943 L
.40242 .71111 L
.41737 .71408 L
.44433 .72303 L
.47522 .73878 L
.61282 .85079 L
.65606 .88791 L
.70734 .92562 L
.73879 .94317 L
.76847 .95428 L
.82763 .95431 L
.88559 .90969 L
.91448 .85908 L
.93714 .79514 L
.96482 .64178 L
.97025 .45409 L
.95347 .29927 L
.92216 .19054 L
.87639 .12275 L
.82107 .10391 L
.79156 .11096 L
.76482 .12478 L
.73677 .14543 L
Mistroke
.70867 .17128 L
.61976 .27573 L
.56718 .34262 L
.54407 .36842 L
.53403 .3779 L
.5254 .38482 L
.50966 .39373 L
.50137 .39614 L
.4936 .39684 L
.47789 .3937 L
.46867 .3893 L
.45975 .38356 L
.42452 .35177 L
.37568 .29956 L
.34103 .26423 L
.32061 .24539 L
.29745 .22647 L
.27588 .2117 L
.25109 .19883 L
.22779 .19157 L
.20574 .18993 L
.18273 .19491 L
.16153 .20712 L
.12527 .25251 L
.09506 .33491 L
.08371 .39417 L
.07754 .45401 L
.07715 .55725 L
.09024 .65598 L
.11305 .72418 L
.13987 .76047 L
.17271 .77263 L
.20846 .75873 L
.22539 .74382 L
.24215 .72378 L
.26815 .68066 L
.2799 .65462 L
.28899 .62999 L
.29703 .60271 L
.30331 .57402 L
.30881 .52706 L
.3092 .50147 L
.30784 .47846 L
.30112 .43842 L
.29061 .40581 L
.27397 .37425 L
.25464 .35217 L
.23289 .34002 L
.22019 .33856 L
.20856 .34108 L
Mistroke
.18816 .3562 L
.1697 .38722 L
.1574 .42709 L
.1507 .47183 L
.14938 .52507 L
.15518 .58097 L
.16902 .63302 L
.17979 .65701 L
.19128 .6752 L
.21525 .69872 L
.22834 .7061 L
.24323 .71124 L
.26948 .71427 L
.29776 .71208 L
.324 .70769 L
.34749 .7037 L
.37066 .70115 L
.39519 .70122 L
.41856 .70479 L
.44032 .71155 L
.46722 .72436 L
.49862 .7447 L
.56476 .7998 L
.643 .87047 L
.69319 .9103 L
.74444 .94038 L
.79045 .95319 L
.84012 .9444 L
.89185 .89564 L
.93125 .80842 L
.96032 .66919 L
.9701 .5141 L
.95985 .34798 L
.92725 .20895 L
.87994 .131 L
.85313 .11385 L
.82299 .10919 L
.77031 .12763 L
.72482 .16316 L
.68375 .20649 L
.65007 .2479 L
.59959 .31623 L
.56032 .36969 L
.54397 .38955 L
.52879 .40472 L
.51512 .41398 L
.50314 .41741 L
.4962 .41716 L
.48954 .41542 L
.47649 .40825 L
Mistroke
.46316 .39704 L
.44931 .38278 L
.41031 .33705 L
.35197 .27011 L
.31603 .23486 L
.27881 .20568 L
.25635 .19263 L
.23177 .1832 L
.2066 .17985 L
.17906 .18536 L
.1568 .19884 L
.13437 .22345 L
.10021 .29581 L
.07872 .3946 L
.07263 .45888 L
.0713 .52066 L
.08121 .63673 L
.09337 .69051 L
.10784 .72966 L
.13735 .77173 L
.17326 .78512 L
.21059 .77039 L
.2422 .73905 L
.2583 .71627 L
.27374 .68926 L
.28552 .66423 L
.29604 .63719 L
.30381 .61269 L
.31045 .586 L
.31744 .54038 L
.31886 .51373 L
.31834 .49037 L
.31571 .46466 L
.31129 .4417 L
.2992 .40489 L
.29022 .38675 L
.28068 .372 L
.26275 .35275 L
.24132 .34099 L
.22032 .34047 L
.20159 .3505 L
.18294 .37423 L
.16696 .41478 L
.16126 .4401 L
.15721 .46981 L
.15575 .52692 L
.15823 .55826 L
.16253 .58598 L
.16936 .61415 L
.17876 .64065 L
Mistroke
.19876 .67597 L
.21198 .69068 L
.22525 .70111 L
.25143 .71297 L
.27632 .71722 L
.30533 .71728 L
.33274 .71534 L
.35983 .71382 L
.37504 .71386 L
.38907 .71476 L
.41517 .71917 L
.44364 .72856 L
.47055 .74183 L
.49734 .75878 L
.56705 .81466 L
.60868 .8514 L
.65958 .89456 L
.7131 .93259 L
.7665 .95683 L
.79697 .96157 L
.8306 .95623 L
.86473 .93557 L
.8947 .89952 L
.93868 .79347 L
.96703 .62649 L
.97114 .45829 L
.95685 .3132 L
.92426 .19216 L
.87641 .11972 L
.84955 .10427 L
.81976 .1007 L
.76655 .11983 L
.71856 .15699 L
.67903 .19738 L
.61153 .27811 L
.56397 .33526 L
.547 .35308 L
.53071 .36743 L
.51434 .37796 L
.50004 .38304 L
.48324 .38349 L
.46715 .3785 L
.45191 .36972 L
.43406 .35581 L
.38913 .31251 L
.32746 .25295 L
.29642 .22804 L
.26026 .2062 L
.21819 .1942 L
.17863 .20158 L
Mistroke
.14221 .23273 L
.11279 .28723 L
.09292 .35575 L
.08042 .44514 L
.07936 .5569 L
.09156 .65014 L
.11676 .72388 L
.13465 .74932 L
.1524 .76254 L
.17146 .76692 L
.18919 .76356 L
.20812 .75301 L
.22716 .73553 L
.24382 .7144 L
.25791 .69167 L
.27956 .64481 L
.29395 .59858 L
.30273 .54999 L
.30513 .50997 L
.30259 .4685 L
.29423 .42774 L
.28722 .4071 L
.27951 .38996 L
.26142 .36232 L
.24136 .34478 L
.22106 .33808 L
.19905 .34361 L
.17977 .36242 L
.1648 .39139 L
.15273 .43498 L
.14644 .49216 L
.14633 .52266 L
.14852 .55499 L
.15828 .60899 L
.16653 .63474 L
.17571 .65532 L
.18724 .67408 L
.20079 .68953 L
.22574 .70589 L
.24065 .71054 L
.25484 .71244 L
.2813 .71128 L
.30514 .70697 L
.33044 .70108 L
.35658 .69564 L
.38068 .6929 L
.40238 .69338 L
.42445 .69738 L
.44587 .70481 L
.47229 .71852 L
Mistroke
.49848 .73628 L
.56753 .79546 L
.64427 .86604 L
.68806 .90163 L
.73138 .92946 L
.77979 .94744 L
.83264 .94348 L
.88719 .89796 L
.93027 .806 L
.95855 .67322 L
.96898 .50282 L
.95838 .34648 L
.93322 .23125 L
.8928 .14925 L
.84062 .11452 L
.81332 .11469 L
.78455 .12451 L
.7356 .15876 L
.71079 .1828 L
.68955 .20627 L
.64743 .25927 L
.59017 .34087 L
.55289 .39435 L
.53908 .41158 L
.52815 .42263 L
.51887 .42917 L
.51058 .43211 L
.50198 .43193 L
.49236 .42797 L
.48177 .41994 L
.46911 .40698 L
.44085 .37218 L
.39631 .31507 L
.33846 .2488 L
.30776 .21965 L
.27206 .19274 L
.22983 .17336 L
.18977 .17169 L
.14709 .19601 L
.12506 .22449 L
.10694 .26083 L
.08133 .35077 L
.06805 .46875 L
.06978 .5777 L
.08252 .66801 L
.10661 .74202 L
.14031 .7864 L
.17969 .79627 L
.20189 .78832 L
.22169 .77439 L
Mistroke
.25464 .73754 L
.27071 .7129 L
.28365 .68917 L
.30367 .64271 L
.31863 .59266 L
.32654 .54728 L
.32874 .50792 L
.32664 .4734 L
.32026 .43939 L
.31064 .41052 L
.29919 .38744 L
.28297 .36516 L
.26269 .34825 L
.24204 .3411 L
.22266 .3437 L
.20369 .35685 L
.18788 .37935 L
.17407 .41474 L
.16471 .46294 L
.16215 .51656 L
.16711 .57308 L
.17727 .61674 L
.19376 .65616 L
.21665 .68728 L
.24089 .70549 L
.25435 .71159 L
.26954 .71611 L
.28568 .7189 L
.30093 .72022 L
.33093 .72094 L
.35946 .72155 L
.38524 .7238 L
.41385 .72954 L
.44078 .73877 L
.47099 .75365 L
.53152 .7954 L
.61715 .86774 L
.66124 .9039 L
.71432 .94044 L
.74628 .95638 L
.77693 .96564 L
.80971 .96702 L
.84445 .95579 L
.88075 .9246 L
.91185 .87412 L
.93569 .81073 L
.95579 .7241 L
.96743 .63642 L
.9731 .53268 L
.97068 .42417 L
Mistroke
.96095 .32966 L
.92819 .19555 L
.9032 .14484 L
.87761 .11436 L
.82552 .09313 L
.77676 .10527 L
.72634 .13888 L
.67812 .18417 L
.6051 .26428 L
.57196 .29944 L
.54507 .32393 L
.52162 .33996 L
.50925 .34571 L
.49826 .34898 L
.48687 .35045 L
.4745 .34982 L
.4627 .34714 L
.45153 .34293 L
.43094 .33161 L
.40627 .31376 L
.34744 .26448 L
.31059 .23575 L
.2888 .22134 L
.26758 .2099 L
.24372 .20092 L
.21703 .19696 L
.19434 .19999 L
.17063 .21128 L
.14935 .23078 L
.12828 .26245 L
.11111 .30242 L
.09823 .34721 L
.0833 .44711 L
.08252 .5593 L
.09555 .65248 L
.11691 .71466 L
.14871 .75323 L
.18176 .75898 L
.21147 .74337 L
.23655 .71633 L
.25999 .67797 L
.27933 .63178 L
.28758 .6043 L
.29333 .5789 L
.29761 .55121 L
.29985 .52252 L
.2985 .47626 L
.29501 .45154 L
.29008 .42974 L
.27688 .39306 L
Mistroke
.26092 .3656 L
.25078 .35351 L
.23892 .34338 L
.21599 .33454 L
.19363 .3399 L
.17456 .35831 L
.15709 .39349 L
.14465 .44494 L
.14009 .4976 L
.14164 .54825 L
.14966 .6004 L
.1647 .64695 L
.17572 .66789 L
.18711 .68333 L
.20067 .69607 L
.21589 .70508 L
.24255 .7114 L
.25788 .71111 L
.27212 .70901 L
.29808 .70203 L
.32086 .69414 L
.36882 .67929 L
.39218 .67623 L
.40523 .6764 L
.41728 .67792 L
.43995 .68437 L
.46516 .69677 L
.49459 .71697 L
.53098 .74785 L
.60854 .82229 L
.65457 .86487 L
.70345 .90359 L
.7325 .92159 L
.76531 .93579 L
.82416 .9385 L
.87822 .90137 L
.92661 .80702 L
.95479 .68285 L
.96682 .51786 L
.95652 .3504 L
.9278 .22528 L
.89085 .15487 L
.84408 .12287 L
.79181 .12927 L
.76361 .14534 L
.73927 .16474 L
.69612 .2095 L
.66115 .25384 L
.57446 .38714 L
.54874 .42916 L
Mistroke
.53951 .44245 L
.53233 .45083 L
.52535 .45617 L
.51832 .45768 L
.51466 .4568 L
.51056 .45458 L
.50247 .44717 L
.49395 .43666 L
.48317 .42149 L
.45753 .38345 L
.41764 .32651 L
.35558 .24893 L
.30986 .20266 L
.28756 .1843 L
.26178 .16719 L
.23628 .15537 L
.21194 .14974 L
.18608 .15112 L
.15892 .16288 L
.11652 .21192 L
.09609 .25737 L
.08042 .31081 L
.0616 .44234 L
.0595 .52241 L
.06304 .59365 L
.08115 .7034 L
.11435 .78391 L
.15317 .81801 L
.19114 .81837 L
.21367 .80747 L
.23683 .78893 L
.25716 .76687 L
.27427 .74402 L
.30216 .69722 L
.32481 .64684 L
.33384 .62126 L
.34149 .59471 L
.35025 .54949 L
.35259 .52371 L
.35283 .50064 L
.3515 .48103 L
.34849 .46093 L
.34006 .4301 L
.32866 .4047 L
.31283 .38136 L
.30266 .37067 L
.29268 .36266 L
.27247 .35297 L
.26062 .3512 L
.24959 .3523 L
Mistroke
.23808 .3566 L
.22802 .36347 L
.21712 .37501 L
.20779 .38945 L
.19478 .42136 L
.18592 .46346 L
.18303 .50363 L
.18516 .54889 L
.19356 .59487 L
.20084 .61807 L
.20893 .63712 L
.22797 .66764 L
.24925 .6887 L
.27173 .70258 L
.29752 .71234 L
.32281 .71848 L
.34662 .72306 L
.37591 .72908 L
.40404 .73677 L
.43463 .74838 L
.47026 .76669 L
.55346 .826 L
.60177 .86574 L
.6517 .90575 L
.70055 .93955 L
.75842 .9663 L
.81867 .96874 L
.88001 .92601 L
.92614 .83695 L
.95628 .71314 L
.97151 .53698 L
.96435 .36704 L
.94055 .23593 L
.90704 .1498 L
.86226 .09771 L
.81052 .08353 L
.75567 .1001 L
.72615 .11772 L
.70025 .13655 L
.6142 .20875 L
.57967 .23559 L
.55 .25433 L
.5209 .26691 L
.49016 .27253 L
.36552 .22538 L
.33083 .20404 L
.29161 .18265 L
.25625 .16906 L
.21645 .1643 L
.17542 .17715 L
Mistroke
.13987 .21111 L
.10732 .27516 L
.08303 .37239 L
.07565 .43263 L
.07247 .50056 L
.07948 .61826 L
.10026 .7091 L
.12819 .76209 L
.16386 .78502 L
.19814 .7785 L
.23323 .74922 L
.25082 .72606 L
.26523 .70218 L
.28879 .64972 L
.29877 .61881 L
.30581 .59001 L
.31323 .53795 L
.31434 .50967 L
.31352 .48476 L
.30717 .43867 L
.29614 .39989 L
.27889 .36266 L
.26843 .34669 L
.25582 .33185 L
.23246 .31467 L
.20595 .31006 L
.18136 .32174 L
.16114 .34745 L
.14181 .3975 L
.13504 .42931 L
.13032 .46791 L
.12959 .53993 L
.13778 .60406 L
.1465 .63789 L
.15706 .66542 L
.18158 .7033 L
.19715 .71657 L
.21237 .72431 L
.22954 .72836 L
.24802 .72848 L
.26414 .72585 L
.27875 .72178 L
.31049 .70937 L
.3363 .69786 L
.34937 .69228 L
.36299 .68707 L
.38582 .68058 L
.40659 .67811 L
.43032 .68021 L
.45256 .68718 L
Mistroke
.47683 .69986 L
.5049 .7198 L
.56424 .77299 L
.60428 .81193 L
.65403 .85836 L
.70377 .89804 L
.73069 .91498 L
.76132 .92897 L
.81795 .9346 L
.86932 .90564 L
.91121 .84065 L
.94522 .72861 L
.95787 .64756 L
.96482 .55178 L
.95856 .37874 L
.93127 .24244 L
.89267 .16344 L
.84413 .12972 L
.79644 .13551 L
.75556 .16107 L
.71504 .2007 L
.64363 .29882 L
.6002 .37658 L
.57537 .4314 L
.56227 .46834 L
.55817 .48349 L
.55561 .49613 L
.55457 .50457 L
.55439 .50999 L
.55476 .51361 L
.55549 .51477 L
.55616 .51346 L
.5565 .51031 L
.55629 .50432 L
.55576 .49986 L
.55493 .49505 L
.55242 .4845 L
.54808 .47083 L
.53297 .43579 L
.50861 .39191 L
.46288 .32312 L
.3988 .24051 L
.32464 .16269 L
.27527 .12508 L
.22677 .10398 L
.1721 .10733 L
.14226 .12678 L
.11656 .15833 L
.07704 .25253 L
.05151 .39618 L
Mistroke
.04701 .5534 L
.06439 .70783 L
.0981 .81293 L
.13835 .8659 L
.16507 .87949 L
.19035 .88167 L
.21791 .87493 L
.24637 .86003 L
.27224 .84085 L
.29513 .82021 L
.33378 .77933 L
.42923 .66547 L
.44571 .64873 L
.46156 .63576 L
.47754 .62721 L
.49174 .62439 L
.49965 .6249 L
.50833 .62715 L
.52479 .63562 L
.54227 .64925 L
.5603 .66647 L
.6611 .77362 L
.69826 .80678 L
.73741 .83363 L
.77495 .84881 L
.81698 .84888 L
.86075 .82084 L
.88289 .78969 L
.9006 .75136 L
.92627 .65196 L
.93708 .53883 L
.93419 .431 L
.91828 .33296 L
.8963 .27177 L
.86632 .23241 L
.83084 .22053 L
.79307 .23538 L
.76045 .26696 L
.73473 .30437 L
.71031 .3534 L
.70054 .37886 L
.69177 .40688 L
.6814 .45519 L
.67738 .49833 L
.67746 .52178 L
.67931 .54542 L
.68689 .58466 L
.69332 .60464 L
.70061 .62181 L
.70991 .63886 L
Mistroke
.7212 .65468 L
.74269 .67447 L
.75579 .68109 L
.76821 .68377 L
.79099 .67889 L
.81338 .65832 L
.83009 .62614 L
.84146 .58563 L
.84795 .53303 L
.84712 .47295 L
.84335 .44198 L
.83779 .41458 L
.82273 .37016 L
.80094 .33444 L
.78678 .32008 L
.77291 .31027 L
.74841 .30009 L
.7206 .29573 L
.69128 .29562 L
.66406 .29691 L
.64863 .29739 L
.63188 .29724 L
.61601 .29613 L
.60124 .29404 L
.57271 .28668 L
.54101 .27308 L
.50441 .2509 L
.46656 .22243 L
.36219 .13343 L
.30859 .0928 L
.25428 .06337 L
.19488 .05382 L
.16357 .06299 L
.13137 .08721 L
.08068 .17427 L
.04677 .3077 L
.03241 .45688 L
.03627 .62337 L
.06225 .77726 L
.08506 .84101 L
.1101 .88301 L
.13907 .90966 L
.16674 .91999 L
.19902 .91841 L
.22911 .90676 L
.27926 .8711 L
.32093 .83026 L
.39691 .74153 L
.44525 .68593 L
.46686 .66544 L
Mistroke
.48496 .65242 L
.50323 .64459 L
.51259 .64299 L
.52256 .64316 L
.54058 .64813 L
.55786 .65763 L
.59732 .69005 L
.6498 .74014 L
.70548 .78691 L
.74143 .8086 L
.77707 .82023 L
.81918 .81609 L
.85579 .78901 L
.87408 .76284 L
.89166 .72491 L
.91507 .63369 L
.92235 .57319 L
.92484 .51623 L
.9228 .45172 L
.91629 .39574 L
.89528 .31611 L
.87937 .28549 L
.86303 .26693 L
.8312 .25517 L
.80151 .26551 L
.77147 .29373 L
.74427 .33605 L
.73297 .35998 L
.72264 .38704 L
.7092 .43722 L
.70277 .48533 L
.70249 .52787 L
.70736 .56761 L
.71758 .60532 L
.72999 .63316 L
.7468 .65761 L
.76778 .67495 L
.78029 .67959 L
.79183 .68016 L
.8138 .67024 L
.83245 .64662 L
.84655 .6123 L
.85647 .56548 L
.86004 .52012 L
.85834 .46881 L
.85007 .41713 L
.8346 .37085 L
.81506 .33881 L
.79431 .31987 L
.76794 .30878 L
Mistroke
.75277 .30681 L
.73898 .30701 L
.71236 .31113 L
.688 .31736 L
.66227 .32435 L
.64861 .32752 L
.63607 .32978 L
.6226 .33126 L
.60792 .33151 L
.59544 .33045 L
.58194 .3279 L
.55656 .31909 L
.54157 .31156 L
.52715 .30286 L
.46531 .25379 L
.38873 .18196 L
.34523 .14303 L
.30051 .10862 L
.25035 .08122 L
.19301 .07226 L
.14317 .09457 L
.09538 .16088 L
.07333 .21845 L
.05449 .29617 L
.03689 .46534 L
.04247 .63537 L
.06601 .76596 L
.1008 .85046 L
.13998 .89177 L
.18594 .90139 L
.23455 .88233 L
.28155 .84396 L
.32088 .80065 L
.37992 .72147 L
.45535 .60884 L
.46671 .59438 L
.47729 .58382 L
.48282 .57999 L
.48769 .57784 L
.49702 .57726 L
.50663 .58141 L
.51243 .58583 L
.51819 .59128 L
.54815 .6282 L
.58953 .68394 L
.64404 .75126 L
.67899 .78816 L
.71607 .82027 L
.7586 .84567 L
.78225 .85314 L
Mistroke
.80802 .85446 L
.83347 .8471 L
.86014 .82726 L
.88337 .79587 L
.90236 .75538 L
.9288 .65203 L
.93697 .58324 L
.9398 .51805 L
.93234 .39284 L
.91176 .30027 L
.87831 .23651 L
.8589 .22017 L
.83672 .21327 L
.79939 .22309 L
.76231 .25463 L
.7321 .29577 L
.70949 .33763 L
.69127 .38232 L
.67787 .42881 L
.6711 .46673 L
.66836 .50615 L
.67057 .54522 L
.67399 .56563 L
.6784 .58327 L
.68951 .61286 L
.70486 .63922 L
.72088 .65738 L
.7399 .67038 L
.7589 .67524 L
.77624 .67228 L
.79568 .65868 L
.81399 .63103 L
.82714 .59347 L
.83456 .5512 L
.83665 .49798 L
.83204 .44758 L
.82268 .40621 L
.80754 .36825 L
.78647 .33715 L
.77442 .32546 L
.76028 .31543 L
.73388 .30396 L
.70804 .29848 L
.68315 .29597 L
.65666 .29416 L
.63384 .29197 L
.60849 .28773 L
.5804 .27988 L
.54895 .26657 L
.51729 .24849 L
Mistroke
.48621 .22691 L
.40402 .15961 L
.35081 .11574 L
.29533 .07694 L
.26458 .06095 L
.23048 .04985 L
.19206 .04853 L
.15734 .06115 L
.12728 .08677 L
.09712 .13235 L
.05385 .26406 L
.03207 .44849 L
.03573 .62574 L
.04713 .71432 L
.06594 .79512 L
.11288 .8924 L
.16539 .92756 L
.22264 .92061 L
.2693 .89335 L
.31613 .85355 L
.3969 .77165 L
.43271 .73711 L
.46234 .71353 L
.47658 .70475 L
.49133 .69786 L
.5072 .69329 L
.52153 .69184 L
.5338 .69263 L
.54735 .69556 L
.56181 .70082 L
.5757 .70764 L
.63576 .74886 L
.70188 .79619 L
.74335 .81728 L
.76781 .82417 L
.79066 .8256 L
.83203 .8114 L
.85174 .79408 L
.87176 .76616 L
.90198 .68997 L
.91938 .59397 L
.92376 .49921 L
.91619 .40185 L
.89545 .31942 L
.87961 .28784 L
.86352 .26881 L
.82976 .25616 L
.79809 .26862 L
.77066 .29574 L
.74594 .33449 L
Mistroke
.72903 .37219 L
.71533 .41566 L
.70639 .46291 L
.70346 .51215 L
.70674 .5561 L
.7145 .59305 L
.72685 .62708 L
.74486 .65799 L
.75535 .67019 L
.76745 .68028 L
.79068 .68892 L
.81282 .68362 L
.83438 .66212 L
.84979 .63072 L
.86189 .58451 L
.86631 .55163 L
.86816 .51885 L
.86536 .45706 L
.86031 .42449 L
.85361 .39709 L
.84425 .37069 L
.83239 .34758 L
.80933 .32067 L
.78538 .30762 L
.75801 .30418 L
.74264 .30594 L
.72879 .30916 L
.7045 .31742 L
.67989 .3275 L
.65968 .3357 L
.63883 .34279 L
.61733 .34737 L
.59745 .34817 L
.58591 .3469 L
.5736 .34407 L
.55083 .33497 L
.52986 .32265 L
.50556 .30462 L
.45483 .2588 L
.38623 .19136 L
.34276 .15137 L
.2904 .11126 L
.26037 .0943 L
.23198 .08375 L
.17537 .08443 L
.14567 .1009 L
.11521 .13492 L
.08948 .18383 L
.06933 .24373 L
.04373 .39293 L
Mistroke
.03898 .54633 L
.05577 .7093 L
.0896 .82056 L
.11223 .85813 L
.13941 .88318 L
.16916 .89334 L
.19717 .89071 L
.24561 .8653 L
.29253 .82155 L
.33911 .76381 L
.37459 .71182 L
.42154 .63334 L
.44697 .58686 L
.46215 .56026 L
.46781 .55235 L
.47308 .54753 L
.47574 .54645 L
.47849 .54642 L
.48357 .54914 L
.48643 .55196 L
.48974 .55602 L
.49662 .56607 L
.51881 .60237 L
.59639 .71753 L
.66471 .7991 L
.7077 .83912 L
.73446 .85844 L
.7607 .87232 L
.80926 .88126 L
.85313 .86341 L
.89848 .80201 L
.93076 .70111 L
.94242 .62908 L
.94814 .55842 L
.94873 .47521 L
.94349 .40029 L
.92162 .2879 L
.90362 .24154 L
.88451 .21097 L
.86167 .19037 L
.83941 .18222 L
.81474 .18375 L
.78887 .19508 L
.76305 .2149 L
.74039 .2387 L
.70359 .2901 L
.67938 .3341 L
.65889 .38113 L
.65095 .40365 L
.64407 .42684 L
Mistroke
.6358 .46587 L
.63246 .50092 L
.63336 .53096 L
.63721 .55532 L
.64437 .5792 L
.65016 .59246 L
.65649 .60394 L
.67036 .62257 L
.67914 .63124 L
.68774 .63795 L
.69766 .64376 L
.70854 .64794 L
.72706 .64978 L
.74418 .64495 L
.76174 .63152 L
.77061 .62012 L
.77786 .60736 L
.78843 .57908 L
.79482 .54751 L
.79734 .50944 L
.79448 .46751 L
.78603 .42837 L
.77983 .41048 L
.77169 .39265 L
.75422 .36601 L
.73513 .34685 L
.71363 .33226 L
.69185 .32185 L
.64824 .30678 L
.53644 .25852 L
.38126 .14159 L
.33326 .1062 L
.27707 .07422 L
.24322 .0629 L
.21177 .05997 L
.15118 .08439 L
.12023 .11994 L
.09452 .16905 L
.07094 .2408 L
.05267 .33511 L
.04297 .43701 L
.04134 .53696 L
.05753 .71097 L
.09477 .83953 L
.14125 .90604 L
.19843 .92894 L
.2277 .926 L
.25926 .91552 L
.29444 .89762 L
.32613 .8781 L
Mistroke
.38111 .84245 L
.40774 .82684 L
.43474 .81368 L
.46326 .80387 L
.48899 .79937 L
Mfstroke
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00e@3oool00`3ooml0W4P0000000020000000307Bo
o`3oool0oooo0=<0oooo003G0?ooo`030?noM00007@0_ooo0=H0oooo003G0?ooo`030?oo_`1d0000
M;oo0=H0oooo003G0?ooo`030?oog`2LB000B9cO0=H0oooo003H0?ooo`030=nLB000000000000080
000000<0M;oo0?ooo`3oool00P3oool01@3o_g@000000000000004P0W=oo0080oooo00<0oono07@0
000000000P0000003@18W=l0oooo0?ooo`3oool0_g@00000000004P0W=oo0?ooo`3o_g@000000000
B02Lgol00P3oool0102oM00000000000B02Lgol20?ooo`050?noM000000000000000B02Lgol00`3o
ool00`3OW4P004RL0=ooo`020?ooo`030;md0000000007Bo09d0oooo003H0?ooo`070?noM00004P0
W=oo0?ooo`3ooml0W4P0001d_`020?ooo`0?0?oOW01804P0W=oo0?ooo`3ogi`0B000001d_`3oool0
oooO09a8001d_ol0oooo0?oOW0180000M;oo0080oooo01L0gia80018W03Ooml0W7BL0=ooo`3o_g@0
001809cOg`2LM9`0gooo0?ooo`3OW4P004RL0=oog`2LM9`0gooo0?oOW01804P0W=oo0?ooo`3ogi`0
B000001d_`020?ooo`030?noM00007@0_ooo0080oooo00@0gia80018W03O_g@0M;ooW03oool00=P0
oooo00<0oono07@0001d_ol00P3oool01`3ooml0W4P004RLg`3oool0gia80018W03Oool00P3oool0
2P3ogi`0B00004RLg`3oool0_gAd0;ooo`3oool0oono07@0001d_ol20?ooo`030?noM00004P0W=oo
0080oooo00<0oono07@0001d_ol00`3oool00`3o_g@0001809cOo`020?ooo`030=nLB000B9`0gooo
0080oooo00L0omnL04P00018W=l0oooo0?oo_`1d0000B9cO0080oooo00<0omnL04P0B02Lgol0W@3o
ool00=P0oooo00<0oooO09a80018W=l00`3oool01P3ogi`0B01809cOo`3o_g@0001d0;ooo`<0oooo
00<0gia80000M02oool00`3oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo
00<0_g@0001d_`3oool00P3oool00`3ookl0M00004RLg`020?ooo`030?noM00007@0_ooo00<0oooo
00/0gia80000M02oool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`2M0?ooo`00f@3oool0
0`3OW4P0001d0;ooo`020?ooo`060?oog`2LB000B9cO0?oo_`1d0000M;oo0`3oool00`3ogi`0B018
09cOo`020?ooo`030?noM00004P0W=oo00@0oooo00<0_g@00018W03Oool00P3oool00`3OW4P004RL
0=ooo`030?ooo`070;md0000B9`0gooo0?ooo`3ookl0M00007Boo`030?ooo`070?oOW01804P0W=oo
0?ooo`3OW4P004Q804Qd_`020?ooo`030;md0000M;l0oooo09`0oooo003I0?ooo`040?noM0000000
04RL0=ooo`80oooo00H0gia8001d_`3oool0gia80000M02oool20?ooo`0:0?oo_`1d0000M;oo0?oo
o`3ogi`0B01809cOo`3oool0giad09cOo`80oooo00<0gia80000B02Lgol00P3oool00`3ogi`0B018
09cOo`030?ooo`030=nLB00004P0W=oo0080oooo00<0gia80000M02oool00P3oool0303ookl0M000
07Boo`3oool0okmd0000M02o_g@0B9cO0?ooo`3o_g@0001d0;oooi`0oooo003I0?ooo`080?oo_`1d
0000M9bL04P0M02oool0oooO09a80000M;l20?ooo`0>0;md000007@0_ooo0?ooo`3o_g@0001d0;oo
o`3oool0omnL04P0B02Lgol0oooO09a8001d_ol20?ooo`030?oOW0180000B9cO0080oooo00<0oooO
09a80018W=l00`3oool00`3ogi`0B00004RLg`030?ooo`0@0;md000007@0_ooo0?ooo`3o_g@0001d
0;ooo`3oool0oooO09a8001d_ol0gia8001d_`3ogi`0B01809cOoi`0oooo003H0?ooo`090?oOW018
0000000004RLg`3ookl0M0000000000007@0_ooo00<0oooo00D0okmd000000000000000007Boo`03
0?ooo`070;md00000000000000000018W=l0oooo0?noM002000000040018W03Oool0oono07@000<0
000000H0M;oo0?noM000000000000018W03Oool30?ooo`0?0?noM000000000000000001d_ol0oooo
0?oo_`1d0000000004RLg`3oool0okmd0000000004P0W=oo09`0oooo003i0?ooo`030?noM00007@0
_ooo0;@0oooo003j0?ooo`030=nLM02Lgol0oooo0;<0oooo003d0?ooo`040?oo_`1d000004RL0=oo
o`L0oooo00@0oono07@00000B9`0gooo[@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool007P0oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`0f0?ooo`030?oo_`1d
000000000080000000<0B9cO0?ooo`3oool0<`3oool0102oM00000000000001d_olj0?ooo`030?oo
_`1d000000000080000000<0B9cO0?ooo`3oool0=`3oool00`3OW4P00000000000030000000304RL
g`3oool0oooo03P0oooo001i0?ooo`030?noM000M;l0oooo0080oooo00<0_gAd0;ooo`3oool0>03o
ool00`3o_g@0000007Boo`0e0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO>`3oool00`3o_g@0
000007Boo`0k0?ooo`030?noM000M;l0oooo0080oooo00<0_gAd0;ooo`3oool0>03oool007X0oooo
00<0okmd001d_`3oool0?03oool00`3ooml0W4P0001d_`0d0?ooo`030?oog`2LB000B9cO0080oooo
00<0okmd0000B02Lgol0>P3oool00`3ooml0W4P0001d_`0l0?ooo`030?noM000M;l0oooo03`0oooo
001k0?ooo`030?noM000M;l0oooo03`0oooo00<0gia80018W03Oool0<`3oool00`3ooml0W4P004RL
g`020?ooo`040?oog`2LB00004RL0=ooocX0oooo00<0gia80018W03Oool0?03oool00`3o_g@007Bo
0?ooo`0k0?ooo`00J`3oool00`3ooml0W4P0000000070000000304RLg`3oool0oooo00@0oooo00<0
okmd04RLg`3oool0:`3oool00`3ooml0W4P0000000070000000304RLg`3oool0oooo00<0oooo00<0
omnL04P0B02Lgol0<`3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo03X0oooo00<0
omnL04P0B02Lgol0?@3oool00`3o_g@0B9cO0?ooo`0j0?ooo`00O@3oool00`3OW4P0B9cO0?ooo`0j
0?ooo`030?oo_`1d0000M;oo03@0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0j
0?ooo`030?oo_`1d0000M;oo03h0oooo00<0gia804RLg`3oool0>@3oool007h0oooo00<0_g@007Bo
o`3oool0>P3oool00`2oM00007Bo0?ooo`0c0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a8
0000M;l0>`3oool00`2oM00007Bo0?ooo`0n0?ooo`030;md001d_ol0oooo03P0oooo001n0?ooo`03
0?oOW01807@0_ooo03X0oooo00<0gia80018W03Oool0<`3oool00`3ogi`0B00004RLg`030?ooo`03
0;md0000B9`0gooo03X0oooo00<0gia80018W03Oool0?P3oool00`3ogi`0B01d0;ooo`0h0?ooo`00
OP3oool00`3ooml0W4P007Boo`0j0?ooo`030?oOW01804P0W=oo03<0oooo00@0oooO09a80000B9`0
gooo0P3oool00`3OW4P004RL0=ooo`0j0?ooo`030?oOW01804P0W=oo03h0oooo00<0oooO09a8001d
_ol0>03oool007h0oooo00<0oono07@00018W=l0>P3oool00`3ookl0M00007Boo`0d0?ooo`030?oO
W0180000M;oo0080oooo00<0gia8001d_`3oool0>P3oool00`3ookl0M00007Boo`0n0?ooo`030?oo
_`1d0000B9cO03P0oooo001j0?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cOo`0k0?ooo`03
0;md0000M;l0oooo03@0oooo00H0gia80000M02oool0oooO09a80018W=ll0?ooo`030;md0000M;l0
oooo03T0oooo00L0okmd0018W03Oool0oooo0=nLB00004P0W=oo03P0oooo001k0?ooo`050?oOW018
000000000000001d_ol0>P3oool01@3ookl0M0000000000007@0_ooo03D0oooo00@0gia800000000
000007Bo>`3oool01@3ookl0M0000000000007@0_ooo03X0oooo00D0omnL04P000000000000007Bo
o`0i0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00A03o
oooo0000068000002`3oool004@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`09
0?ooo`00A03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2^0?ooo`03
0000003oool0oooo0:`0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0
[P3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003o
ool0oooo0:h0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool02@3oool0
04@0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo
00T0oooo00140?ooo`030000003oool0oooo04<0oooo1`00001T0?ooo`030000003oool0oooo0:`0
oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0@@3oool2000000L0oooo
2000001L0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool02@3oool004@0oooo00<0
00000?ooo`3oool0?`3oool2000000P0oooo1@0000040?ooo`<00000F@3oool00`000000oooo0?oo
o`2/0?ooo`030000003oool0oooo00T0oooo00140?ooo`800000?@3oool3000000<0oooo1`000005
0?ooo`@000000`3oool4000005D0oooo00<000000?ooo`3oool0ZP3oool3000000/0oooo00140?oo
o`030000003oool0oooo03X0oooo2000000@0?ooo`<00000103oool300000580oooo00<000000?oo
o`3oool0[03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0f0?ooo`@0
00002@3oool4000000h0oooo100000030?ooo`800000D03oool00`000000oooo0?ooo`2/0?ooo`03
0000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo03D0oooo0`0000090?ooo`800000
103oool4000000h0oooo100000000`3oool000000000001>0?ooo`030000003oool0oooo0:`0oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0<`3oool2000000X0oooo0P00
000:0?ooo`D000003@3oool2000000030?ooo`000000000004`0oooo00<000000?ooo`3oool0[03o
ool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0a0?ooo`<00000203oool3
000000/0oooo100000020?ooo`D000002P3oool2000000030?ooo`000000000004X0oooo00<00000
0?ooo`3oool0[03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0_0?oo
o`80000000<0oooo0000003oool01P3oool2000000<0oooo4P0000040?ooo`@00000203oool20000
00030?ooo`000000oooo04P0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`090?oo
o`00A03oool00`000000oooo0?ooo`0^0?ooo`040000003oool0oooo000000H0oooo0P0000030?oo
o`P000001@3oool;000000@0oooo0`0000070?ooo`@00000A`3oool00`000000oooo0?ooo`2/0?oo
o`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo02d0oooo00@000000?ooo`3o
ool00000103oool300000080oooo1P0000000`3oool0000000000003000000d0oooo100000050?oo
o`8000001`3oool4000004D0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`090?oo
o`00A03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0000000<0oooo0P0000020?ooo`@0
00000P3oool4000000D0oooo1`0000090?ooo`<000001@3oool2000000L0oooo100000130?ooo`03
0000003oool0oooo0:`0oooo00<000000?ooo`3oool02@3oool003@0oooo00<0gia8000000000000
0`0000000`18W=l0oooo0?ooo`070?ooo`030000003oool0oooo02`0oooo00<000000?ooo`000000
0P3oool200000080oooo2000000:0?ooo`d000001@3oool3000000@0oooo0P0000070?ooo`<00000
@P3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo00T0oooo000e0?ooo`030?noM000
M;l0oooo0080oooo00<0_gAd0;ooo`3oool01`3oool00`000000oooo0?ooo`0[0?ooo`040000003o
ool000000?ooo`8000000`3oool00`000000oooo00000002000000`0oooo0P0000070?ooo`X00000
0`3oool4000000<0oooo00<000000?ooo`3oool01P3oool300000400oooo00<000000?ooo`3oool0
[03oool00`000000oooo0?ooo`090?ooo`00=P3oool00`3o_g@007Bo0?ooo`0;0?ooo`030000003o
ool0oooo02X0oooo00D000000?ooo`000000oooo000000030?ooo`80000000<0oooo000000000000
2`3oool4000000l0oooo1@0000030?ooo`@000000P3oool2000000P0oooo0`00000n0?ooo`030000
003oool0oooo0:`0oooo00<000000?ooo`3oool02@3oool003L0oooo00<0okmd001d_`3oool02P3o
ool00`000000oooo0?ooo`0Z0?ooo`8000000P3oool01@000000oooo0?ooo`000000oooo00<00000
2P3oool2000000@0oooo1@00000=0?ooo`@000000`3oool400000080oooo0P0000080?ooo`<00000
?03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo00T0oooo000W0?ooo`030?oog`2L
B000000000L0000000<0B9cO0?ooo`3oool0103oool00`3o_g@0B9cO0?ooo`090?ooo`030000003o
ool0oooo02T0oooo0P0000020?ooo`050000003oool0oooo0000003oool00P00000:0?ooo`H00000
1`3oool4000000`0oooo0`0000030?ooo`@000000P3oool00`000000oooo0?ooo`070?ooo`800000
>`3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo00T0oooo000i0?ooo`030=nLB018
W=l0oooo00P0oooo0`00000X0?ooo`8000000P3oool00`000000oooo0?ooo`04000000P0oooo1@00
00040?ooo`D000001P3oool5000000X0oooo0P0000030?ooo`@0000000<0oooo000000000000203o
ool3000003T0oooo00<000000?ooo`3oool0ZP3oool3000000/0oooo000j0?ooo`030;md001d_ol0
oooo00L0oooo00<000000?ooo`3oool09`3oool200000080oooo00<000000?ooo`3oool010000007
0?ooo`80000000<0oooo0000000000002`3oool5000000H0oooo0`0000080?ooo`<000000`3oool4
000000030?ooo`000000000000P0oooo0`00000g0?ooo`030000003oool0oooo0:`0oooo00<00000
0?ooo`3oool02@3oool003X0oooo00<0omnL04P0M02oool01`3oool00`000000oooo0?ooo`0V0?oo
o`8000000`3oool6000000D0oooo0`0000000`3oool00000000000020?ooo`d000000`3oool50000
00@0oooo0P0000080?ooo`<000000P3oool5000000030?ooo`000000000000L0oooo0`00000f0?oo
o`030000003oool0oooo0:`0oooo00<000000?ooo`3oool02@3oool003X0oooo00<0oooO09a8001d
_ol01`3oool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo0?ooo`<0000000<0oooo0000
00000000103oool200000080oooo0P0000020?ooo`800000103oool?00000080oooo0`0000030?oo
o`800000203oool300000080oooo100000020?ooo`030000003oool0oooo00H0oooo0`00000d0?oo
o`030000003oool0oooo06P0oooo0`0000110?ooo`030000003oool0oooo00T0oooo000j0?ooo`03
0?oo_`1d0000B9cO00L0oooo00<000000?ooo`3oool09@3oool010000000oooo0?ooo`3oool20000
00040?ooo`0000000000000000<0oooo0P0000020?ooo`8000000P3ooolI000000<0oooo0P000003
0?ooo`8000001`3oool300000080oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`08
0?ooo`<00000<P3oool00`000000oooo0?ooo`1Q0?ooo`T0000000<0oooo0000000000001P00000i
0?ooo`030000003oool0oooo00T0oooo000f0?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cO
o`070?ooo`030000003oool0oooo02@0oooo00@000000?ooo`3oool0oooo0P000000103oool00000
0?ooo`0000020?ooo`8000000P3oool200000080oooo1000000C0?ooo`L000000P3oool2000000<0
oooo0P0000070?ooo`<0000000L0oooo00000000000000000?ooo`000000oooo00800000203oool3
00000340oooo00<000000?ooo`3oool0G`3oool2000000030?ooo`000000000001400000=`3oool0
0`000000oooo0?ooo`090?ooo`00=`3oool01@3ogi`0B000000000000000M;oo00P0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`<0000000@0oooo0000003oool0oooo0P00
00000`3oool00000000000020?ooo`@000005`3oool2000000030?ooo`0000000000008000000P3o
ool2000000<0oooo0P0000070?ooo`<0000000<0oooo0000000000000P0000020?ooo`030000003o
ool0oooo00L0oooo0`00000_0?ooo`030000003oool0oooo05d0oooo3`0000030?ooo`L00000=P3o
ool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0R0?ooo`8000000`3oool2
000000030?ooo`000000000000<0oooo0`0000020?ooo`@000002P3oool>000000<0oooo1`000002
0?ooo`8000000`3oool2000000L0oooo0P0000000`3oool0000000000003000000030?ooo`000000
oooo00P0oooo0`00000^0?ooo`030000003oool0oooo05/0oooo3P0000030?ooo`@000000P3oool8
00000380oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool08P3oool01000
0000oooo0?ooo`3oool2000000030?ooo`000000000000<0oooo0P0000020?ooo`D00000203ooolF
000000030?ooo`000000000000@000000P3oool2000000<0oooo0P0000060?ooo`<0000000<0oooo
0000000000000P0000000`3oool00000000000090?ooo`<00000;03oool00`000000oooo0?ooo`1H
0?ooo`<0000000<0oooo000000000000200000020?ooo`@00000103oool300000080oooo1`00000`
0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo0240oooo0P0000020?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo00000004000000030?ooo`000000
oooo00H0oooo1@0000050?ooo`H000001@3oool<00000080oooo0P0000030?ooo`8000001P3oool7
00000080oooo00<000000?ooo`3oool01`3oool4000002X0oooo00<000000?ooo`3oool0EP3oool8
000000030?ooo`000000000000h00000103oool200000080oooo1P00000_0?ooo`030000003oool0
oooo00T0oooo00140?ooo`030000003oool0oooo0200oooo0P0000030?ooo`80000000<0oooo0000
003oool00P3oool00`000000oooo00000006000000D0oooo1000000?0?ooo`L00000103oool70000
00<0oooo0P0000030?ooo`8000001@3oool00`000000oooo00000005000000030?ooo`000000oooo
00T0oooo00<000000?ooo`000000:@3oool00`000000oooo0?ooo`1D0?ooo`/0000000<0oooo0000
000000000P0000050?ooo`80000000<0oooo0000000000002P0000000`3oool000000?ooo`040000
02d0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool07`3oool00`000000
oooo000000020?ooo`80000000<0oooo0000000000000`3oool5000000030?ooo`000000oooo00@0
oooo0P00000:0?ooo`/000001@3oool400000080oooo0P0000000`3oool0000000000002000000<0
oooo0P0000030?ooo`030000003oool0oooo00<0oooo0P000000103oool000000000003oool20000
00030?ooo`000000000000T0oooo1000000W0?ooo`030000003oool0oooo0580oooo1`000000103o
ool000000000003oool3000000H0oooo1P0000030?ooo``0000000<0oooo0000003oool00`00000[
0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01l0oooo0P0000020?oo
o`D000000`3oool400000080oooo00<000000?ooo`3oool00P3oool200000080oooo2P00000;0?oo
o`8000001`3oool200000080oooo0P0000000`3oool0000000000002000000<0oooo0P0000020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`000000100000020?ooo`030000003oool0oooo
00P0oooo00@000000?ooo`00000000009@3oool00`000000oooo0?ooo`1@0?ooo`L0000000@0oooo
000000000000oooo0P0000070?oooa<0000000@0oooo000000000000oooo1@0000000`3oool00000
0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01h0oooo00H0
00000?ooo`000000oooo0000003oool3000000<0oooo00D000000?ooo`00000000000?ooo`020000
00@0oooo0P0000000`3oool000000000000<0?ooo`D000001P3oool3000000H0oooo0P0000020?oo
o`L000000`3oool00`000000oooo0?ooo`02000000D0oooo00<000000?ooo`0000001@0000000`3o
ool000000?ooo`090?ooo`80000000<0oooo0000003oool08`3oool00`000000oooo0?ooo`1=0?oo
o`@0000000@0oooo00000000000000000P3oool010000000oooo0?ooo`0000060?ooo`@0000000<0
oooo0000000000000P3oool?000000040?ooo`00000000000?ooo`@0000000<0oooo0000003oool0
:03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0M0?ooo`050000003o
ool0oooo0000003oool00`0000001P3oool000000?ooo`3oool000000?ooo`@000001@3oool20000
00030?ooo`000000oooo00D0oooo200000030?ooo`@000001`3oool2000000H0oooo00<000000?oo
o`3oool00P3oool600000080oooo0P0000020?ooo`030000003oool0oooo00<0oooo0P0000000`3o
ool0000000000003000000030?ooo`000000000000X0oooo1000000R0?ooo`030000003oool0oooo
04/0oooo100000000`3oool000000000000200000080oooo00@000000?ooo`3oool00000103oool5
000000030?ooo`00000000000080oooo4`0000000`3oool0000000000006000002P0oooo00<00000
0?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool07@3oool010000000oooo0000003oool3
000000040?ooo`000000oooo0?ooo`H00000103oool500000080oooo1@0000090?ooo`800000103o
ool5000000@0oooo0P0000050?ooo`800000103oool600000080oooo00@000000?ooo`3oool00000
1P3oool010000000oooo0000003oool300000080oooo00<000000?ooo`3oool02@3oool00`000000
oooo0000000Q0?ooo`030000003oool0oooo04T0oooo100000020?ooo`@0000000@0oooo00000000
0000oooo0P0000030?ooo`80000000@0oooo000000000000oooo1`00000<0?ooo`8000000P3oool4
000000030?ooo`000000000000D000009`3oool00`000000oooo0?ooo`090?ooo`00A03oool20000
01d0oooo00<000000?ooo`3oool00P0000001P3oool000000000003oool000000?ooo`80000000@0
oooo0000000000000000103oool4000000<0oooo00<000000?ooo`3oool02@3oool9000000<0oooo
2`0000040?ooo`800000103oool500000080oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0000000400000080oooo00<000000?ooo`3oool02@3oool4000001l0oooo00<000000?ooo`3o
ool0A`3oool5000000050?ooo`00000000000?ooo`0000000P3oool010000000oooo0?ooo`000003
0?ooo`80000000<0oooo0000000000002000000@0?ooo`040000003oool0oooo0?ooo`@0000000<0
oooo0000000000001000000T0?ooo`<000002`3oool004@0oooo00<000000?ooo`3oool0703oool0
1@000000oooo000000000000oooo0080000000<0oooo0000003oool00P000000103oool000000000
000000030?ooo`@000000`3oool2000000L0oooo200000060?ooo`8000000`3oool2000000@0oooo
1@0000040?ooo`800000103oool5000000040?ooo`00000000000?ooo`8000001@3oool200000004
0?ooo`00000000000?ooo`80000000<0oooo0000000000002`3oool010000000oooo00000000000M
0?ooo`030000003oool0oooo04D0oooo1@0000020?ooo`040000003oool0000000000080oooo00@0
00000?ooo`00000000000`3oool00`000000oooo00000008000000L0oooo2`0000020?ooo`800000
0`3oool7000000030?ooo`000000oooo02D0oooo00<000000?ooo`3oool02@3oool004@0oooo00<0
00000?ooo`3oool0703oool00`000000oooo00000004000000050?ooo`000000oooo0000003oool0
0P0000040?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`P000003@3oool2000000<0oooo
0`0000050?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`<0000000D0oooo000000000000
oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000100000020?ooo`03
0000003oool0oooo00T0oooo0P0000000`3oool000000?ooo`0K0?ooo`030000003oool0oooo04<0
oooo100000000`3oool000000?ooo`02000000040?ooo`000000oooo0?ooo`80000000<0oooo0000
003oool00P3oool;000000D0oooo2P0000000`3oool0000000000004000000030?ooo`0000000000
00<0oooo100000000`3oool0000000000002000002D0oooo00<000000?ooo`3oool02@3oool004@0
oooo00<000000?ooo`3oool06`3oool01@000000oooo000000000000oooo0080000000<0oooo0000
003oool0100000040?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<000004P3oool2000000@0oooo0P0000050?ooo`800000103oool2000000@0oooo0P0000020?oo
o`<000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000@000000P3oool00`00
0000oooo0?ooo`0:0?ooo`040000003oool00000000001X0oooo00<000000?ooo`3oool0@@3oool2
000000030?ooo`000000oooo0080000000D0oooo000000000000oooo000000020?ooo`040000003o
ool00000000000<0oooo1`0000000`3oool00000000000030?ooo`D0000000<0oooo000000000000
1P0000070?ooo`030000003oool0oooo008000000`3oool3000000030?ooo`000000000000800000
903oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0000000D000000P3oool010000000oooo0000000000040?ooo`800000103oool010000000oooo
0?ooo`3oool2000000030?ooo`000000000001L0oooo0P0000040?ooo`8000001@3oool2000000@0
oooo0P0000030?ooo`<000000P3oool3000000030?ooo`000000oooo00D0oooo0P0000000`3oool0
000000000003000000030?ooo`000000000000/0oooo0P0000000`3oool000000?ooo`0H0?ooo`03
0000003oool0oooo03l0oooo0P0000001@3oool000000000003oool000000080oooo00D000000?oo
o`3oool000000?ooo`02000000030?ooo`000000oooo00<0oooo100000001@3oool000000000003o
ool0000000<0oooo0`0000020?oooaD0000000<0oooo000000000000103oool7000002<0oooo00<0
00000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool06`3oool3000000080?ooo`000000
00000?ooo`000000oooo0000003oool2000000@0oooo0P0000030?ooo`8000000`3oool010000000
oooo00000000000K0?ooo`800000103oool2000000D0oooo0P0000040?ooo`030000003oool0oooo
0080oooo0P0000030?ooo`80000000<0oooo0000000000001P3oool01@000000oooo000000000000
oooo008000000P3oool00`000000oooo0?ooo`0:0?ooo`@000005`3oool00`000000oooo0?ooo`0m
0?ooo`80000000@0oooo000000000000oooo0P0000000`3oool00000000000020?ooo`030000003o
ool000000080oooo00@000000?ooo`3oool0oooo100000001P3oool00000000000000000oooo0000
0080oooo0`0000020?ooo`d000000P3oool9000000040?ooo`0000000000000000<0oooo00<00000
0?ooo`0000001000000R0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`0000001@0000020?ooo`<000001@3oool200000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000050?oooa<000001`3oool2000000@0oooo00<000000?oo
o`3oool00`3oool3000000<0oooo00<000000?ooo`3oool00P3oool2000000@0oooo0P0000000`3o
ool000000?ooo`050?ooo`050000003oool000000000003oool00P0000020?ooo`030000003oool0
oooo00/0oooo1000000E0?ooo`030000003oool0oooo03/0oooo0P0000020?ooo`040000003oool0
oooo00000080oooo0P0000001P3oool000000000003oool000000?ooo`8000000`3oool400000004
0?ooo`00000000000?ooo`8000000P3oool200000080oooo1`0000060?ooo`H0000000D0oooo0000
0000000000000?ooo`03000000040?ooo`000000oooo00000080oooo1P0000000`3oool000000?oo
o`0P0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`0000000`0000001@3oool000000?ooo`000000oooo00800000103oool200000080oooo00@0
00000?ooo`3oool0oooo0P0000000`3oool000000?ooo`030?ooo`8000004`3oool2000000L0oooo
0P0000030?ooo`030000003oool0oooo00<0oooo100000020?ooo`800000103oool2000000<0oooo
100000060?ooo`030000003oool0oooo00@000000P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0000001@0oooo00<000000?ooo`3oool0>@3oool2000000<0oooo00@000000?ooo`3oool0
00000P3oool2000000030?ooo`000000oooo0080000000<0oooo0000003oool00`3oool200000003
0?ooo`000000oooo0080000000@0oooo0000003oool0oooo0P0000020?ooo`@000002P3oool30000
00@0oooo00<000000?ooo`3oool00`0000000`3oool0000000000005000000050?ooo`0000000000
0000003oool00P0000000`3oool000000?ooo`0O0?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo01X0oooo0`0000001@3oool00000000000000000oooo00@00000103oool2
00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo008000005`3o
ool2000000L0oooo0P0000020?ooo`8000001@3oool010000000oooo0000000000020?ooo`030000
003oool0oooo0080oooo0P0000040?ooo`<000001P3oool2000000030?ooo`000000000000<00000
00<0oooo0000003oool03@3oool400000180oooo00<000000?ooo`3oool0=`3oool2000000<0oooo
0P0000020?ooo`040000003oool0000000000080oooo00<000000?ooo`0000000P3oool010000000
oooo0?ooo`3oool:000000030?ooo`000000000000<0oooo0`0000070?oooaL0000000<0oooo0000
003oool02@00000P0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`0000000`0000000`3oool0000000000004000000@0oooo00@000000?ooo`00
000000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool03@3oool5
000000L0oooo0P0000070?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080000000<0oooo0000003oool00`3oool3000000<0oooo00@000000?ooo`00000000001P3o
ool01@000000oooo000000000000oooo0080000000<0oooo0000000000003P3oool300000140oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00800000
00<0oooo0000000000000P3oool00`000000oooo000000020?ooo`040000003oool0oooo0?ooo`80
000000<0oooo0000003oool0100000020?ooo`8000000P3oool4000000<0oooo2P0000050?ooo`80
00000`3oool010000000oooo0?ooo`3oool7000000030?ooo`00000000000080000000D0oooo0000
00000000oooo0000000O0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
01T0oooo0P0000000`3oool0000000000002000000030?ooo`000000000000800000103oool30000
00<0oooo0P0000030?ooo`040000003oool00000000000`0oooo4@0000000`3oool0000000000007
0?ooo`040000003oool0oooo000000D0oooo0P0000020?ooo`<00000103oool3000000<0oooo00<0
00000?ooo`3oool00P0000050?ooo`050000003oool0oooo0000003oool00P0000020?ooo`030000
003oool0oooo00d0oooo0`00000?0?ooo`030000003oool0oooo03@0oooo0P0000040?ooo`040000
003oool0oooo00000080oooo0P0000020?ooo`030000003oool000000080oooo00@000000?ooo`3o
ool0oooo0P0000000`3oool000000?ooo`0400000080oooo00<000000?ooo`3oool0100000020?oo
o`<000000`3oool00`000000oooo0?ooo`040?ooo`X0000000<0oooo0000003oool00P3oool70000
0080oooo0`000000103oool0000000000000000O0?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo01T0oooo0`0000000`3oool000000?ooo`05000000@0oooo0`0000030?oo
o`030000003oool0oooo0080oooo0`0000050?ooo`l00000103oool3000000@0oooo1P0000050?oo
o`80000000<0oooo0000000000001@3oool010000000oooo0?ooo`3oool2000000@0oooo0`000003
0?ooo`030000003oool0oooo008000001@3oool01@000000oooo0?ooo`000000oooo008000000P3o
ool00`000000oooo0?ooo`0>0?ooo`<000003@3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool200000080oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`03000000030?ooo`000000000000<000000P3oool2000000030?oo
o`000000000000<0000000<0oooo0000000000000`0000000`3oool000000000000@0?ooo`@00000
0`3oool00`000000oooo00000004000000030?ooo`00000000000080000000@0oooo000000000000
00007P3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0000000@0000000@0oooo0000000000000000103oool2000000<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`80000000@0oooo000000000000oooo0`0000000`3o
ool0000000000009000000<0oooo0`0000060?ooo`<000001@3oool010000000oooo0?ooo`000005
0?ooo`040000003oool0oooo0?ooo`<000000`3oool400000080oooo00<000000?ooo`3oool00`00
00040?ooo`030000003oool0oooo00D0000000<0oooo0000003oool0403oool3000000/0oooo00<0
00000?ooo`3oool0<@3oool2000000D0oooo00D000000?ooo`3oool000000?ooo`02000000<0oooo
00<000000?ooo`0000000P3oool01`000000oooo0?ooo`000000oooo0000003oool01@0000020?oo
o`80000000<0oooo0000000000001P0000040?ooo`@000004@3oool3000000<0oooo00<000000?oo
o`000000100000001@3oool00000000000000000oooo00<000007P3oool00`000000oooo0?ooo`09
0?ooo`00A03oool00`000000oooo0?ooo`0H0?ooo`80000000<0oooo0000000000000P000000103o
ool000000?ooo`0000040?ooo`<0000000<0oooo000000000000103oool2000000D0oooo50000002
0?ooo`@000000P3oool2000000H0oooo100000030?ooo`030000003oool0oooo00800000103oool2
000000<0oooo0P0000030?ooo`@000000P3oool01@000000oooo0?ooo`000000oooo008000000`3o
ool01P000000oooo0?ooo`3oool000000?ooo`80000000<0oooo0000003oool04@3oool3000000T0
oooo00<000000?ooo`3oool0;`3oool2000000D0oooo0P0000020?ooo`040000003oool000000000
00<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`000000oooo00l000000P3oool2
000000@0oooo0P0000040?ooo`@000003`3oool300000080oooo00<000000?ooo`00000020000000
103oool0000000000000000M0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0
oooo01P0oooo0`0000001@3oool00000000000000000oooo00<000000`3oool3000000030?ooo`00
0000oooo00<0oooo0`0000050?ooo`80000000@0oooo000000000000oooo0`00000<0?ooo`P00000
0P3oool2000000H0oooo00@000000?ooo`00000000000P3oool01@000000oooo0?ooo`3oool00000
00D0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`D0000000D0oooo0000003oool0oooo0000
00020?ooo`8000000P3oool200000080oooo00D000000?ooo`00000000000?ooo`0200000180oooo
0`0000070?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`02000000030?ooo`00000000000080oooo0P000000103oool000000?ooo`3oool600000003
0?ooo`000000000000H0000000<0oooo0000000000002@0000000`3oool000000?ooo`090?ooo`X0
00001`3oool200000080oooo00<000000?ooo`0000000`0000001@3oool00000000000000000oooo
00<000007@3oool00`000000oooo0?ooo`090?ooo`00A03oool2000001T0oooo00<000000?ooo`00
00000`000000103oool000000000000000040?ooo`@00000103oool00`000000oooo000000040?oo
o`8000000P3oool4000001<0oooo1P0000020?ooo`8000001@3oool00`000000oooo0?ooo`050000
0080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool2000000<0oooo0`000000
0`3oool000000?ooo`02000000030?ooo`00000000000080oooo0P0000020?ooo`030000003oool0
oooo00@000000P3oool00`000000oooo0?ooo`0A0?ooo`<000001@3oool00`000000oooo0?ooo`0/
0?ooo`8000001P3oool01@000000oooo0?ooo`000000oooo008000000`3oool00`000000oooo0?oo
o`05000000030?ooo`00000000000080oooo00<000000?ooo`000000300000050?ooo`<000000`3o
ool900000080oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`0:000000040?ooo`00
00000000000001X0oooo0`00000;0?ooo`00A03oool00`000000oooo0?ooo`0G0?ooo`80000000<0
oooo0000000000000P000000103oool000000000000000030?ooo`<0000000<0oooo0000003oool0
0P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo0?ooo`@00000303oool80000
00<0oooo1@0000020?ooo`800000103oool2000000<0oooo0`0000020?ooo`800000103oool01000
0000oooo0?ooo`3oool2000000<0oooo0`0000001@3oool000000000003oool000000080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080000000D0oooo0000003oool0
oooo0000000E0?ooo`8000000`3oool00`000000oooo0?ooo`0Z0?ooo`8000001`3oool01@000000
oooo0?ooo`000000oooo008000000`3ooolA00000080oooo00<000000?ooo`3oool01P0000000`3o
ool0000000000005000000040?ooo`0000000000000000d0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`P0000000@0oooo0000000000000000
703oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0000000<0000000@0oooo0000000000000000103oool4000000@0oooo00<000000?ooo`000000
0P3oool2000000060?ooo`00000000000000003oool000002P3oool4000000P0oooo2P0000020?oo
o`800000103oool00`000000oooo0?ooo`020?ooo`8000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo0P0000020?ooo`<000000P3oool00`000000oooo000000020?oo
o`040000003oool0oooo0?ooo`80000000<0oooo0000003oool00P3oool01@000000oooo00000000
0000oooo008000005@3oool2000000030?ooo`000000oooo02T0oooo0P0000080?ooo`050000003o
ool0oooo0000003oool0300000020?ooo`80000000<0oooo0000000000000`0000020?ooo`030000
003oool0oooo00D000001@3oool2000000<0oooo0P000000103oool0000000000000000<0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool2000000<0oooo3000000K0?ooo`03
0000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01L0oooo00<000000?ooo`000000
0`000000103oool000000000000000030?ooo`<0000000<0oooo0000003oool00P3oool00`000000
oooo000000020?ooo`P000001`3oool:000000d0oooo1@0000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`8000000`3oool3000000040?ooo`000000000000000080oooo00<000000?oo
o`3oool00P3oool3000000<0oooo100000020?ooo`030000003oool0oooo01@0oooo1000000V0?oo
o`800000203oool200000080oooo2`0000000`3oool000000?ooo`020?ooo`80000000<0oooo0000
000000000`0000020?ooo`030000003oool0oooo00D000001@3oool010000000oooo0?ooo`3oool2
00000080oooo0P0000020?ooo`8000002`3oool00`000000oooo0?ooo`030?ooo`8000001@3oool3
00000080oooo2`00000K0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool00P0000000`3oool0000000000002000000@0oooo100000040?oo
o`8000000P3oool3000000040?ooo`0000000000000000H0oooo100000000`3oool0000000000002
000000030?ooo`000000000000L000002@3oool5000000030?ooo`000000oooo00<0oooo00<00000
0?ooo`3oool0103oool2000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool00P3oool2
000000<0oooo0`0000020?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`8000000`3oool4
00000080oooo00<000000?ooo`3oool0503oool00`000000oooo0000000400000200oooo0P000008
0?ooo`/0000000L0oooo0000003oool0oooo0000003oool0000000<0oooo0P0000001@3oool00000
0000003oool0000000<0oooo00<000000?ooo`3oool0100000050?ooo`8000000`3oool00`000000
oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`8000002P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool;000001X0oooo00<000000?oo
o`3oool02@3oool004@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0000000300000004
0?ooo`0000000000000000<0oooo0`0000000`3oool000000?ooo`020?ooo`030000003oool00000
0080000000<0oooo0000003oool00P0000060?ooo`L000001@3oool4000000@0oooo1P0000050?oo
o`L00000103oool00`000000oooo0?ooo`040?ooo`@00000103oool00`000000oooo0?ooo`020?oo
o`8000000`3oool3000000<0oooo00@000000?ooo`3oool000001P3oool200000080oooo0P000000
103oool000000?ooo`3oool2000001@0oooo00<000000?ooo`3oool00`3oool5000001X0oooo0P00
00050?ooo`X0000000<0oooo0000000000000`3oool01P000000oooo0?ooo`000000oooo000000<0
oooo100000000`3oool00000000000030?ooo`030000003oool0oooo00@000001@3oool010000000
oooo0?ooo`3oool2000000P0oooo0P0000030?ooo`8000002@3oool00`000000oooo0?ooo`040?oo
o`8000000`3oool2000000030?ooo`000000oooo00D0000000<0oooo0000000000000`00000J0?oo
o`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01D0oooo0P0000000`3oool0
000000000002000000030?ooo`000000000000<0oooo0P0000000`3oool00000000000030?ooo`04
0000003oool0000000000080oooo100000060?ooo`@000001@3oool8000000L0oooo1P0000040?oo
o`@0000000<0oooo0000000000000`3oool2000000D0oooo00@000000?ooo`0000000000103oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`<000000`3oool2000000030?ooo`00
0000oooo00D0oooo0`0000000`3oool0000000000002000000<0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`070?ooo`L000004P3oool2000000<0oooo2@0000020?ooo`030000003o
ool00000008000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo100000000`3oool0
0000000000030?ooo`030000003oool0000000@000001@3oool00`000000oooo0?ooo`02000000`0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3oool0oooo0`0000020?ooo`T0000000<0oooo0000003oool0603oool00`00
0000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0
000000@0oooo00000000000000000`3oool3000000030?ooo`000000oooo0080oooo0`0000020?oo
o`<000001P3oool3000000@0oooo1@0000060?ooo`T0000000<0oooo0000000000000P3oool40000
0080oooo100000000`3oool00000000000030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P0000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0`000003
0?ooo`80000000<0oooo0000000000001P3oool3000000030?ooo`0000000000008000000P3oool2
00000140oooo00<000000?ooo`3oool02`3ooolK000000D0oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo10000000
0`3oool00000000000030?ooo`030000003oool0000000@000001@3oool010000000oooo00000000
000?0?ooo`8000000`3oool00`000000oooo00000004000000<0oooo00<000000?ooo`3oool01@3o
ool010000000oooo0?ooo`3oool300000080oooo2P00000I0?ooo`030000003oool0oooo00T0oooo
00140?ooo`030000003oool0oooo01D0oooo00<000000?ooo`0000000`0000000`3oool000000000
00030?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`000000oooo00<000001P3o
ool2000000<0oooo0`0000020?ooo`T000001P3oool2000000030?ooo`000000000000<000000P3o
ool400000080oooo0`000000103oool000000000000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`0000000`3oool000000?ooo`050?ooo`040000003oool0oooo0?ooo`<0
00000`3oool3000000030?ooo`000000oooo00D0oooo00<000000?ooo`0000001@0000030?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool05P3oool8000000/0oooo0P0000030?ooo`05
0000003oool000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo00000080oooo0P00
00000`3oool000000?ooo`03000000<0oooo00<000000?ooo`000000100000050?ooo`030000003o
ool000000180oooo1P0000050?ooo`80000000<0oooo0000003oool01`3oool2000000040?ooo`00
0000oooo00000080oooo2@0000000`3oool000000?ooo`0G0?ooo`030000003oool0oooo00T0oooo
00140?ooo`030000003oool0oooo01@0oooo0P0000000`3oool0000000000005000000<0oooo0`00
00000`3oool000000?ooo`020?ooo`<0000000@0oooo00000000000000001@3oool300000080oooo
0`000000103oool000000000000000050?ooo`P00000103oool200000080oooo100000020?ooo`@0
00000P3oool2000000030?ooo`000000oooo0080000000<0oooo0000003oool0103oool01@000000
oooo0?ooo`000000oooo00<000001P3oool200000080oooo0`0000030?ooo`050000003oool00000
0?ooo`0000001P3oool010000000oooo0?ooo`3oool4000000<0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0I0?ooo`8000003@3oool010000000oooo0?ooo`3oool2000000040?oo
o`000000oooo000000<0oooo00L000000?ooo`3oool000000?ooo`000000oooo00<0000000<0oooo
0000003oool00`0000030?ooo`030000003oool0000000@000001@3oool00`000000oooo0000000A
0?ooo`8000000`3oool00`000000oooo000000070?ooo`<000002@3oool00`000000oooo00000002
00000080oooo200000000`3oool000000?ooo`0G0?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`0000000`000000103oool00000000000000002
0?ooo`80000000<0oooo0000000000000`3oool3000000040?ooo`0000000000000000D0oooo0`00
00020?ooo`H000000`3ooolA000000030?ooo`000000000000<0oooo100000000`3oool000000000
0002000000030?ooo`0000000000008000000P3oool4000000@0oooo00@000000?ooo`3oool00000
0P3oool2000000H0oooo0P0000020?ooo`<000000`3oool00`000000oooo00000002000000H0oooo
00H000000?ooo`3oool0oooo0000003oool300000080oooo0P00000=0?ooo`030000003oool0oooo
01H0oooo0`00000=0?ooo`8000000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00D0
00000?ooo`3oool000000?ooo`03000000050?ooo`000000oooo0000003oool00`0000030?ooo`L0
00001@3oool00`000000oooo0000000@0?ooo`8000001P3oool00`000000oooo000000090?ooo`80
0000203oool010000000oooo0000000000020?ooo`X00000603oool00`000000oooo0?ooo`090?oo
o`00A03oool00`000000oooo0?ooo`0C0?ooo`80000000<0oooo0000000000000P0000000`3oool0
0000000000020?ooo`@0000000@0oooo0000003oool0oooo0`000000103oool000000?ooo`000004
0?ooo`@0000000<0oooo0000000000002@0000020?ooo`P000000`3oool6000000030?ooo`000000
000000@0oooo300000030?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool000000P3o
ool2000000D0oooo00<000000?ooo`0000000P3oool3000000<0oooo00<000000?ooo`3oool00P00
00060?ooo`040000003oool0oooo0?ooo`L0000000<0oooo0000003oool02`3oool00`000000oooo
0?ooo`0C0?ooo`<000003`3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003o
ool000000`3oool01@000000oooo0?ooo`000000oooo008000000P3oool010000000oooo0000003o
ool400000080oooo1`0000050?ooo`030000003oool0000000l0oooo0P0000090?ooo`030000003o
ool0000000T0oooo0P0000070?ooo`060000003oool000000?ooo`000000oooo2P00000H0?ooo`03
0000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01<0oooo0P0000000`3oool00000
0000000500000080oooo0P0000000`3oool00000000000030?ooo`H00000103oool3000000030?oo
o`000000000000H000000`3oool@000000030?ooo`000000000000@0000000<0oooo000000000000
103oool00`000000oooo00000002000000030?ooo`000000000000@000000P3oool3000000@0oooo
00@000000?ooo`3oool000000`3oool2000000@0oooo00<000000?ooo`0000000P3oool3000000<0
oooo00<000000?ooo`3oool00P0000060?ooo`8000000`3oool4000000030?ooo`00000000000080
00002P3oool00`000000oooo0?ooo`0?0?ooo`@00000403oool2000000@0oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`040000003oool0oooo0?ooo`<000000P3oool010000000oooo0000
003oool2000000040?ooo`000000oooo0?ooo`L000001@3oool00`000000oooo0000000>0?ooo`80
00002`3oool010000000oooo0?ooo`0000090?ooo`8000001`3oool010000000oooo000000000002
0?ooo`@0000000<0oooo0000000000000`00000G0?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo0180oooo0P0000000`3oool000000?ooo`02000000050?ooo`0000000000
0000003oool010000000103oool000000?ooo`3oool5000000030?ooo`000000oooo0080oooo00@0
00000?ooo`000000oooo0P0000001@3oool000000000003oool0000000@0oooo1`0000060?ooo`d0
000000<0oooo0000000000000`3oool2000000050?ooo`00000000000000003oool01@0000030?oo
o`800000103oool010000000oooo0?ooo`0000030?ooo`<000000`3oool00`000000oooo00000002
0?ooo`<000000`3oool200000080oooo0P0000060?ooo`060000003oool0oooo0?ooo`000000oooo
0`0000030?ooo`@000001P3oool00`000000oooo0?ooo`090?ooo`H000004`3oool00`000000oooo
0?ooo`030?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`3oool2
000000<0oooo00<000000?ooo`3oool00P0000000`3oool00000000000020?ooo`80000000<0oooo
0000000000000P0000050?ooo`030000003oool0000000d0oooo0P00000:0?ooo`/000001P3oool2
000000H0oooo00H000000?ooo`000000oooo0000003oool:000001L0oooo00<000000?ooo`3oool0
2@3oool004@0oooo00<000000?ooo`3oool04P3oool2000000030?ooo`000000000000H0000000<0
oooo0000000000000`0000030?ooo`80000000@0oooo00000000000000000`3oool010000000oooo
0000003oool5000000040?ooo`000000oooo0?ooo`D00000403oool=000000<0oooo00<000000?oo
o`3oool00P0000020?ooo`@00000103oool2000000<0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo000000030?ooo`050000003oool000000000003oool00`0000040?ooo`030000003o
ool0oooo008000001P3oool01P000000oooo0?ooo`3oool000000?ooo`<000000`3oool00`000000
oooo0?ooo`0400000080oooo00@000000?ooo`3oool0oooo2000000G0?ooo`800000103oool20000
00050?ooo`00000000000?ooo`0000000`3oool00`000000oooo0?ooo`03000000<0oooo00D00000
0?ooo`3oool000000?ooo`0300000080oooo0P0000000`3oool0000000000002000000D0oooo00<0
00000?ooo`0000003@3oool00`000000oooo0?ooo`080?ooo`@000000`3oool00`000000oooo0000
0005000000D0oooo0`0000050?ooo`040000003oool0000000000080oooo100000000`3oool00000
00000002000001L0oooo00<000000?ooo`3oool02@3oool004@0oooo0P00000C0?ooo`80000000<0
oooo0000000000001@0000000`3oool0000000000002000000040?ooo`000000oooo0?ooo`D00000
00@0oooo0000003oool0oooo0`0000001@3oool00000000000000000oooo00<000000P3oool40000
00@0oooo2@0000090?ooo`80000000<0oooo0000000000001P0000020?ooo`040000003oool0oooo
0?ooo`80000000<0oooo0000000000000P0000040?ooo`8000000`3oool010000000oooo0?ooo`00
00030?ooo`040000003oool0000000000080oooo00P000000?ooo`3oool000000?ooo`000000oooo
000000@0oooo00<000000?ooo`3oool00P0000060?ooo`060000003oool0oooo0?ooo`000000oooo
0`0000030?ooo`800000103oool6000001h0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000020?ooo`060000003oool0oooo0?ooo`000000oooo100000040?ooo`040000003oool0
00000?ooo`<000000P3oool2000000030?ooo`0000000000008000001P3oool2000000d0oooo00<0
00000?ooo`3oool01P3oool3000000P0oooo00<000000?ooo`000000103oool2000000@0oooo00<0
00000?ooo`000000103oool010000000oooo0?ooo`0000020?ooo`<0000000<0oooo000000000000
0`00000E0?ooo`<000002`3oool004@0oooo00<000000?ooo`3oool04P3oool010000000oooo0000
003oool2000000050?ooo`00000000000000003oool01@0000020?ooo`030000003oool000000080
000000<0oooo0000003oool00P3oool2000000050?ooo`000000oooo0000003oool00P0000030?oo
o`<00000103oool2000000T0oooo2@0000020?ooo`X000000P3oool2000000<0oooo00@000000?oo
o`000000oooo0P0000040?ooo`<000000P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo0080000000H0oooo0000003oool0oooo0000003oool3000000@0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`040000003oool0oooo0?ooo`80000000@0oooo00000000000000000`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01d0oooo0P0000050?ooo`050000003o
ool0oooo0000003oool00P0000030?ooo`070000003oool000000?ooo`000000oooo000000030?oo
o`040000003oool000000?ooo`@0000000@0oooo000000000000oooo100000060?ooo`800000303o
ool2000000L0oooo0P00000<0?ooo`030000003oool0000000D0oooo0P0000030?ooo`030000003o
ool0000000@0oooo00@000000?ooo`00000000000P3oool4000000030?ooo`000000000000800000
5P3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0A0?ooo`80000000<0
oooo0000003oool01`0000001@3oool000000000003oool000000080oooo1@000000103oool00000
0?ooo`3oool2000000050?ooo`000000oooo0000003oool00P0000020?ooo`<000000`3oool30000
01@0oooo0P0000030?ooo`P000000`3oool010000000oooo0?ooo`3oool3000000040?ooo`000000
0000000000<0oooo00H000000?ooo`00000000000?ooo`0000020?ooo`050000003oool0oooo0?oo
o`0000000`3oool300000080oooo00<000000?ooo`3oool00P0000040?ooo`040000003oool0oooo
0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool00000008000000`3oool2
000000<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`040?ooo`060000003oool0
oooo0000003oool00000103oool3000000040?ooo`000000oooo000000<0oooo00@000000?ooo`00
0000oooo10000000103oool000000000003oool4000000H0oooo0P00000<0?ooo`030000003oool0
oooo00H0oooo0P00000>0?ooo`030000003oool0000000D0oooo0P0000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`0000000P3oool3000000030?ooo`000000000000<000005P3o
ool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0A0?ooo`80000000D0oooo
00000000000000000?ooo`03000000030?ooo`000000000000<000000P3oool00`000000oooo0000
0002000000080?ooo`000000oooo0?ooo`000000oooo0000003oool2000000030?ooo`0000000000
0080oooo0P0000030?ooo`8000006@3oool2000000<0oooo10000000103oool00000000000000002
0?ooo`040000003oool0oooo0?ooo`L000000`3oool01P000000oooo0?ooo`000000oooo00000080
oooo00D000000?ooo`3oool0oooo000000040?ooo`8000000P3oool2000000030?ooo`0000000000
00@0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`8000000`3oool00`000000oooo00000002
000000@0oooo00@000000?ooo`3oool00000703oool2000000H0oooo00H000000?ooo`3oool00000
0?ooo`0000040?ooo`8000000P3oool00`000000oooo000000030?ooo`040000003oool000000?oo
o`80000000@0oooo0000003oool0oooo1P0000070?ooo`030000003oool0oooo00T0oooo0P000007
0?ooo`800000303oool500000080oooo00<000000?ooo`3oool00`3oool200000080oooo00@00000
0?ooo`3oool000000`3oool010000000oooo0?ooo`0000020?ooo`P000005P3oool00`000000oooo
0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0A0?ooo`<0000000D0oooo0000000000000000
0?ooo`02000000060?ooo`00000000000000003oool000000P3oool400000080oooo00<000000?oo
o`0000000P0000000`3oool0000000000002000000030?ooo`000000oooo008000000`3oool00`00
0000oooo0?ooo`0K0?ooo`<000000P3oool8000000030?ooo`00000000000080oooo200000020?oo
o`030000003oool0oooo00<000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo0P000002
0?ooo`040000003oool00000000000@0oooo00<000000?ooo`3oool00P3oool3000000@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`<000000`3oool00`000000oooo0000000K0?ooo`030000
003oool0oooo00@0oooo0P0000020?ooo`030000003oool0000000<0oooo0P0000040?ooo`800000
0`3oool020000000oooo0?ooo`000000oooo0000003oool000000P3oool6000000L0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`800000203oool6000000<0oooo1@000006
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo00000002
0?ooo`<0000000<0oooo0000000000000P00000F0?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo0140oooo00@000000?ooo`000000oooo1`000000103oool0000000000000
00020?ooo`030000003oool000000080000000H0oooo0000003oool0oooo0000003oool200000006
0?ooo`00000000000?ooo`000000oooo0P0000020?ooo`8000008@3oool200000080oooo0`000000
0`3oool0000000000002000000030?ooo`000000oooo0080oooo00<000000?ooo`0000000P000000
1@3oool000000000003oool0000000<0oooo0P0000020?ooo`050000003oool0oooo0?ooo`000000
1@3oool3000000030?ooo`000000oooo00800000103oool00`000000oooo0?ooo`020?ooo`040000
003oool00000000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`<000000`3oool20000
01X0oooo00<000000?ooo`3oool0103oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3o
ool3000000@0oooo0P0000030?ooo`050000003oool0oooo0000003oool0100000000`3oool00000
00000004000000L0oooo0P00000:0?ooo`030000003oool0oooo00H0oooo0P0000060?ooo`@00000
0`3oool3000000@0oooo1@0000050?ooo`030000003oool000000080oooo00H000000?ooo`3oool0
oooo0000003oool200000080oooo2000000E0?ooo`030000003oool0oooo00T0oooo00140?ooo`03
0000003oool0oooo0140oooo00@000000?ooo`000000oooo1@0000002@3oool00000000000000000
oooo0000003oool000000?ooo`03000000060?ooo`00000000000?ooo`000000oooo0P0000001P3o
ool000000000003oool000000?ooo`8000000P3oool00`000000oooo0?ooo`0S0?ooo`8000000P3o
ool200000080oooo00<000000?ooo`0000000P0000030?ooo`030000003oool00000008000000P3o
ool3000000@0oooo0P0000001@3oool000000?ooo`3oool0000000H0oooo00<000000?ooo`000000
0P0000000`3oool00000000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P0000020?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000000000000P0000020?ooo`80
00005`3oool2000000H0oooo00P000000?ooo`3oool0oooo0000003oool000000?ooo`80000000<0
oooo0000003oool00`3oool2000000@0oooo00@000000?ooo`000000oooo10000000103oool00000
0000003oool4000000H0oooo0P00000:0?ooo`030000003oool0oooo00D0oooo0`0000040?ooo`@0
0000103oool2000000<0oooo0P0000030?ooo`<0000000<0oooo0000003oool0103oool2000000<0
oooo00H000000?ooo`3oool0oooo0000003oool2000000050?ooo`00000000000000003oool01000
000E0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo0140oooo0P000000
0`3oool0000000000004000000030?ooo`0000000000008000000P3oool00`000000oooo00000002
000000030?ooo`000000oooo0080000000<0oooo0000003oool00P0000000`3oool0000000000002
00000080oooo00<000000?ooo`3oool09P3oool2000000060?ooo`00000000000000003oool00000
0P3oool2000000<0oooo00<000000?ooo`0000000P0000030?ooo`800000103oool3000000<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02000000030?ooo`000000000000@0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000000030?ooo`000000000000<0
oooo00T000000?ooo`3oool000000?ooo`000000oooo0000003oool00P00000D0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P000000103oool000000000000000020?ooo`030000
003oool0oooo0080oooo0P0000040?ooo`040000003oool000000?ooo`@000000P3oool00`000000
oooo00000003000000H0oooo0P00000:0?ooo`030000003oool0oooo00D0oooo0P0000050?ooo`<0
0000103oool2000000L0oooo0`0000001P3oool000000?ooo`000000oooo000000@0oooo0P000003
0?ooo`060000003oool0oooo0?ooo`000000oooo0P0000020?ooo`P00000503oool00`000000oooo
0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0@0?ooo`040000003oool000000?ooo`L00000
00H0oooo00000000000000000?ooo`0000020?ooo`80000000H0oooo000000000000oooo0000003o
ool7000000030?ooo`000000oooo00800000:`3oool2000000040?ooo`00000000000?ooo`800000
0P3oool200000080oooo00<000000?ooo`0000000P0000030?ooo`8000000`3oool00`000000oooo
0?ooo`0200000080oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool4000000@0
oooo00<000000?ooo`3oool00P3oool2000000<0oooo0P0000000`3oool000000?ooo`020?ooo`03
0000003oool0oooo00@000000`3oool200000100oooo0P0000070?ooo`050000003oool0oooo0000
003oool00`0000030?ooo`030000003oool0oooo0080oooo0P0000040?ooo`040000003oool00000
0?ooo`80000000H0oooo0000003oool0oooo0000003oool4000000H0oooo00<000000?ooo`000000
2@3oool00`000000oooo0?ooo`050?ooo`8000001@3oool2000000@0oooo0P00000<0?ooo`P00000
0`3oool2000000<0oooo00@000000?ooo`3oool0oooo100000001@3oool00000000000000000oooo
00@00000503oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0@0?ooo`04
0000003oool000000?ooo`X000000P3oool00`000000oooo00000002000000040?ooo`000000oooo
00000080oooo00<000000?ooo`0000000`000000103oool000000?ooo`00000_0?ooo`050000003o
ool000000000003oool00P0000020?ooo`<0000000<0oooo0000003oool00`0000040?ooo`050000
003oool0oooo0?ooo`0000000P3oool5000000D0oooo00<000000?ooo`3oool00P3oool4000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000000`3oool200000003
0?ooo`000000000000800000103oool2000000`0oooo0P0000070?ooo`8000000P3oool4000000@0
oooo00<000000?ooo`3oool00P3oool2000000@0oooo00@000000?ooo`000000oooo0P0000000`3o
ool0000000000002000000030?ooo`0000000000008000001`3oool2000000X0oooo00<000000?oo
o`3oool00`3oool3000000@0oooo0`0000030?ooo`800000403oool3000000040?ooo`0000000000
000000<0oooo0P0000020?ooo`030000003oool0oooo0080oooo0`0000020?ooo`80000000<0oooo
0000000000000P00000D0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
0100oooo0P0000000`3oool0000000000004000000030?ooo`00000000000080000000@0oooo0000
003oool0oooo0P0000001P3oool000000000003oool000000?ooo`H0000000@0oooo0000003oool0
0000<@3oool5000000040?ooo`000000oooo0?ooo`<0000000<0oooo0000000000000`0000040?oo
o`8000000P3oool010000000oooo0?ooo`0000020?ooo`<00000103oool00`000000oooo0?ooo`02
0?ooo`030000003oool00000008000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo0`0000020?ooo`060000003oool0oooo0000003oool000001@3oool2000000P0oooo
0P0000080?ooo`030000003oool00000008000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`000000oooo0000
003oool0200000000`3oool000000?ooo`050?ooo`8000002P3oool00`000000oooo0?ooo`030?oo
o`8000001@3oool300000080oooo0P00000C0?ooo`@0000000<0oooo0000000000000`3oool20000
0080oooo00@000000?ooo`3oool0oooo100000000`3oool0000000000005000001@0oooo00<00000
0?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool03`3oool3000000030?ooo`0000000000
00D0000000<0oooo0000000000000P3oool00`000000oooo00000002000000040?ooo`000000oooo
00000080oooo00<000000?ooo`0000000P0000020?ooo`030000003oool0000003<0oooo00H00000
0?ooo`00000000000?ooo`0000030?ooo`8000000P3oool5000000<0oooo0P0000020?ooo`040000
003oool0oooo000000<0oooo0`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00000`0000020?ooo`800000103oool00`000000oooo0?ooo`050?ooo`X000001P3oool2000000<0
oooo0`0000090?ooo`<0000000D0oooo0000003oool0oooo000000040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`000000oooo0000003oool01@00
00000`3oool0000000000002000000H0oooo00<000000?ooo`0000002@3oool00`000000oooo0?oo
o`030?ooo`8000001@3oool200000080oooo0P0000090?ooo`P000001@3oool2000000030?ooo`00
0000oooo008000000P3oool2000000<0oooo00@000000?ooo`3oool0oooo0`0000000`3oool00000
00000006000001<0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool03`3o
ool3000000030?ooo`000000000000P0000000@0oooo0000003oool0oooo0P0000001P3oool00000
0000003oool000000?ooo`<0000000L0oooo000000000000oooo0000003oool0000003D0oooo00H0
00000?ooo`00000000000?ooo`0000030?ooo`<0000000<0oooo0000000000000`0000030?ooo`<0
000000D0oooo0000003oool0oooo000000030?ooo`030000003oool000000080000000<0oooo0000
003oool00P3oool00`000000oooo0?ooo`02000000030?ooo`00000000000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`050?ooo`80000000<0oooo0000000000001P0000060?oo
o`<000001`3oool5000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`000000oooo0P0000001P3oool000000000
003oool000000?ooo`@000001P3oool00`000000oooo000000090?ooo`030000003oool0oooo00<0
oooo0P0000050?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`L00000103oool2000000<0
oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo008000000P3oool010000000
oooo0?ooo`3oool3000000050?ooo`00000000000000003oool01000000C0?ooo`030000003oool0
oooo00T0oooo00140?ooo`030000003oool0oooo00l0oooo0P0000020?ooo`D0000000@0oooo0000
0000000000000P3oool00`000000oooo00000002000000040?ooo`000000oooo00000080oooo1@00
0000103oool000000?ooo`00000g0?ooo`H000000`3oool010000000oooo0000003oool5000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool3
000000<0oooo00<000000?ooo`3oool00P0000020?ooo`80000000<0oooo0000003oool00`3oool2
000000L0oooo00<000000?ooo`3oool01`0000030?ooo`8000000P3oool8000000030?ooo`000000
000000<0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`040000003oool000000?ooo`80000000P0oooo000000000000oooo
0000003oool000000?ooo`8000001P3oool00`000000oooo000000090?ooo`030000003oool0oooo
00<0oooo0P0000050?ooo`8000000P3oool00`000000oooo0?ooo`050?ooo`<000001P3oool80000
0080oooo00@000000?ooo`3oool000000P3oool2000000030?ooo`000000000000<0oooo00@00000
0?ooo`3oool0oooo0P0000020?ooo`L000004`3oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`0>0?ooo`<0000000<0oooo0000003oool010000000103oool0000000000000
00020?ooo`030000003oool0000000@0000000<0oooo0000003oool0200000000`3oool000000?oo
o`0h0?ooo`80000000<0oooo0000000000000`3oool00`000000oooo00000007000000040?ooo`00
0000oooo0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0`0000020?ooo`050000003oool0oooo0?ooo`0000000`3oool4000000@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo000000020?ooo`d0000000<0oooo0000000000000`3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`000000oooo0P000000203oool000000000003o
ool000000?ooo`000000oooo0`0000060?ooo`030000003oool0000000T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`<000000P3oool00`000000oooo0?ooo`050?ooo`80
00003`3oool500000080oooo00D000000?ooo`3oool000000?ooo`0300000080oooo00@000000?oo
o`3oool0oooo0`0000000`3oool0000000000005000001<0oooo00<000000?ooo`3oool02@3oool0
04@0oooo0P00000?0?ooo`<0000000D0oooo00000000000000000?ooo`0600000080oooo00<00000
0?ooo`0000000`000000103oool000000000003oool5000000040?ooo`000000oooo000003/0oooo
1@0000030?ooo`030000003oool0oooo00D0000000@0oooo0000003oool000000`3oool200000003
0?ooo`000000oooo00<0oooo00<000000?ooo`3oool00`3oool3000000030?ooo`000000oooo0080
oooo00<000000?ooo`3oool00`3oool8000000H0oooo300000080?ooo`<00000103oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo00<000000?oo
o`0000000P3oool00`000000oooo00000009000000H0oooo00<000000?ooo`0000002@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`040?ooo`8000004`3oool3000000<0oooo00D000000?ooo`00000000000?ooo`02
000000<0oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000000000500000140oooo0`00
000;0?ooo`00A03oool00`000000oooo0?ooo`0>0?ooo`<0000000<0oooo0000000000000`000000
0`3oool000000?ooo`02000000030?ooo`000000oooo00D0000000<0oooo0000003oool01`000000
0`3oool000000?ooo`0m0?ooo`@000000`3oool00`000000oooo0?ooo`05000000040?ooo`000000
0000000000<0oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`0000000P0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool:000000@0oooo1P0000060?ooo`8000000P3oool400000080oooo0P0000040?ooo`030000003o
ool0oooo00<0oooo0P0000040?ooo`0=0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`04000000H0oooo00<000000?ooo`0000002@3oool00`000000oooo0?oo
o`030?ooo`8000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo0P00
000F0?ooo`<000000P3oool00`000000oooo0?ooo`0500000080oooo00@000000?ooo`3oool0oooo
2`00000B0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00h0oooo2@00
0000103oool000000000000000020?ooo`040000003oool000000?ooo`80000000@0oooo00000000
0000oooo1P0000020?ooo`030000003oool0oooo03d0oooo1@0000020?ooo`030000003oool0oooo
00D000000P3oool2000000<0oooo100000030?ooo`030000003oool0oooo00@0oooo00@000000?oo
o`3oool0oooo0`0000000`3oool000000?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool010000000oooo0000000000040?ooo`80000000@0oooo0000000000000000
0P3oool2000000D0oooo00<000000?ooo`0000000P0000050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`000000oooo0000003oool00`0000000`3o
ool000000?ooo`04000000H0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`03
0?ooo`8000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo0`00000H
0?ooo`8000000`3oool01@000000oooo000000000000oooo008000000P3oool010000000oooo0?oo
o`3oool4000000030?ooo`000000000000@000004P3oool00`000000oooo0?ooo`090?ooo`00A03o
ool00`000000oooo0?ooo`0>0?ooo`80000000<0oooo000000000000200000020?ooo`H0000000<0
oooo0000000000001`0000000`3oool000000?ooo`100?ooo`D000000P3oool010000000oooo0?oo
o`3oool3000000<0oooo0P0000030?ooo`040000003oool00000000000<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<00000103oool00`000000
oooo0?ooo`030?ooo`800000103oool01@000000oooo0?ooo`3oool0000000@0oooo0`000000103o
ool000000000000000060?ooo`040000003oool0oooo0?ooo`D0000000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`030?ooo`040000003oool000000?ooo`D0000000<0oooo0000003oool0
100000060?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00P3oool2000000<0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`800000303oool3000000`0
oooo0P0000030?ooo`030000003oool0000000@000000P3oool010000000oooo0?ooo`3oool:0000
0180oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool03@3oool010000000
oooo0000003oool3000000030?ooo`000000000000@000000P3oool5000000060?ooo`0000000000
0?ooo`000000oooo100000000`3oool000000?ooo`130?ooo`@0000000<0oooo0000003oool00`3o
ool3000000<0oooo0`0000020?ooo`040000003oool00000000000<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<00000103oool2000000D0oooo
00D000000?ooo`3oool0oooo000000040?ooo`800000103oool3000000040?ooo`00000000000000
0080oooo0P0000020?ooo`8000001@3oool6000000030?ooo`000000oooo00@0oooo00@000000?oo
o`000000oooo100000000`3oool0000000000006000000H0oooo00<000000?ooo`0000002@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0
oooo0080oooo0P00000:0?ooo`<000000`3oool3000000T0oooo0`0000020?ooo`030000003oool0
000000@000000P3oool010000000oooo0?ooo`3oool:00000180oooo00<000000?ooo`3oool02@3o
ool004@0oooo00<000000?ooo`3oool03@3oool7000000050?ooo`000000oooo0000003oool00P00
00000`3oool000000?ooo`04000000030?ooo`000000000000H000000P3oool00`000000oooo0?oo
o`130?ooo`@0000000<0oooo0000003oool00`3oool3000000<0oooo00<000000?ooo`0000000P00
00030?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo0?ooo`<00000103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
00H0oooo00<000000?ooo`3oool00P0000001@3oool00000000000000000oooo00<000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo7`0000000`3oool000000?ooo`07
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool200000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`@000002@3oool3000000H0oooo0`000003
0?ooo`030000003oool0000000@000000P3oool00`000000oooo0?ooo`0:00000180oooo00<00000
0?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool03@3oool=00000080oooo00<000000?oo
o`0000000P0000020?ooo`<0000000<0oooo0000000000000P0000000`3oool000000?ooo`160?oo
o`@0000000<0oooo0000003oool00`3oool3000000<0oooo00<000000?ooo`3oool00P0000020?oo
o`<0000000<0oooo0000003oool01@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
0?ooo`D000000P3oool00`000000oooo0?ooo`030?ooo`<000001`3oool2000000@0oooo2@000005
0?ooo`8000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo0P000000
1P3oool000000000003oool000000?ooo`@000001P3oool00`000000oooo0?ooo`0;000000@0oooo
00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`@000003P3oool3000000@0oooo0`0000030?ooo`80000000@0oooo000000000000
00000P3oool00`000000oooo0?ooo`04000000030?ooo`000000000000@000004@3oool00`000000
oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0=0?ooo`d000000P3oool5000000030?oo
o`000000000000H0000000<0oooo0000003oool0B03oool4000000030?ooo`000000oooo00<0oooo
0`0000020?ooo`040000003oool0oooo0?ooo`8000000P3oool00`000000oooo00000002000000D0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool200000080oooo1@0000050?oo
o`040000003oool0oooo0?ooo`@000000P3oool00`000000oooo0?ooo`030?ooo`P000000`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool000000?oo
o`02000000030?ooo`000000oooo00P000001@3oool01@000000oooo0?ooo`3oool0000000P0oooo
00<000000?ooo`0000001P0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool01@3oool2000000L0oooo1P0000070?ooo`8000000P3oool4000000<0oooo1P0000000`3oool0
00000?ooo`020?ooo`<0000000<0oooo0000000000001000000A0?ooo`030000003oool0oooo00T0
oooo00140?ooo`030000003oool0oooo00d0oooo1P0000000`3oool000000?ooo`04000000030?oo
o`000000oooo00@0000000D0oooo00000000000000000?ooo`04000000030?ooo`000000oooo04T0
oooo1P0000030?ooo`@000000P3oool00`000000oooo0?ooo`020?ooo`80000000@0oooo0000003o
ool0oooo0P0000050?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P000004
0?ooo`<000000`3oool5000000L0oooo0P0000000`3oool00000000000020?ooo`T000001`3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0000003oool00P0000001@3oool000000?oo
o`000000oooo00<0000000<0oooo0000000000001P3oool010000000oooo0?ooo`0000080?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0`0000000`3oool000000?ooo`030?oo
o`8000001P3oool00`000000oooo0?ooo`030?ooo`@000001P3oool4000000D0oooo00<000000?oo
o`3oool00`0000030?ooo`80000000@0oooo00000000000000000P3oool00`000000oooo0?ooo`0:
00000140oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool03@3oool80000
00030?ooo`00000000000080000000<0oooo0000003oool0100000000`3oool00000000000020000
00050?ooo`00000000000?ooo`000000C03oool6000000<0oooo100000020?ooo`030000003oool0
oooo0080oooo100000030?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool4000000030?ooo`000000oooo00800000203oool3
00000080oooo0P0000020?ooo`P00000103oool00`000000oooo0?ooo`040?ooo`040000003oool0
00000?ooo`8000000P3oool2000000030?ooo`000000oooo00@000001P3oool010000000oooo0?oo
o`0000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool5000000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`8000003P3oool2000000<0oooo
0P0000000`3oool0000000000002000000<0oooo1@0000020?ooo`030000003oool0oooo00@00000
00<0oooo0000000000001000000@0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003o
ool0oooo00d0oooo0P0000000`3oool0000000000004000000030?ooo`00000000000080oooo00<0
00000?ooo`0000000P0000020?ooo`P00000CP3oool6000000<0oooo100000020?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`00000000000`3oool010000000oooo0000000000020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool3000000<0oooo0P0000060?oo
o`@0000000H0oooo00000000000000000?ooo`0000060?ooo`040000003oool000000?ooo`800000
0P3oool2000000030?ooo`000000000000D000001@3oool01@000000oooo0?ooo`3oool0000000P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`80000000@0oooo00000000
000000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0403oool01P000000oooo0?ooo`3oool000000?ooo`80000000<0oooo0000000000000P3o
ool2000000060?ooo`00000000000000003oool000000P3oool4000000030?ooo`000000000000@0
0000403oool00`000000oooo0?ooo`090?ooo`00=03oool00`3ookl0M000000000020000000304RL
g`3oool0oooo00P0oooo00<000000?ooo`3oool03@3oool<00000080oooo1@0000000`3oool00000
00000005000000030?ooo`000000oooo04h0oooo1P0000030?ooo`H00000103oool010000000oooo
0?ooo`3oool2000000030?ooo`000000oooo0080oooo100000050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0103oool3000000@0oooo100000050?ooo`030000003oool0oooo0080
0000103oool00`000000oooo0?ooo`04000000040?ooo`0000000000000000@0oooo00@000000?oo
o`000000oooo0`0000001@3oool000000?ooo`000000oooo00<0000000<0oooo0000000000001P3o
ool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000
00<0oooo0000003oool00P3oool2000000D0oooo0P0000040?ooo`030000003oool0oooo0180oooo
0P0000020?ooo`060000003oool000000000003oool000000`3oool500000080oooo00<000000?oo
o`3oool00`0000000`3oool000000000000400000100oooo00<000000?ooo`3oool02@3oool003H0
oooo00<0okmd0000001d_ol02`3oool00`000000oooo0?ooo`0<0?ooo`d0000000<0oooo0000003o
ool0100000000`3oool0000000000006000002<0oooo1P00000X0?ooo`<0000000<0oooo00000000
00000P3oool4000000030?ooo`000000000000@0oooo00@000000?ooo`3oool0oooo100000050?oo
o`D000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00`0000000`3oool000000?ooo`030?ooo`8000001@3oool4000000H0oooo0`0000002@3o
ool00000000000000000oooo0000003oool000000?ooo`03000000050?ooo`000000oooo0000003o
ool01P0000060?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`8000000P3oool01P000000oooo0?ooo`3oool000000?ooo`8000000P3o
ool2000000<0oooo0P00000G0?ooo`030000003oool0oooo00<0000000<0oooo0000000000000P3o
ool500000080oooo00<000000?ooo`3oool00`0000000`3oool0000000000005000000l0oooo00<0
00000?ooo`3oool02@3oool003H0oooo00<0oooO09a80000M;l02`3oool00`000000oooo0?ooo`0<
0?ooo`d0000000<0oooo0000003oool0100000000`3oool0000000000006000001h0oooo1@000006
0?ooo`<000009P3oool3000000030?ooo`00000000000080oooo100000000`3oool0000000000004
0?ooo`040000003oool0oooo00000080oooo0P0000050?ooo`040000003oool0oooo0?ooo`L00000
00<0oooo0000003oool0103oool4000000D0oooo100000080?ooo`@000001@3oool2000000030?oo
o`000000000000T000000P3oool2000000030?ooo`000000000000D000001@3oool01@000000oooo
0?ooo`3oool0000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo00000007000000<0
oooo00<000000?ooo`3oool00P3oool3000000<0oooo00<000000?ooo`3oool0603oool020000000
oooo000000000000oooo0000003oool000000`3oool500000080oooo00<000000?ooo`0000000`00
00000`3oool0000000000004000000l0oooo00<000000?ooo`3oool02@3oool003L0oooo00<0gia8
0018W03Oool02P3oool00`000000oooo0?ooo`0<0?ooo`P0000000@0oooo00000000000000000P3o
ool00`000000oooo00000002000000030?ooo`000000000000H000007@3oool2000000h0oooo0P00
000V0?ooo`80000000<0oooo0000000000000P3oool400000080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000030?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00L0000000<0oooo0000003oool00P0000040?ooo`@000001`3oool00`000000oooo
0?ooo`020?ooo`H00000103oool;000000030?ooo`000000oooo00<0000000<0oooo000000000000
1P3oool010000000oooo0?ooo`0000080?ooo`P000000`3oool2000000030?ooo`000000oooo00H0
00000P3oool2000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0300000080
oooo00<000000?ooo`3oool01@0000020?ooo`030000003oool0000000<0000000<0oooo00000000
00001000000?0?ooo`030000003oool0oooo00T0oooo000W0?ooo`030?oog`2LB000000000L00000
00<0B9cO0?ooo`3oool00`3oool00`3ogi`0B01809cOo`0:0?ooo`030000003oool0oooo00`0oooo
2@0000000`3oool00000000000020?ooo`D0000000<0oooo0000000000001P00000L0?ooo`030000
003oool0oooo0100oooo0`00000T0?ooo`80000000<0oooo0000000000000P3oool7000000@0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`03000000030?ooo`000000oooo00D0
oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H000000?ooo`3oool0oooo0000003oool2
000000@0oooo0P0000040?ooo`030000003oool0oooo00H0oooo1P0000020?ooo`050000003oool0
00000000003oool03P0000050?ooo`050000003oool0oooo0?ooo`000000103oool5000000@0oooo
00<000000?ooo`3oool00P3oool010000000oooo0000000000040?ooo`040000003oool0oooo0?oo
o`<0000000@0oooo0000003oool000007@3oool020000000oooo0?ooo`000000oooo0000003oool0
00000P3oool00`000000oooo00000003000000040?ooo`000000oooo0?ooo`<0000000<0oooo0000
000000001000000?0?ooo`030000003oool0oooo00T0oooo000g0?ooo`030?oo_`1d0000M;oo00X0
oooo0`00000<0?ooo`030000003oool0000000T0000000<0oooo0000003oool0100000000`3oool0
000000000004000000030?ooo`000000oooo01T0oooo0P00000F0?ooo`8000008`3oool200000006
0?ooo`00000000000?ooo`000000oooo0P0000000`3oool000000000000200000080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo100000050?ooo`030000003o
ool0oooo0080oooo0P0000020?ooo`030000003oool0000000<00000203oool4000000P0oooo0P00
00050?ooo`D0000000<0oooo0000000000000P3ooolA00000080oooo1P0000020?ooo`030000003o
ool0oooo00<0oooo0P0000040?oooa<000007@3oool00`000000oooo0?ooo`0300000080oooo00<0
00000?ooo`3oool01@000000103oool000000?ooo`3oool3000000030?ooo`000000000000@00000
3@3oool3000000/0oooo000h0?ooo`030;md0000M;l0oooo00T0oooo00<000000?ooo`3oool0303o
ool2000000030?ooo`000000000000L0000000<0oooo0000003oool0100000000`3oool000000000
0005000001X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0Q0?ooo`80000000<0
oooo000000000000100000020?ooo`80000000D0oooo0000003oool0oooo000000030?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`0000003`0000040?ooo`8000001`3oool4000000H0
oooo0P0000060?ooo`050000003oool0oooo0000003oool02`0000000`3oool00000000000030?oo
oah000000`3oool00`000000oooo0?ooo`020?ooo`8000000`3oool5000001`0oooo00<000000?oo
o`3oool00P0000020?ooo`050000003oool0oooo0000003oool00`0000020?ooo`030000003oool0
00000080000000<0oooo0000000000001000000?0?ooo`030000003oool0oooo00T0oooo000h0?oo
o`030=nLB000B9`0gooo00T0oooo00<000000?ooo`3oool0303oool2000000030?ooo`0000000000
00H000000P3oool5000000030?ooo`000000000000@0000000<0oooo0000003oool05`3oool20000
00D0oooo0`00000D0?ooo`030000003oool0oooo0240oooo0P0000000`3oool000000?ooo`040000
0080oooo0P0000001@3oool000000000003oool000000080oooo00D000000?ooo`3oool0oooo0000
00050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool3000000L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000000P3oool2000000H0oooo00D0
00000?ooo`3oool000000?ooo`0200000080oooo00<000000?ooo`0000003P0000020?ooo`D00000
0`3oool=000000030?ooo`000000000000D00000103oool01@000000oooo0?ooo`3oool0000000@0
oooo1000000J0?ooo`030000003oool000000080000000H0oooo000000000000oooo0000003oool4
000000030?ooo`000000oooo00@0000000<0oooo0000000000001000000>0?ooo`030000003oool0
oooo00T0oooo000h0?ooo`030?oOW01804P0W=oo00T0oooo00<000000?ooo`3oool0303oool;0000
0080oooo1@0000000`3oool0000000000004000000030?ooo`000000oooo01H0oooo00<000000?oo
o`3oool00`3oool2000000<0oooo1@0000060?ooo`@000001P3oool00`000000oooo0?ooo`0Q0?oo
o`80000000<0oooo0000003oool0100000020?ooo`040000003oool0oooo0?ooo`<000000P3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`800000203oool00`000000oooo0?ooo`02000000P0oooo100000050?ooo`040000003o
ool0oooo00000080oooo0P0000020?ooo`8000000P3oool8000000@0oooo00D000000?ooo`3oool0
oooo000000030?ooo`D00000103oool5000000050?ooo`00000000000?ooo`0000000`3oool30000
0080oooo0P0000020?ooo`030000003oool0oooo00@0oooo1000000I0?ooo`030000003oool0oooo
008000000P3oool01@000000oooo0?ooo`000000oooo00<0000000@0oooo0000003oool0oooo0`00
00000`3oool0000000000004000000h0oooo00<000000?ooo`3oool02@3oool003P0oooo00<0oono
07@0001d_ol02@3oool00`000000oooo0?ooo`0;0?ooo`T0000000H0oooo000000000000oooo0000
003oool4000000030?ooo`000000000000@0000000<0oooo0000003oool05@3oool00`000000oooo
0?ooo`020?ooo`8000002P3oool6000000@0oooo0P0000050?ooo`8000008P3oool300000080oooo
00@000000?ooo`00000000000P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool010000000
oooo0?ooo`0000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool30000
00L0oooo0P00000:0?ooo`8000000P3oool9000000030?ooo`00000000000080oooo0P0000000`3o
ool0000000000005000000H0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0
000000@00000103oool4000000<0oooo2P0000080?ooo`@000006@3oool00`000000oooo00000002
0000000;0?ooo`000000oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool30000
00030?ooo`000000000000@000003P3oool00`000000oooo0?ooo`090?ooo`00>@3oool00`2oM000
07Bo0?ooo`080?ooo`030000003oool0oooo00/0oooo2@000000103oool000000000003oool>0000
01L0oooo00<000000?ooo`3oool00P00000:0?ooo`<000000P3oool00`000000oooo0?ooo`060?oo
o`<00000103oool00`000000oooo0?ooo`0P0?ooo`<000000P3oool400000080oooo00<000000?oo
o`3oool00P3oool4000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?oo
o`060000003oool0oooo0?ooo`000000oooo0P0000040?ooo`80000000<0oooo000000000000203o
ool2000000H0oooo00<000000?ooo`3oool0300000001@3oool000000?ooo`000000oooo00@00000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
200000000`3oool000000000000=000000030?ooo`000000000000<000001@3oool4000001P0oooo
00<000000?ooo`0000000P0000000`3oool00000000000020?ooo`80000000@0oooo000000000000
00000P3oool3000000030?ooo`000000000000@000003P3oool00`000000oooo0?ooo`090?ooo`00
=`3oool01@3ookl0M0000000000007@0_ooo00P0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0000000800000080oooo1@0000000`3oool0000000000004000000030?ooo`000000oooo01D0
oooo00@000000?ooo`00000000001@3oool4000000030?ooo`000000000000H0oooo0P0000090?oo
o`8000000`3oool00`000000oooo0?ooo`0P0?ooo`<000000P3oool3000000<0oooo00<000000?oo
o`3oool00P3oool010000000oooo0000000000030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01P3oool010000000oooo0?ooo`0000020?ooo`80000000<0oooo0000000000001@3o
ool00`000000oooo0?ooo`040?ooo`8000001`3oool01@000000oooo0?ooo`000000oooo00800000
0`3oool200000080oooo1P0000040?ooo`<000000`3oool00`000000oooo0?ooo`050?ooo`<00000
0P3oool:000000<0oooo2`0000040?ooo`800000103oool00`000000oooo00000002000001L0oooo
00@000000?ooo`00000000000P3oool01@000000oooo0?ooo`000000oooo00<0000000<0oooo0000
003oool00`0000000`3oool0000000000004000000h0oooo00<000000?ooo`3oool02@3oool004@0
oooo00<000000?ooo`3oool02`3oool00`000000oooo00000008000000030?ooo`000000oooo00@0
000000<0oooo000000000000100000000`3oool000000?ooo`0D0?ooo`030000003oool0000000D0
oooo0P0000030?ooo`D000001`3oool00`000000oooo0?ooo`080?ooo`8000000P3oool00`000000
oooo0?ooo`0O0?ooo`80000000@0oooo0000003oool0oooo0`0000020?ooo`8000000`3oool00`00
0000oooo0?ooo`04000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool01P3oool01000
0000oooo0000003oool5000000L0oooo0P0000030?ooo`8000001`3oool010000000oooo0?ooo`00
00020?ooo`8000000P3oool200000080oooo00<000000?ooo`0000000P0000000`3oool000000?oo
o`040?ooo`030000003oool0000000<000001@3oool300000080oooo100000020?ooo`l000000P3o
ool5000000@0oooo0P0000030?ooo`030000003oool00000008000005P3oool010000000oooo0000
000000020?ooo`80000000P0oooo0000003oool000000?ooo`000000oooo00000080oooo2@00000>
0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00/0oooo0P0000000`3o
ool0000000000006000000030?ooo`000000oooo00D0000000<0oooo0000000000001000000F0?oo
o`800000103oool2000000<0oooo100000030?ooo`<000001@3oool00`000000oooo0?ooo`090?oo
o`80000000<0oooo0000003oool0803oool2000000050?ooo`000000oooo0000003oool00P000002
0?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`@00000103oool00`000000oooo0?oo
o`050?ooo`@000000`3oool3000000P0oooo100000070?ooo`040000003oool0oooo00000080oooo
0P0000020?ooo`080000003oool000000?ooo`000000oooo0000003oool3000000D0oooo00<00000
0?ooo`3oool00P3oool7000000030?ooo`00000000000080000000<0oooo0000000000000`000000
0`3oool0000000000006000000@0oooo100000040?ooo`@000000`3oool2000000040?ooo`000000
oooo0?ooo`<000005P3oool010000000oooo0000000000020?ooo`030000003oool0oooo00800000
00@0oooo0000003oool000000P3oool3000000030?ooo`000000000000@000003@3oool00`000000
oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0;0?ooo`80000000<0oooo000000000000
0P0000001`3oool00000000000000000oooo0000003oool02P0000000`3oool000000?ooo`0D0?oo
o`8000000`3oool2000000<0oooo0`0000030?ooo`@000000P3oool00`000000oooo0?ooo`030?oo
o`8000002`3oool300000240oooo0P0000001@3oool00000000000000000oooo008000000P3oool2
000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0000000;00000080oooo00<0
00000?ooo`3oool0103oool3000000L0oooo100000050?ooo`040000003oool0oooo00000080oooo
0P0000030?ooo`80000000<0oooo0000000000001@0000060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000001P0000030?ooo`<0000000<0oooo000000000000100000030?ooo`<00000
0`3oool010000000oooo0?ooo`0000060?ooo`040000003oool00000000000<0oooo0`0000020?oo
o`<000005@3oool010000000oooo0000000000020?ooo`030000003oool0oooo008000000P3oool2
00000080oooo0`0000000`3oool0000000000004000000d0oooo00<000000?ooo`3oool02@3oool0
04@0oooo00<000000?ooo`3oool02`3oool2000000030?ooo`000000000000<0000000@0oooo0000
00000000oooo300000000`3oool000000?ooo`0C0?ooo`8000000P3oool200000080oooo2P000003
0?ooo`80000000<0oooo0000000000001@3oool00`000000oooo0?ooo`0:0?ooo`8000008@3oool3
000000030?ooo`000000000000<000000P3oool3000000050?ooo`000000oooo0?ooo`000000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo0P0000060?ooo`<000001@3o
ool2000000<0oooo0`0000001@3oool000000?ooo`3oool000000080oooo00<000000?ooo`000000
0P3oool01P000000oooo0000003oool000000?ooo`80000000<0oooo0000000000001@3oool00`00
0000oooo0?ooo`030?ooo`D0000000<0oooo000000000000200000020?ooo`040000003oool00000
000000<0oooo00H000000?ooo`00000000000?ooo`0000020?ooo`040000003oool00000000000D0
oooo00<000000?ooo`3oool00P0000030?ooo`80000000<0oooo0000003oool00P00000E0?ooo`<0
00000P3oool2000000050?ooo`00000000000000003oool00P0000020?ooo`<0000000<0oooo0000
000000001000000=0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00X0
oooo2`0000000`3oool000000?ooo`0<000001D0oooo0P000000103oool000000?ooo`3oool20000
00030?ooo`0000000000008000001@3oool7000000030?ooo`000000oooo00@0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0P0?ooo`<0000000<0oooo0000000000000`0000001`3o
ool000000?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000070?ooo`<000000P3o
ool2000000L0oooo1@0000020?ooo`8000000P3oool010000000oooo0000003oool7000000H0oooo
00<000000?ooo`000000100000050?ooo`P00000103oool3000000<0oooo0P0000030?ooo`800000
00<0oooo0000003oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<00000
0P3oool2000000030?ooo`000000oooo00800000503oool400000080oooo00<000000?ooo`3oool0
0P000000103oool000000?ooo`0000020?ooo`80000000<0oooo0000000000001000000=0?ooo`03
0000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00X0oooo00<000000?ooo`000000
200000000`3oool000000?ooo`05000000030?ooo`000000000000@00000503oool2000000040?oo
o`000000oooo0?ooo`D000001@3oool3000000D0oooo00D000000?ooo`000000oooo000000050?oo
o`8000002`3oool00`000000oooo0?ooo`0P0?ooo`<0000000<0oooo0000000000001@0000020?oo
o`030000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`000000203oool5000000P0oooo00<000000?oo
o`0000001@0000020?ooo`030000003oool0oooo00P000001@3oool6000000030?ooo`000000oooo
0080oooo0`0000020?ooo`D00000103oool010000000oooo0000000000030?ooo`030000003oool0
oooo0080oooo00@000000?ooo`00000000001@3oool00`000000oooo0?ooo`030?ooo`050000003o
ool0oooo0000003oool00P000000103oool000000?ooo`0000020?ooo`030000003oool0oooo01<0
oooo0`0000020?ooo`030000003oool0oooo0080000000@0oooo0000003oool000000P3oool:0000
00`0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo00000008000000030?ooo`000000oooo00D0000000<0oooo0000000000000P0000000`3oool0
00000?ooo`0B0?ooo`8000000P3oool010000000oooo0000000000020?ooo`030000003oool0oooo
00/000000P3oool010000000oooo0000003oool2000000D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0P0?ooo`<0000000<0oooo0000000000000P0000000`3oool0000000000002
0?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000203oool5000000H0oooo00@000000?ooo`000000
00000P3oool6000000050?ooo`00000000000000003oool02P000000103oool00000000000000002
0?ooo`030000003oool0oooo008000000P3oool3000000<0oooo100000020?ooo`<000000`3oool2
000000<0oooo00<000000?ooo`3oool00P0000060?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P0000001P3oool000000?ooo`000000oooo00000080oooo00<000000?ooo`3oool0
4P3oool300000080oooo0P0000020?ooo`030000003oool00000008000000P3oool3000000030?oo
o`000000000000@00000303oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0000000P0000000<0oooo0000003oool02`00000D0?ooo`050000003o
ool0oooo0000003oool00P0000030?ooo`<000000P3oool2000000D0oooo1P0000001@3oool00000
0?ooo`3oool0000000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0P0?ooo`80
00000P3oool4000000030?ooo`000000oooo0080oooo0P0000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000001@3oool2000000030?ooo`000000000000D000000P3oool010000000oooo000000000003
0?ooo`8000000P3oool00`000000oooo00000008000000@0oooo100000040?ooo`<000000P3oool3
000000@0oooo0P0000030?ooo`80000000<0oooo0000000000000`3oool00`000000oooo0?ooo`02
0?ooo`060000003oool0oooo0000003oool000001P3oool00`000000oooo0?ooo`030?ooo`060000
003oool0oooo0?ooo`000000oooo0`000000103oool000000?ooo`00000E0?ooo`8000000`3oool0
0`000000oooo0?ooo`0500000080oooo0`0000000`3oool0000000000004000000`0oooo00<00000
0?ooo`3oool02@3oool004@0oooo0P00000;0?ooo`030000003oool0000000D0000000@0oooo0000
0000000000000P3oool4000000030?ooo`000000000000@000004`3oool01@000000oooo0?ooo`00
0000oooo008000000`3oool010000000oooo0?ooo`3oool7000000@0oooo0P0000020?ooo`@00000
00<0oooo0000003oool0103oool00`000000oooo0?ooo`080?ooo`8000008P3oool3000000030?oo
o`00000000000080000000<0oooo0000000000000P3oool200000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`02000000030?ooo`000000000000<0oooo20000000103oool00000
0?ooo`3oool200000080oooo00<000000?ooo`3oool01@0000001@3oool00000000000000000oooo
00H000000`3oool3000000060?ooo`00000000000000003oool000001@3oool2000000@0oooo0`00
00030?ooo`8000000`3oool010000000oooo0?ooo`0000030?ooo`8000001@3oool00`000000oooo
0?ooo`030?ooo`060000003oool0oooo0?ooo`000000oooo0P0000001@3oool000000?ooo`3oool0
000001@0oooo0`0000020?ooo`80000000@0oooo000000000000oooo0P0000030?ooo`80000000<0
oooo0000000000001000000:0?ooo`<000002`3oool004@0oooo00<000000?ooo`3oool02P3oool2
000000030?ooo`000000000000<0000000@0oooo00000000000000000P3oool4000000030?ooo`00
0000000000@000004`3oool010000000oooo0000003oool2000000<0oooo1`0000020?ooo`H00000
0`3oool200000080oooo0`0000000`3oool000000?ooo`030?ooo`030000003oool0oooo00T0oooo
0P00000Q0?ooo`@0000000<0oooo0000000000000P0000001@3oool00000000000000000oooo0080
000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000001@3oool200000080oooo00<000000?ooo`3oool01@3oool;000000<0oooo00<000000?oo
o`0000000`0000000`3oool0000000000005000000<0oooo1@000000103oool00000000000000003
0?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`030000003oool00000008000000P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0P0000050?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool0oooo10000000103oool000000?ooo`00000D0?ooo`<0
00000`3oool020000000oooo000000000000oooo0000003oool000000P3oool2000000030?ooo`00
0000000000@00000303oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`09
0?ooo`<0000000<0oooo0000000000001`0000000`3oool0000000000003000000030?ooo`000000
00000080000000<0oooo0000003oool04@3oool00`000000oooo0?ooo`0300000080oooo10000000
0`3oool000000000000E000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool02@3oool2
00000240oooo1P000000103oool000000000000000020?ooo`@0000000<0oooo0000003oool00`3o
ool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000@0oooo0`0000000`3oool00000
0?ooo`080?ooo`D000000P3oool@000000D0oooo0`0000030?ooo`<000001@3oool00`000000oooo
0?ooo`030?ooo`800000103oool300000080oooo0`0000030?ooo`040000003oool0oooo000000H0
oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool400000004
0?ooo`000000oooo000001<0oooo0`0000030?ooo`080000003oool0oooo0000003oool000000?oo
o`0000020?ooo`T00000303oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?oo
o`090?ooo`/0000000<0oooo0000003oool01@0000000`3oool0000000000003000001<0oooo00<0
00000?ooo`0000000P0000020?ooo`050000003oool0oooo0000003oool02@0000000`3oool00000
0000000?000000@0oooo00<000000?ooo`3oool0203oool200000280oooo0P0000000`3oool00000
00000005000000<0oooo0`0000000`3oool000000?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`0000000P3oool200000080oooo0P0000090?ooo`8000000P3oool600000080oooo
00<000000?ooo`3oool0100000000`3oool0000000000002000000030?ooo`000000000000800000
00<0oooo0000003oool00`0000000`3oool000000?ooo`040?ooo`030000003oool0oooo00<0oooo
0P0000040?ooo`040000003oool00000000000<0oooo0`0000020?ooo`040000003oool0oooo0000
00L0oooo0P0000040?ooo`030000003oool0oooo00<0oooo00P000000?ooo`3oool0oooo0000003o
ool000000?ooo`80000000<0oooo0000000000004P3oool3000000<0oooo00<000000?ooo`3oool0
1@0000020?ooo`<0000000<0oooo0000000000000`00000<0?ooo`030000003oool0oooo00T0oooo
00140?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000200000000`3oool000000?oo
o`0;00000180oooo1@0000020?ooo`050000003oool0oooo0000003oool00`0000000`3oool00000
00000002000000040?ooo`00000000000?ooo`8000000P3oool4000000030?ooo`000000000000H0
00000`3oool00`000000oooo0?ooo`090?ooo`8000008P3oool2000000030?ooo`000000000000D0
0000103oool4000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000200000080
oooo0P0000020?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`040000003oool0oooo0?oo
oa8000000P3oool5000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`800000103oool3000000@0oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo
00L0oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01000
0000oooo0000003oool2000000030?ooo`000000oooo0180oooo0`0000020?ooo`030000003oool0
oooo00D000000`3oool2000000030?ooo`000000000000@000002`3oool00`000000oooo0?ooo`09
0?ooo`00A03oool00`000000oooo0?ooo`090?ooo`030000003oool0000000P0000000<0oooo0000
003oool02`00000B0?ooo`030000003oool000000080000000<0oooo0000003oool00P3oool80000
0080oooo00@000000?ooo`00000000000`3oool2000000030?ooo`00000000000080000000<0oooo
0000000000001P0000020?ooo`030000003oool0oooo00T0oooo0P00000R0?ooo`80000000<0oooo
0000000000001P0000030?oooa0000000P3oool2000000@0oooo00<000000?ooo`3oool00`3oool3
00000080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`P0000000<0oooo0000000000001@00
00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`00000000000`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000T0oooo0P0000050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool2000000040?ooo`00000000000?ooo`8000004P3oool30000
0080oooo0P000000103oool000000000003oool2000000<0oooo0P0000000`3oool0000000000004
000000/0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo00000004000000050?ooo`00000000000000003oool01P0000000`3oool0000000000003
000001<0oooo100000000`3oool000000?ooo`020?ooo`L000000P3oool2000000030?ooo`000000
oooo0080oooo0P000000103oool000000000003oool?000000/0oooo00<000000?ooo`0000008P3o
ool2000000040?ooo`00000000000?ooo`<0000000H0oooo000000000000oooo0000003oool30000
00<0oooo00<000000?ooo`3oool0103oool3000000L0oooo00<000000?ooo`3oool00P0000001@3o
ool000000?ooo`3oool0000000<0oooo0P0000030?ooo`050000003oool0oooo0000003oool01`00
00070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`800000103oool3000000@0oooo00@000000?ooo`3oool0oooo1000000;0?ooo`800000
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`000000
oooo0P0000000`3oool000000?ooo`0A0?ooo`<000000`3oool020000000oooo000000000000oooo
0000003oool000000P3oool2000000030?ooo`000000000000@000002`3oool00`000000oooo0?oo
o`090?ooo`00A03oool00`000000oooo0?ooo`090?ooo`030000003oool0000000@0000000<0oooo
0000000000000P0000000`3oool0000000000003000000030?ooo`000000oooo00<000004P3oool0
0`000000oooo00000002000000040?ooo`000000oooo0?ooo`@000000P3oool2000000050?ooo`00
0000oooo0?ooo`0000000`3oool01@000000oooo000000000000oooo00@0000000<0oooo00000000
0000100000000`3oool0000000000004000000/0oooo00<000000?ooo`0000008P3oool00`000000
oooo0?ooo`02000000040?ooo`000000oooo00000080oooo1@0000001@3oool000000000003oool0
000000<0oooo1@0000090?ooo`8000000P3oool010000000oooo0?ooo`0000040?ooo`8000000`3o
ool00`000000oooo0?ooo`03000000030?ooo`000000oooo00<000001P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`040000003oool00000000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00000<0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo0P000000103oool000000000003oool200000140oooo0`0000030?ooo`030000003oool00000
00<0000000@0oooo0000003oool0oooo2@00000;0?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo00P0oooo0`0000000`3oool0000000000002000000030?ooo`0000000000
0080000000D0oooo00000000000000000?ooo`0700000180oooo10000000103oool000000?ooo`3o
ool400000080oooo0P0000001@3oool000000?ooo`3oool0000000<0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000/000002`3oool00`000000oooo
0000000S0?ooo`030000003oool0oooo0080000000@0oooo0000003oool00000103oool:000000<0
oooo00<000000?ooo`0000001`3oool3000000050?ooo`000000oooo0?ooo`000000103oool20000
00<0oooo00<000000?ooo`3oool0100000000`3oool000000?ooo`02000000L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo0P0000040?oo
o`<00000103oool010000000oooo0?ooo`3oool2000000030?ooo`000000000000d0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<0000000D0
oooo000000000000oooo0000000A0?ooo`@000000P3oool00`000000oooo0?ooo`03000000040?oo
o`000000oooo0?ooo`T000002`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo
0?ooo`080?ooo`<0000000<0oooo0000000000001`0000001@3oool00000000000000000oooo00L0
00004@3oool5000000050?ooo`000000oooo0000003oool00`0000001@3oool000000000003oool0
00000080oooo00P000000?ooo`3oool0oooo0000003oool000000?ooo`8000001@3oool300000003
0?ooo`000000000000<0000000<0oooo0000000000001000000:0?ooo`030000003oool000000280
oooo0`0000000`3oool000000?ooo`03000000@0oooo00<000000?ooo`000000103oool500000004
0?ooo`000000oooo000000<0oooo100000020?ooo`8000000P3oool00`000000oooo0?ooo`020?oo
o`8000000`3oool00`000000oooo0?ooo`04000000030?ooo`000000oooo00<000001P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`040000003oool00000000000@0oooo00@000000?ooo`3oool0oooo0P00
0000103oool000000?ooo`00000<0?ooo`8000001@3oool01@000000oooo0?ooo`3oool0000000@0
oooo0P000000103oool000000000003oool200000100oooo100000020?ooo`030000003oool0oooo
00D000000P3oool9000000/0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3o
ool0203oool3000000030?ooo`000000000000D0000000@0oooo000000000000oooo2@00000B0?oo
o`060000003oool000000000003oool000000P3oool4000000080?ooo`000000oooo0000003oool0
00000?ooo`0000030?ooo`050000003oool000000?ooo`0000001P3oool3000000030?ooo`000000
000000@0000000D0oooo00000000000000000?ooo`03000000T0oooo00@000000?ooo`3oool00000
8P3oool9000000@0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`3oool7000000D0
oooo00<000000?ooo`3oool00P0000040?ooo`800000103oool00`000000oooo0000000300000080
oooo100000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`800000103oool00`000000oooo000000040?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`80000000D0oooo0000
003oool0oooo0000000A0?ooo`<000000P3oool00`000000oooo0?ooo`05000000<0oooo2000000;
0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00P0oooo0`0000000`3o
ool0000000000005000000030?ooo`000000000000H0000000@0oooo00000000000000004P3oool4
000000050?ooo`000000oooo0000003oool00`0000001`3oool000000000003oool000000?ooo`00
00000`3oool01@000000oooo0000003oool0000000D0oooo0P0000030?ooo`030000003oool00000
00D0000000D0oooo0000003oool000000?ooo`04000000P0oooo00<000000?ooo`0000008`3oool0
0`000000oooo00000004000000030?ooo`000000oooo0080oooo00@000000?ooo`3oool00000103o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`3oool2000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0300000080
oooo00<000000?ooo`0000000P0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`00
00000000103oool010000000oooo0?ooo`3oool2000000030?ooo`000000oooo00<0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103o
ool2000000050?ooo`00000000000?ooo`0000004@3oool300000080oooo0P0000000`3oool00000
00000002000000040?ooo`000000oooo0?ooo`80000000<0oooo0000000000000`00000;0?ooo`03
0000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000
200000000`3oool0000000000006000000040?ooo`000000000000000140oooo1P0000020?ooo`@0
000000D0oooo000000000000oooo000000020?ooo`080000003oool0oooo0000003oool000000?oo
o`0000040?ooo`8000001P3oool00`000000oooo00000008000000030?ooo`000000oooo00<00000
1`3oool010000000oooo0?ooo`00000S0?ooo`050000003oool000000000003oool00`0000040?oo
o`030000003oool0000000D0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`02
000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3o
ool0100000000`3oool000000?ooo`03000000L0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0000000@0
oooo0P0000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool20000
00050?ooo`000000oooo0?ooo`000000403oool400000080oooo00<000000?ooo`0000000`000000
1P3oool000000?ooo`3oool000000?ooo`L000002P3oool00`000000oooo0?ooo`090?ooo`00A03o
ool00`000000oooo0?ooo`080?ooo`030000003oool0000000H0000000<0oooo0000003oool03000
000A0?ooo`@0000000D0oooo0000003oool000000?ooo`04000000030?ooo`00000000000080oooo
00H000000?ooo`3oool000000?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000002@3oool3
000000030?ooo`000000oooo00D0000000<0oooo0000003oool00`0000070?ooo`040000003oool0
oooo000002<0oooo00D000000?ooo`00000000000?ooo`03000000<0oooo00@000000?ooo`3oool0
0000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0000000@0oooo00<000000?oo
o`3oool00P3oool3000000<0oooo00<000000?ooo`3oool0100000020?ooo`030000003oool00000
008000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@00000
0?ooo`3oool0oooo0P0000000`3oool000000?ooo`060?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo0P0000001@3oool00000
0?ooo`3oool000000100oooo100000020?ooo`030000003oool0000000<0000000H0oooo0000003o
ool0oooo0000003oool7000000X0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?oo
o`3oool01`3oool2000000030?ooo`000000000000<0000000D0oooo0000003oool000000?ooo`0<
00000100oooo1P000000103oool000000000003oool2000000050?ooo`00000000000?ooo`000000
0P3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`<0000000@0oooo000000000000oooo1P000000103oool000000000000000060?ooo`040000003o
ool0oooo000002@0oooo00D000000?ooo`00000000000?ooo`03000000<0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo000000040?ooo`8000001@3oool00`000000oooo0?ooo`020?oo
o`800000103oool010000000oooo0000003oool200000080oooo00<000000?ooo`0000000P000007
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`3o
ool2000000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0`0000000`3oool00000
0?ooo`02000000l0oooo100000020?ooo`030000003oool0oooo00D000000P3oool9000000X0oooo
00<000000?ooo`3oool02@3oool004@0oooo0P0000080?ooo`<0000000<0oooo0000000000000P00
00001@3oool000000?ooo`000000oooo00/000004@3oool02@000000oooo000000000000oooo0000
003oool000000?ooo`04000000030?ooo`00000000000080oooo00<000000?ooo`3oool00P000002
0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo00000008000000030?ooo`00
0000000000@000001P3oool010000000oooo0?ooo`00000S0?ooo`80000000@0oooo000000000000
oooo100000020?ooo`030000003oool0000000D0oooo0P0000020?ooo`8000000P3oool01@000000
oooo0?ooo`3oool0000000@0oooo0`0000030?ooo`030000003oool0oooo00<000000`3oool00`00
0000oooo00000002000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`040000003oool0oooo000000@0oooo00@00000
0?ooo`3oool0oooo0P0000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool2000000030?ooo`000000oooo008000003`3oool010000000oooo0000000000020?ooo`030000
003oool0oooo00D000000P3oool9000000P0oooo0`00000;0?ooo`00A03oool00`000000oooo0?oo
o`070?ooo`<0000000<0oooo0000000000000P0000001@3oool000000?ooo`000000oooo00@00000
00<0oooo0000000000001000000A0?ooo`D0000000@0oooo000000000000oooo0`000000103oool0
00000?ooo`0000020?ooo`040000003oool0000000000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0;0?ooo`T0000000<0oooo0000000000000P3oool4000000D0oooo00@00000
0?ooo`3oool00000903oool5000000040?ooo`00000000000?ooo`<000000P3oool00`000000oooo
0?ooo`020?ooo`@00000103oool010000000oooo0000000000040?ooo`070000003oool000000?oo
o`000000oooo000000020?ooo`040000003oool0000000000080oooo00<000000?ooo`0000000P00
00070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo
0?ooo`3oool2000000030?ooo`000000oooo00T0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool2000000050?ooo`0000000000
0?ooo`000000403oool4000000040?ooo`000000oooo0?ooo`@0000000<0oooo0000003oool02@00
000:0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00L0oooo0`000000
0`3oool0000000000002000000030?ooo`00000000000080000000D0oooo00000000000000000?oo
o`0600000140oooo0`0000001@3oool000000?ooo`000000oooo00@0000000<0oooo000000000000
0`3oool010000000oooo0000000000020?ooo`050000003oool0oooo0?ooo`0000003P3oool50000
00040?ooo`00000000000?ooo`80000000D0oooo0000003oool000000?ooo`03000000D0oooo00@0
00000?ooo`3oool00000903oool5000000030?ooo`000000000000<0oooo2@0000070?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`0000000`3oool2000000030?ooo`000000oooo00800000
0`3oool00`000000oooo00000002000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000050?ooo`080000003oool0oooo0000003oool000000?ooo`00000;0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`060000003oool0
oooo0?ooo`000000oooo0`0000000`3oool000000000000?0?ooo`@0000000@0oooo000000000000
oooo100000000`3oool000000?ooo`09000000X0oooo00<000000?ooo`3oool02@3oool004@0oooo
00<000000?ooo`3oool01`3oool3000000030?ooo`00000000000080000000<0oooo000000000000
0P0000000`3oool0000000000002000000030?ooo`000000000000<00000403oool00`000000oooo
00000002000000040?ooo`00000000000?ooo`<0000000@0oooo0000003oool000000P3oool01000
0000oooo0000000000020?ooo`050000003oool0oooo0?ooo`0000003@3oool2000000050?ooo`00
0000oooo0000003oool01@0000000`3oool00000000000020?ooo`040000003oool000000?ooo`80
00000`3oool010000000oooo0?ooo`00000U0?ooo`L000000`3oool010000000oooo0?ooo`000004
0?ooo`800000103oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`000000103oool3
00000080oooo00H000000?ooo`3oool0oooo0000003oool3000000L0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000040?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003o
ool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`80000000<0oooo0000003oool00P00000?0?ooo`@0
000000H0oooo000000000000oooo0000003oool2000000030?ooo`000000oooo00T000002P3oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`070?ooo`<0000000<0oooo0000
003oool01@0000000`3oool000000?ooo`0:00000100oooo1@0000000`3oool000000?ooo`040000
00030?ooo`000000000000<0oooo00H000000?ooo`00000000000?ooo`0000030?ooo`030000003o
ool0oooo00/0oooo00H000000?ooo`3oool0oooo0000003oool3000000040?ooo`00000000000?oo
o`<000000P3oool01@000000oooo0?ooo`000000oooo00<000000P3oool010000000oooo0?ooo`00
000U0?ooo`<000000P3oool2000000<0oooo00@000000?ooo`3oool000000`3oool200000080oooo
0P0000030?ooo`060000003oool0oooo0000003oool00000103oool01P000000oooo0?ooo`000000
oooo000000<0oooo00<000000?ooo`3oool00`0000060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`8000000`3oool010000000oooo0?oo
o`0000040?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool0303oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01P000000
oooo0?ooo`3oool000000?ooo`<0000000<0oooo0000003oool03P3oool400000080oooo00<00000
0?ooo`0000000`0000000`3oool000000?ooo`03000000030?ooo`000000000000<000002P3oool0
0`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`070?ooo`030000003oool00000
0080000000<0oooo0000000000000`0000000`3oool000000000000:00000100oooo0P0000000`3o
ool0000000000002000000080?ooo`00000000000000003oool000000?ooo`0000020?ooo`040000
003oool0000000000080oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000001P0000000`3oool00000000000020?ooo`0:0000003oool00000
0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`3oool0903oool300000080
oooo1P0000000`3oool000000?ooo`020?ooo`@000001P3oool2000000030?ooo`000000oooo00@0
oooo00@000000?ooo`000000oooo0P0000030?ooo`030000003oool00000008000001`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`040000003oool00000000000@0oooo00@000000?ooo`3oool0oooo0P00
00000`3oool000000?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0?ooo`000000oooo0`0000000`3oool0
00000?ooo`0>0?ooo`030000003oool000000080000000@0oooo0000003oool0oooo0`000000103o
ool000000?ooo`3oool2000000030?ooo`000000000000<000002P3oool00`000000oooo0?ooo`09
0?ooo`00A03oool00`000000oooo0?ooo`070?ooo`030000003oool0000000P0000000<0oooo0000
000000002@00000A0?ooo`<0000000<0oooo0000000000000P3oool3000000040?ooo`000000oooo
00000080oooo00H000000?ooo`00000000000?ooo`0000030?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0103oool00`000000oooo00000002000000040?ooo`00000000000?ooo`<0
00000P3oool00`000000oooo0?ooo`0300000080oooo0P0000030?ooo`030000003oool0oooo02@0
oooo0`0000020?ooo`8000000P3oool700000080oooo00<000000?ooo`3oool0103oool3000000D0
oooo00<000000?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool00`0000060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`000000103oool200000080oooo0P0000000`3oool0
00000?ooo`0>0?ooo`030000003oool0oooo00L0oooo0P0000040?ooo`050000003oool0oooo0?oo
o`000000103oool2000000030?ooo`000000oooo008000003P3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool300000080oooo00D000000?ooo`00000000000?ooo`06000000T0oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000
0008000000030?ooo`000000000000T00000403oool5000000030?ooo`000000oooo00@0000000<0
oooo0000000000000P3oool010000000oooo0000000000020?ooo`050000003oool0oooo0?ooo`00
00002`3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000H0000000<0oooo00000000
00000P3oool01P000000oooo000000000000oooo000000<0oooo00@000000?ooo`3oool000009P3o
ool400000080oooo0P0000020?ooo`060000003oool0oooo0000003oool000000P3oool00`000000
oooo0?ooo`030?ooo`040000003oool00000000000@0oooo00<000000?ooo`0000000P3oool30000
0080oooo00<000000?ooo`0000000P0000070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`800000103oool00`000000oooo000000040?oo
o`040000003oool0oooo0?ooo`80000000<0oooo0000003oool03`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`3o
ool000000?ooo`<0000000<0oooo0000003oool03P3oool2000000040?ooo`000000oooo00000080
oooo0P0000001@3oool000000?ooo`000000oooo00T000002@3oool00`000000oooo0?ooo`090?oo
o`00A03oool00`000000oooo0?ooo`070?ooo`030000003oool0000000@0000000D0oooo0000003o
ool000000?ooo`09000000030?ooo`000000oooo00l0oooo1`000000203oool000000?ooo`000000
oooo0000003oool000000P3oool010000000oooo0000000000020?ooo`040000003oool0oooo0000
00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo00000002000000040?ooo`0000000000
0?ooo`<000000P3oool00`000000oooo0?ooo`03000000<0oooo0P0000000`3oool000000?ooo`0V
0?ooo`@0000000H0oooo00000000000000000?ooo`0000020?ooo`030000003oool0000000<0oooo
00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo00000002
0?ooo`8000000P3oool200000080oooo0`0000060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`8000000`3oool010000000oooo0?ooo`00
00040?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool03`3oool00`000000oooo
0?ooo`070?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0?ooo`00
0000oooo0`0000000`3oool000000?ooo`0>0?ooo`80000000<0oooo0000003oool00P000000203o
ool000000000003oool000000?ooo`000000oooo2@0000090?ooo`030000003oool0oooo00T0oooo
00140?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000100000001@3oool000000?oo
o`000000oooo00T0000000<0oooo0000003oool03`3oool2000000030?ooo`000000000000800000
00P0oooo00000000000000000?ooo`000000oooo00000080oooo00H000000?ooo`00000000000?oo
o`0000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool9000000030?oo
o`00000000000080oooo00@000000?ooo`000000oooo0P0000020?ooo`040000003oool000000000
02P0oooo100000001P3oool00000000000000000oooo00000080oooo0P0000030?ooo`060000003o
ool000000000003oool000000`3oool00`000000oooo000000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`0000000P0000070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000001@3oool01`000000oooo0?ooo`3oool000000?ooo`0000004@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`060000
003oool000000000003oool000003`3oool2000000030?ooo`000000oooo0080000000<0oooo0000
000000000P0000000`3oool000000?ooo`09000000T0oooo00<000000?ooo`3oool02@3oool004@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo00000004000000050?ooo`00000000000000
003oool02`00000@0?ooo`<0000000<0oooo0000000000000P3oool4000000060?ooo`000000oooo
0?ooo`000000oooo0P0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo00000005000000040?ooo`000000000000000080oooo00<000000?ooo`3o
ool00P000000103oool000000?ooo`3oool2000000030?ooo`000000oooo02L0oooo00<000000?oo
o`0000000P000000103oool000000000000000030?ooo`040000003oool0oooo0?ooo`8000000P3o
ool00`000000oooo0?ooo`030?ooo`80000000@0oooo0000003oool0oooo0P0000030?ooo`030000
003oool0000000<000001P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool2000000@0oooo00<000000?ooo`000000103oool200000080oooo
0P0000000`3oool000000?ooo`0A0?ooo`030000003oool0oooo00L0oooo0P0000030?ooo`030000
003oool0oooo0080oooo00H000000?ooo`3oool0oooo0000003oool2000000030?ooo`0000000000
00h0oooo1@0000000`3oool000000?ooo`04000000030?ooo`000000oooo00T000002@3oool00`00
0000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`070?ooo`030000003oool0000000@0
000000D0oooo00000000000000000?ooo`05000000030?ooo`000000000000<000003`3oool50000
000:0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00H000000?ooo`00
000000000?ooo`0000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo00000007000000030?ooo`00000000000080oooo00@000000?ooo`000000oooo0P00
00020?ooo`040000003oool00000000002T0oooo0`0000000`3oool000000?ooo`0300000080oooo
00@000000?ooo`00000000000P3oool2000000H0oooo00<000000?ooo`0000000P3oool2000000<0
oooo00<000000?ooo`3oool0100000060?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`800000103oool00`000000oooo000000040?ooo`040000003oool0oooo
0?ooo`80000000<0oooo0000003oool04@3oool00`000000oooo0?ooo`080?ooo`050000003oool0
oooo0?ooo`000000103oool01P000000oooo0?ooo`3oool000000?ooo`<0000000<0oooo0000003o
ool03@3oool00`000000oooo00000002000000030?ooo`000000oooo00@0000000<0oooo0000003o
ool02@0000090?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`000000100000000`3oool0000000000002000000030?ooo`000000000000P00000
3`3oool7000000030?ooo`00000000000080000000D0oooo0000003oool0oooo000000020?ooo`80
000000D0oooo0000003oool0oooo0000000:0?ooo`030000003oool0oooo00`0oooo2@0000000`3o
ool00000000000020?ooo`030000003oool0oooo0080000000L0oooo0000003oool0oooo0000003o
ool0000002X0oooo300000030?ooo`8000001P3oool300000080oooo0`0000030?ooo`030000003o
ool0000000<000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool2000000<0oooo00@000000?ooo`0000000000103oool01`000000oooo
0?ooo`3oool000000?ooo`0000004`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool02P000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`00000>0?ooo`030000003oool000000080000000@0oooo0000003oool0oooo0`0000000`3o
ool000000?ooo`09000000T0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3o
ool01P3oool2000000030?ooo`000000000000<0000000<0oooo0000000000000P0000000`3oool0
00000000000700000100oooo0P0000000`3oool0000000000002000000030?ooo`00000000000080
000000/0oooo0000003oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0303oool:000000030?ooo`000000oooo0080oooo
00@000000?ooo`000000oooo0P0000020?ooo`040000003oool00000000002T0oooo0`0000000`3o
ool0000000000003000000040?ooo`00000000000?ooo`8000000P3oool00`000000oooo0?ooo`02
0?ooo`80000000<0oooo0000003oool00`0000030?ooo`030000003oool0oooo00@000001P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00L000000?ooo`3oool0oooo0000
003oool0000001@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`000000103oool000000?ooo`00000?0?ooo`@0
000000@0oooo0000003oool0oooo1@0000000`3oool0000000000007000000T0oooo00<000000?oo
o`3oool02@3oool004@0oooo00<000000?ooo`3oool01P3oool2000000030?ooo`000000000000<0
000000<0oooo0000000000000P0000000`3oool0000000000003000000040?ooo`000000oooo0000
0100oooo0`000000103oool000000000003oool5000000060?ooo`000000oooo0?ooo`000000oooo
0P0000001@3oool000000?ooo`3oool0000000X0oooo00<000000?ooo`3oool03@3oool00`000000
oooo00000003000000060?ooo`00000000000000003oool000000`3oool00`000000oooo00000002
000000040?ooo`000000oooo00000080oooo00<000000?ooo`3oool0:03oool3000000030?ooo`00
0000oooo00H00000103oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`000000
103oool00`000000oooo00000003000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`030000
003oool0000000D0oooo00L000000?ooo`3oool0oooo0000003oool0000001@0oooo00<000000?oo
o`3oool01`3oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020000
00040?ooo`00000000000?ooo`8000003P3oool2000000030?ooo`000000oooo0080000000<0oooo
0000000000000`0000000`3oool0000000000006000000030?ooo`000000oooo00L0oooo00<00000
0?ooo`3oool02@3oool004@0oooo0P0000070?ooo`80000000<0oooo0000000000000`0000001P3o
ool000000000003oool000000?ooo`D0000000@0oooo0000003oool00000403oool40000000:0?oo
o`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00H000000?ooo`0000000000
0?ooo`0000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool500000004
0?ooo`000000000000000080oooo00P000000?ooo`3oool0oooo0000003oool000000?ooo`800000
0P3oool00`000000oooo0000000[0?ooo`80000000<0oooo0000003oool00P3oool2000000040?oo
o`0000000000000000<0oooo0`0000040?ooo`@000000`3oool00`000000oooo0?ooo`0400000080
oooo00D000000?ooo`3oool0oooo0000000:0?ooo`050000003oool0oooo0?ooo`0000001P3oool2
000000@0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`3oool2000000030?ooo`00
0000oooo01@0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00H000000?ooo`3oool0oooo0000003oool5000000h0oooo0P0000000`3oool000000?ooo`020000
00030?ooo`00000000000080000000<0oooo0000003oool01`0000000`3oool000000?ooo`050?oo
o`<000002`3oool001<0oooo00<0oono07Ad_`3oool0;P3oool00`000000oooo0?ooo`060?ooo`80
000000<0oooo0000000000000`0000001P3oool000000000003oool000000?ooo`D0000000@0oooo
00000000000000003`3oool5000000030?ooo`000000oooo00@0000000/0oooo0000003oool0oooo
0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool03`3oool2000000030?ooo`00000000000080000000D0oooo0000003oool0oooo0000
00030?ooo`030000003oool000000080000000@0oooo0000003oool000000P3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool00000008000000`3oool01@000000oooo0?ooo`000000oooo00D0
0000103oool010000000oooo0000000000040?ooo`030000003oool000000080000000D0oooo0000
003oool0oooo000000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`8000000`3oool010000000oooo0000000000040?ooo`070000003o
ool0oooo0?ooo`000000oooo0000000F0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0000003oool00`0000000`3o
ool000000?ooo`0=0?ooo`80000000H0oooo0000003oool0oooo0000003oool4000000030?ooo`00
0000oooo0080000000<0oooo0000000000000P0000000`3oool000000?ooo`070?ooo`030000003o
ool0oooo00T0oooo000C0?ooo`040?oOW0180000001809cOobd0oooo00<000000?ooo`3oool01P3o
ool2000000030?ooo`000000000000<0000000H0oooo000000000000oooo0000003oool9000000l0
oooo0P0000000`3oool0000000000002000000030?ooo`00000000000080000000H0oooo0000003o
ool0oooo0000003oool200000080oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0000000<0000000H0oooo00000000000000000?ooo`0000030?ooo`05
0000003oool000000000003oool00P0000001@3oool000000?ooo`3oool0000002/0oooo00<00000
0?ooo`0000000P0000020?ooo`@000000`3oool300000080oooo0P0000020?ooo`8000000`3oool0
0`000000oooo0?ooo`04000000@0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0000
000000040?ooo`070000003oool0oooo0?ooo`000000oooo0000000G0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`0:0000003oool0oooo
0000003oool000000?ooo`000000oooo000000h0oooo0P0000001P3oool000000000003oool00000
0?ooo`@0000000<0oooo0000003oool00P0000000`3oool0000000000002000000030?ooo`000000
oooo00L0oooo00<000000?ooo`3oool02@3oool001D0oooo00<0_g@00000000000000`0000000`00
07@0_ooo0?ooo`0V0?ooo`030000003oool0oooo00H0oooo0P0000000`3oool00000000000030000
00060?ooo`00000000000?ooo`000000oooo2@00000?0?ooo`<0000000<0oooo0000000000000P3o
ool4000000060?ooo`000000oooo0?ooo`000000oooo0P0000001@3oool000000?ooo`3oool00000
00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo00000003000000050?ooo`0000000000
0000003oool00P0000020?ooo`050000003oool000000000003oool00P0000000`3oool000000?oo
o`020?ooo`030000003oool0oooo02P0oooo00<000000?ooo`0000000`000000103oool000000000
003oool4000000<0oooo0P0000030?ooo`80000000@0oooo0000003oool000000P3oool300000003
0?ooo`000000oooo00@0oooo0P00000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool2000000@0oooo00@000000?ooo`0000000000103oool01`000000oooo0?ooo`3oool0
00000?ooo`0000005`3oool00`000000oooo0?ooo`060?ooo`8000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0000000<0oooo0000003oool00P00000=0?ooo`D0000000<0
oooo0000003oool0100000000`3oool000000?ooo`02000000030?ooo`00000000000080000000<0
oooo0000003oool01`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`3ogi`0B00007Boo`0X
0?ooo`030000003oool0oooo00H0oooo20000000103oool000000000003oool;000000l0oooo1000
00000`3oool000000?ooo`03000000040?ooo`000000oooo00000080oooo0P000000103oool00000
0?ooo`0000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool500000004
0?ooo`000000oooo00000080oooo00d000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`3oool0:@3oool010000000oooo0000003oool7
000000030?ooo`000000000000<000000`3oool200000080oooo00<000000?ooo`0000000P3oool4
000000L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo0P0000040?ooo`030000003oool0000000@0oooo0P0000020?ooo`<00000603oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00020?ooo`<0000000<0oooo0000003oool00P00000=0?ooo`D0000000<0oooo0000003oool01000
00000`3oool000000?ooo`02000000030?ooo`00000000000080000000<0oooo0000003oool01`3o
ool00`000000oooo0?ooo`090?ooo`00603oool00`3OW4P0001d0;ooo`0Y0?ooo`030000003oool0
oooo00H0oooo20000000103oool000000000003oool3000000030?ooo`000000000000D000003P3o
ool00`000000oooo00000002000000030?ooo`000000oooo00@000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool04@3oool6000000030?ooo`00000000000080oooo0P0000020?ooo`050000003oool00000
0000003oool00P000000103oool000000?ooo`3oool2000002/0oooo00@000000?ooo`000000oooo
0P0000001@3oool000000?ooo`3oool0000000D0oooo00D000000?ooo`000000oooo000000030?oo
o`030000003oool0oooo0080000000<0oooo0000000000001`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool2000000@0oooo00<000000?oo
o`000000103oool010000000oooo0?ooo`3oool3000001P0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`00000000000?oo
o`02000000030?ooo`000000000000d0oooo1@0000000`3oool0000000000004000000030?ooo`00
0000oooo0080000000<0oooo0000000000000P0000000`3oool000000?ooo`070?ooo`030000003o
ool0oooo00T0oooo000C0?ooo`060?oOW01804P0W=oo0?noM0000000B9cO:`3oool00`000000oooo
0?ooo`060?ooo`P0000000@0oooo000000000000oooo2`00000>0?ooo`L0000000<0oooo00000000
00000P0000020?ooo`040000003oool000000?ooo`8000000P3oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`0000000`0000001@3oool000000?ooo`00
0000oooo008000000P3oool01`000000oooo000000000000oooo0000003oool00P0000030?ooo`03
0000003oool0oooo00D0oooo2`00000I0?ooo`030000003oool0oooo00<0000000D0oooo0000003o
ool0oooo000000050?ooo`80000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`030000
00030?ooo`000000oooo00D0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`040000003oool0oooo0?ooo`<000006@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo000000000000oooo00800000
0P3oool00`000000oooo0?ooo`0;0?ooo`D0000000<0oooo000000000000100000000`3oool00000
0?ooo`02000000030?ooo`00000000000080000000<0oooo0000003oool01`3oool00`000000oooo
0?ooo`090?ooo`004`3oool0103ogi`0B00000000000M;l]0?ooo`030000003oool0oooo00H0oooo
300000000`3oool0000000000008000000h0oooo1`0000000`3oool0000000000002000000040?oo
o`000000oooo0?ooo`80000000L0oooo0000003oool0oooo0000003oool0000000T0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo00000003000000050?ooo`000000oooo0000003oool00P00
00020?ooo`070000003oool0oooo0000003oool000000?ooo`02000000<0oooo00<000000?ooo`3o
ool00P3oool3000000/0oooo0P00000H0?ooo`030000003oool00000008000000P3oool010000000
oooo0?ooo`0000040?ooo`80000000<0oooo0000003oool00P3oool01@000000oooo000000000000
oooo00<000001`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool2000000@0oooo00@000000?ooo`0000000000103oool01`000000oooo
0?ooo`3oool000000?ooo`0000006@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool01@000000oooo000000000000oooo008000000P3oool0
0`000000oooo0?ooo`0;0?ooo`D0000000<0oooo000000000000100000000`3oool000000?ooo`02
000000030?ooo`00000000000080000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`09
0?ooo`00A03oool00`000000oooo0?ooo`060?ooo``0000000<0oooo0000000000001`00000?0?oo
o`@0000000@0oooo0000003oool0oooo10000000103oool000000?ooo`3oool2000000040?ooo`00
0000oooo00000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`D00000
00D0oooo0000003oool000000?ooo`02000000<0oooo00H000000?ooo`000000oooo0000003oool2
000000<0oooo0P0000000`3oool000000000000@0?ooo`8000005`3oool010000000oooo00000000
00020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`0000000000103oool00`000000
oooo00000002000000030?ooo`000000000000L0oooo00@000000?ooo`3oool000001`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`040000003oool00000
000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000001T0oooo00<000000?ooo`3oool0
1P3oool2000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool000000080
000000<0oooo0000003oool0303oool4000000030?ooo`000000000000D0000000<0oooo0000003o
ool02@0000080?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00H0oooo
1`0000000`3oool0000000000002000000030?ooo`000000000000L000003`3oool4000000040?oo
o`000000oooo0?ooo`@0000000X0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01<0oooo1@0000001@3oool00000
0?ooo`000000oooo008000000`3oool01`000000oooo000000000000oooo0000003oool00P000002
0?ooo`<00000503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo008000000P3oool0
10000000oooo0?ooo`0000020?ooo`@000000`3oool00`000000oooo0?ooo`04000000030?ooo`00
0000oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`0000001P3oool2000000@0oooo00@000000?ooo`00000000000`3oool010000000
oooo0?ooo`3oool2000000030?ooo`000000oooo01P0oooo00<000000?ooo`3oool01P3oool20000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`D0000000<0oooo0000003oool0303oool4
000000030?ooo`000000000000D0000000<0oooo0000003oool02@0000080?ooo`030000003oool0
oooo00T0oooo000F0?ooo`060=nLB000000000000000000004P0W=oo:03oool00`000000oooo0?oo
o`060?ooo`L0000000<0oooo0000000000000P0000000`3oool0000000000007000000l0oooo0P00
00001@3oool000000?ooo`000000oooo0080000000d0oooo0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0D0?ooo`040000003oool000000?ooo`<0000000@0oooo000000000000oooo0P0000020?oo
o`070000003oool000000000003oool000000?ooo`0200000080oooo1`00000A0?ooo`8000005@3o
ool00`000000oooo0000000200000080oooo00<000000?ooo`0000000`0000000`3oool000000000
00030?ooo`030000003oool0oooo0080000000@0oooo0000003oool000001P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000060?ooo`80
00000`3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0?ooo`<000006`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00020?ooo`D0000000<0oooo000000000000303oool4000000030?ooo`000000000000D0000000@0
oooo0000003oool0oooo200000080?ooo`030000003oool0oooo00T0oooo000D0?ooo`090?oo_`1d
0000B9cO0?oOW02L_ol0oooo0=nLB000B9`0gooo02L0oooo00<000000?ooo`3oool01P3oool70000
00060?ooo`00000000000?ooo`000000oooo2@00000?0?ooo`@0000000<0oooo0000003oool01000
00020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000002@3oool0
0`000000oooo0?ooo`0D0?ooo`040000003oool000000?ooo`80000000D0oooo0000000000000000
0?ooo`0200000080oooo00L000000?ooo`3oool000000?ooo`000000oooo0080000000<0oooo0000
000000000P0000040?ooo`8000004@3oool00`000000oooo0?ooo`0B0?ooo`040000003oool00000
0?ooo`P000000P3oool200000080oooo00D000000?ooo`3oool000000?ooo`04000000L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00@000000?ooo`3oool0oooo0`00000K0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool000000080oooo0P0000000`3oool00000000000020?oo
o`030000003oool0oooo00X0oooo0P0000000`3oool0000000000007000000040?ooo`000000oooo
0?ooo`P00000203oool00`000000oooo0?ooo`090?ooo`00503oool02@2oM7@0_ooo0?ooo`3o_i`0
W=oo0?ooo`3ookl0M01d0;ooo`0W0?ooo`030000003oool0oooo00H0oooo1`0000001P3oool00000
0000003oool000000?ooo`T000003`3oool4000000030?ooo`000000oooo00@000000P3oool01000
0000oooo0000003oool200000080oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`0F
0?ooo`80000000P0oooo000000000000oooo0000003oool000000?ooo`8000000`3oool01P000000
oooo0000003oool000000?ooo`@0000000@0oooo0000003oool000001@3oool2000000l0oooo00<0
00000?ooo`3oool04`3oool200000080oooo00<000000?ooo`3oool00`0000020?ooo`060000003o
ool0oooo0000003oool000000P3oool00`000000oooo00000003000000L0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`3oool0oooo0`00000K0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool000000080oooo0P0000000`3oool00000000000020?ooo`030000003o
ool0oooo00X0oooo0P0000000`3oool0000000000007000000040?ooo`000000oooo0?ooo`P00000
203oool00`000000oooo0?ooo`090?ooo`004`3oool02@3ogi`0W;oo0?ooo`3ooml0W7BL0=ooo`3o
ool0omnL04Qd_`0X0?ooo`030000003oool0oooo00H0oooo1`000000203oool000000000003oool0
00000?ooo`000000oooo1`00000?0?ooo`<0000000@0oooo000000000000oooo10000000103oool0
00000?ooo`0000020?ooo`80000000D0oooo0000003oool0oooo000000080?ooo`030000003oool0
oooo01H0oooo0P000000203oool000000000003oool000000?ooo`000000oooo0P0000030?ooo`08
0000003oool000000000003oool000000?ooo`0000030?ooo`030000003oool0000000L0oooo0P00
000>0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0100000020?ooo`8000000`3o
ool2000000<0oooo0P000000103oool000000000000000060?ooo`030000003oool0oooo00D0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`04
0000003oool0oooo000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000001/0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`00000000000?ooo`0200000080oooo00<000000?ooo`3oool02P3oool2000000030?oo
o`000000000000L000000P3oool00`000000oooo00000007000000P0oooo00<000000?ooo`3oool0
2@3oool001<0oooo00T0oknL09cOo`3oool0_g@007Boo`3oool0gia80000M02oool0:03oool00`00
0000oooo0?ooo`060?ooo`L0000000P0oooo000000000000oooo0000003oool000000?ooo`L00000
3`3oool3000000040?ooo`00000000000?ooo`@0000000@0oooo0000003oool000000P3oool20000
00050?ooo`000000oooo0?ooo`000000203oool00`000000oooo0?ooo`0F0?ooo`D0000000D0oooo
0000003oool000000?ooo`02000000<0oooo00D000000?ooo`00000000000?ooo`0400000080oooo
00<000000?ooo`0000002@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool00000000000<0oooo00P000000?oo
o`3oool0oooo0000003oool000000?ooo`<000001P3oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000
oooo0?ooo`02000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000001`0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`00000000000?ooo`0200000080oooo00<000000?ooo`3oool02P3oool2000000030?ooo`00
0000000000L000000P3oool00`000000oooo00000007000000P0oooo00<000000?ooo`3oool02@3o
ool001<0oooo00@0oono07@000000000M;oo;@3oool00`000000oooo0?ooo`060?ooo`L0000000P0
oooo000000000000oooo0000003oool000000?ooo`L000003`3oool3000000040?ooo`0000000000
0?ooo`<000000P3oool00`000000oooo000000020?ooo`80000000D0oooo0000003oool0oooo0000
00080?ooo`030000003oool0oooo01H0oooo0`0000001@3oool000000?ooo`000000oooo00@00000
0`3oool00`000000oooo0000000600000080oooo00<000000?ooo`0000002P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0140oooo0P0000030?ooo`040000003oool000000?ooo`80
00000`3oool200000080oooo00@000000?ooo`000000oooo0P0000070?ooo`030000003oool0oooo
00H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`8000000`3oool0
0`000000oooo0?ooo`02000000<0oooo0P0000020?ooo`80000000<0oooo0000003oool06`3oool0
0`000000oooo0?ooo`050?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
00000?ooo`<000000P3oool00`000000oooo0?ooo`0:0?ooo`80000000<0oooo0000000000001`00
00020?ooo`030000003oool0000000L00000203oool00`000000oooo0?ooo`090?ooo`00A03oool2
000000L0oooo1`000000203oool000000000003oool000000?ooo`000000oooo1`00000?0?ooo`<0
000000@0oooo0000003oool0oooo0`0000020?ooo`030000003oool000000080oooo0P0000001@3o
ool000000?ooo`3oool0000000P0oooo00<000000?ooo`3oool05P3oool010000000oooo0000003o
ool3000000060?ooo`00000000000000003oool000000`3oool3000000030?ooo`000000oooo0080
00000`3oool00`000000oooo000000090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo000000020?ooo`060000003oool0oooo0000003oool000000P3oool0
2P000000oooo0000003oool000000?ooo`000000oooo0000003oool2000000H0oooo00<000000?oo
o`3oool01P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo0P000003
0?ooo`040000003oool0oooo000000@0oooo0P0000020?ooo`80000000<0oooo0000003oool06`3o
ool00`000000oooo0?ooo`050?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00@000000P3oool00`000000oooo0?ooo`0:0?ooo`80000000<0oooo0000000000001`00
00020?ooo`030000003oool0000000L000001P3oool3000000/0oooo00140?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`00000010000000203oool000000000003oool000000?ooo`000000
oooo1`00000?0?ooo`<0000000L0oooo0000003oool0oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01L0oooo00@000000?ooo`000000oooo0`0000001P3oool00000000000000000
oooo000000<0oooo00<000000?ooo`0000000P0000020?ooo`070000003oool0oooo0?ooo`000000
oooo0000000:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0403oool010000000
oooo0?ooo`0000020?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool20000
00050?ooo`000000oooo0000003oool00P0000050?ooo`030000003oool0oooo00L0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool010000000oooo0?ooo`3oool2000000030?ooo`000000oooo01/0
oooo00<000000?ooo`3oool01@3oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0400000080oooo00<000000?ooo`3oool02P3oool2000000030?ooo`000000000000L0
00000P3oool00`000000oooo00000007000000P0oooo00<000000?ooo`3oool02@3oool001L0oooo
00H0okmd00000000000000000000M02ooolW0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`00000010000000203oool000000000003oool000000?ooo`000000oooo1`00000?0?ooo`<00000
00L0oooo0000003oool0oooo0000003oool000000080oooo00@000000?ooo`000000oooo0P000002
0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool05`3oool010000000oooo0000
003oool7000000030?ooo`000000oooo0080oooo10000000103oool000000?ooo`0000030?ooo`03
0000003oool0000000X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`04
0000003oool0oooo0?ooo`@0000000<0oooo0000003oool00P0000030?ooo`<000000P3oool20000
00030?ooo`000000oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo000000030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`040000003oool0oooo0?ooo`<000007@3oool00`000000oooo0?ooo`050?ooo`8000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@000000P3oool00`000000oooo0?oo
o`0:0?ooo`80000000<0oooo0000000000001`0000020?ooo`030000003oool0000000L00000203o
ool00`000000oooo0?ooo`090?ooo`003`3oool01P2oW9`0gooo0?ooo`3oool0omnL04P000<00000
00@004RL0=ooo`3ookl0M7Bo:03oool00`000000oooo0?ooo`060?ooo`030000003oool0000000@0
000000P0oooo000000000000oooo0000003oool000000?ooo`L000003`3oool3000000070?ooo`00
0000oooo0?ooo`000000oooo000000020?ooo`040000003oool000000?ooo`8000000P3oool01000
0000oooo0?ooo`0000070?ooo`030000003oool0oooo01L0oooo00@000000?ooo`000000oooo0P00
0000103oool000000000003oool3000000<0oooo10000000103oool000000?ooo`0000030?ooo`03
0000003oool0000000X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00D0oooo1@0000030?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool2000000@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@0
00000?ooo`3oool0oooo0`00000M0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool000000080oooo100000020?ooo`030000003oool0oooo00X0
oooo0P0000000`3oool000000000000700000080oooo00<000000?ooo`0000001`0000080?ooo`03
0000003oool0oooo00T0oooo000>0?ooo`030?oog`2LB000000000<0000000<007Bo0?ooo`3oool0
0P3oool00`3o_g@0001d0;ooo`0X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000
100000001P3oool000000000003oool000000?ooo`T000003P3oool2000000050?ooo`000000oooo
0000003oool00P000000203oool000000?ooo`3oool000000?ooo`000000oooo0P0000020?ooo`04
0000003oool0oooo000000L0oooo00<000000?ooo`3oool05`3oool010000000oooo0000003oool2
000000030?ooo`000000oooo00@000000`3oool020000000oooo000000000000oooo0000003oool0
00000`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000<0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0oooo0`00000M0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
0080oooo100000020?ooo`030000003oool0oooo00X0oooo0P0000000`3oool00000000000070000
0080oooo00<000000?ooo`0000001`0000080?ooo`030000003oool0oooo00T0oooo000>0?ooo`03
0?oo_`1d0000B9cO03<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000700000003
0?ooo`000000oooo00T000003P3oool2000000050?ooo`000000oooo0000003oool00P000000203o
ool000000?ooo`3oool000000?ooo`000000oooo0P0000020?ooo`030000003oool0000000P0oooo
00<000000?ooo`3oool0603oool2000000060?ooo`00000000000?ooo`000000oooo100000030?oo
o`080000003oool000000000003oool000000?ooo`0000030?ooo`040000003oool0oooo000000X0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool000000080oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool01@000000oooo0?ooo`000000oooo008000007@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`@000000P3oool00`000000
oooo0?ooo`0:0?ooo`80000000<0oooo0000000000001`0000020?ooo`030000003oool0000000L0
0000203oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`060?ooo`030000
003oool0000000L0000000<0oooo0000000000002@00000>0?ooo`@0000000<0oooo0000003oool0
0P000000203oool000000?ooo`3oool000000?ooo`000000oooo0P0000001@3oool000000?ooo`3o
ool0000000P0oooo00<000000?ooo`3oool0603oool5000000030?ooo`000000oooo00@000000P3o
ool01@000000oooo000000000000oooo0080000000<0oooo0000003oool00P3oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo00d0oooo0`00000>0?ooo`030000003oool0oooo00P0
oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000040?ooo`040000
003oool0oooo000000`0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`000000oooo008000007@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000020?ooo`@000000P3oool2000000`0oooo0`0000000`3oool000000000000500000080oooo
00<000000?ooo`0000001`0000080?ooo`030000003oool0oooo00T0oooo000F0?ooo`060?oOW018
000000000000000004P0W=oo:03oool00`000000oooo0?ooo`060?ooo`030000003oool0000000L0
000000<0oooo0000000000002@00000>0?ooo`H0000000D0oooo000000000000oooo000000020?oo
o`040000003oool000000?ooo`80000000D0oooo0000003oool0oooo000000080?ooo`030000003o
ool0oooo01P0oooo1@0000000`3oool000000?ooo`0400000080oooo00D000000?ooo`0000000000
0?ooo`02000000030?ooo`000000oooo0080oooo00@000000?ooo`3oool000002P3oool00`000000
oooo0?ooo`0=0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool0203oool01000
0000oooo0000000000020?ooo`050000003oool000000?ooo`000000103oool010000000oooo0?oo
o`00000<0?ooo`050000003oool0oooo0?ooo`0000001P3oool2000000<0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`050000003oool0oooo0000003oool00P00000M0?ooo`030000003oool0
oooo00H0oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool400000080oooo0P00
000<0?ooo`<0000000<0oooo0000000000000P0000000`3oool00000000000020?ooo`030000003o
ool0000000L00000203oool00`000000oooo0?ooo`090?ooo`005@3oool00`2oM000000007Boo`02
0?ooo`030?oog`2LM9`0gooo02L0oooo00<000000?ooo`3oool01P3oool00`000000oooo00000007
000000030?ooo`000000000000T000003P3oool6000000050?ooo`00000000000?ooo`0000000P3o
ool200000080oooo0P0000001@3oool000000?ooo`3oool0000000P0oooo00<000000?ooo`3oool0
603oool5000000030?ooo`000000oooo00@000000P3oool01@000000oooo000000000000oooo0080
000000<0oooo0000000000000P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo
00/0oooo0P0000020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool30000
0080oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0000000`0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P00
00040?ooo`030000003oool0oooo0080000000<0oooo0000003oool07@3oool00`000000oooo0?oo
o`050?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000080oooo0P000000103oool00000
0000003oool2000000`0oooo0P0000000`3oool0000000000002000000040?ooo`00000000000000
0080oooo00<000000?ooo`0000001`0000080?ooo`030000003oool0oooo00T0oooo000D0?ooo`03
0=nLB018W=l0oooo00@0oooo00<0gibL0;ooo`3oool09P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0000000L0000000<0oooo0000000000002@00000>0?ooo`H0000000T0oooo00000000
0000oooo0000003oool000000?ooo`0000000P3oool2000000050?ooo`000000oooo0?ooo`000000
203oool00`000000oooo0?ooo`0H0?ooo`/0000000<0oooo0000000000000P3oool2000000040?oo
o`00000000000?ooo`8000000P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo
00/0oooo0P0000030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool30000
00030?ooo`000000oooo0080000000<0oooo0000003oool0103oool2000000d0oooo0P0000020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020000
00@0oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`0M0?ooo`030000003oool0oooo
00D0oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000040?ooo`000000
00000?ooo`800000303oool2000000060?ooo`00000000000?ooo`000000oooo100000000`3oool0
00000?ooo`08000000P0oooo00<000000?ooo`3oool02@3oool001<0oooo00<0omnL07BLg`3oool0
103oool00`3ooml0W7BL0=ooo`0I0?ooo`040;md00000000000007Boo`X0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo00000007000000030?ooo`000000000000T000003P3oool600000003
0?ooo`00000000000080000000@0oooo0000003oool000000P3oool2000000050?ooo`000000oooo
0?ooo`000000203oool00`000000oooo0?ooo`0H0?ooo`/0000000<0oooo0000000000000P3oool0
0`000000oooo00000002000000030?ooo`00000000000080oooo00@000000?ooo`3oool000002`3o
ool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`040000003oool000000?ooo`80000000<0oooo0000003o
ool0103oool2000000d0oooo0P0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`02000000@0oooo00<000000?ooo`3oool00P0000000`3oool0
00000?ooo`0M0?ooo`030000003oool0oooo00D0oooo0P0000030?ooo`050000003oool0oooo0?oo
o`0000000P3oool2000000030?ooo`00000000000080oooo00<000000?ooo`3oool02P3oool20000
00060?ooo`00000000000?ooo`000000oooo100000000`3oool000000?ooo`08000000P0oooo00<0
00000?ooo`3oool02@3oool001<0oooo00<0oknL09cOo`3oool00`3oool00`3ooml0W4P007Boo`0I
0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO2@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0000000L0000000<0oooo0000000000002@00000>0?ooo`H0000000<0oooo000000000000
0P000000103oool000000?ooo`0000020?ooo`80000000D0oooo0000003oool0oooo000000080?oo
o`030000003oool0oooo01P0oooo1P0000000`3oool0000000000002000000030?ooo`0000000000
0080oooo00<000000?ooo`0000000P0000000`3oool00000000000020?ooo`040000003oool0oooo
000000/0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02`3oool010000000oooo0000003oool2000000030?oo
o`000000oooo00@0oooo0P00000=0?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0200000003
0?ooo`000000oooo01d0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool000000?ooo`0300000080oooo00<000000?ooo`3oool02P3oool2
000000060?ooo`00000000000?ooo`000000oooo100000000`3oool000000?ooo`08000000P0oooo
00<000000?ooo`3oool02@3oool001<0oooo00<0omnL04Qd_`3oool00P3oool00`3OW4P0000004RL
g`0I0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0203oool00`000000oooo0?oo
o`060?ooo`030000003oool0000000L0000000<0oooo0000000000002@00000>0?ooo`H0000000<0
oooo0000000000000P000000103oool000000?ooo`0000020?ooo`80000000D0oooo0000003oool0
oooo000000080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`0000000`0000000`3oool0
000000000002000000030?ooo`00000000000080oooo00<000000?ooo`0000000P0000000`3oool0
0000000000020?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3oool02@3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`03000000H0oooo0P00000=0?ooo`8000000P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`02000000030?ooo`000000oooo01d0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool000000?ooo`0300000080oooo00<000000?ooo`3o
ool02P3oool2000000060?ooo`00000000000?ooo`000000oooo100000000`3oool000000?ooo`08
000000P0oooo00<000000?ooo`3oool02@3oool001@0oooo00H0okmd00000000000000000018W03O
oolJ0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo1`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0000000L0000000<0oooo0000000000002@00000>0?ooo`H00000
00<0oooo0000000000000P000000103oool000000?ooo`0000020?ooo`80000000D0oooo0000003o
ool0oooo000000080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`0000000`0000000`3o
ool0000000000002000000040?ooo`00000000000?ooo`80000000D0oooo00000000000000000?oo
o`0200000080oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`090?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`<0
00001P3oool2000000d0oooo0P0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080000000<0oooo0000
003oool07@3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`000000oooo00<000000P3oool00`000000oooo0?ooo`0:0?ooo`80000000H0
oooo000000000000oooo0000003oool4000000030?ooo`000000oooo00P00000203oool00`000000
oooo0?ooo`090?ooo`00=03oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo00000007000000030?ooo`000000000000T00000
3P3oool6000000030?ooo`00000000000080000000@0oooo0000003oool000000P3oool200000005
0?ooo`000000oooo0?ooo`000000203oool00`000000oooo0?ooo`0H0?ooo`030000003oool00000
00<0000000<0oooo0000000000000P000000103oool000000000003oool2000000040?ooo`000000
000000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00l0oooo0`0000060?ooo`8000003@3oool200000080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool00P0000000`3oool000000?ooo`0M0?ooo`030000003oool0oooo00H0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0000003oool00`0000020?ooo`030000003o
ool0oooo00X0oooo0P0000001P3oool000000000003oool000000?ooo`@0000000<0oooo0000003o
ool0200000080?ooo`030000003oool0oooo00T0oooo000e0?ooo`030;md0000B9`0gooo0080oooo
00<0omnL04P00018W=l01`3ooooo0000068000002`3oool001H0oooo00H0omnL04P0000000000000
0000B02LgolI0?ooo`030=nLB00004P0W=oo0080oooo00<0oooO09a80000M;l01`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0000000L0000000<0oooo0000000000002@00000>0?ooo`H0
000000<0oooo0000000000000P000000103oool000000?ooo`0000020?ooo`80000000D0oooo0000
003oool0oooo000000080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`0000000`000000
0`3oool0000000000002000000040?ooo`00000000000?ooo`80000000@0oooo0000000000000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool4000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`<0
00001P3oool2000000d0oooo0P0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080000000<0oooo0000
003oool07@3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`000000oooo00<000000P3oool00`000000oooo0?ooo`0:0?ooo`80000000H0
oooo000000000000oooo0000003oool4000000030?ooo`000000oooo0080000000<0oooo00000000
00000`0000080?ooo`030000003oool0oooo00T0oooo000D0?ooo`040?oog`2LB00004RL0=ooo`80
oooo00<0okmd0018W03Oool0603oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo00000007000000030?ooo`000000000000T0
00003P3oool6000000030?ooo`00000000000080000000@0oooo0000003oool000000P3oool20000
00050?ooo`000000oooo0?ooo`000000203oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
000000<0000000<0oooo0000000000000P000000103oool000000000003oool2000000040?ooo`00
0000000000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo100000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo000000060?ooo`8000003@3oool200000080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool00P0000000`3oool000000?ooo`0M0?ooo`030000003oool0oooo00H0oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0000003oool00`0000020?ooo`030000003o
ool0oooo00X0oooo0P0000001P3oool000000000003oool000000?ooo`@0000000<0oooo0000003o
ool00P0000000`3oool0000000000003000000P0oooo00<000000?ooo`3oool02@3oool001@0oooo
00<0_gA809cOo`3oool00`3oool00`3ooml0W4Qd0;ooo`0H0?ooo`040?oog`2LB00004RL0=ooo`80
oooo00<0gia80018W03Oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000L0
000000<0oooo0000000000002@00000>0?ooo`H0000000<0oooo0000000000000P000000103oool0
00000?ooo`0000020?ooo`80000000D0oooo0000003oool0oooo000000080?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`0000000`0000000`3oool0000000000002000000040?ooo`000000
00000?ooo`80000000@0oooo00000000000000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool4000000<0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo0P00000=0?ooo`80
00000P3oool00`000000oooo0?ooo`040?ooo`8000000`3oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo0080000000<0oooo0000003oool07@3oool00`000000oooo0?ooo`050?oo
o`8000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000P000002
0?ooo`030000003oool0oooo00X0oooo0P0000001P3oool000000000003oool000000?ooo`@00000
00<0oooo0000003oool00P0000000`3oool0000000000003000000P0oooo00<000000?ooo`3oool0
2@3oool001<0oooo00<0omnL09boo`3oool0103oool00`3ogi`0B7Bo0?ooo`0I0?ooo`030?oOW018
0000M;oo0080oooo00<0gia8001d_`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0000000L0000000<0oooo0000000000002@00000>0?ooo`H0000000<0oooo0000000000000P00
0000103oool000000?ooo`0000020?ooo`80000000D0oooo0000003oool0oooo000000080?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`000000200000001`3oool000000?ooo`000000oooo
0000003oool00`0000000`3oool00000000000020?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool02P3oool4000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000303oool200000080oooo00<0
00000?ooo`3oool0103oool2000000<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`02000000030?ooo`000000oooo01d0oooo00<000000?ooo`3oool01@3oool2000000<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool00000008000000P3oool00`000000
oooo0?ooo`0:0?ooo`80000000H0oooo000000000000oooo0000003oool4000000030?ooo`000000
oooo0080000000<0oooo0000000000000`0000080?ooo`030000003oool0oooo00T0oooo000C0?oo
o`030?noW02Lgol0oooo00<0oooo00<0omnL04Q8W03Oool06`3oool01P3OW4P0001d0;ooo`3ooml0
W4P004RLg`L0oooo00<000000?ooo`3oool01P3oool2000000030?ooo`000000000000D0000000<0
oooo0000000000002@00000>0?ooo`H0000000<0oooo0000000000000P000000103oool000000?oo
o`0000020?ooo`80000000D0oooo0000003oool0oooo000000080?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`000000100000002`3oool00000000000000000oooo0000003oool000000?oo
o`000000oooo00<0000000<0oooo0000000000000P3oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool0oooo00X0oooo0`0000040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000`0oooo0P0000020?oo
o`030000003oool0oooo00@0oooo0P0000030?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool00P0000000`3oool000000?ooo`0M0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000P00
00020?ooo`030000003oool0oooo00X0oooo0P0000001P3oool000000000003oool000000?ooo`@0
000000<0oooo0000003oool00P0000000`3oool0000000000003000000P0oooo00<000000?ooo`3o
ool02@3oool001<0oooo00@0oono07@000000000M;oo8@3oool0103OW4P0000000000000M;l80?oo
o`030000003oool0oooo00H0oooo0P0000000`3oool0000000000005000000030?ooo`0000000000
00T000003P3oool4000000030?ooo`000000oooo00@0000000@0oooo0000003oool000000P3oool2
000000050?ooo`000000oooo0?ooo`000000203oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0000000@0000000/0oooo00000000000000000?ooo`000000oooo0000003oool000000?ooo`03
000000030?ooo`00000000000080oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000303oool200000080oooo
00<000000?ooo`3oool0103oool2000000<0oooo00@000000?ooo`3oool000001@3oool00`000000
oooo0?ooo`02000000030?ooo`000000oooo01d0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000020000
0080oooo00<000000?ooo`3oool02P3oool2000000060?ooo`00000000000?ooo`000000oooo1000
00000`3oool0000000000002000000030?ooo`000000000000<00000203oool00`000000oooo0?oo
o`090?ooo`00A03oool00`000000oooo0?ooo`060?ooo`80000000<0oooo0000000000001@000000
0`3oool0000000000009000000h0oooo100000000`3oool000000?ooo`04000000040?ooo`000000
oooo00000080oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0603oool00`000000oooo00000004000000030?ooo`0000000000008000000P3o
ool01@000000oooo000000000000oooo0080000000<0oooo0000000000000P3oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`00000000000`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000001P3oool2000000@0oooo00<0
00000?ooo`0000001@3oool00`000000oooo0?ooo`02000000030?ooo`000000oooo01`0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0000000200000080oooo00<000000?ooo`3oool02P3oool2000000060?oo
o`00000000000?ooo`000000oooo100000000`3oool0000000000002000000030?ooo`0000000000
00<00000203oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`060?ooo`80
000000<0oooo0000000000001@0000020?ooo`X000003P3oool4000000030?ooo`000000oooo00@0
00000P3oool200000080oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0603oool00`000000oooo00000004000000030?ooo`00000000000080
00000`3oool4000000040?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0?ooo`0:0?ooo`040000003oool00000000000<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0D0?ooo`<000000`3oool00`000000oooo0?ooo`0:0?ooo`050000003o
ool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`040000003oool00000000000@0
oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`0L0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo0P000000103o
ool000000000003oool2000000`0oooo0P0000001P3oool000000000003oool000000?ooo`@00000
00<0oooo000000000000200000080?ooo`030000003oool0oooo00T0oooo000C0?ooo`030?oo_`2L
W=l0oooo00<0oooo00@0okmd0000000007@0_ooo9`3oool00`000000oooo0?ooo`060?ooo`800000
00<0oooo0000000000001@0000020?ooo`X000003P3oool6000000030?ooo`000000000000800000
0P3oool200000080oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0603oool00`000000oooo00000004000000030?ooo`000000000000800000
0`3oool4000000040?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`0:0?ooo`D000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`80000000<0oooo0000003oool00P00
000M0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool000000080oooo0P000000103oool000000000003oool2000000`0oooo0P0000001P3oool0
00000000003oool000000?ooo`@0000000<0oooo000000000000200000080?ooo`030000003oool0
oooo00T0oooo000C0?ooo`040?oo_`2LW=l0oono07@000@0000000<004RL0=ooo`3oool09P3oool0
0`000000oooo0?ooo`060?ooo`80000000<0oooo0000000000001@0000020?ooo`X000003P3oool6
000000050?ooo`00000000000?ooo`0000000P3oool010000000oooo0000003oool2000000030?oo
o`000000oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0H0?ooo`L00000
00<0oooo0000000000000P0000030?ooo`030000003oool00000008000000P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`P0
0000303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000103oool2000000030?ooo`000000oooo008000007@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00X000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo0P0000000`3oool000000?ooo`0<0?ooo`80000000H0oooo000000000000oooo0000003oool4
000000030?ooo`000000000000P00000203oool00`000000oooo0?ooo`090?ooo`004`3oool02@3o
gi`0B0000000000004P0W=oo0?ooo`3ooml0W4Qd0;ooo`0X0?ooo`030000003oool0oooo00H0oooo
0P0000000`3oool000000000000500000080oooo2P00000>0?ooo`H0000000<0oooo000000000000
0P0000020?ooo`040000003oool000000?ooo`80000000<0oooo0000003oool00P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo01P0oooo1@0000001@3oool000000?ooo`000000oooo
008000000`3oool00`000000oooo0000000200000080oooo00L000000?ooo`3oool0oooo0000003o
ool0000000/0oooo00<000000?ooo`3oool02P3oool01@000000oooo000000000000oooo00800000
3@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`03000001d0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`0:0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`80
000000<0oooo0000003oool0303oool2000000030?ooo`00000000000080000000<0oooo00000000
00000P0000000`3oool0000000000008000000P0oooo00<000000?ooo`3oool02@3oool000l0oooo
00@0oooO09a8000007@0_ooo<@3oool00`000000oooo0?ooo`060?ooo`80000000<0oooo00000000
00000P0000000`3oool00000000000020?ooo`X000003P3oool6000000030?ooo`000000000000<0
000000L0oooo0000003oool000000?ooo`000000oooo008000000`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo01L0oooo0P000000203oool000000000003oool000000?ooo`000000
oooo0P0000030?ooo`030000003oool00000008000000P3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000002`3oool00`000000oooo0?ooo`0:0?ooo`80000000<0oooo0000003oool00`00000<
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`0K0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool02P000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool2000000030?ooo`000000oooo00`0oooo0P0000000`3oool000000?oo
o`02000000030?ooo`00000000000080000000<0oooo000000000000200000080?ooo`030000003o
ool0oooo00T0oooo00140?ooo`030000003oool0oooo00H0oooo0P0000000`3oool0000000000002
000000030?ooo`00000000000080oooo2P00000>0?ooo``0000000L0oooo0000003oool000000?oo
o`000000oooo008000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01L0oooo
0P000000203oool000000000003oool000000?ooo`000000oooo0P0000030?ooo`030000003oool0
0000008000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000002`3oool00`000000oooo
0?ooo`090?ooo`<0000000P0oooo0000003oool0oooo0000003oool000000?ooo`800000203oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00<00000103oool01@000000oooo0?ooo`3o
ool0000000H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo0080000000<0oooo0000003oool06`3oool00`000000oooo0?ooo`050?ooo`800000
103oool010000000oooo0?ooo`0000020?ooo`040000003oool000000?ooo`80000000<0oooo0000
003oool0303oool4000000040?ooo`00000000000?ooo`@0000000<0oooo00000000000020000008
0?ooo`030000003oool0oooo00T0oooo000C0?ooo`050?oO_`2ogol0oooo0?ooo`2oM0000`000000
0`0007@0_ooo0?ooo`0V0?ooo`030000003oool0oooo00H0oooo0P0000000`3oool0000000000002
000000030?ooo`00000000000080oooo2P00000>0?ooo``0000000L0oooo0000003oool000000?oo
o`000000oooo008000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01L0oooo
0P000000103oool000000000003oool3000000030?ooo`000000000000<0oooo1@0000000`3oool0
0000000000030?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool02@3oool200000007
0?ooo`000000oooo0000003oool000000?ooo`0200000080oooo0P0000060?ooo`030000003oool0
oooo01l0oooo0`0000060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00P0000000`3oool00000
0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0P0000040?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`000000oooo0P0000000`3oool000000?ooo`0<0?ooo`@0000000@0oooo0000
00000000oooo100000000`3oool0000000000008000000P0oooo00<000000?ooo`3oool02@3oool0
01<0oooo00<0_g@00000000000000P0000001@0007@0_ooo0?ooo`2oW9`0gooo02L0oooo0P000007
0?ooo`80000000<0oooo0000000000000P0000000`3oool00000000000020?ooo`X000003P3oool<
000000040?ooo`000000oooo00000080oooo0`0000030?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool05`3oool2000000050?ooo`00000000000000003oool00`0000000`3oool00000
0?ooo`020?ooo`D0000000<0oooo0000000000000`3oool00`000000oooo0000000;0?ooo`030000
003oool0oooo00T0oooo00L000000?ooo`3oool000000?ooo`000000oooo00@00000103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`8000000`3oool00`000000oooo0?ooo`02000000@0oooo00<000000?ooo`3oool00P000000
0`3oool000000?ooo`0J0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool000000?ooo`80000000<0oooo0000003oool0
303oool4000000040?ooo`00000000000?ooo`@0000000<0oooo000000000000200000060?ooo`<0
00002`3oool00140oooo00D0_g@000000000000004RL0=ooo`030?ooo`030?oog`2LB000M;oo0080
oooo00<0_g@00018W03Oool08`3oool00`000000oooo0?ooo`060?ooo`80000000<0oooo00000000
00000P0000000`3oool00000000000020?ooo`X000003P3oool<000000040?ooo`000000oooo0000
0080oooo0`0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo00000004000000030?ooo`000000000000800000103oool00`000000oooo000000020000
00030?ooo`000000oooo0080oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0:0?oo
o`050000003oool0oooo0000003oool00P000000103oool000000?ooo`0000050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0:03oool01@000000oooo0?ooo`3oool0000000H0oooo
0P0000030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0200000003
0?ooo`000000oooo01X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo00000080oooo0P0000001P3oool00000000000000000oooo000000d0oooo1000
0000103oool000000000003oool4000000030?ooo`000000000000L000002@3oool00`000000oooo
0?ooo`090?ooo`004`3oool00`3o_i`0W=oo0?ooo`080?ooo`030?oOW018M;l0oooo02<0oooo00<0
00000?ooo`3oool01P3oool2000000030?ooo`000000000000D000000P3oool:000000h0oooo3000
0000103oool000000?ooo`0000020?ooo`80000000D0oooo0000003oool0oooo000000080?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`000000100000000`3oool0000000000002000000@0
oooo100000000`3oool00000000000030?ooo`030000003oool0000000/0oooo00<000000?ooo`3o
ool02@3oool200000080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0
oooo00@000000`3oool00`000000oooo0?ooo`0X0?ooo`050000003oool0oooo0?ooo`0000001P3o
ool2000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`02000000030?oo
o`000000oooo01X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo00000080oooo0P0000001P3oool00000000000000000oooo000000`0oooo00<00000
0?ooo`0000000P000000103oool000000000003oool4000000030?ooo`000000000000L000002@3o
ool00`000000oooo0?ooo`090?ooo`004`3oool00`3ookl0M7Bo0?ooo`070?ooo`030?noM000B9`0
gooo02@0oooo00<000000?ooo`3oool01P3oool2000000030?ooo`000000000000H0000000<0oooo
0000000000002000000>0?ooo`D0000000<0oooo000000000000100000020?ooo`8000000P3oool2
000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E
0?ooo`L0000000<0oooo0000000000000P0000040?ooo`@0000000<0oooo0000000000000`3oool0
0`000000oooo0000000;0?ooo`030000003oool0oooo00T0oooo0P0000000`3oool000000?ooo`02
0?ooo`80000000H0oooo0000003oool000000?ooo`0000030?ooo`<0000000<0oooo000000000000
:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`070000003oool0oooo0?ooo`000000oooo0000000K
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool000000080oooo0P000000103oool000000000003oool2000000`0oooo00<000000?ooo`000000
0P000000103oool000000?ooo`3oool4000000030?ooo`000000000000L000002@3oool00`000000
oooo0?ooo`090?ooo`004`3oool0103ogi`0B0000000M02oool50?ooo`030=nLB000M;l0oooo02D0
oooo00<000000?ooo`3oool01P3oool2000000030?ooo`000000000000H0000000@0oooo00000000
0000oooo1`00000?0?ooo`@0000000<0oooo0000003oool0100000020?ooo`8000000P3oool20000
00030?ooo`000000oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?oo
o`D0000000D0oooo00000000000000000?ooo`02000000@0oooo100000020?ooo`070000003oool0
oooo0?ooo`000000oooo0000000;0?ooo`030000003oool0oooo00P0oooo0P0000020?ooo`040000
003oool0oooo0?ooo`80000000H0oooo0000003oool0oooo0000003oool3000000030?ooo`000000
oooo00<00000:P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000040?ooo`8000000P3oool00`000000oooo0000000J0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080
oooo0P000000103oool000000000003oool2000000`0oooo0P0000001@3oool000000000003oool0
00000080oooo100000000`3oool0000000000007000000T0oooo00<000000?ooo`3oool02@3oool0
01@0oooo00<0omnL04P0000000001@0000000`18W=l0oooo0?ooo`0U0?ooo`030000003oool0oooo
00H0oooo0P0000000`3oool0000000000006000000040?ooo`00000000000?ooo`80000000<0oooo
0000000000000P00000?0?ooo`@0000000<0oooo0000003oool00P000000103oool000000?ooo`3o
ool200000080oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool05@3oool5000000050?ooo`00000000000000003oool00P0000040?ooo`D00000
00D0oooo0000003oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0203oool200000080oooo00@000000?ooo`3oool0oooo0P0000000`3oool00000000000030000
00<0oooo0`0000000`3oool000000000000Z0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0P0000020?ooo`80000000<0
oooo0000003oool0603oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`80000000@0oooo000000000000oooo0P00000<0?ooo`80
000000D0oooo000000000000oooo000000020?ooo`@0000000<0oooo0000000000001`0000090?oo
o`030000003oool0oooo00T0oooo000I0?ooo`030?noM00004P0W=oo02P0oooo00<000000?ooo`3o
ool01P3oool2000000030?ooo`000000000000H0000000<0oooo0000000000000`0000000`3oool0
000000000002000000l0oooo100000000`3oool000000?ooo`0400000080oooo00H000000?ooo`00
0000oooo0000003oool2000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E
0?ooo`D0000000H0oooo00000000000000000?ooo`0000040?ooo`030000003oool0000000800000
00P0oooo00000000000000000?ooo`000000oooo000000/0oooo00<000000?ooo`3oool0203oool2
00000080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo0P0000000`3oool00000
0?ooo`040?ooo`@00000:P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool00P0000000`3oool000000?ooo`0H0?ooo`030000003oool0oooo00H0oooo0P0000040?ooo`05
0000003oool0oooo0?ooo`0000000P3oool2000000040?ooo`00000000000?ooo`800000303oool2
000000060?ooo`00000000000?ooo`000000oooo1@0000000`3oool0000000000007000000T0oooo
00<000000?ooo`3oool02@3oool001P0oooo00<0_g@0001d_`3oool0:@3oool00`000000oooo0?oo
o`060?ooo`80000000<0oooo0000000000001P0000000`3oool0000000000003000000030?ooo`00
00000000008000003`3oool4000000030?ooo`000000oooo00@000000P3oool01P000000oooo0000
003oool000000?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0
oooo1@0000001P3oool00000000000000000oooo000000@0oooo00@000000?ooo`00000000000P3o
ool3000000040?ooo`000000oooo000000/0oooo00<000000?ooo`3oool0203oool200000080oooo
00<000000?ooo`3oool00P0000020?ooo`@000000P3oool00`000000oooo0?ooo`030?ooo`<00000
:P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080000000<0oooo0000003o
ool0603oool00`000000oooo0?ooo`060?ooo`800000103oool01@000000oooo0?ooo`3oool00000
0080oooo1@0000000`3oool000000?ooo`0<0?ooo`80000000H0oooo000000000000oooo0000003o
ool5000000030?ooo`000000000000L000002@3oool00`000000oooo0?ooo`090?ooo`004`3oool0
1P3ogi`0B00007Boo`3o_g@0000007Boob/0oooo00<000000?ooo`3oool01`3oool00`000000oooo
00000007000000030?ooo`000000000000<0000000<0oooo0000000000000`00000>0?ooo`<00000
00<0oooo0000000000001P000000103oool000000?ooo`0000020?ooo`80000000D0oooo0000003o
ool0oooo000000090?ooo`030000003oool0oooo01<0oooo300000040?ooo`@000000P3oool20000
00050?ooo`00000000000?ooo`0000002P3oool00`000000oooo0?ooo`080?ooo`8000000`3oool0
10000000oooo0?ooo`0000030?ooo`80000000D0oooo0000003oool0oooo000000060?ooo`<00000
:P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo0080000000<0oooo0000003oool05`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000002
0?ooo`80000000H0oooo00000000000000000?ooo`00000=0?ooo`80000000H0oooo000000000000
oooo0000003oool400000080oooo2@0000090?ooo`030000003oool0oooo00T0oooo000C0?ooo`04
0?oOW01800000000001d_bd0oooo00<000000?ooo`3oool01`3oool00`000000oooo000000070000
00030?ooo`000000000000<0000000<0oooo0000000000000`00000>0?ooo`D0000000<0oooo0000
003oool010000000103oool000000?ooo`0000020?ooo`80000000D0oooo0000003oool0oooo0000
00090?ooo`030000003oool0oooo01<0oooo1`0000000`3oool0000000000002000000@0oooo1000
00020?ooo`8000000P3oool00`000000oooo0000000:0?ooo`030000003oool0oooo00P0oooo0P00
00030?ooo`040000003oool00000000000<0oooo0P0000000`3oool000000?ooo`020?ooo`X00000
:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`8000000P3oool00`000000oooo0000000H0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
0080oooo0P0000000`3oool00000000000020?ooo`030000003oool0oooo00/0oooo0P0000001P3o
ool000000000003oool000000?ooo`@0000000<0oooo0000003oool0200000090?ooo`030000003o
ool0oooo00T0oooo00140?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000001`000000
0`3oool0000000000003000000030?ooo`000000000000<000003`3oool4000000030?ooo`000000
oooo00@000000P3oool010000000oooo0000003oool2000000030?ooo`000000oooo0080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0C0?ooo`T0000000<0oooo000000000000103o
ool400000080oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`090?ooo`030000003o
ool0oooo00L0oooo0P0000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo
000000020?ooo`030000003oool0000000800000103oool3000000030?ooo`000000oooo02L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`800000103oool010000000oooo
0000000000040?ooo`060000003oool0oooo0000003oool00000603oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`80000000<0
oooo0000000000000P3oool00`000000oooo0?ooo`0;0?ooo`80000000H0oooo000000000000oooo
0000003oool4000000030?ooo`000000oooo00P000002@3oool00`000000oooo0?ooo`090?ooo`00
A03oool00`000000oooo0?ooo`070?ooo`80000000<0oooo0000000000001@0000000`3oool00000
00000003000000030?ooo`000000000000<000003`3oool4000000030?ooo`000000oooo00@00000
0P3oool010000000oooo0000003oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0C0?ooo`D0000000D0oooo00000000000000000?ooo`020000
00<0oooo00<000000?ooo`0000000P0000000`3oool00000000000020?ooo`040000003oool00000
000000T0oooo00<000000?ooo`3oool0203oool2000000<0oooo00@000000?ooo`00000000000P3o
ool200000080oooo00@000000?ooo`00000000000P3oool00`000000oooo0?ooo`020?ooo`050000
003oool000000?ooo`000000:03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0080000000<0oooo0000003oool05P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`80000000@0oooo000000000000oooo0P00
000=0?ooo`D0000000<0oooo0000003oool0100000000`3oool000000?ooo`02000000030?ooo`00
0000000000<000002@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`07
0?ooo`80000000<0oooo0000000000001@0000000`3oool0000000000003000000030?ooo`000000
000000<000003`3oool4000000030?ooo`000000oooo00@000000P3oool010000000oooo0000003o
ool2000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool000000080000000H0oooo00000000000000000?ooo`0000040?ooo`06
0000003oool000000?ooo`000000oooo0P0000020?ooo`040000003oool00000000000T0oooo00<0
00000?ooo`3oool01`3oool3000000<0oooo0P0000001@3oool000000?ooo`3oool0000000<0oooo
0P0000000`3oool000000?ooo`020?ooo`060000003oool0oooo0?ooo`000000oooo0P0000000`3o
ool000000?ooo`0W0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P000000
0`3oool000000?ooo`0E0?ooo`030000003oool0oooo00L0oooo0P0000040?ooo`050000003oool0
oooo0?ooo`0000000P3oool3000000030?ooo`000000oooo00800000303oool00`000000oooo0000
0005000000030?ooo`00000000000080000000<0oooo0000003oool00P0000000`3oool000000000
0003000000T0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool01`3oool2
000000030?ooo`000000000000D0000000<0oooo0000000000002@00000?0?ooo`@0000000@0oooo
0000003oool0oooo0`0000020?ooo`030000003oool000000080oooo0P0000001@3oool000000?oo
o`3oool0000000T0oooo00<000000?ooo`3oool04@3oool6000000060?ooo`00000000000000003o
ool00000103oool010000000oooo0000000000020?ooo`8000000P3oool4000000T0oooo00<00000
0?ooo`3oool01`3oool2000000<0oooo0P0000020?ooo`030000003oool0000000@0oooo0P000000
0`3oool000000?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000030?ooo`00
0000oooo02H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`800000103o
ool00`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo0000000F0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0000003oool00`0000000`3oool000000?ooo`0<0?ooo`030000003oool00000
0080000000@0oooo000000000000oooo100000000`3oool000000?ooo`02000000030?ooo`000000
000000<000002@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`070?oo
o`80000000<0oooo0000000000001@0000000`3oool000000000000:000000h0oooo0`0000001@3o
ool00000000000000000oooo00@000000P3oool010000000oooo0000003oool2000000050?ooo`00
0000oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0A0?ooo`T0000000<0oooo000000000000
103oool400000080oooo00@000000?ooo`3oool0oooo0`0000000`3oool000000?ooo`060?ooo`03
0000003oool0oooo00L0oooo0`0000030?ooo`80000000<0oooo0000003oool00P0000030?ooo`03
0000003oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00<0000000<0oooo0000003oool09@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0000000000040?ooo`060000003oool0
oooo0000003oool000005P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0000000000080oooo00<000000?oo
o`3oool02`3oool2000000040?ooo`00000000000?ooo`80000000<0oooo0000000000000P000000
0`3oool000000?ooo`02000000030?ooo`000000000000<000002@3oool00`000000oooo0?ooo`09
0?ooo`00A03oool2000000P0oooo0P0000000`3oool000000000000B000000h0oooo1@0000000`3o
ool000000?ooo`0400000080oooo00@000000?ooo`000000oooo0P0000000`3oool000000?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool9000000030?ooo`000000
000000@0oooo100000000`3oool00000000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`8000000`3oool200000080oooo00<0
00000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000
oooo000000030?ooo`@000009P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool3000000@0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`00000000000P3oool00`000000oooo0?oo
o`0;0?ooo`80000000@0oooo000000000000oooo0P0000000`3oool0000000000002000000030?oo
o`000000oooo0080000000<0oooo0000000000000`0000070?ooo`<000002`3oool004@0oooo00<0
00000?ooo`3oool01`3oool2000000030?ooo`0000000000018000003`3oool4000000030?ooo`00
0000oooo00@000000P3oool010000000oooo0000003oool2000000030?ooo`000000oooo0080oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`80000000D0oooo000000000000
00000?ooo`03000000030?ooo`000000oooo00<0oooo00H000000?ooo`000000oooo0000003oool2
00000080oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo000000030?ooo`8000000P3oool2000000<0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo1@00
000V0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P0000000`3oool000000?oo
o`0C0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?oo
o`3oool0000000<0oooo0P0000001@3oool000000?ooo`3oool0000000d0oooo0P000000103oool0
00000000003oool7000000030?ooo`000000oooo0080000000<0oooo0000000000000`0000090?oo
o`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00L0oooo0P0000000`3oool0
00000000000<000000030?ooo`000000000000<000003`3oool4000000030?ooo`000000oooo00@0
00000P3oool00`000000oooo000000020?ooo`80000000D0oooo0000003oool0oooo000000090?oo
o`030000003oool0oooo00l0oooo0`0000000`3oool0000000000004000000030?ooo`000000oooo
00<0oooo00H000000?ooo`000000oooo0000003oool200000080oooo00<000000?ooo`0000000P3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00L0oooo0P0000040?ooo`060000
003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool00000
000000<0oooo0P0000030?ooo`<0000000<0oooo0000000000009@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000004
0?ooo`070000003oool0oooo0?ooo`000000oooo0000000D0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`80
000000<0oooo0000003oool00P00000=0?ooo`<0000000D0oooo0000003oool000000?ooo`040000
0080oooo00D000000?ooo`00000000000?ooo`05000000T0oooo00<000000?ooo`3oool02@3oool0
04@0oooo00<000000?ooo`3oool01`3oool2000000030?ooo`000000000000<0000000D0oooo0000
0000000000000?ooo`04000000030?ooo`000000000000<000003`3oool4000000040?ooo`000000
00000?ooo`@000000P3oool010000000oooo0000003oool2000000030?ooo`000000oooo0080oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`@0000000<0oooo000000000000
0P0000000`3oool00000000000040?ooo`@000000P3oool200000080oooo00<000000?ooo`000000
0`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`00
00000`3oool200000080oooo0P0000030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool000000`3oool2000000@0oooo1@00000U0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool2000000@0oooo0`0000040?ooo`030000003oool0oooo0080000000<0oooo0000
003oool04P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000030?ooo`@000000P3oool00`000000oooo0?ooo`0<0?ooo`D0000000<0oooo
0000003oool0100000020?ooo`@0000000<0oooo0000000000000`0000090?ooo`030000003oool0
oooo00T0oooo00140?ooo`030000003oool0oooo00L0oooo0P0000000`3oool00000000000070000
00030?ooo`00000000000080000000<0oooo0000000000000`00000?0?ooo`@000000P3oool00`00
0000oooo0000000300000080oooo00@000000?ooo`000000oooo0P0000000`3oool000000?ooo`02
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo00000002
000000030?ooo`00000000000080000000<0oooo000000000000103oool2000000080?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`030000003oool0oooo0080oooo00D000000?ooo`00
0000oooo000000080?ooo`040000003oool00000000000<0oooo00<000000?ooo`3oool00`000002
0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`00000000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000<000009@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool3000000@0oooo00<000000?ooo`3oool00P00
00000`3oool000000?ooo`0A0?ooo`030000003oool0oooo00L0oooo0P0000030?ooo`030000003o
ool0oooo0080oooo00H000000?ooo`3oool0oooo0000003oool200000080oooo00<000000?ooo`3o
ool0303oool5000000030?ooo`000000oooo00@000000P3oool4000000030?ooo`000000000000<0
00002@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`070?ooo`800000
00<0oooo0000000000001`0000000`3oool0000000000002000000030?ooo`000000000000@00000
3`3oool2000000050?ooo`000000oooo0000003oool0100000020?ooo`030000003oool000000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00`0oooo0`000000103oool000000000003oool3000000030?ooo`000000oooo00<0oooo00H00000
0?ooo`000000oooo0000003oool200000080oooo00<000000?ooo`0000001P3oool010000000oooo
0000000000080?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P0000020?ooo`03
0000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool2000000@0oooo0P000000103o
ool0000000000000000T0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool2
000000@0oooo0P0000040?ooo`030000003oool0oooo0080000000<0oooo0000003oool04@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`3oool2000000050?ooo`000000oooo0?ooo`0000003P3oool5000000030?oo
o`000000oooo00@000000P3oool4000000030?ooo`0000000000008000002P3oool00`000000oooo
0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`070?ooo`/0000000<0oooo0000000000000`00
00000`3oool0000000000004000000l0oooo100000000`3oool0000000000005000000060?ooo`00
0000oooo0?ooo`000000oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0303oool:000000030?ooo`000000oooo00<0oooo0`0000000`3oool0
00000?ooo`0200000080oooo00<000000?ooo`0000001`3oool00`000000oooo000000070?ooo`04
0000003oool00000000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00T0oooo00@000000?ooo`3oool000000P3oool2000000@0oooo00H000000?ooo`0000000000
0?ooo`00000T0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`<00000103oool00`000000oooo0?ooo`0300000140oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool20000
00030?ooo`000000oooo008000003P3oool7000000030?ooo`00000000000080000000<0oooo0000
003oool00P0000000`3oool0000000000003000000X0oooo00<000000?ooo`3oool02@3oool004@0
oooo00<000000?ooo`3oool01`3oool;000000030?ooo`00000000000080000000<0oooo00000000
00001@00000?0?ooo`@000000P3oool00`000000oooo0000000300000080oooo00@000000?ooo`00
0000oooo0P0000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool02`3oool9
000000030?ooo`000000000000@0oooo0P000000103oool000000?ooo`3oool200000080oooo00<0
00000?ooo`000000203oool00`000000oooo000000060?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool00P0000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P00
0000103oool000000?ooo`0000030?ooo`030000003oool0oooo0080000000<0oooo0000003oool0
8`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000
oooo000000040?ooo`030000003oool0oooo0080000000<0oooo0000003oool03P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`3oool400000080oooo0P00000=0?ooo`030000003oool0000000D0000000<0oooo0000
000000000P0000000`3oool000000?ooo`02000000030?ooo`000000000000<000002P3oool00`00
0000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`070?ooo`/0000000<0oooo00000000
00000P0000000`3oool0000000000005000000l0oooo100000020?ooo`030000003oool0000000<0
00000P3oool00`000000oooo0?ooo`02000000040?ooo`000000oooo00000080oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`80000000<0oooo0000000000001@0000000`3o
ool000000?ooo`030?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo000000090?ooo`80000000<0oooo0000003oool00`3oool010000000oooo000000000003
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`080000003o
ool0oooo0000003oool000000?ooo`0000040?ooo`070000003oool000000?ooo`000000oooo0000
000S0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000040?ooo`<00000
0`3oool200000080oooo0`00000?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0?ooo`000000oooo0P0000020?oo
o`8000003@3oool010000000oooo0000003oool4000000030?ooo`00000000000080000000<0oooo
0000003oool00P0000000`3oool0000000000003000000X0oooo00<000000?ooo`3oool02@3oool0
04@0oooo00<000000?ooo`3oool01`3oool;000000030?ooo`000000000000X000003`3oool40000
0080oooo1`0000001P3oool000000?ooo`3oool000000?ooo`80000000<0oooo0000003oool00P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo2P0000000`3oool000000?oo
o`030?ooo`<0000000<0oooo0000003oool00P0000020?ooo`030000003oool0000000T0oooo00D0
00000?ooo`000000oooo000000030?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0
0P0000000`3oool000000?ooo`0=0?ooo`030000003oool0oooo00<000000P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`0000000P00000R0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool3000000@0oooo00<000000?oo
o`3oool00`00000>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool00P00000>
0?ooo`030000003oool000000080000000@0oooo000000000000oooo100000000`3oool000000?oo
o`02000000030?ooo`000000000000<000002P3oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`070?ooo`/0000000<0oooo0000000000002P00000@0?ooo`80000000<0oooo
0000003oool00P0000000`3oool000000000000200000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0
oooo300000040?ooo`<0000000<0oooo0000003oool00P0000020?ooo`030000003oool0000000P0
oooo00X000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0P0000030?ooo`800000
00<0oooo0000000000000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00800000
0`3oool01@000000oooo0?ooo`3oool000000080oooo0P0000000`3oool000000?ooo`0R0?ooo`03
0000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000040?ooo`<000000`3oool01000
0000oooo0?ooo`3oool3000000`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0`0000000`3oool000000?oo
o`02000000h0oooo1@000000103oool000000000003oool300000080oooo100000000`3oool00000
00000003000000X0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool01`3o
ool;000000030?ooo`000000000000@0000000<0oooo0000000000001000000?0?ooo`@000000P3o
ool00`000000oooo0000000300000080oooo00<000000?ooo`3oool00P000000103oool000000?oo
o`0000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool01@000000oooo
000000000000oooo00D0000000<0oooo0000000000000`3oool01@000000oooo0000003oool00000
0080oooo0P0000020?ooo`8000002@3oool00`000000oooo0?ooo`020?ooo`060000003oool00000
0000003oool00000103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00T0oooo
300000000`3oool000000?ooo`020?ooo`080000003oool0oooo0000003oool000000?ooo`00000R
0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000030?ooo`<000000`3o
ool200000080oooo0`00000;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0?ooo`000000oooo0P0000020?ooo`80
00003P3oool5000000030?ooo`000000000000@000000P3oool4000000030?ooo`000000000000<0
00002P3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`070?ooo``00000
00<0oooo0000000000002P00000?0?ooo`<0000000D0oooo0000003oool000000?ooo`0200000005
0?ooo`00000000000?ooo`0000000P3oool010000000oooo0000000000020?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool01P3oool:000000030?ooo`000000oooo00<0oooo00d0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000P0oooo00<0
00000?ooo`3oool0103oool2000000030?ooo`000000000000<0oooo0P0000001@3oool000000000
003oool0000000X0oooo0P0000060?ooo`040000003oool0oooo00000080oooo0`0000020?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool000000280oooo00<000000?ooo`3oool01`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000`3oool010000000oooo
0?ooo`3oool3000000X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0`0000001P3oool000000?ooo`000000
oooo000000h0oooo1@0000000`3oool000000000000400000080oooo100000000`3oool000000000
0003000000X0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool01`3oool9
000000040?ooo`00000000000?ooo``000003`3oool3000000030?ooo`000000oooo00L000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01@3oool:000000030?ooo`000000oooo0080oooo00<000000?oo
o`0000000P0000020?ooo`8000000P3oool00`000000oooo000000080?ooo`030000003oool0oooo
00D0oooo100000030?ooo`040000003oool0000000000080oooo00<000000?ooo`3oool01P3oool2
000000T0oooo00@000000?ooo`00000000000`3oool200000080oooo00@000000?ooo`3oool0oooo
0P0000000`3oool000000000000Q0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0
oooo000000020?ooo`<000000`3oool010000000oooo0?ooo`3oool3000000T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool0oooo0`0000001P3oool000000?ooo`000000oooo000000h0oooo1@0000000`3oool00000
0000000400000080oooo100000000`3oool0000000000003000000X0oooo00<000000?ooo`3oool0
2@3oool004@0oooo00<000000?ooo`3oool0203oool8000000040?ooo`00000000000?ooo`<00000
00<0oooo0000000000001P00000?0?ooo`D000000P3oool00`000000oooo0000000300000080oooo
00D000000?ooo`3oool000000?ooo`0200000080oooo00@000000?ooo`3oool000002`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0000000<0000000D0oooo00000000000000000?ooo`02
000000<0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool2000000P0
oooo00<000000?ooo`3oool01@3oool01@000000oooo000000000000oooo00@0000000D0oooo0000
00000000oooo000000070?ooo`8000002`3oool00`000000oooo00000002000000<0oooo10000003
0?ooo`050000003oool000000?ooo`0000008P3oool00`000000oooo0?ooo`080?ooo`80000000<0
oooo0000003oool00P3oool00`000000oooo000000020?ooo`8000000`3oool3000000L0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool200000080oooo00@000000?ooo`00000000003`3oool2000000040?oo
o`00000000000?ooo`H000000P3oool4000000030?ooo`000000000000<000002P3oool00`000000
oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`080?ooo`030000003oool0000000D00000
00@0oooo000000000000oooo3000000@0?ooo`<0000000<0oooo0000003oool0100000001@3oool0
00000000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`X0000000<0oooo0000000000000`3o
ool010000000oooo0000000000020?ooo`030000003oool000000080oooo0P0000080?ooo`030000
003oool0oooo00D0oooo00H000000?ooo`000000oooo0000003oool2000000050?ooo`0000000000
0?ooo`0000001`3oool00`000000oooo0?ooo`0<0?ooo`80000000<0oooo0000003oool00`3oool0
10000000oooo0000000000030?ooo`050000003oool000000?ooo`0000008@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool000000080oooo0`0000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool3000000040?ooo`000000oooo0?oo
o`8000003`3oool3000000050?ooo`00000000000000003oool0100000000`3oool000000?ooo`03
000000030?ooo`000000000000<000002P3oool00`000000oooo0?ooo`090?ooo`00A03oool20000
00T0oooo00<000000?ooo`0000001@000000103oool000000000003oool<00000100oooo1@000000
0`3oool000000000000500000080oooo00D000000?ooo`3oool000000?ooo`0200000080oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000P00000
00<0oooo0000003oool00P3oool00`000000oooo00000002000000040?ooo`000000oooo00000080
oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`040000003oool000000000
0080oooo10000000103oool000000?ooo`0000060?ooo`030000003oool0oooo00h0oooo00@00000
0?ooo`3oool000000`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0000000800000
8@3oool00`000000oooo0?ooo`0:0?ooo`<000000P3oool00`000000oooo000000020?ooo`800000
0`3oool2000000040?ooo`000000oooo0?ooo`800000303oool2000000@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool010000000oooo00000000000@0?oo
o`@0000000@0oooo000000000000oooo100000000`3oool000000?ooo`02000000030?ooo`000000
000000@00000203oool3000000/0oooo00140?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`000000200000000`3oool000000?ooo`0;000000l0oooo100000000`3oool000000?ooo`040000
00050?ooo`00000000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo0?ooo`H0000000@0oooo00000000
000000000P3oool01P000000oooo0?ooo`3oool000000?ooo`8000000P3oool00`000000oooo0000
00020?ooo`800000203oool00`000000oooo0?ooo`050?ooo`030000003oool0000000<0oooo1`00
00060?ooo`030000003oool0oooo00l0oooo00<000000?ooo`0000001P0000020?ooo`8000000P3o
ool010000000oooo0000003oool200000240oooo00<000000?ooo`3oool02`3oool200000080oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`00
00003@3oool2000000D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool30000
00040?ooo`00000000000?ooo`8000003`3oool00`000000oooo00000002000000040?ooo`000000
00000?ooo`@0000000H0oooo000000000000oooo0000003oool6000000X0oooo00<000000?ooo`3o
ool02@3oool004@0oooo00<000000?ooo`3oool0203oool00`000000oooo0000000800000080oooo
0`0000000`3oool0000000000006000000l0oooo100000000`3oool000000?ooo`04000000030?oo
o`00000000000080oooo00<000000?ooo`0000000P3oool200000080oooo00@000000?ooo`3oool0
0000303oool00`000000oooo0?ooo`0:000000030?ooo`000000000000<0oooo00H000000?ooo`00
000000000?ooo`0000020?ooo`030000003oool0oooo008000001`3oool00`000000oooo0?ooo`05
0?ooo`040000003oool00000000000<0oooo1@0000000`3oool000000?ooo`040?ooo`030000003o
ool0oooo00l0oooo0`0000020?ooo`030000003oool0oooo0080oooo0`0000002@3oool000000?oo
o`3oool000000?ooo`000000oooo0000000Q0?ooo`030000003oool0oooo00`0oooo0P0000001P3o
ool000000000003oool000000?ooo`800000103oool3000000h0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000020?ooo`040000003o
ool0000000000100oooo00<000000?ooo`0000000P000000103oool000000000003oool400000003
0?ooo`00000000000080000000<0oooo0000000000000`00000;0?ooo`030000003oool0oooo00T0
oooo00140?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000200000020?ooo`<00000
00<0oooo0000000000001P00000@0?ooo`D0000000<0oooo0000003oool00`0000001@3oool00000
0000003oool000000080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool02P3oool2000000050?ooo`000000oooo0000003oool01@0000000`3oool000000?oo
o`020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000<0oooo00<000000?oo
o`000000100000000`3oool000000?ooo`020?ooo`030000003oool0oooo00d0oooo0`0000001@3o
ool000000?ooo`000000oooo008000000`3oool00`000000oooo0?ooo`0300000080oooo00<00000
0?ooo`0000000P00000Q0?ooo`030000003oool0oooo00`0oooo3`0000000`3oool000000?ooo`0;
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3o
ool3000000040?ooo`00000000000?ooo`800000403oool00`000000oooo00000002000000040?oo
o`000000oooo0?ooo`<000000P3oool4000000030?ooo`000000000000<000002`3oool00`000000
oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`080?ooo`/000000P3oool3000000030?oo
o`000000000000H00000403oool2000000050?ooo`000000oooo0000003oool00P0000000`3oool0
00000?ooo`02000000050?ooo`000000oooo0?ooo`0000000P3oool200000080oooo00D000000?oo
o`3oool0oooo0000000<0?ooo`H0000000@0oooo00000000000000000P3oool01P000000oooo0?oo
o`3oool000000?ooo`8000000P3oool00`000000oooo000000020?ooo`8000001`3oool00`000000
oooo0?ooo`050?ooo`040000003oool0000000000080oooo00<000000?ooo`000000100000001P3o
ool000000?ooo`000000oooo000000h0oooo0P0000040?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool00P3oool010000000oooo0000003oool2000000050?ooo`000000oooo0000003o
ool00P00000P0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`0000000`3oool0
0000000000040?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`040000003o
ool0000000000140oooo100000020?ooo`030000003oool0oooo00<0000000<0oooo0000003oool0
0`0000000`3oool0000000000003000000/0oooo00<000000?ooo`3oool02@3oool004@0oooo00<0
00000?ooo`3oool02@3oool:00000080oooo3000000@0?ooo`@0000000D0oooo0000003oool00000
0?ooo`03000000050?ooo`00000000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`000000103oool00`000000oooo0?ooo`080?ooo`040000003oool000000?ooo`<0000000H0
oooo00000000000000000?ooo`0000040?ooo`@0000000D0oooo0000003oool0oooo000000020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`000003
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`040000003oool00000000000`0
oooo0P0000060?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000020?ooo`<0000000<0oooo0000003oool00P00000P0?ooo`030000003oool0oooo
00d0oooo0`0000001@3oool000000000003oool0000000@0oooo0P0000020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo0?ooo`<0000000@0oooo000000000000oooo0P00000A0?ooo`@000000P3oool00`000000oooo
00000003000000030?ooo`000000oooo00<0000000<0oooo0000000000000`00000;0?ooo`030000
003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00T0oooo2P0000020?ooo`030000003o
ool000000080000000<0oooo0000000000001@00000?0?ooo`030000003oool000000080000000<0
oooo0000003oool00P0000000`3oool000000?ooo`02000000050?ooo`000000oooo0?ooo`000000
0P3oool200000080oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0000000P0
000000<0oooo0000003oool00P3oool010000000oooo0000000000020?ooo`050000003oool0oooo
0000003oool00P0000070?ooo`030000003oool0oooo00D0oooo00@000000?ooo`00000000000P3o
ool00`000000oooo00000004000000@0oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`060?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000030?ooo`<0000000@0oooo00000000000000008@3oool00`000000oooo0?ooo`0=0?oo
o`P00000103oool2000000030?ooo`000000oooo00D0oooo0P0000070?ooo`030000003oool0oooo
0080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@000000?ooo`0000000000
4P3oool4000000040?ooo`00000000000?ooo`@0000000<0oooo0000003oool00`0000000`3oool0
000000000003000000/0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0
2@3oool2000000030?ooo`000000000000D000000P3oool01@000000oooo000000000000oooo00P0
0000403oool2000000070?ooo`000000oooo0000003oool000000?ooo`03000000050?ooo`000000
00000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000103oool00`000000
oooo0?ooo`070?ooo`H0000000H0oooo0000003oool000000?ooo`0000040?ooo`040000003oool0
000000000080oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool000000`3oool010000000oooo0000003oool2000000@0
oooo00H000000?ooo`00000000000?ooo`0000080?ooo`030000003oool0oooo00L0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3o
ool3000000040?ooo`000000000000000240oooo00<000000?ooo`3oool03P3oool6000000D0oooo
0P0000000`3oool000000?ooo`020?ooo`<000001`3oool00`000000oooo0?ooo`020?ooo`070000
003oool0oooo0?ooo`000000oooo000000020?ooo`80000000<0oooo0000000000004@3oool00`00
0000oooo00000002000000040?ooo`000000oooo0?ooo`@0000000<0oooo0000003oool02@00000;
0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`0000001@0000000`3oool00000000000020?ooo`<0000000<0oooo0000000000001P00000@0?oo
o`D0000000<0oooo0000003oool00P0000000`3oool000000?ooo`02000000050?ooo`000000oooo
0?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0000000P0000000<0oooo0000003oool00P3oool010000000oooo00000000
00020?ooo`050000003oool0oooo0000003oool00P0000070?ooo`030000003oool0oooo00D0oooo
00@000000?ooo`00000000000P3oool010000000oooo0000003oool3000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000050?ooo`8000002P3oool00`000000oooo0?ooo`020?oo
o`040000003oool00000000000@0oooo0P0000040?ooo`@0000000<0oooo000000000000803oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0000000<000001@3oool2000000030?ooo`000000
0000008000001`3oool2000000@0oooo00H000000?ooo`3oool0oooo0000003oool200000080oooo
00@000000?ooo`00000000004P3oool010000000oooo0000000000020?ooo`030000003oool0oooo
00@0000000<0oooo0000003oool00P0000000`3oool0000000000004000000/0oooo00<000000?oo
o`3oool02@3oool004@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0000000500000003
0?ooo`00000000000080oooo0`0000000`3oool000000000000700000100oooo0P0000001`3oool0
00000?ooo`000000oooo0000003oool00`0000001@3oool000000000003oool000000080oooo00<0
00000?ooo`3oool00P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo00@0oooo1P00
00000`3oool0000000000003000000@0oooo00@000000?ooo`00000000000P3oool01P000000oooo
0?ooo`000000oooo000000P0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00@000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=000000@0oooo10000000
0`3oool000000000000P0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool030000007
0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`<000000P3oool2000000030?ooo`000000
00000180oooo00@000000?ooo`00000000000P3oool00`000000oooo0?ooo`05000000050?ooo`00
0000oooo0000003oool01P00000;0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`000000200000020?ooo`d00000403oool5000000030?ooo`00
0000oooo0080000000<0oooo0000000000000P0000020?ooo`030000003oool0000000<0oooo0P00
00000`3oool000000?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001000
00001P3oool00000000000000000oooo000000<0oooo00@000000?ooo`00000000000`3oool01000
0000oooo0000003oool2000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000<
000000030?ooo`000000oooo00L0oooo00<000000?ooo`0000000P00000=0?ooo`<000000`3oool0
10000000oooo0?ooo`0000040?ooo`<00000103oool2000000040?ooo`000000000000000240oooo
00<000000?ooo`3oool03`3oool010000000oooo0?ooo`3oool5000000040?ooo`000000oooo0?oo
o`<000000`3oool2000000H0oooo00<000000?ooo`3oool00P3oool2000000030?ooo`000000oooo
0080000000<0oooo0000000000004`3oool4000000040?ooo`00000000000?ooo`H0000000D0oooo
0000003oool000000?ooo`05000000`0oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0000000800000080oooo00<000000?ooo`0000000P000000
0`3oool0000000000004000000030?ooo`000000oooo00l0oooo0P0000001P3oool000000?ooo`3o
ool000000?ooo`@0000000<0oooo0000000000000P3oool00`000000oooo000000030?ooo`800000
00<0oooo0000003oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<00000
00<0oooo0000003oool0100000030?ooo`040000003oool0000000000080oooo00H000000?ooo`3o
ool000000?ooo`0000080?ooo`040000003oool0oooo0?oooaD00000203oool4000000/0oooo0`00
00060?ooo`040000003oool00000000000@0oooo100000030?ooo`030000003oool0oooo00<00000
8@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo100000020?ooo`050000
003oool0oooo0000003oool00`0000070?ooo`040000003oool0oooo0?ooo`<0000000L0oooo0000
003oool000000?ooo`000000oooo008000004P3oool00`000000oooo00000002000000040?ooo`00
0000oooo0?ooo`80000000D0oooo00000000000000000?ooo`03000000030?ooo`000000000000<0
0000303oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`090?ooo`T00000
00H0oooo0000003oool0oooo0000003oool2000000030?ooo`000000000000@0000000<0oooo0000
00000000403oool5000000040?ooo`000000oooo0?ooo`@0000000L0oooo0000003oool0oooo0000
003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`070000003oool0oooo0000
003oool000000?ooo`03000000050?ooo`00000000000000003oool00`000000103oool000000?oo
o`3oool200000080oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0000000`0000000<0oooo0000000000002`0000060?ooo`80000000<0oooo0000003oool0
1`3oool200000080oooo00<000000?ooo`3oool01@3oool010000000oooo0000000000040?ooo`80
000000<0oooo0000000000000P3oool00`000000oooo0000000300000200oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`020?ooo`80000000<0oooo0000000000001P0000000`3oool0
0000000000050?ooo`030000003oool0oooo00@000000P3oool2000000030?ooo`000000oooo0080
00004`3oool010000000oooo0000000000020?ooo`030000003oool0oooo0080000000D0oooo0000
003oool000000?ooo`03000000030?ooo`000000000000<00000303oool00`000000oooo0?ooo`09
0?ooo`00A03oool00`000000oooo0?ooo`090?ooo`T0000000H0oooo000000000000oooo0000003o
ool2000000030?ooo`000000000000L000004@3oool00`000000oooo00000002000000030?ooo`00
0000oooo00D0000000L0oooo0000003oool0oooo0000003oool0000000<0oooo00D000000?ooo`00
0000oooo000000040?ooo`<0000000<0oooo0000000000000P0000001`3oool000000000003oool0
00000?ooo`0000000P3oool2000000030?ooo`00000000000080oooo00H000000?ooo`3oool00000
0?ooo`0000050?oooaX000000P3oool6000000<0oooo00H000000?ooo`3oool000000?ooo`000005
0?ooo`800000103oool00`000000oooo0?ooo`050?ooo`040000003oool00000000000@0oooo0P00
00030?ooo`80000000<0oooo0000003oool00P0000000`3oool000000?ooo`0O0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool3000000<0oooo0P0000020?ooo`80000000<0
oooo0000000000000P3oool00`000000oooo00000003000000<0oooo00L000000?ooo`3oool0oooo
0000003oool0000001@0oooo00@000000?ooo`00000000000P3oool00`000000oooo0?ooo`020000
00050?ooo`000000oooo0000003oool02@00000<0?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo00T0oooo20000000103oool000000000000000020?ooo``0000000<0oooo
0000003oool03`3oool3000000060?ooo`00000000000?ooo`000000oooo1`0000020?ooo`030000
003oool0000000<0oooo00@000000?ooo`000000oooo0P0000030?ooo`<0000000D0oooo00000000
000000000?ooo`03000000030?ooo`000000oooo00<0oooo100000020?ooo`030000003oool00000
0080oooo00@000000?ooo`3oool0oooo50000000103oool000000?ooo`0000020?ooo`H0000000<0
oooo000000000000100000040?ooo`030000003oool000000080oooo0P0000060?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`0000000000103oool2000000@0oooo0`000000103oool00000
00000000000Q0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo000000020?oo
o`<000000P3oool200000080oooo1`0000060?ooo`8000000P3oool010000000oooo00000000000D
0?ooo`040000003oool0000000000080oooo00<000000?ooo`0000001@0000020?ooo`80000000<0
oooo0000000000001000000<0?ooo`030000003oool0oooo00T0oooo00140?ooo`8000002P3oool3
000000030?ooo`00000000000080000000@0oooo00000000000000000P3oool00`000000oooo0000
0009000000030?ooo`000000oooo0100oooo00D000000?ooo`000000oooo000000020?ooo`030000
003oool0000000H000000P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo
00D000000?ooo`3oool000000?ooo`04000000070?ooo`00000000000?ooo`000000oooo00000003
0?ooo`030000003oool000000080000000L0oooo0000003oool0oooo0000003oool000000080oooo
2P0000020?ooo`030000003oool00000008000000P3oool00`000000oooo0000000300000080oooo
00<000000?ooo`3oool00P3oool400000080oooo1@0000030?ooo`@00000203oool00`000000oooo
0?ooo`070?ooo`040000003oool00000000000@0oooo0P0000050?ooo`80000000@0oooo00000000
000000008@3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`000000103oool7
000000X0oooo0`0000020?ooo`040000003oool0oooo000001@0oooo00H000000?ooo`000000oooo
0000003oool2000000030?ooo`000000000000@000000P3oool2000000030?ooo`000000000000@0
00002P3oool3000000/0oooo00140?ooo`030000003oool0oooo00T0oooo0`0000000`3oool00000
00000002000000040?ooo`000000000000000080oooo00<000000?ooo`000000200000000`3oool0
00000000000B0?ooo`030000003oool000000080000000@0oooo0000003oool0oooo1`0000001@3o
ool000000?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool2000000030?ooo`000000
oooo00L0000000<0oooo0000000000000`3oool01@000000oooo000000000000oooo00@000000P3o
ool4000000030?ooo`000000000000<00000103oool3000000080?ooo`000000oooo0?ooo`000000
oooo0000003oool3000000030?ooo`000000oooo00L0oooo100000000`3oool00000000000030000
0080oooo0P0000000`3oool000000?ooo`060?ooo`030000003oool0oooo00L0oooo00D000000?oo
o`000000oooo000000030?ooo`8000001P3oool4000000030?ooo`000000oooo0200oooo00<00000
0?ooo`3oool03`3oool200000080oooo00<000000?ooo`3oool01`3oool3000000@0oooo10000002
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool04`3oool010000000oooo00000000
00020?ooo`030000003oool0oooo00H0000000D0oooo0000003oool000000?ooo`06000000`0oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool02P3oool2000000030?ooo`00
000000000080000000@0oooo00000000000000000P3oool01@000000oooo000000000000oooo00P0
000000<0oooo0000003oool0403oool00`000000oooo0?ooo`03000000040?ooo`000000oooo0?oo
o`L0000000@0oooo0000003oool0oooo0P0000020?ooo`040000003oool000000?ooo`X0000000@0
oooo0000003oool000000`3oool010000000oooo0000000000020?ooo`030000003oool0oooo00@0
000000<0oooo000000000000100000020?ooo`D000000P3oool200000080oooo0P0000001P3oool0
0000000000000000oooo000000/0oooo2P0000020?ooo`030000003oool0000000H0oooo00<00000
0?ooo`3oool0203oool010000000oooo0000000000040?ooo`8000001@3oool00`000000oooo0000
0002000000030?ooo`000000oooo01l0oooo00<000000?ooo`3oool04@3oool010000000oooo0?oo
o`00000;0?ooo`@000001@3oool00`000000oooo000000020?ooo`030000003oool0oooo01@0oooo
100000020?ooo`030000003oool0oooo0080000000T0oooo00000000000000000?ooo`000000oooo
0000003oool01@00000=0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`000000100000020?ooo`8000000P3oool00`000000oooo0000000:0000
00030?ooo`000000oooo0140oooo00@000000?ooo`000000oooo0P0000000`3oool000000?ooo`08
000000030?ooo`00000000000080oooo00<000000?ooo`3oool0100000000`3oool0000000000007
000000030?ooo`000000000000<0oooo00@000000?ooo`00000000000P3oool;000000030?ooo`00
0000000000800000103oool010000000oooo0?ooo`0000020?ooo`040000003oool000000?ooo`<0
000000<0oooo0000003oool02@3oool010000000oooo0?ooo`3oool800000080oooo00<000000?oo
o`0000001@3oool00`000000oooo0?ooo`020?ooo`P0000000<0oooo000000000000103oool20000
00D0oooo00<000000?ooo`0000001000000P0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool00P00000B0?ooo`8000000P3oool2000001H0oooo0P0000001P3oool000000?ooo`3oool0
00000?ooo`<0000000T0oooo0000003oool000000?ooo`000000oooo0000003oool01@00000=0?oo
o`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00X0oooo200000001`3oool0
0000000000000000oooo0000003oool03@00000B0?ooo`060000003oool0oooo0000003oool00000
0P3oool00`000000oooo00000003000000040?ooo`000000000000000080oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo00000004000000030?ooo`000000000000@000000`3oool01@00
0000oooo000000000000oooo00P0000000@0oooo000000000000oooo0`0000060?ooo`030000003o
ool0000001@000000P3oool00`000000oooo0?ooo`040?ooo`P0000000@0oooo0000000000000000
103oool5000000L0oooo1@0000030?ooo`8000001P3oool2000000030?ooo`000000000000800000
803oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00800000403oool00`000000oooo
0?ooo`03000001H0oooo00H000000?ooo`000000oooo0000003oool2000000050?ooo`0000000000
0000003oool00P0000020?ooo`T000003@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`00
0000oooo0?ooo`0:0?ooo`P0000000@0oooo00000000000000000P3oool00`000000oooo00000003
000000030?ooo`000000000000@0000000<0oooo0000003oool04@3oool01P000000oooo0?ooo`00
0000oooo00000080oooo100000000`3oool0000000000004000000080?ooo`00000000000?ooo`00
0000oooo0000003oool8000000030?ooo`000000oooo00<000000P3oool00`000000oooo0000000?
000000030?ooo`000000000000L0000000<0oooo0000000000002@0000030?ooo`D0000000<0oooo
0000000000000P0000050?ooo`H0000000<0oooo0000000000000P3oool6000000`0oooo00<00000
0?ooo`0000000`0000020?ooo`8000001@3oool00`000000oooo0000000500000200oooo00<00000
0?ooo`3oool04@3oool200000080oooo0P00000=0?ooo`80000000@0oooo00000000000000005`3o
ool400000080oooo00<000000?ooo`3oool00P000000103oool000000000000000020?ooo`T00000
3@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0:0?ooo`P0000000@0
oooo00000000000000000P3oool01@000000oooo000000000000oooo00P0000000<0oooo0000003o
ool04@3oool2000000030?ooo`000000oooo008000000`3oool00`000000oooo0000000700000080
oooo00D000000?ooo`00000000000?ooo`0900000080oooo00<000000?ooo`3oool02`0000000`3o
ool0000000000009000000<0oooo200000000`3oool000000?ooo`04000000T0oooo0`0000020?oo
o`D00000103oool9000000040?ooo`000000oooo000000d0oooo00D000000?ooo`00000000000?oo
o`05000000D0oooo00<000000?ooo`0000000P0000000`3oool000000000000P0?ooo`8000004`3o
ool6000000X0oooo0P0000000`3oool000000000000I0?ooo`@000000P3oool00`000000oooo0?oo
o`02000000040?ooo`000000oooo00000080oooo0P0000000`3oool0000000000004000000d0oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool02P3oool4000000050?ooo`00
000000000000003oool0100000000`3oool000000?ooo`0<000000030?ooo`000000oooo0140oooo
00D000000?ooo`3oool000000?ooo`02000000<0oooo00<000000?ooo`3oool00P0000000`3oool0
000000000003000000030?ooo`000000000001P0000000<0oooo0000000000000`0000060?ooo`P0
000000<0oooo0000000000000P3oool9000000T0oooo100000030?ooo`<000001@3oool00`000000
oooo00000003000000030?ooo`000000oooo008000003P3oool010000000oooo0000000000030?oo
o`<000001@3oool00`000000oooo00000002000000040?ooo`000000000000000200oooo00<00000
0?ooo`3oool04`3oool700000080oooo1`00000J0?ooo`030000003oool00000008000000P3oool0
0`000000oooo00000002000000040?ooo`000000oooo00000080oooo0P0000000`3oool000000000
0004000000d0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool02P3oool3
000000030?ooo`000000000000<0000000L0oooo00000000000000000?ooo`000000oooo00D00000
00<0oooo000000000000100000000`3oool000000?ooo`0B0?ooo`050000003oool0oooo0000003o
ool00`0000020?ooo`8000000P3ooolP000000030?ooo`000000000000800000103oool400000080
oooo0P0000000`3oool00000000000020?ooo`070000003oool0oooo0000003oool000000?ooo`03
000000<0oooo1P0000020?ooo`030000003oool0oooo0080oooo0`0000030?ooo`<000000`3oool0
0`000000oooo00000003000000040?ooo`0000000000000000h0oooo00<000000?ooo`3oool00P00
00030?ooo`<00000103oool00`000000oooo0?ooo`03000000040?ooo`000000oooo00000200oooo
00<000000?ooo`3oool05@3oool:000001d0oooo1@000000103oool000000000003oool200000080
oooo0P0000020?ooo`<0000000<0oooo0000000000001000000=0?ooo`030000003oool0oooo00T0
oooo00140?ooo`030000003oool0oooo00X0oooo0`0000000`3oool0000000000003000000070?oo
o`00000000000000003oool000000?ooo`0<000000030?ooo`000000oooo01<0oooo00/000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000030?ooo`000000000002H0
00000P3oool00`000000oooo0000000B000000T0oooo100000040?ooo`<000001@3oool300000003
0?ooo`000000000000@000000P3oool2000000h0oooo00@000000?ooo`0000000000103oool30000
00@0oooo00<000000?ooo`3oool00P0000000`3oool000000000000200000200oooo0P00000L0?oo
o`030000003oool0oooo01d0oooo100000020?ooo`030000003oool0oooo0080000000@0oooo0000
003oool000000P3oool3000000030?ooo`000000000000<000003P3oool00`000000oooo0?ooo`09
0?ooo`00=03oool00`3ookl0M000000000020000000304RLg`3oool0oooo00P0oooo00<000000?oo
o`3oool02`3oool2000000030?ooo`000000000000<0000000H0oooo00000000000000000?ooo`00
00020?ooo`<0000000L0oooo00000000000000000?ooo`000000oooo0080000000<0oooo0000003o
ool04`3oool00`000000oooo0?ooo`0700000080oooo1@0000000`3oool000000000000J00000003
0?ooo`000000000000T00000103oool00`000000oooo0000000500000080oooo2@0000040?ooo`04
0000003oool0oooo0?ooo`@000000`3oool200000080oooo0P0000000`3oool00000000000020?oo
o`030000003oool000000080000000<0oooo0000000000000P00000=0?ooo`040000003oool00000
000000@0oooo100000030?ooo`030000003oool0oooo0080000000<0oooo0000003oool00P00000Q
0?ooo`800000603oool200000200oooo100000020?ooo`030000003oool0oooo0080000000@0oooo
0000003oool000000P3oool9000000h0oooo00<000000?ooo`3oool02@3oool003H0oooo00<0okmd
0000001d_ol02`3oool00`000000oooo0?ooo`0;0?ooo`80000000<0oooo0000000000000`000000
0`3oool0000000000002000000030?ooo`000000oooo00`0000000<0oooo0000003oool04`3oool2
000000<0oooo00@000000?ooo`000000oooo0P0000040?ooob40000000<0oooo0000000000007@00
00000`3oool0000000000002000000H0oooo0`0000040?ooo`8000001@3oool2000000030?ooo`00
0000000000@0000000@0oooo0000003oool00000303oool00`000000oooo0?ooo`02000000@0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`3oool2000000030?ooo`000000oooo
008000008P3oool2000001@0oooo0P00000Q0?ooo`D000000P3oool00`000000oooo000000020000
00030?ooo`000000000000<0oooo2@00000>0?ooo`030000003oool0oooo00T0oooo000f0?ooo`03
0?oog`2LB00007Bo00/0oooo00<000000?ooo`3oool02`3oool800000080oooo0`0000000`3oool0
00000?ooo`04000000050?ooo`00000000000000003oool00P000000103oool000000?ooo`00000D
0?ooo`<000000P3oool01@000000oooo000000000000oooo00L0000000<0oooo0000000000007000
00000`3oool000000000000600000080oooo00<000000?ooo`3oool00P0000020?ooo`80000000@0
oooo00000000000000000`3oool<00000080oooo00@000000?ooo`3oool0oooo0P000000103oool0
00000000003oool2000000D0oooo00<000000?ooo`3oool0100000020?ooo`<00000303oool00`00
0000oooo0?ooo`02000000<0oooo0P0000020?ooo`80000000@0oooo0000003oool0oooo0`000000
0`3oool000000?ooo`02000002<0oooo0P00000?0?ooo`<000008`3oool5000000040?ooo`000000
00000?ooo`80000000@0oooo00000000000000000`3oool2000000030?ooo`000000000000@00000
3P3oool00`000000oooo0?ooo`090?ooo`00=`3oool00`3OW4P004RL0=ooo`0:0?ooo`030000003o
ool0oooo00/0oooo100000000`3oool0000000000002000000070?ooo`00000000000000003oool0
00000?ooo`04000000070?ooo`000000oooo0000003oool000000?ooo`03000000030?ooo`000000
oooo01<0oooo00<000000?ooo`0000000P3oool2000000030?ooo`00000000000080000000@0oooo
0000003oool0oooo3@0000030?oooah000000P3oool2000000030?ooo`000000000000@000001@3o
ool4000000030?ooo`000000000000@000001@3oool2000000@0oooo00<000000?ooo`3oool00`3o
ool2000000030?ooo`0000000000008000000`3oool2000000`0oooo00@000000?ooo`0000000000
103oool2000000<0oooo00<000000?ooo`0000000P3oool200000080oooo00@000000?ooo`000000
0000903oool6000000L0oooo0P00000V0?ooo`@000000P3oool00`000000oooo0?ooo`0200000004
0?ooo`000000oooo00000080oooo0`0000000`3oool0000000000004000000h0oooo00<000000?oo
o`3oool02@3oool003L0oooo00<0omnL04P0B02Lgol02P3oool00`000000oooo0?ooo`0<0?ooo`P0
000000<0oooo0000000000000`0000000`3oool0000000000003000000050?ooo`00000000000000
003oool00P000000103oool000000?ooo`00000D0?ooo`040000003oool0oooo000000<0oooo0P00
00000`3oool0000000000010000000@0oooo00<000000?ooo`0000000P0000000`3oool000000000
000300000080oooo00<000000?ooo`3oool00P0000030?ooo`800000103oool800000080oooo0P00
000<0?ooo`040000003oool00000000000@0oooo00<000000?ooo`3oool00P3oool300000080oooo
0P0000020?ooo`040000003oool0oooo000002T0oooo1`00000X0?ooo`@000000P3oool00`000000
oooo0?ooo`02000000040?ooo`000000oooo00000080oooo0`0000000`3oool00000000000040000
00h0oooo00<000000?ooo`3oool02@3oool003L0oooo00<0oono07@0001d_ol02P3oool3000000`0
oooo0P000000103oool000000000003oool2000000030?ooo`00000000000080000000<0oooo0000
003oool0100000001`3oool00000000000000000oooo0000003oool00`0000000`3oool000000?oo
o`0C0?ooo`040000003oool0oooo000000@0oooo1`0000000`3oool0000000000002000000030?oo
o`000000000000H0000000<0oooo0000003oool00`000000103oool000000?ooo`3ooolN000000<0
oooo1@0000000`3oool000000?ooo`040?ooo`P000001@3oool00`000000oooo0?ooo`020?ooo`@0
00000`3oool;000000X0oooo00<000000?ooo`3oool00P0000040?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo
05@0oooo00H000000?ooo`000000oooo0000003oool2000000040?ooo`00000000000?ooo`<00000
0`3oool3000000030?ooo`000000000000@00000303oool3000000/0oooo000h0?ooo`030;md0000
M;l0oooo00T0oooo00<000000?ooo`3oool0303oool2000000040?ooo`00000000000?ooo`800000
0P3oool3000000030?ooo`000000oooo00<0000000@0oooo000000000000oooo0P0000000`3oool0
000000000003000000030?ooo`000000oooo01<0oooo00<000000?ooo`3oool00P0000040?ooo`h0
000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`02000000030?ooo`000000000000D0
00001`3oool00`000000oooo0?ooo`030?ooo`h00000203oool4000000<0oooo00@000000?ooo`3o
ool0oooo0P000000103oool000000000000000040?ooo`@0000000<0oooo0000000000001@3oool0
0`000000oooo0000000300000080oooo100000090?ooo`030000003oool0oooo008000000`3oool2
000000D0oooo0P0000001P3oool000000?ooo`000000oooo000000<0oooo0P00001D0?ooo`060000
003oool000000?ooo`000000oooo0P000000103oool000000000003oool300000080oooo2`00000>
0?ooo`030000003oool0oooo00T0oooo000h0?ooo`030=nLB000B9`0gooo00T0oooo00<000000?oo
o`3oool0303oool2000000030?ooo`000000000000<000000P3oool3000000030?ooo`000000oooo
00D0000000D0oooo00000000000000000?ooo`04000000040?ooo`000000oooo000001@0oooo0P00
00020?ooo`@000000P3oool00`000000oooo00000006000000030?ooo`000000oooo008000000`3o
ool00`000000oooo0000000400000080oooo00@000000?ooo`00000000001P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080000000<0oooo0000003oool02`0000030?ooo`030000
003oool0oooo00D00000103oool01@000000oooo000000000000oooo00<0000000@0oooo00000000
0000oooo0P0000030?ooo`030000003oool0oooo0080oooo1`0000030?ooo`D000001`3oool01000
0000oooo0000000000040?ooo`8000001@3oool2000000060?ooo`00000000000000003oool00000
0`3oool2000005<0oooo100000020?ooo`030000003oool0oooo0080000000@0oooo0000003oool0
00000P3oool:000000l0oooo00<000000?ooo`3oool02@3oool003P0oooo00<0omnL04P0B02Lgol0
2@3oool00`000000oooo0?ooo`0=0?ooo`P0000000<0oooo0000000000000P0000000`3oool00000
00000003000000040?ooo`00000000000?ooo`80000000<0oooo0000000000000`0000020?ooo`03
0000003oool0oooo01<0oooo00@000000?ooo`3oool0oooo1@0000000`3oool00000000000040000
00050?ooo`000000oooo0?ooo`0000000`3oool5000000030?ooo`000000oooo0080oooo0`000006
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`00000000000P3oool2000000040?ooo`00
000000000?ooo`/000001@3oool3000000030?ooo`000000000000@0oooo0P000000103oool00000
0000000000040?ooo`040000003oool0oooo0?ooo`8000000P3oool00`000000oooo0?ooo`050000
00<0oooo0`0000000`3oool00000000000060?ooo`040000003oool00000000000@0oooo00<00000
0?ooo`3oool0103oool6000000030?ooo`000000oooo0080oooo0P00001A0?ooo`<0000000D0oooo
0000003oool0oooo000000020?ooo`030000003oool0oooo008000000`3oool3000000030?ooo`00
0000000000@000003`3oool00`000000oooo0?ooo`090?ooo`00>03oool00`3ookl0M00007Boo`09
0?ooo`030000003oool0oooo00d0oooo0P0000000`3oool0000000000003000000030?ooo`000000
00000080000000<0oooo0000003oool02@0000020?ooo`<0000000@0oooo0000003oool000005P3o
ool00`000000oooo000000020?ooo`80000000<0oooo0000000000003@0000020?ooo`040000003o
ool00000000000<0oooo0P0000000`3oool000000?ooo`050?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool2000000050?ooo`00000000000?ooo`0000001`3oool60000
0080oooo00<000000?ooo`3oool00`0000070?ooo`80000000@0oooo00000000000000000`3oool2
000000<0oooo00<000000?ooo`0000000`3oool3000000030?ooo`00000000000080oooo00<00000
0?ooo`0000000P3oool2000000D0oooo00@000000?ooo`0000000000103oool00`000000oooo0?oo
o`040?ooo`030000003oool0000000<0000000<0oooo0000003oool00`3oool00`000000oooo0?oo
o`1>0?ooo`040000003oool0000000000080oooo00<000000?ooo`3oool00P000000103oool00000
0000000000030?ooo`<0000000<0oooo0000000000001000000?0?ooo`030000003oool0oooo00T0
oooo000i0?ooo`030;md0000M;l0oooo00P0oooo00<000000?ooo`3oool03@3oool2000000030?oo
o`000000000000<000000P3oool3000000030?ooo`000000oooo00@0000000@0oooo000000000000
oooo0P0000002@3oool000000000003oool000000?ooo`000000oooo0000000E0?ooo`8000000P3o
ool2000000030?ooo`000000000000H000000P3oool2000000<0oooo00@000000?ooo`000000oooo
0P0000040?ooo`<000001P3oool00`000000oooo0?ooo`040?ooo`090000003oool000000000003o
ool000000?ooo`000000oooo00<000000P3oool@000000030?ooo`000000oooo00@000000`3oool0
0`000000oooo0?ooo`02000000030?ooo`000000000000@0oooo0P0000020?ooo``000000P3oool3
000000<0oooo0P0000030?ooo`030000003oool0oooo008000000`3oool2000000H0oooo00<00000
0?ooo`0000000`0000000`3oool000000?ooo`030?ooo`030000003oool0oooo04d0oooo0P000000
1@3oool000000?ooo`3oool000000080oooo0P000000103oool000000000000000020?ooo`@00000
00<0oooo0000000000001000000?0?ooo`030000003oool0oooo00T0oooo000g0?ooo`050?oo_`1d
000000000000M02oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000800000
00D0oooo00000000000000000?ooo`03000000040?ooo`000000oooo0?ooo`<0000000D0oooo0000
0000000000000?ooo`02000000030?ooo`00000000000080000000<0oooo0000003oool00P00000A
0?ooo`8000000P3oool3000000030?ooo`000000000000D0000000<0oooo0000003oool00P000000
1P3oool00000000000000000oooo00000080oooo00<000000?ooo`3oool00P3oool2000000030?oo
o`000000oooo00@0oooo00<000000?ooo`3oool0103oool01`000000oooo000000000000oooo0000
003oool0200000060?ooo`030000003oool0oooo00<0oooo1`0000020?ooo`D000001@3oool40000
00@0oooo1`0000020?ooo`@0000000<0oooo0000000000001@0000040?ooo`8000000P3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
000000D0oooo00<000000?ooo`3oool0B`3oool4000000<0oooo00@000000?ooo`3oool000000P3o
ool2000000<0oooo2`00000?0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0
oooo00d0oooo1@0000001@3oool00000000000000000oooo00@0000000<0oooo0000003oool01000
00000`3oool00000000000020?ooo`030000003oool0000000H000000P3oool2000000d0oooo0P00
00030?ooo`T0000000D0oooo0000003oool000000?ooo`02000000@0oooo1P0000030?ooo`040000
003oool00000000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0800000003
0?ooo`000000oooo00L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool<0000
00H0oooo200000000`3oool0000000000002000000D0oooo0P0000000`3oool00000000000030?oo
o`<00000103oool2000000060?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D000001@3oool2000004/0oooo00@000000?ooo`0000000000
0P3oool200000080oooo00<000000?ooo`0000000P0000030?ooo`<0000000<0oooo000000000000
1000000@0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00d0oooo1@00
0000103oool000000000000000020?ooo`<0000000@0oooo0000003oool0oooo0`0000001@3oool0
00000?ooo`000000oooo0080000000<0oooo0000000000000P0000000`3oool000000?ooo`030?oo
o`<000001`3oool3000000<0oooo0`0000000`3oool000000?ooo`03000000090?ooo`0000000000
0?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`000000oooo0P0000000`3oool0
00000000000R000000<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool00000
00<0oooo2`0000050?ooo`D00000103oool010000000oooo0?ooo`0000050?ooo`D000000`3oool5
000000<0oooo0`0000000`3oool00000000000040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`0000000`3oool000000?ooo`040?ooo`800000B@3oool4000000<0oooo00<00000
0?ooo`3oool00P000000103oool000000000000000020?ooo`050000003oool000000000003oool0
1P00000@0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00h0oooo0P00
00000`3oool0000000000004000000060?ooo`00000000000000003oool000000P3oool400000003
0?ooo`00000000000080oooo00@000000?ooo`000000oooo0`0000000`3oool000000?ooo`050?oo
o`8000000`3oool2000000@0oooo100000001@3oool000000?ooo`000000oooo00@000000P3oool2
000000030?ooo`000000oooo0080oooo00@000000?ooo`000000oooo0P0000040?ooo`80000000<0
oooo0000003oool0103oool00`000000oooo00000005000000080?ooo`00000000000?ooo`000000
oooo0000003oool2000000030?ooo`000000oooo00@0oooo2@0000030?ooo`030000003oool0oooo
00@0oooo1@0000000`3oool0000000000003000000050?ooo`00000000000000003oool010000003
0?ooo`<0000000<0oooo0000003oool0103oool6000000<0oooo0P0000000`3oool0000000000003
0?ooo`80000000<0oooo000000000000103oool00`000000oooo0?ooo`040?ooo`040000003oool0
00000?ooo`@000001@3oool2000004P0oooo00@000000?ooo`00000000000P3oool200000080oooo
0P0000000`3oool00000000000030?ooo`@0000000<0oooo0000000000001000000@0?ooo`030000
003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00h0oooo2@0000000`3oool000000000
0002000000040?ooo`000000oooo0?ooo`<0000000D0oooo0000003oool000000?ooo`0200000004
0?ooo`00000000000?ooo`80000000@0oooo00000000000000001@3oool3000000@0oooo10000002
0?ooo`D0000000<0oooo0000000000001P0000030?ooo`030000003oool000000080oooo0P000004
0?ooo`<0000000<0oooo0000000000001@0000040?ooo`040000003oool0oooo00000080oooo00D0
00000?ooo`00000000000?ooo`02000000P0oooo00<000000?ooo`3oool00P3oool5000000D0oooo
0P0000020?ooo`D000000P3oool4000000D0oooo100000001`3oool000000?ooo`3oool000000?oo
o`0000001@3oool8000000030?ooo`00000000000080oooo0P0000030?ooo`040000003oool00000
000000<0oooo0P0000060?ooo`040000003oool000000?ooo`@000001P3oool00`000000oooo0?oo
o`140?ooo`80000000<0oooo0000003oool00P3oool01P000000oooo0?ooo`3oool000000?ooo`<0
00000`3oool4000000030?ooo`000000000000@00000403oool00`000000oooo0?ooo`090?ooo`00
A03oool00`000000oooo0?ooo`0>0?ooo`T000000P3oool3000000040?ooo`000000oooo0?ooo`<0
00000P3oool010000000oooo0000003oool2000000030?ooo`00000000000080oooo2P0000040?oo
o`@000000P3oool5000000040?ooo`000000000000000080oooo00D000000?ooo`00000000000?oo
o`0B000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02000000050?ooo`00
0000oooo0000003oool00`0000080?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0
00000?ooo`05000000H0oooo1P0000000`3oool0000000000002000000@0oooo1@0000030?ooo`03
0000003oool0000000D0oooo1@0000020?ooo`D000000P3oool2000000030?ooo`000000000000<0
00000`3oool2000000H0oooo00@000000?ooo`000000oooo100000060?ooo`030000003oool0oooo
0480oooo0P0000000`3oool00000000000030?ooo`030000003oool0oooo0080000000@0oooo0000
003oool000000P3oool01@000000oooo000000000000oooo00H000004@3oool00`000000oooo0?oo
o`090?ooo`00A03oool00`000000oooo0?ooo`0>0?ooo`D0000000<0oooo0000000000000P000000
1P3oool00000000000000000oooo00000080oooo100000000`3oool000000?ooo`06000000040?oo
o`00000000000?ooo`80000000<0oooo000000000000103oool4000000@0oooo1P000000103oool0
00000?ooo`0000020?ooo`050000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`00
0000oooo008000001@3oool00`000000oooo000000060?ooo`030000003oool0oooo0080oooo00X0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0P0000000`3oool000000?ooo`06
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool5000000H0oooo1000
00040?ooo`8000001@3oool4000000<0oooo00@000000?ooo`0000000000103oool5000000<0oooo
100000030?ooo`<0000000@0oooo00000000000000000`3oool2000000D0oooo00D000000?ooo`3o
ool000000?ooo`04000000H0oooo0P0000120?ooo`80000000<0oooo0000003oool00P3oool01000
0000oooo0?ooo`3oool2000000040?ooo`000000oooo00000080oooo00D000000?ooo`0000000000
0?ooo`0600000140oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool03P3o
ool2000000040?ooo`00000000000?ooo`@0000000@0oooo00000000000000000P3oool00`000000
oooo0000000300000080oooo00<000000?ooo`0000000`0000000`3oool000000?ooo`0600000003
0?ooo`0000000000008000001@3oool3000000090?ooo`00000000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo000000030?ooo`070000003oool000000?ooo`00
0000oooo000000040?ooo`<000001P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo000000000000oooo008000001`3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool600000080oooo
100000030?ooo`<00000103oool2000000030?ooo`000000oooo0080oooo00@000000?ooo`3oool0
0000103oool5000000D0oooo0`0000030?ooo`80000000@0oooo0000003oool000000`3oool20000
00D0oooo00D000000?ooo`3oool000000?ooo`02000000030?ooo`000000oooo00D0oooo0P000010
0?ooo`80000000<0oooo0000000000000`3oool00`000000oooo0?ooo`02000000040?ooo`000000
0000000000<0oooo100000000`3oool000000000000400000140oooo00<000000?ooo`3oool02@3o
ool004@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0000000700000080oooo0`000000
103oool000000?ooo`3oool4000000060?ooo`000000oooo0?ooo`000000oooo0P000000103oool0
00000?ooo`3oool3000000040?ooo`0000000000000000<0oooo100000020?ooo`8000000P3oool5
00000080oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool000000080oooo0P00
00050?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`00000000000?ooo`02000000L0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000030?ooo`800000203oool5000000<0oooo100000020?oo
o`@000000`3oool2000000030?ooo`000000oooo0080oooo0P0000000`3oool000000?ooo`040?oo
o`@000001@3oool4000000<0oooo100000030?ooo`8000001P3oool01@000000oooo0?ooo`000000
oooo0080000000<0oooo0000003oool01@3oool2000003h0oooo00D000000?ooo`000000oooo0000
00030?ooo`040000003oool0oooo0?ooo`80000000@0oooo0000003oool000000P3oool00`000000
oooo0000000800000180oooo00<000000?ooo`3oool02@3oool004@0oooo0P00000?0?ooo`030000
003oool0000000L000000P3oool300000080oooo00<000000?ooo`0000000`0000020?ooo`050000
003oool000000000003oool01@0000000`3oool000000000000=000000030?ooo`00000000000080
000000@0oooo000000000000oooo0P000000103oool000000?ooo`0000030?ooo`050000003oool0
oooo0000003oool00P0000050?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool00P3o
ool020000000oooo0?ooo`3oool000000?ooo`000000oooo100000000`3oool000000?ooo`050?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`07
0?ooo`800000103oool2000000<0oooo100000020?ooo`<000000P3oool00`000000oooo00000003
000000<0oooo00<000000?ooo`0000001@3oool4000000D0oooo1P0000000`3oool0000000000002
000000<0oooo0P0000060?ooo`050000003oool0oooo0000003oool00P0000000`3oool000000000
00050?ooo`<00000>`3oool01@000000oooo0000003oool0000000<0oooo0P0000020?ooo`<00000
00@0oooo0000003oool000000P3oool01@000000oooo000000000000oooo00H00000403oool30000
00/0oooo00140?ooo`030000003oool0oooo00l0oooo0P000000103oool000000000003oool40000
00040?ooo`000000000000000080oooo00@000000?ooo`000000oooo0`000000103oool000000?oo
o`3oool2000000060?ooo`00000000000000003oool000000P3oool00`000000oooo0?ooo`020000
00<0oooo1P0000020?ooo`060000003oool000000000003oool000000P3oool010000000oooo0?oo
o`0000020?ooo`050000003oool0oooo0000003oool00P0000050?ooo`030000003oool0000000H0
oooo00<000000?ooo`3oool00P3oool020000000oooo0?ooo`3oool000000?ooo`000000oooo0`00
00000`3oool00000000000060?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0P3oool2000000P0oooo0P0000080?ooo`8000000P3oool5000000030?ooo`000000000000<00000
0P3oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`0000001@3oool4000000H0oooo
0P0000020?ooo`<0000000<0oooo0000000000000`3oool2000000H0oooo00<000000?ooo`3oool0
0P0000001@3oool000000000003oool0000000D0oooo00<000000?ooo`000000>@3oool01P000000
oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool0oooo0P000000103oool000000?oo
o`0000030?ooo`050000003oool000000000003oool01P00000B0?ooo`030000003oool0oooo00T0
oooo00140?ooo`030000003oool0oooo00l0oooo0P0000000`3oool0000000000002000000030?oo
o`00000000000080oooo0`0000020?ooo`050000003oool000000000003oool00P000000103oool0
00000?ooo`3oool200000080oooo100000020?ooo`8000000P3oool5000000@0oooo100000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0000
000000050?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool000000080oooo00P000000?ooo`00000000000?ooo`000000oooo000000D0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0
oooo0P00000;0?ooo`8000000P3oool2000000040?ooo`00000000000?ooo`@000000P3oool20000
00030?ooo`00000000000080oooo00@000000?ooo`0000000000103oool2000000030?ooo`000000
oooo00D0oooo0`0000020?ooo`H000000P3oool2000000H0oooo00<000000?ooo`3oool00P000000
1@3oool000000000003oool0000000D0oooo00@000000?ooo`0000000000=P3oool01P000000oooo
0?ooo`000000oooo000000<0oooo0P0000030?ooo`80000000@0oooo0000003oool000000`3oool4
000000030?ooo`000000000000<000004`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0000000<0000000@0oooo00000000000000000P3oool3
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool200000080
oooo100000020?ooo`<000000P3oool900000080oooo00@000000?ooo`00000000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool00000000000D0oooo0P0000000`3oool000000?oo
o`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000000`3oool00000
0?ooo`03000000030?ooo`000000000000H0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00H0oooo0P00000?0?ooo`80000000L0oooo00000000
000000000?ooo`000000oooo0080000000<0oooo0000003oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000@0oooo0P0000000`3oool000000?ooo`050?ooo`<00000
0P3oool00`000000oooo0?ooo`05000000030?ooo`000000oooo00@0oooo00@000000?ooo`3oool0
oooo0P000000103oool000000000003oool2000000@0oooo0P0000000`3oool000000?ooo`0d0?oo
o`030000003oool0oooo00<000000`3oool010000000oooo0?ooo`3oool400000080oooo00D00000
0?ooo`3oool000000?ooo`09000001<0oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo00000003000000030?ooo`00000000000080000000@0oooo
00000000000000000`3oool2000000030?ooo`000000oooo0080000000<0oooo0000003oool00P3o
ool010000000oooo0000000000020?ooo`T000000P3oool600000080oooo00<000000?ooo`000000
0`3oool01@000000oooo0?ooo`000000oooo00D000001@3oool2000000030?ooo`000000oooo00@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool000000?oo
o`<0000000<0oooo0000000000001P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0000003oool00P0000080?ooo`8000004P3oool00`000000oooo0?ooo`02000000030?ooo`000000
000000D000000P3oool2000000040?ooo`000000oooo0?ooo`80000000<0oooo0000003oool00`3o
ool2000000030?ooo`000000000000H0oooo0P0000020?ooo`030000003oool0oooo00D0000000<0
oooo0000003oool0103oool010000000oooo0?ooo`3oool2000000030?ooo`00000000000080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0000000c0?ooo`040000003oool0oooo0?ooo`80
00000`3oool2000000<0oooo0P000000103oool000000?ooo`0000030?ooo`050000003oool00000
0000003oool01P00000C0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo
00l0oooo00@000000?ooo`000000oooo1`0000020?ooo`<000000P3oool01P000000oooo0000003o
ool000000?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`0200000080oooo
100000020?ooo`H000000P3oool3000000040?ooo`000000oooo0?ooo`8000000P3oool00`000000
oooo00000002000000030?ooo`000000oooo00@0oooo0P0000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool020000000oooo0?ooo`3oool000000?ooo`000000oooo0`00
0000103oool000000?ooo`0000050?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000
oooo000000090?ooo`800000503oool2000000070?ooo`00000000000000003oool000000?ooo`02
000000040?ooo`000000oooo0?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo0000
00040?ooo`80000000<0oooo0000000000001P3oool3000000060?ooo`000000oooo0?ooo`000000
oooo0`0000000`3oool000000?ooo`040?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000
000000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0000000000300oooo00@00000
0?ooo`3oool0oooo0`0000020?ooo`8000000`3oool5000000030?ooo`000000oooo0080oooo00D0
00000?ooo`00000000000?ooo`06000001<0oooo00<000000?ooo`3oool02@3oool004@0oooo00<0
00000?ooo`3oool0403oool2000000030?ooo`000000000000D000000P3oool3000000<0oooo0P00
0000103oool000000?ooo`3oool2000000030?ooo`000000oooo0080oooo0P0000020?ooo`800000
0P3oool5000000<0oooo100000020?ooo`8000000P3oool01P000000oooo0?ooo`3oool000000?oo
o`<000000P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00P000000?ooo`3oool0oooo0000003oool000000?ooo`<00000
0P3oool2000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo00000002000000P0oooo
0P00000H0?ooo`030000003oool0000000@0000000<0oooo0000000000000P0000030?ooo`030000
003oool0000000<0oooo00<000000?ooo`000000103oool2000000030?ooo`000000000000H0oooo
00H000000?ooo`000000oooo0000003oool200000080oooo100000050?ooo`040000003oool0oooo
0?ooo`80000000<0oooo0000000000000P3oool2000000@0oooo00@000000?ooo`3oool00000;P3o
ool00`000000oooo0?ooo`020?ooo`8000000`3oool2000000<0oooo0P0000001@3oool000000?oo
o`3oool000000080oooo00<000000?ooo`0000002@00000C0?ooo`030000003oool0oooo00T0oooo
00140?ooo`030000003oool0oooo0100oooo00<000000?ooo`0000000`0000000`3oool000000000
0002000000030?ooo`0000000000008000000P3oool200000080oooo00H000000?ooo`000000oooo
0000003oool2000000<0oooo0`0000000`3oool00000000000030?ooo`D00000103oool2000000<0
oooo00H000000?ooo`3oool0oooo0000003oool300000080oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo
0P0000000`3oool000000?ooo`03000000030?ooo`000000000000D0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0000000000090?ooo`8000006P3oool2000000030?ooo`000000000000<0
000000<0oooo0000000000000P0000020?ooo`040000003oool0000000000080oooo00@000000?oo
o`00000000000`3oool2000000030?ooo`000000000000H0oooo0`0000000`3oool000000?ooo`02
00000080oooo100000050?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000000000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00800000:`3oool00`000000oooo0?oo
o`020?ooo`030000003oool000000080oooo0P0000030?ooo`D000000P3oool01@000000oooo0?oo
o`000000oooo00X000004`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?oo
o`0A0?ooo`80000000@0oooo000000000000oooo100000020?ooo`<000000`3oool00`000000oooo
0?ooo`02000000030?ooo`000000000000<0oooo00<000000?ooo`3oool00`3oool6000000L0oooo
0P0000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool00`3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`000000oooo0`000000103oool000000?oo
o`0000040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`0000000000203oool3000001d0
oooo1@0000000`3oool000000?ooo`02000000040?ooo`000000oooo0?ooo`80000000D0oooo0000
003oool0oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`00000000001`3o
ool300000080oooo0P0000020?ooo`80000000<0oooo0000003oool0103oool010000000oooo0?oo
o`3oool2000000030?ooo`000000000000<0oooo00<000000?ooo`3oool00P3oool200000080oooo
00<000000?ooo`3oool0:03oool010000000oooo0?ooo`3oool3000000<0oooo0P0000030?ooo`80
000000D0oooo0000003oool0oooo000000030?ooo`@0000000<0oooo0000000000001000000D0?oo
o`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo0140oooo0P0000000`3oool0
00000000000500000080oooo100000020?ooo`8000000P3oool5000000<0oooo00<000000?ooo`3o
ool01P3oool3000000<0oooo0`0000040?ooo`8000000P3oool4000000050?ooo`000000oooo0?oo
o`0000001@3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool000000080oooo0P00
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000002@3oool200000240oooo00<0
00000?ooo`0000000`0000020?ooo`<000000`3oool00`000000oooo000000020?ooo`80000000<0
oooo0000003oool00`3oool010000000oooo0000000000070?ooo`030000003oool000000080oooo
0P0000030?ooo`040000003oool00000000000<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000<0oooo0P0000040?ooo`80000000<0oooo0000000000009`3oool00`00
0000oooo0?ooo`03000000040?ooo`000000oooo0?ooo`8000000`3oool2000000030?ooo`000000
00000080oooo00D000000?ooo`3oool000000?ooo`0:000001@0oooo00<000000?ooo`3oool02@3o
ool004@0oooo00<000000?ooo`3oool04@3oool00`000000oooo00000003000000030?ooo`000000
0000008000000P3oool3000000<0oooo00@000000?ooo`3oool000000P3oool3000000<0oooo0P00
00090?ooo`<000001@3oool2000000<0oooo00H000000?ooo`00000000000?ooo`0000020?ooo`03
0000003oool0oooo00<0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`000000oooo00000002
0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`<000002@3oool200000280oooo20000000
0`3oool000000000000200000080oooo00<000000?ooo`0000000`3oool00`000000oooo00000004
0?ooo`040000003oool00000000000L0oooo0`0000020?ooo`8000000`3oool00`000000oooo0000
000200000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000000<0oooo
0P0000040?ooo`80000000<0oooo0000000000008`3oool200000080oooo00<000000?ooo`000000
0P0000030?ooo`8000000`3oool4000000<0oooo00D000000?ooo`3oool000000?ooo`0:000001@0
oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool04P3oool5000000030?oo
o`0000000000008000000P3oool400000080oooo0P0000020?ooo`050000003oool0oooo0000003o
ool00P0000030?ooo`8000003@3oool2000000@0oooo00<000000?ooo`0000000`0000020?ooo`03
0000003oool0oooo00<0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`<0000000@0oooo0000003oool000000`3oool20000
00@0oooo00<000000?ooo`3oool00P3oool3000000T0oooo0P00000L0?ooo`<00000103oool01@00
0000oooo0?ooo`000000oooo0080000000<0oooo0000003oool00P000000103oool000000?ooo`3o
ool3000000<0oooo00<000000?ooo`000000103oool4000000P0oooo0`0000000`3oool000000?oo
o`030?ooo`8000000P3oool2000000030?ooo`000000oooo00<0oooo00@000000?ooo`3oool0oooo
0P0000040?ooo`800000103oool2000000030?ooo`000000000001l0oooo0P0000030?ooo`060000
003oool000000000003oool000000P3oool2000000<0oooo0P0000000`3oool00000000000020?oo
o`040000003oool0oooo0?ooo`<0000000<0oooo0000000000000P000000103oool0000000000000
000D0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo0180oooo0P000000
1@3oool00000000000000000oooo00<000000`3oool400000080oooo00D000000?ooo`3oool0oooo
000000020?ooo`80000000<0oooo0000003oool00`3oool3000000H0oooo100000040?ooo`H00000
0`3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`000000103oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000000000000`0000020?oo
o`800000103oool00`000000oooo0?ooo`020?ooo`<00000203oool2000001X0oooo100000070?oo
o`060000003oool0oooo0?ooo`000000oooo100000020?ooo`030000003oool0000000<0oooo0P00
00030?ooo`030000003oool0000000@0oooo100000080?ooo`<0000000<0oooo0000003oool00`3o
ool2000000<0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`3oool2000000D0oooo
0P0000040?ooo`80000000<0oooo0000000000006`3oool2000000<0oooo100000000`3oool00000
000000020?ooo`030000003oool000000080oooo1@0000030?ooo`040000003oool0oooo0?ooo``0
0000503oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0C0?ooo`030000
003oool000000080000000<0oooo0000000000000P0000020?ooo`<0000000D0oooo0000003oool0
oooo000000030?ooo`80000000<0oooo0000000000000`0000050?ooo`H000001P3oool700000080
oooo0P0000050?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`000000100000020?ooo`800000103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000P0oooo0P00000G0?ooo`@000002`3oool00`00
0000oooo0?ooo`020?ooo`80000000@0oooo00000000000000000P3oool400000080oooo0P000003
0?ooo`030000003oool0000000@0oooo100000080?ooo`D000000`3oool00`000000oooo00000003
0?ooo`<00000103oool200000080oooo0P0000060?ooo`800000103oool2000000030?ooo`000000
000001H0oooo0`0000040?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool2
00000080oooo00D000000?ooo`000000oooo000000030?ooo`040000003oool0oooo0?ooo``00000
5@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0C0?ooo`H0000000@0
oooo00000000000000000P3oool2000000040?ooo`000000oooo00000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo000000020?ooo`<000002`3oool5000000060?ooo`00000000000?oo
o`000000oooo0P0000060?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000100000020?ooo`800000103o
ool010000000oooo0?ooo`3oool4000000P0oooo0P00000E0?ooo`<000003`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0000000<0000000D0oooo000000000000oooo000000020?ooo`<0
00000P3oool010000000oooo0000000000030?ooo`@00000203oool2000000030?ooo`0000000000
00<0oooo00@000000?ooo`00000000000`3oool2000000@0oooo0P0000020?ooo`8000001`3oool2
000000@0oooo0P000000103oool0000000000000000A0?ooo`8000001P3oool00`000000oooo0000
00030?ooo`8000000P3oool2000000<0oooo0P0000000`3oool000000?ooo`030?ooo`040000003o
ool0oooo0?ooo`<0000000<0oooo0000000000001P00000E0?ooo`030000003oool0oooo00T0oooo
00140?ooo`030000003oool0oooo01@0oooo00<000000?ooo`0000000P0000000`3oool000000000
000200000080oooo1@0000020?ooo`800000103oool010000000oooo0000000000020?ooo`l00000
00@0oooo000000000000oooo0P0000000`3oool000000?ooo`050?ooo`80000000@0oooo0000003o
ool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo1`0000030?oo
o`8000000`3oool01P000000oooo0?ooo`3oool000000?ooo`800000203oool200000180oooo1000
00000`3oool0000000000008000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000
000300000080oooo00D000000?ooo`00000000000?ooo`0300000080oooo00@000000?ooo`3oool0
00000`3oool4000000P0oooo0P0000000`3oool00000000000030?ooo`040000003oool000000000
00@0oooo00<000000?ooo`3oool00P3oool200000080oooo0`0000070?ooo`800000103oool30000
00030?ooo`000000000000l000001P3oool4000000<0oooo00<000000?ooo`0000000P3oool01000
0000oooo0?ooo`3oool3000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool00P3oool;
000001H0oooo00<000000?ooo`3oool02@3oool004@0oooo0P00000E0?ooo`030000003oool00000
008000000P3oool300000080oooo1P0000020?ooo`800000103oool2000000030?ooo`000000oooo
00<0oooo0`0000030?ooo`L0000000@0oooo000000000000oooo0P0000060?ooo`060000003oool0
oooo0000003oool000000`3oool2000000D0oooo00<000000?ooo`3oool00P3oool5000000030?oo
o`00000000000080oooo0P0000030?ooo`030000003oool0oooo0080000000<0oooo000000000000
203oool00`000000oooo0?ooo`0>0?ooo`T000002P3oool6000000030?ooo`000000oooo00L0oooo
0P000000103oool000000000000000020?ooo`040000003oool0oooo00000080oooo0P0000020?oo
o`040000003oool0oooo000000<0oooo100000080?ooo`D000000`3oool010000000oooo00000000
00040?ooo`8000000`3oool2000000<0oooo0P0000080?ooo`8000001@3oool3000001@0oooo0`00
00040?ooo`040000003oool000000?ooo`8000000`3oool01@000000oooo0000003oool0000000<0
oooo00<000000?ooo`3oool00P3oool3000000030?ooo`000000000000H00000503oool3000000/0
oooo00140?ooo`030000003oool0oooo01@0oooo00<000000?ooo`0000000`0000000`3oool00000
0000000200000080oooo0`0000000`3oool00000000000020?ooo`8000001@3oool00`000000oooo
000000060?ooo`H000000`3oool200000080oooo00<000000?ooo`3oool0103oool200000080oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
0P000000103oool000000000003oool200000080oooo0P0000030?ooo`040000003oool0oooo0000
0080oooo0P0000080?ooo`030000003oool0oooo00`0oooo1@00000G0?ooo`D000001`3oool00`00
0000oooo0000000200000080oooo0P000000103oool000000?ooo`3oool200000080oooo0P000000
0`3oool000000?ooo`020?ooo`@00000203oool00`000000oooo0000000300000080oooo00<00000
0?ooo`0000000P0000030?ooo`800000103oool010000000oooo0?ooo`3oool2000000T0oooo0`00
00050?ooo`<000002@3oool8000000H0oooo00<000000?ooo`3oool00`0000030?ooo`030000003o
ool0000000<000000P3oool00`000000oooo0?ooo`030?ooo``000005P3oool00`000000oooo0?oo
o`090?ooo`00A03oool00`000000oooo0?ooo`0E0?ooo`030000003oool00000008000000P3oool3
000000<0oooo0`0000000`3oool00000000000020?ooo`8000001@3oool00`000000oooo0000000>
00000080oooo0P0000060?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000060?ooo`030000003oool0oooo00<0oooo00D000000?ooo`00000000000?ooo`0200000080
oooo0P0000030?ooo`040000003oool0000000000080oooo0P0000070?ooo`8000002`3oool40000
00030?ooo`000000000001X0oooo00@000000?ooo`3oool0oooo0`0000050?ooo`030000003oool0
0000008000000P3oool2000000040?ooo`00000000000?ooo`8000000`3oool00`000000oooo0000
00030?ooo`@00000203oool00`000000oooo0000000300000080oooo00D000000?ooo`000000oooo
000000030?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo
0P0000060?ooo`T000000P3oool3000000P0oooo00<000000?ooo`3oool00P0000050?ooo`D00000
0`3oool00`000000oooo0?ooo`020?ooo`<0000000<0oooo0000000000001P00000G0?ooo`030000
003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01D0oooo00<000000?ooo`0000000`00
00000`3oool000000000000200000080oooo0`0000000`3oool00000000000020?ooo`030000003o
ool0000000D0oooo0P00000>0?ooo`8000001`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`030?ooo`050000003oool000000000
003oool00P0000020?ooo`030000003oool0000000<0oooo0P0000030?ooo`8000001`3oool20000
00T0oooo0`0000030?ooo`800000703oool00`000000oooo0?ooo`040?ooo`<000000`3oool20000
00040?ooo`000000000000000080oooo00D000000?ooo`3oool000000?ooo`02000000<0oooo00<0
00000?ooo`0000000`3oool4000000P0oooo00<000000?ooo`3oool0100000001P3oool000000?oo
o`000000oooo000000@0oooo0`0000020?ooo`8000000`3oool2000000/0oooo0`00000;0?ooo`<0
00002P3oool01@000000oooo0?ooo`3oool0000000D0oooo0`0000000`3oool000000?ooo`020?oo
o`030000003oool0oooo00<0oooo0`0000000`3oool0000000000002000000040?ooo`0000000000
000001L0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool05@3oool30000
00030?ooo`00000000000080oooo100000020?ooo`040000003oool000000?ooo`8000000P3oool0
0`000000oooo000000060?ooo`h000001`3oool200000080oooo0P0000020?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool00`3oool01@000000oooo000000000000oooo00800000
0`3oool2000000<0oooo0P0000030?ooo`8000001`3oool2000000L0oooo0`0000040?ooo`800000
7P3oool00`000000oooo0?ooo`070?ooo`<000000P3oool00`000000oooo0000000200000080oooo
00D000000?ooo`3oool000000?ooo`02000000<0oooo00<000000?ooo`0000000`3oool4000000P0
oooo00<000000?ooo`3oool00P0000001@3oool000000?ooo`000000oooo00@000000`3oool01@00
0000oooo000000000000oooo008000000`3oool3000000`0oooo2`00000<0?ooo`030000003oool0
oooo00800000103oool2000000030?ooo`0000000000008000000P3oool00`000000oooo0?ooo`03
0?ooo`<0000000<0oooo0000000000001P00000H0?ooo`030000003oool0oooo00T0oooo00140?oo
o`030000003oool0oooo01D0oooo0P000000103oool000000000000000020?ooo`@000000`3oool2
00000080oooo0P0000020?ooo`030000003oool0000001T0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`040000003oool00000000000H0oooo00<000000?ooo`3oool00`3oool01@000000oooo
000000000000oooo008000000`3oool2000000<0oooo0P0000030?ooo`8000001`3oool00`000000
oooo0?ooo`050?ooo`8000001P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00X0
oooo0P0000000`3oool000000?ooo`0300000080oooo0P0000000`3oool000000000000300000080
oooo00<000000?ooo`0000000`3oool2000000030?ooo`000000000000L0oooo00<000000?ooo`3o
ool00P000000103oool000000000000000020?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool0100000040?ooo`800000803oool200000080oooo0P0000030?ooo`8000000P3oool40000
0080oooo00<000000?ooo`3oool00`3oool4000000030?ooo`00000000000080000000@0oooo0000
000000000000603oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0F0?oo
o`040000003oool000000?ooo`8000000P3oool2000000040?ooo`000000oooo0?ooo`<000000P3o
ool2000000040?ooo`000000oooo0?ooo`8000005@3oool2000000<0oooo00L000000?ooo`3oool0
oooo0000003oool0000000L0oooo00<000000?ooo`3oool00`3oool010000000oooo0000003oool3
000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`8000001`3oool0
0`000000oooo0?ooo`040?ooo`8000001P3oool200000240oooo00<000000?ooo`3oool0303oool3
000000040?ooo`000000000000000080oooo0P0000020?ooo`@000000P3oool010000000oooo0000
000000020?ooo`80000000<0oooo0000000000001`3oool00`000000oooo0?ooo`03000000030?oo
o`00000000000080oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`3oool3000000@0
oooo0`00000M0?ooo`030000003oool0oooo00<000000P3oool200000080oooo100000001@3oool0
00000?ooo`3oool0000000D0oooo0`0000000`3oool0000000000007000001P0oooo00<000000?oo
o`3oool02@3oool004@0oooo00<000000?ooo`3oool05P3oool3000000030?ooo`00000000000080
oooo00@000000?ooo`00000000000`3oool300000080oooo0P0000000`3oool000000?ooo`020?oo
o`8000003`3oool4000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo00<0
00000?ooo`3oool00P3oool2000000030?ooo`000000oooo00<000000`3oool00`000000oooo0000
00020?ooo`030000003oool0oooo0080oooo0P0000070?ooo`030000003oool0oooo00<0oooo0P00
00060?ooo`8000008`3oool00`000000oooo0?ooo`0>0?ooo`<0000000D0oooo0000000000000000
0?ooo`0200000080oooo100000020?ooo`040000003oool0oooo00000080oooo0P0000000`3oool0
0000000000070?ooo`070000003oool0oooo0000003oool000000?ooo`0200000080oooo00@00000
0?ooo`00000000000P3oool00`000000oooo0?ooo`020?ooo`<00000103oool3000001X0oooo00<0
00000?ooo`3oool00`0000020?ooo`060000003oool0oooo0?ooo`000000oooo100000020?ooo`03
0000003oool0oooo00<0oooo100000000`3oool0000000000002000000040?ooo`00000000000000
01T0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool05`3oool200000004
0?ooo`000000000000000080oooo0P000000103oool000000?ooo`3oool3000000<0oooo00@00000
0?ooo`3oool00000103oool2000000D0oooo200000070?ooo`070000003oool0oooo0?ooo`000000
oooo000000060?ooo`800000103oool2000000060?ooo`000000oooo0000003oool000000`3oool0
10000000oooo0000003oool2000000@0oooo0P0000070?ooo`030000003oool0oooo0080oooo0P00
00060?ooo`8000009@3oool00`000000oooo0?ooo`0@0?ooo`80000000@0oooo0000000000000000
0P3oool00`000000oooo0?ooo`0400000080oooo00@000000?ooo`3oool000000P3oool200000003
0?ooo`000000000000L0oooo00D000000?ooo`3oool000000?ooo`02000000050?ooo`0000000000
0?ooo`0000000P3oool2000000030?ooo`000000oooo00@0oooo0`0000040?ooo`<000005`3oool0
0`000000oooo0?ooo`0200000080oooo0P0000030?ooo`030000003oool0oooo0080000000@0oooo
0000003oool000001@3oool01`000000oooo000000000000oooo0000003oool01`00000I0?ooo`03
0000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01L0oooo0`0000000`3oool00000
000000020?ooo`040000003oool00000000000<0oooo0`0000020?ooo`80000000<0oooo0000003o
ool01@3oool5000000h0oooo00@000000?ooo`3oool0oooo0`0000060?ooo`030000003oool0oooo
00<0oooo0P0000001P3oool000000?ooo`000000oooo000000<0oooo00@000000?ooo`000000oooo
0P0000040?ooo`8000001P3oool2000000<0oooo0P0000060?ooo`8000009`3oool00`000000oooo
0?ooo`0B0?ooo`D000000P3oool200000080oooo0`0000020?ooo`040000003oool0oooo00000080
oooo0P0000000`3oool00000000000070?ooo`040000003oool0oooo00000080oooo1P0000030?oo
o`<000001@3oool600000080oooo0`00000D0?ooo`030000003oool000000080000000<0oooo0000
000000000`3oool200000080oooo0P0000001@3oool000000?ooo`3oool0000000@0oooo00<00000
0?ooo`0000000P0000000`3oool0000000000007000001T0oooo00<000000?ooo`3oool02@3oool0
04@0oooo00<000000?ooo`3oool0603oool2000000040?ooo`000000000000000080oooo00@00000
0?ooo`00000000000P3oool010000000oooo0000000000020?ooo`@000005P3oool200000080oooo
0`0000060?ooo`8000001@3oool2000000060?ooo`000000oooo0000003oool00000103oool00`00
0000oooo00000002000000@0oooo0P0000060?ooo`8000000P3oool2000000H0oooo0P00000Y0?oo
o`030000003oool0oooo01<0oooo1@0000020?ooo`8000000P3oool300000080oooo00@000000?oo
o`3oool000000P3oool2000000030?ooo`000000000000L0oooo00@000000?ooo`3oool000000`3o
ool2000000040?ooo`0000000000000000<0oooo0P0000060?ooo`<0000000<0oooo000000000000
1P00000?0?ooo`P00000103oool00`000000oooo0?ooo`0500000080oooo00<000000?ooo`3oool0
0`3oool010000000oooo0000000000020?ooo`@0000000<0oooo0000000000000P00000I0?ooo`03
0000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01P0oooo0P0000020?ooo`800000
0P3oool00`000000oooo0000000200000080oooo00@000000?ooo`00000000000P3oool4000001<0
oooo0P0000020?ooo`@000001P3oool00`000000oooo0?ooo`040?ooo`@0000000@0oooo0000003o
ool00000103oool00`000000oooo00000002000000@0oooo0P0000060?ooo`D000001P3oool20000
02/0oooo00<000000?ooo`3oool05@3oool5000000030?ooo`00000000000080oooo100000001@3o
ool000000?ooo`3oool000000080oooo0P0000000`3oool00000000000070?ooo`040000003oool0
oooo000000@0oooo0P0000000`3oool00000000000040?ooo`8000001P3oool=000000@0oooo2`00
00000`3oool00000000000040?ooo`80000000@0oooo000000000000oooo0P0000030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`07000001X0oooo
00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool06@3oool2000000030?ooo`00
0000000000<0oooo00@000000?ooo`00000000000P3oool00`000000oooo00000002000000<0oooo
1000000>0?ooo`<000000P3oool4000000H0oooo0P0000060?ooo`<000000P3oool00`000000oooo
000000040?ooo`030000003oool0000000800000103oool2000000H0oooo0`0000080?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool05P3oool00`000000oooo00000002000000050?oo
o`00000000000000003oool0100000001@3oool000000?ooo`3oool0000000<0oooo100000070?oo
o`040000003oool0oooo000000@0oooo0`0000000`3oool00000000000040?ooo`8000001P3oool2
00000080oooo5`0000030?ooo`<000000P3oool00`000000oooo0?ooo`02000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0200000080oooo100000000`3oool0000000000002
000001X0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool06@3oool20000
0080oooo0P0000020?ooo`D000000P3oool00`000000oooo00000002000000@0oooo1@0000080?oo
o`<000000`3oool3000000P0oooo00<000000?ooo`3oool01@3oool3000000030?ooo`0000000000
00800000103oool00`000000oooo00000002000000@0oooo0P0000050?ooo`<00000203oool20000
02h0oooo00<000000?ooo`3oool05`3oool500000080oooo0P0000020?ooo`<0000000D0oooo0000
003oool0oooo000000030?ooo`@000001`3oool00`000000oooo0?ooo`02000000<0oooo00<00000
0?ooo`0000001P000000103oool000000000000000060?ooo`8000001P3oool800000080oooo0P00
00020?ooo`030000003oool0000000<000000`3oool2000000030?ooo`000000000000D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo00000002000000030?ooo`000000oooo00P000006P3o
ool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0J0?ooo`8000000P3oool0
1P000000oooo0?ooo`3oool000000?ooo`8000000`3oool010000000oooo0000003oool2000000<0
oooo00@000000?ooo`3oool0oooo0`0000030?ooo`8000000P3oool4000000T0oooo0P0000070?oo
o`<0000000<0oooo0000003oool00P0000040?ooo`040000003oool00000000000D0oooo0P000004
0?ooo`<000002@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01T0oooo1@000000
0`3oool00000000000020?ooo`040000003oool000000?ooo`80000000<0oooo0000000000000P3o
ool4000000L0oooo00<000000?ooo`3oool00P0000030?ooo`8000000P3oool3000000030?ooo`00
0000000000D00000103oool3000000L0oooo3@0000050?ooo`80000000@0oooo0000000000000000
1@3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000000P3oool400000003
0?ooo`0000000000008000006`3oool00`000000oooo0?ooo`090?ooo`00A03oool2000001/0oooo
0P0000020?ooo`8000000P3oool5000000<0oooo00@000000?ooo`000000oooo100000000`3oool0
00000?ooo`030?ooo`@0000000<0oooo0000000000000`00000:0?ooo`030000003oool0oooo00D0
oooo100000000`3oool000000?ooo`02000000D0oooo0`0000050?ooo`8000000`3oool200000003
0?ooo`000000oooo00L0oooo0P00000a0?ooo`030000003oool0oooo01X0oooo1@0000000`3oool0
0000000000020?ooo`030000003oool000000080oooo00@000000?ooo`3oool000000P3oool40000
00L0oooo00<000000?ooo`3oool00P0000040?ooo`040000003oool0oooo0?ooo`<000000`3oool7
00000080oooo0`0000080?ooo`8000000`3oool2000000H0oooo1P0000060?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`0000020?ooo`T000006@3oool3000000/0oooo00140?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`3oool4
000000@0oooo0P0000030?ooo`@000001P3oool3000000030?ooo`000000000000X0oooo0P000007
0?ooo`80000000D0oooo00000000000000000?ooo`02000000D0oooo0`0000050?ooo`80000000@0
oooo00000000000000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool06`3oool9000000030?ooo`00000000000080000000D0oooo0000003oool0
oooo000000020?ooo`@000001`3oool00`000000oooo0?ooo`02000000@0oooo00<000000?ooo`3o
ool00P3oool4000000030?ooo`000000oooo0080oooo3`0000000`3oool0000000000002000000L0
oooo1P0000060?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo000000020?oo
o`X000006`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0K0?ooo`80
00000P3oool200000080oooo0P000000103oool000000000000000040?ooo`030000003oool0oooo
0080oooo300000070?ooo`D000001`3oool3000000030?ooo`00000000000080oooo0P0000050?oo
o`<000001@3oool4000000<0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool07@3oool800000080oooo0`0000001@3oool000000?ooo`3oool000000080oooo10000007
0?ooo`80000000<0oooo000000000000103oool2000000D0oooo1P0000030?ooo`<000000P3oool3
000000030?ooo`000000000000H000001@3oool6000000P0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0300000080oooo0P0000000`3oool0000000000004000001`0oooo00<00000
0?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool06`3oool00`000000oooo000000020?oo
o`8000000P3oool2000000040?ooo`0000000000000000@0oooo00<000000?ooo`3oool0103oool2
000000H0oooo2000000;0?ooo`8000000P3oool2000000040?ooo`0000000000000000@0oooo1000
00050?ooo`<00000103oool2000000L0oooo0P00000e0?ooo`030000003oool0oooo01h0oooo1000
0000103oool000000000000000020?ooo`<0000000D0oooo0000003oool0oooo000000020?ooo`D0
00001`3oool00`000000oooo00000002000000@0oooo00<000000?ooo`3oool0103oool200000003
0?ooo`000000000000@0000000<0oooo0000000000001`0000050?ooo`T00000203oool2000000D0
oooo00<000000?ooo`3oool00`0000020?ooo`X00000703oool00`000000oooo0?ooo`090?ooo`00
A03oool00`000000oooo0?ooo`0L0?ooo`<0000000<0oooo0000000000000P3oool01P000000oooo
0000003oool000000?ooo`8000000`3oool2000000H0oooo1P00000A0?ooo`8000000P3oool20000
0080oooo0P0000040?ooo`<0000000<0oooo0000003oool00P3oool3000000H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01l0oooo00@000000?oo
o`00000000000P3oool3000000060?ooo`00000000000000003oool000000P3oool00`000000oooo
0?ooo`05000000L0oooo00<000000?ooo`3oool00P0000040?ooo`030000003oool0oooo00D0oooo
0P0000000`3oool00000000000020?ooo`@000001@3oool>000000L0oooo0P0000060?ooo`040000
003oool0oooo0?ooo`8000000`3oool2000000030?ooo`000000oooo00D00000703oool00`000000
oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0L0?ooo`030000003oool000000080oooo
0P0000020?ooo`<0000000D0oooo000000000000oooo000000030?ooo`<000001P3oool00`000000
oooo0?ooo`0A0?ooo`80000000@0oooo00000000000000000P3oool2000000<0oooo0P0000001@3o
ool000000?ooo`000000oooo00<0000000<0oooo0000003oool01@3oool00`000000oooo0?ooo`05
0?ooo`800000>03oool00`000000oooo0?ooo`0P0?ooo`@000000P3oool3000000060?ooo`000000
00000000003oool000000P3oool00`000000oooo0?ooo`05000000L0oooo0P0000000`3oool00000
000000040?ooo`8000001`3oool2000000030?ooo`000000000001@0oooo00<000000?ooo`3oool0
103oool3000000P0oooo00<000000?ooo`3oool00P0000030?ooo`<0000000<0oooo000000000000
1@00000L0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo01d0oooo0`00
00000`3oool00000000000020?ooo`050000003oool000000000003oool00P0000000`3oool00000
000000020?ooo`040000003oool00000000000D0oooo0P00000?0?ooo`80000000@0oooo00000000
000000000`3oool200000080oooo0P000000103oool000000000003oool3000000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool08P3oool4000000050?ooo`00000000000000003oool00`000000103oool000000?oo
o`3oool200000080oooo100000080?ooo`040000003oool0oooo000000D0oooo0P0000070?ooo`L0
00003P3oool2000000D0oooo0P00000:0?ooo`030000003oool0oooo00800000103oool200000003
0?ooo`000000oooo00D000007@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo
0?ooo`0M0?ooo`030000003oool000000080oooo0P0000020?ooo`030000003oool0000000800000
00@0oooo0000003oool0oooo0P000000103oool000000?ooo`3oool2000000D0oooo0P00000:0?oo
o`H0000000@0oooo0000003oool0oooo0P0000030?ooo`050000003oool0oooo0000003oool00`00
00030?ooo`8000001P3oool00`000000oooo0?ooo`040?ooo`800000>`3oool00`000000oooo0?oo
o`0S0?ooo`040000003oool0000000000080oooo0`000000103oool000000000003oool200000080
oooo00<000000?ooo`3oool0100000080?ooo`030000003oool0oooo008000001@3oool00`000000
oooo0?ooo`080?ooo`T000000`3oool5000000@0oooo0`00000;0?ooo`030000003oool0oooo0080
0000103oool;000001d0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0
7@3oool01@000000oooo0?ooo`000000oooo008000000`3oool2000000030?ooo`00000000000080
00000P3oool2000000030?ooo`00000000000080oooo1@0000020?ooo`8000000`3oool900000003
0?ooo`00000000000080oooo0P0000020?ooo`8000000P3oool4000000@0oooo0P0000050?ooo`80
00001P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02@0oooo100000020?ooo`<0
000000H0oooo00000000000000000?ooo`0000020?ooo`030000003oool0oooo00@00000203oool2
00000080oooo00<000000?ooo`3oool00`3oool2000000`0oooo2`0000040?ooo`8000003P3oool0
0`000000oooo00000002000000<0oooo1@0000000`3oool0000000000003000001h0oooo00<00000
0?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool07P3oool01@000000oooo000000000000
oooo00800000103oool3000000040?ooo`000000000000000080oooo0P0000000`3oool000000?oo
o`050?ooo`h0000000<0oooo0000000000000P3oool3000000030?ooo`000000000000@0000000<0
oooo000000000000103oool2000000D0oooo00<000000?ooo`3oool0103oool2000003h0oooo00<0
00000?ooo`3oool09P3oool300000080oooo00@000000?ooo`000000oooo0`0000001@3oool00000
0?ooo`3oool0000000<0oooo0`0000090?ooo`030000003oool0oooo008000001@3oool2000001D0
oooo1000000>0?ooo`80000000@0oooo0000000000000000103oool;000001h0oooo00<000000?oo
o`3oool02@3oool004@0oooo00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`000000oooo
00<00000103oool300000080oooo200000040?oooa00000000<0oooo0000000000001P0000030?oo
o`@00000103oool2000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo02L0oooo0`0000020?ooo`030000003oool0000000@0000000D0oooo0000
00000000oooo000000030?ooo`@00000203oool00`000000oooo0?ooo`02000000H0oooo00<00000
0?ooo`3oool08P3oool2000000050?ooo`00000000000?ooo`000000103oool5000000030?ooo`00
0000000000<000007`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`0O
0?ooo`050000003oool000000000003oool00`0000030?ooo`030000003oool00000008000000`3o
ool<000000H0oooo2@000000103oool000000000000000050?ooo`80000000<0oooo0000003oool0
0`3oool00`000000oooo0?ooo`030?ooo`8000001@3oool200000440oooo00<000000?ooo`3oool0
:03oool4000000040?ooo`00000000000?ooo`@000000P3oool00`000000oooo000000030?ooo`@0
0000203oool200000080oooo0P0000050?ooo`800000803oool200000080oooo0P0000000`3oool0
00000?ooo`030?ooo`@0000000<0oooo0000000000001@00000O0?ooo`030000003oool0oooo00T0
oooo00140?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool00`0000000`3oool00000
000000030?ooo`040000003oool000000?ooo`8000000`3oool:000000030?ooo`000000000000<0
0000103oool7000000H0oooo0P0000000`3oool000000?ooo`030?ooo`030000003oool0oooo00<0
oooo0P0000040?ooo`800000@`3oool00`000000oooo0?ooo`0Z0?ooo`<000000P3oool00`000000
oooo00000004000000040?ooo`000000oooo000000<0oooo1@0000080?ooo`8000000P3oool00`00
0000oooo0?ooo`040?ooo`800000703oool2000000<0oooo0P0000000`3oool000000?ooo`030?oo
o`H0000000<0oooo0000000000000`00000P0?ooo`030000003oool0oooo00T0oooo00140?ooo`03
0000003oool0oooo0200oooo00D000000?ooo`00000000000?ooo`04000000<0oooo00<000000?oo
o`000000100000040?oooaD00000203oool4000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0:`3oool30000
0080oooo00<000000?ooo`3oool0100000000`3oool000000?ooo`02000000<0oooo100000090?oo
o`80000000<0oooo0000000000001P3oool4000001D0oooo0`0000040?ooo`040000003oool0oooo
000000@0oooo1@0000000`3oool000000000000500000200oooo00<000000?ooo`3oool02@3oool0
04@0oooo00<000000?ooo`3oool08@3oool01@000000oooo000000000000oooo00@000000P3oool0
0`000000oooo0?ooo`020?ooo`H000000P3oool3000000L0oooo1P0000090?ooo`80000000<0oooo
0000003oool00`3oool2000000@0oooo0P0000040?ooo`800000AP3oool00`000000oooo0?ooo`0/
0?ooo`<000000P3oool00`000000oooo0?ooo`04000000050?ooo`00000000000?ooo`0000000`3o
ool5000000T0oooo0P0000000`3oool00000000000080?ooo`H000003@3oool2000000H0oooo00@0
00000?ooo`00000000001@3oool4000000030?ooo`000000oooo00D000008@3oool00`000000oooo
0?ooo`090?ooo`00A03oool2000002<0oooo00<000000?ooo`0000000`3oool300000080oooo00<0
00000?ooo`3oool01@3oool8000000<0oooo1@00000<0?ooo`80000000<0oooo0000003oool00P3o
ool2000000D0oooo0P0000030?ooo`800000B03oool00`000000oooo0?ooo`0^0?ooo`<0000000<0
oooo0000000000000P3oool4000000040?ooo`000000oooo000000<0oooo1@00000:0?ooo`800000
00@0oooo00000000000000002`3oool6000000D0oooo0P0000060?ooo`80000000<0oooo0000003o
ool01@3oool5000000030?ooo`000000000000<0000000<0oooo0000003oool07P3oool3000000/0
oooo00140?ooo`030000003oool0oooo02<0oooo00<000000?ooo`0000000P3oool400000080oooo
00<000000?ooo`3oool01P3oool2000000<0oooo1@00000?0?ooo`@000000`3oool2000000@0oooo
0P0000030?ooo`800000BP3oool00`000000oooo0?ooo`0_0?ooo`<000000P3oool00`000000oooo
0?ooo`04000000040?ooo`000000oooo000000@0oooo1@00000:0?ooo`80000000<0oooo00000000
00000P00000>0?ooo`D000001`3oool2000000030?ooo`000000oooo00D0oooo0`0000000`3oool0
00000?ooo`0700000280oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0
903oool00`000000oooo000000020?ooo`060000003oool000000000003oool000002P3oool30000
01<0oooo00<000000?ooo`0000000`3oool3000000@0oooo0P0000020?ooo`800000C03oool00`00
0000oooo0?ooo`0`0?ooo`<000000P3oool00`000000oooo0?ooo`04000000030?ooo`0000000000
008000000`3oool5000000/0oooo0P0000000`3oool0000000000002000001L0oooo100000060?oo
o`D0000000<0oooo0000000000001@00000S0?ooo`030000003oool0oooo00T0oooo00140?ooo`03
0000003oool0oooo02D0oooo0`000000103oool000000?ooo`3oool2000000030?ooo`0000000000
01`0oooo0P000000103oool000000?ooo`3oool4000000<0oooo0P0000020?ooo`800000CP3oool0
0`000000oooo0?ooo`0b0?ooo`<0000000<0oooo0000000000000P3oool4000000040?ooo`000000
oooo000000<0oooo1P00000;0?ooo`80000000<0oooo0000000000000`00000A0?ooo`D000001`3o
ool8000000030?ooo`000000000000<000008`3oool00`000000oooo0?ooo`090?ooo`00A03oool0
0`000000oooo0?ooo`0V0?ooo`D000000P3oool3000000030?ooo`000000000001L0oooo0`000000
103oool000000000003oool4000000<0oooo0`0000000`3oool000000000001@0?ooo`030000003o
ool0oooo03<0oooo0`0000020?ooo`030000003oool0oooo00@0000000<0oooo0000003oool00P00
00030?ooo`H000002`3oool2000000030?ooo`000000000001<0000000<0oooo0000000000001`3o
ool4000000050?ooo`000000oooo0000003oool01@00000T0?ooo`030000003oool0oooo00T0oooo
00140?ooo`030000003oool0oooo02L0oooo1P0000000`3oool000000000000600000180oooo0`00
00020?ooo`060000003oool0oooo0000003oool000000`3oool3000000030?ooo`00000000000580
oooo00<000000?ooo`3oool0=03oool300000080oooo00@000000?ooo`3oool0oooo1P0000000`3o
ool000000?ooo`030?ooo`H000002`3oool2000000D0oooo400000080?ooo`<000000P3oool01000
0000oooo0000003oool6000002@0oooo00<000000?ooo`3oool02@3oool004@0oooo00<000000?oo
o`3oool0:03oool01@000000oooo000000000000oooo00<0000000<0oooo0000003oool01@00000=
0?ooo`@000000`3oool00`000000oooo0000000300000080oooo1P00001D0?ooo`030000003oool0
oooo03D0oooo100000000`3oool00000000000030?ooo`<0000000<0oooo0000000000000P000003
0?ooo`L000002`3oool;00000100oooo100000020?ooo`040000003oool000000?ooo`80000000@0
oooo00000000000000009@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?oo
o`0Y0?ooo`80000000@0oooo0000003oool0oooo0P0000000`3oool00000000000030?ooo`l00000
103oool600000080oooo1@00001G0?ooo`030000003oool0oooo03L0oooo0`0000020?ooo`040000
003oool0oooo0?ooo`@0000000@0oooo0000003oool00000103oool7000002<0oooo100000020?oo
o`040000003oool000000?ooo`80000000D0oooo000000000000oooo0000000U0?ooo`030000003o
ool0oooo00T0oooo00140?ooo`030000003oool0oooo02/0oooo1`0000020?ooo`030000003oool0
oooo00@0oooo0P0000040?ooo`<000000`3oool700000080oooo1000001J0?ooo`030000003oool0
oooo03P0oooo100000000`3oool000000?ooo`020?ooo`T00000103oool8000001d0oooo1P000000
0`3oool0000000000002000000030?ooo`00000000000080oooo0`00000V0?ooo`030000003oool0
oooo00T0oooo00140?ooo`030000003oool0oooo02d0oooo2P0000060?ooo`l0000000<0oooo0000
000000000`00001L0?ooo`030000003oool0oooo03T0oooo100000000`3oool00000000000030?oo
o`H0000000<0oooo0000003oool0103oool9000001P0oooo1`0000001@3oool000000?ooo`000000
oooo00<000000P3oool2000000030?ooo`000000oooo02D0oooo00<000000?ooo`3oool02@3oool0
04@0oooo00<000000?ooo`3oool0;`3ooolF000000030?ooo`000000000000L00000G`3oool00`00
0000oooo0?ooo`0k0?ooo`<000000P3oool010000000oooo0?ooo`3oool9000000D0oooo1@000000
0`3oool000000000000200000140oooo2P0000001@3oool000000?ooo`000000oooo00@0000000D0
oooo000000000000oooo0000000W0?ooo`030000003oool0oooo00T0oooo000d0?ooo`030=nLB000
0000000000<0000000<0B9cO0?ooo`3oool01`3oool00`000000oooo0?ooo`0a0?ooo`8000000`3o
oolF00000680oooo00<000000?ooo`3oool0?03oool01@000000oooo000000000000oooo00800000
0P3oool:000000D0oooo300000090?ooo`D0000000<0oooo0000000000000`0000001`3oool00000
0?ooo`000000oooo0000003oool0100000001@3oool000000000003oool0000002P0oooo00<00000
0?ooo`3oool02@3oool003D0oooo00<0okmd001d_`3oool00P3oool00`2oM7@0_ooo0?ooo`070?oo
o`030000003oool0oooo03<0oooo1@0000020?ooo`@0000000<0oooo0000000000001`00001V0?oo
o`030000003oool0oooo03d0oooo100000020?ooo`040000003oool0oooo0?ooo`L0000000@0oooo
0000000000000000103oool3000000040?ooo`00000000000?oooaH0000000D0oooo0000003oool0
00000?ooo`09000000030?ooo`000000oooo02P0oooo00<000000?ooo`3oool02@3oool003H0oooo
00<0okmd001d_`3oool02`3oool00`000000oooo0?ooo`0n0?ooo`@00000K03oool00`000000oooo
0?ooo`0o0?ooo`060000003oool000000000003oool00000103oool<000000<0oooo7P0000000`3o
ool0000000000007000000030?ooo`000000oooo02T0oooo00<000000?ooo`3oool02@3oool003L0
oooo00<0okmd001d_`3oool02P3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0400
oooo1`0000040?ooo`@0000000<0oooo0000000000001@00000<0?ooo`h000000P3oool00`000000
oooo0?ooo`09000000030?ooo`000000oooo02X0oooo00<000000?ooo`3oool02@3oool003P0oooo
00<0okmd04RLg`3oool02@3oool300000:h0oooo00<000000?ooo`3oool0@P3oool7000000@0oooo
100000000`3oool0000000000006000000/0oooo1`0000060?ooo`030000003oool0oooo00T00000
00<0oooo0000003oool0:@3oool3000000/0oooo000i0?ooo`030=nLB018W=l0oooo00P0oooo00<0
00000?ooo`3oool0[P3oool00`000000oooo0?ooo`140?ooo`030000003oool0000000@000001@3o
ool3000000030?ooo`00000000000080000000<0oooo0000000000000`0000030?oooa`0000000<0
oooo0000003oool0;03oool00`000000oooo0?ooo`090?ooo`00>P3oool00`2oM000M;oo0?ooo`07
0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0A@3oool2000000030?ooo`000000
000000<000001@3oool3000000<0oooo100000000`3oool0000000000009000000@0oooo1P000000
0`3oool0000000000007000000030?ooo`000000oooo02d0oooo00<000000?ooo`3oool02@3oool0
03X0oooo00<0omnL04P0M02oool01`3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo
04L0oooo2@0000050?ooo`@000000`3oool4000000H0oooo1P0000050?ooo`X0000000<0oooo0000
003oool0;P3oool00`000000oooo0?ooo`090?ooo`00>P3oool00`3ooml0W4P007Boo`070?ooo`03
0000003oool0oooo0:h0oooo00<000000?ooo`3oool0B@3oool6000000030?ooo`000000000000D0
oooo3`0000090?ooo`D0000000<0oooo0000000000000`0000000`3oool000000?ooo`0_0?ooo`03
0000003oool0oooo00T0oooo000j0?ooo`030?oo_`1d0000B9cO00L0oooo00<000000?ooo`3oool0
[P3oool00`000000oooo0?ooo`1;0?ooo`X00000103oool5000000D0oooo3`0000000`3oool00000
0000000600000340oooo00<000000?ooo`3oool02@3oool003H0oooo00L0okmd0018W03Oool0oooo
0=nLB00004P0W=oo00L0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1=0?ooo``0
0000103oool7000000@0oooo1`0000020?ooo`P00000<`3oool00`000000oooo0?ooo`090?ooo`00
=`3oool01@3ogi`0B000000000000000M;oo00P0oooo00<000000?ooo`3oool0[P3oool00`000000
oooo0?ooo`1@0?ooo`H000000P3oool6000000@0oooo1`0000000`3oool00000000000020?ooo`T0
0000=@3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2^0?ooo`030000
003oool0oooo05<0oooo1P0000030?ooo`P00000103oool2000000030?ooo`000000000000P00000
=`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2^0?ooo`030000003o
ool0oooo05H0oooo300000000`3oool000000000000;000000030?ooo`000000000003T0oooo00<0
00000?ooo`3oool02@3oool004@0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1J
0?oooa@0000000<0oooo000000000000>`3oool00`000000oooo0?ooo`090?ooo`00A03oool00`00
0000oooo0?ooo`2^0?ooo`030000003oool0oooo05d0oooo2@0000020?ooo`L00000?@3oool00`00
0000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0600
oooo200000140?ooo`030000003oool0oooo00T0oooo00140?ooo`030000003oool0oooo0:h0oooo
00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`090?ooo`00A03oool00`000000oooo0?oo
o`2^0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool02@3oool004@0oooo00<00000
0?ooo`3oool0[P3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo00T0oooo00140?oo
o`800000[`3oool00`000000oooo0?ooo`2Z0?ooo`<000002`3oool004@0oooo00<000000?ooo`3o
ool0[P3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo00T0oooo00140?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo03`0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo00T0oooo00140?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3o
ool004@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`00A03ooooo0000
068000002`3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00<L0oooo00T0oono07@000000000B9cO0?ooo`3ookl0M000
00000018W=l0503oool00`3o_g@0000000000002000000030018W03Oool0oooo0180oooo00D0_g@0
000000000000000004RLg`2]0?ooo`00a`3oool02P3ookl0M01809cOo`2oM00007Bo0?oo_`1d04P0
W=oo0;md0000M;lB0?ooo`030?noM0000000B9cO00<0oooo00<0omnL04P0B02Lgol04`3oool00`3o
oml0W4P004RLg`2^0?ooo`00bP3oool00`3ookl0M00007Boo`020?ooo`030?oo_`1d0000M;oo0140
oooo00<0okmd0000M02oool0103oool00`3OW4P007Bo0?ooo`0C0?ooo`030=nLB000B9`0gooo0:d0
oooo003;0?ooo`030=nLB000B9`0gooo0080oooo00<0gia80018W03Oool04@3oool0202oM000001d
0;ooo`3oool0oooO09a800000000B9cO503oool00`3ogi`0B01d0;ooo`2]0?ooo`00]03oool00`2o
M000000000000005000000030018W03Oool0oooo00<0oooo00`0omnL04P00000000004RL0=ooo`2o
M0000000001d_`3oool0okmd0000B02Lgol20?ooo`030?noM00004P0W=oo00<0oooo00P0_g@00000
000004P0W=oo0?ooo`3OW4P004RL0=ooo`80oooo00<0_g@000000000M;l00P3oool01P3ookl0M000
000000000000001d0;ooo`D0oooo00<0okmd0000000000001`0000002@1d_ol0oooo0?oOW0180000
00000000M02ookl0M00007Boo`020?ooo`0;0?oOW018000000000018W03Oool0_g@000000000M;l0
oooo0?oOW01800000P0000002@1d_ol0gia800000000B9`0gooo0?noM0000000001809cOo`020?oo
o`040;md00000000001809cOo`80oooo00D0okmd000000000000001809cOo`030?ooo`030=nLB000
B9`0gooo0080oooo00<0_g@000000000M;l0O@3oool00;D0oooo00@0oono07@00000B9`0gooo0`3o
ool00`2oM0000000001d_`030?ooo`0<0?oOW01804P0W=oo0?oOW018M;l0_g@0001d_`3o_i`0W=oo
0?oo_`1d0000B9cO0P3oool00`3ookl0M00004RLg`030?ooo`080=nLB000B9`0gooO09adW03Oool0
okmd0000M02oool20?ooo`080=nLB000B9`0gkmd07Boo`3oool0okmd0000M02oool90?ooo`040?oo
g`2LB00004RL0=ooo`<0oooo00/0oooO09a80000B9`0gooo0;md0000B9`0gooo0?oo_`1d07@0M7@0
04RLg`020?ooo`0T0?oOW01804P0W=oo0?oOW018M;l0_g@0001d_`3o_i`0W=oo0;md0000B9`0gooo
0?ooo`2oM000M7Ad0000M02ogi`0W;oo0?noM00004P0W=oO09adW03Oool0oooo0=nLB000B9`0gooO
09adW03Oool0omnL04P0B02Lgol0oooo0?oOW018000007Bo0P3oool00`3o_g@0001d0;ooo`020?oo
o`040=nLB000B9`0gkmd07Boog`0oooo002f0?ooo`030=nLB00004P0W=oo00@0oooo00d0oono07@0
0000B9`0gooo0?ooo`3ooml0W4P004RLg`3oool0okmd07AdM000B9`0gooo0080oooo00<0_g@00018
W03Oool00P3oool00`2oM00004RL0=ooo`020?ooo`030?noM00004P0W=oo0080oooo00<0oono07@0
0018W=l00P3oool00`3ogi`0B01809cOo`030?ooo`030;md001d_ol0oooo00T0oooo00<0okmd0000
B02Lgol01@3oool0103OW7@0W=oo0;md0000M;l20?ooo`0@0?oo_`1d000004RL0=ooo`3oool0oooO
09a80018W=l0oooo0?noM01dM7@004RL0=ooo`3oool0_g@0001d_`<0oooo00L0_g@00000001d_ol0
oooo0?oo_`1d0000M;oo00<0oooo00<0okmd0000B02Lgol00P3oool00`3OW4P004RL0=ooo`020?oo
o`070?oOW0180000B9cO0?ooo`3ookl0M00004RLg`020?ooo`030?oOW01804P0W=oo07d0oooo002f
0?ooo`030?oOW0180000M;oo00D0oooo00<0omnL04P00000M;l00P3oool01`2oM00004RL0=ooo`3o
ool0_g@00000B02Lgol00P3oool00`3OW4P0001d0;ooo`020?ooo`030=nLB00007@0_ooo0080oooo
00<0oono07@00018W=l00P3oool0203ooml0W4P00000M02oool0oooo0?oog`2LB000B9cO0P3oool0
0`3ookl0M000000000020000000307Boo`3oool0oooo00D0oooo00<0oono07@00018W=l01`3oool0
0`3OW4P004RL0=ooo`020?ooo`030?noM00007@0_ooo0080oooo00/0_g@00018W03Oool0oooo0;md
000004P0W=oo0?ooo`3o_g@0001d0;ooo`020?ooo`030?oo_`1d0000B9cO0080oooo00<0_g@0001d
_`3oool00P3oool00`3ookl0M00004RLg`020?ooo`030?noM00007@0_ooo00<0oooo00/0gia80000
M02oool0oooO09a8000007@0_ooo0?ooo`3ooml0W4P004RLg`1m0?ooo`00]P3oool00`3ookl0M000
001d_`060?ooo`0;0;md000004P0W=oo0?ooo`3o_g@0001d0;ooo`3oool0oono07@0001d_ol00P3o
ool00`3ogi`0B00007Boo`020?ooo`030?oOW0180000M;oo00<0oooo00<0_g@00018W03Oool00P3o
ool00`3OW4P004Q804Qd_`020?ooo`0;0;md0000M;l0oooo0?ooo`2oM00004RL0=ooo`3oool0omnL
04P00018W=l01P3oool00`3ooml0W4P0001d_`020?ooo`030?oo_`2LW=l0oooo0080oooo00<0omnL
04P0001d_ol00P3oool00`3ookl0M00007Boo`020?ooo`0;0?noM00007@0_ooo0?ooo`3ookl0M000
07Boo`3oool0oono07@0001d_ol00`3oool01`2oM00004RL0=ooo`3oool0gia80018W03Oool00`3o
ool01`2oM00004RL0=ooo`3oool0oono07@0001d_ol00`3oool01`3ogi`0B01809cOo`3oool0gia8
0018B018M;l00P3oool00`2oM00007Bo0?ooo`1l0?ooo`00]`3oool00`2oM00004RL0=ooo`050?oo
o`070?noM0000000B9cO0?oOg`3Ookl0M00007Boo`020?ooo`070;md0000M;l0oooo0?ooo`3ooml0
W4P004RLg`020?ooo`030?oog`2LB000B9cO00<0oooo00<0gia80000B02Lgol00P3oool02`3o_g@0
001d0;noM018W=l0oooo0?noM00007@0_ooo0?ooo`2oM00007Bo00<0oooo00<0gia80000M02oool0
1P3oool01P3OW4P0001d0;ooo`3oool0omnL04Qd_`@0oooo00`0_g@00000M02oool0oooo0?oog`2L
B000B9cO0?ooo`3ogml0gono07@0001d_ol20?ooo`070;md0000M;l0oooo0?ooo`3o_g@0001d0;oo
o`020?ooo`070=nLB00007@0_ooo0?ooo`3ogi`0B01809cOo`030?ooo`030=nLB00004P0W=oo0080
oooo00<0gia80000M02oool00P3oool0303ookl0M00007Boo`3oool0okmd0000M02o_g@0B9cO0?oo
o`3o_g@0001d0;ooog`0oooo002g0?ooo`030?noM00004P0W=oo00D0oooo00L0omnL04P00000M;l0
omnL04Qd_`2oM00007Bo0080oooo00<0okmd0018W03Oool00P3oool00`2oM00004RL0=ooo`020?oo
o`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l00P3oool0303ooml0W4P007Boo`3OW4P0
07Bo0?oOW01804P0W=oo0?ooo`3ogi`0B00004RLg`80oooo00<0gia80000M02oool01P3oool00`3o
_g@0000000000002000000030000M02oool0oooo0080oooo00`0oooO09a80000B9`0gooo0?oo_`2L
B4P004RL0=ooo`3ogi`0B7Bo0;md0000M;l20?ooo`030?noM000B9`0gooo0080oooo00/0gia80000
M02oool0oooo0;md000004P0W=oo0?ooo`3ooml0W4P004RLg`030?ooo`030?oOW0180000B9cO00<0
oooo0100_g@00000M02oool0oooo0?noM00007@0_ooo0?ooo`3ooml0W4P007Boo`3OW4P007Bo0?oO
W01804P0W=ooO03oool00;L0oooo00<0omnL04P0001d_ol01@3oool01`3ogi`0B000001d_`3oool0
okmd00000000M;l00P3oool01@3ogi`0B01809cOo`3ookl0M00000<0000000<0M;no07@000000000
0P0000003`1d_ol0okmd00000000000004RL0=ooo`3ookl0M00000000018W=l0oooo0?noM0000000
001809cOo`020?ooo`030?oo_`1d0000000000@0000000<0B9cO0?ooo`3oool00`3oool00`3ookl0
M00007Boo`020?ooo`030;mdB02Lgol0oooo00@0oooo00X0gia80000000007@0_kmd0000M02oool0
oooo0?noM000000007Bo0P3oool00`3ogi`0B01809cOo`030?ooo`080?oOW0180000000004RLW01d
0000B9cO0?oo_`1d00030000000607Boo`3o_g@0000000000000B9`0gooo0`3oool03`3o_g@00000
000000000000M;oo0?ooo`3ookl0M00000000018W=l0oooo0?noM0000000001809cOo`1l0?ooo`00
]`3oool00`3ooml0W4P0001d_`050?ooo`030?noM0000000B9cO00/0oooo00<0okmd0000B02Lgol0
0P3oool00`3o_g@0001809cOo`0O0?ooo`060;md0000M;l0oooo0?ooo`3ogi`0M9cO7`3oool00`3o
_g@0001d0;ooo`2D0?ooo`00^03oool00`2oM00004RL0=ooo`030?ooo`040?oog`2LB000001d0;oo
o`/0oooo00<0oooO09a80000M;l00P3oool00`3ooml0W4P0001d_`0O0?ooo`030=nLB00007@0_ooo
00@0oooo00<0gibL0;ooo`3oool0703oool00`3OW7@0W=oo0?ooo`2C0?ooo`00^03oool00`3OW4P0
001809cOo`020?ooo`040?oo_`1d0000000007Boo`d0oooo00<0okmd0000M02oool00P3oool00`3o
_g@0001d0;ooo`020?ooo`040?oo_`1d000004RL0=oooaP0oooo00<0okmd0000B02Lgol00`3oool0
0`3ookl0M01809cOo`0R0?ooo`040?oo_`1d000004RL0=ooohd0oooo002g0?ooo`030;md00000000
000000@0000000<004RL0=ooo`3oool03P3oool02P3OW4P004RL0=oog`2LB000B9cO0=nLB000B9`0
gooO09a80018W=lJ0?ooo`030;md00000000000000H0000000<0M;oo0?ooo`3oool0/@3oool00=00
oooo00T0gia80000000004P0W=oo0?ooo`3OW4P000000000B02Lgol0e`3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-3.86195, -3.02156, 0.0236202, \
0.019667}}]
}, Closed]],

Cell[TextData[{
  "This system does not appear to approach a periodic trajectory.  Again, we \
use the Poincar\[EAcute] map to search for underlying periodicities but this \
time we obtain a fractal structure, described as a ",
  StyleBox["strange attractor",
    FontSlant->"Italic"],
  ",",
  " instead of a closed curve.  The phase point jumps around unpredictably on \
this fractal from one period of the driving force to the next.  Thus, the \
behavior of this system is truly chaotic.  We suppressed the first ",
  Cell[BoxData[
      \(TraditionalForm\`t\_min = 10\^3\)]],
  " time steps to permit transients to decay.  Although the detailed shape of \
the strange attractor depends upon the value of ",
  Cell[BoxData[
      \(TraditionalForm\`t\_min\)]],
  ", the observation that it is not a simple closed curve does not."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[sol];\)\), "\[IndentingNewLine]", 
    \(\(sol[
          t_] = \(duffingSol[\(-1\), 0.5, 0.1, 1, 0.5, 0, 0.2, 10\^5, 
            MaxSteps \[Rule] 10\^7]\)[t];\)\), "\[IndentingNewLine]", 
    \(\(pts = 
        poincare[sol[t], 0.5, 1000, 10\^5];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[pts, Frame \[Rule] True, 
        FrameLabel \[Rule] {\*"\"\<\!\(x\_k\)\>\"", \*"\"\<\!\(x\_k\%\[Prime]\
\)\>\""}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.836628 0.308735 0.319531 0.141477 [
[.06479 -0.0125 -13.8438 -15.6875 ]
[.06479 -0.0125 13.8438 0 ]
[.21916 -0.0125 -9.34375 -15.6875 ]
[.21916 -0.0125 9.34375 0 ]
[.37353 -0.0125 -13.8438 -15.6875 ]
[.37353 -0.0125 13.8438 0 ]
[.52789 -0.0125 -9.34375 -15.6875 ]
[.52789 -0.0125 9.34375 0 ]
[.68226 -0.0125 -13.8438 -15.6875 ]
[.68226 -0.0125 13.8438 0 ]
[.83663 -0.0125 -5 -15.6875 ]
[.83663 -0.0125 5 0 ]
[.991 -0.0125 -9.5 -15.6875 ]
[.991 -0.0125 9.5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -7.125 -31.375 ]
[.5 -0.0125 7.125 -15.6875 ]
[-0.0125 .03658 -18.6875 -7.84375 ]
[-0.0125 .03658 0 7.84375 ]
[-0.0125 .17805 -18.6875 -7.84375 ]
[-0.0125 .17805 0 7.84375 ]
[-0.0125 .31953 -10 -7.84375 ]
[-0.0125 .31953 0 7.84375 ]
[-0.0125 .46101 -10 -7.84375 ]
[-0.0125 .46101 0 7.84375 ]
[-0.0125 .60249 -10 -7.84375 ]
[-0.0125 .60249 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.375 -7.125 ]
[-0.01875 .30902 -18.6875 7.125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06479 0 m
.06479 .00625 L
s
gsave
.06479 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.21916 0 m
.21916 .00625 L
s
gsave
.21916 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.37353 0 m
.37353 .00625 L
s
gsave
.37353 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.52789 0 m
.52789 .00625 L
s
gsave
.52789 -0.0125 -70.3438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.68226 0 m
.68226 .00625 L
s
gsave
.68226 -0.0125 -74.8438 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.83663 0 m
.83663 .00625 L
s
gsave
.83663 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.991 0 m
.991 .00625 L
s
gsave
.991 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.09566 0 m
.09566 .00375 L
s
.12654 0 m
.12654 .00375 L
s
.15741 0 m
.15741 .00375 L
s
.18828 0 m
.18828 .00375 L
s
.25003 0 m
.25003 .00375 L
s
.2809 0 m
.2809 .00375 L
s
.31178 0 m
.31178 .00375 L
s
.34265 0 m
.34265 .00375 L
s
.4044 0 m
.4044 .00375 L
s
.43527 0 m
.43527 .00375 L
s
.46615 0 m
.46615 .00375 L
s
.49702 0 m
.49702 .00375 L
s
.55877 0 m
.55877 .00375 L
s
.58964 0 m
.58964 .00375 L
s
.62051 0 m
.62051 .00375 L
s
.65139 0 m
.65139 .00375 L
s
.71313 0 m
.71313 .00375 L
s
.74401 0 m
.74401 .00375 L
s
.77488 0 m
.77488 .00375 L
s
.80575 0 m
.80575 .00375 L
s
.8675 0 m
.8675 .00375 L
s
.89838 0 m
.89838 .00375 L
s
.92925 0 m
.92925 .00375 L
s
.96012 0 m
.96012 .00375 L
s
.03392 0 m
.03392 .00375 L
s
.00304 0 m
.00304 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -68.125 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 17.688 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
73.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .03658 m
.00625 .03658 L
s
gsave
-0.0125 .03658 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .17805 m
.00625 .17805 L
s
gsave
-0.0125 .17805 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .31953 m
.00625 .31953 L
s
gsave
-0.0125 .31953 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .46101 m
.00625 .46101 L
s
gsave
-0.0125 .46101 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .60249 m
.00625 .60249 L
s
gsave
-0.0125 .60249 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .06487 m
.00375 .06487 L
s
0 .09317 m
.00375 .09317 L
s
0 .12146 m
.00375 .12146 L
s
0 .14976 m
.00375 .14976 L
s
0 .20635 m
.00375 .20635 L
s
0 .23464 m
.00375 .23464 L
s
0 .26294 m
.00375 .26294 L
s
0 .29124 m
.00375 .29124 L
s
0 .34783 m
.00375 .34783 L
s
0 .37612 m
.00375 .37612 L
s
0 .40442 m
.00375 .40442 L
s
0 .43271 m
.00375 .43271 L
s
0 .4893 m
.00375 .4893 L
s
0 .5176 m
.00375 .5176 L
s
0 .54589 m
.00375 .54589 L
s
0 .57419 m
.00375 .57419 L
s
0 .00828 m
.00375 .00828 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -94.6563 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.125 11.8438 translate
90 rotate
-68.125 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 18.625 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
68.563 11.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\242) show
73.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.06479 .61178 m
.06479 .61803 L
s
.21916 .61178 m
.21916 .61803 L
s
.37353 .61178 m
.37353 .61803 L
s
.52789 .61178 m
.52789 .61803 L
s
.68226 .61178 m
.68226 .61803 L
s
.83663 .61178 m
.83663 .61803 L
s
.991 .61178 m
.991 .61803 L
s
.125 Mabswid
.09566 .61428 m
.09566 .61803 L
s
.12654 .61428 m
.12654 .61803 L
s
.15741 .61428 m
.15741 .61803 L
s
.18828 .61428 m
.18828 .61803 L
s
.25003 .61428 m
.25003 .61803 L
s
.2809 .61428 m
.2809 .61803 L
s
.31178 .61428 m
.31178 .61803 L
s
.34265 .61428 m
.34265 .61803 L
s
.4044 .61428 m
.4044 .61803 L
s
.43527 .61428 m
.43527 .61803 L
s
.46615 .61428 m
.46615 .61803 L
s
.49702 .61428 m
.49702 .61803 L
s
.55877 .61428 m
.55877 .61803 L
s
.58964 .61428 m
.58964 .61803 L
s
.62051 .61428 m
.62051 .61803 L
s
.65139 .61428 m
.65139 .61803 L
s
.71313 .61428 m
.71313 .61803 L
s
.74401 .61428 m
.74401 .61803 L
s
.77488 .61428 m
.77488 .61803 L
s
.80575 .61428 m
.80575 .61803 L
s
.8675 .61428 m
.8675 .61803 L
s
.89838 .61428 m
.89838 .61803 L
s
.92925 .61428 m
.92925 .61803 L
s
.96012 .61428 m
.96012 .61803 L
s
.03392 .61428 m
.03392 .61803 L
s
.00304 .61428 m
.00304 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03658 m
1 .03658 L
s
.99375 .17805 m
1 .17805 L
s
.99375 .31953 m
1 .31953 L
s
.99375 .46101 m
1 .46101 L
s
.99375 .60249 m
1 .60249 L
s
.125 Mabswid
.99625 .06487 m
1 .06487 L
s
.99625 .09317 m
1 .09317 L
s
.99625 .12146 m
1 .12146 L
s
.99625 .14976 m
1 .14976 L
s
.99625 .20635 m
1 .20635 L
s
.99625 .23464 m
1 .23464 L
s
.99625 .26294 m
1 .26294 L
s
.99625 .29124 m
1 .29124 L
s
.99625 .34783 m
1 .34783 L
s
.99625 .37612 m
1 .37612 L
s
.99625 .40442 m
1 .40442 L
s
.99625 .43271 m
1 .43271 L
s
.99625 .4893 m
1 .4893 L
s
.99625 .5176 m
1 .5176 L
s
.99625 .54589 m
1 .54589 L
s
.99625 .57419 m
1 .57419 L
s
.99625 .00828 m
1 .00828 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .31953 m
1 .31953 L
s
.83663 0 m
.83663 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.4841 .27469 Mdot
.22703 .5351 Mdot
.58958 .42074 Mdot
.4777 .29285 Mdot
.40329 .49013 Mdot
.49021 .26905 Mdot
.09413 .45077 Mdot
.47865 .42783 Mdot
.49053 .30735 Mdot
.40479 .4889 Mdot
.48959 .26926 Mdot
.10232 .46282 Mdot
.51791 .35412 Mdot
.46658 .43283 Mdot
.48956 .30187 Mdot
.38635 .49987 Mdot
.49777 .26899 Mdot
.05855 .29554 Mdot
.05058 .2025 Mdot
.09823 .48939 Mdot
.45349 .03369 Mdot
.19014 .55851 Mdot
.53037 .3397 Mdot
.40792 .48602 Mdot
.48837 .2699 Mdot
.12233 .4859 Mdot
.57581 .38765 Mdot
.49301 .36983 Mdot
.49436 .38008 Mdot
.49681 .36703 Mdot
.49203 .38744 Mdot
.49788 .35603 Mdot
.48447 .40578 Mdot
.49659 .33138 Mdot
.45375 .44876 Mdot
.4855 .28854 Mdot
.33609 .52202 Mdot
.53374 .28396 Mdot
.34997 .05045 Mdot
.11675 .52141 Mdot
.21665 .03692 Mdot
.15015 .53441 Mdot
.48804 .41532 Mdot
.49418 .32152 Mdot
.43708 .46473 Mdot
.48372 .27816 Mdot
.2667 .53609 Mdot
.59134 .34914 Mdot
.37809 .50281 Mdot
.50148 .26985 Mdot
.07139 .22789 Mdot
.03416 .3571 Mdot
.07421 .46145 Mdot
.04894 .20857 Mdot
.09731 .48866 Mdot
.41784 .02724 Mdot
.18856 .55669 Mdot
.53901 .33869 Mdot
.38287 .50093 Mdot
.49918 .26932 Mdot
.06143 .27019 Mdot
.03394 .27261 Mdot
.08859 .47889 Mdot
.21524 .03732 Mdot
.14982 .53418 Mdot
.48684 .41706 Mdot
.49371 .31942 Mdot
.43283 .46836 Mdot
.48381 .27625 Mdot
.24675 .53649 Mdot
.59766 .38096 Mdot
.49044 .38004 Mdot
.49736 .36456 Mdot
.49054 .39169 Mdot
.49802 .35 Mdot
.47879 .41614 Mdot
.49424 .31911 Mdot
.43053 .47023 Mdot
.48396 .27534 Mdot
.23566 .53594 Mdot
.59547 .40216 Mdot
.48976 .32526 Mdot
.45501 .44772 Mdot
.48568 .28932 Mdot
.34002 .52066 Mdot
.53038 .28193 Mdot
.34165 .05023 Mdot
.11597 .52055 Mdot
.21384 .03788 Mdot
.14938 .53391 Mdot
.48395 .42112 Mdot
.49254 .31468 Mdot
.42262 .47646 Mdot
.48491 .27268 Mdot
.19504 .52857 Mdot
.51497 .50804 Mdot
.53592 .27961 Mdot
.59654 .10459 Mdot
.088 .50164 Mdot
.03609 .36065 Mdot
.07003 .45578 Mdot
.03603 .2619 Mdot
.08978 .48055 Mdot
.23134 .03234 Mdot
.15416 .53694 Mdot
.50325 .3891 Mdot
.49707 .3591 Mdot
.48726 .39991 Mdot
.4975 .33889 Mdot
.46526 .43554 Mdot
.48874 .29944 Mdot
.379 .50379 Mdot
.5019 .26974 Mdot
.07614 .21416 Mdot
.03755 .37748 Mdot
.06874 .45337 Mdot
.03467 .27165 Mdot
.0884 .47905 Mdot
.20308 .04179 Mdot
.14646 .53195 Mdot
.46359 .44532 Mdot
.48556 .29117 Mdot
.35244 .51598 Mdot
.52028 .27652 Mdot
.27279 .05506 Mdot
.10661 .5107 Mdot
.15119 .06932 Mdot
.13133 .52088 Mdot
.05777 .30003 Mdot
.051 .20136 Mdot
.0984 .48959 Mdot
.45791 .0346 Mdot
.19018 .55869 Mdot
.52898 .34044 Mdot
.41393 .48193 Mdot
.48668 .27093 Mdot
.15363 .51026 Mdot
.3382 .59178 Mdot
.13718 .11974 Mdot
.07322 .4681 Mdot
.03224 .30705 Mdot
.08283 .4728 Mdot
.11336 .10107 Mdot
.11972 .51102 Mdot
.95001 .21289 Mdot
.06059 .34895 Mdot
.25511 .02651 Mdot
.16049 .5407 Mdot
.51556 .36073 Mdot
.478 .41619 Mdot
.49425 .31892 Mdot
.42997 .47068 Mdot
.484 .27513 Mdot
.23291 .53571 Mdot
.59405 .40788 Mdot
.48638 .31393 Mdot
.43865 .46362 Mdot
.48369 .27876 Mdot
.27274 .53563 Mdot
.58769 .34087 Mdot
.30272 .53018 Mdot
.56201 .30626 Mdot
.11989 .13899 Mdot
.06387 .45216 Mdot
.03612 .36251 Mdot
.0701 .45582 Mdot
.03626 .26047 Mdot
.08998 .48077 Mdot
.23566 .03117 Mdot
.15529 .53764 Mdot
.50609 .38312 Mdot
.49581 .36945 Mdot
.49342 .38301 Mdot
.49738 .36255 Mdot
.48936 .39482 Mdot
.49794 .34568 Mdot
.47401 .42364 Mdot
.49217 .31099 Mdot
.41182 .48421 Mdot
.48734 .27022 Mdot
.1375 .49914 Mdot
.48433 .52447 Mdot
.56868 .30786 Mdot
.14553 .11296 Mdot
.07449 .47026 Mdot
.03242 .3004 Mdot
.08396 .47411 Mdot
.12793 .08727 Mdot
.12426 .51502 Mdot
.81429 .18421 Mdot
.16547 .05334 Mdot
.13842 .52453 Mdot
.44073 .46646 Mdot
.48288 .27691 Mdot
.26265 .53632 Mdot
.59342 .35502 Mdot
.41748 .47827 Mdot
.48583 .27221 Mdot
.17898 .52297 Mdot
.43334 .55791 Mdot
.47361 .53702 Mdot
.60009 .37383 Mdot
.48276 .40227 Mdot
.49727 .33471 Mdot
.45874 .44328 Mdot
.48671 .2928 Mdot
.35495 .51494 Mdot
.51833 .2756 Mdot
.25286 .05908 Mdot
.10303 .50684 Mdot
.12586 .08919 Mdot
.12359 .51447 Mdot
.86566 .2013 Mdot
.55905 .05661 Mdot
.1887 .56216 Mdot
.47371 .43422 Mdot
.48857 .30098 Mdot
.387 .49954 Mdot
.49744 .26895 Mdot
.05815 .30237 Mdot
.05917 .18111 Mdot
.10164 .49305 Mdot
.54723 .05742 Mdot
.18155 .5599 Mdot
.33887 .52294 Mdot
.534 .28394 Mdot
.35762 .05078 Mdot
.11742 .52216 Mdot
.21835 .03636 Mdot
.15061 .53471 Mdot
.49026 .41199 Mdot
.49503 .32567 Mdot
.44497 .45756 Mdot
.48412 .28242 Mdot
.3011 .53148 Mdot
.56508 .30929 Mdot
.08745 .18857 Mdot
.04522 .40742 Mdot
.05796 .43392 Mdot
.03603 .36253 Mdot
.07033 .45614 Mdot
.03669 .2578 Mdot
.09035 .48117 Mdot
.2438 .02915 Mdot
.1574 .53893 Mdot
.51037 .37331 Mdot
.49111 .38817 Mdot
.49798 .35465 Mdot
.48324 .40818 Mdot
.49612 .32843 Mdot
.44868 .45395 Mdot
.48459 .28482 Mdot
.31628 .52796 Mdot
.55138 .29663 Mdot
.25967 .05762 Mdot
.10412 .50805 Mdot
.1327 .08329 Mdot
.1257 .51627 Mdot
.67192 .13124 Mdot
.05058 .44418 Mdot
.06758 .4493 Mdot
.03579 .26339 Mdot
.08958 .48032 Mdot
.22739 .03347 Mdot
.15311 .53628 Mdot
.5002 .39509 Mdot
.49741 .34947 Mdot
.47876 .41624 Mdot
.49421 .31901 Mdot
.43032 .4704 Mdot
.48397 .27527 Mdot
.23465 .53586 Mdot
.59499 .40424 Mdot
.48861 .321 Mdot
.44908 .45383 Mdot
.48457 .28489 Mdot
.31696 .52778 Mdot
.55076 .29612 Mdot
.26661 .05623 Mdot
.10537 .50941 Mdot
.14154 .07628 Mdot
.12841 .51852 Mdot
.27356 .05452 Mdot
.10777 .51173 Mdot
.16483 .06059 Mdot
.1354 .52404 Mdot
.19406 .52938 Mdot
.50031 .5188 Mdot
.56354 .30225 Mdot
.26459 .05664 Mdot
.10495 .50896 Mdot
.13823 .07883 Mdot
.1274 .51769 Mdot
.42503 .05804 Mdot
.12116 .52699 Mdot
.19816 .04388 Mdot
.14501 .53099 Mdot
.44776 .46047 Mdot
.48306 .28035 Mdot
.29283 .53303 Mdot
.57231 .31739 Mdot
.06064 .35441 Mdot
.26148 .02534 Mdot
.16206 .54162 Mdot
.51758 .35607 Mdot
.47008 .42814 Mdot
.4909 .30636 Mdot
.3994 .49228 Mdot
.49164 .26886 Mdot
.08 .42431 Mdot
.74999 .16065 Mdot
.02679 .27837 Mdot
.08669 .47171 Mdot
.30392 .02059 Mdot
.17158 .547 Mdot
.52867 .34045 Mdot
.4146 .48146 Mdot
.48652 .27106 Mdot
.15716 .51235 Mdot
.33429 .59296 Mdot
.89687 .21008 Mdot
.88074 .17193 Mdot
.24441 .0231 Mdot
.16299 .54043 Mdot
.52931 .33996 Mdot
.41129 .48376 Mdot
.48738 .27043 Mdot
.1396 .50075 Mdot
.45826 .5412 Mdot
.60007 .37532 Mdot
.48493 .39716 Mdot
.4979 .34118 Mdot
.46812 .43186 Mdot
.48978 .30284 Mdot
.38959 .49807 Mdot
.49611 .26881 Mdot
.0582 .33086 Mdot
.12761 .08717 Mdot
.12429 .51495 Mdot
.78879 .17504 Mdot
.07488 .13951 Mdot
.10699 .496 Mdot
.8319 .15842 Mdot
.05015 .1853 Mdot
.09739 .48462 Mdot
.60172 .07449 Mdot
.16486 .55628 Mdot
.78569 .14094 Mdot
.02818 .37286 Mdot
.07915 .46274 Mdot
.13889 .0782 Mdot
.12764 .51786 Mdot
.37325 .05143 Mdot
.11961 .52427 Mdot
.23431 .0316 Mdot
.15487 .5374 Mdot
.50485 .38579 Mdot
.4965 .36474 Mdot
.49098 .39061 Mdot
.49801 .35154 Mdot
.48035 .41347 Mdot
.49492 .32216 Mdot
.43683 .46493 Mdot
.48372 .27805 Mdot
.26565 .53615 Mdot
.59191 .35063 Mdot
.38917 .49675 Mdot
.49558 .26904 Mdot
.05972 .34904 Mdot
.21411 .03749 Mdot
.1497 .53403 Mdot
.48751 .41608 Mdot
.49397 .32059 Mdot
.43522 .46634 Mdot
.48373 .27729 Mdot
.2581 .53648 Mdot
.59532 .36194 Mdot
.45057 .44916 Mdot
.48573 .28824 Mdot
.33247 .52322 Mdot
.53687 .28596 Mdot
.35054 .05048 Mdot
.11679 .52145 Mdot
.21658 .03694 Mdot
.15013 .53439 Mdot
.48794 .41547 Mdot
.49414 .32134 Mdot
.43672 .46505 Mdot
.48372 .27798 Mdot
.26504 .53619 Mdot
.59223 .35151 Mdot
.39532 .49311 Mdot
.49279 .26907 Mdot
.07337 .4079 Mdot
.86051 .16938 Mdot
.1559 .05855 Mdot
.13536 .52208 Mdot
.39631 .49704 Mdot
.49417 .26823 Mdot
.06121 .36003 Mdot
.28997 .02151 Mdot
.16874 .5454 Mdot
.5256 .34295 Mdot
.42954 .47018 Mdot
.48412 .27543 Mdot
.23486 .53588 Mdot
.5951 .40381 Mdot
.48886 .32187 Mdot
.45032 .4526 Mdot
.48476 .28575 Mdot
.32186 .52644 Mdot
.54633 .29263 Mdot
.30865 .05101 Mdot
.11197 .51635 Mdot
.18935 .04772 Mdot
.14253 .52926 Mdot
.41277 .48699 Mdot
.48764 .26915 Mdot
.12138 .48497 Mdot
.57457 .38082 Mdot
.48856 .38896 Mdot
.49817 .35238 Mdot
.48104 .41224 Mdot
.49522 .32359 Mdot
.43965 .46244 Mdot
.48377 .27945 Mdot
.27836 .53507 Mdot
.58381 .33371 Mdot
.21989 .5334 Mdot
.58326 .43382 Mdot
.47011 .2768 Mdot
.3663 .51024 Mdot
.51028 .27223 Mdot
.16045 .10086 Mdot
.08008 .47853 Mdot
.03631 .26056 Mdot
.08993 .48076 Mdot
.23359 .03172 Mdot
.15475 .53731 Mdot
.50478 .38592 Mdot
.49653 .36451 Mdot
.49084 .39098 Mdot
.49802 .35101 Mdot
.47983 .41438 Mdot
.49469 .32111 Mdot
.43471 .46675 Mdot
.48375 .27708 Mdot
.25579 .53653 Mdot
.5961 .36561 Mdot
.46329 .43434 Mdot
.48928 .30034 Mdot
.3806 .50296 Mdot
.50096 .26954 Mdot
.07024 .23159 Mdot
.03342 .35111 Mdot
.07559 .46335 Mdot
.05544 .19096 Mdot
.10004 .49157 Mdot
.49261 .04254 Mdot
.1891 .5598 Mdot
.51644 .35901 Mdot
.47521 .42064 Mdot
.49305 .31405 Mdot
.41901 .47912 Mdot
.48558 .27172 Mdot
.17596 .52172 Mdot
.41532 .56621 Mdot
.27817 .6026 Mdot
.06021 .18105 Mdot
.10168 .49357 Mdot
.52532 .05114 Mdot
.18554 .56017 Mdot
.48198 .42389 Mdot
.49172 .3116 Mdot
.41548 .48168 Mdot
.48638 .27091 Mdot
.15687 .51219 Mdot
.33424 .59295 Mdot
.89419 .20939 Mdot
.85446 .16191 Mdot
.09252 .11429 Mdot
.11324 .50237 Mdot
.94849 .21083 Mdot
.12246 .13679 Mdot
.0633 .45123 Mdot
.03673 .36613 Mdot
.06895 .45403 Mdot
.03454 .27266 Mdot
.08825 .47889 Mdot
.20016 .04296 Mdot
.14564 .53139 Mdot
.45572 .45316 Mdot
.48395 .2852 Mdot
.32401 .52583 Mdot
.54441 .29119 Mdot
.32259 .05037 Mdot
.11377 .51824 Mdot
.2013 .04258 Mdot
.14591 .53159 Mdot
.45758 .45137 Mdot
.48427 .28649 Mdot
.33089 .52374 Mdot
.53829 .28689 Mdot
.34855 .05041 Mdot
.1166 .52125 Mdot
.21587 .03718 Mdot
.14993 .53427 Mdot
.48695 .4169 Mdot
.49375 .31961 Mdot
.43322 .46803 Mdot
.4838 .27642 Mdot
.24865 .53653 Mdot
.59755 .3776 Mdot
.48733 .39081 Mdot
.49823 .34956 Mdot
.47815 .41717 Mdot
.49397 .31796 Mdot
.42804 .47223 Mdot
.48418 .27443 Mdot
.22326 .53462 Mdot
.58558 .42946 Mdot
.47233 .28159 Mdot
.37943 .50384 Mdot
.50182 .26969 Mdot
.07603 .21444 Mdot
.03748 .37711 Mdot
.06886 .45355 Mdot
.03482 .27046 Mdot
.08857 .47923 Mdot
.20644 .04049 Mdot
.1474 .53258 Mdot
.47137 .43683 Mdot
.48782 .29853 Mdot
.37929 .50366 Mdot
.50173 .2697 Mdot
.07506 .21709 Mdot
.03676 .37338 Mdot
.06995 .45524 Mdot
.03654 .25873 Mdot
.09022 .48103 Mdot
.24102 .02981 Mdot
.15669 .5385 Mdot
.50904 .37645 Mdot
.49304 .3819 Mdot
.49728 .36377 Mdot
.49013 .39283 Mdot
.49801 .34842 Mdot
.47711 .41888 Mdot
.49351 .31607 Mdot
.42387 .47549 Mdot
.48471 .27306 Mdot
.20177 .53042 Mdot
.53968 .4873 Mdot
.49338 .25841 Mdot
.16456 .09787 Mdot
.08151 .48053 Mdot
.03822 .24972 Mdot
.09144 .4824 Mdot
.26735 .02454 Mdot
.16327 .54238 Mdot
.51871 .35364 Mdot
.46501 .43481 Mdot
.489 .30005 Mdot
.3806 .50296 Mdot
.50096 .26954 Mdot
.07025 .23156 Mdot
.03342 .35117 Mdot
.07558 .46333 Mdot
.05537 .19113 Mdot
.10001 .49154 Mdot
.49185 .04236 Mdot
.18915 .55979 Mdot
.51677 .35823 Mdot
.47391 .42262 Mdot
.49249 .31196 Mdot
.41399 .48271 Mdot
.48675 .27062 Mdot
.14902 .50736 Mdot
.35994 .58539 Mdot
.52451 .34575 Mdot
.43991 .4613 Mdot
.48397 .28016 Mdot
.283 .5345 Mdot
.58033 .32815 Mdot
.15128 .50817 Mdot
.34291 .59049 Mdot
.24985 .53787 Mdot
.59771 .38048 Mdot
.49008 .3815 Mdot
.49759 .36247 Mdot
.48922 .39516 Mdot
.49792 .34522 Mdot
.47347 .42444 Mdot
.49193 .31016 Mdot
.40973 .48563 Mdot
.48795 .26988 Mdot
.12663 .48997 Mdot
.57239 .42288 Mdot
.48075 .29753 Mdot
.40806 .48699 Mdot
.48853 .26957 Mdot
.11672 .48017 Mdot
.56198 .35422 Mdot
.42512 .47295 Mdot
.48461 .27424 Mdot
.21642 .53356 Mdot
.57562 .44635 Mdot
.46622 .26572 Mdot
.31615 .52818 Mdot
.5518 .29695 Mdot
.2555 .05854 Mdot
.10334 .50721 Mdot
.12736 .08786 Mdot
.12406 .51487 Mdot
.83507 .19139 Mdot
.29024 .01656 Mdot
.17474 .54687 Mdot
.5497 .34317 Mdot
.38466 .49981 Mdot
.49813 .26919 Mdot
.05878 .2925 Mdot
.04743 .2117 Mdot
.09686 .48792 Mdot
.41657 .02704 Mdot
.18846 .55661 Mdot
.53922 .33872 Mdot
.38256 .5011 Mdot
.49935 .26935 Mdot
.062 .2667 Mdot
.03299 .28104 Mdot
.08744 .47763 Mdot
.19256 .04619 Mdot
.14349 .52991 Mdot
.42935 .47542 Mdot
.4838 .2727 Mdot
.20785 .53188 Mdot
.55729 .46957 Mdot
.47284 .25558 Mdot
.12172 .48541 Mdot
.57489 .38228 Mdot
.48983 .38474 Mdot
.49792 .35825 Mdot
.48618 .40222 Mdot
.49719 .33589 Mdot
.46089 .44083 Mdot
.48732 .29483 Mdot
.36287 .51154 Mdot
.51246 .27309 Mdot
.18562 .08476 Mdot
.08762 .4887 Mdot
.05111 .20253 Mdot
.09822 .48968 Mdot
.4409 .03122 Mdot
.18983 .55793 Mdot
.53399 .33861 Mdot
.39465 .49434 Mdot
.49338 .26888 Mdot
.06834 .39239 Mdot
.6413 .08784 Mdot
.14557 .54893 Mdot
.25367 .02711 Mdot
.15979 .54039 Mdot
.51394 .36465 Mdot
.48319 .40688 Mdot
.4964 .32984 Mdot
.45103 .45157 Mdot
.48497 .28648 Mdot
.32561 .52535 Mdot
.54296 .29014 Mdot
.33119 .05021 Mdot
.11479 .5193 Mdot
.2073 .04024 Mdot
.14758 .53272 Mdot
.47213 .43597 Mdot
.48807 .29933 Mdot
.38186 .50232 Mdot
.50025 .26939 Mdot
.06652 .24512 Mdot
.0316 .32709 Mdot
.08037 .46947 Mdot
.0908 .12754 Mdot
.11248 .50426 Mdot
.8261 .15621 Mdot
.04002 .21276 Mdot
.09322 .47942 Mdot
.49249 .0425 Mdot
.18913 .55981 Mdot
.51656 .35873 Mdot
.47475 .42135 Mdot
.49285 .31329 Mdot
.41722 .48042 Mdot
.48597 .2713 Mdot
.16635 .51729 Mdot
.36105 .58615 Mdot
.51263 .3693 Mdot
.48776 .397 Mdot
.49782 .34246 Mdot
.47 .42934 Mdot
.49051 .30525 Mdot
.39661 .49398 Mdot
.49282 .26876 Mdot
.07082 .40047 Mdot
.75485 .12918 Mdot
.0519 .45069 Mdot
.06881 .45061 Mdot
.03947 .24314 Mdot
.09239 .48336 Mdot
.29126 .02156 Mdot
.16881 .54549 Mdot
.52527 .34329 Mdot
.43121 .46882 Mdot
.48401 .27609 Mdot
.24298 .53637 Mdot
.59749 .38784 Mdot
.49334 .35984 Mdot
.4896 .39477 Mdot
.49793 .34584 Mdot
.47421 .42335 Mdot
.49225 .31129 Mdot
.41257 .4837 Mdot
.48713 .27035 Mdot
.14144 .50211 Mdot
.43553 .55386 Mdot
.56041 .46794 Mdot
.47197 .25557 Mdot
.13212 .49489 Mdot
.54271 .47323 Mdot
.47356 .2567 Mdot
.12777 .4911 Mdot
.56909 .43195 Mdot
.47516 .28538 Mdot
.38265 .50211 Mdot
.49994 .2693 Mdot
.06527 .25035 Mdot
.03136 .31686 Mdot
.08212 .47157 Mdot
.1099 .10468 Mdot
.11862 .51003 Mdot
.94303 .20648 Mdot
.78943 .17665 Mdot
.08261 .1282 Mdot
.10981 .49903 Mdot
.89274 .18236 Mdot
.43203 .02489 Mdot
.19831 .55913 Mdot
.57031 .36924 Mdot
.47088 .42469 Mdot
.49197 .30962 Mdot
.40761 .48704 Mdot
.48862 .26959 Mdot
.11596 .47935 Mdot
.55928 .35099 Mdot
.41249 .48238 Mdot
.48699 .27086 Mdot
.14923 .50749 Mdot
.35853 .58584 Mdot
.52077 .35138 Mdot
.45853 .44252 Mdot
.48698 .29341 Mdot
.35684 .51415 Mdot
.51689 .27495 Mdot
.23726 .06323 Mdot
.09993 .50342 Mdot
.10597 .10908 Mdot
.11735 .50889 Mdot
.92583 .19696 Mdot
.86977 .16756 Mdot
.16599 .0525 Mdot
.13874 .52464 Mdot
.4503 .45819 Mdot
.48327 .28179 Mdot
.30312 .53107 Mdot
.56329 .30746 Mdot
.1064 .15658 Mdot
.05699 .43821 Mdot
.04297 .39388 Mdot
.05809 .4345 Mdot
.03615 .36321 Mdot
.07011 .4558 Mdot
.0363 .2602 Mdot
.09002 .48081 Mdot
.23647 .03096 Mdot
.15551 .53777 Mdot
.50657 .38205 Mdot
.49547 .37137 Mdot
.49425 .37995 Mdot
.4968 .36714 Mdot
.49208 .38728 Mdot
.49787 .35627 Mdot
.48467 .40537 Mdot
.49667 .3319 Mdot
.4546 .44786 Mdot
.48568 .28921 Mdot
.33933 .52091 Mdot
.53097 .28228 Mdot
.34367 .05027 Mdot
.11617 .52076 Mdot
.21465 .0376 Mdot
.1496 .53405 Mdot
.48519 .4194 Mdot
.49304 .31665 Mdot
.42698 .47309 Mdot
.48429 .27405 Mdot
.21776 .53379 Mdot
.57786 .44296 Mdot
.46685 .26833 Mdot
.33227 .52349 Mdot
.53736 .28626 Mdot
.35081 .05049 Mdot
.11681 .52148 Mdot
.21662 .03693 Mdot
.15014 .5344 Mdot
.48799 .41539 Mdot
.49416 .32144 Mdot
.43691 .46488 Mdot
.48372 .27807 Mdot
.26591 .53614 Mdot
.59177 .35026 Mdot
.38647 .49828 Mdot
.49692 .26913 Mdot
.05786 .32037 Mdot
.09492 .12162 Mdot
.11393 .50552 Mdot
.86667 .1719 Mdot
.19531 .0384 Mdot
.14821 .53134 Mdot
.50559 .38414 Mdot
.4961 .36762 Mdot
.49254 .38594 Mdot
.49775 .35823 Mdot
.48626 .40205 Mdot
.49721 .3361 Mdot
.46121 .44045 Mdot
.48742 .29515 Mdot
.36405 .51101 Mdot
.51162 .27276 Mdot
.17558 .09065 Mdot
.08476 .48497 Mdot
.04402 .22497 Mdot
.09491 .48614 Mdot
.3527 .02042 Mdot
.18071 .55192 Mdot
.53909 .33864 Mdot
.3824 .50118 Mdot
.49944 .26937 Mdot
.06231 .26491 Mdot
.0326 .28525 Mdot
.08686 .47698 Mdot
.18169 .05131 Mdot
.14037 .5277 Mdot
.37025 .51043 Mdot
.50939 .27168 Mdot
.15648 .10384 Mdot
.07877 .47665 Mdot
.03493 .27013 Mdot
.08858 .47928 Mdot
.20554 .04084 Mdot
.14715 .53241 Mdot
.4694 .43906 Mdot
.48719 .29651 Mdot
.37255 .50704 Mdot
.50589 .2708 Mdot
.11062 .15047 Mdot
.05976 .44405 Mdot
.03991 .38188 Mdot
.06328 .44449 Mdot
.03236 .32518 Mdot
.07956 .46882 Mdot
.07994 .14329 Mdot
.10888 .50071 Mdot
.73464 .12173 Mdot
.07086 .48385 Mdot
.05675 .42944 Mdot
.03591 .36193 Mdot
.07057 .45649 Mdot
.03716 .25509 Mdot
.09073 .48158 Mdot
.25217 .02731 Mdot
.15953 .5402 Mdot
.5138 .36498 Mdot
.48357 .40613 Mdot
.49655 .33076 Mdot
.45261 .44995 Mdot
.48527 .28765 Mdot
.33172 .52346 Mdot
.53754 .2864 Mdot
.34977 .05045 Mdot
.11672 .52137 Mdot
.2163 .03704 Mdot
.15005 .53435 Mdot
.48755 .41603 Mdot
.49399 .32066 Mdot
.43536 .46622 Mdot
.48373 .27735 Mdot
.25874 .53646 Mdot
.59508 .36094 Mdot
.44653 .45332 Mdot
.48502 .28529 Mdot
.3165 .5279 Mdot
.55117 .29646 Mdot
.26197 .05714 Mdot
.10454 .50851 Mdot
.13564 .08089 Mdot
.12661 .51703 Mdot
.54711 .08806 Mdot
.10584 .51832 Mdot
.04005 .24144 Mdot
.09256 .48367 Mdot
.29167 .02153 Mdot
.1689 .54555 Mdot
.52538 .34318 Mdot
.43065 .46928 Mdot
.48404 .27586 Mdot
.24028 .53624 Mdot
.59702 .39298 Mdot
.4932 .34633 Mdot
.47925 .41575 Mdot
.49433 .31959 Mdot
.4316 .46936 Mdot
.48388 .27577 Mdot
.2409 .53627 Mdot
.59716 .39179 Mdot
.49337 .34935 Mdot
.48193 .41105 Mdot
.49549 .32504 Mdot
.44249 .45987 Mdot
.48392 .28098 Mdot
.29069 .53338 Mdot
.5741 .3196 Mdot
.07003 .397 Mdot
.73108 .12031 Mdot
.07448 .48899 Mdot
.054 .42343 Mdot
.03938 .3801 Mdot
.06435 .44637 Mdot
.03214 .31599 Mdot
.08133 .47098 Mdot
.09667 .11995 Mdot
.11439 .50609 Mdot
.87021 .1733 Mdot
.22037 .02945 Mdot
.15593 .53628 Mdot
.5191 .35273 Mdot
.46296 .43735 Mdot
.48831 .29779 Mdot
.37307 .50677 Mdot
.50555 .2707 Mdot
.10709 .15536 Mdot
.05788 .44011 Mdot
.04193 .39004 Mdot
.05984 .43802 Mdot
.03446 .35135 Mdot
.07352 .46081 Mdot
.04504 .22109 Mdot
.09548 .4867 Mdot
.36891 .02144 Mdot
.18318 .55329 Mdot
.54094 .33907 Mdot
.3803 .50227 Mdot
.5006 .26958 Mdot
.0673 .24203 Mdot
.03187 .33286 Mdot
.07932 .46817 Mdot
.08103 .14159 Mdot
.10924 .50107 Mdot
.74433 .12534 Mdot
.06157 .46914 Mdot
.06318 .44169 Mdot
.03213 .30786 Mdot
.0828 .47273 Mdot
.11361 .10081 Mdot
.1198 .5111 Mdot
.95019 .21329 Mdot
.06644 .38148 Mdot
.57832 .06682 Mdot
.17357 .55858 Mdot
.84557 .19488 Mdot
.37193 .01702 Mdot
.19122 .55507 Mdot
.57176 .37278 Mdot
.4778 .41345 Mdot
.49499 .32165 Mdot
.43533 .46621 Mdot
.48374 .27736 Mdot
.25875 .53646 Mdot
.59507 .36092 Mdot
.44648 .45338 Mdot
.48501 .28525 Mdot
.31626 .52796 Mdot
.55139 .29663 Mdot
.25957 .05764 Mdot
.1041 .50804 Mdot
.13257 .0834 Mdot
.12567 .51624 Mdot
.67679 .13305 Mdot
.04784 .43792 Mdot
.06932 .45188 Mdot
.03979 .24168 Mdot
.09259 .48358 Mdot
.29607 .02115 Mdot
.16987 .54608 Mdot
.52655 .34205 Mdot
.42475 .47397 Mdot
.48462 .27374 Mdot
.21075 .53249 Mdot
.56431 .46145 Mdot
.46815 .25755 Mdot
.20699 .53179 Mdot
.55444 .47267 Mdot
.47539 .25532 Mdot
.09045 .4448 Mdot
.40632 .491 Mdot
.48986 .26852 Mdot
.09194 .4472 Mdot
.44548 .46232 Mdot
.48297 .27925 Mdot
.28389 .53439 Mdot
.57964 .32714 Mdot
.13929 .49987 Mdot
.44972 .54615 Mdot
.59687 .40563 Mdot
.4873 .31696 Mdot
.44344 .45927 Mdot
.48392 .28134 Mdot
.29371 .53287 Mdot
.57154 .31647 Mdot
.05873 .33576 Mdot
.15456 .06665 Mdot
.13252 .52172 Mdot
.08381 .43385 Mdot
.12416 .13322 Mdot
.0677 .45894 Mdot
.03344 .34098 Mdot
.07597 .46422 Mdot
.05551 .19079 Mdot
.10007 .4916 Mdot
.49334 .04272 Mdot
.18905 .55982 Mdot
.51611 .35977 Mdot
.47644 .41872 Mdot
.49358 .31613 Mdot
.42381 .47553 Mdot
.48472 .27304 Mdot
.20147 .53035 Mdot
.53869 .48821 Mdot
.49484 .25887 Mdot
.18852 .08313 Mdot
.08851 .48983 Mdot
.05383 .1952 Mdot
.09936 .49089 Mdot
.4722 .03771 Mdot
.19004 .55923 Mdot
.52422 .34476 Mdot
.4375 .46346 Mdot
.48388 .27891 Mdot
.27227 .53567 Mdot
.588 .3415 Mdot
.30925 .5287 Mdot
.5561 .30075 Mdot
.19779 .07855 Mdot
.09058 .49247 Mdot
.06036 .17963 Mdot
.10192 .49359 Mdot
.54308 .0562 Mdot
.18241 .55999 Mdot
.38711 .50215 Mdot
.49894 .26877 Mdot
.06327 .25974 Mdot
.03179 .29705 Mdot
.08518 .4751 Mdot
.15279 .06814 Mdot
.13185 .52127 Mdot
.06042 .35847 Mdot
.24924 .02773 Mdot
.15899 .53982 Mdot
.5134 .36596 Mdot
.48468 .40389 Mdot
.49694 .33354 Mdot
.45718 .44504 Mdot
.4863 .29139 Mdot
.34908 .5173 Mdot
.52292 .27783 Mdot
.29653 .05193 Mdot
.11038 .51466 Mdot
.17883 .05283 Mdot
.1395 .52709 Mdot
.34566 .52053 Mdot
.52819 .28048 Mdot
.33981 .0502 Mdot
.11579 .52035 Mdot
.21316 .03812 Mdot
.14919 .53378 Mdot
.48288 .42257 Mdot
.49212 .31305 Mdot
.41889 .47923 Mdot
.48561 .27168 Mdot
.17518 .52138 Mdot
.41064 .56823 Mdot
.24653 .6031 Mdot
.03349 .32922 Mdot
.07709 .46601 Mdot
.05995 .18038 Mdot
.10179 .49342 Mdot
.54112 .05563 Mdot
.1828 .56003 Mdot
.40509 .49189 Mdot
.49038 .2684 Mdot
.08618 .43698 Mdot
.18598 .52668 Mdot
.46025 .54389 Mdot
.59557 .41034 Mdot
.4842 .3082 Mdot
.43001 .47094 Mdot
.48397 .27499 Mdot
.23172 .5356 Mdot
.59331 .41039 Mdot
.48474 .30935 Mdot
.43152 .4697 Mdot
.48386 .27558 Mdot
.23921 .53618 Mdot
.59675 .39506 Mdot
.49272 .34123 Mdot
.47424 .42366 Mdot
.49215 .311 Mdot
.41191 .48415 Mdot
.48731 .27024 Mdot
.13799 .49952 Mdot
.47833 .52856 Mdot
.57907 .32052 Mdot
.06709 .38672 Mdot
.59128 .07098 Mdot
.16912 .55751 Mdot
.91796 .19333 Mdot
.76045 .12655 Mdot
.05602 .45941 Mdot
.06682 .44758 Mdot
.03517 .26767 Mdot
.08898 .47967 Mdot
.21496 .03742 Mdot
.14975 .53413 Mdot
.48643 .41765 Mdot
.49354 .31871 Mdot
.43136 .46957 Mdot
.4839 .27566 Mdot
.23965 .53621 Mdot
.59687 .39421 Mdot
.49294 .34329 Mdot
.47634 .42046 Mdot
.49306 .31439 Mdot
.42006 .47835 Mdot
.48537 .27199 Mdot
.18156 .52399 Mdot
.44827 .55038 Mdot
.56688 .46047 Mdot
.46782 .25749 Mdot
.21021 .53249 Mdot
.56252 .4636 Mdot
.46913 .25686 Mdot
.18553 .52556 Mdot
.46896 .53888 Mdot
.60032 .37974 Mdot
.48978 .38241 Mdot
.49773 .36114 Mdot
.48831 .39739 Mdot
.49776 .3422 Mdot
.46972 .42973 Mdot
.4904 .30488 Mdot
.39555 .49461 Mdot
.49329 .26873 Mdot
.0679 .39083 Mdot
.62023 .08059 Mdot
.15681 .5536 Mdot
.52294 .05055 Mdot
.18574 .56013 Mdot
.48622 .41807 Mdot
.49342 .31822 Mdot
.43035 .4704 Mdot
.48397 .27526 Mdot
.23468 .53586 Mdot
.59501 .40418 Mdot
.48865 .32111 Mdot
.44925 .45367 Mdot
.48459 .285 Mdot
.31762 .52761 Mdot
.55017 .29564 Mdot
.27297 .05509 Mdot
.10648 .51059 Mdot
.14951 .07048 Mdot
.13082 .52048 Mdot
.06585 .24587 Mdot
.03191 .33324 Mdot
.07922 .46805 Mdot
.08008 .14306 Mdot
.10892 .50075 Mdot
.73594 .12222 Mdot
.06961 .48201 Mdot
.05767 .43134 Mdot
.03493 .35526 Mdot
.07251 .45936 Mdot
.04184 .23301 Mdot
.09379 .48489 Mdot
.32546 .01988 Mdot
.1759 .54933 Mdot
.53388 .3385 Mdot
.39438 .4945 Mdot
.49349 .26888 Mdot
.06764 .3899 Mdot
.60792 .07646 Mdot
.16247 .55556 Mdot
.70332 .11022 Mdot
.09974 .51768 Mdot
.03478 .35077 Mdot
.07281 .45992 Mdot
.04237 .23091 Mdot
.09409 .4852 Mdot
.33287 .01987 Mdot
.17728 .55007 Mdot
.53551 .33835 Mdot
.3897 .49719 Mdot
.49567 .26891 Mdot
.05917 .34393 Mdot
.18528 .0493 Mdot
.14158 .52849 Mdot
.40147 .49404 Mdot
.49185 .26826 Mdot
.07352 .4083 Mdot
.86574 .17143 Mdot
.18813 .04147 Mdot
.14593 .52979 Mdot
.49868 .39788 Mdot
.49731 .3452 Mdot
.47407 .4236 Mdot
.49218 .31104 Mdot
.41194 .48413 Mdot
.48731 .27024 Mdot
.13814 .49963 Mdot
.47646 .5298 Mdot
.58205 .32479 Mdot
.10187 .46149 Mdot
.51856 .3527 Mdot
.46345 .43676 Mdot
.48846 .2983 Mdot
.37483 .5059 Mdot
.50443 .27038 Mdot
.09645 .17176 Mdot
.05171 .42573 Mdot
.04936 .41364 Mdot
.04774 .40948 Mdot
.05053 .41707 Mdot
.04619 .40485 Mdot
.05301 .42323 Mdot
.04254 .39269 Mdot
.05898 .4363 Mdot
.03523 .35719 Mdot
.0719 .45849 Mdot
.04015 .24017 Mdot
.09279 .48381 Mdot
.30069 .02082 Mdot
.17087 .54662 Mdot
.52775 .34107 Mdot
.41885 .47841 Mdot
.48559 .27205 Mdot
.17985 .52332 Mdot
.43839 .55543 Mdot
.51404 .50991 Mdot
.54245 .28417 Mdot
.57468 .09726 Mdot
.0963 .50999 Mdot
.03238 .31491 Mdot
.08119 .47093 Mdot
.09407 .12324 Mdot
.11355 .50529 Mdot
.85122 .16587 Mdot
.11008 .09496 Mdot
.11954 .50855 Mdot
.68694 .13686 Mdot
.04222 .42345 Mdot
.07258 .45632 Mdot
.05342 .19604 Mdot
.09923 .4907 Mdot
.47069 .03737 Mdot
.19007 .55917 Mdot
.52474 .34414 Mdot
.43477 .46583 Mdot
.48388 .27761 Mdot
.25981 .53642 Mdot
.59466 .35929 Mdot
.43939 .4602 Mdot
.48427 .28087 Mdot
.2866 .534 Mdot
.57747 .32405 Mdot
.10558 .46645 Mdot
.52718 .3404 Mdot
.41751 .47941 Mdot
.48586 .27171 Mdot
.17257 .52023 Mdot
.39511 .57451 Mdot
.42562 .55849 Mdot
.50947 .51326 Mdot
.551 .29084 Mdot
.4961 .07393 Mdot
.11508 .52456 Mdot
.08668 .13346 Mdot
.11109 .50295 Mdot
.78865 .14199 Mdot
.02684 .36383 Mdot
.07981 .46336 Mdot
.15276 .06814 Mdot
.13185 .52126 Mdot
.06074 .3606 Mdot
.26441 .02484 Mdot
.16276 .54203 Mdot
.51844 .35421 Mdot
.46625 .43323 Mdot
.48944 .3015 Mdot
.38519 .50051 Mdot
.49839 .26908 Mdot
.05974 .28257 Mdot
.03958 .24031 Mdot
.09289 .4836 Mdot
.31335 .02016 Mdot
.17351 .54805 Mdot
.53099 .33927 Mdot
.40466 .48816 Mdot
.48944 .2695 Mdot
.10642 .46819 Mdot
.52743 .34023 Mdot
.41633 .48025 Mdot
.48612 .27143 Mdot
.1663 .51726 Mdot
.3608 .58622 Mdot
.51191 .37102 Mdot
.48924 .39332 Mdot
.49803 .34743 Mdot
.47599 .42064 Mdot
.49302 .31416 Mdot
.41948 .47878 Mdot
.48549 .27184 Mdot
.17845 .52275 Mdot
.43014 .55945 Mdot
.443 .55392 Mdot
.52448 .50177 Mdot
.52279 .27143 Mdot
.56966 .09558 Mdot
.09811 .51167 Mdot
.0325 .30282 Mdot
.08337 .47351 Mdot
.1191 .09537 Mdot
.12152 .51263 Mdot
.93859 .2177 Mdot
.05864 .31792 Mdot
.10599 .10847 Mdot
.11749 .50887 Mdot
.93328 .20074 Mdot
.96006 .20592 Mdot
.10193 .16421 Mdot
.05252 .42793 Mdot
.0485 .41126 Mdot
.04908 .41323 Mdot
.04842 .4114 Mdot
.04944 .41418 Mdot
.04786 .40979 Mdot
.05034 .41656 Mdot
.04648 .40575 Mdot
.05253 .42208 Mdot
.04322 .39514 Mdot
.05784 .43399 Mdot
.03639 .36469 Mdot
.06965 .45509 Mdot
.03555 .26514 Mdot
.08932 .48005 Mdot
.22175 .03519 Mdot
.15159 .53532 Mdot
.49486 .4046 Mdot
.49654 .33549 Mdot
.46122 .44048 Mdot
.48741 .29513 Mdot
.36399 .51104 Mdot
.51166 .27278 Mdot
.17608 .09034 Mdot
.08491 .48516 Mdot
.04434 .22382 Mdot
.09508 .48631 Mdot
.35694 .02064 Mdot
.18139 .55229 Mdot
.53968 .33875 Mdot
.3816 .5016 Mdot
.49987 .26944 Mdot
.06398 .25621 Mdot
.03148 .3047 Mdot
.08404 .4738 Mdot
.13537 .08102 Mdot
.12656 .51697 Mdot
.54471 .08733 Mdot
.10648 .51882 Mdot
.04144 .2354 Mdot
.09341 .48459 Mdot
.31246 .02019 Mdot
.17333 .54795 Mdot
.53076 .33936 Mdot
.40557 .48757 Mdot
.48913 .2696 Mdot
.11075 .47348 Mdot
.54041 .33808 Mdot
.37596 .50452 Mdot
.50315 .27015 Mdot
.08394 .19552 Mdot
.04331 .40105 Mdot
.06055 .43909 Mdot
.03369 .34449 Mdot
.07528 .46326 Mdot
.05225 .1992 Mdot
.09874 .49019 Mdot
.45665 .03434 Mdot
.19017 .55864 Mdot
.52938 .34021 Mdot
.41216 .48316 Mdot
.48714 .27059 Mdot
.14424 .50412 Mdot
.40292 .56933 Mdot
.25675 .60331 Mdot
.0335 .29255 Mdot
.08453 .47511 Mdot
.13071 .08489 Mdot
.12512 .51576 Mdot
.73307 .15426 Mdot
.02479 .3281 Mdot
.08277 .46731 Mdot
.20331 .04168 Mdot
.14654 .53199 Mdot
.46449 .44438 Mdot
.48579 .29194 Mdot
.35558 .51469 Mdot
.51786 .27538 Mdot
.2479 .0603 Mdot
.10207 .50579 Mdot
.11949 .09509 Mdot
.12161 .51274 Mdot
.93809 .21768 Mdot
.05912 .29881 Mdot
.06344 .17194 Mdot
.10322 .49472 Mdot
.59145 .07114 Mdot
.16881 .5574 Mdot
.91127 .19033 Mdot
.66731 .09251 Mdot
.14012 .54683 Mdot
.15159 .06914 Mdot
.1314 .52097 Mdot
.05778 .29995 Mdot
.05091 .20162 Mdot
.09836 .48954 Mdot
.45685 .03438 Mdot
.19017 .55865 Mdot
.52932 .34024 Mdot
.41243 .48297 Mdot
.48707 .27064 Mdot
.14566 .5051 Mdot
.38821 .57536 Mdot
.39288 .57311 Mdot
.27208 .60205 Mdot
.06148 .1782 Mdot
.10217 .49408 Mdot
.53929 .0551 Mdot
.18315 .56005 Mdot
.41948 .48255 Mdot
.48574 .27023 Mdot
.15584 .51159 Mdot
.33458 .59281 Mdot
.84541 .19479 Mdot
.3701 .01687 Mdot
.19094 .55492 Mdot
.57163 .37243 Mdot
.47718 .41455 Mdot
.49472 .32041 Mdot
.43277 .46837 Mdot
.48382 .27625 Mdot
.24664 .53649 Mdot
.59766 .38116 Mdot
.49058 .37941 Mdot
.49724 .36546 Mdot
.49108 .39021 Mdot
.49801 .35208 Mdot
.48088 .41254 Mdot
.49514 .32323 Mdot
.43897 .46305 Mdot
.48375 .2791 Mdot
.27531 .53539 Mdot
.58597 .33754 Mdot
.26574 .53531 Mdot
.59087 .34809 Mdot
.3699 .50693 Mdot
.5065 .27116 Mdot
.11332 .14692 Mdot
.06114 .44683 Mdot
.03853 .3756 Mdot
.06568 .4487 Mdot
.03222 .30439 Mdot
.08337 .47339 Mdot
.12061 .09393 Mdot
.12199 .51305 Mdot
.92867 .21675 Mdot
.41224 .05682 Mdot
.11894 .52497 Mdot
.18212 .05119 Mdot
.14044 .52777 Mdot
.36946 .51079 Mdot
.50994 .27187 Mdot
.16299 .09903 Mdot
.08091 .47969 Mdot
.03735 .25444 Mdot
.09079 .48169 Mdot
.25241 .02726 Mdot
.15959 .54024 Mdot
.51389 .36476 Mdot
.48332 .40662 Mdot
.49645 .33015 Mdot
.45157 .45102 Mdot
.48507 .28687 Mdot
.32769 .52473 Mdot
.5411 .28882 Mdot
.34004 .05023 Mdot
.11575 .52033 Mdot
.21227 .03843 Mdot
.14895 .53362 Mdot
.48143 .4245 Mdot
.49153 .31091 Mdot
.41381 .48285 Mdot
.4868 .27057 Mdot
.14793 .50664 Mdot
.368 .58274 Mdot
.5546 .34797 Mdot
.40291 .48889 Mdot
.48996 .26943 Mdot
.10057 .46039 Mdot
.51373 .36408 Mdot
.48273 .40779 Mdot
.49622 .32873 Mdot
.4491 .45352 Mdot
.48465 .28511 Mdot
.31797 .52751 Mdot
.54984 .29538 Mdot
.27636 .05454 Mdot
.10706 .5112 Mdot
.1537 .06762 Mdot
.13208 .52148 Mdot
.06303 .3732 Mdot
.37081 .02145 Mdot
.18368 .55349 Mdot
.54199 .33939 Mdot
.37957 .50264 Mdot
.50101 .26967 Mdot
.06944 .23428 Mdot
.03294 .34659 Mdot
.07658 .46466 Mdot
.06098 .1781 Mdot
.10218 .49383 Mdot
.55206 .05885 Mdot
.18048 .55977 Mdot
.26024 .53772 Mdot
.59561 .36292 Mdot
.45427 .44513 Mdot
.48656 .29128 Mdot
.34671 .5182 Mdot
.52483 .27882 Mdot
.31131 .05081 Mdot
.11244 .51681 Mdot
.19339 .0459 Mdot
.14368 .53006 Mdot
.43087 .47427 Mdot
.48359 .27317 Mdot
.21559 .53342 Mdot
.57411 .44856 Mdot
.46601 .26418 Mdot
.30435 .53097 Mdot
.56247 .30662 Mdot
.11648 .14314 Mdot
.06222 .44902 Mdot
.03754 .37062 Mdot
.06745 .45164 Mdot
.03306 .28772 Mdot
.08603 .47643 Mdot
.16001 .06345 Mdot
.13401 .52296 Mdot
.13354 .49709 Mdot
.54405 .47164 Mdot
.47251 .25701 Mdot
.14473 .50455 Mdot
.39923 .5709 Mdot
.24456 .60287 Mdot
.03363 .33165 Mdot
.0765 .46523 Mdot
.05669 .18792 Mdot
.10053 .4921 Mdot
.50619 .04599 Mdot
.18795 .56005 Mdot
.50881 .37725 Mdot
.49343 .38044 Mdot
.49701 .36596 Mdot
.49143 .38923 Mdot
.49798 .35347 Mdot
.4822 .41016 Mdot
.4957 .32605 Mdot
.44436 .45812 Mdot
.48407 .28207 Mdot
.29862 .53197 Mdot
.56727 .31162 Mdot
.06969 .23408 Mdot
.03271 .34432 Mdot
.07707 .4653 Mdot
.06408 .17156 Mdot
.10333 .49503 Mdot
.58391 .06872 Mdot
.17147 .55807 Mdot
.94898 .21621 Mdot
.1299 .49097 Mdot
.53618 .48052 Mdot
.47984 .25629 Mdot
.06441 .37714 Mdot
.44857 .03258 Mdot
.1903 .55834 Mdot
.53259 .3389 Mdot
.39934 .49151 Mdot
.49141 .26905 Mdot
.08361 .43195 Mdot
.06208 .26364 Mdot
.0318 .29712 Mdot
.08516 .47508 Mdot
.15225 .06851 Mdot
.13169 .52114 Mdot
.05856 .34309 Mdot
.16124 .0624 Mdot
.13452 .52327 Mdot
.16827 .51932 Mdot
.35886 .58681 Mdot
.5048 .38687 Mdot
.49667 .36309 Mdot
.48999 .39329 Mdot
.498 .3478 Mdot
.47643 .41995 Mdot
.49321 .31491 Mdot
.4212 .4775 Mdot
.48516 .27229 Mdot
.18768 .52621 Mdot
.48126 .53141 Mdot
.59267 .34397 Mdot
.33166 .52234 Mdot
.53596 .28547 Mdot
.34664 .05035 Mdot
.11643 .52106 Mdot
.2154 .03734 Mdot
.14981 .53419 Mdot
.48628 .41786 Mdot
.49348 .31847 Mdot
.43085 .46999 Mdot
.48393 .27546 Mdot
.23716 .53605 Mdot
.59608 .39913 Mdot
.49124 .3318 Mdot
.46349 .43804 Mdot
.48803 .29723 Mdot
.37168 .50745 Mdot
.50644 .27097 Mdot
.11625 .14319 Mdot
.06259 .4497 Mdot
.03717 .36863 Mdot
.06813 .45273 Mdot
.03364 .28102 Mdot
.08704 .47755 Mdot
.17737 .05351 Mdot
.13912 .52679 Mdot
.33696 .52355 Mdot
.5356 .28497 Mdot
.35826 .05082 Mdot
.11747 .52221 Mdot
.21832 .03637 Mdot
.1506 .5347 Mdot
.49022 .41204 Mdot
.49501 .32561 Mdot
.44486 .45768 Mdot
.48411 .28235 Mdot
.3006 .53158 Mdot
.56552 .30975 Mdot
.08332 .19724 Mdot
.04229 .39747 Mdot
.06198 .4418 Mdot
.03279 .33351 Mdot
.07782 .46662 Mdot
.06672 .1663 Mdot
.10429 .49603 Mdot
.61033 .07736 Mdot
.16116 .55511 Mdot
.66151 .09511 Mdot
.13241 .54206 Mdot
.09604 .121 Mdot
.11413 .50591 Mdot
.86099 .16967 Mdot
.15954 .05632 Mdot
.13658 .52302 Mdot
.41901 .48281 Mdot
.48585 .27016 Mdot
.15372 .51032 Mdot
.338 .59184 Mdot
.16742 .0954 Mdot
.08361 .48328 Mdot
.04221 .2318 Mdot
.09395 .48509 Mdot
.32798 .01987 Mdot
.17637 .54959 Mdot
.53445 .33843 Mdot
.39266 .4955 Mdot
.49427 .26887 Mdot
.06369 .37363 Mdot
.41417 .02655 Mdot
.18852 .55652 Mdot
.54048 .33899 Mdot
.38098 .50192 Mdot
.50021 .26951 Mdot
.06546 .24952 Mdot
.03138 .3185 Mdot
.08185 .47125 Mdot
.1067 .10816 Mdot
.11761 .5091 Mdot
.93065 .19937 Mdot
.93242 .19262 Mdot
.84703 .15889 Mdot
.06713 .151 Mdot
.10389 .49229 Mdot
.77016 .13501 Mdot
.03855 .41655 Mdot
.07495 .45848 Mdot
.07588 .14979 Mdot
.1075 .49931 Mdot
.69865 .10845 Mdot
.10394 .52151 Mdot
.03301 .33137 Mdot
.07769 .46658 Mdot
.06497 .16976 Mdot
.10365 .49537 Mdot
.59285 .0716 Mdot
.16829 .55726 Mdot
.89683 .18414 Mdot
.48083 .03509 Mdot
.1992 .56134 Mdot
.55113 .34435 Mdot
.38875 .4975 Mdot
.49602 .26898 Mdot
.05861 .33736 Mdot
.15363 .06727 Mdot
.13224 .5215 Mdot
.07478 .41343 Mdot
.88593 .17948 Mdot
.35738 .01568 Mdot
.18924 .55394 Mdot
.57158 .37226 Mdot
.47689 .41507 Mdot
.49459 .31983 Mdot
.43156 .46938 Mdot
.48389 .27575 Mdot
.24073 .53626 Mdot
.59712 .39211 Mdot
.49333 .34853 Mdot
.48123 .41233 Mdot
.49519 .32354 Mdot
.4396 .46249 Mdot
.48377 .27942 Mdot
.27811 .53509 Mdot
.58399 .33402 Mdot
.22363 .53394 Mdot
.58773 .42492 Mdot
.47501 .28719 Mdot
.39209 .49692 Mdot
.49501 .2687 Mdot
.06023 .35319 Mdot
.24038 .02977 Mdot
.15672 .53845 Mdot
.50962 .37509 Mdot
.49226 .38458 Mdot
.49767 .35983 Mdot
.48745 .39941 Mdot
.49756 .33953 Mdot
.46616 .43441 Mdot
.48905 .30046 Mdot
.38229 .50207 Mdot
.49999 .26934 Mdot
.0653 .25019 Mdot
.03136 .31718 Mdot
.08207 .47151 Mdot
.10929 .10534 Mdot
.11843 .50986 Mdot
.94104 .20518 Mdot
.9067 .21539 Mdot
.97614 .21946 Mdot
.45982 .43262 Mdot
.49006 .30149 Mdot
.38218 .50211 Mdot
.50005 .26936 Mdot
.06553 .24921 Mdot
.03139 .31912 Mdot
.08175 .47112 Mdot
.10549 .1095 Mdot
.11722 .50875 Mdot
.92488 .1965 Mdot
.85664 .16257 Mdot
.1001 .10542 Mdot
.11597 .5051 Mdot
.92768 .21662 Mdot
.47831 .06988 Mdot
.11616 .52486 Mdot
.10341 .11205 Mdot
.11652 .50814 Mdot
.911 .19013 Mdot
.66243 .09078 Mdot
.14349 .54852 Mdot
.19385 .04577 Mdot
.14376 .53014 Mdot
.43103 .47415 Mdot
.48357 .27322 Mdot
.21636 .53355 Mdot
.57548 .44657 Mdot
.4662 .26557 Mdot
.31506 .52846 Mdot
.55278 .29778 Mdot
.24381 .06145 Mdot
.10106 .50471 Mdot
.11242 .10214 Mdot
.11939 .51076 Mdot
.94844 .21081 Mdot
.1251 .13379 Mdot
.06452 .45351 Mdot
.03574 .36004 Mdot
.07085 .45696 Mdot
.03767 .25226 Mdot
.09112 .482 Mdot
.26106 .0256 Mdot
.16174 .5415 Mdot
.51681 .35781 Mdot
.47328 .42357 Mdot
.49222 .31097 Mdot
.41154 .4844 Mdot
.48742 .27017 Mdot
.13606 .49801 Mdot
.50146 .51188 Mdot
.53588 .27987 Mdot
.58515 .10072 Mdot
.09252 .50634 Mdot
.03338 .3377 Mdot
.07635 .4648 Mdot
.05712 .18688 Mdot
.1007 .49228 Mdot
.51096 .04724 Mdot
.18743 .56011 Mdot
.5048 .38611 Mdot
.49656 .36423 Mdot
.49068 .39143 Mdot
.49802 .35038 Mdot
.47919 .41547 Mdot
.49441 .31988 Mdot
.43214 .4689 Mdot
.48385 .27599 Mdot
.24356 .53639 Mdot
.59755 .38677 Mdot
.49315 .36281 Mdot
.4913 .3902 Mdot
.49799 .3522 Mdot
.481 .41233 Mdot
.49519 .32349 Mdot
.43946 .46261 Mdot
.48376 .27935 Mdot
.2775 .53516 Mdot
.58443 .33478 Mdot
.23299 .53497 Mdot
.59494 .40435 Mdot
.48855 .32079 Mdot
.44878 .45414 Mdot
.48453 .28468 Mdot
.31574 .5281 Mdot
.55187 .29703 Mdot
.2541 .05886 Mdot
.10308 .50692 Mdot
.12557 .08945 Mdot
.1235 .51439 Mdot
.87088 .20289 Mdot
.61233 .07367 Mdot
.17081 .55881 Mdot
.90267 .1866 Mdot
.55318 .05464 Mdot
.1905 .56237 Mdot
.49503 .4045 Mdot
.49655 .33566 Mdot
.46147 .44017 Mdot
.48749 .29538 Mdot
.36495 .51061 Mdot
.51099 .27252 Mdot
.16808 .0955 Mdot
.0825 .48191 Mdot
.03973 .24238 Mdot
.09247 .4835 Mdot
.29144 .02155 Mdot
.16885 .54552 Mdot
.52532 .34324 Mdot
.43096 .46902 Mdot
.48402 .27599 Mdot
.24179 .53632 Mdot
.59732 .39009 Mdot
.49348 .35377 Mdot
.48548 .40417 Mdot
.49687 .33347 Mdot
.45716 .44507 Mdot
.48629 .29137 Mdot
.34901 .51733 Mdot
.52298 .27786 Mdot
.29703 .05188 Mdot
.11045 .51474 Mdot
.17935 .05257 Mdot
.13965 .5272 Mdot
.34982 .51899 Mdot
.52477 .2786 Mdot
.31888 .05045 Mdot
.11342 .51784 Mdot
.19989 .04315 Mdot
.14551 .53132 Mdot
.45355 .45521 Mdot
.48363 .28377 Mdot
.31579 .5281 Mdot
.55184 .29701 Mdot
.25438 .0588 Mdot
.10313 .50698 Mdot
.12593 .08913 Mdot
.12361 .51449 Mdot
.86442 .20092 Mdot
.5466 .05289 Mdot
.19144 .56234 Mdot
.50402 .38776 Mdot
.49686 .36141 Mdot
.48889 .39607 Mdot
.49786 .344 Mdot
.47199 .42658 Mdot
.49132 .30799 Mdot
.40409 .48933 Mdot
.48984 .2692 Mdot
.09923 .45848 Mdot
.50989 .37357 Mdot
.49139 .38738 Mdot
.49793 .35579 Mdot
.48424 .40624 Mdot
.49651 .33082 Mdot
.4528 .44975 Mdot
.4853 .2878 Mdot
.33246 .52323 Mdot
.5369 .28597 Mdot
.35054 .05048 Mdot
.11679 .52145 Mdot
.21658 .03695 Mdot
.15013 .53439 Mdot
.48793 .41547 Mdot
.49414 .32133 Mdot
.43671 .46506 Mdot
.48372 .27798 Mdot
.26498 .53619 Mdot
.59226 .3516 Mdot
.39593 .49274 Mdot
.49253 .26909 Mdot
.07533 .41312 Mdot
.92509 .19646 Mdot
.85738 .16285 Mdot
.10312 .1021 Mdot
.11706 .50615 Mdot
.88854 .20796 Mdot
.79788 .14067 Mdot
.02649 .3621 Mdot
.07989 .4633 Mdot
.15665 .06557 Mdot
.13302 .52218 Mdot
.09293 .45018 Mdot
.44218 .46513 Mdot
.4829 .27764 Mdot
.26964 .53589 Mdot
.58965 .34506 Mdot
.3439 .51808 Mdot
.52566 .27939 Mdot
.31232 .05075 Mdot
.11257 .51695 Mdot
.19424 .04553 Mdot
.14392 .53023 Mdot
.43426 .47166 Mdot
.48322 .27432 Mdot
.23235 .53567 Mdot
.5937 .40909 Mdot
.4856 .31169 Mdot
.43519 .46662 Mdot
.48369 .27713 Mdot
.25684 .53651 Mdot
.59576 .36393 Mdot
.45783 .44105 Mdot
.48751 .29455 Mdot
.36017 .51272 Mdot
.5144 .27387 Mdot
.20876 .07346 Mdot
.09357 .49607 Mdot
.07256 .15565 Mdot
.10633 .49816 Mdot
.66465 .09617 Mdot
.1304 .54089 Mdot
.08274 .13932 Mdot
.10976 .50166 Mdot
.75355 .12879 Mdot
.05291 .4528 Mdot
.06827 .44982 Mdot
.03804 .2502 Mdot
.09141 .48231 Mdot
.26817 .02441 Mdot
.16347 .5425 Mdot
.51895 .35315 Mdot
.46388 .43621 Mdot
.48861 .29879 Mdot
.37646 .50509 Mdot
.50342 .27011 Mdot
.08765 .18783 Mdot
.04593 .40962 Mdot
.05697 .43184 Mdot
.03714 .36895 Mdot
.06827 .45294 Mdot
.0338 .27937 Mdot
.08728 .47782 Mdot
.18179 .05126 Mdot
.1404 .52772 Mdot
.37091 .51013 Mdot
.50894 .27152 Mdot
.15111 .10808 Mdot
.07693 .47394 Mdot
.0335 .28326 Mdot
.08665 .47716 Mdot
.16976 .05765 Mdot
.13689 .52515 Mdot
.26072 .53768 Mdot
.59542 .3621 Mdot
.45117 .44851 Mdot
.48585 .28871 Mdot
.33483 .52244 Mdot
.53483 .28464 Mdot
.35095 .05049 Mdot
.11684 .5215 Mdot
.21685 .03685 Mdot
.1502 .53444 Mdot
.48831 .41492 Mdot
.49428 .32201 Mdot
.43805 .46389 Mdot
.48373 .27862 Mdot
.27108 .53577 Mdot
.58875 .34309 Mdot
.32532 .52436 Mdot
.54159 .28926 Mdot
.33388 .0502 Mdot
.11509 .51963 Mdot
.20901 .03961 Mdot
.14805 .53303 Mdot
.47557 .43189 Mdot
.48928 .30324 Mdot
.39362 .49577 Mdot
.49417 .26872 Mdot
.06339 .37216 Mdot
.39906 .02443 Mdot
.18713 .55556 Mdot
.54211 .33946 Mdot
.37966 .50259 Mdot
.50095 .26966 Mdot
.06914 .23532 Mdot
.03277 .34481 Mdot
.07696 .46515 Mdot
.06331 .17314 Mdot
.10305 .49474 Mdot
.57611 .06624 Mdot
.174 .55864 Mdot
.77652 .17052 Mdot
.05057 .18578 Mdot
.09784 .48548 Mdot
.59953 .07377 Mdot
.16573 .55654 Mdot
.81533 .15217 Mdot
.02841 .26136 Mdot
.08761 .47222 Mdot
.3467 .02015 Mdot
.17975 .55139 Mdot
.53825 .3385 Mdot
.38374 .50047 Mdot
.49871 .26925 Mdot
.06009 .27964 Mdot
.03789 .24826 Mdot
.09183 .48244 Mdot
.2875 .02193 Mdot
.16797 .54503 Mdot
.52428 .34443 Mdot
.43641 .46442 Mdot
.48387 .27837 Mdot
.26732 .53605 Mdot
.59099 .34826 Mdot
.37123 .50628 Mdot
.50565 .27091 Mdot
.10478 .15868 Mdot
.05661 .43733 Mdot
.04337 .39529 Mdot
.05742 .43313 Mdot
.03687 .36746 Mdot
.06876 .45371 Mdot
.03433 .27445 Mdot
.088 .4786 Mdot
.19519 .04505 Mdot
.14424 .53043 Mdot
.43953 .46746 Mdot
.48291 .27638 Mdot
.25719 .53651 Mdot
.59565 .3634 Mdot
.45598 .4432 Mdot
.487 .2928 Mdot
.35319 .51566 Mdot
.51967 .27623 Mdot
.26671 .05614 Mdot
.10556 .50958 Mdot
.14357 .07475 Mdot
.12903 .51903 Mdot
.19397 .07986 Mdot
.09101 .49282 Mdot
.06339 .17313 Mdot
.10305 .49478 Mdot
.57457 .06575 Mdot
.17447 .55874 Mdot
.68901 .13762 Mdot
.04113 .42031 Mdot
.07317 .45708 Mdot
.05703 .18704 Mdot
.10068 .49224 Mdot
.51069 .04717 Mdot
.18746 .5601 Mdot
.50505 .38558 Mdot
.49644 .36516 Mdot
.49122 .38992 Mdot
.498 .35251 Mdot
.48129 .41181 Mdot
.49532 .3241 Mdot
.44065 .46154 Mdot
.48381 .27998 Mdot
.28277 .53453 Mdot
.5805 .32842 Mdot
.15452 .51016 Mdot
.33559 .59255 Mdot
.72553 .15138 Mdot
.02598 .34772 Mdot
.0813 .46583 Mdot
.1686 .05829 Mdot
.13656 .5249 Mdot
.24835 .53777 Mdot
.59772 .38288 Mdot
.49168 .37412 Mdot
.49598 .37316 Mdot
.49475 .37778 Mdot
.49628 .37043 Mdot
.49368 .38197 Mdot
.49721 .36408 Mdot
.49033 .3923 Mdot
.49802 .34916 Mdot
.47791 .41759 Mdot
.49385 .31749 Mdot
.42702 .47304 Mdot
.48429 .27407 Mdot
.21808 .53384 Mdot
.57837 .44215 Mdot
.46705 .26899 Mdot
.33575 .52235 Mdot
.53433 .28431 Mdot
.35144 .05051 Mdot
.11689 .52155 Mdot
.21702 .0368 Mdot
.15025 .53447 Mdot
.48854 .41458 Mdot
.49437 .32243 Mdot
.43886 .46317 Mdot
.48374 .27903 Mdot
.27474 .53544 Mdot
.58636 .33827 Mdot
.27415 .53463 Mdot
.58553 .33684 Mdot
.25772 .53567 Mdot
.59478 .35992 Mdot
.44219 .45757 Mdot
.48449 .28249 Mdot
.2986 .53197 Mdot
.56729 .31164 Mdot
.06958 .23446 Mdot
.03265 .34366 Mdot
.07721 .46548 Mdot
.06497 .16975 Mdot
.10366 .49537 Mdot
.59297 .07164 Mdot
.16824 .55725 Mdot
.89551 .18359 Mdot
.46521 .03152 Mdot
.19942 .56074 Mdot
.55969 .3523 Mdot
.41836 .47815 Mdot
.48567 .2722 Mdot
.18072 .52366 Mdot
.44345 .55287 Mdot
.54508 .48376 Mdot
.489 .25707 Mdot
.10509 .15816 Mdot
.05692 .43801 Mdot
.043 .39398 Mdot
.05804 .43441 Mdot
.03619 .3635 Mdot
.07002 .45566 Mdot
.03615 .26116 Mdot
.08988 .48066 Mdot
.23357 .03173 Mdot
.15475 .5373 Mdot
.50478 .38594 Mdot
.49653 .36448 Mdot
.49083 .39102 Mdot
.49802 .35095 Mdot
.47977 .41448 Mdot
.49467 .32099 Mdot
.43446 .46696 Mdot
.48375 .27697 Mdot
.25465 .53654 Mdot
.59643 .36745 Mdot
.46857 .42717 Mdot
.4913 .30708 Mdot
.40064 .49151 Mdot
.49114 .26893 Mdot
.08469 .4341 Mdot
.08072 .42739 Mdot
.77169 .16876 Mdot
.04376 .20349 Mdot
.09511 .48214 Mdot
.52684 .05155 Mdot
.18533 .56017 Mdot
.47822 .42874 Mdot
.49024 .30643 Mdot
.40246 .49039 Mdot
.49045 .26905 Mdot
.09196 .44724 Mdot
.44606 .46181 Mdot
.48299 .27955 Mdot
.28634 .53405 Mdot
.5777 .32436 Mdot
.10875 .47043 Mdot
.53637 .33744 Mdot
.38277 .50102 Mdot
.49926 .26933 Mdot
.06171 .26842 Mdot
.03343 .27693 Mdot
.088 .47825 Mdot
.20349 .04163 Mdot
.14658 .53202 Mdot
.46461 .44425 Mdot
.48582 .29205 Mdot
.35602 .51451 Mdot
.51752 .27523 Mdot
.24429 .06124 Mdot
.10136 .50501 Mdot
.11487 .09963 Mdot
.12017 .51145 Mdot
.95039 .2147 Mdot
.10236 .46074 Mdot
.52294 .34492 Mdot
.43999 .46127 Mdot
.48396 .28017 Mdot
.28317 .53448 Mdot
.58019 .32795 Mdot
.14886 .50661 Mdot
.35467 .58705 Mdot
.50944 .37674 Mdot
.49308 .38169 Mdot
.49724 .36408 Mdot
.49032 .39232 Mdot
.49802 .34913 Mdot
.47787 .41765 Mdot
.49384 .31743 Mdot
.42689 .47314 Mdot
.48431 .27403 Mdot
.2174 .53373 Mdot
.57727 .44386 Mdot
.46665 .26761 Mdot
.32822 .52476 Mdot
.54094 .28869 Mdot
.34144 .05025 Mdot
.11589 .52048 Mdot
.21293 .0382 Mdot
.14913 .53374 Mdot
.48251 .42307 Mdot
.49196 .31248 Mdot
.41757 .48019 Mdot
.48589 .27137 Mdot
.16807 .51813 Mdot
.36973 .58347 Mdot
.53534 .33954 Mdot
.396 .4935 Mdot
.49278 .26892 Mdot
.07228 .40483 Mdot
.81734 .15277 Mdot
.02976 .25363 Mdot
.08838 .4732 Mdot
.36653 .02124 Mdot
.18287 .5531 Mdot
.54085 .33904 Mdot
.38037 .50224 Mdot
.50056 .26957 Mdot
.0671 .24282 Mdot
.03179 .33141 Mdot
.07959 .46851 Mdot
.08342 .13798 Mdot
.11004 .50187 Mdot
.76511 .13312 Mdot
.04266 .42857 Mdot
.07322 .45648 Mdot
.06083 .17837 Mdot
.10213 .49377 Mdot
.55122 .0586 Mdot
.18067 .5598 Mdot
.27579 .53672 Mdot
.58762 .34056 Mdot
.29931 .53088 Mdot
.56505 .30935 Mdot
.08644 .19061 Mdot
.04452 .40515 Mdot
.05892 .43587 Mdot
.03507 .3561 Mdot
.07222 .45895 Mdot
.04101 .23644 Mdot
.09331 .48437 Mdot
.31346 .02015 Mdot
.17353 .54806 Mdot
.53101 .33926 Mdot
.40458 .48821 Mdot
.48947 .26949 Mdot
.10603 .4677 Mdot
.52644 .34103 Mdot
.42133 .47659 Mdot
.48513 .2727 Mdot
.19285 .5279 Mdot
.50567 .51497 Mdot
.55353 .29301 Mdot
.45876 .065 Mdot
.11887 .52633 Mdot
.13993 .07755 Mdot
.1279 .51812 Mdot
.35317 .05018 Mdot
.11807 .52251 Mdot
.23372 .03176 Mdot
.15472 .53731 Mdot
.50448 .38657 Mdot
.49666 .3634 Mdot
.49017 .3928 Mdot
.49801 .34847 Mdot
.47717 .41878 Mdot
.49353 .31618 Mdot
.42411 .4753 Mdot
.48468 .27313 Mdot
.20303 .53074 Mdot
.54368 .48354 Mdot
.48779 .25686 Mdot
.09007 .18305 Mdot
.04773 .41496 Mdot
.05455 .42653 Mdot
.04015 .38334 Mdot
.063 .44397 Mdot
.03245 .32731 Mdot
.07913 .46828 Mdot
.07637 .14902 Mdot
.10766 .49949 Mdot
.7024 .10982 Mdot
.1007 .51858 Mdot
.0343 .34662 Mdot
.07395 .46154 Mdot
.04617 .21727 Mdot
.09603 .48729 Mdot
.38346 .02275 Mdot
.18512 .55441 Mdot
.54161 .33928 Mdot
.37986 .50249 Mdot
.50084 .26963 Mdot
.06855 .23743 Mdot
.03245 .34115 Mdot
.07771 .46613 Mdot
.06836 .16315 Mdot
.10487 .49664 Mdot
.62661 .08287 Mdot
.15337 .55227 Mdot
.42748 .0289 Mdot
.18905 .5572 Mdot
.53668 .33845 Mdot
.38734 .49851 Mdot
.49683 .26901 Mdot
.05784 .31905 Mdot
.09152 .12604 Mdot
.11282 .50445 Mdot
.84139 .16207 Mdot
.07402 .13988 Mdot
.10649 .49524 Mdot
.83094 .15805 Mdot
.04825 .1899 Mdot
.09663 .48369 Mdot
.58189 .06806 Mdot
.17217 .55824 Mdot
.936 .21749 Mdot
.0794 .20769 Mdot
.0377 .37844 Mdot
.06857 .45308 Mdot
.03445 .27339 Mdot
.08815 .47877 Mdot
.19819 .04377 Mdot
.14509 .53101 Mdot
.44977 .45868 Mdot
.48321 .28148 Mdot
.30099 .53151 Mdot
.5652 .30941 Mdot
.08638 .19076 Mdot
.04447 .40499 Mdot
.05898 .43601 Mdot
.03501 .35563 Mdot
.07235 .45914 Mdot
.04137 .23491 Mdot
.09353 .4846 Mdot
.31878 .01999 Mdot
.1746 .54863 Mdot
.53232 .33883 Mdot
.39965 .49132 Mdot
.49129 .26907 Mdot
.08479 .43429 Mdot
.08644 .43886 Mdot
.13182 .49562 Mdot
.55606 .45581 Mdot
.46763 .26367 Mdot
.28357 .53457 Mdot
.5801 .32781 Mdot
.1471 .50544 Mdot
.36672 .58318 Mdot
.54872 .34355 Mdot
.38865 .4976 Mdot
.49609 .26898 Mdot
.05849 .33569 Mdot
.14648 .07221 Mdot
.13008 .51977 Mdot
.0809 .20118 Mdot
.04271 .39884 Mdot
.06131 .44055 Mdot
.03317 .33877 Mdot
.07664 .46509 Mdot
.05934 .18174 Mdot
.10156 .49318 Mdot
.53473 .05379 Mdot
.184 .56011 Mdot
.4476 .46068 Mdot
.48303 .28022 Mdot
.29191 .53319 Mdot
.57309 .31834 Mdot
.06388 .37319 Mdot
.42877 .02891 Mdot
.18952 .55735 Mdot
.5378 .33853 Mdot
.385 .49979 Mdot
.49804 .26915 Mdot
.05869 .29357 Mdot
.0485 .20847 Mdot
.09734 .48843 Mdot
.42932 .02913 Mdot
.18931 .55733 Mdot
.53682 .33846 Mdot
.38703 .49868 Mdot
.49699 .26903 Mdot
.05783 .3157 Mdot
.08349 .13726 Mdot
.11017 .50184 Mdot
.77647 .1374 Mdot
.03385 .4001 Mdot
.07681 .46047 Mdot
.09858 .11755 Mdot
.11502 .50668 Mdot
.88409 .17884 Mdot
.3403 .01491 Mdot
.18611 .5524 Mdot
.56884 .36597 Mdot
.4632 .43524 Mdot
.48899 .29958 Mdot
.37839 .5041 Mdot
.50226 .26983 Mdot
.07861 .20782 Mdot
.0394 .386 Mdot
.06604 .44898 Mdot
.03242 .29846 Mdot
.08435 .47452 Mdot
.13405 .08209 Mdot
.12615 .51663 Mdot
.60374 .10664 Mdot
.08595 .49946 Mdot
.03779 .37039 Mdot
.06674 .45054 Mdot
.03258 .29514 Mdot
.08488 .47513 Mdot
.1418 .076 Mdot
.12852 .51859 Mdot
.24891 .05962 Mdot
.10332 .50698 Mdot
.13148 .08432 Mdot
.12533 .51595 Mdot
.71671 .14808 Mdot
.02846 .3682 Mdot
.07963 .46421 Mdot
.13407 .08206 Mdot
.12617 .51663 Mdot
.59899 .10501 Mdot
.08799 .5017 Mdot
.03622 .36145 Mdot
.06978 .45538 Mdot
.03562 .26466 Mdot
.08939 .48013 Mdot
.22314 .03475 Mdot
.15197 .53556 Mdot
.4963 .40215 Mdot
.4969 .33895 Mdot
.46616 .43444 Mdot
.48904 .30044 Mdot
.38222 .50211 Mdot
.50004 .26935 Mdot
.06549 .24936 Mdot
.03138 .31883 Mdot
.0818 .47118 Mdot
.10606 .10887 Mdot
.1174 .50892 Mdot
.92766 .19786 Mdot
.89458 .17714 Mdot
.36932 .01649 Mdot
.19129 .55494 Mdot
.57287 .37602 Mdot
.48293 .40339 Mdot
.49708 .33355 Mdot
.45699 .44525 Mdot
.48625 .29123 Mdot
.34837 .51757 Mdot
.52349 .27812 Mdot
.30117 .05151 Mdot
.11105 .51536 Mdot
.18366 .05041 Mdot
.14089 .5281 Mdot
.38063 .50545 Mdot
.50268 .2696 Mdot
.08625 .19064 Mdot
.04497 .40657 Mdot
.05828 .43458 Mdot
.03571 .36044 Mdot
.07096 .45709 Mdot
.03794 .25083 Mdot
.09132 .48222 Mdot
.2656 .02482 Mdot
.16285 .54214 Mdot
.5182 .35473 Mdot
.46737 .43178 Mdot
.48986 .30286 Mdot
.38933 .49821 Mdot
.49624 .26882 Mdot
.05808 .32814 Mdot
.1181 .09593 Mdot
.12132 .51235 Mdot
.93714 .21763 Mdot
.06384 .26067 Mdot
.03303 .28046 Mdot
.08754 .47772 Mdot
.1947 .04525 Mdot
.1441 .53033 Mdot
.43778 .46887 Mdot
.48298 .27566 Mdot
.24911 .53654 Mdot
.5975 .3768 Mdot
.48641 .39345 Mdot
.49816 .34604 Mdot
.47423 .42331 Mdot
.49226 .31134 Mdot
.41268 .48362 Mdot
.4871 .27037 Mdot
.14203 .50254 Mdot
.42833 .55753 Mdot
.51928 .50585 Mdot
.53232 .2772 Mdot
.60042 .10591 Mdot
.0864 .49988 Mdot
.03731 .36785 Mdot
.06764 .45201 Mdot
.03316 .28645 Mdot
.08623 .47664 Mdot
.16322 .06148 Mdot
.13496 .52369 Mdot
.17727 .52336 Mdot
.40914 .56887 Mdot
.24273 .60286 Mdot
.0342 .33895 Mdot
.07459 .46264 Mdot
.0479 .21175 Mdot
.09684 .48816 Mdot
.40499 .02535 Mdot
.18748 .55589 Mdot
.54069 .33904 Mdot
.38072 .50205 Mdot
.50036 .26954 Mdot
.06613 .24669 Mdot
.03149 .32407 Mdot
.08091 .47011 Mdot
.09621 .12052 Mdot
.11424 .50595 Mdot
.86698 .17202 Mdot
.19738 .03756 Mdot
.14886 .53177 Mdot
.50719 .38062 Mdot
.49496 .37397 Mdot
.49524 .37586 Mdot
.49572 .37342 Mdot
.49489 .37722 Mdot
.49613 .37129 Mdot
.49405 .38059 Mdot
.49694 .36615 Mdot
.49155 .38888 Mdot
.49796 .35397 Mdot
.48265 .40931 Mdot
.49588 .32707 Mdot
.44623 .45633 Mdot
.48427 .28322 Mdot
.30638 .53036 Mdot
.56035 .30458 Mdot
.14313 .11505 Mdot
.07365 .46895 Mdot
.03226 .30586 Mdot
.08304 .47304 Mdot
.11587 .09853 Mdot
.12051 .51173 Mdot
.94934 .21623 Mdot
.13622 .49624 Mdot
.46441 .5375 Mdot
.59689 .3564 Mdot
.4256 .47199 Mdot
.4846 .2747 Mdot
.22176 .53441 Mdot
.5837 .43306 Mdot
.47046 .27759 Mdot
.36868 .50913 Mdot
.50865 .27166 Mdot
.14132 .11652 Mdot
.07336 .46845 Mdot
.03224 .30742 Mdot
.08277 .47273 Mdot
.11255 .10191 Mdot
.11946 .51079 Mdot
.94909 .21153 Mdot
.07848 .21003 Mdot
.03702 .375 Mdot
.06959 .45467 Mdot
.03593 .26256 Mdot
.08969 .48045 Mdot
.22946 .03287 Mdot
.15366 .53663 Mdot
.50186 .39189 Mdot
.49733 .35454 Mdot
.48358 .40759 Mdot
.49624 .32916 Mdot
.44996 .45266 Mdot
.48479 .28571 Mdot
.3214 .52657 Mdot
.54674 .29295 Mdot
.30529 .05124 Mdot
.11151 .51587 Mdot
.1861 .04924 Mdot
.1416 .5286 Mdot
.39548 .49752 Mdot
.49457 .26825 Mdot
.06001 .35147 Mdot
.22902 .03279 Mdot
.15373 .53661 Mdot
.50282 .38998 Mdot
.49717 .35765 Mdot
.48616 .40234 Mdot
.49717 .33574 Mdot
.46067 .44108 Mdot
.48726 .29462 Mdot
.36206 .5119 Mdot
.51304 .27332 Mdot
.19255 .08105 Mdot
.08949 .49107 Mdot
.05684 .18772 Mdot
.10057 .49217 Mdot
.50549 .04581 Mdot
.18802 .56004 Mdot
.50932 .37607 Mdot
.4928 .38274 Mdot
.49742 .36254 Mdot
.48934 .39488 Mdot
.49794 .3456 Mdot
.47392 .42378 Mdot
.49212 .31084 Mdot
.41144 .48447 Mdot
.48745 .27016 Mdot
.13553 .49758 Mdot
.50748 .50708 Mdot
.52436 .2727 Mdot
.56281 .09337 Mdot
.10031 .51364 Mdot
.03336 .28664 Mdot
.08602 .47653 Mdot
.15763 .06497 Mdot
.13329 .5224 Mdot
.1029 .46485 Mdot
.51616 .35818 Mdot
.47429 .42208 Mdot
.49264 .31252 Mdot
.41537 .48174 Mdot
.4864 .27089 Mdot
.15639 .51191 Mdot
.3343 .59291 Mdot
.88087 .20575 Mdot
.71606 .11033 Mdot
.09949 .51786 Mdot
.03551 .35621 Mdot
.0712 .45756 Mdot
.03822 .2494 Mdot
.09151 .48243 Mdot
.27018 .0241 Mdot
.16395 .54277 Mdot
.51953 .35199 Mdot
.46111 .43957 Mdot
.48772 .29587 Mdot
.36625 .51001 Mdot
.51008 .27219 Mdot
.15729 .10322 Mdot
.07904 .47704 Mdot
.03519 .2682 Mdot
.08885 .47958 Mdot
.21106 .03879 Mdot
.14868 .53342 Mdot
.48027 .42602 Mdot
.49107 .30928 Mdot
.40977 .48562 Mdot
.48794 .26988 Mdot
.12674 .49007 Mdot
.57209 .42383 Mdot
.48013 .29615 Mdot
.40543 .48871 Mdot
.48942 .26926 Mdot
.10403 .46511 Mdot
.52172 .34682 Mdot
.44688 .45481 Mdot
.48458 .28425 Mdot
.31198 .52905 Mdot
.55528 .29993 Mdot
.21159 .07238 Mdot
.094 .49662 Mdot
.07413 .15293 Mdot
.10687 .49871 Mdot
.67936 .10145 Mdot
.11963 .5339 Mdot
.0424 .2317 Mdot
.09393 .48516 Mdot
.32428 .01989 Mdot
.17567 .54921 Mdot
.53361 .33854 Mdot
.39525 .49398 Mdot
.49311 .26889 Mdot
.06998 .39782 Mdot
.71702 .1151 Mdot
.08776 .50543 Mdot
.04328 .39325 Mdot
.05674 .43176 Mdot
.03772 .37203 Mdot
.06721 .45123 Mdot
.0329 .28988 Mdot
.0857 .47606 Mdot
.1546 .06693 Mdot
.13239 .5217 Mdot
.07168 .40494 Mdot
.76602 .13337 Mdot
.04205 .42691 Mdot
.07349 .4568 Mdot
.06284 .17409 Mdot
.10288 .49455 Mdot
.57194 .06493 Mdot
.17526 .5589 Mdot
.49605 .0735 Mdot
.1162 .52543 Mdot
.09363 .12401 Mdot
.11336 .50516 Mdot
.84425 .16318 Mdot
.08322 .12644 Mdot
.10988 .4989 Mdot
.90303 .18667 Mdot
.5565 .05564 Mdot
.18975 .56232 Mdot
.48676 .41731 Mdot
.49363 .31913 Mdot
.43225 .46884 Mdot
.48384 .27602 Mdot
.24396 .53641 Mdot
.59759 .38602 Mdot
.49296 .36494 Mdot
.4924 .38695 Mdot
.49783 .35685 Mdot
.48516 .40438 Mdot
.49685 .33315 Mdot
.45663 .44566 Mdot
.48616 .29091 Mdot
.347 .5181 Mdot
.5246 .2787 Mdot
.30967 .0509 Mdot
.11222 .51659 Mdot
.1919 .04656 Mdot
.14325 .52977 Mdot
.42461 .47889 Mdot
.4846 .27139 Mdot
.18331 .52465 Mdot
.45804 .54511 Mdot
.59256 .41867 Mdot
.47847 .29475 Mdot
.40732 .48752 Mdot
.48878 .26946 Mdot
.11281 .47586 Mdot
.5477 .34123 Mdot
.37727 .50375 Mdot
.5023 .26996 Mdot
.07742 .21082 Mdot
.0385 .38202 Mdot
.06734 .45112 Mdot
.0332 .28597 Mdot
.0863 .47673 Mdot
.16453 .06069 Mdot
.13535 .52398 Mdot
.19499 .52966 Mdot
.50448 .51584 Mdot
.55584 .29502 Mdot
.42128 .05784 Mdot
.12006 .52607 Mdot
.18745 .04862 Mdot
.14197 .52887 Mdot
.40232 .49353 Mdot
.49149 .26828 Mdot
.07626 .41551 Mdot
.94477 .20744 Mdot
.6372 .11945 Mdot
.06771 .47539 Mdot
.05415 .42412 Mdot
.03948 .38052 Mdot
.06418 .44607 Mdot
.03215 .31748 Mdot
.08105 .47065 Mdot
.09381 .12358 Mdot
.11346 .50521 Mdot
.84924 .1651 Mdot
.10177 .10368 Mdot
.11658 .50572 Mdot
.91086 .2135 Mdot
.97613 .21916 Mdot
.45783 .43526 Mdot
.48936 .29918 Mdot
.3745 .50605 Mdot
.50463 .27044 Mdot
.09821 .16883 Mdot
.05279 .42843 Mdot
.04799 .40984 Mdot
.0499 .41542 Mdot
.04717 .40779 Mdot
.05143 .41937 Mdot
.04483 .40058 Mdot
.0552 .4283 Mdot
.03955 .38073 Mdot
.06402 .4458 Mdot
.03218 .31886 Mdot
.08079 .47034 Mdot
.09122 .12699 Mdot
.11262 .50439 Mdot
.82931 .15744 Mdot
.04526 .19759 Mdot
.09542 .48219 Mdot
.5501 .05826 Mdot
.18095 .55984 Mdot
.2966 .53386 Mdot
.57163 .31643 Mdot
.05861 .33384 Mdot
.14629 .07235 Mdot
.13002 .51973 Mdot
.08344 .19551 Mdot
.0446 .40526 Mdot
.05871 .43547 Mdot
.03528 .35754 Mdot
.07181 .45835 Mdot
.03992 .2412 Mdot
.09265 .48366 Mdot
.29719 .02107 Mdot
.17012 .54621 Mdot
.52684 .34179 Mdot
.42328 .4751 Mdot
.48482 .27329 Mdot
.20319 .53078 Mdot
.54419 .48305 Mdot
.48711 .2567 Mdot
.08363 .19609 Mdot
.04323 .40075 Mdot
.06066 .4393 Mdot
.03361 .34368 Mdot
.07548 .46353 Mdot
.05319 .19669 Mdot
.09913 .4906 Mdot
.46743 .03665 Mdot
.19013 .55906 Mdot
.52585 .34294 Mdot
.42904 .47058 Mdot
.48416 .27524 Mdot
.23242 .53567 Mdot
.59375 .4089 Mdot
.48572 .31204 Mdot
.43574 .46616 Mdot
.48368 .27737 Mdot
.25939 .53644 Mdot
.59483 .35994 Mdot
.4423 .45747 Mdot
.4845 .28256 Mdot
.29907 .53188 Mdot
.56688 .31119 Mdot
.07238 .22537 Mdot
.03437 .35874 Mdot
.07384 .46093 Mdot
.04743 .21321 Mdot
.09662 .48793 Mdot
.39933 .0246 Mdot
.18692 .55552 Mdot
.54116 .33916 Mdot
.38028 .50228 Mdot
.50061 .26959 Mdot
.06735 .24186 Mdot
.03189 .33317 Mdot
.07926 .4681 Mdot
.08052 .14238 Mdot
.10907 .5009 Mdot
.73982 .12366 Mdot
.06589 .47628 Mdot
.06031 .43652 Mdot
.03281 .33419 Mdot
.07771 .46647 Mdot
.06602 .16767 Mdot
.10403 .49577 Mdot
.6034 .07506 Mdot
.16414 .55606 Mdot
.76148 .13182 Mdot
.04566 .43638 Mdot
.07188 .4548 Mdot
.05211 .1995 Mdot
.09869 .49013 Mdot
.45591 .03419 Mdot
.19017 .55861 Mdot
.52961 .34008 Mdot
.41114 .48386 Mdot
.48742 .27041 Mdot
.13887 .50019 Mdot
.46746 .53559 Mdot
.59401 .34764 Mdot
.36531 .50907 Mdot
.50952 .27215 Mdot
.14638 .11204 Mdot
.07524 .47138 Mdot
.03267 .29494 Mdot
.08484 .47513 Mdot
.14063 .07689 Mdot
.12816 .5183 Mdot
.29866 .05134 Mdot
.1117 .51582 Mdot
.19535 .04505 Mdot
.14423 .53045 Mdot
.43852 .46828 Mdot
.48295 .27596 Mdot
.25252 .53656 Mdot
.59695 .371 Mdot
.477 .4138 Mdot
.49492 .32112 Mdot
.43413 .46723 Mdot
.48377 .27683 Mdot
.25311 .53655 Mdot
.59682 .36998 Mdot
.4748 .41758 Mdot
.49396 .31696 Mdot
.42517 .47448 Mdot
.48453 .27346 Mdot
.20857 .53203 Mdot
.55913 .46751 Mdot
.47139 .25591 Mdot
.14393 .50399 Mdot
.40815 .56705 Mdot
.30537 .59955 Mdot
.26684 .0249 Mdot
.16282 .54222 Mdot
.51761 .35602 Mdot
.46997 .42828 Mdot
.49086 .30622 Mdot
.39902 .49251 Mdot
.4918 .26884 Mdot
.07863 .4212 Mdot
.90674 .21262 Mdot
.96208 .20732 Mdot
.06035 .34678 Mdot
.24095 .02962 Mdot
.15688 .53855 Mdot
.50994 .37432 Mdot
.49178 .38611 Mdot
.49783 .3576 Mdot
.48574 .40316 Mdot
.49704 .33468 Mdot
.45904 .44296 Mdot
.48679 .29307 Mdot
.35602 .5145 Mdot
.51751 .27522 Mdot
.24408 .0613 Mdot
.10132 .50496 Mdot
.1146 .0999 Mdot
.12008 .51138 Mdot
.95042 .21433 Mdot
.09188 .44481 Mdot
.47443 .43301 Mdot
.48896 .30214 Mdot
.39034 .49766 Mdot
.49574 .26878 Mdot
.05871 .33863 Mdot
.1593 .0636 Mdot
.13394 .52282 Mdot
.1422 .50376 Mdot
.44826 .54696 Mdot
.59522 .41117 Mdot
.48365 .30679 Mdot
.42774 .47276 Mdot
.48419 .27417 Mdot
.22027 .53419 Mdot
.58167 .43669 Mdot
.46886 .2739 Mdot
.35675 .51443 Mdot
.51721 .27506 Mdot
.24177 .06193 Mdot
.10085 .50445 Mdot
.11167 .10292 Mdot
.11916 .51054 Mdot
.94697 .20942 Mdot
.30282 .05189 Mdot
.10995 .5145 Mdot
.1677 .05891 Mdot
.13624 .52468 Mdot
.23105 .53673 Mdot
.5909 .41754 Mdot
.47985 .29755 Mdot
.41183 .48448 Mdot
.48738 .27012 Mdot
.13586 .49785 Mdot
.50374 .51009 Mdot
.53147 .27699 Mdot
.58579 .10093 Mdot
.0923 .50612 Mdot
.03348 .33895 Mdot
.07605 .46439 Mdot
.05553 .19074 Mdot
.10007 .49161 Mdot
.49352 .04277 Mdot
.18903 .55982 Mdot
.51603 .35996 Mdot
.47674 .41824 Mdot
.4937 .31665 Mdot
.42499 .47462 Mdot
.48455 .2734 Mdot
.20761 .53182 Mdot
.55669 .47023 Mdot
.47335 .2555 Mdot
.11474 .47813 Mdot
.55435 .34609 Mdot
.39313 .49492 Mdot
.49393 .26892 Mdot
.06561 .38211 Mdot
.50929 .04669 Mdot
.18786 .56015 Mdot
.50725 .3808 Mdot
.49501 .37373 Mdot
.49515 .37624 Mdot
.49584 .37283 Mdot
.49467 .37815 Mdot
.49638 .36987 Mdot
.49343 .38286 Mdot
.49736 .36274 Mdot
.48949 .3945 Mdot
.49795 .34612 Mdot
.47452 .42288 Mdot
.49238 .31179 Mdot
.41379 .48285 Mdot
.4868 .27058 Mdot
.14793 .50663 Mdot
.36805 .58272 Mdot
.5548 .34815 Mdot
.40357 .48846 Mdot
.48973 .2695 Mdot
.1036 .46453 Mdot
.52075 .34846 Mdot
.45216 .4495 Mdot
.48545 .28799 Mdot
.33271 .52314 Mdot
.53667 .28583 Mdot
.35073 .05049 Mdot
.11681 .52147 Mdot
.21665 .03692 Mdot
.15015 .53441 Mdot
.48803 .41533 Mdot
.49418 .32151 Mdot
.43706 .46476 Mdot
.48372 .27814 Mdot
.26658 .5361 Mdot
.5914 .3493 Mdot
.37932 .50216 Mdot
.50077 .2697 Mdot
.06747 .2414 Mdot
.03194 .33403 Mdot
.0791 .4679 Mdot
.07915 .14454 Mdot
.10861 .50044 Mdot
.72758 .11911 Mdot
.07759 .49315 Mdot
.05154 .41755 Mdot
.04299 .39443 Mdot
.05829 .43489 Mdot
.03592 .36179 Mdot
.07054 .45647 Mdot
.0371 .25542 Mdot
.09068 .48153 Mdot
.25113 .02752 Mdot
.15927 .54005 Mdot
.51342 .36592 Mdot
.48463 .40398 Mdot
.49693 .33342 Mdot
.45699 .44525 Mdot
.48625 .29123 Mdot
.34838 .51757 Mdot
.52348 .27812 Mdot
.30112 .05152 Mdot
.11104 .51535 Mdot
.18362 .05044 Mdot
.14088 .52809 Mdot
.38031 .50561 Mdot
.50287 .26964 Mdot
.08782 .18749 Mdot
.04606 .41 Mdot
.0568 .43149 Mdot
.03733 .36999 Mdot
.06793 .45238 Mdot
.03347 .28285 Mdot
.08677 .47725 Mdot
.17254 .0561 Mdot
.13771 .52576 Mdot
.29139 .53471 Mdot
.57595 .32185 Mdot
.08536 .43464 Mdot
.16245 .51633 Mdot
.33751 .59237 Mdot
.68311 .13539 Mdot
.04436 .42926 Mdot
.07138 .45475 Mdot
.04731 .21352 Mdot
.09658 .48787 Mdot
.39851 .02449 Mdot
.18684 .55547 Mdot
.54122 .33918 Mdot
.38023 .50231 Mdot
.50064 .26959 Mdot
.06748 .24136 Mdot
.03194 .3341 Mdot
.07909 .46788 Mdot
.07904 .14471 Mdot
.10857 .5004 Mdot
.72659 .11874 Mdot
.07854 .49437 Mdot
.05078 .41564 Mdot
.04416 .39848 Mdot
.05635 .43083 Mdot
.0381 .37395 Mdot
.06654 .45012 Mdot
.03252 .29628 Mdot
.0847 .47492 Mdot
.1391 .07806 Mdot
.1277 .51792 Mdot
.36836 .05105 Mdot
.11928 .52387 Mdot
.23492 .03144 Mdot
.15503 .5375 Mdot
.50524 .38495 Mdot
.4963 .36621 Mdot
.4918 .38821 Mdot
.49793 .35494 Mdot
.48353 .40764 Mdot
.49623 .3291 Mdot
.44985 .45278 Mdot
.48477 .28563 Mdot
.32094 .5267 Mdot
.54716 .29327 Mdot
.30178 .05151 Mdot
.11101 .51535 Mdot
.18258 .05094 Mdot
.14058 .52787 Mdot
.37344 .50895 Mdot
.50725 .27094 Mdot
.1315 .12599 Mdot
.06946 .46209 Mdot
.03275 .33161 Mdot
.07809 .46701 Mdot
.06838 .16313 Mdot
.10488 .49664 Mdot
.62666 .08289 Mdot
.15335 .55226 Mdot
.42686 .02879 Mdot
.18901 .55717 Mdot
.53681 .33845 Mdot
.38705 .49867 Mdot
.49698 .26902 Mdot
.05783 .31589 Mdot
.08391 .13664 Mdot
.11031 .50198 Mdot
.78003 .13874 Mdot
.03149 .39016 Mdot
.07775 .46139 Mdot
.11301 .1014 Mdot
.11961 .51092 Mdot
.94977 .21248 Mdot
.05869 .31042 Mdot
.08629 .13319 Mdot
.1111 .50276 Mdot
.80029 .14639 Mdot
.02384 .32314 Mdot
.08261 .46619 Mdot
.21919 .03598 Mdot
.15092 .53488 Mdot
.49218 .40898 Mdot
.49571 .32957 Mdot
.45182 .45079 Mdot
.48511 .28704 Mdot
.32859 .52445 Mdot
.5403 .28826 Mdot
.34304 .05028 Mdot
.11606 .52066 Mdot
.21367 .03794 Mdot
.14933 .53388 Mdot
.48369 .42148 Mdot
.49244 .31427 Mdot
.4217 .47715 Mdot
.48507 .27242 Mdot
.19017 .52705 Mdot
.49345 .52349 Mdot
.57542 .3155 Mdot
.06157 .27068 Mdot
.0347 .26687 Mdot
.08936 .47974 Mdot
.23154 .03228 Mdot
.15421 .53697 Mdot
.5034 .38879 Mdot
.49703 .35962 Mdot
.48764 .39905 Mdot
.4976 .34002 Mdot
.46683 .43355 Mdot
.4893 .30126 Mdot
.38478 .50074 Mdot
.49862 .26911 Mdot
.06031 .27793 Mdot
.037 .25285 Mdot
.09122 .48177 Mdot
.27308 .02368 Mdot
.16464 .54316 Mdot
.52035 .35042 Mdot
.45701 .44426 Mdot
.48656 .292 Mdot
.35109 .5165 Mdot
.52132 .27703 Mdot
.28253 .05357 Mdot
.10822 .5124 Mdot
.16302 .06168 Mdot
.13486 .52363 Mdot
.16938 .51985 Mdot
.36434 .58517 Mdot
.52051 .35188 Mdot
.45984 .44102 Mdot
.48735 .29465 Mdot
.36168 .51207 Mdot
.51331 .27343 Mdot
.19586 .07939 Mdot
.09035 .49215 Mdot
.0598 .18087 Mdot
.10171 .49337 Mdot
.53721 .0545 Mdot
.18355 .56008 Mdot
.43355 .47227 Mdot
.48329 .27404 Mdot
.22858 .53529 Mdot
.59095 .41728 Mdot
.48004 .29797 Mdot
.41257 .48398 Mdot
.48717 .27025 Mdot
.13977 .50087 Mdot
.45621 .54241 Mdot
.60022 .38214 Mdot
.49145 .37498 Mdot
.49624 .37185 Mdot
.49423 .37987 Mdot
.49679 .36724 Mdot
.49213 .38712 Mdot
.49786 .3565 Mdot
.48486 .40498 Mdot
.49674 .33239 Mdot
.4554 .44699 Mdot
.48586 .28987 Mdot
.34237 .51982 Mdot
.52841 .28079 Mdot
.33317 .05017 Mdot
.11508 .5196 Mdot
.20961 .03939 Mdot
.14822 .53314 Mdot
.47672 .43049 Mdot
.4897 .30464 Mdot
.39756 .49342 Mdot
.49242 .26878 Mdot
.07364 .40864 Mdot
.87049 .1733 Mdot
.22141 .02914 Mdot
.15624 .53647 Mdot
.51953 .35189 Mdot
.4609 .43981 Mdot
.48766 .29566 Mdot
.3655 .51035 Mdot
.51061 .27238 Mdot
.16349 .09867 Mdot
.08106 .47991 Mdot
.03755 .25329 Mdot
.09095 .48186 Mdot
.25602 .02654 Mdot
.1605 .54077 Mdot
.51517 .36167 Mdot
.47936 .4139 Mdot
.49483 .32152 Mdot
.4354 .46616 Mdot
.48373 .27739 Mdot
.25902 .53645 Mdot
.59497 .3605 Mdot
.44472 .45512 Mdot
.48477 .28408 Mdot
.30914 .52972 Mdot
.55785 .30224 Mdot
.17694 .08994 Mdot
.08485 .48512 Mdot
.04407 .22478 Mdot
.09494 .48616 Mdot
.35338 .02045 Mdot
.18082 .55198 Mdot
.53919 .33865 Mdot
.38226 .50126 Mdot
.49951 .26938 Mdot
.06259 .26337 Mdot
.03231 .28882 Mdot
.08636 .47643 Mdot
.17269 .05602 Mdot
.13775 .52579 Mdot
.29303 .53445 Mdot
.57459 .32009 Mdot
.07267 .405 Mdot
.84526 .16346 Mdot
.08616 .12247 Mdot
.11095 .50003 Mdot
.92174 .19499 Mdot
.81243 .14595 Mdot
.02381 .30954 Mdot
.08349 .46706 Mdot
.24416 .02904 Mdot
.15752 .53899 Mdot
.51063 .37269 Mdot
.49068 .38942 Mdot
.49803 .35288 Mdot
.48161 .41123 Mdot
.49545 .32478 Mdot
.44197 .46034 Mdot
.48388 .28069 Mdot
.28846 .53373 Mdot
.57595 .322 Mdot
.08686 .4375 Mdot
.27094 .53707 Mdot
.5905 .34688 Mdot
.3599 .51155 Mdot
.51334 .27358 Mdot
.19142 .08164 Mdot
.08918 .49069 Mdot
.05585 .19012 Mdot
.10018 .49175 Mdot
.49467 .04305 Mdot
.18895 .55985 Mdot
.5155 .36121 Mdot
.47862 .41515 Mdot
.49452 .32009 Mdot
.43246 .46864 Mdot
.48384 .27612 Mdot
.24508 .53645 Mdot
.59765 .38397 Mdot
.49222 .37089 Mdot
.49493 .37796 Mdot
.49629 .37029 Mdot
.49362 .38217 Mdot
.49724 .36377 Mdot
.49014 .3928 Mdot
.49801 .34846 Mdot
.47715 .41881 Mdot
.49353 .31615 Mdot
.42405 .47535 Mdot
.48468 .27311 Mdot
.2027 .53066 Mdot
.54267 .4845 Mdot
.48916 .2572 Mdot
.10507 .15819 Mdot
.05691 .43799 Mdot
.04301 .39403 Mdot
.05802 .43436 Mdot
.03622 .36365 Mdot
.06997 .45559 Mdot
.03607 .26167 Mdot
.08981 .48059 Mdot
.23206 .03214 Mdot
.15435 .53705 Mdot
.50376 .38807 Mdot
.49692 .36084 Mdot
.4885 .39702 Mdot
.49779 .34271 Mdot
.47038 .42883 Mdot
.49066 .30576 Mdot
.39802 .49312 Mdot
.49222 .2688 Mdot
.07521 .41282 Mdot
.9219 .19495 Mdot
.81281 .14609 Mdot
.02385 .30803 Mdot
.0836 .46719 Mdot
.24694 .02841 Mdot
.15823 .53942 Mdot
.51184 .36977 Mdot
.48839 .39553 Mdot
.49793 .34444 Mdot
.47248 .42587 Mdot
.49152 .3087 Mdot
.40597 .48812 Mdot
.48917 .26939 Mdot
.10794 .4701 Mdot
.53156 .33808 Mdot
.39798 .49236 Mdot
.49197 .26898 Mdot
.07854 .42097 Mdot
.91258 .21392 Mdot
.97499 .22302 Mdot
.47484 .4079 Mdot
.49636 .32643 Mdot
.44376 .45866 Mdot
.48402 .28173 Mdot
.29618 .53243 Mdot
.56941 .31399 Mdot
.05982 .28372 Mdot
.04149 .2323 Mdot
.09397 .48477 Mdot
.34073 .01999 Mdot
.1787 .55083 Mdot
.53708 .33838 Mdot
.38598 .49927 Mdot
.49754 .26909 Mdot
.05807 .30418 Mdot
.06185 .17529 Mdot
.10263 .4941 Mdot
.57478 .06582 Mdot
.17441 .55873 Mdot
.70221 .14259 Mdot
.03444 .39778 Mdot
.07658 .46107 Mdot
.08746 .13211 Mdot
.11139 .50319 Mdot
.79969 .14617 Mdot
.02388 .32538 Mdot
.08245 .46602 Mdot
.21529 .03728 Mdot
.14986 .53419 Mdot
.48714 .41662 Mdot
.49383 .31994 Mdot
.4339 .46746 Mdot
.48377 .27671 Mdot
.25187 .53656 Mdot
.59708 .37207 Mdot
.4791 .40993 Mdot
.49582 .32554 Mdot
.44291 .45947 Mdot
.48395 .28123 Mdot
.29253 .53308 Mdot
.57255 .31769 Mdot
.06153 .36041 Mdot
.30782 .02023 Mdot
.1726 .5475 Mdot
.53036 .33953 Mdot
.40721 .48649 Mdot
.48859 .26981 Mdot
.11877 .48232 Mdot
.56858 .36455 Mdot
.45937 .43995 Mdot
.48774 .29549 Mdot
.36408 .51099 Mdot
.51159 .27275 Mdot
.17529 .09083 Mdot
.08468 .48485 Mdot
.04383 .22564 Mdot
.09482 .48603 Mdot
.35022 .02031 Mdot
.18031 .5517 Mdot
.53871 .33857 Mdot
.38297 .50088 Mdot
.49913 .26931 Mdot
.06128 .27117 Mdot
.03425 .27018 Mdot
.08891 .47925 Mdot
.22201 .0351 Mdot
.15166 .53536 Mdot
.49515 .40412 Mdot
.49662 .33616 Mdot
.46221 .4393 Mdot
.48771 .29613 Mdot
.36765 .50936 Mdot
.50912 .27185 Mdot
.14604 .11233 Mdot
.07511 .47119 Mdot
.03263 .29576 Mdot
.08471 .47498 Mdot
.13869 .07839 Mdot
.12757 .51781 Mdot
.38804 .05285 Mdot
.12042 .52532 Mdot
.22943 .03296 Mdot
.15358 .5366 Mdot
.50134 .3929 Mdot
.49738 .35291 Mdot
.48212 .41035 Mdot
.49565 .32583 Mdot
.44394 .45851 Mdot
.48403 .28182 Mdot
.29686 .53231 Mdot
.56882 .31333 Mdot
.06171 .26966 Mdot
.03429 .26979 Mdot
.08897 .47931 Mdot
.22326 .03471 Mdot
.152 .53558 Mdot
.49644 .40191 Mdot
.49693 .33929 Mdot
.46661 .43386 Mdot
.48921 .30097 Mdot
.38391 .50121 Mdot
.4991 .26919 Mdot
.06175 .26819 Mdot
.03336 .27749 Mdot
.08793 .47817 Mdot
.20196 .04223 Mdot
.14615 .53174 Mdot
.46073 .44825 Mdot
.48489 .28885 Mdot
.34231 .51986 Mdot
.52848 .28083 Mdot
.33356 .05017 Mdot
.11512 .51964 Mdot
.20983 .03931 Mdot
.14828 .53318 Mdot
.47713 .42999 Mdot
.48986 .30515 Mdot
.39897 .49256 Mdot
.49183 .26883 Mdot
.07836 .42057 Mdot
.92199 .21577 Mdot
.79977 .18042 Mdot
.11459 .09124 Mdot
.12115 .51021 Mdot
.52201 .08061 Mdot
.11173 .52264 Mdot
.06045 .17963 Mdot
.10192 .49364 Mdot
.54113 .05563 Mdot
.1828 .56003 Mdot
.40504 .49193 Mdot
.4904 .2684 Mdot
.08597 .43659 Mdot
.17017 .52018 Mdot
.3689 .58375 Mdot
.53241 .34009 Mdot
.40508 .48786 Mdot
.48929 .26955 Mdot
.10857 .47087 Mdot
.53342 .33764 Mdot
.39129 .49632 Mdot
.49492 .26888 Mdot
.06117 .35977 Mdot
.288 .02171 Mdot
.1683 .54515 Mdot
.52506 .34352 Mdot
.43229 .46792 Mdot
.48395 .27653 Mdot
.24816 .53652 Mdot
.59759 .37844 Mdot
.48824 .38804 Mdot
.49819 .35333 Mdot
.48191 .41066 Mdot
.49559 .32545 Mdot
.44324 .45917 Mdot
.48398 .28141 Mdot
.29389 .53284 Mdot
.57139 .31629 Mdot
.0585 .33202 Mdot
.13888 .07788 Mdot
.12776 .51788 Mdot
.31781 .0501 Mdot
.11429 .51849 Mdot
.21411 .03778 Mdot
.14946 .53396 Mdot
.48441 .42049 Mdot
.49273 .3154 Mdot
.42424 .47523 Mdot
.48466 .27316 Mdot
.20355 .53087 Mdot
.5453 .48198 Mdot
.48567 .25638 Mdot
.07206 .22567 Mdot
.03472 .36111 Mdot
.07323 .46007 Mdot
.04514 .22074 Mdot
.09553 .48675 Mdot
.3703 .02155 Mdot
.18338 .5534 Mdot
.54105 .3391 Mdot
.38021 .50232 Mdot
.50065 .26959 Mdot
.06754 .24115 Mdot
.03197 .33448 Mdot
.07902 .46779 Mdot
.07842 .14569 Mdot
.10836 .50019 Mdot
.72108 .1167 Mdot
.08373 .50079 Mdot
.04654 .40389 Mdot
.05111 .41866 Mdot
.04539 .40237 Mdot
.05429 .42623 Mdot
.04076 .38586 Mdot
.06195 .44205 Mdot
.03293 .33561 Mdot
.07736 .46602 Mdot
.06364 .17246 Mdot
.10317 .49487 Mdot
.57942 .06729 Mdot
.17295 .55841 Mdot
.8963 .20999 Mdot
.87599 .17011 Mdot
.20854 .03329 Mdot
.15237 .53404 Mdot
.51402 .36436 Mdot
.48287 .40751 Mdot
.49628 .32907 Mdot
.4497 .45293 Mdot
.48475 .28552 Mdot
.32034 .52687 Mdot
.5477 .29368 Mdot
.29711 .05193 Mdot
.11033 .51464 Mdot
.17769 .05343 Mdot
.13917 .52685 Mdot
.33619 .52381 Mdot
.53628 .2854 Mdot
.35803 .05081 Mdot
.11745 .52218 Mdot
.21824 .03639 Mdot
.15058 .53469 Mdot
.49011 .41221 Mdot
.49497 .32539 Mdot
.44447 .45804 Mdot
.48408 .28212 Mdot
.29898 .5319 Mdot
.56696 .31127 Mdot
.07182 .22711 Mdot
.034 .35596 Mdot
.0745 .46185 Mdot
.0502 .2049 Mdot
.09786 .48925 Mdot
.43282 .02975 Mdot
.18949 .55752 Mdot
.53602 .33845 Mdot
.38893 .49763 Mdot
.49604 .26894 Mdot
.05851 .33591 Mdot
.14739 .07157 Mdot
.13036 .52 Mdot
.06996 .23095 Mdot
.03437 .35854 Mdot
.07381 .46091 Mdot
.0473 .21361 Mdot
.09657 .48787 Mdot
.39775 .02439 Mdot
.18676 .55542 Mdot
.54126 .33919 Mdot
.38019 .50233 Mdot
.50066 .2696 Mdot
.0676 .24092 Mdot
.03199 .33491 Mdot
.07893 .46769 Mdot
.07775 .14677 Mdot
.10813 .49996 Mdot
.71501 .11446 Mdot
.08938 .50721 Mdot
.04197 .38844 Mdot
.05905 .43654 Mdot
.03523 .3572 Mdot
.0719 .45848 Mdot
.04013 .24022 Mdot
.09279 .4838 Mdot
.30051 .02083 Mdot
.17083 .5466 Mdot
.52771 .3411 Mdot
.41907 .47825 Mdot
.48554 .2721 Mdot
.18103 .52378 Mdot
.44523 .55196 Mdot
.55393 .47497 Mdot
.47811 .25521 Mdot
.06726 .38871 Mdot
.58793 .0699 Mdot
.17032 .55781 Mdot
.94288 .20651 Mdot
.79182 .17753 Mdot
.0892 .11939 Mdot
.11218 .50149 Mdot
.93315 .20066 Mdot
.95871 .20518 Mdot
.19422 .08089 Mdot
.08824 .4897 Mdot
.05168 .20096 Mdot
.09846 .48993 Mdot
.44746 .03249 Mdot
.19003 .55824 Mdot
.53217 .33902 Mdot
.40088 .49055 Mdot
.49081 .26915 Mdot
.0897 .44339 Mdot
.38454 .50337 Mdot
.50031 .26905 Mdot
.0697 .23342 Mdot
.03309 .34808 Mdot
.07626 .46424 Mdot
.05909 .18229 Mdot
.10147 .49308 Mdot
.53221 .05307 Mdot
.18443 .56014 Mdot
.45936 .44969 Mdot
.48458 .28774 Mdot
.33717 .52167 Mdot
.53283 .28339 Mdot
.34852 .0504 Mdot
.11663 .52127 Mdot
.21628 .03704 Mdot
.15005 .53434 Mdot
.48753 .41606 Mdot
.49398 .32062 Mdot
.43528 .46629 Mdot
.48373 .27732 Mdot
.25837 .53647 Mdot
.59522 .36152 Mdot
.44891 .45089 Mdot
.48541 .28699 Mdot
.32599 .52524 Mdot
.54262 .28989 Mdot
.33301 .0502 Mdot
.11499 .51952 Mdot
.20842 .03983 Mdot
.14789 .53292 Mdot
.47442 .43327 Mdot
.48886 .30189 Mdot
.38969 .49803 Mdot
.49607 .26881 Mdot
.05825 .33171 Mdot
.13075 .08448 Mdot
.12526 .51578 Mdot
.68553 .13633 Mdot
.04299 .42558 Mdot
.07215 .45577 Mdot
.05109 .20234 Mdot
.09825 .48966 Mdot
.44386 .03179 Mdot
.18993 .55807 Mdot
.53319 .33876 Mdot
.39727 .49277 Mdot
.49225 .26895 Mdot
.07621 .41536 Mdot
.94397 .20688 Mdot
.72411 .152 Mdot
.02573 .34438 Mdot
.08157 .46614 Mdot
.17394 .05531 Mdot
.13813 .52606 Mdot
.30672 .53183 Mdot
.56271 .30673 Mdot
.11615 .14355 Mdot
.06206 .4487 Mdot
.03769 .3714 Mdot
.06718 .4512 Mdot
.03287 .29035 Mdot
.08563 .47598 Mdot
.15345 .0677 Mdot
.13204 .52143 Mdot
.06363 .37605 Mdot
.39909 .02444 Mdot
.18713 .55556 Mdot
.54208 .33944 Mdot
.37968 .50258 Mdot
.50094 .26965 Mdot
.06909 .23549 Mdot
.03274 .34452 Mdot
.07702 .46523 Mdot
.0637 .17233 Mdot
.10319 .49489 Mdot
.58009 .0675 Mdot
.17274 .55837 Mdot
.91064 .21341 Mdot
.97582 .21845 Mdot
.45164 .44288 Mdot
.4875 .2929 Mdot
.35066 .51666 Mdot
.52165 .27719 Mdot
.28546 .05318 Mdot
.10869 .51289 Mdot
.16646 .05963 Mdot
.13588 .52441 Mdot
.21538 .53452 Mdot
.56889 .45574 Mdot
.46645 .25997 Mdot
.25657 .53664 Mdot
.59595 .36481 Mdot
.46074 .43755 Mdot
.48841 .29751 Mdot
.37107 .50774 Mdot
.50684 .27109 Mdot
.12041 .13816 Mdot
.06458 .45345 Mdot
.03553 .35868 Mdot
.07126 .45757 Mdot
.03856 .24767 Mdot
.09175 .48269 Mdot
.27579 .02331 Mdot
.16528 .54352 Mdot
.5211 .34909 Mdot
.45318 .44841 Mdot
.48566 .28879 Mdot
.33667 .52182 Mdot
.53324 .28365 Mdot
.34922 .05043 Mdot
.11669 .52133 Mdot
.21647 .03698 Mdot
.1501 .53437 Mdot
.48778 .41569 Mdot
.49408 .32107 Mdot
.43618 .46552 Mdot
.48372 .27773 Mdot
.26253 .53632 Mdot
.59346 .35517 Mdot
.41834 .47764 Mdot
.48566 .27243 Mdot
.18358 .52475 Mdot
.45961 .54423 Mdot
.59482 .41259 Mdot
.48266 .30433 Mdot
.42377 .47585 Mdot
.48472 .27289 Mdot
.19967 .52987 Mdot
.53256 .49368 Mdot
.50443 .26245 Mdot
.35574 .05063 Mdot
.11741 .52209 Mdot
.22027 .03573 Mdot
.15113 .53504 Mdot
.49259 .40834 Mdot
.49585 .33042 Mdot
.45324 .44932 Mdot
.48538 .28812 Mdot
.33407 .5227 Mdot
.53549 .28506 Mdot
.35117 .0505 Mdot
.11686 .52152 Mdot
.21686 .03685 Mdot
.1502 .53444 Mdot
.48832 .4149 Mdot
.49429 .32203 Mdot
.43809 .46385 Mdot
.48373 .27864 Mdot
.27126 .53576 Mdot
.58864 .34285 Mdot
.32289 .52508 Mdot
.54376 .29082 Mdot
.32263 .05036 Mdot
.11378 .51824 Mdot
.20138 .04255 Mdot
.14593 .53161 Mdot
.4578 .45115 Mdot
.48431 .28666 Mdot
.33173 .52347 Mdot
.53755 .28641 Mdot
.3498 .05045 Mdot
.11672 .52138 Mdot
.21631 .03704 Mdot
.15005 .53435 Mdot
.48757 .416 Mdot
.49399 .32069 Mdot
.43541 .46617 Mdot
.48373 .27738 Mdot
.25899 .53645 Mdot
.59498 .36055 Mdot
.44493 .45492 Mdot
.4848 .28421 Mdot
.30998 .52953 Mdot
.55709 .30154 Mdot
.18734 .08393 Mdot
.0878 .48897 Mdot
.05143 .20163 Mdot
.09836 .48982 Mdot
.44466 .03194 Mdot
.18996 .55811 Mdot
.53296 .33881 Mdot
.39803 .49231 Mdot
.49194 .26898 Mdot
.07882 .42163 Mdot
.89356 .20935 Mdot
.85 .16022 Mdot
.07701 .1352 Mdot
.10757 .49639 Mdot
.85683 .16804 Mdot
.13657 .07185 Mdot
.12879 .51677 Mdot
.1715 .52083 Mdot
.3756 .58156 Mdot
.55759 .35088 Mdot
.41375 .48152 Mdot
.48668 .27111 Mdot
.15582 .51157 Mdot
.3346 .5928 Mdot
.84354 .19418 Mdot
.3547 .01579 Mdot
.18838 .55363 Mdot
.56998 .36839 Mdot
.46901 .42741 Mdot
.4912 .30691 Mdot
.40038 .49167 Mdot
.49125 .26891 Mdot
.08369 .43211 Mdot
.05997 .27703 Mdot
.03492 .26544 Mdot
.08954 .47995 Mdot
.23512 .03131 Mdot
.15515 .53755 Mdot
.50576 .38382 Mdot
.49601 .36819 Mdot
.49282 .38502 Mdot
.49765 .35958 Mdot
.48729 .39979 Mdot
.49751 .33904 Mdot
.46547 .43527 Mdot
.48881 .29968 Mdot
.37977 .50339 Mdot
.50144 .26964 Mdot
.07315 .22253 Mdot
.03537 .36541 Mdot
.07213 .4585 Mdot
.04163 .23386 Mdot
.09367 .48476 Mdot
.32252 .01992 Mdot
.17533 .54903 Mdot
.5332 .33862 Mdot
.39658 .49319 Mdot
.49254 .26893 Mdot
.07394 .40946 Mdot
.88143 .17766 Mdot
.31333 .01492 Mdot
.18049 .54965 Mdot
.56119 .35395 Mdot
.42456 .47341 Mdot
.48468 .27404 Mdot
.21344 .53302 Mdot
.57006 .45416 Mdot
.4662 .2608 Mdot
.26851 .53611 Mdot
.59048 .34699 Mdot
.36085 .51113 Mdot
.51266 .27331 Mdot
.18339 .08601 Mdot
.08699 .4879 Mdot
.04939 .20745 Mdot
.09748 .48888 Mdot
.42061 .02768 Mdot
.18876 .55685 Mdot
.53854 .33861 Mdot
.38364 .50052 Mdot
.49876 .26926 Mdot
.06023 .27861 Mdot
.03734 .25104 Mdot
.09146 .48204 Mdot
.27874 .02292 Mdot
.16597 .54391 Mdot
.52192 .34774 Mdot
.44891 .45279 Mdot
.48488 .28563 Mdot
.32015 .52692 Mdot
.54787 .29382 Mdot
.29556 .05208 Mdot
.1101 .5144 Mdot
.17602 .0543 Mdot
.13868 .52649 Mdot
.32145 .52823 Mdot
.5494 .29488 Mdot
.28668 .05308 Mdot
.10874 .51297 Mdot
.16599 .0599 Mdot
.13574 .5243 Mdot
.20932 .53332 Mdot
.55467 .47246 Mdot
.4752 .25532 Mdot
.09237 .44803 Mdot
.45198 .4565 Mdot
.48348 .2829 Mdot
.31028 .52947 Mdot
.55684 .30132 Mdot
.19076 .0821 Mdot
.08873 .49015 Mdot
.05419 .19429 Mdot
.09951 .49104 Mdot
.4762 .03862 Mdot
.18993 .55936 Mdot
.52281 .34666 Mdot
.44491 .45669 Mdot
.48435 .28301 Mdot
.30406 .53087 Mdot
.56244 .3066 Mdot
.1165 .14312 Mdot
.06223 .44903 Mdot
.03753 .37058 Mdot
.06747 .45166 Mdot
.03307 .28758 Mdot
.08606 .47645 Mdot
.16038 .06322 Mdot
.13412 .52304 Mdot
.13851 .50102 Mdot
.49356 .51786 Mdot
.55121 .29131 Mdot
.48029 .06995 Mdot
.11704 .5256 Mdot
.10873 .10612 Mdot
.11821 .5097 Mdot
.93719 .20289 Mdot
.9761 .22267 Mdot
.47548 .40652 Mdot
.49664 .32799 Mdot
.44666 .45589 Mdot
.48433 .28351 Mdot
.30823 .52994 Mdot
.55868 .303 Mdot
.16563 .09731 Mdot
.08141 .48043 Mdot
.03795 .25114 Mdot
.09125 .48219 Mdot
.2628 .0253 Mdot
.16217 .54175 Mdot
.51735 .35659 Mdot
.47106 .42677 Mdot
.4913 .30772 Mdot
.40311 .48996 Mdot
.4902 .26911 Mdot
.09487 .45193 Mdot
.48604 .41788 Mdot
.49348 .31841 Mdot
.43068 .47013 Mdot
.48394 .27539 Mdot
.23632 .53599 Mdot
.59575 .40082 Mdot
.49045 .32811 Mdot
.45881 .44353 Mdot
.48662 .29261 Mdot
.35432 .5152 Mdot
.51881 .27582 Mdot
.25791 .05793 Mdot
.10397 .50787 Mdot
.13235 .08359 Mdot
.1256 .51618 Mdot
.68529 .13624 Mdot
.04312 .42594 Mdot
.07208 .45568 Mdot
.05071 .2034 Mdot
.09809 .48949 Mdot
.43945 .03095 Mdot
.18978 .55786 Mdot
.53438 .33856 Mdot
.39347 .49502 Mdot
.4939 .26887 Mdot
.06546 .38146 Mdot
.50155 .04468 Mdot
.18863 .56004 Mdot
.51258 .36829 Mdot
.487 .39883 Mdot
.49764 .34004 Mdot
.46679 .43359 Mdot
.48929 .30122 Mdot
.38466 .5008 Mdot
.49868 .26912 Mdot
.06049 .27662 Mdot
.03638 .2563 Mdot
.09076 .48128 Mdot
.26252 .02534 Mdot
.1621 .54171 Mdot
.51727 .35677 Mdot
.4714 .42629 Mdot
.49144 .3082 Mdot
.40439 .48914 Mdot
.48973 .26923 Mdot
.10058 .4604 Mdot
.51375 .36404 Mdot
.48268 .4079 Mdot
.4962 .32859 Mdot
.44886 .45377 Mdot
.48462 .28494 Mdot
.31701 .52777 Mdot
.55072 .29609 Mdot
.26702 .05615 Mdot
.10545 .50948 Mdot
.14206 .07589 Mdot
.12856 .51865 Mdot
.25185 .0589 Mdot
.10388 .50759 Mdot
.13551 .08099 Mdot
.12657 .517 Mdot
.55247 .08973 Mdot
.10436 .51714 Mdot
.03738 .25497 Mdot
.09066 .48162 Mdot
.24762 .02828 Mdot
.15838 .53952 Mdot
.51203 .3693 Mdot
.48797 .39655 Mdot
.49786 .34307 Mdot
.47079 .42826 Mdot
.49082 .30631 Mdot
.39955 .49219 Mdot
.49158 .26887 Mdot
.08054 .42549 Mdot
.6452 .12141 Mdot
.06548 .47205 Mdot
.05628 .42882 Mdot
.03672 .36673 Mdot
.06906 .45417 Mdot
.03471 .27131 Mdot
.08845 .4791 Mdot
.20399 .04144 Mdot
.14671 .53212 Mdot
.4658 .44299 Mdot
.48613 .2931 Mdot
.36016 .51275 Mdot
.51443 .27389 Mdot
.2092 .07328 Mdot
.09368 .4962 Mdot
.07302 .15484 Mdot
.10649 .49833 Mdot
.66904 .09774 Mdot
.1273 .539 Mdot
.06646 .16721 Mdot
.10413 .49596 Mdot
.60134 .07438 Mdot
.16498 .55632 Mdot
.79021 .14264 Mdot
.02615 .35835 Mdot
.0802 .46373 Mdot
.16129 .06263 Mdot
.1344 .52325 Mdot
.15256 .5107 Mdot
.34885 .58876 Mdot
.46451 .44466 Mdot
.48569 .2917 Mdot
.35481 .51502 Mdot
.51845 .27565 Mdot
.2542 .05876 Mdot
.10328 .50712 Mdot
.12759 .08766 Mdot
.12413 .51493 Mdot
.82983 .18961 Mdot
.25408 .02152 Mdot
.16534 .54187 Mdot
.5323 .33874 Mdot
.39926 .49156 Mdot
.49145 .26905 Mdot
.08327 .43125 Mdot
.08059 .20194 Mdot
.04242 .39778 Mdot
.06172 .44133 Mdot
.03293 .33558 Mdot
.07737 .46604 Mdot
.06372 .17229 Mdot
.1032 .4949 Mdot
.58026 .06755 Mdot
.17268 .55835 Mdot
.91382 .21409 Mdot
.97112 .22455 Mdot
.47378 .41015 Mdot
.49589 .32395 Mdot
.43893 .46306 Mdot
.48375 .2791 Mdot
.27526 .53539 Mdot
.58601 .33761 Mdot
.2666 .53525 Mdot
.59038 .34688 Mdot
.35995 .51153 Mdot
.5133 .27357 Mdot
.19102 .08185 Mdot
.08908 .49056 Mdot
.05551 .19097 Mdot
.10004 .49161 Mdot
.49088 .04212 Mdot
.18921 .55976 Mdot
.51719 .35728 Mdot
.47223 .4251 Mdot
.49178 .3094 Mdot
.40754 .48709 Mdot
.48864 .26958 Mdot
.11562 .47898 Mdot
.55806 .34966 Mdot
.40718 .48604 Mdot
.48852 .26996 Mdot
.12143 .48502 Mdot
.57467 .38127 Mdot
.48897 .38766 Mdot
.49813 .35417 Mdot
.48272 .40916 Mdot
.49592 .32724 Mdot
.44654 .45603 Mdot
.4843 .28342 Mdot
.30765 .53007 Mdot
.5592 .30349 Mdot
.15856 .10241 Mdot
.07911 .47718 Mdot
.0352 .2681 Mdot
.08886 .4796 Mdot
.21134 .03869 Mdot
.14875 .53347 Mdot
.48074 .4254 Mdot
.49126 .30994 Mdot
.41143 .4845 Mdot
.48745 .27015 Mdot
.13535 .49744 Mdot
.50954 .5054 Mdot
.52054 .27056 Mdot
.53813 .0857 Mdot
.1072 .51925 Mdot
.04384 .22598 Mdot
.09475 .48602 Mdot
.3463 .02016 Mdot
.17965 .55135 Mdot
.53807 .33848 Mdot
.38404 .50031 Mdot
.49855 .26922 Mdot
.05969 .28302 Mdot
.03987 .23905 Mdot
.09306 .48378 Mdot
.31754 .02002 Mdot
.17435 .5485 Mdot
.53202 .33891 Mdot
.40072 .49065 Mdot
.49087 .26914 Mdot
.08906 .44225 Mdot
.35918 .5152 Mdot
.51733 .27492 Mdot
.25006 .05975 Mdot
.10249 .50626 Mdot
.12231 .09243 Mdot
.12249 .51351 Mdot
.916 .21457 Mdot
.95347 .22468 Mdot
.40621 .4834 Mdot
.48831 .27097 Mdot
.13563 .49766 Mdot
.50624 .50809 Mdot
.52672 .27407 Mdot
.57367 .0969 Mdot
.09672 .5104 Mdot
.03237 .31221 Mdot
.0817 .47154 Mdot
.09937 .11663 Mdot
.11526 .50692 Mdot
.88877 .18074 Mdot
.38841 .01843 Mdot
.19399 .55638 Mdot
.57342 .37789 Mdot
.48538 .39773 Mdot
.49783 .3407 Mdot
.46753 .43263 Mdot
.48956 .30211 Mdot
.38741 .49929 Mdot
.49722 .26892 Mdot
.05796 .30722 Mdot
.06674 .16541 Mdot
.10441 .49597 Mdot
.62358 .08183 Mdot
.15491 .55287 Mdot
.46938 .03716 Mdot
.18995 .5591 Mdot
.5248 .34406 Mdot
.43443 .46612 Mdot
.48389 .27746 Mdot
.25824 .53647 Mdot
.59526 .36172 Mdot
.44968 .45009 Mdot
.48555 .28756 Mdot
.32901 .52432 Mdot
.53993 .28801 Mdot
.34427 .0503 Mdot
.11618 .52079 Mdot
.2142 .03776 Mdot
.14948 .53397 Mdot
.4845 .42035 Mdot
.49277 .31555 Mdot
.42457 .47497 Mdot
.48461 .27326 Mdot
.20531 .53129 Mdot
.55047 .47682 Mdot
.47947 .25543 Mdot
.06166 .36308 Mdot
.31209 .02005 Mdot
.17348 .54797 Mdot
.53145 .3391 Mdot
.40287 .4893 Mdot
.49007 .26932 Mdot
.09822 .45702 Mdot
.50634 .38184 Mdot
.49545 .37158 Mdot
.49434 .37963 Mdot
.49673 .36763 Mdot
.49234 .38648 Mdot
.4978 .35743 Mdot
.48562 .40342 Mdot
.497 .33436 Mdot
.45854 .44352 Mdot
.48665 .29261 Mdot
.35416 .51527 Mdot
.51893 .27588 Mdot
.25918 .05765 Mdot
.10421 .50812 Mdot
.13399 .08223 Mdot
.1261 .51661 Mdot
.61974 .11224 Mdot
.07861 .49072 Mdot
.04429 .39709 Mdot
.05517 .42831 Mdot
.03967 .38124 Mdot
.06382 .44544 Mdot
.03221 .32055 Mdot
.08047 .46994 Mdot
.0881 .13125 Mdot
.11159 .5034 Mdot
.80431 .14792 Mdot
.02396 .30767 Mdot
.08371 .46743 Mdot
.2471 .02837 Mdot
.15827 .53945 Mdot
.51191 .36961 Mdot
.48825 .39587 Mdot
.4979 .34398 Mdot
.47192 .42668 Mdot
.49129 .30789 Mdot
.40382 .48951 Mdot
.48994 .26917 Mdot
.098 .4567 Mdot
.50546 .3838 Mdot
.49604 .36808 Mdot
.49277 .38521 Mdot
.49767 .3593 Mdot
.48708 .40026 Mdot
.49746 .33842 Mdot
.4646 .43636 Mdot
.48851 .2987 Mdot
.37656 .50504 Mdot
.50337 .2701 Mdot
.08717 .18879 Mdot
.0456 .40859 Mdot
.05742 .43279 Mdot
.03663 .36609 Mdot
.06921 .45442 Mdot
.03491 .26973 Mdot
.08867 .47935 Mdot
.20848 .03973 Mdot
.14796 .53295 Mdot
.47553 .43194 Mdot
.48926 .30319 Mdot
.39348 .49585 Mdot
.49424 .26872 Mdot
.06311 .37077 Mdot
.38507 .02279 Mdot
.18556 .55458 Mdot
.54257 .3396 Mdot
.3794 .50272 Mdot
.5011 .26969 Mdot
.06996 .23253 Mdot
.03324 .34954 Mdot
.07594 .46381 Mdot
.0573 .18646 Mdot
.10077 .49235 Mdot
.51292 .04777 Mdot
.18721 .56012 Mdot
.5028 .39023 Mdot
.49719 .35728 Mdot
.48587 .40295 Mdot
.49708 .33496 Mdot
.45948 .44246 Mdot
.48691 .29347 Mdot
.35764 .51382 Mdot
.51629 .27468 Mdot
.23055 .06532 Mdot
.09852 .50183 Mdot
.09763 .11886 Mdot
.11468 .50639 Mdot
.87514 .17525 Mdot
.25905 .02027 Mdot
.16701 .54269 Mdot
.53599 .33824 Mdot
.38796 .49817 Mdot
.49653 .26898 Mdot
.05798 .32554 Mdot
.10974 .10441 Mdot
.11868 .50997 Mdot
.94604 .20866 Mdot
.43748 .06111 Mdot
.11873 .52558 Mdot
.15626 .06596 Mdot
.13283 .52207 Mdot
.08205 .43027 Mdot
.50207 .0751 Mdot
.11526 .52488 Mdot
.0848 .13618 Mdot
.11046 .50234 Mdot
.77274 .13599 Mdot
.03655 .40998 Mdot
.07575 .45936 Mdot
.08473 .13602 Mdot
.11048 .5023 Mdot
.77691 .13756 Mdot
.03355 .3989 Mdot
.07693 .46059 Mdot
.10029 .11549 Mdot
.11557 .5072 Mdot
.89539 .18347 Mdot
.46272 .03098 Mdot
.19941 .56063 Mdot
.56084 .35367 Mdot
.42358 .47417 Mdot
.48481 .27372 Mdot
.20839 .53199 Mdot
.5587 .468 Mdot
.47172 .25582 Mdot
.1386 .50008 Mdot
.47274 .53223 Mdot
.58754 .33376 Mdot
.21309 .53222 Mdot
.57242 .45091 Mdot
.46596 .26267 Mdot
.29041 .53358 Mdot
.5746 .32023 Mdot
.07376 .40807 Mdot
.88669 .17978 Mdot
.36503 .0162 Mdot
.19053 .55458 Mdot
.57235 .37444 Mdot
.48058 .40825 Mdot
.49617 .32767 Mdot
.44694 .45564 Mdot
.48436 .28368 Mdot
.30932 .52969 Mdot
.55769 .30209 Mdot
.17911 .08862 Mdot
.08548 .48596 Mdot
.04547 .21985 Mdot
.09565 .48692 Mdot
.37183 .02167 Mdot
.18359 .55352 Mdot
.54115 .33913 Mdot
.38013 .50236 Mdot
.50069 .2696 Mdot
.06776 .2403 Mdot
.03207 .33602 Mdot
.07872 .46742 Mdot
.076 .14963 Mdot
.10754 .49936 Mdot
.69906 .1086 Mdot
.10359 .5212 Mdot
.03311 .33309 Mdot
.0773 .46608 Mdot
.06249 .17486 Mdot
.10274 .49442 Mdot
.56764 .06359 Mdot
.1765 .55914 Mdot
.17769 .08885 Mdot
.0866 .48724 Mdot
.0491 .20831 Mdot
.09735 .48874 Mdot
.41716 .02714 Mdot
.18851 .55665 Mdot
.53912 .3387 Mdot
.3827 .50102 Mdot
.49927 .26934 Mdot
.06173 .26833 Mdot
.0334 .27714 Mdot
.08797 .47822 Mdot
.2029 .04186 Mdot
.14641 .53191 Mdot
.46315 .44577 Mdot
.48545 .2908 Mdot
.35091 .51659 Mdot
.52148 .2771 Mdot
.28402 .05337 Mdot
.10846 .51265 Mdot
.16478 .06062 Mdot
.13538 .52403 Mdot
.19326 .52914 Mdot
.49669 .52131 Mdot
.56999 .30906 Mdot
.12713 .13082 Mdot
.06709 .45804 Mdot
.03388 .3455 Mdot
.07486 .46271 Mdot
.05021 .20489 Mdot
.09787 .48926 Mdot
.43283 .02975 Mdot
.18949 .55752 Mdot
.53602 .33845 Mdot
.38894 .49762 Mdot
.49604 .26894 Mdot
.05851 .33597 Mdot
.14765 .07138 Mdot
.13043 .52006 Mdot
.06754 .23935 Mdot
.03279 .34478 Mdot
.07692 .46512 Mdot
.06305 .17369 Mdot
.10295 .49464 Mdot
.57342 .06539 Mdot
.17482 .55882 Mdot
.60979 .10874 Mdot
.08328 .49641 Mdot
.04004 .38104 Mdot
.06261 .44335 Mdot
.03264 .33096 Mdot
.07837 .46732 Mdot
.07052 .15915 Mdot
.10564 .49742 Mdot
.64748 .0901 Mdot
.14163 .54702 Mdot
.19132 .04689 Mdot
.14304 .52964 Mdot
.42022 .48199 Mdot
.48555 .2704 Mdot
.16007 .514 Mdot
.33794 .59224 Mdot
.58404 .09992 Mdot
.09402 .50791 Mdot
.03287 .33025 Mdot
.07805 .46703 Mdot
.06757 .16465 Mdot
.10459 .49635 Mdot
.61876 .0802 Mdot
.15727 .55376 Mdot
.53808 .05482 Mdot
.18323 .56003 Mdot
.42447 .47904 Mdot
.48463 .27133 Mdot
.18223 .52424 Mdot
.45197 .54841 Mdot
.57922 .44377 Mdot
.46629 .26697 Mdot
.32606 .52542 Mdot
.54287 .29006 Mdot
.33246 .0502 Mdot
.11493 .51945 Mdot
.20808 .03995 Mdot
.14779 .53286 Mdot
.47373 .4341 Mdot
.48862 .3011 Mdot
.38732 .49936 Mdot
.49728 .26893 Mdot
.058 .30589 Mdot
.06454 .16974 Mdot
.10362 .49514 Mdot
.60186 .07455 Mdot
.16477 .55626 Mdot
.78297 .13991 Mdot
.02965 .38118 Mdot
.0785 .46212 Mdot
.12633 .08866 Mdot
.12378 .5146 Mdot
.8486 .19589 Mdot
.39796 .01985 Mdot
.19477 .55698 Mdot
.57233 .37443 Mdot
.48055 .4083 Mdot
.49616 .32761 Mdot
.44683 .45575 Mdot
.48434 .28361 Mdot
.30887 .52979 Mdot
.55811 .30247 Mdot
.17347 .0921 Mdot
.08382 .48374 Mdot
.04197 .23276 Mdot
.09381 .48495 Mdot
.32454 .01989 Mdot
.17572 .54923 Mdot
.53367 .33853 Mdot
.39506 .4941 Mdot
.4932 .26889 Mdot
.06944 .39607 Mdot
.69224 .10602 Mdot
.10959 .52631 Mdot
.03262 .30082 Mdot
.08365 .47386 Mdot
.12232 .09233 Mdot
.12252 .51352 Mdot
.91271 .21389 Mdot
.9749 .22308 Mdot
.47493 .40772 Mdot
.4964 .32664 Mdot
.44415 .45829 Mdot
.48406 .28196 Mdot
.29783 .53212 Mdot
.56797 .31238 Mdot
.06559 .24978 Mdot
.03134 .31477 Mdot
.08247 .47198 Mdot
.11422 .10019 Mdot
.11999 .51127 Mdot
.95041 .21421 Mdot
.08855 .43898 Mdot
.4051 .49174 Mdot
.49033 .26844 Mdot
.08698 .43847 Mdot
.24347 .53757 Mdot
.59721 .39177 Mdot
.49337 .34938 Mdot
.48196 .411 Mdot
.4955 .3251 Mdot
.4426 .45976 Mdot
.48393 .28105 Mdot
.29118 .5333 Mdot
.57369 .31908 Mdot
.06727 .38745 Mdot
.59947 .07366 Mdot
.16599 .55664 Mdot
.82217 .15477 Mdot
.03488 .23061 Mdot
.09093 .47649 Mdot
.43265 .0297 Mdot
.18951 .55752 Mdot
.53615 .33845 Mdot
.3886 .49781 Mdot
.4962 .26895 Mdot
.05829 .33244 Mdot
.13351 .08218 Mdot
.12611 .5165 Mdot
.57087 .0956 Mdot
.09865 .51226 Mdot
.03258 .30031 Mdot
.0838 .47401 Mdot
.12471 .09014 Mdot
.12326 .51416 Mdot
.88046 .2057 Mdot
.71276 .10912 Mdot
.10256 .52069 Mdot
.03393 .343 Mdot
.07488 .46284 Mdot
.04989 .20579 Mdot
.09773 .48911 Mdot
.42907 .02909 Mdot
.18929 .55732 Mdot
.53687 .33846 Mdot
.38692 .49874 Mdot
.49705 .26903 Mdot
.05783 .31453 Mdot
.08089 .14118 Mdot
.10929 .50097 Mdot
.75413 .12901 Mdot
.05238 .45169 Mdot
.06855 .45024 Mdot
.03876 .24653 Mdot
.09192 .48286 Mdot
.28007 .02276 Mdot
.16628 .54409 Mdot
.52227 .34718 Mdot
.44702 .45466 Mdot
.4846 .28436 Mdot
.31262 .52889 Mdot
.5547 .29943 Mdot
.21919 .06938 Mdot
.09578 .49871 Mdot
.08252 .13945 Mdot
.10972 .50158 Mdot
.75513 .12938 Mdot
.05146 .44974 Mdot
.06904 .45094 Mdot
.04013 .24014 Mdot
.0928 .48381 Mdot
.30136 .02077 Mdot
.17101 .5467 Mdot
.52793 .34094 Mdot
.41802 .47901 Mdot
.48575 .27184 Mdot
.17544 .5215 Mdot
.41221 .56755 Mdot
.25419 .60332 Mdot
.03306 .30342 Mdot
.08257 .47283 Mdot
.10602 .10892 Mdot
.11739 .5089 Mdot
.92739 .19773 Mdot
.89096 .17573 Mdot
.33303 .01472 Mdot
.18474 .55171 Mdot
.56746 .36333 Mdot
.45605 .44383 Mdot
.48679 .29232 Mdot
.35156 .51631 Mdot
.52095 .27684 Mdot
.27904 .05407 Mdot
.10766 .5118 Mdot
.15885 .06427 Mdot
.13362 .52268 Mdot
.11355 .47788 Mdot
.54491 .33977 Mdot
.37485 .50502 Mdot
.50379 .27032 Mdot
.08896 .18524 Mdot
.04684 .41236 Mdot
.05575 .42921 Mdot
.0386 .3764 Mdot
.06567 .44866 Mdot
.03222 .30435 Mdot
.08338 .4734 Mdot
.12071 .09383 Mdot
.12202 .51308 Mdot
.92785 .21664 Mdot
.46789 .06744 Mdot
.11713 .52529 Mdot
.11746 .09712 Mdot
.12096 .51218 Mdot
.94708 .21717 Mdot
.1327 .49337 Mdot
.50722 .50731 Mdot
.5249 .273 Mdot
.56559 .09427 Mdot
.09943 .51285 Mdot
.03291 .29332 Mdot
.08496 .47533 Mdot
.14108 .07654 Mdot
.1283 .51841 Mdot
.27905 .05366 Mdot
.10868 .51268 Mdot
.17193 .05652 Mdot
.13749 .52561 Mdot
.28075 .53617 Mdot
.58418 .33419 Mdot
.22552 .53418 Mdot
.58963 .42056 Mdot
.47783 .29313 Mdot
.4038 .4898 Mdot
.49002 .26909 Mdot
.09637 .45425 Mdot
.49723 .40007 Mdot
.49715 .34189 Mdot
.47002 .42936 Mdot
.4905 .30524 Mdot
.39657 .494 Mdot
.49284 .26875 Mdot
.0707 .4001 Mdot
.74955 .1272 Mdot
.05684 .46058 Mdot
.06608 .44648 Mdot
.03404 .27687 Mdot
.08766 .47822 Mdot
.18908 .04777 Mdot
.1425 .52922 Mdot
.41361 .48645 Mdot
.48738 .26926 Mdot
.12557 .48899 Mdot
.5748 .41349 Mdot
.48675 .31269 Mdot
.43446 .46721 Mdot
.48372 .27683 Mdot
.25355 .53655 Mdot
.59671 .36926 Mdot
.47314 .42028 Mdot
.49323 .31408 Mdot
.4185 .47948 Mdot
.48569 .2716 Mdot
.17328 .52055 Mdot
.39932 .57287 Mdot
.3343 .59212 Mdot
.18862 .08261 Mdot
.08967 .49115 Mdot
.05856 .18368 Mdot
.10124 .49287 Mdot
.52411 .05081 Mdot
.18572 .56017 Mdot
.4849 .41992 Mdot
.49289 .31606 Mdot
.42571 .47409 Mdot
.48445 .27362 Mdot
.21119 .53258 Mdot
.5653 .46024 Mdot
.46768 .258 Mdot
.21838 .534 Mdot
.57846 .44201 Mdot
.46708 .26911 Mdot
.33637 .52214 Mdot
.5338 .28398 Mdot
.35087 .05049 Mdot
.11684 .5215 Mdot
.21691 .03683 Mdot
.15022 .53445 Mdot
.48838 .41481 Mdot
.49431 .32215 Mdot
.43831 .46366 Mdot
.48373 .27875 Mdot
.27228 .53567 Mdot
.58799 .34148 Mdot
.30911 .52874 Mdot
.55623 .30087 Mdot
.196 .07943 Mdot
.09012 .4919 Mdot
.05873 .18329 Mdot
.1013 .49294 Mdot
.52585 .05129 Mdot
.18546 .56017 Mdot
.48063 .42567 Mdot
.49117 .30966 Mdot
.41077 .48495 Mdot
.48765 .27004 Mdot
.13188 .49458 Mdot
.54341 .47241 Mdot
.47301 .25685 Mdot
.13656 .49849 Mdot
.49734 .51504 Mdot
.54389 .28555 Mdot
.55238 .09011 Mdot
.10333 .51618 Mdot
.03623 .2619 Mdot
.08968 .48056 Mdot
.22638 .03377 Mdot
.15284 .53611 Mdot
.49933 .39672 Mdot
.49737 .34697 Mdot
.47608 .42054 Mdot
.49304 .31427 Mdot
.41975 .47858 Mdot
.48543 .27191 Mdot
.17989 .52333 Mdot
.43864 .5553 Mdot
.5158 .50857 Mdot
.53908 .28174 Mdot
.59048 .10253 Mdot
.09044 .50422 Mdot
.03447 .34878 Mdot
.07352 .46091 Mdot
.04473 .22217 Mdot
.09533 .48654 Mdot
.36486 .02114 Mdot
.1826 .55296 Mdot
.54058 .33897 Mdot
.38061 .50211 Mdot
.50042 .26955 Mdot
.06644 .24542 Mdot
.03158 .3265 Mdot
.08048 .4696 Mdot
.09184 .12615 Mdot
.11282 .50459 Mdot
.83428 .15934 Mdot
.05525 .17386 Mdot
.09939 .48705 Mdot
.65396 .09237 Mdot
.13758 .54495 Mdot
.14145 .07644 Mdot
.12834 .51849 Mdot
.29376 .05181 Mdot
.11098 .51507 Mdot
.18983 .04749 Mdot
.14267 .52935 Mdot
.4152 .4854 Mdot
.4869 .2695 Mdot
.1337 .49611 Mdot
.52692 .48989 Mdot
.49159 .25841 Mdot
.12351 .13454 Mdot
.06611 .45625 Mdot
.03444 .35048 Mdot
.07357 .46091 Mdot
.04513 .22077 Mdot
.09553 .48675 Mdot
.37012 .02153 Mdot
.18335 .55338 Mdot
.54104 .3391 Mdot
.38022 .50231 Mdot
.50064 .26959 Mdot
.06751 .24126 Mdot
.03196 .33428 Mdot
.07905 .46784 Mdot
.07875 .14517 Mdot
.10847 .5003 Mdot
.724 .11778 Mdot
.08099 .49747 Mdot
.04879 .41036 Mdot
.04736 .40846 Mdot
.0512 .41877 Mdot
.04518 .4017 Mdot
.05464 .42703 Mdot
.04029 .38392 Mdot
.06275 .44352 Mdot
.03255 .32933 Mdot
.07871 .46776 Mdot
.07311 .15456 Mdot
.10654 .49834 Mdot
.67206 .09882 Mdot
.12511 .5376 Mdot
.05752 .18644 Mdot
.10078 .49246 Mdot
.50815 .04651 Mdot
.18774 .56007 Mdot
.50728 .38072 Mdot
.49498 .37387 Mdot
.4952 .37602 Mdot
.49577 .37317 Mdot
.4948 .37761 Mdot
.49623 .3707 Mdot
.4938 .38154 Mdot
.49713 .36472 Mdot
.49072 .39123 Mdot
.49802 .35064 Mdot
.47945 .41502 Mdot
.49453 .32038 Mdot
.4332 .46802 Mdot
.4838 .27642 Mdot
.24864 .53653 Mdot
.59755 .37761 Mdot
.48735 .39078 Mdot
.49823 .34961 Mdot
.47821 .41708 Mdot
.49399 .31806 Mdot
.42826 .47206 Mdot
.48416 .2745 Mdot
.22434 .53477 Mdot
.58682 .42693 Mdot
.47378 .28463 Mdot
.38657 .50003 Mdot
.49781 .26895 Mdot
.0587 .29351 Mdot
.04843 .20867 Mdot
.09731 .4884 Mdot
.4285 .02899 Mdot
.18926 .55729 Mdot
.53699 .33847 Mdot
.38664 .4989 Mdot
.49719 .26905 Mdot
.05786 .3115 Mdot
.07459 .15129 Mdot
.10716 .4988 Mdot
.69787 .10817 Mdot
.10461 .5221 Mdot
.03282 .328 Mdot
.07844 .46754 Mdot
.07008 .15996 Mdot
.10548 .49726 Mdot
.64319 .0886 Mdot
.14421 .54827 Mdot
.23088 .03259 Mdot
.15392 .53683 Mdot
.50217 .39127 Mdot
.49729 .35553 Mdot
.48443 .40591 Mdot
.49657 .33123 Mdot
.4535 .44902 Mdot
.48545 .28834 Mdot
.33514 .52234 Mdot
.53457 .28448 Mdot
.35081 .05048 Mdot
.11683 .52149 Mdot
.21684 .03686 Mdot
.1502 .53444 Mdot
.48828 .41495 Mdot
.49428 .32197 Mdot
.43796 .46397 Mdot
.48373 .27858 Mdot
.27067 .5358 Mdot
.58901 .34364 Mdot
.33063 .5227 Mdot
.5369 .28608 Mdot
.34622 .05034 Mdot
.11639 .52101 Mdot
.21518 .03742 Mdot
.14974 .53415 Mdot
.48596 .41832 Mdot
.49335 .31792 Mdot
.42971 .47092 Mdot
.48402 .27502 Mdot
.23149 .53558 Mdot
.59315 .4109 Mdot
.4844 .30846 Mdot
.4301 .47086 Mdot
.48396 .27503 Mdot
.23217 .53565 Mdot
.5936 .40943 Mdot
.48537 .31107 Mdot
.43423 .46744 Mdot
.48372 .2767 Mdot
.25229 .53656 Mdot
.597 .37136 Mdot
.47773 .41248 Mdot
.49524 .32261 Mdot
.43717 .46462 Mdot
.48372 .27822 Mdot
.26724 .53605 Mdot
.59104 .34837 Mdot
.37212 .50584 Mdot
.50509 .27075 Mdot
.0994 .16692 Mdot
.0535 .43016 Mdot
.0471 .40726 Mdot
.05132 .41909 Mdot
.04502 .40118 Mdot
.0549 .42762 Mdot
.03995 .38246 Mdot
.06334 .44458 Mdot
.03234 .32456 Mdot
.07968 .46898 Mdot
.081 .14164 Mdot
.10923 .50106 Mdot
.74399 .12522 Mdot
.0619 .4697 Mdot
.06297 .44132 Mdot
.03211 .30991 Mdot
.08245 .47231 Mdot
.1093 .10533 Mdot
.11843 .50986 Mdot
.94104 .20518 Mdot
.90678 .21541 Mdot
.97619 .21966 Mdot
.46122 .43069 Mdot
.49058 .30323 Mdot
.38764 .49915 Mdot
.49709 .26891 Mdot
.05789 .30998 Mdot
.07168 .15631 Mdot
.10615 .49777 Mdot
.67084 .09838 Mdot
.126 .53817 Mdot
.06091 .17872 Mdot
.10208 .49383 Mdot
.54439 .05659 Mdot
.18214 .55996 Mdot
.37346 .50897 Mdot
.50726 .27094 Mdot
.13176 .12573 Mdot
.06957 .46227 Mdot
.03272 .33099 Mdot
.07823 .46718 Mdot
.06933 .16135 Mdot
.10522 .49699 Mdot
.63594 .08608 Mdot
.14837 .55018 Mdot
.30902 .02044 Mdot
.17249 .54754 Mdot
.52945 .33999 Mdot
.41112 .48387 Mdot
.48743 .2704 Mdot
.13876 .5001 Mdot
.46883 .53473 Mdot
.59251 .34391 Mdot
.33117 .5225 Mdot
.53639 .28575 Mdot
.34648 .05035 Mdot
.11641 .52104 Mdot
.21531 .03737 Mdot
.14978 .53417 Mdot
.48615 .41804 Mdot
.49343 .31824 Mdot
.43039 .47037 Mdot
.48397 .27528 Mdot
.23485 .53588 Mdot
.59509 .40382 Mdot
.48885 .32184 Mdot
.45027 .45264 Mdot
.48476 .28572 Mdot
.32169 .52649 Mdot
.54648 .29275 Mdot
.30744 .05109 Mdot
.1118 .51618 Mdot
.18819 .04825 Mdot
.1422 .52902 Mdot
.40691 .49072 Mdot
.48967 .26854 Mdot
.09393 .45046 Mdot
.47633 .43072 Mdot
.48965 .3044 Mdot
.39683 .49386 Mdot
.49273 .26876 Mdot
.07141 .40225 Mdot
.78037 .13877 Mdot
.03139 .38971 Mdot
.07779 .46143 Mdot
.11369 .1007 Mdot
.11983 .51112 Mdot
.95029 .21356 Mdot
.07204 .40096 Mdot
.84714 .16418 Mdot
.09295 .11387 Mdot
.11341 .50256 Mdot
.94905 .21145 Mdot
.08165 .20235 Mdot
.03924 .38555 Mdot
.06632 .44943 Mdot
.03255 .29574 Mdot
.08479 .47502 Mdot
.14043 .07704 Mdot
.1281 .51825 Mdot
.30751 .05065 Mdot
.11294 .5171 Mdot
.20462 .04126 Mdot
.14684 .53222 Mdot
.46618 .44258 Mdot
.48624 .29344 Mdot
.36148 .51217 Mdot
.51347 .27349 Mdot
.19782 .07843 Mdot
.09086 .49277 Mdot
.06161 .17689 Mdot
.10239 .49409 Mdot
.5562 .0601 Mdot
.1795 .55964 Mdot
.1726 .52136 Mdot
.38148 .57954 Mdot
.57531 .39014 Mdot
.49376 .36355 Mdot
.49143 .38972 Mdot
.49798 .35286 Mdot
.48163 .4112 Mdot
.49546 .32482 Mdot
.44203 .46029 Mdot
.48389 .28072 Mdot
.28873 .53369 Mdot
.57573 .32171 Mdot
.08449 .43293 Mdot
.09845 .45859 Mdot
.50196 .39114 Mdot
.49729 .35564 Mdot
.48452 .40574 Mdot
.4966 .33144 Mdot
.45385 .44865 Mdot
.48552 .28862 Mdot
.33648 .52189 Mdot
.5334 .28375 Mdot
.34948 .05044 Mdot
.11671 .52136 Mdot
.21654 .03696 Mdot
.15011 .53439 Mdot
.48788 .41555 Mdot
.49412 .32123 Mdot
.43651 .46523 Mdot
.48372 .27788 Mdot
.26408 .53624 Mdot
.59271 .3529 Mdot
.40457 .48728 Mdot
.48927 .26978 Mdot
.11135 .47418 Mdot
.54247 .33872 Mdot
.37453 .50521 Mdot
.50401 .27038 Mdot
.09089 .18159 Mdot
.04813 .41614 Mdot
.05402 .4253 Mdot
.04087 .38631 Mdot
.06178 .44173 Mdot
.03303 .33695 Mdot
.07705 .46563 Mdot
.06177 .1764 Mdot
.10248 .49414 Mdot
.56018 .0613 Mdot
.17851 .55949 Mdot
.08752 .44092 Mdot
.20645 .53265 Mdot
.54684 .4805 Mdot
.48377 .25601 Mdot
.06194 .26683 Mdot
.03294 .28156 Mdot
.08737 .47755 Mdot
.19117 .04681 Mdot
.1431 .52964 Mdot
.42341 .47975 Mdot
.48484 .2711 Mdot
.17696 .52214 Mdot
.42124 .56358 Mdot
.34251 .59204 Mdot
.74119 .15729 Mdot
.02482 .30556 Mdot
.08447 .46913 Mdot
.24609 .0286 Mdot
.15801 .53929 Mdot
.51147 .37067 Mdot
.48914 .39362 Mdot
.49802 .34703 Mdot
.47554 .42134 Mdot
.49282 .31342 Mdot
.41772 .48006 Mdot
.48586 .27141 Mdot
.16901 .51859 Mdot
.3748 .58181 Mdot
.55466 .34805 Mdot
.40324 .48867 Mdot
.48984 .26947 Mdot
.10207 .46247 Mdot
.51735 .35538 Mdot
.46918 .42939 Mdot
.49054 .30514 Mdot
.396 .49434 Mdot
.49309 .26874 Mdot
.0691 .39496 Mdot
.67674 .1004 Mdot
.12188 .53546 Mdot
.0474 .214 Mdot
.09649 .4879 Mdot
.39075 .02355 Mdot
.18599 .55493 Mdot
.54156 .33927 Mdot
.37994 .50245 Mdot
.5008 .26962 Mdot
.06833 .23823 Mdot
.03233 .33975 Mdot
.07799 .46649 Mdot
.07039 .15939 Mdot
.10559 .49737 Mdot
.64629 .08968 Mdot
.14235 .54738 Mdot
.20183 .04242 Mdot
.14601 .53168 Mdot
.45796 .45099 Mdot
.48434 .28677 Mdot
.33231 .52329 Mdot
.53704 .28607 Mdot
.35044 .05048 Mdot
.11678 .52144 Mdot
.21654 .03696 Mdot
.15011 .53439 Mdot
.48788 .41555 Mdot
.49412 .32123 Mdot
.4365 .46524 Mdot
.48372 .27788 Mdot
.26405 .53624 Mdot
.59273 .35294 Mdot
.40484 .4871 Mdot
.48918 .26981 Mdot
.11267 .47569 Mdot
.54718 .34092 Mdot
.37659 .50411 Mdot
.50271 .27006 Mdot
.08038 .20354 Mdot
.04071 .39143 Mdot
.06417 .44576 Mdot
.03213 .31538 Mdot
.08144 .47112 Mdot
.09791 .11841 Mdot
.11479 .50647 Mdot
.8789 .17675 Mdot
.2914 .01616 Mdot
.17537 .54709 Mdot
.55196 .3448 Mdot
.38982 .49688 Mdot
.49549 .26895 Mdot
.05968 .3487 Mdot
.21206 .03821 Mdot
.14914 .53366 Mdot
.4845 .42036 Mdot
.49277 .31555 Mdot
.42456 .47498 Mdot
.48461 .27326 Mdot
.20527 .53128 Mdot
.55034 .47695 Mdot
.47961 .25545 Mdot
.06114 .3599 Mdot
.28642 .02187 Mdot
.16795 .54495 Mdot
.52463 .344 Mdot
.43454 .46603 Mdot
.48388 .27751 Mdot
.25873 .53646 Mdot
.59508 .36096 Mdot
.44664 .45321 Mdot
.48504 .28536 Mdot
.31693 .52779 Mdot
.55078 .29614 Mdot
.26631 .05628 Mdot
.10532 .50935 Mdot
.14116 .07656 Mdot
.12829 .51843 Mdot
.28962 .05227 Mdot
.11036 .51443 Mdot
.18498 .04977 Mdot
.14128 .52837 Mdot
.38896 .50112 Mdot
.4979 .2686 Mdot
.05992 .28107 Mdot
.03868 .24444 Mdot
.09233 .48299 Mdot
.29978 .02088 Mdot
.17068 .54652 Mdot
.52752 .34124 Mdot
.41996 .47759 Mdot
.48537 .27234 Mdot
.18575 .52554 Mdot
.47131 .53749 Mdot
.59994 .37228 Mdot
.48011 .40784 Mdot
.49627 .32798 Mdot
.44741 .45519 Mdot
.48442 .28398 Mdot
.3112 .52924 Mdot
.55599 .30056 Mdot
.20215 .07649 Mdot
.09169 .49383 Mdot
.06447 .17091 Mdot
.10345 .49519 Mdot
.58551 .06923 Mdot
.17092 .55794 Mdot
.94957 .21256 Mdot
.0587 .30973 Mdot
.08466 .13552 Mdot
.11056 .50223 Mdot
.78682 .1413 Mdot
.02768 .36967 Mdot
.07939 .46296 Mdot
.14377 .07449 Mdot
.12913 .51909 Mdot
.17204 .09238 Mdot
.08493 .48505 Mdot
.04497 .22159 Mdot
.0954 .48665 Mdot
.36533 .02117 Mdot
.18266 .553 Mdot
.54063 .33898 Mdot
.38057 .50213 Mdot
.50045 .26955 Mdot
.06655 .24498 Mdot
.03161 .32735 Mdot
.08033 .46941 Mdot
.09034 .12816 Mdot
.11233 .50411 Mdot
.82249 .15483 Mdot
.03514 .2296 Mdot
.09106 .47664 Mdot
.43584 .03028 Mdot
.18966 .55768 Mdot
.53539 .33847 Mdot
.39059 .49669 Mdot
.49524 .26889 Mdot
.06021 .35303 Mdot
.23934 .03002 Mdot
.15645 .53829 Mdot
.50911 .37629 Mdot
.49295 .38222 Mdot
.49733 .36331 Mdot
.48984 .3936 Mdot
.49799 .34735 Mdot
.47593 .42073 Mdot
.49299 .31407 Mdot
.41926 .47894 Mdot
.48553 .27178 Mdot
.17728 .52227 Mdot
.42322 .56267 Mdot
.36598 .58541 Mdot
.51442 .36508 Mdot
.48337 .40647 Mdot
.49648 .33032 Mdot
.45187 .45071 Mdot
.48512 .2871 Mdot
.32886 .52437 Mdot
.54006 .2881 Mdot
.34384 .05029 Mdot
.11614 .52075 Mdot
.21402 .03782 Mdot
.14943 .53394 Mdot
.48423 .42074 Mdot
.49266 .31512 Mdot
.4236 .47571 Mdot
.48475 .27297 Mdot
.20023 .53002 Mdot
.53452 .49196 Mdot
.50126 .26117 Mdot
.30129 .05146 Mdot
.11118 .51547 Mdot
.18534 .0496 Mdot
.14138 .52844 Mdot
.39101 .50001 Mdot
.49681 .26845 Mdot
.05809 .30372 Mdot
.06113 .17681 Mdot
.10237 .49382 Mdot
.56748 .06354 Mdot
.17655 .55915 Mdot
.16839 .09476 Mdot
.08386 .48362 Mdot
.04268 .22996 Mdot
.09421 .48537 Mdot
.33455 .01989 Mdot
.17759 .55024 Mdot
.53586 .33835 Mdot
.38881 .4977 Mdot
.4961 .26894 Mdot
.05842 .33459 Mdot
.14196 .07554 Mdot
.1287 .51865 Mdot
.19301 .08035 Mdot
.09076 .49251 Mdot
.06245 .17511 Mdot
.1027 .49441 Mdot
.56487 .06274 Mdot
.17727 .55928 Mdot
.07335 .22051 Mdot
.03693 .37418 Mdot
.06965 .45479 Mdot
.03601 .26206 Mdot
.08976 .48053 Mdot
.23096 .03245 Mdot
.15406 .53687 Mdot
.50298 .38966 Mdot
.49713 .35818 Mdot
.48656 .40146 Mdot
.4973 .33687 Mdot
.46236 .43909 Mdot
.48777 .29631 Mdot
.36829 .50906 Mdot
.50869 .2717 Mdot
.14106 .11675 Mdot
.07326 .4683 Mdot
.03223 .30805 Mdot
.08266 .4726 Mdot
.11122 .1033 Mdot
.11904 .51041 Mdot
.94657 .20909 Mdot
.35985 .05136 Mdot
.11638 .52143 Mdot
.20051 .0429 Mdot
.14568 .53144 Mdot
.45521 .45364 Mdot
.48387 .28486 Mdot
.32211 .52638 Mdot
.54612 .29247 Mdot
.31032 .05091 Mdot
.1122 .51659 Mdot
.19091 .04701 Mdot
.14297 .52957 Mdot
.42019 .48201 Mdot
.48556 .27039 Mdot
.15988 .51389 Mdot
.33755 .59232 Mdot
.64305 .12058 Mdot
.06674 .47404 Mdot
.05521 .42648 Mdot
.03805 .37383 Mdot
.06665 .4503 Mdot
.03258 .29518 Mdot
.08487 .47512 Mdot
.14171 .07607 Mdot
.12849 .51857 Mdot
.25269 .0587 Mdot
.10404 .50776 Mdot
.13667 .08006 Mdot
.12692 .51729 Mdot
.49912 .07431 Mdot
.11574 .52516 Mdot
.08911 .13006 Mdot
.11189 .50374 Mdot
.80866 .14957 Mdot
.02492 .29015 Mdot
.08506 .46903 Mdot
.28149 .02257 Mdot
.16663 .54428 Mdot
.52273 .34649 Mdot
.4446 .45698 Mdot
.48432 .28282 Mdot
.30278 .53113 Mdot
.56358 .30775 Mdot
.10313 .16139 Mdot
.05515 .43408 Mdot
.04513 .40118 Mdot
.05452 .42678 Mdot
.04046 .38464 Mdot
.06246 .44298 Mdot
.03268 .33166 Mdot
.07822 .46713 Mdot
.06947 .16109 Mdot
.10526 .49704 Mdot
.63728 .08654 Mdot
.14762 .54985 Mdot
.29363 .02146 Mdot
.1692 .54575 Mdot
.5255 .34306 Mdot
.43006 .46976 Mdot
.48408 .27563 Mdot
.23742 .53607 Mdot
.59618 .3986 Mdot
.49147 .333 Mdot
.46496 .43624 Mdot
.48852 .29882 Mdot
.37709 .50477 Mdot
.50305 .27002 Mdot
.08458 .19413 Mdot
.04378 .40264 Mdot
.05991 .43784 Mdot
.03419 .34915 Mdot
.0741 .46164 Mdot
.04721 .21391 Mdot
.09652 .48782 Mdot
.39652 .02424 Mdot
.18663 .55533 Mdot
.54133 .33921 Mdot
.38013 .50236 Mdot
.50069 .2696 Mdot
.06777 .24027 Mdot
.03207 .33608 Mdot
.07871 .4674 Mdot
.07591 .14979 Mdot
.1075 .49933 Mdot
.6982 .10829 Mdot
.10432 .52185 Mdot
.0329 .32946 Mdot
.07812 .46713 Mdot
.06783 .16416 Mdot
.10468 .49644 Mdot
.6213 .08106 Mdot
.15604 .5533 Mdot
.50151 .04485 Mdot
.18824 .55994 Mdot
.51146 .371 Mdot
.48936 .39303 Mdot
.49804 .34784 Mdot
.47644 .41993 Mdot
.49321 .31493 Mdot
.42125 .47747 Mdot
.48515 .2723 Mdot
.18792 .5263 Mdot
.48249 .53063 Mdot
.59127 .34081 Mdot
.29857 .531 Mdot
.56567 .30999 Mdot
.08086 .20283 Mdot
.04049 .39062 Mdot
.06449 .44632 Mdot
.03212 .31255 Mdot
.08196 .47173 Mdot
.1035 .11177 Mdot
.11659 .50816 Mdot
.91421 .19155 Mdot
.70663 .1067 Mdot
.10859 .52592 Mdot
.03244 .31316 Mdot
.08143 .47125 Mdot
.09621 .12052 Mdot
.11424 .50595 Mdot
.8669 .17199 Mdot
.19685 .03777 Mdot
.14869 .53166 Mdot
.50679 .3815 Mdot
.49529 .37235 Mdot
.49465 .3784 Mdot
.49644 .36951 Mdot
.49326 .38344 Mdot
.49745 .36189 Mdot
.48892 .39593 Mdot
.49787 .34418 Mdot
.47221 .42627 Mdot
.49141 .3083 Mdot
.40492 .4888 Mdot
.48954 .26928 Mdot
.10301 .46375 Mdot
.51945 .3509 Mdot
.45901 .44202 Mdot
.4871 .29381 Mdot
.35847 .51346 Mdot
.51566 .27441 Mdot
.22341 .06775 Mdot
.09696 .50005 Mdot
.08903 .13007 Mdot
.11188 .5037 Mdot
.80987 .15003 Mdot
.02536 .28515 Mdot
.08547 .46954 Mdot
.29197 .02148 Mdot
.16899 .54559 Mdot
.52554 .34302 Mdot
.42985 .46993 Mdot
.4841 .27555 Mdot
.23638 .53599 Mdot
.59578 .4007 Mdot
.49051 .32837 Mdot
.45914 .44315 Mdot
.48672 .29291 Mdot
.35556 .51469 Mdot
.51786 .27538 Mdot
.24785 .06031 Mdot
.10206 .50578 Mdot
.11943 .09515 Mdot
.12159 .51272 Mdot
.93839 .2177 Mdot
.05868 .31044 Mdot
.08611 .13343 Mdot
.11104 .5027 Mdot
.79888 .14586 Mdot
.02396 .32839 Mdot
.08225 .4658 Mdot
.21013 .0391 Mdot
.14844 .53326 Mdot
.47892 .42775 Mdot
.49054 .30745 Mdot
.40511 .4887 Mdot
.48948 .26929 Mdot
.10377 .46476 Mdot
.52114 .34779 Mdot
.45007 .45164 Mdot
.48506 .28644 Mdot
.32464 .52564 Mdot
.54383 .29077 Mdot
.32618 .05028 Mdot
.1142 .51869 Mdot
.20393 .04153 Mdot
.14664 .53209 Mdot
.46448 .44439 Mdot
.48578 .29193 Mdot
.35555 .51471 Mdot
.51788 .27539 Mdot
.24813 .06024 Mdot
.10211 .50584 Mdot
.11978 .09481 Mdot
.1217 .51282 Mdot
.93639 .21758 Mdot
.07177 .22903 Mdot
.03277 .34525 Mdot
.07692 .4651 Mdot
.06318 .17342 Mdot
.103 .49469 Mdot
.57474 .06581 Mdot
.17442 .55873 Mdot
.69976 .14167 Mdot
.03561 .40226 Mdot
.076 .46044 Mdot
.08092 .14173 Mdot
.10921 .50103 Mdot
.74391 .12519 Mdot
.06198 .46983 Mdot
.06292 .44124 Mdot
.0321 .3104 Mdot
.08236 .47221 Mdot
.10829 .10642 Mdot
.11811 .50957 Mdot
.93736 .20299 Mdot
.97553 .22316 Mdot
.47627 .40481 Mdot
.49696 .32994 Mdot
.45017 .45242 Mdot
.48483 .28588 Mdot
.3223 .52632 Mdot
.54593 .29233 Mdot
.31176 .05082 Mdot
.11239 .51679 Mdot
.19223 .04641 Mdot
.14335 .52983 Mdot
.42603 .47786 Mdot
.48433 .27176 Mdot
.19073 .52724 Mdot
.49603 .52174 Mdot
.57105 .31027 Mdot
.10883 .15319 Mdot
.05824 .44092 Mdot
.04157 .38867 Mdot
.06044 .43919 Mdot
.03396 .34707 Mdot
.07463 .46237 Mdot
.04934 .20741 Mdot
.09748 .48885 Mdot
.42247 .02798 Mdot
.18888 .55695 Mdot
.5382 .33857 Mdot
.38423 .50021 Mdot
.49845 .26921 Mdot
.05946 .28512 Mdot
.04128 .23317 Mdot
.09385 .48465 Mdot
.33755 .01993 Mdot
.17813 .55053 Mdot
.53647 .33835 Mdot
.38733 .49852 Mdot
.49684 .26901 Mdot
.05784 .31888 Mdot
.0911 .12659 Mdot
.11268 .50431 Mdot
.83817 .16083 Mdot
.06483 .15521 Mdot
.10306 .49136 Mdot
.74765 .12658 Mdot
.05844 .46357 Mdot
.06512 .44495 Mdot
.03305 .28761 Mdot
.08607 .47646 Mdot
.16083 .06295 Mdot
.13425 .52314 Mdot
.14454 .50543 Mdot
.4199 .56164 Mdot
.4451 .55282 Mdot
.53786 .49041 Mdot
.49973 .26051 Mdot
.27726 .05429 Mdot
.10747 .51159 Mdot
.15802 .0648 Mdot
.13337 .52249 Mdot
.10329 .46537 Mdot
.51705 .3561 Mdot
.47055 .42751 Mdot
.49109 .30698 Mdot
.40113 .49121 Mdot
.49095 .26896 Mdot
.08659 .43775 Mdot
.21651 .53468 Mdot
.57134 .45248 Mdot
.46602 .26172 Mdot
.28012 .53501 Mdot
.58275 .33193 Mdot
.19769 .52865 Mdot
.53075 .49523 Mdot
.50739 .26372 Mdot
.40305 .05502 Mdot
.12007 .52552 Mdot
.20696 .04039 Mdot
.14747 .53265 Mdot
.47122 .437 Mdot
.48777 .29837 Mdot
.37878 .50392 Mdot
.50204 .26977 Mdot
.07712 .21157 Mdot
.03829 .38103 Mdot
.06765 .45163 Mdot
.03347 .28282 Mdot
.08677 .47725 Mdot
.17268 .05602 Mdot
.13775 .52579 Mdot
.29281 .53448 Mdot
.57478 .32032 Mdot
.07417 .4092 Mdot
.90089 .18565 Mdot
.52766 .04723 Mdot
.19517 .56242 Mdot
.5209 .34981 Mdot
.45504 .44641 Mdot
.48608 .29032 Mdot
.34376 .51931 Mdot
.52725 .28014 Mdot
.32701 .05023 Mdot
.11439 .51886 Mdot
.20577 .04082 Mdot
.14715 .53243 Mdot
.46881 .43972 Mdot
.487 .29592 Mdot
.37052 .50802 Mdot
.50721 .27121 Mdot
.12456 .13341 Mdot
.06647 .45689 Mdot
.03422 .34863 Mdot
.07406 .4616 Mdot
.04692 .21483 Mdot
.09639 .48768 Mdot
.39294 .02381 Mdot
.18624 .55509 Mdot
.5415 .33925 Mdot
.37999 .50243 Mdot
.50077 .26962 Mdot
.06816 .23882 Mdot
.03225 .33869 Mdot
.0782 .46676 Mdot
.07195 .15659 Mdot
.10614 .49793 Mdot
.66115 .09493 Mdot
.13281 .5423 Mdot
.09876 .11762 Mdot
.11501 .50675 Mdot
.88029 .17731 Mdot
.30406 .0153 Mdot
.17838 .54861 Mdot
.55757 .34984 Mdot
.40868 .48503 Mdot
.48806 .27018 Mdot
.12904 .49213 Mdot
.56267 .44511 Mdot
.46925 .27166 Mdot
.33834 .52144 Mdot
.53207 .28292 Mdot
.34756 .05037 Mdot
.11654 .52117 Mdot
.21602 .03713 Mdot
.14998 .5343 Mdot
.48717 .41659 Mdot
.49384 .31998 Mdot
.43399 .46738 Mdot
.48377 .27675 Mdot
.25231 .53656 Mdot
.59699 .37133 Mdot
.47767 .4126 Mdot
.49521 .32248 Mdot
.4369 .46486 Mdot
.48372 .27809 Mdot
.26602 .53613 Mdot
.59171 .3501 Mdot
.3853 .49893 Mdot
.49752 .26919 Mdot
.05795 .30765 Mdot
.06749 .16398 Mdot
.10468 .49625 Mdot
.63085 .08432 Mdot
.15115 .55137 Mdot
.37153 .02173 Mdot
.18341 .55346 Mdot
.54056 .33897 Mdot
.38067 .50208 Mdot
.50039 .26954 Mdot
.06628 .24606 Mdot
.03153 .32528 Mdot
.08069 .46986 Mdot
.09403 .1233 Mdot
.11353 .50527 Mdot
.85094 .16576 Mdot
.10886 .0962 Mdot
.1191 .50814 Mdot
.73692 .15571 Mdot
.02462 .31755 Mdot
.08356 .46814 Mdot
.22287 .03482 Mdot
.15191 .53552 Mdot
.49619 .40234 Mdot
.49688 .33867 Mdot
.46577 .43494 Mdot
.48891 .29999 Mdot
.38078 .50287 Mdot
.50086 .26951 Mdot
.06967 .23351 Mdot
.03307 .34791 Mdot
.0763 .46429 Mdot
.0593 .18182 Mdot
.10155 .49316 Mdot
.53441 .0537 Mdot
.18405 .56012 Mdot
.44922 .45924 Mdot
.48315 .28112 Mdot
.29851 .532 Mdot
.56739 .31174 Mdot
.06896 .2366 Mdot
.03234 .33989 Mdot
.07798 .46647 Mdot
.0703 .15956 Mdot
.10556 .49734 Mdot
.64537 .08936 Mdot
.14291 .54765 Mdot
.21014 .03925 Mdot
.14832 .53322 Mdot
.47696 .4302 Mdot
.48979 .30494 Mdot
.39838 .49292 Mdot
.49207 .26881 Mdot
.07633 .41567 Mdot
.9458 .2082 Mdot
.50305 .0762 Mdot
.11293 .52303 Mdot
.07213 .15656 Mdot
.10615 .49802 Mdot
.6582 .09388 Mdot
.13479 .54342 Mdot
.1146 .10003 Mdot
.12004 .51138 Mdot
.95034 .21377 Mdot
.07701 .41452 Mdot
.92647 .21652 Mdot
.55061 .09 Mdot
.1027 .51554 Mdot
.03575 .26508 Mdot
.08923 .48006 Mdot
.21694 .03675 Mdot
.15029 .53448 Mdot
.48916 .41365 Mdot
.49461 .32358 Mdot
.44108 .46118 Mdot
.48383 .28019 Mdot
.28454 .5343 Mdot
.57912 .32638 Mdot
.1305 .49277 Mdot
.54681 .46832 Mdot
.47067 .25786 Mdot
.17957 .5233 Mdot
.43555 .55683 Mdot
.49248 .52514 Mdot
.58124 .32329 Mdot
.08678 .43731 Mdot
.26746 .53731 Mdot
.59241 .35181 Mdot
.3974 .49184 Mdot
.49192 .26916 Mdot
.08044 .42526 Mdot
.66697 .12942 Mdot
.05335 .45008 Mdot
.06572 .44637 Mdot
.03328 .28471 Mdot
.0865 .47694 Mdot
.16815 .05857 Mdot
.13642 .52479 Mdot
.24157 .53752 Mdot
.59672 .39562 Mdot
.49255 .33985 Mdot
.47279 .42579 Mdot
.49153 .30882 Mdot
.40634 .48788 Mdot
.48905 .26943 Mdot
.10972 .47226 Mdot
.53699 .33749 Mdot
.38144 .50172 Mdot
.49999 .26946 Mdot
.0645 .25379 Mdot
.03138 .30981 Mdot
.08325 .47289 Mdot
.12432 .09049 Mdot
.12314 .51406 Mdot
.88647 .20739 Mdot
.77623 .13259 Mdot
.04109 .42464 Mdot
.07396 .45726 Mdot
.06719 .16535 Mdot
.10446 .4962 Mdot
.61573 .07918 Mdot
.15871 .55427 Mdot
.58226 .06825 Mdot
.17187 .55815 Mdot
.94276 .21762 Mdot
.08579 .43381 Mdot
.27388 .53682 Mdot
.58873 .34288 Mdot
.3232 .52499 Mdot
.54348 .29062 Mdot
.32428 .05032 Mdot
.11398 .51845 Mdot
.20261 .04205 Mdot
.14627 .53184 Mdot
.46112 .44785 Mdot
.48498 .28915 Mdot
.34371 .51934 Mdot
.52731 .28017 Mdot
.3274 .05023 Mdot
.11443 .51891 Mdot
.20604 .04072 Mdot
.14723 .53248 Mdot
.4694 .43906 Mdot
.48719 .29651 Mdot
.37255 .50704 Mdot
.50589 .2708 Mdot
.1106 .15051 Mdot
.05975 .44402 Mdot
.03992 .38194 Mdot
.06325 .44445 Mdot
.03237 .32538 Mdot
.07952 .46877 Mdot
.07961 .14381 Mdot
.10876 .50059 Mdot
.73163 .12061 Mdot
.07374 .48795 Mdot
.05457 .42471 Mdot
.03861 .37656 Mdot
.06568 .44867 Mdot
.03223 .30422 Mdot
.0834 .47343 Mdot
.121 .09356 Mdot
.12211 .51315 Mdot
.92549 .21628 Mdot
.62278 .11424 Mdot
.07503 .48589 Mdot
.0474 .40678 Mdot
.04992 .41554 Mdot
.04719 .40785 Mdot
.05139 .41927 Mdot
.04489 .40077 Mdot
.05511 .42809 Mdot
.03968 .38128 Mdot
.0638 .44542 Mdot
.03222 .32067 Mdot
.08044 .46991 Mdot
.08788 .13155 Mdot
.11152 .50333 Mdot
.80254 .14725 Mdot
.02383 .31454 Mdot
.08321 .46686 Mdot
.23447 .03146 Mdot
.155 .53745 Mdot
.50547 .38446 Mdot
.49618 .36707 Mdot
.49226 .38682 Mdot
.49783 .35695 Mdot
.48523 .40423 Mdot
.49687 .33333 Mdot
.45692 .44533 Mdot
.48623 .29117 Mdot
.34812 .51767 Mdot
.5237 .27823 Mdot
.30282 .05138 Mdot
.11128 .5156 Mdot
.18533 .04961 Mdot
.14137 .52844 Mdot
.39093 .50005 Mdot
.49685 .26846 Mdot
.05812 .30287 Mdot
.05988 .17955 Mdot
.1019 .49333 Mdot
.55453 .05959 Mdot
.1799 .55969 Mdot
.20978 .53344 Mdot
.55577 .47128 Mdot
.4742 .2554 Mdot
.10385 .46497 Mdot
.52105 .34794 Mdot
.45054 .45116 Mdot
.48515 .28678 Mdot
.32648 .52509 Mdot
.54218 .28958 Mdot
.33522 .0502 Mdot
.11523 .51978 Mdot
.20972 .03935 Mdot
.14825 .53316 Mdot
.47692 .43025 Mdot
.48978 .30489 Mdot
.39824 .49301 Mdot
.49213 .2688 Mdot
.07586 .41448 Mdot
.93756 .20292 Mdot
.97547 .22321 Mdot
.47633 .40466 Mdot
.49699 .33011 Mdot
.45048 .45211 Mdot
.48488 .2861 Mdot
.3235 .52597 Mdot
.54485 .29152 Mdot
.31959 .05046 Mdot
.1134 .51785 Mdot
.19895 .04354 Mdot
.14525 .53114 Mdot
.45066 .45787 Mdot
.4833 .28199 Mdot
.30452 .53078 Mdot
.56204 .30621 Mdot
.12143 .13719 Mdot
.06458 .4535 Mdot
.03556 .35886 Mdot
.07121 .45749 Mdot
.03844 .24826 Mdot
.09167 .4826 Mdot
.27388 .02357 Mdot
.16483 .54327 Mdot
.52057 .35002 Mdot
.4559 .44549 Mdot
.48628 .29103 Mdot
.34694 .51812 Mdot
.52464 .27873 Mdot
.31001 .05088 Mdot
.11227 .51663 Mdot
.19221 .04642 Mdot
.14334 .52983 Mdot
.42594 .47793 Mdot
.48435 .27173 Mdot
.19025 .52708 Mdot
.49379 .52326 Mdot
.57486 .31479 Mdot
.0647 .25382 Mdot
.03144 .30606 Mdot
.08384 .47357 Mdot
.13256 .08332 Mdot
.12569 .51624 Mdot
.66497 .12866 Mdot
.05451 .45245 Mdot
.06491 .44505 Mdot
.03266 .29341 Mdot
.08517 .47545 Mdot
.1464 .0726 Mdot
.12992 .51973 Mdot
.10524 .15722 Mdot
.05846 .44122 Mdot
.04118 .38713 Mdot
.06111 .44049 Mdot
.03346 .3421 Mdot
.07585 .46404 Mdot
.05505 .19194 Mdot
.09988 .49141 Mdot
.48823 .04147 Mdot
.18938 .5597 Mdot
.51829 .35486 Mdot
.4675 .43161 Mdot
.48991 .30302 Mdot
.38981 .49794 Mdot
.496 .2688 Mdot
.05834 .33323 Mdot
.13654 .07973 Mdot
.12704 .51728 Mdot
.42876 .05869 Mdot
.12112 .52708 Mdot
.19365 .04581 Mdot
.14373 .53011 Mdot
.43138 .47388 Mdot
.48353 .27334 Mdot
.21814 .53385 Mdot
.57845 .44202 Mdot
.46708 .2691 Mdot
.33632 .52216 Mdot
.53384 .284 Mdot
.35092 .05049 Mdot
.11684 .5215 Mdot
.21692 .03683 Mdot
.15022 .53446 Mdot
.4884 .41478 Mdot
.49432 .32218 Mdot
.43837 .46361 Mdot
.48373 .27878 Mdot
.27253 .53565 Mdot
.58783 .34115 Mdot
.30565 .52953 Mdot
.55936 .30372 Mdot
.15403 .1059 Mdot
.07758 .47494 Mdot
.0339 .27911 Mdot
.08727 .47784 Mdot
.18073 .05179 Mdot
.14009 .5275 Mdot
.36335 .51351 Mdot
.51429 .27359 Mdot
.21557 .07068 Mdot
.09519 .49798 Mdot
.08001 .1433 Mdot
.10888 .50074 Mdot
.73305 .12114 Mdot
.07238 .48604 Mdot
.05561 .42701 Mdot
.03727 .36979 Mdot
.06806 .45259 Mdot
.03359 .28148 Mdot
.08697 .47747 Mdot
.17617 .05415 Mdot
.13877 .52654 Mdot
.32647 .52681 Mdot
.54488 .29139 Mdot
.32565 .05029 Mdot
.11414 .51862 Mdot
.20348 .04171 Mdot
.14652 .532 Mdot
.46336 .44556 Mdot
.4855 .29098 Mdot
.35163 .5163 Mdot
.52092 .27683 Mdot
.27881 .0541 Mdot
.10762 .51176 Mdot
.15857 .06444 Mdot
.13354 .52261 Mdot
.11005 .47385 Mdot
.53347 .33766 Mdot
.39127 .49632 Mdot
.49493 .26888 Mdot
.06115 .35963 Mdot
.28695 .02181 Mdot
.16806 .54502 Mdot
.52478 .34383 Mdot
.43378 .46668 Mdot
.4839 .27717 Mdot
.25519 .53653 Mdot
.59627 .36658 Mdot
.46615 .43055 Mdot
.49034 .30383 Mdot
.3914 .49703 Mdot
.49521 .26876 Mdot
.05984 .35008 Mdot
.22038 .03541 Mdot
.15141 .53514 Mdot
.49517 .40408 Mdot
.49662 .33622 Mdot
.46229 .43921 Mdot
.48774 .29621 Mdot
.36795 .50922 Mdot
.50892 .27178 Mdot
.14371 .11437 Mdot
.07425 .46986 Mdot
.03238 .30152 Mdot
.08377 .47389 Mdot
.1254 .08952 Mdot
.12348 .51435 Mdot
.86856 .20219 Mdot
.58852 .06585 Mdot
.18012 .56095 Mdot
.06903 .23402 Mdot
.03376 .3538 Mdot
.07494 .46246 Mdot
.05214 .19949 Mdot
.09869 .49014 Mdot
.45546 .0341 Mdot
.19016 .55859 Mdot
.52975 .34001 Mdot
.41053 .48427 Mdot
.48759 .2703 Mdot
.13569 .49771 Mdot
.50569 .50853 Mdot
.52775 .27469 Mdot
.57741 .09813 Mdot
.09541 .50916 Mdot
.03248 .32068 Mdot
.08007 .46956 Mdot
.08338 .13805 Mdot
.11003 .50186 Mdot
.76467 .13296 Mdot
.04303 .42957 Mdot
.07306 .45629 Mdot
.05966 .18096 Mdot
.10169 .49331 Mdot
.53895 .055 Mdot
.18322 .56006 Mdot
.42198 .48081 Mdot
.48515 .27075 Mdot
.16908 .51862 Mdot
.37511 .58171 Mdot
.55593 .34922 Mdot
.40755 .48582 Mdot
.48841 .27 Mdot
.12312 .48666 Mdot
.57635 .39356 Mdot
.49414 .35464 Mdot
.48571 .40362 Mdot
.49697 .33416 Mdot
.45826 .44384 Mdot
.48658 .29235 Mdot
.3531 .5157 Mdot
.51975 .27627 Mdot
.2675 .05599 Mdot
.1057 .50973 Mdot
.14458 .07401 Mdot
.12933 .51928 Mdot
.16083 .10005 Mdot
.08147 .48035 Mdot
.03848 .24841 Mdot
.09163 .4826 Mdot
.27163 .02389 Mdot
.16429 .54297 Mdot
.51994 .3512 Mdot
.45908 .44192 Mdot
.48712 .2939 Mdot
.35879 .51332 Mdot
.51543 .27431 Mdot
.22072 .06872 Mdot
.09636 .49935 Mdot
.08587 .13452 Mdot
.11084 .50268 Mdot
.78374 .14014 Mdot
.02928 .37919 Mdot
.07866 .46227 Mdot
.12933 .08603 Mdot
.12471 .51539 Mdot
.77312 .16928 Mdot
.04562 .19833 Mdot
.09587 .48308 Mdot
.54709 .05737 Mdot
.1816 .55991 Mdot
.34164 .52199 Mdot
.53162 .28248 Mdot
.35317 .05057 Mdot
.11705 .52174 Mdot
.21767 .03658 Mdot
.15042 .53459 Mdot
.48939 .4133 Mdot
.4947 .32401 Mdot
.4419 .46043 Mdot
.48387 .28064 Mdot
.28807 .53379 Mdot
.57627 .32243 Mdot
.09045 .44395 Mdot
.4249 .47857 Mdot
.48454 .27152 Mdot
.18548 .52545 Mdot
.46983 .53836 Mdot
.60025 .37693 Mdot
.48699 .39163 Mdot
.49822 .34844 Mdot
.47694 .41913 Mdot
.49344 .3158 Mdot
.42325 .47596 Mdot
.48481 .27287 Mdot
.19853 .52956 Mdot
.52848 .49718 Mdot
.51129 .26551 Mdot
.45828 .06482 Mdot
.1191 .52649 Mdot
.14267 .07547 Mdot
.12873 .5188 Mdot
.23424 .06372 Mdot
.10037 .50375 Mdot
.11153 .10306 Mdot
.11911 .5105 Mdot
.94667 .20917 Mdot
.34615 .05081 Mdot
.11516 .52006 Mdot
.1972 .04427 Mdot
.14475 .5308 Mdot
.44489 .46297 Mdot
.48292 .27886 Mdot
.2808 .53479 Mdot
.58202 .33076 Mdot
.18325 .52396 Mdot
.46546 .5409 Mdot
.59971 .39129 Mdot
.49329 .34916 Mdot
.48183 .41124 Mdot
.49545 .32482 Mdot
.44206 .46026 Mdot
.48389 .28074 Mdot
.28887 .53367 Mdot
.57561 .32155 Mdot
.08324 .43042 Mdot
.05931 .28232 Mdot
.03723 .25173 Mdot
.09136 .48194 Mdot
.27625 .02324 Mdot
.16539 .54359 Mdot
.52123 .34886 Mdot
.45249 .44913 Mdot
.48552 .28826 Mdot
.33407 .5227 Mdot
.53549 .28506 Mdot
.35116 .0505 Mdot
.11685 .52152 Mdot
.21686 .03685 Mdot
.1502 .53444 Mdot
.48832 .41491 Mdot
.49429 .32202 Mdot
.43807 .46387 Mdot
.48373 .27863 Mdot
.27118 .53576 Mdot
.58869 .34295 Mdot
.32393 .52477 Mdot
.54282 .29014 Mdot
.32792 .05025 Mdot
.11441 .51891 Mdot
.2052 .04104 Mdot
.147 .53233 Mdot
.4675 .44115 Mdot
.48662 .29467 Mdot
.36604 .51012 Mdot
.51024 .27225 Mdot
.15926 .10174 Mdot
.07969 .47797 Mdot
.03587 .26345 Mdot
.08953 .48032 Mdot
.22496 .03419 Mdot
.15246 .53587 Mdot
.49806 .39905 Mdot
.49723 .34346 Mdot
.47199 .42661 Mdot
.4913 .30796 Mdot
.40401 .48939 Mdot
.48986 .26919 Mdot
.09887 .45796 Mdot
.50871 .37639 Mdot
.49308 .3818 Mdot
.49726 .36394 Mdot
.49023 .39256 Mdot
.49801 .34879 Mdot
.47751 .41823 Mdot
.49368 .31679 Mdot
.42547 .47425 Mdot
.48448 .27356 Mdot
.21009 .53235 Mdot
.5628 .46327 Mdot
.46896 .25696 Mdot
.18897 .52676 Mdot
.48661 .528 Mdot
.58594 .33068 Mdot
.17262 .51958 Mdot
.40383 .57105 Mdot
.265 .60244 Mdot
.0445 .22513 Mdot
.09478 .48629 Mdot
.3387 .01995 Mdot
.17833 .55064 Mdot
.53668 .33836 Mdot
.38685 .49879 Mdot
.49709 .26903 Mdot
.05784 .31365 Mdot
.07899 .14412 Mdot
.10866 .50033 Mdot
.73754 .12281 Mdot
.06807 .47969 Mdot
.05878 .43356 Mdot
.0339 .34676 Mdot
.07476 .46254 Mdot
.04993 .20569 Mdot
.09774 .48913 Mdot
.42951 .02917 Mdot
.18931 .55734 Mdot
.53677 .33846 Mdot
.38714 .49862 Mdot
.49694 .26902 Mdot
.05783 .31687 Mdot
.0862 .13333 Mdot
.11107 .50273 Mdot
.79911 .14595 Mdot
.02393 .32751 Mdot
.08231 .46586 Mdot
.21162 .03856 Mdot
.14885 .53353 Mdot
.4815 .4244 Mdot
.49156 .31102 Mdot
.41408 .48267 Mdot
.48673 .27062 Mdot
.14934 .50756 Mdot
.35782 .58606 Mdot
.51896 .35485 Mdot
.4669 .43237 Mdot
.48969 .3023 Mdot
.38764 .49916 Mdot
.4971 .26891 Mdot
.0579 .30974 Mdot
.07123 .15711 Mdot
.10599 .49761 Mdot
.66663 .09688 Mdot
.12902 .54006 Mdot
.07488 .15186 Mdot
.1071 .49899 Mdot
.68267 .10264 Mdot
.11707 .53207 Mdot
.03813 .25112 Mdot
.09118 .48222 Mdot
.25851 .02606 Mdot
.16111 .54113 Mdot
.51599 .35971 Mdot
.47644 .41873 Mdot
.49357 .31611 Mdot
.42378 .47556 Mdot
.48473 .27303 Mdot
.20128 .5303 Mdot
.53809 .48876 Mdot
.49574 .25917 Mdot
.20376 .07561 Mdot
.09246 .49472 Mdot
.06796 .16406 Mdot
.10471 .4965 Mdot
.62026 .08071 Mdot
.15655 .55349 Mdot
.5165 .0488 Mdot
.18661 .56011 Mdot
.49758 .40007 Mdot
.49713 .34198 Mdot
.47016 .42917 Mdot
.49056 .30542 Mdot
.3971 .49368 Mdot
.49261 .26877 Mdot
.07229 .40484 Mdot
.81745 .15281 Mdot
.02985 .25317 Mdot
.08842 .47326 Mdot
.36772 .02133 Mdot
.18304 .5532 Mdot
.54095 .33907 Mdot
.38028 .50228 Mdot
.50061 .26958 Mdot
.06734 .2419 Mdot
.03189 .33311 Mdot
.07928 .46811 Mdot
.08063 .14221 Mdot
.10911 .50094 Mdot
.74082 .12403 Mdot
.06493 .47474 Mdot
.06097 .43774 Mdot
.03248 .32853 Mdot
.07892 .46801 Mdot
.07476 .15172 Mdot
.10711 .49893 Mdot
.68753 .1044 Mdot
.1132 .52916 Mdot
.0342 .27807 Mdot
.08729 .47797 Mdot
.17882 .05276 Mdot
.13954 .5271 Mdot
.34885 .51936 Mdot
.52556 .27902 Mdot
.32441 .05028 Mdot
.11409 .51854 Mdot
.20406 .04148 Mdot
.14668 .53211 Mdot
.4648 .44405 Mdot
.48587 .29221 Mdot
.35669 .51423 Mdot
.51702 .275 Mdot
.23873 .0628 Mdot
.10024 .50376 Mdot
.10782 .10704 Mdot
.11794 .50943 Mdot
.93431 .20129 Mdot
.96824 .21091 Mdot
.25289 .53437 Mdot
.59547 .36309 Mdot
.45486 .44448 Mdot
.4867 .29179 Mdot
.34894 .51735 Mdot
.52303 .27789 Mdot
.29739 .05185 Mdot
.1105 .51479 Mdot
.17974 .05237 Mdot
.13976 .52728 Mdot
.35286 .51782 Mdot
.52232 .27732 Mdot
.29958 .05165 Mdot
.11083 .51513 Mdot
.1821 .05118 Mdot
.14044 .52777 Mdot
.37015 .51048 Mdot
.50947 .2717 Mdot
.15734 .10319 Mdot
.07906 .47706 Mdot
.03521 .26806 Mdot
.08887 .4796 Mdot
.21146 .03864 Mdot
.14879 .5335 Mdot
.48096 .42513 Mdot
.49134 .31024 Mdot
.41217 .48399 Mdot
.48724 .27027 Mdot
.13921 .50045 Mdot
.46325 .5382 Mdot
.59775 .35973 Mdot
.44203 .45767 Mdot
.48449 .28243 Mdot
.29812 .53207 Mdot
.56771 .3121 Mdot
.067 .24394 Mdot
.03156 .32634 Mdot
.08052 .46964 Mdot
.09226 .1256 Mdot
.11296 .50472 Mdot
.83753 .16059 Mdot
.06314 .15826 Mdot
.10242 .49063 Mdot
.73163 .1206 Mdot
.07375 .48798 Mdot
.05456 .42468 Mdot
.03863 .37665 Mdot
.06565 .44861 Mdot
.03222 .30451 Mdot
.08335 .47337 Mdot
.12036 .09417 Mdot
.12191 .51298 Mdot
.93058 .217 Mdot
.28868 .05329 Mdot
.10787 .51229 Mdot
.15373 .0676 Mdot
.13209 .52148 Mdot
.06315 .37382 Mdot
.37683 .02197 Mdot
.1845 .55396 Mdot
.54234 .33951 Mdot
.37944 .50271 Mdot
.50108 .26968 Mdot
.06984 .23292 Mdot
.03317 .34888 Mdot
.07609 .464 Mdot
.0581 .18459 Mdot
.10108 .49268 Mdot
.52155 .0501 Mdot
.18609 .56017 Mdot
.49029 .41208 Mdot
.495 .32558 Mdot
.44481 .45772 Mdot
.48411 .28232 Mdot
.30042 .53162 Mdot
.56569 .30992 Mdot
.08187 .2005 Mdot
.04123 .39351 Mdot
.06345 .44449 Mdot
.03224 .32149 Mdot
.08029 .46973 Mdot
.08646 .13356 Mdot
.11105 .50287 Mdot
.7908 .1428 Mdot
.02596 .35677 Mdot
.08031 .46384 Mdot
.16377 .06112 Mdot
.13514 .52382 Mdot
.18651 .52691 Mdot
.46266 .54253 Mdot
.59798 .40146 Mdot
.4897 .32537 Mdot
.45533 .44738 Mdot
.48575 .28958 Mdot
.34123 .52023 Mdot
.52936 .28133 Mdot
.3376 .05018 Mdot
.11555 .5201 Mdot
.21197 .03854 Mdot
.14887 .53357 Mdot
.48094 .42515 Mdot
.49134 .31022 Mdot
.41211 .48403 Mdot
.48726 .27026 Mdot
.1389 .50021 Mdot
.46712 .53581 Mdot
.59437 .34858 Mdot
.37308 .50533 Mdot
.50447 .27058 Mdot
.09364 .1766 Mdot
.04993 .4211 Mdot
.05165 .41961 Mdot
.04425 .39867 Mdot
.05617 .43042 Mdot
.03833 .3751 Mdot
.06613 .44943 Mdot
.03236 .30014 Mdot
.08408 .47421 Mdot
.13014 .08537 Mdot
.12495 .51561 Mdot
.75142 .16117 Mdot
.02731 .27393 Mdot
.08708 .47218 Mdot
.31421 .02011 Mdot
.17371 .54815 Mdot
.53128 .33916 Mdot
.40353 .48888 Mdot
.48984 .26938 Mdot
.10119 .46126 Mdot
.51529 .36023 Mdot
.47756 .41695 Mdot
.49405 .31807 Mdot
.42815 .47215 Mdot
.48417 .27446 Mdot
.22378 .53469 Mdot
.58619 .42824 Mdot
.47302 .28304 Mdot
.38292 .502 Mdot
.4998 .26927 Mdot
.06472 .25278 Mdot
.03136 .31191 Mdot
.08292 .47251 Mdot
.11994 .09456 Mdot
.12178 .51286 Mdot
.93347 .21733 Mdot
.14481 .11423 Mdot
.07271 .4676 Mdot
.0322 .31325 Mdot
.08173 .4715 Mdot
.10054 .11523 Mdot
.11564 .50727 Mdot
.89637 .18388 Mdot
.47435 .03358 Mdot
.19936 .56111 Mdot
.55494 .34746 Mdot
.39973 .4909 Mdot
.49115 .26917 Mdot
.08693 .43838 Mdot
.24041 .53742 Mdot
.59639 .3977 Mdot
.49183 .33501 Mdot
.46736 .43319 Mdot
.48938 .30161 Mdot
.38597 .50009 Mdot
.49798 .26902 Mdot
.05888 .29118 Mdot
.04619 .21563 Mdot
.0963 .4873 Mdot
.40138 .02486 Mdot
.18713 .55566 Mdot
.54102 .33912 Mdot
.38041 .50221 Mdot
.50054 .26957 Mdot
.06698 .24329 Mdot
.03175 .33053 Mdot
.07975 .46871 Mdot
.08489 .13582 Mdot
.11053 .50235 Mdot
.77766 .13785 Mdot
.03303 .39682 Mdot
.07713 .46079 Mdot
.10329 .11197 Mdot
.11653 .5081 Mdot
.91355 .19126 Mdot
.69752 .10338 Mdot
.11659 .53218 Mdot
.03602 .2637 Mdot
.08939 .48028 Mdot
.21951 .0359 Mdot
.15099 .53493 Mdot
.49235 .40871 Mdot
.49577 .32993 Mdot
.45242 .45017 Mdot
.48522 .28749 Mdot
.33092 .52372 Mdot
.53825 .28687 Mdot
.34858 .05042 Mdot
.1166 .52125 Mdot
.21588 .03718 Mdot
.14994 .53427 Mdot
.48696 .41688 Mdot
.49376 .31963 Mdot
.43327 .46799 Mdot
.48379 .27644 Mdot
.24887 .53653 Mdot
.59752 .3772 Mdot
.48688 .39213 Mdot
.49821 .34779 Mdot
.47623 .42025 Mdot
.49313 .31459 Mdot
.42046 .47805 Mdot
.48529 .27209 Mdot
.18372 .5248 Mdot
.46037 .54381 Mdot
.59576 .40971 Mdot
.48462 .30932 Mdot
.43178 .46949 Mdot
.48384 .27568 Mdot
.24046 .53625 Mdot
.59706 .39264 Mdot
.49326 .34719 Mdot
.48003 .41442 Mdot
.49468 .32111 Mdot
.43475 .46671 Mdot
.48375 .2771 Mdot
.25601 .53652 Mdot
.59603 .36526 Mdot
.46218 .43575 Mdot
.48889 .29908 Mdot
.37646 .50508 Mdot
.50342 .27011 Mdot
.0876 .18792 Mdot
.0459 .40952 Mdot
.05701 .43193 Mdot
.03708 .36867 Mdot
.06837 .45309 Mdot
.0339 .27842 Mdot
.08742 .47797 Mdot
.18434 .05001 Mdot
.14114 .52825 Mdot
.38756 .50186 Mdot
.49866 .26873 Mdot
.06221 .2655 Mdot
.03272 .28392 Mdot
.08704 .47719 Mdot
.18508 .04965 Mdot
.14135 .5284 Mdot
.39209 .49942 Mdot
.49626 .26839 Mdot
.05783 .3155 Mdot
.08299 .13801 Mdot
.11 .50167 Mdot
.7722 .13579 Mdot
.03696 .41138 Mdot
.07558 .45918 Mdot
.08282 .13885 Mdot
.10985 .50167 Mdot
.76055 .13141 Mdot
.04659 .43866 Mdot
.07145 .45424 Mdot
.0498 .20599 Mdot
.0977 .48907 Mdot
.42883 .02905 Mdot
.18928 .55731 Mdot
.53692 .33846 Mdot
.38681 .4988 Mdot
.4971 .26904 Mdot
.05784 .3133 Mdot
.07826 .14528 Mdot
.10841 .50008 Mdot
.731 .12038 Mdot
.07434 .48879 Mdot
.0541 .42365 Mdot
.03925 .3795 Mdot
.06458 .44677 Mdot
.03212 .314 Mdot
.08169 .47142 Mdot
.10056 .11521 Mdot
.11564 .50728 Mdot
.89649 .18393 Mdot
.47579 .03391 Mdot
.19933 .56116 Mdot
.55412 .34673 Mdot
.39704 .49258 Mdot
.49224 .26902 Mdot
.07687 .41701 Mdot
.95064 .21332 Mdot
.07063 .39657 Mdot
.78539 .14066 Mdot
.02849 .37475 Mdot
.07901 .4626 Mdot
.13606 .08043 Mdot
.12678 .51715 Mdot
.50756 .07657 Mdot
.11441 .52437 Mdot
.07762 .14724 Mdot
.10805 .49993 Mdot
.70933 .11237 Mdot
.09455 .51264 Mdot
.03805 .37134 Mdot
.06616 .44958 Mdot
.03233 .30073 Mdot
.08398 .4741 Mdot
.12876 .08655 Mdot
.12452 .51524 Mdot
.79229 .17632 Mdot
.08382 .12648 Mdot
.11024 .49947 Mdot
.90152 .18603 Mdot
.53731 .04998 Mdot
.19363 .56247 Mdot
.51464 .36332 Mdot
.48148 .41012 Mdot
.49572 .32593 Mdot
.44401 .45845 Mdot
.48404 .28186 Mdot
.29716 .53225 Mdot
.56856 .31303 Mdot
.06277 .26343 Mdot
.03263 .28488 Mdot
.08692 .47704 Mdot
.18279 .05076 Mdot
.14069 .52793 Mdot
.37776 .50687 Mdot
.50445 .27008 Mdot
.1021 .1627 Mdot
.05509 .4339 Mdot
.04516 .40129 Mdot
.05447 .42666 Mdot
.04054 .38493 Mdot
.06234 .44276 Mdot
.03273 .3326 Mdot
.07801 .46687 Mdot
.06803 .16378 Mdot
.10475 .49651 Mdot
.62328 .08173 Mdot
.15506 .55293 Mdot
.47357 .0381 Mdot
.18985 .55924 Mdot
.52337 .34587 Mdot
.44196 .45945 Mdot
.48408 .28127 Mdot
.29174 .53321 Mdot
.57322 .3185 Mdot
.06455 .37632 Mdot
.46312 .03559 Mdot
.19042 .55895 Mdot
.52796 .34113 Mdot
.41866 .47854 Mdot
.48562 .272 Mdot
.17887 .52292 Mdot
.43264 .55825 Mdot
.46726 .54075 Mdot
.59922 .39502 Mdot
.49248 .33989 Mdot
.47292 .4256 Mdot
.49159 .30901 Mdot
.40684 .48755 Mdot
.48888 .26949 Mdot
.11215 .47511 Mdot
.54532 .33994 Mdot
.3749 .50499 Mdot
.50375 .27031 Mdot
.08862 .18591 Mdot
.0466 .41166 Mdot
.05607 .4299 Mdot
.03821 .3745 Mdot
.06636 .44981 Mdot
.03244 .29801 Mdot
.08442 .47461 Mdot
.13504 .08129 Mdot
.12645 .51688 Mdot
.55991 .09207 Mdot
.10217 .51533 Mdot
.03464 .27359 Mdot
.08799 .47871 Mdot
.19246 .04624 Mdot
.14346 .52989 Mdot
.42887 .47577 Mdot
.48387 .27256 Mdot
.20542 .53133 Mdot
.55075 .47653 Mdot
.47916 .25541 Mdot
.06287 .36978 Mdot
.37231 .02157 Mdot
.1839 .55361 Mdot
.54212 .33943 Mdot
.37951 .50267 Mdot
.50104 .26967 Mdot
.06962 .23367 Mdot
.03304 .34763 Mdot
.07636 .46437 Mdot
.05966 .18102 Mdot
.10168 .49331 Mdot
.53817 .05478 Mdot
.18337 .56007 Mdot
.4274 .47691 Mdot
.4841 .27211 Mdot
.19756 .5293 Mdot
.52486 .50019 Mdot
.51765 .26868 Mdot
.52859 .08286 Mdot
.10942 .52089 Mdot
.05114 .20272 Mdot
.09819 .48969 Mdot
.43784 .03065 Mdot
.18972 .55778 Mdot
.53479 .33851 Mdot
.39225 .49574 Mdot
.49446 .26887 Mdot
.06289 .36966 Mdot
.37434 .02175 Mdot
.18418 .55377 Mdot
.54225 .33948 Mdot
.37946 .50269 Mdot
.50107 .26968 Mdot
.06977 .23319 Mdot
.03313 .34844 Mdot
.07618 .46413 Mdot
.05864 .18332 Mdot
.10129 .4929 Mdot
.5274 .05172 Mdot
.18522 .56016 Mdot
.47635 .43105 Mdot
.48953 .30408 Mdot
.39603 .49434 Mdot
.49308 .26874 Mdot
.06913 .39506 Mdot
.67813 .1009 Mdot
.12083 .53474 Mdot
.04486 .2225 Mdot
.09524 .48657 Mdot
.358 .0207 Mdot
.18155 .55238 Mdot
.53981 .33878 Mdot
.38144 .50168 Mdot
.49996 .26946 Mdot
.06436 .25442 Mdot
.0314 .30849 Mdot
.08346 .47313 Mdot
.12713 .08797 Mdot
.12402 .51481 Mdot
.83322 .19077 Mdot
.27709 .01794 Mdot
.17145 .54517 Mdot
.54337 .33978 Mdot
.37856 .50315 Mdot
.50158 .26979 Mdot
.07277 .22365 Mdot
.0351 .36371 Mdot
.07257 .45914 Mdot
.04296 .22861 Mdot
.09441 .48555 Mdot
.34121 .02001 Mdot
.17878 .55087 Mdot
.53717 .33839 Mdot
.3858 .49936 Mdot
.49763 .2691 Mdot
.05816 .30224 Mdot
.059 .18151 Mdot
.10157 .49297 Mdot
.54538 .05687 Mdot
.18194 .55994 Mdot
.3623 .51399 Mdot
.5151 .27393 Mdot
.22517 .06713 Mdot
.09736 .5005 Mdot
.09115 .12719 Mdot
.11258 .50438 Mdot
.8268 .15648 Mdot
.04107 .20951 Mdot
.09367 .47999 Mdot
.50429 .04549 Mdot
.18816 .56003 Mdot
.51024 .37391 Mdot
.49149 .38702 Mdot
.49791 .35629 Mdot
.48466 .40539 Mdot
.49667 .33187 Mdot
.45455 .4479 Mdot
.48567 .28918 Mdot
.33916 .52097 Mdot
.53112 .28236 Mdot
.34414 .05028 Mdot
.11621 .52081 Mdot
.21483 .03754 Mdot
.14965 .53408 Mdot
.48545 .41904 Mdot
.49315 .31708 Mdot
.4279 .47237 Mdot
.48419 .27436 Mdot
.22243 .5345 Mdot
.58455 .43146 Mdot
.47126 .27933 Mdot
.37357 .50679 Mdot
.50543 .27063 Mdot
.10657 .15609 Mdot
.0576 .4395 Mdot
.04224 .39122 Mdot
.05931 .43698 Mdot
.03493 .35504 Mdot
.07251 .45937 Mdot
.04182 .23308 Mdot
.09378 .48488 Mdot
.32519 .01988 Mdot
.17584 .5493 Mdot
.53382 .33851 Mdot
.39458 .49438 Mdot
.49341 .26888 Mdot
.06816 .39173 Mdot
.63246 .08478 Mdot
.15053 .55112 Mdot
.35584 .02067 Mdot
.18107 .55216 Mdot
.53897 .33862 Mdot
.3826 .50108 Mdot
.49933 .26935 Mdot
.06194 .26708 Mdot
.03308 .28013 Mdot
.08757 .47777 Mdot
.19495 .04515 Mdot
.14417 .53038 Mdot
.4387 .46813 Mdot
.48294 .27603 Mdot
.25337 .53656 Mdot
.59676 .36958 Mdot
.4739 .41906 Mdot
.49356 .31537 Mdot
.42153 .47725 Mdot
.4851 .27238 Mdot
.18945 .52681 Mdot
.49002 .52577 Mdot
.58092 .32287 Mdot
.08325 .43041 Mdot
.0585 .29016 Mdot
.04206 .23014 Mdot
.09426 .4851 Mdot
.34781 .02021 Mdot
.17991 .55148 Mdot
.53833 .33851 Mdot
.38359 .50055 Mdot
.49879 .26926 Mdot
.0603 .27802 Mdot
.03705 .25261 Mdot
.09125 .48181 Mdot
.27384 .02357 Mdot
.16482 .54327 Mdot
.52057 .35003 Mdot
.45592 .44546 Mdot
.48629 .29106 Mdot
.34705 .51808 Mdot
.52456 .27868 Mdot
.30937 .05092 Mdot
.11218 .51654 Mdot
.19163 .04668 Mdot
.14318 .52971 Mdot
.42341 .47975 Mdot
.48484 .2711 Mdot
.17696 .52214 Mdot
.42123 .56358 Mdot
.34241 .59207 Mdot
.75455 .16231 Mdot
.0287 .26396 Mdot
.088 .4733 Mdot
.3384 .01993 Mdot
.17831 .55061 Mdot
.53672 .33836 Mdot
.38676 .49883 Mdot
.49713 .26904 Mdot
.05785 .31272 Mdot
.07705 .14723 Mdot
.108 .49966 Mdot
.72019 .11637 Mdot
.08457 .50177 Mdot
.04586 .4018 Mdot
.05227 .42156 Mdot
.04368 .39672 Mdot
.05709 .43241 Mdot
.03723 .36946 Mdot
.06809 .45265 Mdot
.03362 .28119 Mdot
.08701 .47752 Mdot
.17692 .05375 Mdot
.13899 .5267 Mdot
.33308 .52481 Mdot
.539 .28721 Mdot
.35371 .05061 Mdot
.11707 .52176 Mdot
.21723 .03673 Mdot
.1503 .53451 Mdot
.4888 .41418 Mdot
.49448 .32292 Mdot
.43981 .46233 Mdot
.48377 .27951 Mdot
.27895 .535 Mdot
.58338 .33298 Mdot
.21088 .53181 Mdot
.56788 .45697 Mdot
.46671 .25939 Mdot
.24698 .53662 Mdot
.59766 .38102 Mdot
.49049 .37982 Mdot
.49732 .36487 Mdot
.49073 .39118 Mdot
.49802 .35071 Mdot
.47952 .41491 Mdot
.49456 .32051 Mdot
.43346 .46781 Mdot
.48379 .27653 Mdot
.24989 .53655 Mdot
.59741 .37544 Mdot
.48463 .39805 Mdot
.49781 .34005 Mdot
.46659 .43384 Mdot
.48922 .30099 Mdot
.38395 .50119 Mdot
.49907 .26918 Mdot
.06168 .26863 Mdot
.03348 .27643 Mdot
.08807 .47833 Mdot
.20483 .04111 Mdot
.14695 .53227 Mdot
.46781 .44082 Mdot
.4867 .29495 Mdot
.36708 .50964 Mdot
.50953 .27199 Mdot
.15082 .10832 Mdot
.07683 .47378 Mdot
.03344 .284 Mdot
.08654 .47703 Mdot
.16783 .05875 Mdot
.13632 .52472 Mdot
.23758 .53728 Mdot
.59519 .40362 Mdot
.48896 .32223 Mdot
.45083 .45208 Mdot
.48485 .28611 Mdot
.32387 .52586 Mdot
.54452 .29128 Mdot
.32183 .05039 Mdot
.11368 .51814 Mdot
.20071 .04281 Mdot
.14574 .53148 Mdot
.45592 .45297 Mdot
.48398 .28534 Mdot
.32476 .52562 Mdot
.54374 .29071 Mdot
.32676 .05027 Mdot
.11427 .51876 Mdot
.20435 .04137 Mdot
.14676 .53217 Mdot
.46548 .44333 Mdot
.48605 .29281 Mdot
.35905 .51323 Mdot
.51525 .27423 Mdot
.21871 .06947 Mdot
.0959 .49882 Mdot
.08355 .1379 Mdot
.11007 .50192 Mdot
.76406 .13273 Mdot
.04355 .43096 Mdot
.07283 .456 Mdot
.05807 .1846 Mdot
.10108 .49266 Mdot
.52195 .05021 Mdot
.18603 .56017 Mdot
.48951 .41326 Mdot
.49471 .32408 Mdot
.44203 .46031 Mdot
.48388 .28071 Mdot
.28865 .5337 Mdot
.5758 .3218 Mdot
.0852 .43433 Mdot
.15019 .50916 Mdot
.36372 .58416 Mdot
.53677 .33947 Mdot
.39236 .49564 Mdot
.49439 .26887 Mdot
.06319 .37116 Mdot
.38905 .02322 Mdot
.18604 .55487 Mdot
.54254 .33959 Mdot
.37943 .50271 Mdot
.50108 .26968 Mdot
.06986 .23286 Mdot
.03318 .34898 Mdot
.07606 .46398 Mdot
.05798 .18486 Mdot
.10104 .49263 Mdot
.52026 .04975 Mdot
.18627 .56017 Mdot
.49265 .40838 Mdot
.49583 .33038 Mdot
.45319 .44938 Mdot
.48537 .28807 Mdot
.33386 .52277 Mdot
.53567 .28518 Mdot
.35117 .0505 Mdot
.11685 .52152 Mdot
.21685 .03686 Mdot
.1502 .53444 Mdot
.4883 .41493 Mdot
.49428 .32199 Mdot
.43801 .46392 Mdot
.48373 .27861 Mdot
.27092 .53578 Mdot
.58885 .34331 Mdot
.32743 .52372 Mdot
.53972 .28796 Mdot
.34075 .05024 Mdot
.11583 .52041 Mdot
.21271 .03828 Mdot
.14907 .5337 Mdot
.48215 .42355 Mdot
.49182 .31196 Mdot
.41633 .48108 Mdot
.48617 .27109 Mdot
.16143 .51473 Mdot
.34145 .59143 Mdot
.08207 .19845 Mdot
.04369 .40223 Mdot
.05995 .43794 Mdot
.03416 .34885 Mdot
.07418 .46174 Mdot
.04751 .21297 Mdot
.09666 .48797 Mdot
.40024 .02471 Mdot
.18701 .55558 Mdot
.5411 .33914 Mdot
.38033 .50225 Mdot
.50058 .26958 Mdot
.06719 .24248 Mdot
.03183 .33204 Mdot
.07947 .46836 Mdot
.08238 .13954 Mdot
.10969 .50152 Mdot
.75608 .12974 Mdot
.05059 .44786 Mdot
.06948 .45158 Mdot
.04155 .23407 Mdot
.09365 .48472 Mdot
.32227 .01992 Mdot
.17528 .549 Mdot
.53314 .33863 Mdot
.39678 .49307 Mdot
.49246 .26893 Mdot
.07457 .41115 Mdot
.90288 .1865 Mdot
.5529 .05456 Mdot
.19056 .56237 Mdot
.49563 .40348 Mdot
.49671 .33709 Mdot
.46355 .43768 Mdot
.48815 .29753 Mdot
.37261 .507 Mdot
.50584 .27079 Mdot
.11005 .15124 Mdot
.05946 .44344 Mdot
.04022 .3832 Mdot
.06274 .44353 Mdot
.03256 .3295 Mdot
.07867 .46771 Mdot
.07282 .15506 Mdot
.10644 .49824 Mdot
.66936 .09785 Mdot
.12707 .53885 Mdot
.06542 .16927 Mdot
.10375 .49557 Mdot
.59086 .07095 Mdot
.16902 .55746 Mdot
.91692 .19286 Mdot
.74584 .12113 Mdot
.07062 .4839 Mdot
.05745 .43085 Mdot
.03513 .35666 Mdot
.07212 .45879 Mdot
.04073 .2376 Mdot
.09315 .4842 Mdot
.30947 .02032 Mdot
.17272 .54762 Mdot
.53001 .3397 Mdot
.40867 .48552 Mdot
.48814 .27001 Mdot
.12612 .4895 Mdot
.57369 .41833 Mdot
.4837 .30454 Mdot
.42075 .47808 Mdot
.48524 .27206 Mdot
.18388 .52486 Mdot
.46121 .54333 Mdot
.59669 .40655 Mdot
.48669 .31514 Mdot
.44074 .46176 Mdot
.48376 .27983 Mdot
.28201 .53463 Mdot
.58109 .32931 Mdot
.16535 .51614 Mdot
.36283 .5856 Mdot
.51735 .3583 Mdot
.47359 .42307 Mdot
.49236 .31148 Mdot
.41281 .48353 Mdot
.48706 .27039 Mdot
.14274 .50305 Mdot
.41988 .56165 Mdot
.44458 .55308 Mdot
.53487 .49305 Mdot
.50457 .26244 Mdot
.36114 .05092 Mdot
.11786 .52259 Mdot
.22098 .0355 Mdot
.15132 .53517 Mdot
.4934 .40702 Mdot
.49611 .33218 Mdot
.45611 .44626 Mdot
.48602 .29044 Mdot
.34496 .51887 Mdot
.52627 .2796 Mdot
.3211 .05038 Mdot
.11368 .51812 Mdot
.20153 .04248 Mdot
.14597 .53164 Mdot
.45822 .45074 Mdot
.48438 .28696 Mdot
.33326 .52298 Mdot
.53622 .28553 Mdot
.35107 .0505 Mdot
.11684 .52151 Mdot
.21678 .03688 Mdot
.15018 .53443 Mdot
.48821 .41507 Mdot
.49424 .32183 Mdot
.43768 .46421 Mdot
.48372 .27844 Mdot
.26942 .5359 Mdot
.58977 .34534 Mdot
.34649 .51709 Mdot
.52356 .27828 Mdot
.29687 .0519 Mdot
.11042 .51471 Mdot
.17914 .05267 Mdot
.13959 .52716 Mdot
.34816 .51961 Mdot
.52613 .27933 Mdot
.32809 .05021 Mdot
.11452 .519 Mdot
.20659 .04051 Mdot
.14738 .53259 Mdot
.47062 .43769 Mdot
.48757 .29774 Mdot
.37671 .50498 Mdot
.50329 .27008 Mdot
.08654 .19005 Mdot
.04517 .40721 Mdot
.05801 .43402 Mdot
.03599 .36224 Mdot
.07042 .45627 Mdot
.03686 .25682 Mdot
.09049 .48132 Mdot
.24679 .02846 Mdot
.15817 .53939 Mdot
.51169 .37014 Mdot
.4887 .39475 Mdot
.49797 .34549 Mdot
.47375 .42403 Mdot
.49205 .31059 Mdot
.41082 .4849 Mdot
.48763 .27005 Mdot
.13226 .49491 Mdot
.54019 .47611 Mdot
.47575 .25634 Mdot
.09841 .4574 Mdot
.50669 .38106 Mdot
.49517 .37301 Mdot
.49489 .37738 Mdot
.49617 .37106 Mdot
.49396 .38095 Mdot
.49702 .36561 Mdot
.49124 .38978 Mdot
.498 .35269 Mdot
.48146 .4115 Mdot
.49539 .32447 Mdot
.44136 .4609 Mdot
.48385 .28036 Mdot
.28583 .53412 Mdot
.57809 .32491 Mdot
.11443 .47702 Mdot
.55674 .34829 Mdot
.40172 .48962 Mdot
.49039 .26933 Mdot
.09543 .45281 Mdot
.49077 .41083 Mdot
.49531 .32711 Mdot
.44753 .4551 Mdot
.48442 .28404 Mdot
.31159 .52914 Mdot
.55564 .30025 Mdot
.20686 .07438 Mdot
.09286 .49525 Mdot
.06917 .16178 Mdot
.10514 .49694 Mdot
.63211 .08476 Mdot
.15047 .55108 Mdot
.35553 .02065 Mdot
.18102 .55214 Mdot
.53893 .33861 Mdot
.38266 .50105 Mdot
.4993 .26934 Mdot
.06182 .26775 Mdot
.03325 .27854 Mdot
.08778 .47801 Mdot
.19918 .04336 Mdot
.14537 .5312 Mdot
.45285 .45586 Mdot
.48354 .28333 Mdot
.31311 .52878 Mdot
.55427 .29906 Mdot
.22466 .0674 Mdot
.09701 .50014 Mdot
.08886 .13031 Mdot
.11182 .50365 Mdot
.80843 .14948 Mdot
.02485 .29108 Mdot
.08499 .46894 Mdot
.27959 .0228 Mdot
.16619 .54403 Mdot
.52221 .34727 Mdot
.44735 .45434 Mdot
.48465 .28457 Mdot
.31392 .52856 Mdot
.55352 .29841 Mdot
.23422 .06424 Mdot
.09909 .5025 Mdot
.1004 .1155 Mdot
.11557 .50724 Mdot
.89377 .1828 Mdot
.44393 .02711 Mdot
.19894 .55976 Mdot
.56763 .36376 Mdot
.45728 .44242 Mdot
.48712 .29345 Mdot
.35621 .51441 Mdot
.51736 .27516 Mdot
.24243 .06175 Mdot
.10099 .5046 Mdot
.1125 .10205 Mdot
.11942 .51078 Mdot
.94857 .21095 Mdot
.11344 .14785 Mdot
.05888 .4424 Mdot
.04102 .38647 Mdot
.06138 .44099 Mdot
.03329 .34014 Mdot
.07632 .46466 Mdot
.05751 .18596 Mdot
.10086 .49244 Mdot
.51518 .04837 Mdot
.18693 .56014 Mdot
.50018 .39532 Mdot
.4974 .34915 Mdot
.47843 .41678 Mdot
.49407 .3184 Mdot
.429 .47147 Mdot
.48408 .27477 Mdot
.22808 .53523 Mdot
.59054 .41837 Mdot
.4793 .29632 Mdot
.40965 .48597 Mdot
.48803 .26977 Mdot
.12451 .488 Mdot
.57611 .40463 Mdot
.49152 .32961 Mdot
.4595 .44269 Mdot
.48683 .29329 Mdot
.35704 .51407 Mdot
.51674 .27488 Mdot
.23562 .06373 Mdot
.09959 .50304 Mdot
.10391 .11141 Mdot
.11669 .50828 Mdot
.91497 .1919 Mdot
.71724 .11058 Mdot
.09881 .51723 Mdot
.03594 .3591 Mdot
.0703 .45621 Mdot
.03646 .25921 Mdot
.09015 .48096 Mdot
.23945 .0302 Mdot
.15628 .53825 Mdot
.50823 .37832 Mdot
.49398 .3783 Mdot
.49652 .36919 Mdot
.4931 .38399 Mdot
.49752 .36107 Mdot
.48836 .39729 Mdot
.49777 .34235 Mdot
.46992 .42946 Mdot
.49048 .30514 Mdot
.39627 .49418 Mdot
.49297 .26875 Mdot
.06986 .39745 Mdot
.71172 .11315 Mdot
.09262 .51067 Mdot
.03947 .37814 Mdot
.06353 .44502 Mdot
.03231 .32369 Mdot
.07985 .46919 Mdot
.08249 .13938 Mdot
.10973 .50156 Mdot
.75701 .13009 Mdot
.04975 .446 Mdot
.06991 .45217 Mdot
.04305 .22818 Mdot
.09447 .48561 Mdot
.34326 .02006 Mdot
.17913 .55107 Mdot
.53754 .33842 Mdot
.38504 .49977 Mdot
.49802 .26915 Mdot
.05867 .29392 Mdot
.04886 .2074 Mdot
.09749 .4886 Mdot
.43357 .02988 Mdot
.18953 .55756 Mdot
.53585 .33845 Mdot
.38937 .49738 Mdot
.49583 .26893 Mdot
.05886 .34046 Mdot
.16785 .05846 Mdot
.13649 .52477 Mdot
.25463 .53781 Mdot
.59713 .37196 Mdot
.47891 .4103 Mdot
.49574 .32511 Mdot
.44208 .46023 Mdot
.48389 .28076 Mdot
.28901 .53364 Mdot
.5755 .32141 Mdot
.08213 .42812 Mdot
.163 .09851 Mdot
.08212 .48125 Mdot
.03947 .24357 Mdot
.0923 .48332 Mdot
.28752 .02193 Mdot
.16797 .54503 Mdot
.52428 .34443 Mdot
.43641 .46442 Mdot
.48387 .27838 Mdot
.26735 .53605 Mdot
.59097 .34821 Mdot
.37086 .50646 Mdot
.50589 .27098 Mdot
.10712 .15531 Mdot
.0579 .44014 Mdot
.04191 .38998 Mdot
.05986 .43808 Mdot
.03443 .35116 Mdot
.07357 .46089 Mdot
.04522 .22047 Mdot
.09557 .4868 Mdot
.37127 .02162 Mdot
.18352 .55348 Mdot
.54112 .33912 Mdot
.38016 .50234 Mdot
.50068 .2696 Mdot
.06768 .2406 Mdot
.03203 .33549 Mdot
.07882 .46755 Mdot
.07683 .14826 Mdot
.10782 .49965 Mdot
.70666 .11139 Mdot
.09693 .51501 Mdot
.03644 .36235 Mdot
.06928 .45464 Mdot
.03488 .27004 Mdot
.08863 .4793 Mdot
.20757 .04007 Mdot
.14771 .53278 Mdot
.47373 .4341 Mdot
.48862 .3011 Mdot
.38732 .49936 Mdot
.49728 .26893 Mdot
.058 .30593 Mdot
.0646 .16963 Mdot
.10364 .49516 Mdot
.60242 .07473 Mdot
.16454 .55619 Mdot
.7753 .13702 Mdot
.0346 .40296 Mdot
.07652 .46017 Mdot
.09449 .12266 Mdot
.11369 .50542 Mdot
.85502 .16734 Mdot
.12754 .07902 Mdot
.12567 .5141 Mdot
.05842 .34147 Mdot
.15401 .06703 Mdot
.13235 .52159 Mdot
.07784 .42097 Mdot
.95088 .2146 Mdot
.10609 .46569 Mdot
.53292 .33767 Mdot
.39271 .4955 Mdot
.49426 .26886 Mdot
.06373 .3738 Mdot
.41591 .02682 Mdot
.18865 .55662 Mdot
.54021 .33893 Mdot
.38128 .50176 Mdot
.50005 .26948 Mdot
.06473 .25274 Mdot
.03136 .31199 Mdot
.08291 .47249 Mdot
.11976 .09473 Mdot
.12173 .51281 Mdot
.93463 .21744 Mdot
.10701 .15661 Mdot
.0555 .435 Mdot
.04485 .40027 Mdot
.05497 .4278 Mdot
.03987 .38211 Mdot
.06348 .44483 Mdot
.0323 .3234 Mdot
.07991 .46926 Mdot
.08302 .13859 Mdot
.10991 .50174 Mdot
.76157 .1318 Mdot
.04569 .43646 Mdot
.07187 .45479 Mdot
.05205 .19967 Mdot
.09866 .4901 Mdot
.4552 .03404 Mdot
.19016 .55858 Mdot
.52984 .33996 Mdot
.41018 .48451 Mdot
.48769 .27025 Mdot
.13385 .49623 Mdot
.5253 .49144 Mdot
.49396 .2591 Mdot
.15802 .10262 Mdot
.07939 .47753 Mdot
.03556 .26551 Mdot
.08923 .48 Mdot
.21889 .0361 Mdot
.15082 .53482 Mdot
.49162 .40986 Mdot
.49552 .32841 Mdot
.44984 .45281 Mdot
.48476 .2856 Mdot
.32082 .52674 Mdot
.54727 .29335 Mdot
.30085 .05159 Mdot
.11088 .51521 Mdot
.18163 .05142 Mdot
.14031 .52768 Mdot
.36681 .51199 Mdot
.51179 .27258 Mdot
.18548 .08483 Mdot
.08758 .48865 Mdot
.05101 .20279 Mdot
.09818 .48963 Mdot
.43981 .03102 Mdot
.18979 .55787 Mdot
.53428 .33857 Mdot
.39376 .49486 Mdot
.49377 .26887 Mdot
.06612 .38414 Mdot
.53395 .05346 Mdot
.18438 .56018 Mdot
.45544 .4535 Mdot
.48389 .28496 Mdot
.32273 .5262 Mdot
.54556 .29205 Mdot
.31457 .05068 Mdot
.11276 .51717 Mdot
.19473 .04532 Mdot
.14406 .53032 Mdot
.43614 .47019 Mdot
.48308 .27501 Mdot
.24137 .5363 Mdot
.59725 .39091 Mdot
.49345 .35162 Mdot
.48381 .40752 Mdot
.49625 .32929 Mdot
.45022 .4524 Mdot
.48483 .28589 Mdot
.32239 .52629 Mdot
.54585 .29227 Mdot
.31238 .05079 Mdot
.11247 .51687 Mdot
.1928 .04616 Mdot
.14351 .52994 Mdot
.42842 .47611 Mdot
.48393 .27242 Mdot
.20312 .53077 Mdot
.54393 .48329 Mdot
.48745 .25678 Mdot
.08674 .18957 Mdot
.04544 .40807 Mdot
.05763 .43324 Mdot
.03639 .36471 Mdot
.06965 .45509 Mdot
.03555 .26512 Mdot
.08933 .48006 Mdot
.22183 .03516 Mdot
.15161 .53533 Mdot
.49495 .40446 Mdot
.49656 .33569 Mdot
.46151 .44013 Mdot
.4875 .29542 Mdot
.36508 .51055 Mdot
.5109 .27249 Mdot
.16696 .09626 Mdot
.08216 .48143 Mdot
.03917 .24503 Mdot
.0921 .4831 Mdot
.28264 .02245 Mdot
.16687 .54442 Mdot
.52297 .34615 Mdot
.44334 .45817 Mdot
.48419 .28207 Mdot
.29755 .53218 Mdot
.56821 .31265 Mdot
.06435 .25538 Mdot
.03153 .30302 Mdot
.0843 .4741 Mdot
.13926 .07793 Mdot
.12775 .51796 Mdot
.36049 .05054 Mdot
.11869 .52319 Mdot
.23488 .03145 Mdot
.15502 .5375 Mdot
.50522 .38499 Mdot
.49631 .36614 Mdot
.49176 .38833 Mdot
.49793 .35477 Mdot
.48338 .40793 Mdot
.49618 .32875 Mdot
.44923 .4534 Mdot
.48467 .2852 Mdot
.31848 .52738 Mdot
.54938 .29501 Mdot
.28107 .05383 Mdot
.10784 .51202 Mdot
.15941 .06391 Mdot
.13379 .52281 Mdot
.12076 .4855 Mdot
.56966 .36676 Mdot
.4651 .43275 Mdot
.48968 .30183 Mdot
.38558 .5003 Mdot
.49818 .26905 Mdot
.05928 .28694 Mdot
.04262 .22798 Mdot
.09456 .48542 Mdot
.35577 .02057 Mdot
.18121 .55219 Mdot
.53953 .33872 Mdot
.38179 .5015 Mdot
.49977 .26942 Mdot
.06356 .2583 Mdot
.03164 .30019 Mdot
.08472 .47458 Mdot
.14551 .07324 Mdot
.12965 .51951 Mdot
.12525 .132 Mdot
.06822 .45985 Mdot
.03319 .33792 Mdot
.07669 .46518 Mdot
.05944 .18153 Mdot
.1016 .49322 Mdot
.53575 .05408 Mdot
.18381 .5601 Mdot
.44216 .46534 Mdot
.48286 .27751 Mdot
.26873 .53596 Mdot
.59019 .34631 Mdot
.35506 .51364 Mdot
.5169 .27509 Mdot
.2325 .06469 Mdot
.09893 .5023 Mdot
.10002 .11596 Mdot
.11545 .50712 Mdot
.89127 .18177 Mdot
.41566 .02214 Mdot
.19704 .55819 Mdot
.57245 .3748 Mdot
.48113 .40714 Mdot
.49639 .32899 Mdot
.44931 .4533 Mdot
.48469 .28526 Mdot
.31885 .52728 Mdot
.54905 .29474 Mdot
.28441 .05337 Mdot
.10838 .51259 Mdot
.16337 .06147 Mdot
.13496 .52371 Mdot
.17424 .52207 Mdot
.3912 .57601 Mdot
.50547 .50826 Mdot
.52655 .27399 Mdot
.57219 .09641 Mdot
.09723 .51087 Mdot
.03239 .3088 Mdot
.08232 .47228 Mdot
.1063 .10861 Mdot
.11748 .50899 Mdot
.92875 .19841 Mdot
.90887 .18281 Mdot
.53293 .04868 Mdot
.19445 .56247 Mdot
.51784 .3559 Mdot
.46959 .4288 Mdot
.49071 .30571 Mdot
.39759 .49338 Mdot
.4924 .26878 Mdot
.07383 .40916 Mdot
.87742 .17605 Mdot
.27709 .01762 Mdot
.17179 .54524 Mdot
.545 .34048 Mdot
.37887 .50296 Mdot
.50138 .26975 Mdot
.07154 .22742 Mdot
.03426 .35785 Mdot
.07403 .46121 Mdot
.0482 .21081 Mdot
.09698 .48831 Mdot
.40884 .02589 Mdot
.18783 .55614 Mdot
.54027 .33894 Mdot
.38117 .50182 Mdot
.50011 .26949 Mdot
.06499 .25155 Mdot
.03135 .31442 Mdot
.08252 .47204 Mdot
.11478 .09962 Mdot
.12016 .51143 Mdot
.95033 .21497 Mdot
.1097 .47019 Mdot
.54516 .33981 Mdot
.37454 .50517 Mdot
.50398 .27037 Mdot
.09055 .18222 Mdot
.04791 .41549 Mdot
.05432 .426 Mdot
.04046 .38465 Mdot
.06247 .443 Mdot
.03267 .33157 Mdot
.07824 .46716 Mdot
.0696 .16084 Mdot
.10531 .49709 Mdot
.63856 .08699 Mdot
.14689 .54952 Mdot
.27919 .02297 Mdot
.16594 .54394 Mdot
.52166 .34814 Mdot
.45024 .45145 Mdot
.4851 .28657 Mdot
.32534 .52543 Mdot
.54319 .29031 Mdot
.3299 .05022 Mdot
.11464 .51915 Mdot
.20647 .04056 Mdot
.14735 .53256 Mdot
.47036 .43799 Mdot
.48749 .29747 Mdot
.37582 .50543 Mdot
.50383 .27022 Mdot
.09115 .18111 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{362.313, 223.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008O0001Cb000`400?l00000o`00003oo`3ooooo
0?ooob40oooo003o0?ooool0oooo8@3oool00?l0ooooo`3ooolQ0?ooo`00o`3ooooo0?ooob40oooo
003o0?ooobT0oooo00L0_gA809cOo`3oool0omnL04P000000000M;oo0?00oooo003o0?ooobT0oooo
00P0okmd04RLg`3oool0gia8001d_`3oool0_ibL0=ooonl0oooo003o0?ooob00oooo00h0gia80000
0000M;l0oooo0?oog`2LB000000007Boo`3oool0oono07A8B018M9`0W4P007Booo80oooo003o0?oo
ob80oooo00`0okmd07Boo`3ogi`0B01809cOo`2oM7@0_ooo0?oog`2LB7@0_kmd0000M02oooob0?oo
o`00o`3ooolS0?ooo`040;mdM02LW4P004RL0=ooo`<0oooo00@0gia807Boo`3ookl0M7BolP3oool0
0?l0oooo8`3oool00`3ookl0M000001d_`040?ooo`040?oOW018M;l0oooO09a80080000000<0M;oo
0?ooo`3oool0k@3oool00?l0oooo8`3oool00`3ookl0M00007Boo`040?ooo`030?oog`2LB7@0_ooo
0?<0oooo003o0?ooob<0oooo00@0okmd00000000B9`0gooo103oool00`3OW4P0M;oo0?ooo`3b0?oo
o`00o`3ooolS0?ooo`050;md0000B9`0gmnL04Q8W03Oool00P3oool00`3OW4P00000001d_`3c0?oo
o`00o`3ooolQ0?ooo`090?noM0000000000007Boo`3oool0omnL04P00000B9`0gooo0?H0oooo003o
0?ooool0oooo8@3oool00?l0ooooo`3ooolQ0?ooo`00o`3ooooo0?ooob40oooo003o0?ooool0oooo
8@3oool00?l0ooooo`3ooolQ0?ooo`00o`3ooooo0?ooob40oooo003o0?ooool0oooo8@3oool00?l0
ooooo`3ooolQ0?ooo`00o`3ooooo0?ooob40oooo003o0?ooool0oooo8@3oool00?l0ooooo`3ooolQ
0?ooo`00o`3ooooo0?ooob40oooo003o0?ooool0oooo8@3oool00?l0ooooo`3ooolQ0?ooo`00o`3o
oooo0?ooob40oooo003o0?ooool0oooo8@3oool00600oooo00<0gia80000000000000`0000001P18
W=l0oooo0?ooo`3ogi`0B00007Boo`80oooo00H0omnL04P00000000000000018W03Ooolh0?ooo`03
0=nLB0000000000000<0000000<0B9cO0?ooo`3oool0=@3oool00`3ookl0M0000000000200000007
04RLg`3oool0oooo0?ooo`3ogi`0B00007Boo`020?ooo`060?oOW0180000000000000000B9`0gooo
>03oool00`3ookl0M000000000020000000304RLg`3oool0oooo03T0oooo00@0_g@0000000000000
M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`060?oOW0180000000000000000B9`0gooo<`3oool0
102oM00000000000001d_olk0?ooo`040;md00000000000007Boo`<0oooo00<0omnL04P0001d_ol0
0P3oool01P3ogi`0B00000000000000004RL0=oooa80oooo001Q0?ooo`030?noM000M;l0oooo0080
oooo00H0_gAd0;ooo`3oool0omnL04P0001d_ol20?ooo`060?noM0000000M;oo0?ooo`3ogi`0B7Bo
>@3oool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02oool0oooo03L0oooo00<0okmd0000001d_ol0
103oool00`3ogi`0B00007Boo`020?ooo`060?noM0000000M;oo0?ooo`3ogi`0B7Bo>P3oool00`3o
_g@0000007Boo`0k0?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0P3oool00`3ogi`0B00007Bo
o`020?ooo`060?noM0000000M;oo0?ooo`3ogi`0B7Bo<P3oool01P3OW4P007Bo0?ooo`3ogi`0B000
04RLgcT0oooo00H0gia8001d_`3oool0omnL04P00018W=l20?ooo`030?oOW0180000M;oo0080oooo
00H0okmd0000001d_ol0oooo0?oOW018M;lB0?ooo`00HP3oool00`3o_g@007Bo0?ooo`0>0?ooo`03
0?noM018W=l0oooo03P0oooo00<0okmd001d_`3oool0>`3oool00`3ooml0W4P0001d_`0>0?ooo`03
0?noM018W=l0oooo03P0oooo00<0oooO09a80000M;l0>P3oool00`3ooml0W4P004RLg`020?ooo`03
0?noM00004P0W=oo00/0oooo00<0okmd04RLg`3oool0;`3oool00`3ooml0W4P004RLg`020?ooo`03
0?noM00004P0W=oo03L0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`0;0?ooo`03
0?noM018W=l0oooo0100oooo001S0?ooo`030?noM000M;l0oooo00d0oooo00<0oono07@0M02oool0
>@3oool00`3o_g@007Bo0?ooo`0k0?ooo`030=nLB000B9`0gooo00d0oooo00<0oono07@0M02oool0
>@3oool00`3OW4P004RL0=ooo`0i0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0
gooo2P3oool00`3ookl0M01d0;ooo`0_0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000
B9`0gooo=P3oool00`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`X0oooo00<0oono
07@0M02oool0403oool005<0oooo00<0oooO09a8000000001`0000000`18W=l0oooo0?ooo`040?oo
o`030?noM018W=l0oooo00`0oooo00<0oooO09a8001d_ol0:@3oool00`3ooml0W4P0000000070000
000304RLg`3oool0oooo00@0oooo00<0okmd04RLg`3oool0:P3oool00`3ooml0W4P0000000070000
000304RLg`3oool0oooo00<0oooo00<0omnL04P0B02Lgol03@3oool00`3ooml0W4P007Boo`0Y0?oo
o`030?oog`2LB000000000L0000000<0B9cO0?ooo`3oool00`3oool00`3ogi`0B01809cOo`0/0?oo
o`030?oog`2LB000000000L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`030=nLB000
04P0W=oo00X0oooo00<0oooO09a8001d_ol0;`3oool00`3ooml0W4P0001d_`030?ooo`030=nLB000
04P0W=oo03H0oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`0:0?ooo`030?oog`2L
B000M;oo0100oooo001U0?ooo`030=nLB018W=l0oooo00/0oooo00<0oono07@00018W=l0>`3oool0
0`3OW4P0B9cO0?ooo`0i0?ooo`030?oo_`1d0000M;oo00d0oooo00<0oono07@00018W=l0>@3oool0
0`3ookl0M00007Boo`0j0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l02P3oool0
0`3ookl0M00004RLg`0`0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0=`3oool0
0`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO00X0oooo00<0oono07@00018W=l0403oool0
06H0oooo00<0_g@007Boo`3oool02P3oool00`3o_g@0000007Boo`0l0?ooo`030;md001d_ol0oooo
03T0oooo00<0_g@0001d_`3oool0303oool00`3o_g@0000007Boo`0j0?ooo`030;md0000M;l0oooo
03T0oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0:0?ooo`030?noM0000000M;oo
0300oooo00<0gia80000B02Lgol00P3oool00`3ooml0W4P0001d_`0g0?ooo`030=nLB00004P0W=oo
0080oooo00<0oooO09a80000M;l02P3oool00`3o_g@0000007Boo`0@0?ooo`00IP3oool00`3ogi`0
B01d0;ooo`070?ooo`060?oOg`3Oool0okmd0000000007@0_ooo?03oool00`3ogi`0B01d0;ooo`0i
0?ooo`030=nLB000B9`0gooo00T0oooo00H0omoO0=ooo`3o_g@000000000M02ooolj0?ooo`030=nL
B000B9`0gooo03T0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`060?ooo`060?oO
g`3Oool0okmd0000000007@0_ooo<03oool00`3ogi`0B00004RLg`030?ooo`030;md0000B9`0gooo
03H0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`060?ooo`060?oOg`3Oool0okmd
0000000007@0_ooo403oool006H0oooo00<0oooO09a8001d_ol01`3oool01@3ookl0M00000000000
04P0W=oo03d0oooo00<0oooO09a8001d_ol0>@3oool00`3ogi`0B01809cOo`090?ooo`050?oo_`1d
000000000000B02Lgol0>`3oool00`3ogi`0B01809cOo`0i0?ooo`040?oog`2LB00004RL0=ooo`80
oooo00<0gia80018W03Oool01P3oool01@3ookl0M0000000000004P0W=oo0340oooo00@0oooO09a8
0000B9`0gooo0P3oool00`3OW4P004RL0=ooo`0f0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0
gia80018W03Oool01P3oool01@3ookl0M0000000000004P0W=oo0140oooo001V0?ooo`030?oo_`1d
0000B9cO00P0oooo00<0gibL0;ooo`3oool0?P3oool00`3ookl0M00004RLg`0i0?ooo`030?oo_`1d
0000M;oo00X0oooo00<0gibL0;ooo`3oool0?03oool00`3ookl0M00007Boo`0j0?ooo`030?oOW018
0000M;oo0080oooo00<0gia8001d_`3oool01`3oool00`3OW9`0_ooo0?ooo`0c0?ooo`030?oOW018
0000M;oo0080oooo00<0gia8001d_`3oool0=`3oool00`3ogi`0B00007Boo`020?ooo`030=nLB000
M;l0oooo00L0oooo00<0gibL0;ooo`3oool04P3oool00680oooo00L0okmd0018W03Oool0oooo0=nL
B00004P0W=oo00P0oooo00<0omnL07BLg`3oool0>P3oool01`3o_g@004RL0=ooo`3oool0gia80000
B02Lgol0>P3oool00`2oM00007Bo0?ooo`090?ooo`030?oOW01dW=l0oooo03d0oooo00<0_g@0001d
_`3oool0>P3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`P0oooo00<0omnL07BLg`3oool0=03o
ool01P3OW4P0001d0;ooo`3ooml0W4P004RLgcT0oooo00H0gia80000M02oool0oooO09a80018W=l8
0?ooo`030?oOW01dW=l0oooo0180oooo001S0?ooo`050?oOW018000000000000001d_ol02P3oool0
1@2oM0000000000000000000B9cO03P0oooo00D0omnL04P000000000000007Boo`0i0?ooo`050?oo
_`1d000000000000M02oool02P3oool01@2oM0000000000000000000B9cO03P0oooo00D0oono07@0
00000000001d0;ooo`0k0?ooo`040=nLB00000000000001d_`X0oooo00D0_g@00000000000000000
04RLg`0b0?ooo`040=nLB00000000000001d_c/0oooo00@0gia800000000000007Bo2P3oool01@2o
M0000000000000000000B9cO00l0oooo003o0?ooool0oooo8@3oool00?l0ooooo`3ooolQ0?ooo`00
o`3ooooo0?ooob40oooo003o0?ooool0oooo8@3oool00?l0ooooo`3ooolQ0?ooo`00o`3ooooo0?oo
ob40oooo003o0?ooool0oooo8@3oool00?l0ooooo`3ooolQ0?ooo`00o`3ooooo0?ooob40oooo003o
0?ooool0oooo8@3oool004L0ooooo`000033000001H0oooo00170?ooo`030000003oool0000000`0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool0000001H0oooo00170?ooo`03
0000003oool0000000`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool00000
01H0oooo00170?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo0480oooo00D000000?ooo`3oool0oooo0000000F0?oo
o`00A`3oool300000?l0ooooMP3oool00`000000oooo0?ooo`140?ooo`<000005P3oool004L0oooo
00<000000?ooo`3oool0o`3ooomf0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
503oool004L0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo00D000000?ooo`3oool0oooo0000003N0?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool0503oool004L0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`030?ooo`8000000`3oool300000080oooo0`0000050?ooo`<0000000@0oooo0000000000000000
103oool2000000<0oooo00@000000?ooo`0000000000d03oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo07P0oooo0`0000030?ooo`@00000
0`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<0000000<0oooo00000000
00000`0000040?ooo`@0000000<0oooo000000000000100000050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0
oooo00170?ooo`030000003oool0oooo06l0oooo00<000000?ooo`0000001P3oool300000080oooo
2@0000000`3oool000000000000F00000080oooo1P0000030?ooo`<000000P3oool3000000D0oooo
00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo
00170?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool01@0000030?oooa/0000000<0
oooo000000000000500000000`3oool0000000000003000000030?ooo`000000000000D0oooo0`00
002l0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo00<00000
0?ooo`3oool0JP3oool300000080oooo5`0000000`3oool0000000000004000000P0oooo2P000002
0?ooo`H0000000<0oooo000000000000200000000`3oool00000000000020?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo01@0oooo000f0?ooo`030=nLB0000000000000<0000000<0B9cO0?ooo`3oool0203oool00`00
0000oooo0?ooo`1[0?oooa800000;03oool2000000040?ooo`00000000000?ooo`X0000000@0oooo
000000000000oooo100000030?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0D0?ooo`00=`3oool00`3o_g@007Bo0?ooo`020?ooo`030;mdM02oool0
oooo00P0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`040?ooo`l00000>P3oool2
000000030?ooo`00000000000080oooo3`0000070?ooo`030000003oool0oooo0:D0oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00>03oool00`3o_g@007Bo0?ooo`0<0?oo
o`030000003oool0oooo05/0oooo00@000000?ooo`3oool0oooo0`0000020?ooo``00000B03oool0
0`000000oooo0000000<000000D0oooo0`00002V0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0503oool003T0oooo00<0okmd001d_`3oool02`3oool00`000000oooo0?ooo`1J0?oo
o`<000000`3oool<00000540oooo3P0000020?ooo`<000000P3oool010000000oooo0?ooo`00002O
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool002T0oooo00<0oooO09a8
000000001`0000000`18W=l0oooo0?ooo`040?ooo`030?noM018W=l0oooo00X0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000X00000F`3oool90000
00030?ooo`000000000000P00000WP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
01@0oooo000k0?ooo`030=nLB018W=l0oooo00T0oooo1000001D0?ooo`<000000P3oool:000006@0
oooo0`0000000`3oool0000000000006000000030?ooo`000000oooo09h0oooo00<000000?ooo`3o
ool0@`3oool4000001H0oooo000l0?ooo`030;md001d_ol0oooo00P0oooo00<000000?ooo`3oool0
D@3oool00`000000oooo0?ooo`03000000030?ooo`000000000000L00000K03oool00`000000oooo
00000005000000<0oooo0P00002K0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
503oool003`0oooo00<0omnL04P0M02oool0203oool00`000000oooo0?ooo`1@0?ooo`<000000P3o
ool9000007<0oooo00<000000?ooo`0000000`3oool5000009T0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0D0?ooo`00?03oool00`3ooml0W4P007Boo`080?ooo`030000003oool0
oooo0540oooo00<000000?ooo`0000001`00001m0?ooo`D0000000<0oooo0000000000000P00002C
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool003`0oooo00<0oono07@0
0018W=l0203oool00`000000oooo0?ooo`1A0?ooo`P00000P@3oool2000000030?ooo`0000000000
00L00000103oool00`000000oooo000000280?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool0503oool003P0oooo00L0okmd0018W03Oool0oooo0=nLB00004P0W=oo00P0oooo00<00000
0?ooo`3oool0C`3oool700000340oooo100000000`3oool000000000000B00000080oooo00<00000
0?ooo`3oool0>@3ooolA000008H0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D
0?ooo`00>@3oool01@3ogi`0B000000000000000M;oo00T0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`030?ooo`L00000:@3oool3000000030?ooo`0000000000028000001P3oool0
0`000000oooo0?ooo`0d0?ooo`T0000000<0oooo0000000000000P0000020?ooo`030000003oool0
oooo0800oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`00
0000oooo0?ooo`160?ooo`<000000P3oool6000002H0oooo500000000`3oool000000000000B0000
0080oooo100000040?ooo`<000001@3oool00`000000oooo0?ooo`0a0?ooo`X0000000H0oooo0000
0000000000000?ooo`00001o0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503o
ool004L0oooo00<000000?ooo`3oool0A@3oool010000000oooo0000003oool700000240oooo00<0
00000?ooo`000000300000000`3oool0000000000004000001L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0`0000020?ooo`030000003o
ool0oooo0300oooo0P0000000`3oool000000000000;000007`0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`130?ooo`/000007`3ooolA
000003@0oooo00<000000?ooo`3oool00`0000020?ooo`040000003oool00000000002l0oooo3@00
001k0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo00<00000
0?ooo`3oool0@P3oool9000001h0oooo3@0000100?ooo`030000003oool0oooo00H000000P3oool0
0`000000oooo0?ooo`0/0?ooo`T00000O03oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo01@0oooo00170?ooo`030000003oool0oooo04<0oooo1`00000L0?ooo``00000B03oool01000
0000oooo0000000000020?ooo`<00000<@3oool7000000030?ooo`000000oooo07L0oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool300000480oooo1P00000L0?oo
o`T00000E03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02T0oooo2P0000040?oo
o`030000003oool0oooo06d0oooo00<000000?ooo`3oool0A03oool3000001H0oooo00170?ooo`03
0000003oool0oooo0440oooo1@00000J0?ooo`T00000H@3oool300000080oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0000000:000006h0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`100?ooo`D000006@3oool8000006D0oooo
00<000000?ooo`3oool00`0000030?ooo`800000:03oool9000006h0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0j0?ooo`040000003o
ool0oooo0?ooo`D00000603oool8000006`0oooo00@000000?ooo`3oool0oooo1000000Z0?ooo`L0
0000K@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?ooo`030000
003oool0oooo03T0oooo0`0000000`3oool0000000000003000001H0oooo00<000000?ooo`000000
1@00001d0?ooo`8000001P3oool3000002D0oooo1@000000103oool000000000000000030?ooo`03
0000003oool0oooo0680oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00
A`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0000000<000005`3oool6000007h0oooo
1@0000000`3oool000000?ooo`0T0?ooo`030000003oool0000000P00000H`3oool00`000000oooo
0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo03H0oooo00@0
00000?ooo`3oool0oooo1@00000E0?ooo`P00000P03oool7000002L0oooo2000001S0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo00<000000?ooo`3oool0=@3o
ool3000000030?ooo`000000000000<000005@3oool6000008H0oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`0T0?ooo`P00000G`3oool00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo01@0oooo00170?ooo`030000003oool0oooo03H0oooo00<000000?ooo`0000000`00000E
0?ooo`H00000S`3oool3000000030?ooo`000000oooo02D0oooo1P0000000`3oool000000?ooo`1K
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo00<000000?oo
o`3oool0=`3oool4000001@0oooo1P00002B0?ooo`030000003oool00000008000000P3oool00`00
0000oooo0?ooo`0R0?ooo`T00000F@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
01@0oooo00170?ooo`030000003oool0oooo03H0oooo1000000C0?ooo`H00000U`3oool00`000000
oooo0?ooo`03000000040?ooo`000000oooo00000280oooo00<000000?ooo`0000001P00001F0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo00<000000?ooo`3o
ool0=@3oool4000001<0oooo1@00002M0?ooo`030000003oool0000000D000008`3oool8000000D0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0
oooo00170?ooo`030000003oool0oooo0300oooo00@000000?ooo`3oool0oooo0`00000C0?ooo`@0
0000X`3oool00`000000oooo00000003000000040?ooo`000000oooo00000240oooo1`0000020?oo
o`@00000C03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?ooo`<0
0000;P3oool800000180oooo1@00002W0?ooo`80000000<0oooo0000000000000`0000000`3oool0
00000?ooo`0P0?ooo`H0000000<0oooo0000000000000P00001;0?ooo`030000003oool0oooo04@0
oooo0`00000F0?ooo`00A`3oool00`000000oooo0?ooo`0]0?ooo`P000004P3oool500000:`0oooo
00<000000?ooo`0000001@00000R0?ooo`P00000B`3oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo01@0oooo00170?ooo`030000003oool0oooo02d0oooo1`00000A0?ooo`D00000/@3o
ool00`000000oooo0000000300000080oooo00<000000?ooo`3oool07P3oool00`000000oooo0000
0005000004T0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00D000004@3oool500000;D0oooo1`00000R
0?ooo`P00000AP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?oo
o`030000003oool0oooo02X0oooo0`0000000`3oool000000000000200000140oooo1000002i0?oo
o`030000003oool0oooo00@000000P3oool00`000000oooo0?ooo`0N0?ooo`H000000P3oool01@00
0000oooo0?ooo`3oool0000003h0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D
0?ooo`00A`3oool00`000000oooo0?ooo`0Z0?ooo`L000004@3oool400000;h0oooo1`0000000`3o
ool000000?ooo`0O0?ooo`/000000P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool0503oool004L0oooo00<000000?ooo`3oool0:@3oool700000140
oooo100000310?ooo`030000003oool0oooo00D0000000<0oooo0000003oool07P3oool00`000000
oooo0?ooo`06000000040?ooo`0000000000000003T0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0Z0?ooo`D000004@3oool300000<L0
oooo00@000000?ooo`000000oooo0`00000S0?ooo`L000000P3oool3000003D0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0[0?ooo`<0
0000403oool2000000030?ooo`000000oooo0<`0oooo00D000000?ooo`3oool0oooo0000000R0?oo
o`/00000=03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?ooo`03
0000003oool0oooo02H0oooo0P0000020?ooo`@000003`3oool400000=40oooo0`00000S0?ooo`P0
0000=@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?ooo`030000
003oool0oooo02D0oooo2000000?0?ooo`@00000d`3oool3000002@0oooo2@00000b0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo00<000000?ooo`3oool09@3o
ool7000000h0oooo1@00003E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0803o
ool700000300oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool0
0`000000oooo0?ooo`0T0?ooo`L000003P3oool400000=d0oooo0`0000000`3oool000000000000P
0?ooo`P00000103oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0503oool004L0oooo0`00000T0?ooo`80000000@0oooo0000000000000000403oool0
0`000000oooo0?ooo`3N0?ooo`030000003oool0000000<000008P3oool7000000040?ooo`000000
0000000002L0oooo00<000000?ooo`3oool0A03oool3000001H0oooo00170?ooo`030000003oool0
oooo0280oooo1`00000?0?ooo`030000003oool0oooo0><0oooo0P00000U0?ooo`T00000103oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool0
04L0oooo00<000000?ooo`3oool08@3oool7000000l0oooo0`00003]0?ooo`030000003oool0oooo
01h0oooo20000000103oool0000000000000000Q0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0503oool004L0oooo00<000000?ooo`3oool08@3oool7000000h0oooo00<000000?oo
o`000000k@3oool300000080oooo00<000000?ooo`3oool07@3oool800000280oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0R0?ooo`D0
00003P3oool300000>l0oooo1`00000O0?ooo`030000003oool0000000H000000`3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo
00<000000?ooo`3oool07`3oool010000000oooo0?ooo`3oool3000000h0oooo0`00003a0?ooo`03
0000003oool0oooo00@0000000<0oooo0000003oool07P3oool;000001X0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0N0?ooo`<00000
00@0oooo00000000000000003P3oool400000?H0oooo00<000000?ooo`0000000`00000O0?ooo`T0
00006P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?ooo`030000
003oool0oooo01h0oooo0P0000000`3oool0000000000002000000d0oooo1000003j0?ooo`@00000
8`3oool7000001L0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3o
ool00`000000oooo0?ooo`0M0?ooo`L000003P3oool300000?`0oooo0P0000040?ooo`030000003o
ool0oooo01h0oooo200000030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0N0?ooo`D000003P3oool0
0`000000oooo0000003o0?ooo`<0oooo0`00000R0?ooo`H0000000@0oooo0000000000000000403o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003oool0
oooo01l0oooo1000000=0?ooo`<00000o`3oool50?ooo`<000008`3oool5000000030?ooo`000000
000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo01@0oooo00170?ooo`030000003oool0oooo01l0oooo0`00000=0?ooo`<00000o`3oool70?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`040000
0080oooo0`0000090?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`04000000`0oooo1000003o0?ooo`d0
oooo0`0000020?ooo`030000003oool0oooo01h0oooo1@0000000`3oool000000?ooo`090?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo0`00000J0?ooo`L00000
303oool400000?l0oooo3`3oool00`000000oooo0?ooo`0300000200oooo1@0000000`3oool00000
000000080?ooo`030000003oool0oooo04@0oooo0`00000F0?ooo`00A`3oool00`000000oooo0?oo
o`0J0?ooo`80000000<0oooo0000000000000P00000<0?ooo`<00000o`3ooolB0?ooo`<000000P3o
ool00`000000oooo0000000O0?ooo`030000003oool0000000@000001P3oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo01T0oooo1`00000<
0?ooo`<00000o`3ooolD0?ooo`030000003oool0oooo00H00000803oool800000080oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0I0?oo
o`80000000@0oooo0000000000000000303oool400000?l0oooo603oool00`000000oooo00000003
00000280oooo1P0000000`3oool000000?ooo`020?ooo`800000@`3oool00`000000oooo0?ooo`0D
0?ooo`00A`3oool00`000000oooo0?ooo`0H0?ooo`L00000303oool300000?l0oooo7@3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000007`3oool6000000030?ooo`000000000000@00000@@3o
ool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
000000800000303oool300000?l0oooo8@3oool500000200oooo3@00000o0?ooo`030000003oool0
oooo01@0oooo00170?ooo`030000003oool0oooo01X0oooo1000000<0?ooo`<00000o`3ooolR0?oo
o`030000003oool0000002@0oooo00<000000?ooo`0000002000000n0?ooo`030000003oool0oooo
01@0oooo000f0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool02@3oool00`000000
oooo0?ooo`0J0?ooo`<00000303oool300000?l0oooo;03oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00L00000103oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01@0
oooo000h0?ooo`030?noM0000000M;oo00`0oooo00<000000?ooo`3oool06P3oool3000000/0oooo
0`00003o0?ooob`0oooo1000000K0?ooo`030000003oool0oooo0080oooo1P0000020?ooo`<00000
00<0oooo0000003oool0=P3oool00`000000oooo0?ooo`0D0?ooo`00>03oool00`3ooml0W4P0001d
_`0<0?ooo`030000003oool0oooo01T0oooo0`00000<0?ooo`800000o`3oool^0?ooo`@000006P3o
ool00`000000oooo0?ooo`050?ooo``00000=@3oool00`000000oooo0?ooo`0D0?ooo`00>@3oool0
0`3OW4P004RL0=ooo`0;0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`0000000`00000;
0?ooo`<00000o`3oool_0?ooo`8000001@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`000000200000030?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0503oool002T0oooo00<0oooO09a8000000001`0000000`18W=l0oooo0?ooo`030?oo
o`030?oOW01804P0W=oo00/0oooo00<000000?ooo`3oool05@3oool6000000`0oooo0P00003o0?oo
ocH0oooo1000000C0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`0000001@0000020?oo
o`<00000;`3oool00`000000oooo0?ooo`0D0?ooo`00>@3oool00`3ookl0M00007Boo`0;0?ooo`@0
00005@3oool5000000/0oooo0`00003o0?ooocH0oooo1@00000B0?ooo`030000003oool0oooo00h0
oooo1P000000103oool0000000000000000[0?ooo`@000005P3oool003X0oooo00<0_g@0001d_`3o
ool02P3oool00`000000oooo0?ooo`0G0?ooo`@000002`3oool200000?l0oooo>03oool300000080
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`P00000;`3oool00`000000
oooo0?ooo`0D0?ooo`00>P3oool00`3OW4P004RL0=ooo`0:0?ooo`030000003oool0oooo01H0oooo
1000000;0?ooo`<00000o`3oooll0?ooo`<00000103oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0180oooo1P0000050?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
503oool003X0oooo00<0omnL04P0B02Lgol02P3oool00`000000oooo0?ooo`0C0?ooo`80000000@0
oooo00000000000000002`3oool300000?l0oooo?P3oool00`000000oooo0?ooo`020?ooo`<00000
2@3oool00`000000oooo0?ooo`0D0?ooo`L0000000@0oooo00000000000000009`3oool00`000000
oooo0?ooo`0D0?ooo`00>P3oool00`3ookl0M00007Boo`0:0?ooo`030000003oool0oooo0180oooo
1`00000;0?ooo`<00000o`3ooom40?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
5P3oool6000000030?ooo`000000oooo02L0oooo00<000000?ooo`3oool0503oool003/0oooo00<0
_g@0001d_`3oool02@3oool00`000000oooo0?ooo`0C0?ooo`H000002P3oool300000?l0ooooC03o
ool00`000000oooo00000002000001/0oooo0P0000030?ooo`8000009P3oool00`000000oooo0?oo
o`0D0?ooo`00>@3oool01@3ookl0M0000000000007@0_ooo00T0oooo00<000000?ooo`3oool04P3o
ool6000000/0oooo0`00003o0?oood/0oooo1P00000O0?ooo`D000001@3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`0000000P00000:0?ooo`<00000o`3ooom=0?ooo`030000003oool00000008000000P3oool0
0`000000oooo0000000K0?ooo`H000000P3oool3000001d0oooo00<000000?ooo`3oool0503oool0
04L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`03000000X0oooo1000003o0?oo
oe40oooo00<000000?ooo`0000001000000K0?ooo`L0000000<0oooo0000003oool07@3oool00`00
0000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0@0?ooo`<0000000@0oooo00000000
000000002P3oool300000?l0ooooDP3oool01P000000oooo0?ooo`000000oooo00000200oooo1@00
000N0?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo0100oooo1P00000;
0?ooo`<00000o`3ooomB0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000603oool5
000001d0oooo00<000000?ooo`3oool0503oool004L0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo00000002000000X0oooo1000003o0?oooe80oooo00<000000?ooo`3oool0203oool50000
01T0oooo1@00000K0?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo0100
oooo1P00000:0?ooo`<00000o`3ooomC0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`00
00000P0000020?ooo`030000003oool0oooo01D0oooo1P0000050?ooo`8000004@3oool00`000000
oooo0?ooo`0D0?ooo`00A`3oool300000140oooo1000000;0?ooo`800000o`3ooomD0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool00`0000000`3oool000000000000E0?ooo`D00000
0`3oool4000000h0oooo0`00000F0?ooo`00A`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00<000002P3oool400000?l0ooooD`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0000000D000004`3oool5000000<0oooo100000000`3oool000000?ooo`0<0?ooo`030000003o
ool0oooo01@0oooo00170?ooo`030000003oool0oooo00h0oooo0`000000103oool0000000000000
000:0?ooo`<00000o`3ooomD0?ooo`030000003oool0oooo01<0oooo1P0000030?ooo`030000003o
ool0000000h0oooo100000040?ooo`030000003oool0000000800000303oool00`000000oooo0?oo
o`0D0?ooo`00A`3oool00`000000oooo0?ooo`0>0?ooo`H000002`3oool300000?l0ooooE03oool0
0`000000oooo0?ooo`0F0?ooo`8000000`3oool600000080oooo00<000000?ooo`3oool0203oool4
000000H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool00000008000002P3oool300000?l0ooooE@3oool00`00
0000oooo0?ooo`0K0?oooa00000000<0oooo0000003oool01000000D0?ooo`030000003oool0oooo
01@0oooo00170?ooo`030000003oool0oooo0140oooo0`00000:0?ooo`<00000o`3ooomE0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool00P0000020?ooo`h000002P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo0100oooo
0`00000;0?ooo`800000o`3ooomF0?ooo`030000003oool0oooo02@0oooo1`0000000`3oool00000
0?ooo`02000000X0oooo0`0000090?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003o
ool0oooo0100oooo0`00000:0?ooo`<00000o`3ooomF0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool01@3oool4000000T0oooo00<000000?ooo`3oool0503oool004L0oooo00<00000
0?ooo`3oool0403oool3000000X0oooo0`00003o0?oooeH0oooo00<000000?ooo`3oool0<03oool3
000000D0oooo1@0000090?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo
0100oooo0`0000090?ooo`<00000o`3ooomG0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool01@3oool00`000000oooo0000000:0?ooo`030000003oool0oooo01@0oooo00170?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`0000000P00000:0?ooo`<00000o`3ooomG0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo00<000000?ooo`3oool0
303oool6000000T0oooo0`00003o0?oooeP0oooo00<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0=0?ooo`D000002@3oool300000?l0ooooF03o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?ooo`<000003P3oool4
000000T0oooo0`00003o0?oooeP0oooo00<000000?ooo`3oool0A03oool3000001H0oooo00170?oo
o`030000003oool0oooo00h0oooo0`00000:0?ooo`<00000o`3ooomH0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool0503oool004L0oooo00<000000?ooo`3oool03P3oool3000000T0
oooo1000003o0?oooeP0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00
A`3oool00`000000oooo0?ooo`0>0?ooo`<000002@3oool300000?l0ooooF@3oool00`000000oooo
0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo00d0oooo1000
00090?ooo`<00000o`3ooomI0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503o
ool004L0oooo00<000000?ooo`3oool03@3oool4000000P0oooo1000003o0?oooeT0oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0=0?oo
o`<000002@3oool300000?l0ooooFP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
01@0oooo00170?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`0000090?ooo`<0
0000o`3ooomJ0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo
00<000000?ooo`3oool02@3oool3000000040?ooo`0000000000000000T0oooo0`00002e0?ooo`80
000000@0oooo0000003oool00000WP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
01@0oooo00170?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`0000090?ooo`<0
0000/`3oool:000009`0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00
A`3oool00`000000oooo0?ooo`0<0?ooo`<000002@3oool400000;80oooo3P0000000`3oool00000
0?ooo`2F0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo00000002000000T0oooo0`00002b0?ooo`H0000000@0
oooo0000003oool0oooo2@00002E0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
503oool004L0oooo0`0000090?ooo`H000002P3oool300000;40oooo0`00000:0?ooo`80000000<0
oooo0000000000000`00002C0?ooo`030000003oool0oooo04@0oooo0`00000F0?ooo`00A`3oool0
0`000000oooo0?ooo`090?ooo`H000002@3oool300000;80oooo1000000=0?ooo`D00000TP3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`0000000P0000090?ooo`<00000/P3oool3000000P0oooo1P0000030?oo
o`<0000000<0oooo0000003oool0SP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
01@0oooo00170?ooo`030000003oool0oooo00`0oooo0`0000090?ooo`<00000/P3oool4000000D0
oooo3@0000000`3oool0000000000003000008`0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0;0?ooo`@00000203oool400000;<0oooo
100000030?oooaD00000R`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo
00170?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000000P00000:0?ooo`800000]03o
ool3000000@0oooo1@0000030?ooo`h00000RP3oool00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo01@0oooo00170?ooo`030000003oool0oooo00P0oooo1P00000:0?ooo`030000003oool0
oooo0;@0oooo0P0000040?ooo`<000002@3oool<000008P0oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`080?ooo`H000002@3oool30000
0;D0oooo0`0000030?ooo`<00000303oool:000008L0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`090?ooo`030000003oool000000080
00002@3oool300000;D0oooo0`0000030?ooo`<000003P3oool:000008D0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0;0?ooo`<00000
2@3oool300000;H0oooo0`0000020?ooo`<00000403oool9000008@0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<000002@3oool300000;H0oooo100000000`3oool000000000000200000140oooo2000
00230?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo00<00000
0?ooo`3oool01`3oool3000000040?ooo`0000000000000000T0oooo0`00002g0?ooo`<0000000<0
oooo0000000000000P00000C0?ooo`L00000PP3oool00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo01@0oooo00170?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000000`000009
0?ooo`800000^@3oool00`000000oooo0?ooo`04000001@0oooo1@0000020?ooo`030000003oool0
oooo07h0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool30000
00L0oooo0`000000103oool000000000000000080?ooo`<00000^P3oool00`000000oooo0?ooo`03
000001H0oooo1`00001o0?ooo`030000003oool0oooo04@0oooo0`00000F0?ooo`006`3oool00`3O
W4P0001d0;ooo`0Y0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`0000080?oo
o`<00000^@3oool3000000030?ooo`0000000000008000005P3oool7000007h0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00503oool00`3ookl0M7Bo0?ooo`040?ooo`03
0?oo_`1dB9`0gooo02T0oooo00<000000?ooo`3oool02`3oool3000000P0oooo0`00002j0?ooo`L0
0000603oool6000007d0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00
503oool00`3ogi`0B01d0;ooo`030?ooo`030?noM00007@0_ooo02X0oooo00<000000?ooo`3oool0
2P3oool4000000T0oooo00<000000?ooo`3oool0^@3oool7000001T0oooo1000001n0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool0503oool001@0oooo00L0omnL04P0000000000018
09cOo`3ogi`0B7Bo02`0oooo00<000000?ooo`3oool02P3oool4000000P0oooo0`00002k0?ooo`80
000000<0oooo0000000000000P00000I0?ooo`@000000P3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool001H0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`0Y0?ooo`030000003oool0oooo00X0oooo100000080?ooo`<00000
_@3oool5000001/0oooo1P00001i0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
503oool001D0oooo00T0oono07@0M02oool0oooo0?oog`2LB00000000000M02oool0:@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0000000<00000203oool300000;`0oooo1P00000L0?oo
o`@00000NP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo000D0?ooo`03
0?oo_`1d07@0_ooo00@0oooo00<0omnL04Qd_`3oool0:@3oool00`000000oooo0?ooo`070?ooo`H0
00002@3oool300000;`0oooo1P00000M0?ooo`H00000M`3oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo01@0oooo000D0?ooo`030?noM0000000M;oo00<0oooo00<0oono07A8W03Oool0
6`3oool0102oM00000000000001d_ol;0?ooo`030000003oool0oooo00L0oooo1P0000090?ooo`<0
0000_03oool7000001d0oooo1P00001f0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool0503oool003L0oooo00H0gia8001d_`3oool0omnL04P00018W=l:0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`0000000P0000090?ooo`<00000_@3oool6000001h0oooo1@00001f0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool001h0oooo00@0okmd00000000
07@0_ooo503oool00`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo00T0oooo00<000000?oo
o`3oool0203oool00`000000oooo00000002000000T0oooo0`00002m0?ooo`H000007`3oool50000
07D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`004`3oool0203OW4P0
000007Boo`3oool0oooO09bL_`3ooml0W4P00`0000000`00M;l0oooo0?ooo`0E0?ooo`030?oog`2L
B000B9cO0080oooo00@0oooO09a80000B9`0gooo203oool00`000000oooo0?ooo`070?ooo`H00000
2@3oool300000;d0oooo1P00000P0?ooo`D00000M03oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo01@0oooo000@0?ooo`040=nLB00000000000001d_`<0oooo00@0oono07@0000004P0
W=oo0P3oool00`2oW9`0gooo0?ooo`0F0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02L
gol0203oool00`000000oooo0?ooo`070?ooo`H000002@3oool300000;h0oooo1P00000O0?ooo`@0
000000<0oooo0000003oool0LP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0
oooo000?0?ooo`040?oo_`1d000004RL0=ooo`P0oooo00D0gmoO0;md000000000000001d_`0G0?oo
o`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0203ooooo00000<<000005P3oool001X0
oooo00<0oooO09a8001d_ol00P3oool00`3OW4P0001d0;ooo`0E0?ooo`030=nLB00004P0W=oo0080
oooo00<0oooO09a80000M;l0203oool00`000000oooo0?ooo`080?ooo`030000003oool000000080
00002P3oool00`000000oooo0?ooo`2m0?ooo`H000008@3oool600000740oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0D0?ooo`006P3oool00`3ooml0W7BL0=ooo`020?ooo`030=nL
M02Lgol0oooo01D0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`070?ooo`030000
003oool0oooo00L0oooo1P00000:0?ooo`030000003oool0oooo0;h0oooo1P00000Q0?ooo`D00000
L@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo000g0?ooo`040?oog`2L
B00004RL0=ooo`80oooo00<0gia80018W03Oool01`3oool00`000000oooo0?ooo`070?ooo`H00000
2@3oool300000;l0oooo1P00000R0?ooo`<00000LP3oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo01@0oooo000h0?ooo`030?oOW0180000M;oo0080oooo00<0gia8001d_`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`<0000000@0oooo0000000000000000203oool300000;l0oooo
1P00000R0?ooo`D00000L03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo
000i0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0000000<00000203oool300000;l0oooo1P00000S0?ooo`D00000K`3oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo000j0?ooo`040=nLB00000000000001d_`T0
oooo00<000000?ooo`3oool02P3oool4000000P0oooo0`0000300?ooo`D000008`3oool6000006h0
oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo
0?ooo`0:0?ooo`@00000203oool300000<00oooo1@00000>0?ooo`@000004P3oool4000006l0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?oo
o`0;0?ooo`<00000203oool300000<40oooo1000000<0?ooo`T00000403oool3000006l0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0:
0?ooo`@00000203oool300000<00oooo1@00000;0?ooo`/00000403oool3000006h0oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0000000<00000203oool300000<00oooo1@00000:0?ooo`h000003P3oool40000
06d0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000
oooo0?ooo`070?ooo`<0000000@0oooo0000000000000000203oool300000<00oooo1@0000090?oo
o`@000001`3oool5000000d0oooo1@00001/0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool0503oool004L0oooo0`0000080?ooo`80000000@0oooo00000000000000002@3oool30000
0;l0oooo1P0000070?ooo`@000002@3oool5000000d0oooo1000001/0?ooo`030000003oool0oooo
04@0oooo0`00000F0?ooo`00A`3oool00`000000oooo0?ooo`080?ooo`H000002@3oool300000;l0
oooo1P0000070?ooo`<00000303oool4000000`0oooo1@00001[0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool0503oool004L0oooo00<000000?ooo`3oool02@3oool00`000000oooo
00000003000000P0oooo0`00002o0?ooo`D000001`3oool4000000d0oooo1000000<0?ooo`<00000
K03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003o
ool0oooo00/0oooo0`0000090?ooo`<00000_`3oool6000000D0oooo1000000?0?ooo`@000002`3o
ool3000006`0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0000000<00000203oool300000<00oooo1@000005
0?ooo`@00000403oool3000000/0oooo1000001[0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0503oool004L0oooo00<000000?ooo`3oool0203oool7000000P0oooo0`0000300?oo
o`@000001P3oool300000180oooo00<000000?ooo`3oool02`3oool4000006X0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0000000<00000203oool400000;h0oooo1@0000050?ooo`@00000803oool4000006X0
oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo
0?ooo`080?ooo`<0000000@0oooo00000000000000002@3oool200000;l0oooo1@0000050?ooo`<0
00005P3oool00`000000oooo0?ooo`080?ooo`<00000J`3oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo00P0oooo0`000000103oool00000
0000000000090?ooo`<00000_P3oool5000000D0oooo0`00000E0?ooo`<000002@3oool3000006/0
oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo
0?ooo`090?ooo`80000000@0oooo00000000000000002P3oool00`000000oooo0?ooo`2n0?ooo`@0
0000103oool3000001H0oooo100000080?ooo`@00000JP3oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo00P0oooo10000000103oool00000
0000000000080?ooo`<00000_`3oool4000000@0oooo0`00000G0?ooo`<000002@3oool3000006X0
oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo
0?ooo`090?ooo`8000000P3oool3000000P0oooo0`00002n0?ooo`D000000`3oool4000001P0oooo
0P0000090?ooo`<00000JP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo
00170?ooo`030000003oool0oooo00T0oooo1`0000080?ooo`@00000_@3oool5000000<0oooo0`00
000H0?ooo`@00000203oool4000006T0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`0D0?ooo`00A`3oool3000000T0oooo0`000000103oool000000000000000080?ooo`@00000_@3o
ool4000000<0oooo1000000I0?ooo`<00000203oool4000006T0oooo00<000000?ooo`3oool0A03o
ool3000001H0oooo00170?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool010000008
0?ooo`<00000_@3oool4000000<0oooo1000000I0?ooo`<00000203oool4000006T0oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`090?oo
o`<000000P3oool3000000T0oooo0P00002l0?ooo`D000000`3oool3000001/0oooo0`0000070?oo
o`@00000J@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?ooo`03
0000003oool0oooo00T0oooo0`0000000`3oool0000000000002000000P0oooo1000002k0?ooo`D0
00000P3oool3000001`0oooo0`0000070?ooo`@00000J@3oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool0
oooo0`0000090?ooo`<00000^`3oool4000000<0oooo0`00000M0?ooo`030000003oool0oooo00H0
oooo0`00001Z0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`03000000T0oooo0`00002k0?ooo`@00000
0P3oool4000001d0oooo00<000000?ooo`3oool01P3oool3000006X0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0:0?ooo`<000000P3o
ool3000000P0oooo0`00002j0?ooo`D000000P3oool3000001d0oooo0`0000070?ooo`<00000JP3o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003oool0
oooo00X0oooo0`0000000`3oool0000000000002000000P0oooo1000002i0?ooo`@000000P3oool4
000001d0oooo0`0000070?ooo`@00000J@3oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo01@0oooo00170?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0100000090?oo
o`<00000^03oool500000080oooo0`00000O0?ooo`<000001P3oool3000006X0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00<000002@3oool300000;P0oooo1@000000103oool0000000000000000Q0?oo
o`030000003oool0oooo00D0oooo1000001Y0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool0503oool004L0oooo00<000000?ooo`3oool02`3oool3000000030?ooo`00000000000080
0000203oool400000;H0oooo1@0000020?ooo`<00000:@3oool3000006X0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0;0?ooo`<00000
00<0oooo0000000000000P0000090?ooo`<00000]`3oool4000000040?ooo`0000000000000002T0
oooo0`00001[0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo
00<000000?ooo`3oool02`3oool9000000P0oooo0`00002d0?ooo`030000003oool0000000<00000
0P3oool300000280oooo00<000000?ooo`3oool0103oool4000006X0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool3000000`0oooo0P0000020?ooo`@00000203o
ool400000;80oooo1`000000103oool0000000000000000R0?ooo`<000001@3oool3000006/0oooo
00<000000?ooo`3oool0A03oool3000001H0oooo00170?ooo`030000003oool0oooo0100oooo1000
00090?ooo`800000/P3oool7000000040?ooo`0000000000000002@0oooo00<000000?ooo`3oool0
103oool4000006X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3o
ool00`000000oooo0?ooo`0=0?ooo`80000000<0oooo0000000000000P0000090?ooo`<00000/@3o
ool7000000040?ooo`0000000000000002X0oooo1000001[0?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool0503oool004L0oooo00<000000?ooo`3oool0303oool4000000030?ooo`00
0000000000800000203oool300000;40oooo1P0000000`3oool0000000000002000002<0oooo00<0
00000?ooo`3oool0103oool4000006/0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`0D0?ooo`00A`3oool00`000000oooo0?ooo`0=0?ooo`8000000P3oool4000000P0oooo1000002a
0?ooo`T000008`3oool3000000H0oooo0`00001[0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0503oool004L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050000
00P0oooo0`00002a0?ooo`@0000000@0oooo0000000000000000903oool2000000H0oooo0`00001/
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo00<000000?oo
o`3oool03@3oool300000080oooo100000080?ooo`<00000/03oool9000002<0oooo0`0000050?oo
o`@00000K03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?ooo`03
0000003oool0oooo00h0oooo0`0000020?ooo`<000002@3oool300000:h0oooo2@00000U0?ooo`03
0000003oool0oooo00@0oooo0`00001]0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool0503oool004L0oooo00<000000?ooo`3oool03`3oool2000000030?ooo`000000000000<00000
203oool300000:h0oooo10000000103oool0000000000000000U0?ooo`<000001@3oool2000006h0
oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo
0?ooo`0>0?ooo`@0000000<0oooo0000000000000P0000090?ooo`<00000[03oool8000002H0oooo
0`0000040?ooo`<00000KP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo
00170?ooo`030000003oool0oooo00l0oooo0`0000000`3oool0000000000003000000P0oooo0`00
002[0?ooo`T000009`3oool00`000000oooo0?ooo`020?ooo`<00000K`3oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo00l0oooo2@000009
0?ooo`<00000Z03oool00`000000oooo00000007000002H0oooo00<000000?ooo`3oool0103oool3
000006l0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`00
0000oooo0?ooo`0?0?ooo`<000000P3oool5000000P0oooo0`00002W0?ooo`X000009P3oool30000
00@0oooo0`00001`0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0
oooo0`00000@0?ooo`8000000`3oool4000000P0oooo1000002U0?ooo`X00000:03oool00`000000
oooo0?ooo`030?ooo`<00000L03oool00`000000oooo0?ooo`140?ooo`<000005P3oool004L0oooo
00<000000?ooo`3oool0403oool300000080oooo1@0000080?ooo`<00000Y03oool:000002l0oooo
0P00001a0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo00<0
00000?ooo`3oool04@3oool3000000030?ooo`000000000000<000002@3oool300000:@0oooo2@00
000^0?ooo`<00000L@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo0017
0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool0oooo100000090?ooo`@00000X@3o
ool00`000000oooo00000007000002h0oooo0`00001b0?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool0503oool004L0oooo00<000000?ooo`3oool0503oool00`000000oooo00000004
000000T0oooo0`00002P0?ooo`X00000:03oool00`000000oooo0?ooo`030?ooo`@00000LP3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo
01<0oooo0`0000000`3oool0000000000003000000P0oooo1000002P0?ooo`P00000:03oool30000
00@0oooo1000001b0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0
oooo00<000000?ooo`3oool04P3oool300000080oooo1P0000080?ooo`<00000W`3oool8000002X0
oooo00<000000?ooo`3oool00P3oool4000007<0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0D0?ooo`00=P3oool00`3ookl0M000000000020000000304RLg`3oool0oooo00T0oooo
00<000000?ooo`3oool04`3oool300000080oooo1P0000070?ooo`@00000W@3oool800000300oooo
0`00001d0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool003P0oooo00<0
okmd0000001d_ol0303oool00`000000oooo0?ooo`0C0?ooo`@0000000<0oooo0000000000001000
00080?ooo`@00000V`3oool800000300oooo0`00001e0?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool0503oool003P0oooo00<0oooO09a80000M;l0303oool00`000000oooo0?ooo`0D
0?ooo`<000000P3oool6000000P0oooo0`00002J0?ooo`P00000:`3oool00`000000oooo0?ooo`02
0?ooo`<00000MP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo000i0?oo
o`030=nLB000B9`0gooo00/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?oo
o`H00000203oool2000009T0oooo2000000[0?ooo`<000000P3oool3000007L0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00>@3oool00`3ogi`0B01809cOo`0;0?ooo`03
0000003oool0oooo01H0oooo00@000000?ooo`3oool0oooo1`0000070?ooo`@00000UP3oool80000
02d0oooo00@000000?ooo`3oool0oooo0`00001g0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0503oool003T0oooo00<0oono07@0001d_ol02`3oool4000001@0oooo0`0000020?oo
o`P000001`3oool4000009@0oooo2000000a0?ooo`<00000N03oool00`000000oooo0?ooo`130?oo
o`@000005P3oool003X0oooo00<0_g@0001d_`3oool02P3oool00`000000oooo0?ooo`0F0?ooo`80
00000`3oool8000000H0oooo1000002D0?ooo`L00000<@3oool3000007T0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0D0?ooo`00>P3oool00`3OW4P004RL0=ooo`0:0?ooo`030000
003oool0oooo01H0oooo0`0000030?ooo`030000003oool0000000@000001`3oool400000980oooo
1P00000b0?ooo`<00000NP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo
000j0?ooo`030?oOW01804P0W=oo00X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0000
00030?ooo`L000001`3oool4000008l0oooo1`00000]0?ooo`030000003oool0oooo0080oooo0`00
001k0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool003X0oooo00<0oono
07@0001d_ol02P3oool00`000000oooo0?ooo`0H0?ooo`<000000P3oool8000000L0oooo0`00002=
0?ooo`P00000;@3oool300000080oooo1000001k0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0503oool003/0oooo00<0_g@0001d_`3oool02@3oool00`000000oooo0?ooo`0I0?oo
o`<0000000<0oooo0000000000001`0000060?ooo`@00000R`3oool8000002d0oooo0`0000020?oo
o`@00000O03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo000i0?ooo`05
0?oo_`1d000000000000M02oool02@3oool00`000000oooo0?ooo`0J0?ooo`<0000000<0oooo0000
000000001`0000060?ooo`@00000R@3oool8000002d0oooo100000000`3oool00000000000020000
07d0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000
oooo0?ooo`0I0?ooo`@000000P3oool9000000H0oooo100000260?ooo`T00000;@3oool400000003
0?ooo`000000000000<00000O@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0
oooo00170?ooo`030000003oool0oooo01X0oooo0P0000030?ooo`T000001`3oool3000008D0oooo
2000000_0?ooo`8000000P3oool5000007h0oooo00<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0J0?ooo`<000000`3oool9000000L0oooo0`00
00230?ooo`P00000;`3oool3000000030?ooo`000000000000800000P03oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo01/0oooo0`000003
0?ooo`T000001`3oool4000007h0oooo2P00000a0?ooo`030000003oool0000000<00000P@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo
01`0oooo100000020?ooo`T000001`3oool4000007`0oooo2@00000d0?ooo`D00000P@3oool00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo01`0
oooo1@0000000`3oool0000000000008000000L0oooo1000001j0?ooo`P00000<03oool00`000000
oooo0?ooo`020?ooo`D00000PP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0
oooo00170?ooo`<000007@3oool400000080oooo2@0000080?ooo`@00000M`3oool900000300oooo
0`0000020?ooo`@00000Q03oool00`000000oooo0?ooo`140?ooo`<000005P3oool004L0oooo00<0
00000?ooo`3oool07P3oool400000080oooo0`0000000`3oool0000000000003000000P0oooo1000
001e0?ooo`P00000<P3oool3000000030?ooo`000000000000800000Q@3oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo01l0oooo10000002
0?ooo`<0000000<0oooo0000000000000`0000080?ooo`D00000L@3oool9000003@0oooo00<00000
0?ooo`0000000`0000260?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool0
04L0oooo00<000000?ooo`3oool0803oool4000000030?ooo`00000000000080000000<0oooo0000
000000000`0000080?ooo`D00000KP3oool9000003L0oooo100000270?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool0503oool004L0oooo00<000000?ooo`3oool0803oool500000003
0?ooo`00000000000080000000<0oooo0000000000000`0000080?ooo`D00000K03oool8000003P0
oooo0`0000290?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo
00<000000?ooo`3oool08@3oool5000000030?ooo`00000000000080000000<0oooo000000000000
0`0000080?ooo`D00000J@3oool9000003P0oooo0`00002:0?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool0503oool004L0oooo00<000000?ooo`3oool08P3oool5000000030?ooo`00
000000000080000000<0oooo0000000000000`0000090?ooo`D00000I03oool:000003@0oooo00<0
00000?ooo`3oool00P3oool3000008/0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`0D0?ooo`00A`3oool00`000000oooo0?ooo`0S0?ooo`D0000000<0oooo0000000000000P000000
0`3oool0000000000003000000T0oooo1@00001R0?ooo`T00000=@3oool300000080oooo00<00000
0?ooo`000000S03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?oo
o`030000003oool0oooo02@0oooo1@0000000`3oool0000000000002000000030?ooo`0000000000
00<000002@3oool5000005l0oooo2000000g0?ooo`<0000000<0oooo0000000000000P00002=0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo00<000000?ooo`3o
ool09@3oool5000000040?ooo`000000000000000080oooo1@00000:0?ooo`D00000FP3oool90000
03L0oooo100000000`3oool0000000000002000008h0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0U0?ooo`H0000000@0oooo00000000
000000000P3oool5000000X0oooo1P00001F0?ooo`X00000=`3oool4000000040?ooo`000000oooo
00000900oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`00
0000oooo0?ooo`0V0?ooo`H0000000@0oooo00000000000000000P3oool5000000X0oooo1`00001B
0?ooo`X00000>03oool00`000000oooo0000000500000940oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0W0?ooo`X000000P3oool50000
00/0oooo1`00001=0?ooo`X00000>@3oool900000980oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0D0?ooo`00A`3oool3000002P0oooo2P0000020?ooo`D00000303oool7000004T0
oooo2P00000j0?ooo`P00000U03oool00`000000oooo0?ooo`140?ooo`<000005P3oool004L0oooo
00<000000?ooo`3oool0:@3oool:000000<0oooo1@00000<0?ooo`P00000@P3oool;000003h0oooo
1000002G0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo00<0
00000?ooo`3oool0:`3oool9000000<0oooo1@00000<0?ooo`T00000?@3oool=000003/0oooo00@0
00000?ooo`3oool0oooo1000002G0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
503oool004L0oooo00<000000?ooo`3oool0;03oool00`000000oooo00000006000000<0oooo1@00
000=0?ooo`X00000=`3oool<000003h0oooo0`0000000`3oool0000000000002000009P0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0]
0?ooo`P00000103oool6000000l0oooo1`0000000`3oool000000000000^0?ooo`d0000000<0oooo
0000003oool0?@3oool2000000030?ooo`000000000000<00000VP3oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo02h0oooo1P0000070?oo
o`H000003`3oool>000002@0oooo3P0000110?ooo`T00000V`3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo0300oooo100000080?ooo`H0
00004@3oool2000000030?ooo`000000000000/000002`3oool00`000000oooo0?ooo`0;0?oooa00
000000<0oooo0000003oool0@@3oool8000009d0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`0a0?ooo`@00000203oool7000001<0oooo
<@0000170?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0W@3oool00`000000oooo
0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo0380oooo1@00
00080?ooo`H000005@3ooolY000004X0oooo100000000`3oool000000?ooo`2Q0?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo00<000000?ooo`3oool0<`3oool5
000000P0oooo1`00000G0?ooo`030000003oool0oooo01`000000`3oool00`000000oooo0?ooo`18
0?ooo`T00000X@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?oo
o`030000003oool0oooo03D0oooo1@0000080?ooo`L000007`3oool3000000050?ooo`0000000000
0?ooo`0000000P3oool01@000000oooo0?ooo`000000oooo00800000D@3oool7000000030?ooo`00
0000oooo0:40oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool0
0`000000oooo0?ooo`0g0?ooo`D00000203oool7000007h0oooo1`00002U0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo0`00000h0?ooo`H00000203oool70000
07T0oooo0P0000020?ooo`@00000Y`3oool00`000000oooo0?ooo`140?ooo`<000005P3oool004L0
oooo00<000000?ooo`3oool0>`3oool5000000L0oooo2000001f0?ooo`@000000P3oool200000:P0
oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo
0?ooo`0l0?ooo`L000001P3oool8000007@0oooo1@00002[0?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool0503oool004L0oooo00<000000?ooo`3oool0?@3oool8000000H0oooo2000
001]0?ooo`040000003oool0oooo0?ooo`D00000[03oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo01@0oooo00170?ooo`030000003oool0oooo0400oooo200000050?ooo`P00000JP3o
ool800000:h0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool0
0`000000oooo0?ooo`120?ooo`/000000P3oool7000006H0oooo0P0000000`3oool0000000000005
00000:l0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`00
0000oooo0?ooo`150?oooa800000I03oool6000000030?ooo`000000oooo0;40oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`180?oooa00
0000H@3oool00`000000oooo0000000400000;D0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`1<0?ooo``00000H03oool5000000030?oo
o`000000oooo0;D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3o
ool00`000000oooo0?ooo`1B0?ooo`D00000G@3oool01@000000oooo000000000000oooo00<00000
^@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003o
ool0oooo0;80oooo1`0000000`3oool000000?ooo`2i0?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool0503oool004L0oooo00<000000?ooo`3oool0/03oool800000;d0oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`2]0?oo
o`L0000000<0oooo0000003oool0_P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
01@0oooo00170?ooo`<00000Z`3oool800000<80oooo00<000000?ooo`3oool0A03oool3000001H0
oooo00170?ooo`030000003oool0oooo0:X0oooo1@0000000`3oool000000?ooo`330?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo00<000000?ooo`3oool0Z03o
ool01P000000oooo0?ooo`000000oooo00000<L0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`2R0?ooo`80000000<0oooo000000000000
0`00003;0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool004L0oooo00<0
00000?ooo`3oool0WP3oool00`000000oooo0000000800000<`0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0D0?ooo`00A`3oool00`000000oooo0?ooo`2L0?ooo`/00000cP3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo00170?ooo`030000003oool0oooo
09X0oooo200000000`3oool000000?ooo`3@0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool0503oool004L0oooo00<000000?ooo`3oool0T`3oool5000000030?ooo`00000000000080
000000<0oooo000000000000e@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01@0
oooo000f0?ooo`030=nLB0000000000000<0000000<0B9cO0?ooo`3oool0203oool00`000000oooo
0?ooo`2B0?ooo`L0000000<0oooo0000003oool0f@3oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo01@0oooo000g0?ooo`030?noM000M;l0oooo0080oooo00<0_gAd0;ooo`3oool0203o
ool00`000000oooo0?ooo`2B0?ooo`H00000g@3oool00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo01@0oooo000h0?ooo`030?noM000M;l0oooo00`0oooo00<000000?ooo`3oool0T`3oool2
00000>00oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00>@3oool00`3o
_g@007Bo0?ooo`0;0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0k03oool00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo01@0oooo000j0?ooo`030?noM018W=l0oooo00X0
oooo00<000000?ooo`3oool0JP3oool300000080oooo0P0000030?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0203oool300000>d0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0D0?ooo`00>`3oool00`3OW4P0B9cO0?ooo`090?ooo`@00000J03oool900000003
0?ooo`000000000000L000002P3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo04<0
oooo1000000F0?ooo`00?03oool00`2oM000M;oo0?ooo`080?ooo`030000003oool0oooo06X0oooo
0`0000020?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?P0
oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`00?03oool00`3ogi`0B01d
0;ooo`080?ooo`030000003oool0oooo0?l0ooooMP3oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo01@0oooo000l0?ooo`030?oog`2LB000M;oo00P0oooo00<000000?ooo`3oool0o`3o
oomf0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503oool003`0oooo00<0oono
07@00018W=l0203oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04<0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`120?ooo`050000003oool0oooo0?ooo`0000005P3o
ool003P0oooo00L0okmd0018W03Oool0oooo0=nLB00004P0W=oo00P0oooo00<000000?ooo`000000
303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000005P3oool003T0oooo
00D0omnL04P000000000000007Boo`090?ooo`030000003oool0000000`0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool01@000000oooo0?ooo`3oool0000001H0oooo00170?ooool00000``00000F0?ooo`00
o`3ooooo0?ooob40oooo003o0?ooool0oooo8@3oool00?l0ooooo`3ooolQ0?ooo`00o`3ooooo0?oo
ob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 542.438}, {334.875, 0}} -> {-3.22706, -3.08802, \
0.0108242, 0.0236208}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ListPlot[First /@ pts, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<k\>", \*"\"\<\!\(x\_k\)\>\""}];\)\), "\
\[IndentingNewLine]", 
    \(\(ListPlot[Last /@ pts, Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<k\>", \
\*"\"\<\!\(x\_k\%\[Prime]\)\>\""}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.000120876 0.517065 0.190809 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.26556 -0.0125 -14 -15.6875 ]
[.26556 -0.0125 14 0 ]
[.50731 -0.0125 -14 -15.6875 ]
[.50731 -0.0125 14 0 ]
[.74906 -0.0125 -14 -15.6875 ]
[.74906 -0.0125 14 0 ]
[.99082 -0.0125 -14 -15.6875 ]
[.99082 -0.0125 14 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4.9375 -31.375 ]
[.5 -0.0125 4.9375 -15.6875 ]
[-0.0125 .04004 -27.6875 -7.84375 ]
[-0.0125 .04004 0 7.84375 ]
[-0.0125 .13545 -18.6875 -7.84375 ]
[-0.0125 .13545 0 7.84375 ]
[-0.0125 .23085 -27.6875 -7.84375 ]
[-0.0125 .23085 0 7.84375 ]
[-0.0125 .32626 -18.6875 -7.84375 ]
[-0.0125 .32626 0 7.84375 ]
[-0.0125 .42166 -27.6875 -7.84375 ]
[-0.0125 .42166 0 7.84375 ]
[-0.0125 .51706 -10 -7.84375 ]
[-0.0125 .51706 0 7.84375 ]
[-0.0125 .61247 -19 -7.84375 ]
[-0.0125 .61247 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -43.375 -7.125 ]
[-0.01875 .30902 -27.6875 7.125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.26556 0 m
.26556 .00625 L
s
gsave
.26556 -0.0125 -75 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
1.000 setlinewidth
grestore
.50731 0 m
.50731 .00625 L
s
gsave
.50731 -0.0125 -75 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4000) show
1.000 setlinewidth
grestore
.74906 0 m
.74906 .00625 L
s
gsave
.74906 -0.0125 -75 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6000) show
1.000 setlinewidth
grestore
.99082 0 m
.99082 .00625 L
s
gsave
.99082 -0.0125 -75 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8000) show
1.000 setlinewidth
grestore
.125 Mabswid
.08425 0 m
.08425 .00375 L
s
.14469 0 m
.14469 .00375 L
s
.20512 0 m
.20512 .00375 L
s
.326 0 m
.326 .00375 L
s
.38644 0 m
.38644 .00375 L
s
.44688 0 m
.44688 .00375 L
s
.56775 0 m
.56775 .00375 L
s
.62819 0 m
.62819 .00375 L
s
.68863 0 m
.68863 .00375 L
s
.8095 0 m
.8095 .00375 L
s
.86994 0 m
.86994 .00375 L
s
.93038 0 m
.93038 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65.9375 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
68.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .04004 m
.00625 .04004 L
s
gsave
-0.0125 .04004 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
0 .13545 m
.00625 .13545 L
s
gsave
-0.0125 .13545 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .23085 m
.00625 .23085 L
s
gsave
-0.0125 .23085 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .32626 m
.00625 .32626 L
s
gsave
-0.0125 .32626 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .42166 m
.00625 .42166 L
s
gsave
-0.0125 .42166 -88.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .51706 m
.00625 .51706 L
s
gsave
-0.0125 .51706 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .61247 m
.00625 .61247 L
s
gsave
-0.0125 .61247 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05912 m
.00375 .05912 L
s
0 .0782 m
.00375 .0782 L
s
0 .09729 m
.00375 .09729 L
s
0 .11637 m
.00375 .11637 L
s
0 .15453 m
.00375 .15453 L
s
0 .17361 m
.00375 .17361 L
s
0 .19269 m
.00375 .19269 L
s
0 .21177 m
.00375 .21177 L
s
0 .24993 m
.00375 .24993 L
s
0 .26901 m
.00375 .26901 L
s
0 .28809 m
.00375 .28809 L
s
0 .30717 m
.00375 .30717 L
s
0 .34534 m
.00375 .34534 L
s
0 .36442 m
.00375 .36442 L
s
0 .3835 m
.00375 .3835 L
s
0 .40258 m
.00375 .40258 L
s
0 .44074 m
.00375 .44074 L
s
0 .45982 m
.00375 .45982 L
s
0 .4789 m
.00375 .4789 L
s
0 .49798 m
.00375 .49798 L
s
0 .53615 m
.00375 .53615 L
s
0 .55523 m
.00375 .55523 L
s
0 .57431 m
.00375 .57431 L
s
0 .59339 m
.00375 .59339 L
s
0 .02096 m
.00375 .02096 L
s
0 .00188 m
.00375 .00188 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -103.656 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.125 11.8438 translate
90 rotate
-68.125 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 17.688 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
73.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.26556 .61178 m
.26556 .61803 L
s
.50731 .61178 m
.50731 .61803 L
s
.74906 .61178 m
.74906 .61803 L
s
.99082 .61178 m
.99082 .61803 L
s
.125 Mabswid
.08425 .61428 m
.08425 .61803 L
s
.14469 .61428 m
.14469 .61803 L
s
.20512 .61428 m
.20512 .61803 L
s
.326 .61428 m
.326 .61803 L
s
.38644 .61428 m
.38644 .61803 L
s
.44688 .61428 m
.44688 .61803 L
s
.56775 .61428 m
.56775 .61803 L
s
.62819 .61428 m
.62819 .61803 L
s
.68863 .61428 m
.68863 .61803 L
s
.8095 .61428 m
.8095 .61803 L
s
.86994 .61428 m
.86994 .61803 L
s
.93038 .61428 m
.93038 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04004 m
1 .04004 L
s
.99375 .13545 m
1 .13545 L
s
.99375 .23085 m
1 .23085 L
s
.99375 .32626 m
1 .32626 L
s
.99375 .42166 m
1 .42166 L
s
.99375 .51706 m
1 .51706 L
s
.99375 .61247 m
1 .61247 L
s
.125 Mabswid
.99625 .05912 m
1 .05912 L
s
.99625 .0782 m
1 .0782 L
s
.99625 .09729 m
1 .09729 L
s
.99625 .11637 m
1 .11637 L
s
.99625 .15453 m
1 .15453 L
s
.99625 .17361 m
1 .17361 L
s
.99625 .19269 m
1 .19269 L
s
.99625 .21177 m
1 .21177 L
s
.99625 .24993 m
1 .24993 L
s
.99625 .26901 m
1 .26901 L
s
.99625 .28809 m
1 .28809 L
s
.99625 .30717 m
1 .30717 L
s
.99625 .34534 m
1 .34534 L
s
.99625 .36442 m
1 .36442 L
s
.99625 .3835 m
1 .3835 L
s
.99625 .40258 m
1 .40258 L
s
.99625 .44074 m
1 .44074 L
s
.99625 .45982 m
1 .45982 L
s
.99625 .4789 m
1 .4789 L
s
.99625 .49798 m
1 .49798 L
s
.99625 .53615 m
1 .53615 L
s
.99625 .55523 m
1 .55523 L
s
.99625 .57431 m
1 .57431 L
s
.99625 .59339 m
1 .59339 L
s
.99625 .02096 m
1 .02096 L
s
.99625 .00188 m
1 .00188 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .51706 m
1 .51706 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02393 .29919 Mdot
.02405 .14031 Mdot
.02417 .36438 Mdot
.02429 .29524 Mdot
.02441 .24925 Mdot
.02453 .30296 Mdot
.02466 .05818 Mdot
.02478 .29582 Mdot
.0249 .30316 Mdot
.02502 .25018 Mdot
.02514 .30258 Mdot
.02526 .06324 Mdot
.02538 .32009 Mdot
.0255 .28836 Mdot
.02562 .30256 Mdot
.02574 .23878 Mdot
.02586 .30764 Mdot
.02599 .03618 Mdot
.02611 .03126 Mdot
.02623 .06071 Mdot
.02635 .28027 Mdot
.02647 .11751 Mdot
.02659 .32779 Mdot
.02671 .25211 Mdot
.02683 .30183 Mdot
.02695 .0756 Mdot
.02707 .35587 Mdot
.02719 .3047 Mdot
.02731 .30553 Mdot
.02744 .30705 Mdot
.02756 .30409 Mdot
.02768 .30771 Mdot
.0278 .29942 Mdot
.02792 .30691 Mdot
.02804 .28043 Mdot
.02816 .30005 Mdot
.02828 .20772 Mdot
.0284 .32987 Mdot
.02852 .21629 Mdot
.02864 .07216 Mdot
.02877 .1339 Mdot
.02889 .0928 Mdot
.02901 .30162 Mdot
.02913 .30542 Mdot
.02925 .27013 Mdot
.02937 .29895 Mdot
.02949 .16483 Mdot
.02961 .36547 Mdot
.02973 .23367 Mdot
.02985 .30993 Mdot
.02997 .04412 Mdot
.0301 .02111 Mdot
.03022 .04586 Mdot
.03034 .03025 Mdot
.03046 .06014 Mdot
.03058 .25824 Mdot
.0307 .11654 Mdot
.03082 .33313 Mdot
.03094 .23663 Mdot
.03106 .30851 Mdot
.03118 .03797 Mdot
.0313 .02097 Mdot
.03142 .05475 Mdot
.03155 .13302 Mdot
.03167 .0926 Mdot
.03179 .30088 Mdot
.03191 .30513 Mdot
.03203 .2675 Mdot
.03215 .29901 Mdot
.03227 .1525 Mdot
.03239 .36937 Mdot
.03251 .30311 Mdot
.03263 .30738 Mdot
.03275 .30317 Mdot
.03288 .3078 Mdot
.033 .29591 Mdot
.03312 .30546 Mdot
.03324 .26608 Mdot
.03336 .2991 Mdot
.03348 .14565 Mdot
.0336 .36802 Mdot
.03372 .30269 Mdot
.03384 .28121 Mdot
.03396 .30017 Mdot
.03408 .21015 Mdot
.0342 .32779 Mdot
.03433 .21115 Mdot
.03445 .07167 Mdot
.03457 .13216 Mdot
.03469 .09232 Mdot
.03481 .2991 Mdot
.03493 .30441 Mdot
.03505 .26119 Mdot
.03517 .29969 Mdot
.03529 .12054 Mdot
.03541 .31827 Mdot
.03553 .33121 Mdot
.03566 .36868 Mdot
.03578 .05439 Mdot
.0359 .0223 Mdot
.03602 .04328 Mdot
.03614 .02227 Mdot
.03626 .05549 Mdot
.03638 .14298 Mdot
.0365 .09527 Mdot
.03662 .31103 Mdot
.03674 .3072 Mdot
.03686 .30114 Mdot
.03698 .30747 Mdot
.03711 .28755 Mdot
.03723 .30206 Mdot
.03735 .23423 Mdot
.03747 .31019 Mdot
.03759 .04705 Mdot
.03771 .02321 Mdot
.03783 .04249 Mdot
.03795 .02143 Mdot
.03807 .05464 Mdot
.03819 .12551 Mdot
.03831 .09052 Mdot
.03844 .28651 Mdot
.03856 .30009 Mdot
.03868 .21782 Mdot
.0388 .32155 Mdot
.03892 .16859 Mdot
.03904 .06589 Mdot
.03916 .09344 Mdot
.03928 .08116 Mdot
.0394 .03571 Mdot
.03952 .03152 Mdot
.03964 .06081 Mdot
.03977 .28301 Mdot
.03989 .11754 Mdot
.04001 .32693 Mdot
.04013 .25583 Mdot
.04025 .30079 Mdot
.04037 .09495 Mdot
.04049 .20902 Mdot
.04061 .08478 Mdot
.04073 .04525 Mdot
.04085 .01993 Mdot
.04097 .05119 Mdot
.04109 .07006 Mdot
.04122 .07399 Mdot
.04134 .58714 Mdot
.04146 .03744 Mdot
.04158 .15767 Mdot
.0417 .09919 Mdot
.04182 .31863 Mdot
.04194 .29542 Mdot
.04206 .30546 Mdot
.04218 .26573 Mdot
.0423 .29913 Mdot
.04242 .14394 Mdot
.04255 .36714 Mdot
.04267 .3006 Mdot
.04279 .2711 Mdot
.04291 .29894 Mdot
.04303 .16857 Mdot
.04315 .36321 Mdot
.04327 .18709 Mdot
.04339 .34734 Mdot
.04351 .0741 Mdot
.04363 .03947 Mdot
.04375 .02233 Mdot
.04387 .04333 Mdot
.044 .02241 Mdot
.04412 .05561 Mdot
.04424 .14564 Mdot
.04436 .09598 Mdot
.04448 .31278 Mdot
.0446 .30643 Mdot
.04472 .30495 Mdot
.04484 .3074 Mdot
.04496 .30244 Mdot
.04508 .30774 Mdot
.0452 .29296 Mdot
.04533 .30417 Mdot
.04545 .25452 Mdot
.04557 .30119 Mdot
.04569 .08498 Mdot
.04581 .29933 Mdot
.04593 .35146 Mdot
.04605 .08994 Mdot
.04617 .04603 Mdot
.04629 .02004 Mdot
.04641 .05189 Mdot
.04653 .07906 Mdot
.04666 .0768 Mdot
.04678 .50326 Mdot
.0469 .10227 Mdot
.04702 .08555 Mdot
.04714 .27238 Mdot
.04726 .29844 Mdot
.04738 .16233 Mdot
.0475 .36675 Mdot
.04762 .25802 Mdot
.04774 .30026 Mdot
.04786 .11062 Mdot
.04798 .26782 Mdot
.04811 .29271 Mdot
.04823 .37088 Mdot
.04835 .29836 Mdot
.04847 .30733 Mdot
.04859 .28352 Mdot
.04871 .3008 Mdot
.04883 .21937 Mdot
.04895 .32034 Mdot
.04907 .15628 Mdot
.04919 .06367 Mdot
.04931 .07779 Mdot
.04944 .07639 Mdot
.04956 .53501 Mdot
.04968 .34551 Mdot
.0498 .11662 Mdot
.04992 .29277 Mdot
.05004 .30196 Mdot
.05016 .23918 Mdot
.05028 .30744 Mdot
.0504 .03594 Mdot
.05052 .03657 Mdot
.05064 .06281 Mdot
.05076 .33821 Mdot
.05089 .1122 Mdot
.05101 .20943 Mdot
.05113 .33003 Mdot
.05125 .22102 Mdot
.05137 .07257 Mdot
.05149 .13495 Mdot
.05161 .09308 Mdot
.05173 .30299 Mdot
.05185 .30594 Mdot
.05197 .27501 Mdot
.05209 .29921 Mdot
.05222 .18609 Mdot
.05234 .34924 Mdot
.05246 .05405 Mdot
.05258 .02795 Mdot
.0527 .03582 Mdot
.05282 .02227 Mdot
.05294 .04346 Mdot
.05306 .02268 Mdot
.05318 .05584 Mdot
.0533 .15068 Mdot
.05342 .09728 Mdot
.05354 .31543 Mdot
.05367 .30352 Mdot
.05379 .30777 Mdot
.05391 .29866 Mdot
.05403 .30662 Mdot
.05415 .2773 Mdot
.05427 .29949 Mdot
.05439 .19547 Mdot
.05451 .34077 Mdot
.05463 .16048 Mdot
.05475 .06435 Mdot
.05487 .08201 Mdot
.055 .07769 Mdot
.05512 .41527 Mdot
.05524 .03126 Mdot
.05536 .04177 Mdot
.05548 .02212 Mdot
.0556 .05536 Mdot
.05572 .14054 Mdot
.05584 .09463 Mdot
.05596 .30914 Mdot
.05608 .30742 Mdot
.0562 .29589 Mdot
.05633 .30544 Mdot
.05645 .26595 Mdot
.05657 .29911 Mdot
.05669 .14502 Mdot
.05681 .36773 Mdot
.05693 .30198 Mdot
.05705 .27755 Mdot
.05717 .29948 Mdot
.05729 .19589 Mdot
.05741 .34039 Mdot
.05753 .16477 Mdot
.05765 .06512 Mdot
.05778 .08747 Mdot
.0579 .07936 Mdot
.05802 .16907 Mdot
.05814 .06661 Mdot
.05826 .10187 Mdot
.05838 .08368 Mdot
.0585 .11993 Mdot
.05862 .30921 Mdot
.05874 .34828 Mdot
.05886 .16352 Mdot
.05898 .06486 Mdot
.05911 .08543 Mdot
.05923 .07874 Mdot
.05935 .26268 Mdot
.05947 .07488 Mdot
.05959 .12247 Mdot
.05971 .08962 Mdot
.05983 .27673 Mdot
.05995 .29855 Mdot
.06007 .18098 Mdot
.06019 .35371 Mdot
.06031 .03748 Mdot
.06043 .1616 Mdot
.06056 .10016 Mdot
.06068 .31988 Mdot
.0608 .29052 Mdot
.06092 .3034 Mdot
.06104 .24684 Mdot
.06116 .30385 Mdot
.06128 .04945 Mdot
.0614 .46352 Mdot
.06152 .01656 Mdot
.06164 .05358 Mdot
.06176 .18783 Mdot
.06189 .10604 Mdot
.06201 .32673 Mdot
.06213 .25624 Mdot
.06225 .30069 Mdot
.06237 .09713 Mdot
.06249 .2066 Mdot
.06261 .5543 Mdot
.06273 .54433 Mdot
.06285 .15105 Mdot
.06297 .10073 Mdot
.06309 .32713 Mdot
.06322 .25419 Mdot
.06334 .30122 Mdot
.06346 .08628 Mdot
.06358 .28322 Mdot
.0637 .37086 Mdot
.06382 .2997 Mdot
.06394 .30772 Mdot
.06406 .28931 Mdot
.06418 .3027 Mdot
.0643 .24078 Mdot
.06442 .30661 Mdot
.06454 .03597 Mdot
.06467 .07887 Mdot
.06479 .07681 Mdot
.06491 .4875 Mdot
.06503 .04628 Mdot
.06515 .06612 Mdot
.06527 .51414 Mdot
.06539 .03099 Mdot
.06551 .06019 Mdot
.06563 .37188 Mdot
.06575 .10189 Mdot
.06587 .48559 Mdot
.066 .01742 Mdot
.06612 .04892 Mdot
.06624 .08584 Mdot
.06636 .07889 Mdot
.06648 .23068 Mdot
.0666 .07392 Mdot
.06672 .14481 Mdot
.06684 .09571 Mdot
.06696 .31201 Mdot
.06708 .30685 Mdot
.0672 .30344 Mdot
.06732 .30779 Mdot
.06745 .29687 Mdot
.06757 .30588 Mdot
.06769 .26998 Mdot
.06781 .29896 Mdot
.06793 .16418 Mdot
.06805 .36582 Mdot
.06817 .24052 Mdot
.06829 .30629 Mdot
.06841 .03691 Mdot
.06853 .13232 Mdot
.06865 .09252 Mdot
.06878 .3013 Mdot
.0689 .30529 Mdot
.06902 .26898 Mdot
.06914 .29896 Mdot
.06926 .15951 Mdot
.06938 .36793 Mdot
.0695 .27847 Mdot
.06962 .3002 Mdot
.06974 .20548 Mdot
.06986 .33181 Mdot
.06998 .21665 Mdot
.0701 .07218 Mdot
.07023 .13385 Mdot
.07035 .09278 Mdot
.07047 .30156 Mdot
.07059 .30539 Mdot
.07071 .26991 Mdot
.07083 .29895 Mdot
.07095 .1638 Mdot
.07107 .36602 Mdot
.07119 .24432 Mdot
.07131 .30456 Mdot
.07143 .04535 Mdot
.07156 .53182 Mdot
.07168 .09635 Mdot
.0718 .08366 Mdot
.07192 .24494 Mdot
.07204 .30541 Mdot
.07216 .03783 Mdot
.07228 .17921 Mdot
.0724 .10429 Mdot
.07252 .32484 Mdot
.07264 .26547 Mdot
.07276 .2992 Mdot
.07289 .14515 Mdot
.07301 .36779 Mdot
.07313 .30213 Mdot
.07325 .27831 Mdot
.07337 .2996 Mdot
.07349 .19892 Mdot
.07361 .33765 Mdot
.07373 .19076 Mdot
.07385 .0692 Mdot
.07397 .11703 Mdot
.07409 .08809 Mdot
.07421 .25511 Mdot
.07434 .30138 Mdot
.07446 .07502 Mdot
.07458 .3551 Mdot
.0747 .30194 Mdot
.07482 .30789 Mdot
.07494 .2973 Mdot
.07506 .30606 Mdot
.07518 .27172 Mdot
.0753 .29899 Mdot
.07542 .17204 Mdot
.07554 .36082 Mdot
.07567 .1359 Mdot
.07579 .36047 Mdot
.07591 .29054 Mdot
.07603 .22638 Mdot
.07615 .31537 Mdot
.07627 .09916 Mdot
.07639 .04949 Mdot
.07651 .02244 Mdot
.07663 .05558 Mdot
.07675 .14436 Mdot
.07687 .09564 Mdot
.07699 .31197 Mdot
.07712 .30687 Mdot
.07724 .30336 Mdot
.07736 .30779 Mdot
.07748 .29655 Mdot
.0776 .30574 Mdot
.07772 .26866 Mdot
.07784 .29897 Mdot
.07796 .15808 Mdot
.07808 .36841 Mdot
.0782 .28633 Mdot
.07832 .30239 Mdot
.07845 .23522 Mdot
.07857 .30961 Mdot
.07869 .04341 Mdot
.07881 .02065 Mdot
.07893 .04672 Mdot
.07905 .03426 Mdot
.07917 .06183 Mdot
.07929 .30445 Mdot
.07941 .11687 Mdot
.07953 .31918 Mdot
.07965 .2937 Mdot
.07978 .30472 Mdot
.0799 .25896 Mdot
.08002 .30011 Mdot
.08014 .10875 Mdot
.08026 .25668 Mdot
.08038 .17192 Mdot
.0805 .03721 Mdot
.08062 .06284 Mdot
.08074 .32466 Mdot
.08086 .11467 Mdot
.08098 .29788 Mdot
.0811 .3039 Mdot
.08123 .25678 Mdot
.08135 .3006 Mdot
.08147 .09695 Mdot
.08159 .20657 Mdot
.08171 .55264 Mdot
.08183 .52808 Mdot
.08195 .05718 Mdot
.08207 .06999 Mdot
.08219 .5862 Mdot
.08231 .07568 Mdot
.08243 .03912 Mdot
.08256 .0227 Mdot
.08268 .04261 Mdot
.0828 .02135 Mdot
.08292 .05454 Mdot
.08304 .12371 Mdot
.08316 .09001 Mdot
.08328 .28165 Mdot
.0834 .2991 Mdot
.08352 .20025 Mdot
.08364 .33646 Mdot
.08376 .19937 Mdot
.08388 .07032 Mdot
.08401 .12441 Mdot
.08413 .09017 Mdot
.08425 .2828 Mdot
.08437 .29929 Mdot
.08449 .2045 Mdot
.08461 .33268 Mdot
.08473 .21542 Mdot
.08485 .07206 Mdot
.08497 .13341 Mdot
.08509 .09266 Mdot
.08521 .30095 Mdot
.08534 .30515 Mdot
.08546 .26775 Mdot
.08558 .299 Mdot
.0857 .15367 Mdot
.08582 .3693 Mdot
.08594 .30119 Mdot
.08606 .30792 Mdot
.08618 .29552 Mdot
.0863 .30529 Mdot
.08642 .26455 Mdot
.08654 .29924 Mdot
.08666 .13798 Mdot
.08679 .36191 Mdot
.08691 .29192 Mdot
.08703 .2345 Mdot
.08715 .31014 Mdot
.08727 .04699 Mdot
.08739 .02316 Mdot
.08751 .04256 Mdot
.08763 .02152 Mdot
.08775 .05474 Mdot
.08787 .12759 Mdot
.08799 .0911 Mdot
.08812 .29133 Mdot
.08824 .30149 Mdot
.08836 .23442 Mdot
.08848 .31009 Mdot
.0886 .04639 Mdot
.08872 .02272 Mdot
.08884 .04323 Mdot
.08896 .02258 Mdot
.08908 .05576 Mdot
.0892 .14896 Mdot
.08932 .09684 Mdot
.08945 .3146 Mdot
.08957 .30471 Mdot
.08969 .30734 Mdot
.08981 .30292 Mdot
.08993 .30779 Mdot
.09005 .29487 Mdot
.09017 .305 Mdot
.09029 .26197 Mdot
.09041 .29957 Mdot
.09053 .1247 Mdot
.09065 .33354 Mdot
.09077 .30493 Mdot
.0909 .1017 Mdot
.09102 .05038 Mdot
.09114 .02362 Mdot
.09126 .05652 Mdot
.09138 .16523 Mdot
.0915 .10091 Mdot
.09162 .32058 Mdot
.09174 .28739 Mdot
.09186 .30222 Mdot
.09198 .23522 Mdot
.0921 .30961 Mdot
.09223 .04342 Mdot
.09235 .02066 Mdot
.09247 .04671 Mdot
.09259 .03422 Mdot
.09271 .06181 Mdot
.09283 .30398 Mdot
.09295 .1169 Mdot
.09307 .31938 Mdot
.09319 .2929 Mdot
.09331 .30438 Mdot
.09343 .25586 Mdot
.09355 .30083 Mdot
.09368 .0921 Mdot
.0938 .22246 Mdot
.09392 .32416 Mdot
.09404 .27188 Mdot
.09416 .29911 Mdot
.09428 .1749 Mdot
.0944 .35866 Mdot
.09452 .0935 Mdot
.09464 .21193 Mdot
.09476 .15442 Mdot
.09488 .3694 Mdot
.09501 .30289 Mdot
.09513 .30753 Mdot
.09525 .30235 Mdot
.09537 .30773 Mdot
.09549 .29262 Mdot
.09561 .30403 Mdot
.09573 .25323 Mdot
.09585 .30157 Mdot
.09597 .07826 Mdot
.09609 .35376 Mdot
.09621 .29712 Mdot
.09634 .25219 Mdot
.09646 .30193 Mdot
.09658 .07214 Mdot
.0967 .34732 Mdot
.09682 .26274 Mdot
.09694 .29951 Mdot
.09706 .13376 Mdot
.09718 .35575 Mdot
.0973 .28814 Mdot
.09742 .19539 Mdot
.09754 .34103 Mdot
.09766 .15791 Mdot
.09779 .06387 Mdot
.09791 .07871 Mdot
.09803 .07667 Mdot
.09815 .5161 Mdot
.09827 .17938 Mdot
.09839 .10799 Mdot
.09851 .33973 Mdot
.09863 .23773 Mdot
.09875 .30786 Mdot
.09887 .03633 Mdot
.09899 .02932 Mdot
.09912 .05986 Mdot
.09924 .25745 Mdot
.09936 .11648 Mdot
.09948 .33326 Mdot
.0996 .23643 Mdot
.09972 .30862 Mdot
.09984 .03832 Mdot
.09996 .02039 Mdot
.10008 .05404 Mdot
.1002 .11901 Mdot
.10032 .08868 Mdot
.10044 .26535 Mdot
.10057 .299 Mdot
.10069 .12846 Mdot
.10081 .34443 Mdot
.10093 .29223 Mdot
.10105 .07523 Mdot
.10117 .3553 Mdot
.10129 .30273 Mdot
.10141 .30773 Mdot
.10153 .30047 Mdot
.10165 .30728 Mdot
.10177 .28485 Mdot
.1019 .30118 Mdot
.10202 .22427 Mdot
.10214 .31671 Mdot
.10226 .11472 Mdot
.10238 .05415 Mdot
.1025 .03159 Mdot
.10262 .0607 Mdot
.10274 .27249 Mdot
.10286 .11732 Mdot
.10298 .33003 Mdot
.1031 .24391 Mdot
.10322 .30492 Mdot
.10335 .04224 Mdot
.10347 .39635 Mdot
.10359 .08996 Mdot
.10371 .15678 Mdot
.10383 .09875 Mdot
.10395 .31763 Mdot
.10407 .29863 Mdot
.10419 .30679 Mdot
.10431 .27875 Mdot
.10443 .29973 Mdot
.10455 .20124 Mdot
.10468 .33557 Mdot
.1048 .20469 Mdot
.10492 .07094 Mdot
.10504 .12812 Mdot
.10516 .09121 Mdot
.10528 .29179 Mdot
.1054 .30164 Mdot
.10552 .236 Mdot
.10564 .30917 Mdot
.10576 .04111 Mdot
.10588 .01953 Mdot
.10601 .04967 Mdot
.10613 .05612 Mdot
.10625 .06952 Mdot
.10637 .51056 Mdot
.10649 .02473 Mdot
.10661 .05762 Mdot
.10673 .30437 Mdot
.10685 .11689 Mdot
.10697 .31925 Mdot
.10709 .29341 Mdot
.10721 .3046 Mdot
.10733 .25786 Mdot
.10746 .30034 Mdot
.10758 .10281 Mdot
.1077 .22314 Mdot
.10782 .31682 Mdot
.10794 .30145 Mdot
.10806 .30767 Mdot
.10818 .29048 Mdot
.1083 .30315 Mdot
.10842 .24512 Mdot
.10854 .30458 Mdot
.10866 .04377 Mdot
.10879 .46652 Mdot
.10891 .03208 Mdot
.10903 .04253 Mdot
.10915 .0244 Mdot
.10927 .0571 Mdot
.10939 .18001 Mdot
.10951 .10433 Mdot
.10963 .32464 Mdot
.10975 .2665 Mdot
.10987 .29913 Mdot
.10999 .15017 Mdot
.11011 .36927 Mdot
.11024 .3049 Mdot
.11036 .30259 Mdot
.11048 .30774 Mdot
.1106 .29308 Mdot
.11072 .30423 Mdot
.11084 .25498 Mdot
.11096 .30106 Mdot
.11108 .08741 Mdot
.1112 .26917 Mdot
.11132 .34635 Mdot
.11144 .29169 Mdot
.11157 .08165 Mdot
.11169 .33541 Mdot
.11181 .29268 Mdot
.11193 .07897 Mdot
.11205 .35172 Mdot
.11217 .29367 Mdot
.11229 .23649 Mdot
.11241 .30898 Mdot
.11253 .04034 Mdot
.11265 .01938 Mdot
.11277 .05075 Mdot
.1129 .06792 Mdot
.11302 .07331 Mdot
.11314 .58283 Mdot
.11326 .4879 Mdot
.11338 .05106 Mdot
.1135 .06786 Mdot
.11362 .55175 Mdot
.11374 .26701 Mdot
.11386 .12256 Mdot
.11398 .35247 Mdot
.1141 .29102 Mdot
.11422 .30406 Mdot
.11435 .25192 Mdot
.11447 .30199 Mdot
.11459 .07167 Mdot
.11471 .34566 Mdot
.11483 .25493 Mdot
.11495 .30098 Mdot
.11507 .09223 Mdot
.11519 .22158 Mdot
.11531 .32185 Mdot
.11543 .28339 Mdot
.11555 .30097 Mdot
.11568 .22054 Mdot
.1158 .31945 Mdot
.11592 .14664 Mdot
.11604 .06176 Mdot
.11616 .06549 Mdot
.11628 .07253 Mdot
.1164 .57219 Mdot
.11652 .53755 Mdot
.11664 .10259 Mdot
.11676 .08575 Mdot
.11688 .2783 Mdot
.117 .29867 Mdot
.11713 .18734 Mdot
.11725 .34813 Mdot
.11737 .06576 Mdot
.11749 .03522 Mdot
.11761 .02656 Mdot
.11773 .0359 Mdot
.11785 .02234 Mdot
.11797 .04333 Mdot
.11809 .02243 Mdot
.11821 .05563 Mdot
.11833 .14615 Mdot
.11846 .09611 Mdot
.11858 .31308 Mdot
.1187 .30622 Mdot
.11882 .30547 Mdot
.11894 .30704 Mdot
.11906 .30412 Mdot
.11918 .3077 Mdot
.1193 .29954 Mdot
.11942 .30696 Mdot
.11954 .28096 Mdot
.11966 .30017 Mdot
.11978 .20972 Mdot
.11991 .32816 Mdot
.12003 .2124 Mdot
.12015 .0718 Mdot
.12027 .13266 Mdot
.12039 .09246 Mdot
.12051 .29986 Mdot
.12063 .30472 Mdot
.12075 .26389 Mdot
.12087 .29931 Mdot
.12099 .13458 Mdot
.12111 .35713 Mdot
.12124 .28853 Mdot
.12136 .20535 Mdot
.12148 .33211 Mdot
.1216 .21681 Mdot
.12172 .07219 Mdot
.12184 .13388 Mdot
.12196 .09279 Mdot
.12208 .30159 Mdot
.1222 .30541 Mdot
.12232 .27002 Mdot
.12244 .29895 Mdot
.12257 .16434 Mdot
.12269 .36573 Mdot
.12281 .23885 Mdot
.12293 .30711 Mdot
.12305 .03576 Mdot
.12317 .05866 Mdot
.12329 .07041 Mdot
.12341 .53563 Mdot
.12353 .12071 Mdot
.12365 .0916 Mdot
.12377 .31247 Mdot
.12389 .30661 Mdot
.12402 .30441 Mdot
.12414 .30763 Mdot
.12426 .30053 Mdot
.12438 .30729 Mdot
.1245 .28504 Mdot
.12462 .30124 Mdot
.12474 .225 Mdot
.12486 .3162 Mdot
.12498 .10852 Mdot
.1251 .05239 Mdot
.12522 .0272 Mdot
.12535 .05866 Mdot
.12547 .21798 Mdot
.12559 .11169 Mdot
.12571 .33318 Mdot
.12583 .23634 Mdot
.12595 .30867 Mdot
.12607 .03851 Mdot
.12619 .02015 Mdot
.12631 .05368 Mdot
.12643 .11229 Mdot
.12655 .08676 Mdot
.12667 .22883 Mdot
.1268 .31482 Mdot
.12692 .09671 Mdot
.12704 .04869 Mdot
.12716 .02159 Mdot
.12728 .05474 Mdot
.1274 .12703 Mdot
.12752 .09094 Mdot
.12764 .29011 Mdot
.12776 .3011 Mdot
.12788 .23025 Mdot
.128 .31266 Mdot
.12813 .06837 Mdot
.12825 .03693 Mdot
.12837 .02466 Mdot
.12849 .03911 Mdot
.12861 .02 Mdot
.12873 .04917 Mdot
.12885 .04941 Mdot
.12897 .06729 Mdot
.12909 .45403 Mdot
.12921 .04379 Mdot
.12933 .03507 Mdot
.12946 .0222 Mdot
.12958 .04361 Mdot
.1297 .02297 Mdot
.12982 .05607 Mdot
.12994 .15585 Mdot
.13006 .0986 Mdot
.13018 .31755 Mdot
.1303 .29886 Mdot
.13042 .30688 Mdot
.13054 .27973 Mdot
.13066 .29991 Mdot
.13078 .20501 Mdot
.13091 .33222 Mdot
.13103 .21617 Mdot
.13115 .07214 Mdot
.13127 .13368 Mdot
.13139 .09274 Mdot
.13151 .30132 Mdot
.13163 .3053 Mdot
.13175 .26907 Mdot
.13187 .29896 Mdot
.13199 .15991 Mdot
.13211 .36778 Mdot
.13224 .27597 Mdot
.13236 .29976 Mdot
.13248 .19561 Mdot
.1326 .34064 Mdot
.13272 .16191 Mdot
.13284 .06461 Mdot
.13296 .08383 Mdot
.13308 .07825 Mdot
.1332 .33813 Mdot
.13332 .06541 Mdot
.13344 .02475 Mdot
.13356 .05721 Mdot
.13369 .18026 Mdot
.13381 .10439 Mdot
.13393 .3247 Mdot
.13405 .26616 Mdot
.13417 .29915 Mdot
.13429 .1485 Mdot
.13441 .36898 Mdot
.13453 .30481 Mdot
.13465 .29619 Mdot
.13477 .30551 Mdot
.13489 .26674 Mdot
.13502 .29906 Mdot
.13514 .14889 Mdot
.13526 .36906 Mdot
.13538 .30492 Mdot
.1355 .29785 Mdot
.13562 .30623 Mdot
.13574 .27347 Mdot
.13586 .29908 Mdot
.13598 .17966 Mdot
.1361 .35481 Mdot
.13622 .04328 Mdot
.13634 .45183 Mdot
.13647 .04603 Mdot
.13659 .03338 Mdot
.13671 .02434 Mdot
.13683 .03977 Mdot
.13695 .01986 Mdot
.13707 .05026 Mdot
.13719 .05974 Mdot
.13731 .0707 Mdot
.13743 .53782 Mdot
.13755 .1362 Mdot
.13767 .09637 Mdot
.1378 .32082 Mdot
.13792 .28613 Mdot
.13804 .30179 Mdot
.13816 .23057 Mdot
.13828 .31244 Mdot
.1384 .06618 Mdot
.13852 .03577 Mdot
.13864 .02591 Mdot
.13876 .03698 Mdot
.13888 .0213 Mdot
.139 .04543 Mdot
.13913 .02784 Mdot
.13925 .05901 Mdot
.13937 .228 Mdot
.13949 .11321 Mdot
.13961 .33432 Mdot
.13973 .23504 Mdot
.13985 .30939 Mdot
.13997 .0416 Mdot
.14009 .0197 Mdot
.14021 .04902 Mdot
.14033 .05008 Mdot
.14045 .06752 Mdot
.14058 .46002 Mdot
.1407 .03806 Mdot
.14082 .03905 Mdot
.14094 .01986 Mdot
.14106 .05118 Mdot
.14118 .07022 Mdot
.1413 .07404 Mdot
.14142 .58725 Mdot
.14154 .04106 Mdot
.14166 .35742 Mdot
.14178 .10727 Mdot
.14191 .52259 Mdot
.14203 .22986 Mdot
.14215 .11818 Mdot
.14227 .35337 Mdot
.14239 .2953 Mdot
.14251 .30592 Mdot
.14263 .26905 Mdot
.14275 .29897 Mdot
.14287 .15992 Mdot
.14299 .36778 Mdot
.14311 .27594 Mdot
.14323 .29975 Mdot
.14336 .19546 Mdot
.14348 .34078 Mdot
.1436 .16042 Mdot
.14372 .06434 Mdot
.14384 .08194 Mdot
.14396 .07767 Mdot
.14408 .41828 Mdot
.1442 .02956 Mdot
.14432 .04284 Mdot
.14444 .02459 Mdot
.14456 .05722 Mdot
.14469 .18298 Mdot
.14481 .10499 Mdot
.14493 .32542 Mdot
.14505 .26251 Mdot
.14517 .29951 Mdot
.14529 .13025 Mdot
.14541 .34876 Mdot
.14553 .28933 Mdot
.14565 .12792 Mdot
.14577 .34266 Mdot
.14589 .29381 Mdot
.14602 .0559 Mdot
.14614 .25112 Mdot
.14626 .30275 Mdot
.14638 .05682 Mdot
.1465 .27532 Mdot
.14662 .29849 Mdot
.14674 .17545 Mdot
.14686 .35824 Mdot
.14698 .08609 Mdot
.1471 .27794 Mdot
.14722 .36888 Mdot
.14734 .30116 Mdot
.14747 .27406 Mdot
.14759 .29908 Mdot
.14771 .18152 Mdot
.14783 .35323 Mdot
.14795 .0363 Mdot
.14807 .09552 Mdot
.14819 .0819 Mdot
.14831 .0518 Mdot
.14843 .07674 Mdot
.14855 .04184 Mdot
.14867 .02067 Mdot
.1488 .04695 Mdot
.14892 .03431 Mdot
.14904 .06185 Mdot
.14916 .3049 Mdot
.14928 .11684 Mdot
.1494 .31897 Mdot
.14952 .29446 Mdot
.14964 .30505 Mdot
.14976 .26193 Mdot
.14988 .29957 Mdot
.15 .12451 Mdot
.15012 .33293 Mdot
.15025 .30583 Mdot
.15037 .11651 Mdot
.15049 .0547 Mdot
.15061 .03327 Mdot
.15073 .06141 Mdot
.15085 .29183 Mdot
.15097 .11745 Mdot
.15109 .32399 Mdot
.15121 .27039 Mdot
.15133 .29906 Mdot
.15145 .16827 Mdot
.15158 .3634 Mdot
.1517 .19113 Mdot
.15182 .34369 Mdot
.15194 .12224 Mdot
.15206 .05598 Mdot
.15218 .0373 Mdot
.1523 .06299 Mdot
.15242 .33564 Mdot
.15254 .11274 Mdot
.15266 .23924 Mdot
.15278 .30836 Mdot
.1529 .0391 Mdot
.15303 .01965 Mdot
.15315 .05265 Mdot
.15327 .09443 Mdot
.15339 .08149 Mdot
.15351 .03734 Mdot
.15363 .15404 Mdot
.15375 .09826 Mdot
.15387 .3173 Mdot
.15399 .29955 Mdot
.15411 .30713 Mdot
.15423 .28255 Mdot
.15436 .30055 Mdot
.15448 .21574 Mdot
.1546 .32318 Mdot
.15472 .18327 Mdot
.15484 .06822 Mdot
.15496 .11052 Mdot
.15508 .08621 Mdot
.1552 .21363 Mdot
.15532 .32644 Mdot
.15544 .21002 Mdot
.15556 .07156 Mdot
.15569 .13174 Mdot
.15581 .09221 Mdot
.15593 .29844 Mdot
.15605 .30414 Mdot
.15617 .25889 Mdot
.15629 .30012 Mdot
.15641 .10827 Mdot
.15653 .25379 Mdot
.15665 .15237 Mdot
.15677 .0207 Mdot
.15689 .04764 Mdot
.15701 .03705 Mdot
.15714 .06291 Mdot
.15726 .33443 Mdot
.15738 .11298 Mdot
.1575 .25036 Mdot
.15762 .30307 Mdot
.15774 .05326 Mdot
.15786 .11494 Mdot
.15798 .28445 Mdot
.1581 .36808 Mdot
.15822 .29925 Mdot
.15834 .26576 Mdot
.15847 .29911 Mdot
.15859 .14321 Mdot
.15871 .36669 Mdot
.15883 .29958 Mdot
.15895 .2667 Mdot
.15907 .29904 Mdot
.15919 .14784 Mdot
.15931 .36881 Mdot
.15943 .30452 Mdot
.15955 .2931 Mdot
.15967 .30417 Mdot
.15979 .25458 Mdot
.15992 .30118 Mdot
.16004 .08528 Mdot
.16016 .29563 Mdot
.16028 .35788 Mdot
.1604 .04146 Mdot
.16052 .36543 Mdot
.16064 .10452 Mdot
.16076 .56733 Mdot
.16088 .46999 Mdot
.161 .03462 Mdot
.16112 .0413 Mdot
.16125 .02174 Mdot
.16137 .05499 Mdot
.16149 .13285 Mdot
.16161 .09255 Mdot
.16173 .30063 Mdot
.16185 .30503 Mdot
.16197 .2666 Mdot
.16209 .29906 Mdot
.16221 .14811 Mdot
.16233 .36888 Mdot
.16245 .30466 Mdot
.16258 .29439 Mdot
.1627 .30473 Mdot
.16282 .25961 Mdot
.16294 .29998 Mdot
.16306 .11221 Mdot
.16318 .27704 Mdot
.1633 .35035 Mdot
.16342 .28913 Mdot
.16354 .12992 Mdot
.16366 .34765 Mdot
.16378 .28994 Mdot
.1639 .11466 Mdot
.16403 .28983 Mdot
.16415 .37102 Mdot
.16427 .3027 Mdot
.16439 .30761 Mdot
.16451 .30179 Mdot
.16463 .30763 Mdot
.16475 .2903 Mdot
.16487 .30308 Mdot
.16499 .24446 Mdot
.16511 .30487 Mdot
.16523 .04197 Mdot
.16536 .38332 Mdot
.16548 .09692 Mdot
.1656 .32319 Mdot
.16572 .11479 Mdot
.16584 .3005 Mdot
.16596 .30495 Mdot
.16608 .26597 Mdot
.1662 .29911 Mdot
.16632 .14504 Mdot
.16644 .36773 Mdot
.16656 .302 Mdot
.16668 .27765 Mdot
.16681 .2995 Mdot
.16693 .1963 Mdot
.16705 .34002 Mdot
.16717 .16871 Mdot
.16729 .06581 Mdot
.16741 .0924 Mdot
.16753 .08085 Mdot
.16765 .0407 Mdot
.16777 .01972 Mdot
.16789 .04896 Mdot
.16801 .04949 Mdot
.16814 .06732 Mdot
.16826 .45483 Mdot
.16838 .04302 Mdot
.1685 .03564 Mdot
.16862 .02159 Mdot
.16874 .04481 Mdot
.16886 .02586 Mdot
.16898 .05797 Mdot
.1691 .20115 Mdot
.16922 .10871 Mdot
.16934 .32996 Mdot
.16946 .24374 Mdot
.16959 .305 Mdot
.16971 .04181 Mdot
.16983 .37572 Mdot
.16995 .10041 Mdot
.17007 .43468 Mdot
.17019 .06164 Mdot
.17031 .0215 Mdot
.17043 .045 Mdot
.17055 .02618 Mdot
.17067 .05815 Mdot
.17079 .20573 Mdot
.17092 .10957 Mdot
.17104 .33096 Mdot
.17116 .24085 Mdot
.17128 .30634 Mdot
.1714 .03657 Mdot
.17152 .11451 Mdot
.17164 .0875 Mdot
.17176 .24812 Mdot
.17188 .30398 Mdot
.172 .04544 Mdot
.17212 .53506 Mdot
.17225 .11627 Mdot
.17237 .09019 Mdot
.17249 .3082 Mdot
.17261 .30736 Mdot
.17273 .29299 Mdot
.17285 .30418 Mdot
.17297 .25459 Mdot
.17309 .30117 Mdot
.17321 .08538 Mdot
.17333 .29447 Mdot
.17345 .35973 Mdot
.17357 .06296 Mdot
.1737 .32049 Mdot
.17382 .28643 Mdot
.17394 .30189 Mdot
.17406 .23166 Mdot
.17418 .31176 Mdot
.1743 .05961 Mdot
.17442 .03196 Mdot
.17454 .0305 Mdot
.17466 .02951 Mdot
.17478 .03123 Mdot
.1749 .02854 Mdot
.17503 .03276 Mdot
.17515 .02629 Mdot
.17527 .03645 Mdot
.17539 .02177 Mdot
.17551 .04444 Mdot
.17563 .02481 Mdot
.17575 .05735 Mdot
.17587 .18583 Mdot
.17599 .1056 Mdot
.17611 .32617 Mdot
.17623 .25886 Mdot
.17635 .30011 Mdot
.17648 .11115 Mdot
.1766 .27094 Mdot
.17672 .31769 Mdot
.17684 .33525 Mdot
.17696 .35517 Mdot
.17708 .05952 Mdot
.1772 .02001 Mdot
.17732 .05018 Mdot
.17744 .05814 Mdot
.17756 .07018 Mdot
.17768 .52609 Mdot
.17781 .06804 Mdot
.17793 .07388 Mdot
.17805 .42455 Mdot
.17817 .02609 Mdot
.17829 .04486 Mdot
.17841 .03302 Mdot
.17853 .06133 Mdot
.17865 .2909 Mdot
.17877 .11747 Mdot
.17889 .32431 Mdot
.17901 .2687 Mdot
.17914 .29905 Mdot
.17926 .16057 Mdot
.17938 .36752 Mdot
.1795 .27156 Mdot
.17962 .2993 Mdot
.17974 .17713 Mdot
.17986 .3569 Mdot
.17998 .06525 Mdot
.1801 .32582 Mdot
.18022 .25803 Mdot
.18034 .30028 Mdot
.18046 .10665 Mdot
.18059 .24419 Mdot
.18071 .26305 Mdot
.18083 .31487 Mdot
.18095 .34054 Mdot
.18107 .30661 Mdot
.18119 .07112 Mdot
.18131 .05357 Mdot
.18143 .06866 Mdot
.18155 .48741 Mdot
.18167 .01659 Mdot
.18179 .04933 Mdot
.18192 .09441 Mdot
.18204 .08149 Mdot
.18216 .03754 Mdot
.18228 .16342 Mdot
.1824 .10059 Mdot
.18252 .32041 Mdot
.18264 .28816 Mdot
.18276 .30249 Mdot
.18288 .23806 Mdot
.183 .30802 Mdot
.18312 .03692 Mdot
.18324 .02446 Mdot
.18337 .05741 Mdot
.18349 .19366 Mdot
.18361 .10724 Mdot
.18373 .32817 Mdot
.18385 .2501 Mdot
.18397 .30249 Mdot
.18409 .06577 Mdot
.18421 .32597 Mdot
.18433 .25731 Mdot
.18445 .30044 Mdot
.18457 .10278 Mdot
.1847 .22298 Mdot
.18482 .31638 Mdot
.18494 .30236 Mdot
.18506 .3078 Mdot
.18518 .29418 Mdot
.1853 .3047 Mdot
.18542 .25925 Mdot
.18554 .30005 Mdot
.18566 .11029 Mdot
.18578 .26584 Mdot
.1859 .27379 Mdot
.18602 .32415 Mdot
.18615 .3231 Mdot
.18627 .35207 Mdot
.18639 .06063 Mdot
.18651 .02009 Mdot
.18663 .05153 Mdot
.18675 .07361 Mdot
.18687 .0751 Mdot
.18699 .58008 Mdot
.18711 .03624 Mdot
.18723 .0655 Mdot
.18735 .07261 Mdot
.18748 .5768 Mdot
.1876 .59335 Mdot
.18772 .063 Mdot
.18784 .03246 Mdot
.18796 .02997 Mdot
.18808 .03033 Mdot
.1882 .02993 Mdot
.18832 .03056 Mdot
.18844 .02958 Mdot
.18856 .03111 Mdot
.18868 .02873 Mdot
.18881 .03247 Mdot
.18893 .02671 Mdot
.18905 .03575 Mdot
.18917 .02249 Mdot
.18929 .04304 Mdot
.18941 .02197 Mdot
.18953 .0552 Mdot
.18965 .13705 Mdot
.18977 .09369 Mdot
.18989 .30584 Mdot
.19001 .30688 Mdot
.19013 .28505 Mdot
.19026 .30123 Mdot
.19038 .22496 Mdot
.1905 .31622 Mdot
.19062 .10883 Mdot
.19074 .05248 Mdot
.19086 .0274 Mdot
.19098 .05876 Mdot
.1911 .2206 Mdot
.19122 .1121 Mdot
.19134 .33354 Mdot
.19146 .23584 Mdot
.19159 .30894 Mdot
.19171 .03954 Mdot
.19183 .01946 Mdot
.19195 .05194 Mdot
.19207 .08366 Mdot
.19219 .07822 Mdot
.19231 .33665 Mdot
.19243 .06581 Mdot
.19255 .02561 Mdot
.19267 .05773 Mdot
.19279 .19311 Mdot
.19291 .10712 Mdot
.19304 .32803 Mdot
.19316 .25066 Mdot
.19328 .3023 Mdot
.1934 .06845 Mdot
.19352 .33399 Mdot
.19364 .23235 Mdot
.19376 .31097 Mdot
.19388 .05188 Mdot
.194 .02677 Mdot
.19412 .03742 Mdot
.19424 .02082 Mdot
.19437 .04653 Mdot
.19449 .03229 Mdot
.19461 .06102 Mdot
.19473 .28222 Mdot
.19485 .11753 Mdot
.19497 .32717 Mdot
.19509 .25473 Mdot
.19521 .30107 Mdot
.19533 .08915 Mdot
.19545 .24902 Mdot
.19557 .15868 Mdot
.1957 .02071 Mdot
.19582 .05224 Mdot
.19594 .08078 Mdot
.19606 .07733 Mdot
.19618 .45306 Mdot
.1963 .01532 Mdot
.19642 .05116 Mdot
.19654 .12565 Mdot
.19666 .09057 Mdot
.19678 .28707 Mdot
.1969 .30023 Mdot
.19702 .21976 Mdot
.19715 .32005 Mdot
.19727 .15321 Mdot
.19739 .06308 Mdot
.19751 .07385 Mdot
.19763 .07516 Mdot
.19775 .57977 Mdot
.19787 .03654 Mdot
.19799 .03921 Mdot
.19811 .0638 Mdot
.19823 .36554 Mdot
.19835 .10433 Mdot
.19848 .5632 Mdot
.1986 .41242 Mdot
.19872 .0866 Mdot
.19884 .09369 Mdot
.19896 .08121 Mdot
.19908 .03571 Mdot
.1992 .03146 Mdot
.19932 .06079 Mdot
.19944 .28235 Mdot
.19956 .11753 Mdot
.19968 .32714 Mdot
.1998 .2549 Mdot
.19993 .30103 Mdot
.20005 .09002 Mdot
.20017 .23993 Mdot
.20029 .24281 Mdot
.20041 .16815 Mdot
.20053 .038 Mdot
.20065 .06315 Mdot
.20077 .3333 Mdot
.20089 .1132 Mdot
.20101 .25925 Mdot
.20113 .3002 Mdot
.20126 .09632 Mdot
.20138 .20678 Mdot
.2015 .52249 Mdot
.20162 .22874 Mdot
.20174 .11801 Mdot
.20186 .35329 Mdot
.20198 .29491 Mdot
.2021 .30575 Mdot
.20222 .26747 Mdot
.20234 .29902 Mdot
.20246 .15243 Mdot
.20258 .36937 Mdot
.20271 .3032 Mdot
.20283 .30731 Mdot
.20295 .3035 Mdot
.20307 .30779 Mdot
.20319 .2972 Mdot
.20331 .30602 Mdot
.20343 .2713 Mdot
.20355 .29897 Mdot
.20367 .17015 Mdot
.20379 .36215 Mdot
.20391 .16424 Mdot
.20404 .36518 Mdot
.20416 .22861 Mdot
.20428 .31304 Mdot
.2044 .07003 Mdot
.20452 .03778 Mdot
.20464 .02381 Mdot
.20476 .0406 Mdot
.20488 .01991 Mdot
.205 .05152 Mdot
.20512 .07454 Mdot
.20524 .07539 Mdot
.20537 .57395 Mdot
.20549 .25478 Mdot
.20561 .07351 Mdot
.20573 .11255 Mdot
.20585 .08679 Mdot
.20597 .22834 Mdot
.20609 .31516 Mdot
.20621 .10073 Mdot
.20633 .05 Mdot
.20645 .02308 Mdot
.20657 .05611 Mdot
.20669 .156 Mdot
.20682 .09863 Mdot
.20694 .3176 Mdot
.20706 .29871 Mdot
.20718 .30682 Mdot
.2073 .27908 Mdot
.20742 .29979 Mdot
.20754 .20253 Mdot
.20766 .33442 Mdot
.20778 .21015 Mdot
.2079 .07154 Mdot
.20802 .13119 Mdot
.20815 .09206 Mdot
.20827 .29754 Mdot
.20839 .30378 Mdot
.20851 .25575 Mdot
.20863 .30086 Mdot
.20875 .09143 Mdot
.20887 .22744 Mdot
.20899 .34276 Mdot
.20911 .24901 Mdot
.20923 .30281 Mdot
.20935 .06215 Mdot
.20947 .3175 Mdot
.2096 .29835 Mdot
.20972 .30668 Mdot
.20984 .27756 Mdot
.20996 .29953 Mdot
.21008 .19652 Mdot
.2102 .33982 Mdot
.21032 .1708 Mdot
.21044 .06617 Mdot
.21056 .09499 Mdot
.21068 .08163 Mdot
.2108 .03895 Mdot
.21093 .22917 Mdot
.21105 .11352 Mdot
.21117 .33497 Mdot
.21129 .23459 Mdot
.21141 .30964 Mdot
.21153 .04292 Mdot
.21165 .02036 Mdot
.21177 .04733 Mdot
.21189 .03769 Mdot
.21201 .06315 Mdot
.21213 .34119 Mdot
.21225 .11154 Mdot
.21238 .16084 Mdot
.2125 .36811 Mdot
.21262 .28075 Mdot
.21274 .30071 Mdot
.21286 .21428 Mdot
.21298 .32436 Mdot
.2131 .1924 Mdot
.21322 .06949 Mdot
.21334 .11952 Mdot
.21346 .0888 Mdot
.21358 .26629 Mdot
.21371 .29887 Mdot
.21383 .13324 Mdot
.21395 .35482 Mdot
.21407 .28801 Mdot
.21419 .1881 Mdot
.21431 .34762 Mdot
.21443 .07199 Mdot
.21455 .03846 Mdot
.21467 .0232 Mdot
.21479 .04169 Mdot
.21491 .02043 Mdot
.21504 .05317 Mdot
.21516 .09889 Mdot
.21528 .08282 Mdot
.2154 .08253 Mdot
.21552 .33624 Mdot
.21564 .29203 Mdot
.21576 .08945 Mdot
.21588 .24674 Mdot
.216 .15115 Mdot
.21612 .02079 Mdot
.21624 .04728 Mdot
.21636 .03504 Mdot
.21649 .06213 Mdot
.21661 .31284 Mdot
.21673 .11616 Mdot
.21685 .31446 Mdot
.21697 .30496 Mdot
.21709 .30717 Mdot
.21721 .30372 Mdot
.21733 .30777 Mdot
.21745 .29801 Mdot
.21757 .30636 Mdot
.21769 .27463 Mdot
.21782 .29917 Mdot
.21794 .18456 Mdot
.21806 .35059 Mdot
.21818 .04307 Mdot
.2183 .02022 Mdot
.21842 .04763 Mdot
.21854 .0396 Mdot
.21866 .06386 Mdot
.21878 .36088 Mdot
.2189 .10597 Mdot
.21902 .5865 Mdot
.21914 .08028 Mdot
.21927 .33138 Mdot
.21939 .29656 Mdot
.21951 .03981 Mdot
.21963 .27723 Mdot
.21975 .11761 Mdot
.21987 .32916 Mdot
.21999 .24681 Mdot
.22011 .30371 Mdot
.22023 .05167 Mdot
.22035 .03837 Mdot
.22047 .01966 Mdot
.2206 .05263 Mdot
.22072 .0941 Mdot
.22084 .08139 Mdot
.22096 .03619 Mdot
.22108 .09965 Mdot
.2212 .08314 Mdot
.22132 .104 Mdot
.22144 .22179 Mdot
.22156 .31198 Mdot
.22168 .30696 Mdot
.2218 .30283 Mdot
.22193 .30778 Mdot
.22205 .29445 Mdot
.22217 .30482 Mdot
.22229 .26032 Mdot
.22241 .29984 Mdot
.22253 .11599 Mdot
.22265 .29743 Mdot
.22277 .36629 Mdot
.22289 .20497 Mdot
.22301 .33124 Mdot
.22313 .21424 Mdot
.22325 .07196 Mdot
.22338 .13312 Mdot
.2235 .09258 Mdot
.22362 .30054 Mdot
.22374 .30499 Mdot
.22386 .26628 Mdot
.22398 .29909 Mdot
.2241 .14657 Mdot
.22422 .3684 Mdot
.22434 .3036 Mdot
.22446 .28646 Mdot
.22458 .30162 Mdot
.22471 .22971 Mdot
.22483 .313 Mdot
.22495 .07185 Mdot
.22507 .03869 Mdot
.22519 .02297 Mdot
.22531 .04211 Mdot
.22543 .02079 Mdot
.22555 .05379 Mdot
.22567 .10962 Mdot
.22579 .08598 Mdot
.22591 .20825 Mdot
.22603 .33102 Mdot
.22616 .22142 Mdot
.22628 .0726 Mdot
.2264 .13493 Mdot
.22652 .09308 Mdot
.22664 .30297 Mdot
.22676 .30593 Mdot
.22688 .27494 Mdot
.227 .2992 Mdot
.22712 .18578 Mdot
.22724 .34951 Mdot
.22736 .0515 Mdot
.22749 .02614 Mdot
.22761 .03831 Mdot
.22773 .02026 Mdot
.22785 .0481 Mdot
.22797 .04123 Mdot
.22809 .06445 Mdot
.22821 .37721 Mdot
.22833 .0996 Mdot
.22845 .40883 Mdot
.22857 .08183 Mdot
.22869 .05936 Mdot
.22881 .07054 Mdot
.22894 .53212 Mdot
.22906 .0986 Mdot
.22918 .08441 Mdot
.2293 .25896 Mdot
.22942 .30027 Mdot
.22954 .09501 Mdot
.22966 .20889 Mdot
.22978 .10347 Mdot
.2299 .05168 Mdot
.23002 .02609 Mdot
.23014 .05806 Mdot
.23027 .2027 Mdot
.23039 .109 Mdot
.23051 .33031 Mdot
.23063 .24268 Mdot
.23075 .30548 Mdot
.23087 .03936 Mdot
.23099 .25597 Mdot
.23111 .11651 Mdot
.23123 .33403 Mdot
.23135 .23546 Mdot
.23147 .30915 Mdot
.2316 .04045 Mdot
.23172 .01939 Mdot
.23184 .05059 Mdot
.23196 .06594 Mdot
.23208 .07269 Mdot
.2322 .57517 Mdot
.23232 .57627 Mdot
.23244 .52349 Mdot
.23256 .04149 Mdot
.23268 .06421 Mdot
.2328 .47599 Mdot
.23292 .02383 Mdot
.23305 .04632 Mdot
.23317 .0469 Mdot
.23329 .06644 Mdot
.23341 .43179 Mdot
.23353 .06424 Mdot
.23365 .0204 Mdot
.23377 .04802 Mdot
.23389 .04015 Mdot
.23401 .06406 Mdot
.23413 .3664 Mdot
.23425 .10401 Mdot
.23438 .55427 Mdot
.2345 .29717 Mdot
.23462 .12311 Mdot
.23474 .34062 Mdot
.23486 .24026 Mdot
.23498 .30656 Mdot
.2351 .03622 Mdot
.23522 .09495 Mdot
.23534 .08173 Mdot
.23546 .04621 Mdot
.23558 .54754 Mdot
.2357 .22088 Mdot
.23583 .11696 Mdot
.23595 .35325 Mdot
.23607 .29473 Mdot
.23619 .30567 Mdot
.23631 .26672 Mdot
.23643 .29906 Mdot
.23655 .14878 Mdot
.23667 .36904 Mdot
.23679 .3049 Mdot
.23691 .29741 Mdot
.23703 .30604 Mdot
.23716 .27169 Mdot
.23728 .29899 Mdot
.2374 .17188 Mdot
.23752 .36093 Mdot
.23764 .13821 Mdot
.23776 .36324 Mdot
.23788 .29357 Mdot
.238 .24233 Mdot
.23812 .30593 Mdot
.23824 .03722 Mdot
.23836 .14856 Mdot
.23849 .09686 Mdot
.23861 .31496 Mdot
.23873 .30423 Mdot
.23885 .30758 Mdot
.23897 .30126 Mdot
.23909 .30751 Mdot
.23921 .2881 Mdot
.23933 .30225 Mdot
.23945 .23627 Mdot
.23957 .30901 Mdot
.23969 .04036 Mdot
.23981 .01938 Mdot
.23994 .05072 Mdot
.24006 .06754 Mdot
.24018 .07319 Mdot
.2403 .5816 Mdot
.24042 .56037 Mdot
.24054 .60329 Mdot
.24066 .28418 Mdot
.24078 .30287 Mdot
.2409 .2362 Mdot
.24102 .30905 Mdot
.24114 .0405 Mdot
.24127 .0194 Mdot
.24139 .05052 Mdot
.24151 .0652 Mdot
.24163 .07245 Mdot
.24175 .5716 Mdot
.24187 .52943 Mdot
.24199 .06186 Mdot
.24211 .07167 Mdot
.24223 .57334 Mdot
.24235 .29561 Mdot
.24247 .07179 Mdot
.24259 .06391 Mdot
.24272 .07201 Mdot
.24284 .56303 Mdot
.24296 .4094 Mdot
.24308 .08868 Mdot
.2432 .11981 Mdot
.24332 .08885 Mdot
.24344 .26639 Mdot
.24356 .29886 Mdot
.24368 .13372 Mdot
.2438 .35567 Mdot
.24392 .28812 Mdot
.24405 .19472 Mdot
.24417 .34164 Mdot
.24429 .15068 Mdot
.24441 .06246 Mdot
.24453 .06948 Mdot
.24465 .07379 Mdot
.24477 .58617 Mdot
.24489 .07732 Mdot
.24501 .03987 Mdot
.24513 .02209 Mdot
.24525 .04379 Mdot
.24537 .02328 Mdot
.2455 .05631 Mdot
.24562 .16134 Mdot
.24574 .09996 Mdot
.24586 .31941 Mdot
.24598 .2925 Mdot
.2461 .30421 Mdot
.24622 .25435 Mdot
.24634 .30124 Mdot
.24646 .08409 Mdot
.24658 .30992 Mdot
.2467 .33119 Mdot
.24683 .36164 Mdot
.24695 .05718 Mdot
.24707 .02063 Mdot
.24719 .04719 Mdot
.24731 .0353 Mdot
.24743 .06224 Mdot
.24755 .31579 Mdot
.24767 .11584 Mdot
.24779 .31198 Mdot
.24791 .30689 Mdot
.24803 .30326 Mdot
.24816 .30779 Mdot
.24828 .29615 Mdot
.2484 .30556 Mdot
.24852 .26708 Mdot
.24864 .29904 Mdot
.24876 .15053 Mdot
.24888 .36931 Mdot
.249 .30478 Mdot
.24912 .30364 Mdot
.24924 .30778 Mdot
.24936 .29727 Mdot
.24948 .30605 Mdot
.24961 .2716 Mdot
.24973 .29898 Mdot
.24985 .1715 Mdot
.24997 .3612 Mdot
.25009 .14399 Mdot
.25021 .36769 Mdot
.25033 .30194 Mdot
.25045 .27736 Mdot
.25057 .29945 Mdot
.25069 .19514 Mdot
.25081 .34107 Mdot
.25094 .15704 Mdot
.25106 .0637 Mdot
.25118 .07761 Mdot
.2513 .07633 Mdot
.25142 .53823 Mdot
.25154 .37844 Mdot
.25166 .10557 Mdot
.25178 .55788 Mdot
.2519 .34188 Mdot
.25202 .11774 Mdot
.25214 .30594 Mdot
.25226 .30689 Mdot
.25239 .28521 Mdot
.25251 .30128 Mdot
.25263 .22555 Mdot
.25275 .31581 Mdot
.25287 .10388 Mdot
.25299 .05099 Mdot
.25311 .02455 Mdot
.25323 .05715 Mdot
.25335 .18012 Mdot
.25347 .10436 Mdot
.25359 .32467 Mdot
.25372 .26635 Mdot
.25384 .29914 Mdot
.25396 .14943 Mdot
.25408 .36916 Mdot
.2542 .30499 Mdot
.25432 .30004 Mdot
.25444 .30709 Mdot
.25456 .28254 Mdot
.25468 .30054 Mdot
.2548 .2157 Mdot
.25492 .32322 Mdot
.25505 .18357 Mdot
.25517 .06826 Mdot
.25529 .11085 Mdot
.25541 .08631 Mdot
.25553 .2162 Mdot
.25565 .32432 Mdot
.25577 .19708 Mdot
.25589 .0701 Mdot
.25601 .12354 Mdot
.25613 .08993 Mdot
.25625 .28031 Mdot
.25637 .2989 Mdot
.2565 .19517 Mdot
.25662 .34106 Mdot
.25674 .15722 Mdot
.25686 .06374 Mdot
.25698 .07783 Mdot
.2571 .0764 Mdot
.25722 .53424 Mdot
.25734 .33782 Mdot
.25746 .11832 Mdot
.25758 .3115 Mdot
.2577 .30708 Mdot
.25783 .30215 Mdot
.25795 .3077 Mdot
.25807 .29171 Mdot
.25819 .30365 Mdot
.25831 .24974 Mdot
.25843 .30274 Mdot
.25855 .06133 Mdot
.25867 .31513 Mdot
.25879 .3037 Mdot
.25891 .30774 Mdot
.25903 .29928 Mdot
.25915 .30686 Mdot
.25928 .27985 Mdot
.2594 .29993 Mdot
.25952 .20547 Mdot
.25964 .33182 Mdot
.25976 .21665 Mdot
.25988 .07218 Mdot
.26 .13385 Mdot
.26012 .09278 Mdot
.26024 .30156 Mdot
.26036 .30539 Mdot
.26048 .2699 Mdot
.26061 .29895 Mdot
.26073 .16376 Mdot
.26085 .36604 Mdot
.26097 .2447 Mdot
.26109 .3044 Mdot
.26121 .04656 Mdot
.26133 .57173 Mdot
.26145 .52989 Mdot
.26157 .06373 Mdot
.26169 .07234 Mdot
.26181 .54915 Mdot
.26193 .49312 Mdot
.26206 .01637 Mdot
.26218 .04938 Mdot
.2623 .09681 Mdot
.26242 .08221 Mdot
.26254 .05744 Mdot
.26266 .27328 Mdot
.26278 .29845 Mdot
.2629 .16665 Mdot
.26302 .36442 Mdot
.26314 .21254 Mdot
.26326 .32488 Mdot
.26339 .19303 Mdot
.26351 .06957 Mdot
.26363 .12005 Mdot
.26375 .08895 Mdot
.26387 .26839 Mdot
.26399 .29865 Mdot
.26411 .1436 Mdot
.26423 .36693 Mdot
.26435 .30012 Mdot
.26447 .26896 Mdot
.26459 .29894 Mdot
.26472 .15873 Mdot
.26484 .3682 Mdot
.26496 .28296 Mdot
.26508 .3013 Mdot
.2652 .2226 Mdot
.26532 .31792 Mdot
.26544 .12902 Mdot
.26556 .05783 Mdot
.26568 .04484 Mdot
.2658 .06571 Mdot
.26592 .41078 Mdot
.26604 .08059 Mdot
.26617 .05113 Mdot
.26629 .06784 Mdot
.26641 .46572 Mdot
.26653 .0327 Mdot
.26665 .04219 Mdot
.26677 .02351 Mdot
.26689 .0565 Mdot
.26701 .16574 Mdot
.26713 .10103 Mdot
.26725 .32073 Mdot
.26737 .2867 Mdot
.2675 .30198 Mdot
.26762 .23267 Mdot
.26774 .31113 Mdot
.26786 .05417 Mdot
.26798 .02839 Mdot
.2681 .03521 Mdot
.26822 .02295 Mdot
.26834 .0422 Mdot
.26846 .02089 Mdot
.26858 .05394 Mdot
.2687 .11235 Mdot
.26882 .08677 Mdot
.26895 .22924 Mdot
.26907 .31454 Mdot
.26919 .09339 Mdot
.26931 .04755 Mdot
.26943 .02071 Mdot
.26955 .05355 Mdot
.26967 .10492 Mdot
.26979 .0846 Mdot
.26991 .16113 Mdot
.27003 .36799 Mdot
.27015 .27884 Mdot
.27028 .30027 Mdot
.2704 .20693 Mdot
.27052 .33054 Mdot
.27064 .2169 Mdot
.27076 .07221 Mdot
.27088 .13402 Mdot
.271 .09283 Mdot
.27112 .30179 Mdot
.27124 .30548 Mdot
.27136 .27073 Mdot
.27148 .29896 Mdot
.27161 .16753 Mdot
.27173 .36387 Mdot
.27185 .20106 Mdot
.27197 .33472 Mdot
.27209 .20635 Mdot
.27221 .07113 Mdot
.27233 .12917 Mdot
.27245 .0915 Mdot
.27257 .29392 Mdot
.27269 .30239 Mdot
.27281 .24327 Mdot
.27293 .30542 Mdot
.27306 .03918 Mdot
.27318 .24663 Mdot
.2733 .11565 Mdot
.27342 .33504 Mdot
.27354 .23464 Mdot
.27366 .30961 Mdot
.27378 .04273 Mdot
.2739 .02025 Mdot
.27402 .04756 Mdot
.27414 .03913 Mdot
.27426 .06369 Mdot
.27439 .35605 Mdot
.27451 .10754 Mdot
.27463 .47992 Mdot
.27475 .03126 Mdot
.27487 .06047 Mdot
.27499 .37053 Mdot
.27511 .10243 Mdot
.27523 .5039 Mdot
.27535 .01756 Mdot
.27547 .05415 Mdot
.27559 .21427 Mdot
.27571 .11109 Mdot
.27584 .33265 Mdot
.27596 .23716 Mdot
.27608 .30822 Mdot
.2762 .03714 Mdot
.27632 .02342 Mdot
.27644 .05675 Mdot
.27656 .17769 Mdot
.27668 .10381 Mdot
.2768 .32402 Mdot
.27692 .26971 Mdot
.27704 .29905 Mdot
.27717 .16521 Mdot
.27729 .36525 Mdot
.27741 .22943 Mdot
.27753 .31251 Mdot
.27765 .06476 Mdot
.27777 .03499 Mdot
.27789 .0268 Mdot
.27801 .03549 Mdot
.27813 .02279 Mdot
.27825 .04249 Mdot
.27837 .02122 Mdot
.27849 .05439 Mdot
.27862 .12063 Mdot
.27874 .08914 Mdot
.27886 .27165 Mdot
.27898 .29846 Mdot
.2791 .15895 Mdot
.27922 .36813 Mdot
.27934 .28181 Mdot
.27946 .30098 Mdot
.27958 .21828 Mdot
.2797 .32118 Mdot
.27982 .16483 Mdot
.27995 .06524 Mdot
.28007 .08873 Mdot
.28019 .07974 Mdot
.28031 .11988 Mdot
.28043 .05625 Mdot
.28055 .03918 Mdot
.28067 .06369 Mdot
.28079 .3551 Mdot
.28091 .10783 Mdot
.28103 .42583 Mdot
.28115 .02542 Mdot
.28128 .04522 Mdot
.2814 .03525 Mdot
.28152 .06222 Mdot
.28164 .31562 Mdot
.28176 .11586 Mdot
.28188 .31214 Mdot
.282 .30682 Mdot
.28212 .30359 Mdot
.28224 .30778 Mdot
.28236 .29745 Mdot
.28248 .30612 Mdot
.2826 .27234 Mdot
.28273 .29901 Mdot
.28285 .17476 Mdot
.28297 .35877 Mdot
.28309 .0955 Mdot
.28321 .2074 Mdot
.28333 .4484 Mdot
.28345 .01606 Mdot
.28357 .05025 Mdot
.28369 .1042 Mdot
.28381 .0844 Mdot
.28393 .15349 Mdot
.28406 .36941 Mdot
.28418 .30387 Mdot
.2843 .30653 Mdot
.28442 .30577 Mdot
.28454 .30672 Mdot
.28466 .30511 Mdot
.28478 .30729 Mdot
.2849 .30304 Mdot
.28502 .30779 Mdot
.28514 .29536 Mdot
.28526 .30522 Mdot
.28538 .26392 Mdot
.28551 .29931 Mdot
.28563 .13478 Mdot
.28575 .35745 Mdot
.28587 .28865 Mdot
.28599 .2075 Mdot
.28611 .33023 Mdot
.28623 .2172 Mdot
.28635 .07224 Mdot
.28647 .13413 Mdot
.28659 .09286 Mdot
.28671 .30193 Mdot
.28684 .30554 Mdot
.28696 .27123 Mdot
.28708 .29897 Mdot
.2872 .1698 Mdot
.28732 .36239 Mdot
.28744 .16943 Mdot
.28756 .36188 Mdot
.28768 .15928 Mdot
.2878 .36759 Mdot
.28792 .27329 Mdot
.28804 .29943 Mdot
.28817 .18454 Mdot
.28829 .3506 Mdot
.28841 .043 Mdot
.28853 .02018 Mdot
.28865 .04772 Mdot
.28877 .04016 Mdot
.28889 .06406 Mdot
.28901 .36648 Mdot
.28913 .10398 Mdot
.28925 .55346 Mdot
.28937 .28752 Mdot
.28949 .12325 Mdot
.28962 .3459 Mdot
.28974 .25856 Mdot
.28986 .30016 Mdot
.28998 .11169 Mdot
.2901 .27407 Mdot
.29022 .33688 Mdot
.29034 .30222 Mdot
.29046 .06495 Mdot
.29058 .03518 Mdot
.2907 .02657 Mdot
.29082 .03587 Mdot
.29095 .02237 Mdot
.29107 .04327 Mdot
.29119 .02234 Mdot
.29131 .05555 Mdot
.29143 .14436 Mdot
.29155 .09564 Mdot
.29167 .31197 Mdot
.29179 .30687 Mdot
.29191 .30335 Mdot
.29203 .30779 Mdot
.29215 .29651 Mdot
.29227 .30572 Mdot
.2924 .26851 Mdot
.29252 .29898 Mdot
.29264 .15738 Mdot
.29276 .36861 Mdot
.29288 .28959 Mdot
.293 .30364 Mdot
.29312 .24761 Mdot
.29324 .30354 Mdot
.29336 .05234 Mdot
.29348 .04989 Mdot
.2936 .47693 Mdot
.29373 .02705 Mdot
.29385 .05878 Mdot
.29397 .3256 Mdot
.29409 .11454 Mdot
.29421 .29555 Mdot
.29433 .30298 Mdot
.29445 .24873 Mdot
.29457 .30311 Mdot
.29469 .05683 Mdot
.29481 .27568 Mdot
.29493 .29851 Mdot
.29505 .17697 Mdot
.29518 .35704 Mdot
.2953 .06721 Mdot
.29542 .3315 Mdot
.29554 .23657 Mdot
.29566 .30856 Mdot
.29578 .03814 Mdot
.2959 .02066 Mdot
.29602 .05439 Mdot
.29614 .12576 Mdot
.29626 .09059 Mdot
.29638 .28715 Mdot
.29651 .30025 Mdot
.29663 .22003 Mdot
.29675 .31985 Mdot
.29687 .15098 Mdot
.29699 .06264 Mdot
.29711 .071 Mdot
.29723 .07427 Mdot
.29735 .58737 Mdot
.29747 .06326 Mdot
.29759 .32319 Mdot
.29771 .27193 Mdot
.29784 .2991 Mdot
.29796 .17501 Mdot
.29808 .35858 Mdot
.2982 .092 Mdot
.29832 .2192 Mdot
.29844 .31485 Mdot
.29856 .30474 Mdot
.29868 .30731 Mdot
.2988 .30303 Mdot
.29892 .30779 Mdot
.29904 .29534 Mdot
.29916 .30521 Mdot
.29929 .26383 Mdot
.29941 .29932 Mdot
.29953 .13436 Mdot
.29965 .35677 Mdot
.29977 .2884 Mdot
.29989 .20285 Mdot
.30001 .33432 Mdot
.30013 .21102 Mdot
.30025 .07163 Mdot
.30037 .1316 Mdot
.30049 .09217 Mdot
.30062 .29821 Mdot
.30074 .30405 Mdot
.30086 .25807 Mdot
.30098 .3003 Mdot
.3011 .10387 Mdot
.30122 .22851 Mdot
.30134 .33086 Mdot
.30146 .24474 Mdot
.30158 .30455 Mdot
.3017 .04467 Mdot
.30182 .50515 Mdot
.30194 .01839 Mdot
.30207 .05462 Mdot
.30219 .22653 Mdot
.30231 .11302 Mdot
.30243 .33426 Mdot
.30255 .23508 Mdot
.30267 .30936 Mdot
.30279 .04147 Mdot
.30291 .01965 Mdot
.30303 .04919 Mdot
.30315 .05156 Mdot
.30327 .06801 Mdot
.3034 .47286 Mdot
.30352 .02636 Mdot
.30364 .04525 Mdot
.30376 .0376 Mdot
.30388 .06312 Mdot
.304 .34067 Mdot
.30412 .11166 Mdot
.30424 .17045 Mdot
.30436 .36317 Mdot
.30448 .18498 Mdot
.3046 .34922 Mdot
.30473 .05343 Mdot
.30485 .02751 Mdot
.30497 .03641 Mdot
.30509 .02168 Mdot
.30521 .04464 Mdot
.30533 .02534 Mdot
.30545 .05767 Mdot
.30557 .19373 Mdot
.30569 .10725 Mdot
.30581 .32818 Mdot
.30593 .25004 Mdot
.30605 .30251 Mdot
.30618 .06553 Mdot
.3063 .32536 Mdot
.30642 .26039 Mdot
.30654 .29983 Mdot
.30666 .11918 Mdot
.30678 .31252 Mdot
.3069 .3421 Mdot
.30702 .28353 Mdot
.30714 .07346 Mdot
.30726 .08648 Mdot
.30738 .07905 Mdot
.30751 .21827 Mdot
.30763 .07297 Mdot
.30775 .14445 Mdot
.30787 .09562 Mdot
.30799 .31178 Mdot
.30811 .30695 Mdot
.30823 .30294 Mdot
.30835 .30779 Mdot
.30847 .29491 Mdot
.30859 .30502 Mdot
.30871 .26212 Mdot
.30883 .29955 Mdot
.30896 .12548 Mdot
.30908 .33601 Mdot
.3092 .30147 Mdot
.30932 .05567 Mdot
.30944 .0295 Mdot
.30956 .03372 Mdot
.30968 .02481 Mdot
.3098 .03894 Mdot
.30992 .02006 Mdot
.31004 .0489 Mdot
.31016 .0472 Mdot
.31029 .06654 Mdot
.31041 .43411 Mdot
.31053 .06223 Mdot
.31065 .0212 Mdot
.31077 .0457 Mdot
.31089 .02854 Mdot
.31101 .05935 Mdot
.31113 .23699 Mdot
.31125 .11441 Mdot
.31137 .33473 Mdot
.31149 .23477 Mdot
.31161 .30954 Mdot
.31174 .04236 Mdot
.31186 .02005 Mdot
.31198 .04803 Mdot
.3121 .04225 Mdot
.31222 .06482 Mdot
.31234 .38727 Mdot
.31246 .09479 Mdot
.31258 .2642 Mdot
.3127 .11684 Mdot
.31282 .33168 Mdot
.31294 .23939 Mdot
.31307 .30706 Mdot
.31319 .03575 Mdot
.31331 .05656 Mdot
.31343 .06972 Mdot
.31355 .52001 Mdot
.31367 .04575 Mdot
.31379 .06582 Mdot
.31391 .51355 Mdot
.31403 .02982 Mdot
.31415 .05972 Mdot
.31427 .35963 Mdot
.3144 .10641 Mdot
.31452 .57848 Mdot
.31464 .04907 Mdot
.31476 .0233 Mdot
.31488 .04238 Mdot
.315 .02129 Mdot
.31512 .05448 Mdot
.31524 .12249 Mdot
.31536 .08967 Mdot
.31548 .27797 Mdot
.3156 .29864 Mdot
.31572 .18602 Mdot
.31585 .34931 Mdot
.31597 .05338 Mdot
.31609 .02748 Mdot
.31621 .03645 Mdot
.31633 .02164 Mdot
.31645 .04472 Mdot
.31657 .02557 Mdot
.31669 .0578 Mdot
.31681 .19702 Mdot
.31693 .10791 Mdot
.31705 .32899 Mdot
.31718 .247 Mdot
.3173 .30363 Mdot
.31742 .0524 Mdot
.31754 .05343 Mdot
.31766 .08147 Mdot
.31778 .34366 Mdot
.3179 .28901 Mdot
.31802 .17525 Mdot
.31814 .35852 Mdot
.31826 .09091 Mdot
.31838 .22664 Mdot
.3185 .33913 Mdot
.31863 .2402 Mdot
.31875 .3066 Mdot
.31887 .03615 Mdot
.31899 .09053 Mdot
.31911 .08039 Mdot
.31923 .05 Mdot
.31935 .0264 Mdot
.31947 .03789 Mdot
.31959 .0205 Mdot
.31971 .04737 Mdot
.31983 .03667 Mdot
.31996 .06277 Mdot
.32008 .33048 Mdot
.3202 .11372 Mdot
.32032 .27663 Mdot
.32044 .29853 Mdot
.32056 .18041 Mdot
.32068 .35419 Mdot
.3208 .03948 Mdot
.32092 .26499 Mdot
.32104 .11713 Mdot
.32116 .33238 Mdot
.32129 .23794 Mdot
.32141 .30781 Mdot
.32153 .03627 Mdot
.32165 .02998 Mdot
.32177 .06016 Mdot
.32189 .26533 Mdot
.32201 .117 Mdot
.32213 .33177 Mdot
.32225 .2392 Mdot
.32237 .30716 Mdot
.32249 .03574 Mdot
.32261 .0516 Mdot
.32274 .06809 Mdot
.32286 .47989 Mdot
.32298 .02092 Mdot
.3231 .04747 Mdot
.32322 .06093 Mdot
.32334 .07108 Mdot
.32346 .5464 Mdot
.32358 .21032 Mdot
.3237 .11502 Mdot
.32382 .35156 Mdot
.32394 .28627 Mdot
.32407 .30221 Mdot
.32419 .23386 Mdot
.32431 .31041 Mdot
.32443 .04858 Mdot
.32455 .02435 Mdot
.32467 .04082 Mdot
.32479 .02004 Mdot
.32491 .05213 Mdot
.32503 .08285 Mdot
.32515 .07797 Mdot
.32527 .37313 Mdot
.32539 .05312 Mdot
.32552 .02335 Mdot
.32564 .04125 Mdot
.32576 .02014 Mdot
.32588 .05246 Mdot
.326 .08764 Mdot
.32612 .07943 Mdot
.32624 .15384 Mdot
.32636 .06385 Mdot
.32648 .08126 Mdot
.3266 .07746 Mdot
.32672 .44295 Mdot
.32685 .01759 Mdot
.32697 .04922 Mdot
.32709 .08286 Mdot
.32721 .07797 Mdot
.32733 .3702 Mdot
.32745 .05438 Mdot
.32757 .02238 Mdot
.32769 .04312 Mdot
.32781 .02201 Mdot
.32793 .05525 Mdot
.32805 .13791 Mdot
.32817 .09392 Mdot
.3283 .30673 Mdot
.32842 .3071 Mdot
.32854 .2881 Mdot
.32866 .30225 Mdot
.32878 .23622 Mdot
.3289 .30904 Mdot
.32902 .04048 Mdot
.32914 .01939 Mdot
.32926 .05055 Mdot
.32938 .06555 Mdot
.3295 .07256 Mdot
.32963 .57332 Mdot
.32975 .55288 Mdot
.32987 .22825 Mdot
.32999 .11822 Mdot
.33011 .35405 Mdot
.33023 .29847 Mdot
.33035 .30721 Mdot
.33047 .28243 Mdot
.33059 .30052 Mdot
.33071 .21531 Mdot
.33083 .32353 Mdot
.33096 .18613 Mdot
.33108 .06863 Mdot
.3312 .11351 Mdot
.33132 .08708 Mdot
.33144 .23524 Mdot
.33156 .31067 Mdot
.33168 .05331 Mdot
.3318 .02779 Mdot
.33192 .03602 Mdot
.33204 .02207 Mdot
.33216 .04385 Mdot
.33228 .02345 Mdot
.33241 .05644 Mdot
.33253 .16415 Mdot
.33265 .10065 Mdot
.33277 .32026 Mdot
.33289 .28885 Mdot
.33301 .30275 Mdot
.33313 .24062 Mdot
.33325 .30669 Mdot
.33337 .03589 Mdot
.33349 .07299 Mdot
.33361 .07498 Mdot
.33374 .57919 Mdot
.33386 .03946 Mdot
.33398 .02041 Mdot
.3341 .0541 Mdot
.33422 .12033 Mdot
.33434 .08906 Mdot
.33446 .27056 Mdot
.33458 .2985 Mdot
.3347 .15396 Mdot
.33482 .36928 Mdot
.33494 .30062 Mdot
.33506 .30788 Mdot
.33519 .29309 Mdot
.33531 .30423 Mdot
.33543 .25505 Mdot
.33555 .30104 Mdot
.33567 .08778 Mdot
.33579 .26472 Mdot
.33591 .32094 Mdot
.33603 .32899 Mdot
.33615 .37108 Mdot
.33627 .0534 Mdot
.33639 .02306 Mdot
.33652 .04181 Mdot
.33664 .02049 Mdot
.33676 .05329 Mdot
.33688 .10088 Mdot
.337 .08341 Mdot
.33712 .10956 Mdot
.33724 .25286 Mdot
.33736 .15002 Mdot
.33748 .02114 Mdot
.3376 .0461 Mdot
.33772 .0296 Mdot
.33785 .05985 Mdot
.33797 .2503 Mdot
.33809 .11587 Mdot
.33821 .33417 Mdot
.33833 .2353 Mdot
.33845 .30924 Mdot
.33857 .04087 Mdot
.33869 .01946 Mdot
.33881 .05 Mdot
.33893 .05946 Mdot
.33905 .07061 Mdot
.33917 .53582 Mdot
.3393 .12199 Mdot
.33942 .092 Mdot
.33954 .31346 Mdot
.33966 .3059 Mdot
.33978 .30607 Mdot
.3399 .30637 Mdot
.34002 .30586 Mdot
.34014 .30662 Mdot
.34026 .30534 Mdot
.34038 .30713 Mdot
.3405 .30379 Mdot
.34063 .30776 Mdot
.34075 .29829 Mdot
.34087 .30647 Mdot
.34099 .27579 Mdot
.34111 .29929 Mdot
.34123 .18935 Mdot
.34135 .34632 Mdot
.34147 .08846 Mdot
.34159 .04552 Mdot
.34171 .01994 Mdot
.34183 .05132 Mdot
.34195 .07161 Mdot
.34208 .07448 Mdot
.3422 .58673 Mdot
.34232 .08419 Mdot
.34244 .28702 Mdot
.34256 .3689 Mdot
.34268 .26304 Mdot
.3428 .2995 Mdot
.34292 .13705 Mdot
.34304 .36075 Mdot
.34316 .29076 Mdot
.34328 .22786 Mdot
.34341 .31436 Mdot
.34353 .08734 Mdot
.34365 .04534 Mdot
.34377 .01992 Mdot
.34389 .05115 Mdot
.34401 .06956 Mdot
.34413 .07383 Mdot
.34425 .58657 Mdot
.34437 .04851 Mdot
.34449 .02288 Mdot
.34461 .04301 Mdot
.34473 .0222 Mdot
.34486 .05543 Mdot
.34498 .14182 Mdot
.3451 .09497 Mdot
.34522 .31017 Mdot
.34534 .30737 Mdot
.34546 .29887 Mdot
.34558 .3067 Mdot
.3457 .27809 Mdot
.34582 .29962 Mdot
.34594 .19864 Mdot
.34606 .33791 Mdot
.34619 .18868 Mdot
.34631 .06891 Mdot
.34643 .11502 Mdot
.34655 .08751 Mdot
.34667 .24442 Mdot
.34679 .30566 Mdot
.34691 .03709 Mdot
.34703 .14154 Mdot
.34715 .09501 Mdot
.34727 .31076 Mdot
.34739 .30727 Mdot
.34752 .30046 Mdot
.34764 .30727 Mdot
.34776 .28471 Mdot
.34788 .30114 Mdot
.348 .22377 Mdot
.34812 .31707 Mdot
.34824 .11901 Mdot
.34836 .05531 Mdot
.34848 .03513 Mdot
.3486 .06215 Mdot
.34872 .31241 Mdot
.34884 .1162 Mdot
.34897 .31478 Mdot
.34909 .30457 Mdot
.34921 .30742 Mdot
.34933 .30243 Mdot
.34945 .30774 Mdot
.34957 .2929 Mdot
.34969 .30415 Mdot
.34981 .25429 Mdot
.34993 .30126 Mdot
.35005 .08376 Mdot
.35017 .31364 Mdot
.3503 .32408 Mdot
.35042 .34783 Mdot
.35054 .062 Mdot
.35066 .02062 Mdot
.35078 .05316 Mdot
.3509 .09742 Mdot
.35102 .08238 Mdot
.35114 .0636 Mdot
.35126 .319 Mdot
.35138 .29313 Mdot
.3515 .30447 Mdot
.35162 .25671 Mdot
.35175 .30061 Mdot
.35187 .09666 Mdot
.35199 .20661 Mdot
.35211 .54441 Mdot
.35223 .44255 Mdot
.35235 .06149 Mdot
.35247 .02195 Mdot
.35259 .044 Mdot
.35271 .02362 Mdot
.35283 .05656 Mdot
.35295 .16698 Mdot
.35308 .10133 Mdot
.3532 .32109 Mdot
.35332 .28498 Mdot
.35344 .30143 Mdot
.35356 .22635 Mdot
.35368 .31525 Mdot
.3538 .09721 Mdot
.35392 .04885 Mdot
.35404 .02175 Mdot
.35416 .05491 Mdot
.35428 .13044 Mdot
.35441 .09189 Mdot
.35453 .29682 Mdot
.35465 .3035 Mdot
.35477 .25325 Mdot
.35489 .30157 Mdot
.35501 .07833 Mdot
.35513 .35357 Mdot
.35525 .29674 Mdot
.35537 .25057 Mdot
.35549 .30248 Mdot
.35561 .0643 Mdot
.35573 .32244 Mdot
.35586 .27619 Mdot
.35598 .29949 Mdot
.3561 .19282 Mdot
.35622 .34318 Mdot
.35634 .13077 Mdot
.35646 .0581 Mdot
.35658 .04581 Mdot
.3567 .06605 Mdot
.35682 .41987 Mdot
.35694 .07394 Mdot
.35706 .0262 Mdot
.35719 .05805 Mdot
.35731 .20041 Mdot
.35743 .10857 Mdot
.35755 .32979 Mdot
.35767 .24428 Mdot
.35779 .30476 Mdot
.35791 .04325 Mdot
.35803 .44314 Mdot
.35815 .05424 Mdot
.35827 .02675 Mdot
.35839 .03507 Mdot
.35851 .02331 Mdot
.35864 .04154 Mdot
.35876 .02034 Mdot
.35888 .05297 Mdot
.359 .09555 Mdot
.35912 .08182 Mdot
.35924 .0443 Mdot
.35936 .47343 Mdot
.35948 .02599 Mdot
.3596 .04542 Mdot
.35972 .03883 Mdot
.35984 .06358 Mdot
.35997 .35348 Mdot
.36009 .10832 Mdot
.36021 .30658 Mdot
.36033 .07181 Mdot
.36045 .05787 Mdot
.36057 .07006 Mdot
.36069 .52178 Mdot
.36081 .05143 Mdot
.36093 .06791 Mdot
.36105 .5581 Mdot
.36117 .34394 Mdot
.36129 .11727 Mdot
.36142 .30083 Mdot
.36154 .30508 Mdot
.36166 .26714 Mdot
.36178 .29903 Mdot
.3619 .15078 Mdot
.36202 .36933 Mdot
.36214 .30467 Mdot
.36226 .30432 Mdot
.36238 .30767 Mdot
.3625 .29985 Mdot
.36262 .30707 Mdot
.36275 .28221 Mdot
.36287 .30046 Mdot
.36299 .21446 Mdot
.36311 .32422 Mdot
.36323 .19139 Mdot
.36335 .06936 Mdot
.36347 .1186 Mdot
.36359 .08854 Mdot
.36371 .26243 Mdot
.36383 .2995 Mdot
.36395 .11329 Mdot
.36408 .28308 Mdot
.3642 .36622 Mdot
.36432 .29571 Mdot
.36444 .25174 Mdot
.36456 .30208 Mdot
.36468 .06972 Mdot
.3648 .3385 Mdot
.36492 .23317 Mdot
.36504 .31044 Mdot
.36516 .04785 Mdot
.36528 .0238 Mdot
.3654 .04162 Mdot
.36553 .02052 Mdot
.36565 .05334 Mdot
.36577 .10169 Mdot
.36589 .08365 Mdot
.36601 .12051 Mdot
.36613 .31179 Mdot
.36625 .34353 Mdot
.36637 .26037 Mdot
.36649 .0742 Mdot
.36661 .11585 Mdot
.36673 .08774 Mdot
.36686 .24865 Mdot
.36698 .30376 Mdot
.3671 .04713 Mdot
.36722 .5839 Mdot
.36734 .39381 Mdot
.36746 .04185 Mdot
.36758 .03346 Mdot
.3677 .0244 Mdot
.36782 .03966 Mdot
.36794 .01987 Mdot
.36806 .05009 Mdot
.36818 .05798 Mdot
.36831 .07012 Mdot
.36843 .52486 Mdot
.36855 .0629 Mdot
.36867 .07205 Mdot
.36879 .56294 Mdot
.36891 .60328 Mdot
.36903 .28295 Mdot
.36915 .30244 Mdot
.36927 .23146 Mdot
.36939 .31188 Mdot
.36951 .0607 Mdot
.36964 .03263 Mdot
.36976 .02966 Mdot
.36988 .03084 Mdot
.37 .02915 Mdot
.37012 .03179 Mdot
.37024 .02771 Mdot
.37036 .03412 Mdot
.37048 .02444 Mdot
.3706 .03957 Mdot
.37072 .01989 Mdot
.37084 .04993 Mdot
.37097 .05637 Mdot
.37109 .0696 Mdot
.37121 .51254 Mdot
.37133 .02797 Mdot
.37145 .05897 Mdot
.37157 .33998 Mdot
.37169 .11183 Mdot
.37181 .18331 Mdot
.37193 .35329 Mdot
.37205 .03622 Mdot
.37217 .09041 Mdot
.37229 .08036 Mdot
.37242 .05157 Mdot
.37254 .02756 Mdot
.37266 .03629 Mdot
.37278 .0218 Mdot
.3729 .04438 Mdot
.37302 .02467 Mdot
.37314 .05726 Mdot
.37326 .18367 Mdot
.37338 .10514 Mdot
.3735 .32561 Mdot
.37362 .2616 Mdot
.37375 .29964 Mdot
.37387 .12558 Mdot
.37399 .33633 Mdot
.37411 .30105 Mdot
.37423 .05169 Mdot
.37435 .02672 Mdot
.37447 .03749 Mdot
.37459 .02077 Mdot
.37471 .04665 Mdot
.37483 .03288 Mdot
.37495 .06127 Mdot
.37507 .28889 Mdot
.3752 .11751 Mdot
.37532 .32499 Mdot
.37544 .26516 Mdot
.37556 .29923 Mdot
.37568 .14364 Mdot
.3758 .36696 Mdot
.37592 .30019 Mdot
.37604 .2693 Mdot
.37616 .29893 Mdot
.37628 .16031 Mdot
.3764 .36762 Mdot
.37653 .27336 Mdot
.37665 .29944 Mdot
.37677 .18483 Mdot
.37689 .35035 Mdot
.37701 .04474 Mdot
.37713 .02124 Mdot
.37725 .04563 Mdot
.37737 .02931 Mdot
.37749 .05972 Mdot
.37761 .2468 Mdot
.37773 .11552 Mdot
.37785 .33446 Mdot
.37798 .23502 Mdot
.3781 .30939 Mdot
.37822 .04162 Mdot
.37834 .01971 Mdot
.37846 .04899 Mdot
.37858 .04977 Mdot
.3787 .06741 Mdot
.37882 .45723 Mdot
.37894 .04072 Mdot
.37906 .03728 Mdot
.37918 .02028 Mdot
.37931 .04803 Mdot
.37943 .0408 Mdot
.37955 .0643 Mdot
.37967 .37292 Mdot
.37979 .10144 Mdot
.37991 .47062 Mdot
.38003 .02822 Mdot
.38015 .04442 Mdot
.38027 .03221 Mdot
.38039 .06099 Mdot
.38051 .28177 Mdot
.38064 .11753 Mdot
.38076 .32732 Mdot
.38088 .2541 Mdot
.381 .30124 Mdot
.38112 .08582 Mdot
.38124 .28891 Mdot
.38136 .36712 Mdot
.38148 .22578 Mdot
.3816 .3149 Mdot
.38172 .09047 Mdot
.38184 .0465 Mdot
.38196 .02019 Mdot
.38209 .05244 Mdot
.38221 .08691 Mdot
.38233 .07921 Mdot
.38245 .18458 Mdot
.38257 .06904 Mdot
.38269 .12073 Mdot
.38281 .08914 Mdot
.38293 .27102 Mdot
.38305 .29848 Mdot
.38317 .15606 Mdot
.38329 .36894 Mdot
.38342 .2948 Mdot
.38354 .30588 Mdot
.38366 .26831 Mdot
.38378 .29898 Mdot
.3839 .15643 Mdot
.38402 .36885 Mdot
.38414 .29345 Mdot
.38426 .30528 Mdot
.38438 .26277 Mdot
.3845 .29945 Mdot
.38462 .1289 Mdot
.38474 .34556 Mdot
.38487 .29133 Mdot
.38499 .08895 Mdot
.38511 .25225 Mdot
.38523 .18873 Mdot
.38535 .16492 Mdot
.38547 .10063 Mdot
.38559 .3199 Mdot
.38571 .29046 Mdot
.38583 .30337 Mdot
.38595 .24661 Mdot
.38607 .30395 Mdot
.3862 .0486 Mdot
.38632 .5604 Mdot
.38644 .5946 Mdot
.38656 .0373 Mdot
.38668 .14892 Mdot
.3868 .09696 Mdot
.38692 .31516 Mdot
.38704 .30394 Mdot
.38716 .30768 Mdot
.38728 .3002 Mdot
.3874 .30719 Mdot
.38753 .2837 Mdot
.38765 .30085 Mdot
.38777 .22003 Mdot
.38789 .31984 Mdot
.38801 .15085 Mdot
.38813 .06262 Mdot
.38825 .07083 Mdot
.38837 .07421 Mdot
.38849 .58739 Mdot
.38861 .05679 Mdot
.38873 .29321 Mdot
.38885 .30219 Mdot
.38898 .24124 Mdot
.3891 .30639 Mdot
.38922 .03628 Mdot
.38934 .09845 Mdot
.38946 .08278 Mdot
.38958 .08788 Mdot
.3897 .27704 Mdot
.38982 .36787 Mdot
.38994 .29891 Mdot
.39006 .26436 Mdot
.39018 .29925 Mdot
.39031 .13614 Mdot
.39043 .35949 Mdot
.39055 .28977 Mdot
.39067 .22048 Mdot
.39079 .31965 Mdot
.39091 .14942 Mdot
.39103 .06233 Mdot
.39115 .06902 Mdot
.39127 .07364 Mdot
.39139 .58526 Mdot
.39151 .18715 Mdot
.39163 .06795 Mdot
.39176 .10365 Mdot
.39188 .0842 Mdot
.392 .1428 Mdot
.39212 .36519 Mdot
.39224 .29656 Mdot
.39236 .25453 Mdot
.39248 .30121 Mdot
.3926 .08397 Mdot
.39272 .31133 Mdot
.39284 .32847 Mdot
.39296 .36204 Mdot
.39309 .05705 Mdot
.39321 .02069 Mdot
.39333 .047 Mdot
.39345 .03432 Mdot
.39357 .06185 Mdot
.39369 .30501 Mdot
.39381 .11683 Mdot
.39393 .31892 Mdot
.39405 .29464 Mdot
.39417 .30513 Mdot
.39429 .26266 Mdot
.39441 .29947 Mdot
.39454 .12831 Mdot
.39466 .34405 Mdot
.39478 .29254 Mdot
.3949 .07091 Mdot
.39502 .34261 Mdot
.39514 .24297 Mdot
.39526 .30527 Mdot
.39538 .04055 Mdot
.3955 .31476 Mdot
.39562 .11611 Mdot
.39574 .3135 Mdot
.39587 .30593 Mdot
.39599 .30602 Mdot
.39611 .30644 Mdot
.39623 .30573 Mdot
.39635 .30678 Mdot
.39647 .30496 Mdot
.39659 .30738 Mdot
.39671 .30252 Mdot
.39683 .30775 Mdot
.39695 .29327 Mdot
.39707 .30431 Mdot
.3972 .25574 Mdot
.39732 .30086 Mdot
.39744 .09142 Mdot
.39756 .22747 Mdot
.39768 .34289 Mdot
.3978 .24942 Mdot
.39792 .30267 Mdot
.39804 .06403 Mdot
.39816 .32184 Mdot
.39828 .27945 Mdot
.3984 .30002 Mdot
.39852 .20563 Mdot
.39865 .33168 Mdot
.39877 .21676 Mdot
.39889 .07219 Mdot
.39901 .1339 Mdot
.39913 .0928 Mdot
.39925 .30162 Mdot
.39937 .30542 Mdot
.39949 .27012 Mdot
.39961 .29895 Mdot
.39973 .16476 Mdot
.39985 .36551 Mdot
.39998 .23444 Mdot
.4001 .30949 Mdot
.40022 .0417 Mdot
.40034 .01974 Mdot
.40046 .04889 Mdot
.40058 .04891 Mdot
.4007 .06712 Mdot
.40082 .44967 Mdot
.40094 .04796 Mdot
.40106 .03185 Mdot
.40118 .02657 Mdot
.4013 .03602 Mdot
.40143 .0222 Mdot
.40155 .0436 Mdot
.40167 .02293 Mdot
.40179 .05604 Mdot
.40191 .15521 Mdot
.40203 .09844 Mdot
.40215 .31731 Mdot
.40227 .29952 Mdot
.40239 .30712 Mdot
.40251 .28244 Mdot
.40263 .30052 Mdot
.40276 .21531 Mdot
.40288 .32353 Mdot
.403 .1861 Mdot
.40312 .06863 Mdot
.40324 .11348 Mdot
.40336 .08707 Mdot
.40348 .23505 Mdot
.4036 .31079 Mdot
.40372 .05427 Mdot
.40384 .02846 Mdot
.40396 .0351 Mdot
.40408 .02307 Mdot
.40421 .04198 Mdot
.40433 .02068 Mdot
.40445 .05362 Mdot
.40457 .10664 Mdot
.40469 .08511 Mdot
.40481 .18009 Mdot
.40493 .35596 Mdot
.40505 .05275 Mdot
.40517 .1004 Mdot
.40529 .2086 Mdot
.40541 .42219 Mdot
.40554 .02742 Mdot
.40566 .04412 Mdot
.40578 .02924 Mdot
.4059 .05969 Mdot
.40602 .24629 Mdot
.40614 .11547 Mdot
.40626 .33449 Mdot
.40638 .23499 Mdot
.4065 .30941 Mdot
.40662 .04171 Mdot
.40674 .01974 Mdot
.40687 .04888 Mdot
.40699 .04885 Mdot
.40711 .0671 Mdot
.40723 .44906 Mdot
.40735 .04854 Mdot
.40747 .03138 Mdot
.40759 .0273 Mdot
.40771 .03483 Mdot
.40783 .02355 Mdot
.40795 .04113 Mdot
.40807 .0201 Mdot
.40819 .05235 Mdot
.40832 .08597 Mdot
.40844 .07892 Mdot
.40856 .22766 Mdot
.40868 .07372 Mdot
.4088 .14519 Mdot
.40892 .09581 Mdot
.40904 .31226 Mdot
.40916 .30673 Mdot
.40928 .30395 Mdot
.4094 .30774 Mdot
.40952 .29884 Mdot
.40965 .30669 Mdot
.40977 .27802 Mdot
.40989 .2996 Mdot
.41001 .19835 Mdot
.41013 .33816 Mdot
.41025 .18651 Mdot
.41037 .06861 Mdot
.41049 .11284 Mdot
.41061 .08688 Mdot
.41073 .2308 Mdot
.41085 .3135 Mdot
.41097 .08127 Mdot
.4111 .04293 Mdot
.41122 .02024 Mdot
.41134 .04827 Mdot
.41146 .04226 Mdot
.41158 .06482 Mdot
.4117 .38729 Mdot
.41182 .09477 Mdot
.41194 .26381 Mdot
.41206 .11682 Mdot
.41218 .33176 Mdot
.4123 .23921 Mdot
.41243 .30715 Mdot
.41255 .03574 Mdot
.41267 .05186 Mdot
.41279 .06817 Mdot
.41291 .48208 Mdot
.41303 .01946 Mdot
.41315 .04805 Mdot
.41327 .06984 Mdot
.41339 .07393 Mdot
.41351 .58699 Mdot
.41363 .03627 Mdot
.41376 .05333 Mdot
.41388 .06866 Mdot
.414 .4946 Mdot
.41412 .01474 Mdot
.41424 .05105 Mdot
.41436 .13546 Mdot
.41448 .09327 Mdot
.4146 .30419 Mdot
.41472 .30637 Mdot
.41484 .27924 Mdot
.41496 .29981 Mdot
.41508 .20308 Mdot
.41521 .33392 Mdot
.41533 .21201 Mdot
.41545 .07173 Mdot
.41557 .13206 Mdot
.41569 .09229 Mdot
.41581 .29893 Mdot
.41593 .30434 Mdot
.41605 .26062 Mdot
.41617 .29979 Mdot
.41629 .11753 Mdot
.41641 .30497 Mdot
.41654 .35563 Mdot
.41666 .03805 Mdot
.41678 .02144 Mdot
.4169 .05523 Mdot
.41702 .1431 Mdot
.41714 .09531 Mdot
.41726 .31112 Mdot
.41738 .30718 Mdot
.4175 .30138 Mdot
.41762 .30753 Mdot
.41774 .28851 Mdot
.41786 .3024 Mdot
.41799 .23781 Mdot
.41811 .30816 Mdot
.41823 .03728 Mdot
.41835 .02287 Mdot
.41847 .05637 Mdot
.41859 .16877 Mdot
.41871 .10175 Mdot
.41883 .3216 Mdot
.41895 .28245 Mdot
.41907 .30071 Mdot
.41919 .21699 Mdot
.41932 .32219 Mdot
.41944 .17461 Mdot
.41956 .06689 Mdot
.41968 .10075 Mdot
.4198 .08335 Mdot
.41992 .10468 Mdot
.42004 .22517 Mdot
.42016 .3217 Mdot
.42028 .2842 Mdot
.4204 .3012 Mdot
.42052 .22353 Mdot
.42064 .31725 Mdot
.42077 .12105 Mdot
.42089 .05584 Mdot
.42101 .03696 Mdot
.42113 .06286 Mdot
.42125 .33202 Mdot
.42137 .11344 Mdot
.42149 .26795 Mdot
.42161 .29869 Mdot
.42173 .14127 Mdot
.42185 .36523 Mdot
.42197 .29668 Mdot
.4221 .25499 Mdot
.42222 .30109 Mdot
.42234 .08638 Mdot
.42246 .28196 Mdot
.42258 .37096 Mdot
.4227 .30373 Mdot
.42282 .30669 Mdot
.42294 .30545 Mdot
.42306 .30703 Mdot
.42318 .30415 Mdot
.4233 .30769 Mdot
.42343 .29966 Mdot
.42355 .307 Mdot
.42367 .28145 Mdot
.42379 .30028 Mdot
.42391 .2116 Mdot
.42403 .32657 Mdot
.42415 .20591 Mdot
.42427 .07112 Mdot
.42439 .12954 Mdot
.42451 .0916 Mdot
.42463 .29463 Mdot
.42475 .30265 Mdot
.42488 .2457 Mdot
.425 .30433 Mdot
.42512 .04551 Mdot
.42524 .53799 Mdot
.42536 .13684 Mdot
.42548 .09656 Mdot
.4256 .32108 Mdot
.42572 .28485 Mdot
.42584 .30139 Mdot
.42596 .22589 Mdot
.42608 .31557 Mdot
.42621 .10104 Mdot
.42633 .0501 Mdot
.42645 .02321 Mdot
.42657 .05621 Mdot
.42669 .15823 Mdot
.42681 .09919 Mdot
.42693 .31839 Mdot
.42705 .29626 Mdot
.42717 .30582 Mdot
.42729 .26909 Mdot
.42741 .29896 Mdot
.42753 .16009 Mdot
.42766 .36771 Mdot
.42778 .27485 Mdot
.4279 .2996 Mdot
.42802 .19106 Mdot
.42814 .34477 Mdot
.42826 .10936 Mdot
.42838 .05244 Mdot
.4285 .02724 Mdot
.42862 .05868 Mdot
.42874 .2184 Mdot
.42886 .11175 Mdot
.42899 .33324 Mdot
.42911 .23625 Mdot
.42923 .30872 Mdot
.42935 .03868 Mdot
.42947 .01997 Mdot
.42959 .05337 Mdot
.42971 .10673 Mdot
.42983 .08514 Mdot
.42995 .1811 Mdot
.43007 .35512 Mdot
.43019 .04491 Mdot
.43032 .5224 Mdot
.43044 .05325 Mdot
.43056 .06857 Mdot
.43068 .56967 Mdot
.4308 .50211 Mdot
.43092 .01472 Mdot
.43104 .0516 Mdot
.43116 .1509 Mdot
.43128 .09735 Mdot
.4314 .31559 Mdot
.43152 .30326 Mdot
.43164 .3078 Mdot
.43177 .29765 Mdot
.43189 .30621 Mdot
.43201 .27315 Mdot
.43213 .29906 Mdot
.43225 .17828 Mdot
.43237 .35596 Mdot
.43249 .05368 Mdot
.43261 .16745 Mdot
.43273 .36495 Mdot
.43285 .22243 Mdot
.43297 .31726 Mdot
.4331 .11831 Mdot
.43322 .05512 Mdot
.43334 .03452 Mdot
.43346 .06191 Mdot
.43358 .30572 Mdot
.4337 .11678 Mdot
.43382 .3186 Mdot
.43394 .2958 Mdot
.43406 .30563 Mdot
.43418 .26727 Mdot
.4343 .29903 Mdot
.43442 .15147 Mdot
.43455 .36937 Mdot
.43467 .30421 Mdot
.43479 .30588 Mdot
.43491 .30673 Mdot
.43503 .30508 Mdot
.43515 .30731 Mdot
.43527 .30292 Mdot
.43539 .30779 Mdot
.43551 .2949 Mdot
.43563 .30502 Mdot
.43575 .26208 Mdot
.43588 .29955 Mdot
.436 .12528 Mdot
.43612 .33539 Mdot
.43624 .30232 Mdot
.43636 .06494 Mdot
.43648 .03517 Mdot
.4366 .02658 Mdot
.43672 .03586 Mdot
.43684 .02238 Mdot
.43696 .04324 Mdot
.43708 .02229 Mdot
.4372 .05551 Mdot
.43733 .14342 Mdot
.43745 .09539 Mdot
.43757 .31134 Mdot
.43769 .30711 Mdot
.43781 .30191 Mdot
.43793 .30765 Mdot
.43805 .29071 Mdot
.43817 .30325 Mdot
.43829 .24599 Mdot
.43841 .30421 Mdot
.43853 .04648 Mdot
.43866 .56977 Mdot
.43878 .50234 Mdot
.4389 .01474 Mdot
.43902 .05167 Mdot
.43914 .15262 Mdot
.43926 .09779 Mdot
.43938 .31633 Mdot
.4395 .30184 Mdot
.43962 .30774 Mdot
.43974 .29201 Mdot
.43986 .30378 Mdot
.43999 .2509 Mdot
.44011 .30233 Mdot
.44023 .06671 Mdot
.44035 .32852 Mdot
.44047 .24597 Mdot
.44059 .30405 Mdot
.44071 .04854 Mdot
.44083 .56401 Mdot
.44095 .60257 Mdot
.44107 .29347 Mdot
.44119 .30677 Mdot
.44131 .27426 Mdot
.44144 .29914 Mdot
.44156 .18305 Mdot
.44168 .35192 Mdot
.4418 .03697 Mdot
.44192 .02564 Mdot
.44204 .05808 Mdot
.44216 .21058 Mdot
.44228 .11044 Mdot
.4424 .33194 Mdot
.44252 .23855 Mdot
.44264 .30749 Mdot
.44277 .03589 Mdot
.44289 .03823 Mdot
.44301 .06343 Mdot
.44313 .35524 Mdot
.44325 .10779 Mdot
.44337 .43399 Mdot
.44349 .02128 Mdot
.44361 .04733 Mdot
.44373 .05405 Mdot
.44385 .06884 Mdot
.44397 .49423 Mdot
.44409 .01476 Mdot
.44422 .05096 Mdot
.44434 .13306 Mdot
.44446 .09262 Mdot
.44458 .30107 Mdot
.4447 .3052 Mdot
.44482 .26816 Mdot
.44494 .29899 Mdot
.44506 .15566 Mdot
.44518 .36902 Mdot
.4453 .2961 Mdot
.44542 .30644 Mdot
.44555 .27373 Mdot
.44567 .2991 Mdot
.44579 .18079 Mdot
.44591 .35386 Mdot
.44603 .03803 Mdot
.44615 .19024 Mdot
.44627 .10667 Mdot
.44639 .32778 Mdot
.44651 .25167 Mdot
.44663 .30197 Mdot
.44675 .0734 Mdot
.44688 .3514 Mdot
.447 .2839 Mdot
.44712 .30144 Mdot
.44724 .22501 Mdot
.44736 .31618 Mdot
.44748 .10833 Mdot
.4476 .05233 Mdot
.44772 .02709 Mdot
.44784 .0586 Mdot
.44796 .21645 Mdot
.44808 .11144 Mdot
.4482 .33294 Mdot
.44833 .23669 Mdot
.44845 .30848 Mdot
.44857 .03787 Mdot
.44869 .02117 Mdot
.44881 .05495 Mdot
.44893 .13721 Mdot
.44905 .09373 Mdot
.44917 .30602 Mdot
.44929 .30693 Mdot
.44941 .28566 Mdot
.44953 .30142 Mdot
.44966 .22722 Mdot
.44978 .31465 Mdot
.4499 .09026 Mdot
.45002 .04642 Mdot
.45014 .02016 Mdot
.45026 .05236 Mdot
.45038 .08571 Mdot
.4505 .07884 Mdot
.45062 .23982 Mdot
.45074 .07442 Mdot
.45086 .1418 Mdot
.45098 .09492 Mdot
.45111 .30985 Mdot
.45123 .3074 Mdot
.45135 .29797 Mdot
.45147 .30633 Mdot
.45159 .27437 Mdot
.45171 .29915 Mdot
.45183 .18347 Mdot
.45195 .35155 Mdot
.45207 .03814 Mdot
.45219 .0212 Mdot
.45231 .05499 Mdot
.45244 .13798 Mdot
.45256 .09394 Mdot
.45268 .30682 Mdot
.4528 .30712 Mdot
.45292 .28838 Mdot
.45304 .30235 Mdot
.45316 .23727 Mdot
.45328 .30846 Mdot
.4534 .03816 Mdot
.45352 .02062 Mdot
.45364 .05434 Mdot
.45376 .12482 Mdot
.45389 .09033 Mdot
.45401 .28474 Mdot
.45413 .29968 Mdot
.45425 .21156 Mdot
.45437 .32662 Mdot
.45449 .20615 Mdot
.45461 .07115 Mdot
.45473 .12968 Mdot
.45485 .09164 Mdot
.45497 .29488 Mdot
.45509 .30275 Mdot
.45522 .24658 Mdot
.45534 .30397 Mdot
.45546 .04843 Mdot
.45558 .56982 Mdot
.4557 .49428 Mdot
.45582 .07082 Mdot
.45594 .07488 Mdot
.45606 .32262 Mdot
.45618 .06906 Mdot
.4563 .03736 Mdot
.45642 .06299 Mdot
.45655 .33443 Mdot
.45667 .11298 Mdot
.45679 .25033 Mdot
.45691 .30308 Mdot
.45703 .05313 Mdot
.45715 .10517 Mdot
.45727 .22799 Mdot
.45739 .32905 Mdot
.45751 .25036 Mdot
.45763 .3024 Mdot
.45775 .0671 Mdot
.45787 .32967 Mdot
.458 .24183 Mdot
.45812 .30588 Mdot
.45824 .0378 Mdot
.45836 .178 Mdot
.45848 .10402 Mdot
.4586 .32451 Mdot
.45872 .26717 Mdot
.45884 .2991 Mdot
.45896 .15337 Mdot
.45908 .36933 Mdot
.4592 .30175 Mdot
.45933 .3079 Mdot
.45945 .29784 Mdot
.45957 .30629 Mdot
.45969 .27393 Mdot
.45981 .29911 Mdot
.45993 .18163 Mdot
.46005 .35314 Mdot
.46017 .03615 Mdot
.46029 .08583 Mdot
.46041 .07896 Mdot
.46053 .19641 Mdot
.46065 .07063 Mdot
.46078 .13233 Mdot
.4609 .09237 Mdot
.46102 .29938 Mdot
.46114 .30452 Mdot
.46126 .26219 Mdot
.46138 .29953 Mdot
.4615 .1258 Mdot
.46162 .33701 Mdot
.46174 .30016 Mdot
.46186 .04454 Mdot
.46198 .02146 Mdot
.46211 .04526 Mdot
.46223 .0279 Mdot
.46235 .05904 Mdot
.46247 .22886 Mdot
.46259 .11334 Mdot
.46271 .33439 Mdot
.46283 .23498 Mdot
.46295 .30942 Mdot
.46307 .04174 Mdot
.46319 .01976 Mdot
.46331 .04883 Mdot
.46344 .04847 Mdot
.46356 .06697 Mdot
.46368 .44565 Mdot
.4638 .05175 Mdot
.46392 .02877 Mdot
.46404 .03159 Mdot
.46416 .02805 Mdot
.46428 .03355 Mdot
.4644 .02519 Mdot
.46452 .03829 Mdot
.46464 .02035 Mdot
.46476 .04781 Mdot
.46489 .03933 Mdot
.46501 .06376 Mdot
.46513 .3581 Mdot
.46525 .10689 Mdot
.46537 .55394 Mdot
.46549 .54139 Mdot
.46561 .12889 Mdot
.46573 .09417 Mdot
.46585 .31768 Mdot
.46597 .29843 Mdot
.46609 .30672 Mdot
.46622 .27793 Mdot
.46634 .29959 Mdot
.46646 .19798 Mdot
.46658 .33849 Mdot
.4667 .18363 Mdot
.46682 .06819 Mdot
.46694 .10982 Mdot
.46706 .08601 Mdot
.46718 .20778 Mdot
.4673 .33144 Mdot
.46742 .22127 Mdot
.46754 .07259 Mdot
.46767 .13488 Mdot
.46779 .09306 Mdot
.46791 .30291 Mdot
.46803 .30591 Mdot
.46815 .2747 Mdot
.46827 .29918 Mdot
.46839 .18478 Mdot
.46851 .3504 Mdot
.46863 .04439 Mdot
.46875 .02101 Mdot
.46887 .04604 Mdot
.469 .03102 Mdot
.46912 .06048 Mdot
.46924 .2675 Mdot
.46936 .11711 Mdot
.46948 .33128 Mdot
.4696 .24037 Mdot
.46972 .30657 Mdot
.46984 .03616 Mdot
.46996 .09109 Mdot
.47008 .08057 Mdot
.4702 .04324 Mdot
.47032 .02124 Mdot
.47045 .04562 Mdot
.47057 .02923 Mdot
.47069 .05968 Mdot
.47081 .24582 Mdot
.47093 .11542 Mdot
.47105 .33452 Mdot
.47117 .23497 Mdot
.47129 .30942 Mdot
.47141 .04178 Mdot
.47153 .01977 Mdot
.47165 .04878 Mdot
.47178 .04805 Mdot
.4719 .06683 Mdot
.47202 .4419 Mdot
.47214 .05524 Mdot
.47226 .02594 Mdot
.47238 .0365 Mdot
.4725 .02177 Mdot
.47262 .04443 Mdot
.47274 .0248 Mdot
.47286 .05734 Mdot
.47298 .18572 Mdot
.47311 .10558 Mdot
.47323 .32614 Mdot
.47335 .259 Mdot
.47347 .30008 Mdot
.47359 .11188 Mdot
.47371 .27516 Mdot
.47383 .34235 Mdot
.47395 .29549 Mdot
.47407 .04157 Mdot
.47419 .36336 Mdot
.47431 .10527 Mdot
.47443 .58273 Mdot
.47456 .48937 Mdot
.47468 .05513 Mdot
.4748 .06933 Mdot
.47492 .57672 Mdot
.47504 .59252 Mdot
.47516 .12003 Mdot
.47528 .05454 Mdot
.4754 .03194 Mdot
.47552 .06085 Mdot
.47564 .27655 Mdot
.47576 .11744 Mdot
.47589 .3289 Mdot
.47601 .24776 Mdot
.47613 .30334 Mdot
.47625 .05544 Mdot
.47637 .23766 Mdot
.47649 .30921 Mdot
.47661 .04307 Mdot
.47673 .02045 Mdot
.47685 .04713 Mdot
.47697 .03652 Mdot
.47709 .06271 Mdot
.47721 .32892 Mdot
.47734 .11399 Mdot
.47746 .2839 Mdot
.47758 .29949 Mdot
.4777 .20838 Mdot
.47782 .3293 Mdot
.47794 .2154 Mdot
.47806 .07208 Mdot
.47818 .13367 Mdot
.4783 .09273 Mdot
.47842 .30131 Mdot
.47854 .3053 Mdot
.47867 .26902 Mdot
.47879 .29896 Mdot
.47891 .15968 Mdot
.47903 .36787 Mdot
.47915 .27744 Mdot
.47927 .3 Mdot
.47939 .20147 Mdot
.47951 .33536 Mdot
.47963 .20581 Mdot
.47975 .07107 Mdot
.47987 .12881 Mdot
.48 .0914 Mdot
.48012 .29321 Mdot
.48024 .30213 Mdot
.48036 .24084 Mdot
.48048 .30659 Mdot
.4806 .036 Mdot
.48072 .08081 Mdot
.48084 .07741 Mdot
.48096 .42368 Mdot
.48108 .02657 Mdot
.4812 .04459 Mdot
.48132 .03157 Mdot
.48145 .06072 Mdot
.48157 .27432 Mdot
.48169 .11738 Mdot
.48181 .32953 Mdot
.48193 .24553 Mdot
.48205 .30423 Mdot
.48217 .0471 Mdot
.48229 .5834 Mdot
.48241 .44753 Mdot
.48253 .0159 Mdot
.48265 .05041 Mdot
.48278 .1075 Mdot
.4829 .08537 Mdot
.48302 .18956 Mdot
.48314 .34777 Mdot
.48326 .07178 Mdot
.48338 .03836 Mdot
.4835 .02329 Mdot
.48362 .04152 Mdot
.48374 .02032 Mdot
.48386 .05292 Mdot
.48398 .09484 Mdot
.4841 .08161 Mdot
.48423 .03933 Mdot
.48435 .24665 Mdot
.48447 .11565 Mdot
.48459 .33502 Mdot
.48471 .23465 Mdot
.48483 .3096 Mdot
.48495 .0427 Mdot
.48507 .02023 Mdot
.48519 .0476 Mdot
.48531 .03937 Mdot
.48543 .06378 Mdot
.48556 .35852 Mdot
.48568 .10676 Mdot
.4858 .56281 Mdot
.48592 .60309 Mdot
.48604 .27913 Mdot
.48616 .30129 Mdot
.48628 .21672 Mdot
.4864 .3224 Mdot
.48652 .17642 Mdot
.48664 .06717 Mdot
.48676 .10288 Mdot
.48688 .08398 Mdot
.48701 .13311 Mdot
.48713 .35159 Mdot
.48725 .28828 Mdot
.48737 .15857 Mdot
.48749 .36831 Mdot
.48761 .28476 Mdot
.48773 .30186 Mdot
.48785 .22934 Mdot
.48797 .31324 Mdot
.48809 .07442 Mdot
.48821 .03991 Mdot
.48834 .02196 Mdot
.48846 .04404 Mdot
.48858 .02383 Mdot
.4887 .05671 Mdot
.48882 .17045 Mdot
.48894 .10215 Mdot
.48906 .32206 Mdot
.48918 .28008 Mdot
.4893 .30016 Mdot
.48942 .20807 Mdot
.48954 .32956 Mdot
.48967 .21583 Mdot
.48979 .07212 Mdot
.48991 .13378 Mdot
.49003 .09276 Mdot
.49015 .30147 Mdot
.49027 .30536 Mdot
.49039 .26957 Mdot
.49051 .29896 Mdot
.49063 .16226 Mdot
.49075 .36678 Mdot
.49087 .25855 Mdot
.49099 .30016 Mdot
.49112 .11346 Mdot
.49124 .28405 Mdot
.49136 .36762 Mdot
.49148 .2983 Mdot
.4916 .2619 Mdot
.49172 .29957 Mdot
.49184 .1234 Mdot
.49196 .32914 Mdot
.49208 .31175 Mdot
.4922 .21986 Mdot
.49232 .07256 Mdot
.49245 .13613 Mdot
.49257 .0934 Mdot
.49269 .30444 Mdot
.49281 .30645 Mdot
.49293 .28012 Mdot
.49305 .29998 Mdot
.49317 .20647 Mdot
.49329 .33095 Mdot
.49341 .21703 Mdot
.49353 .07222 Mdot
.49365 .13403 Mdot
.49377 .09283 Mdot
.4939 .3018 Mdot
.49402 .30549 Mdot
.49414 .27075 Mdot
.49426 .29896 Mdot
.49438 .16765 Mdot
.4945 .3638 Mdot
.49462 .19955 Mdot
.49474 .33606 Mdot
.49486 .1994 Mdot
.49498 .07032 Mdot
.4951 .12446 Mdot
.49523 .09019 Mdot
.49535 .28294 Mdot
.49547 .29932 Mdot
.49559 .20502 Mdot
.49571 .33223 Mdot
.49583 .21619 Mdot
.49595 .07214 Mdot
.49607 .13369 Mdot
.49619 .09274 Mdot
.49631 .30133 Mdot
.49643 .30531 Mdot
.49656 .2691 Mdot
.49668 .29896 Mdot
.4968 .16007 Mdot
.49692 .36772 Mdot
.49704 .27498 Mdot
.49716 .29962 Mdot
.49728 .19158 Mdot
.4974 .3443 Mdot
.49752 .11578 Mdot
.49764 .05426 Mdot
.49776 .03179 Mdot
.49788 .06079 Mdot
.49801 .27481 Mdot
.49813 .1174 Mdot
.49825 .32939 Mdot
.49837 .246 Mdot
.49849 .30403 Mdot
.49861 .04871 Mdot
.49873 .55225 Mdot
.49885 .52533 Mdot
.49897 .04759 Mdot
.49909 .06648 Mdot
.49921 .52955 Mdot
.49934 .08441 Mdot
.49946 .0796 Mdot
.49958 .10599 Mdot
.4997 .23213 Mdot
.49982 .34461 Mdot
.49994 .25571 Mdot
.50006 .30078 Mdot
.50018 .0963 Mdot
.5003 .20679 Mdot
.50042 .52133 Mdot
.50054 .21922 Mdot
.50066 .11642 Mdot
.50079 .35227 Mdot
.50091 .28987 Mdot
.50103 .30358 Mdot
.50115 .24745 Mdot
.50127 .30361 Mdot
.50139 .05172 Mdot
.50151 .03706 Mdot
.50163 .02158 Mdot
.50175 .05534 Mdot
.50187 .14531 Mdot
.50199 .09589 Mdot
.50212 .31258 Mdot
.50224 .30655 Mdot
.50236 .30458 Mdot
.50248 .30757 Mdot
.5026 .30116 Mdot
.50272 .30748 Mdot
.50284 .28768 Mdot
.50296 .3021 Mdot
.50308 .23471 Mdot
.5032 .30991 Mdot
.50332 .04521 Mdot
.50344 .02186 Mdot
.50357 .04458 Mdot
.50369 .02573 Mdot
.50381 .05789 Mdot
.50393 .19933 Mdot
.50405 .10836 Mdot
.50417 .32954 Mdot
.50429 .2451 Mdot
.50441 .30441 Mdot
.50453 .0457 Mdot
.50465 .54476 Mdot
.50477 .19365 Mdot
.5049 .11155 Mdot
.50502 .34683 Mdot
.50514 .26239 Mdot
.50526 .29955 Mdot
.50538 .13191 Mdot
.5055 .35231 Mdot
.50562 .28812 Mdot
.50574 .16595 Mdot
.50586 .36494 Mdot
.50598 .22302 Mdot
.5061 .31684 Mdot
.50623 .11334 Mdot
.50635 .05377 Mdot
.50647 .03053 Mdot
.50659 .06024 Mdot
.50671 .25995 Mdot
.50683 .11666 Mdot
.50695 .33283 Mdot
.50707 .2371 Mdot
.50719 .30825 Mdot
.50731 .03722 Mdot
.50743 .02308 Mdot
.50755 .05652 Mdot
.50768 .17227 Mdot
.5078 .10257 Mdot
.50792 .32256 Mdot
.50804 .27744 Mdot
.50816 .29967 Mdot
.50828 .19786 Mdot
.5084 .3386 Mdot
.50852 .18267 Mdot
.50864 .06805 Mdot
.50876 .10878 Mdot
.50888 .08571 Mdot
.50901 .19867 Mdot
.50913 .33955 Mdot
.50925 .17718 Mdot
.50937 .0672 Mdot
.50949 .10259 Mdot
.50961 .08389 Mdot
.50973 .12937 Mdot
.50985 .34281 Mdot
.50997 .29369 Mdot
.51009 .05709 Mdot
.51021 .27934 Mdot
.51033 .29881 Mdot
.51046 .19177 Mdot
.51058 .34415 Mdot
.5107 .1179 Mdot
.51082 .05484 Mdot
.51094 .03349 Mdot
.51106 .0615 Mdot
.51118 .29431 Mdot
.5113 .11738 Mdot
.51142 .32312 Mdot
.51154 .27497 Mdot
.51166 .29934 Mdot
.51179 .18792 Mdot
.51191 .34761 Mdot
.51203 .072 Mdot
.51215 .03846 Mdot
.51227 .0232 Mdot
.51239 .0417 Mdot
.51251 .02044 Mdot
.51263 .05319 Mdot
.51275 .09912 Mdot
.51287 .08289 Mdot
.51299 .0856 Mdot
.51312 .30504 Mdot
.51324 .34067 Mdot
.51336 .29684 Mdot
.51348 .07233 Mdot
.5136 .0672 Mdot
.51372 .07306 Mdot
.51384 .57921 Mdot
.51396 .60326 Mdot
.51408 .29386 Mdot
.5142 .30694 Mdot
.51432 .27605 Mdot
.51444 .29933 Mdot
.51457 .1905 Mdot
.51469 .34528 Mdot
.51481 .10237 Mdot
.51493 .05031 Mdot
.51505 .02346 Mdot
.51517 .05639 Mdot
.51529 .16242 Mdot
.51541 .10022 Mdot
.51553 .31974 Mdot
.51565 .29113 Mdot
.51577 .30364 Mdot
.5159 .24913 Mdot
.51602 .30296 Mdot
.51614 .05863 Mdot
.51626 .30039 Mdot
.51638 .30499 Mdot
.5165 .26618 Mdot
.51662 .29909 Mdot
.51674 .14605 Mdot
.51686 .3682 Mdot
.51698 .30312 Mdot
.5171 .28356 Mdot
.51722 .30075 Mdot
.51735 .21898 Mdot
.51747 .32064 Mdot
.51759 .15939 Mdot
.51771 .06426 Mdot
.51783 .0818 Mdot
.51795 .07762 Mdot
.51807 .42353 Mdot
.51819 .02665 Mdot
.51831 .04455 Mdot
.51843 .03134 Mdot
.51855 .06062 Mdot
.51868 .2716 Mdot
.5188 .11729 Mdot
.51892 .33026 Mdot
.51904 .24318 Mdot
.51916 .30525 Mdot
.51928 .04045 Mdot
.5194 .30998 Mdot
.51952 .11658 Mdot
.51964 .31679 Mdot
.51976 .30098 Mdot
.51988 .30756 Mdot
.52 .28849 Mdot
.52013 .3024 Mdot
.52025 .23773 Mdot
.52037 .3082 Mdot
.52049 .03738 Mdot
.52061 .02248 Mdot
.52073 .05609 Mdot
.52085 .16225 Mdot
.52097 .10018 Mdot
.52109 .31969 Mdot
.52121 .29134 Mdot
.52133 .30373 Mdot
.52146 .24992 Mdot
.52158 .30267 Mdot
.5217 .06216 Mdot
.52182 .31752 Mdot
.52194 .29831 Mdot
.52206 .30667 Mdot
.52218 .27741 Mdot
.5223 .29951 Mdot
.52242 .19592 Mdot
.52254 .34036 Mdot
.52266 .16503 Mdot
.52279 .06517 Mdot
.52291 .0878 Mdot
.52303 .07946 Mdot
.52315 .15565 Mdot
.52327 .0642 Mdot
.52339 .08375 Mdot
.52351 .07822 Mdot
.52363 .34145 Mdot
.52375 .0645 Mdot
.52387 .0231 Mdot
.52399 .05603 Mdot
.52411 .15304 Mdot
.52424 .09789 Mdot
.52436 .31645 Mdot
.52448 .30158 Mdot
.5246 .30769 Mdot
.52472 .29096 Mdot
.52484 .30335 Mdot
.52496 .24694 Mdot
.52508 .30382 Mdot
.5252 .04978 Mdot
.52532 .39876 Mdot
.52544 .04047 Mdot
.52557 .03479 Mdot
.52569 .02269 Mdot
.52581 .04268 Mdot
.52593 .02145 Mdot
.52605 .05466 Mdot
.52617 .12607 Mdot
.52629 .09067 Mdot
.52641 .28788 Mdot
.52653 .30045 Mdot
.52665 .22259 Mdot
.52677 .31794 Mdot
.52689 .12929 Mdot
.52702 .0579 Mdot
.52714 .04513 Mdot
.52726 .06581 Mdot
.52738 .41349 Mdot
.5275 .07868 Mdot
.52762 .04108 Mdot
.52774 .06436 Mdot
.52786 .37165 Mdot
.52798 .10197 Mdot
.5281 .48838 Mdot
.52822 .01616 Mdot
.52835 .04957 Mdot
.52847 .09968 Mdot
.52859 .08306 Mdot
.52871 .09429 Mdot
.52883 .2156 Mdot
.52895 .28708 Mdot
.52907 .30017 Mdot
.52919 .21928 Mdot
.52931 .32042 Mdot
.52943 .1571 Mdot
.52955 .06383 Mdot
.52968 .07885 Mdot
.5298 .07672 Mdot
.52992 .51286 Mdot
.53004 .15703 Mdot
.53016 .10219 Mdot
.53028 .32898 Mdot
.5304 .24675 Mdot
.53052 .30373 Mdot
.53064 .05146 Mdot
.53076 .04981 Mdot
.53088 .02622 Mdot
.531 .03815 Mdot
.53113 .02035 Mdot
.53125 .04782 Mdot
.53137 .03938 Mdot
.53149 .06378 Mdot
.53161 .35862 Mdot
.53173 .10672 Mdot
.53185 .56477 Mdot
.53197 .60018 Mdot
.53209 .29281 Mdot
.53221 .30647 Mdot
.53233 .27128 Mdot
.53246 .29898 Mdot
.53258 .17012 Mdot
.5327 .36217 Mdot
.53282 .16477 Mdot
.53294 .36487 Mdot
.53306 .22246 Mdot
.53318 .31724 Mdot
.5333 .11806 Mdot
.53342 .05505 Mdot
.53354 .03431 Mdot
.53366 .06183 Mdot
.53378 .30338 Mdot
.53391 .11694 Mdot
.53403 .31964 Mdot
.53415 .29185 Mdot
.53427 .30394 Mdot
.53439 .25188 Mdot
.53451 .302 Mdot
.53463 .07146 Mdot
.53475 .3449 Mdot
.53487 .25165 Mdot
.53499 .30192 Mdot
.53511 .07505 Mdot
.53524 .35517 Mdot
.53536 .3022 Mdot
.53548 .30786 Mdot
.5356 .29834 Mdot
.53572 .30649 Mdot
.53584 .27598 Mdot
.53596 .29932 Mdot
.53608 .19014 Mdot
.5362 .34561 Mdot
.53632 .098 Mdot
.53644 .0489 Mdot
.53656 .02176 Mdot
.53669 .05492 Mdot
.53681 .13061 Mdot
.53693 .09193 Mdot
.53705 .29712 Mdot
.53717 .30362 Mdot
.53729 .25428 Mdot
.53741 .30126 Mdot
.53753 .08365 Mdot
.53765 .31491 Mdot
.53777 .32171 Mdot
.53789 .33258 Mdot
.53802 .06625 Mdot
.53814 .0271 Mdot
.53826 .05856 Mdot
.53838 .21403 Mdot
.5385 .11103 Mdot
.53862 .33255 Mdot
.53874 .23735 Mdot
.53886 .30812 Mdot
.53898 .03689 Mdot
.5391 .02464 Mdot
.53922 .05751 Mdot
.53935 .19625 Mdot
.53947 .10776 Mdot
.53959 .32881 Mdot
.53971 .24766 Mdot
.53983 .30338 Mdot
.53995 .05504 Mdot
.54007 .22198 Mdot
.54019 .31973 Mdot
.54031 .15455 Mdot
.54043 .06334 Mdot
.54055 .07559 Mdot
.54067 .0757 Mdot
.5408 .56612 Mdot
.54092 .58928 Mdot
.54104 .25105 Mdot
.54116 .30179 Mdot
.54128 .08382 Mdot
.5414 .31287 Mdot
.54152 .32553 Mdot
.54164 .35455 Mdot
.54176 .05978 Mdot
.54188 .02 Mdot
.542 .05049 Mdot
.54213 .06142 Mdot
.54225 .07124 Mdot
.54237 .54929 Mdot
.54249 .24005 Mdot
.54261 .11989 Mdot
.54273 .35439 Mdot
.54285 .29998 Mdot
.54297 .30767 Mdot
.54309 .28895 Mdot
.54321 .30257 Mdot
.54333 .23943 Mdot
.54345 .3073 Mdot
.54358 .03582 Mdot
.5437 .04125 Mdot
.54382 .06453 Mdot
.54394 .38539 Mdot
.54406 .09574 Mdot
.54418 .29009 Mdot
.5443 .11739 Mdot
.54442 .32435 Mdot
.54454 .26849 Mdot
.54466 .29906 Mdot
.54478 .1596 Mdot
.54491 .36789 Mdot
.54503 .27792 Mdot
.54515 .30009 Mdot
.54527 .20334 Mdot
.54539 .33369 Mdot
.54551 .21277 Mdot
.54563 .0718 Mdot
.54575 .13238 Mdot
.54587 .09238 Mdot
.54599 .29944 Mdot
.54611 .30455 Mdot
.54624 .2624 Mdot
.54636 .2995 Mdot
.54648 .12689 Mdot
.5466 .34021 Mdot
.54672 .29633 Mdot
.54684 .03811 Mdot
.54696 .19288 Mdot
.54708 .10722 Mdot
.5472 .32845 Mdot
.54732 .24899 Mdot
.54744 .30288 Mdot
.54756 .0607 Mdot
.54769 .31294 Mdot
.54781 .3062 Mdot
.54793 .30552 Mdot
.54805 .307 Mdot
.54817 .30428 Mdot
.54829 .30766 Mdot
.54841 .30013 Mdot
.54853 .30717 Mdot
.54865 .28339 Mdot
.54877 .30077 Mdot
.54889 .21888 Mdot
.54902 .32072 Mdot
.54914 .16018 Mdot
.54926 .0644 Mdot
.54938 .08281 Mdot
.5495 .07793 Mdot
.54962 .38302 Mdot
.54974 .04858 Mdot
.54986 .02737 Mdot
.54998 .0341 Mdot
.5501 .02452 Mdot
.55022 .03944 Mdot
.55034 .01991 Mdot
.55047 .04973 Mdot
.55059 .05445 Mdot
.55071 .06897 Mdot
.55083 .49709 Mdot
.55095 .01481 Mdot
.55107 .05174 Mdot
.55119 .15272 Mdot
.55131 .09782 Mdot
.55143 .31638 Mdot
.55155 .30175 Mdot
.55167 .30772 Mdot
.5518 .29166 Mdot
.55192 .30363 Mdot
.55204 .24957 Mdot
.55216 .3028 Mdot
.55228 .06057 Mdot
.5524 .31239 Mdot
.55252 .30657 Mdot
.55264 .30455 Mdot
.55276 .30758 Mdot
.55288 .30103 Mdot
.553 .30744 Mdot
.55312 .28714 Mdot
.55325 .30192 Mdot
.55337 .23273 Mdot
.55349 .3111 Mdot
.55361 .05387 Mdot
.55373 .02818 Mdot
.55385 .03549 Mdot
.55397 .02264 Mdot
.55409 .04278 Mdot
.55421 .02158 Mdot
.55433 .0548 Mdot
.55445 .12885 Mdot
.55458 .09145 Mdot
.5547 .29389 Mdot
.55482 .30238 Mdot
.55494 .24318 Mdot
.55506 .30546 Mdot
.55518 .039 Mdot
.5553 .23799 Mdot
.55542 .11468 Mdot
.55554 .33532 Mdot
.55566 .23448 Mdot
.55578 .3097 Mdot
.55591 .04324 Mdot
.55603 .02055 Mdot
.55615 .04693 Mdot
.55627 .03541 Mdot
.55639 .06228 Mdot
.55651 .317 Mdot
.55663 .1157 Mdot
.55675 .31075 Mdot
.55687 .30728 Mdot
.55699 .30028 Mdot
.55711 .30721 Mdot
.55723 .28397 Mdot
.55736 .30093 Mdot
.55748 .22103 Mdot
.5576 .31908 Mdot
.55772 .14249 Mdot
.55784 .06089 Mdot
.55796 .06034 Mdot
.55808 .07088 Mdot
.5582 .54087 Mdot
.55832 .1601 Mdot
.55844 .10322 Mdot
.55856 .33126 Mdot
.55869 .23977 Mdot
.55881 .30687 Mdot
.55893 .03584 Mdot
.55905 .06782 Mdot
.55917 .07335 Mdot
.55929 .58469 Mdot
.55941 .27038 Mdot
.55953 .07338 Mdot
.55965 .09657 Mdot
.55977 .08209 Mdot
.55989 .05071 Mdot
.56001 .3103 Mdot
.56014 .07123 Mdot
.56026 .05241 Mdot
.56038 .06827 Mdot
.5605 .47758 Mdot
.56062 .02259 Mdot
.56074 .04681 Mdot
.56086 .05236 Mdot
.56098 .06828 Mdot
.5611 .48016 Mdot
.56122 .02073 Mdot
.56134 .04755 Mdot
.56147 .06199 Mdot
.56159 .07143 Mdot
.56171 .55338 Mdot
.56183 .28598 Mdot
.56195 .12325 Mdot
.56207 .34662 Mdot
.56219 .26179 Mdot
.56231 .29963 Mdot
.56243 .12879 Mdot
.56255 .34529 Mdot
.56267 .29154 Mdot
.5628 .08566 Mdot
.56292 .29217 Mdot
.56304 .36312 Mdot
.56316 .1317 Mdot
.56328 .35378 Mdot
.5634 .28798 Mdot
.56352 .17948 Mdot
.56364 .35512 Mdot
.56376 .04559 Mdot
.56388 .548 Mdot
.564 .2256 Mdot
.56412 .11776 Mdot
.56425 .35373 Mdot
.56437 .29701 Mdot
.56449 .30665 Mdot
.56461 .27623 Mdot
.56473 .29935 Mdot
.56485 .19117 Mdot
.56497 .34467 Mdot
.56509 .1107 Mdot
.56521 .05283 Mdot
.56533 .0281 Mdot
.56545 .05911 Mdot
.56558 .2298 Mdot
.5657 .11347 Mdot
.56582 .33445 Mdot
.56594 .23494 Mdot
.56606 .30944 Mdot
.56618 .04188 Mdot
.5663 .01982 Mdot
.56642 .04865 Mdot
.56654 .04697 Mdot
.56666 .06646 Mdot
.56678 .43204 Mdot
.5669 .06402 Mdot
.56703 .02047 Mdot
.56715 .04777 Mdot
.56727 .03862 Mdot
.56739 .0635 Mdot
.56751 .35082 Mdot
.56763 .10908 Mdot
.56775 .10982 Mdot
.56787 .05352 Mdot
.56799 .03035 Mdot
.56811 .06016 Mdot
.56823 .25782 Mdot
.56836 .1165 Mdot
.56848 .33319 Mdot
.5686 .23652 Mdot
.56872 .30857 Mdot
.56884 .03815 Mdot
.56896 .02064 Mdot
.56908 .05437 Mdot
.5692 .1254 Mdot
.56932 .09049 Mdot
.56944 .28624 Mdot
.56956 .30002 Mdot
.56968 .21688 Mdot
.56981 .32229 Mdot
.56993 .17553 Mdot
.57005 .06703 Mdot
.57017 .10184 Mdot
.57029 .08367 Mdot
.57041 .11944 Mdot
.57053 .30697 Mdot
.57065 .35227 Mdot
.57077 .07857 Mdot
.57089 .04146 Mdot
.57101 .02094 Mdot
.57114 .04626 Mdot
.57126 .03103 Mdot
.57138 .06048 Mdot
.5715 .2675 Mdot
.57162 .11711 Mdot
.57174 .33128 Mdot
.57186 .24038 Mdot
.57198 .30657 Mdot
.5721 .03616 Mdot
.57222 .09125 Mdot
.57234 .08061 Mdot
.57247 .04174 Mdot
.57259 .02026 Mdot
.57271 .04754 Mdot
.57283 .03897 Mdot
.57295 .06363 Mdot
.57307 .35439 Mdot
.57319 .10805 Mdot
.57331 .37687 Mdot
.57343 .05147 Mdot
.57355 .02475 Mdot
.57367 .0387 Mdot
.57379 .02017 Mdot
.57392 .04843 Mdot
.57404 .04359 Mdot
.57416 .06529 Mdot
.57428 .40017 Mdot
.5744 .08753 Mdot
.57452 .11824 Mdot
.57464 .0884 Mdot
.57476 .25971 Mdot
.57488 .30009 Mdot
.575 .09893 Mdot
.57512 .20886 Mdot
.57525 .36095 Mdot
.57537 .0581 Mdot
.57549 .02032 Mdot
.57561 .04824 Mdot
.57573 .04176 Mdot
.57585 .06464 Mdot
.57597 .38242 Mdot
.57609 .0972 Mdot
.57621 .33255 Mdot
.57633 .11324 Mdot
.57645 .26233 Mdot
.57657 .29952 Mdot
.5767 .11262 Mdot
.57682 .27933 Mdot
.57694 .35798 Mdot
.57706 .28818 Mdot
.57718 .20151 Mdot
.5773 .33551 Mdot
.57742 .20547 Mdot
.57754 .07103 Mdot
.57766 .1286 Mdot
.57778 .09134 Mdot
.5779 .29278 Mdot
.57803 .30198 Mdot
.57815 .23937 Mdot
.57827 .30733 Mdot
.57839 .03585 Mdot
.57851 .03989 Mdot
.57863 .06404 Mdot
.57875 .37197 Mdot
.57887 .10183 Mdot
.57899 .4839 Mdot
.57911 .01832 Mdot
.57923 .04852 Mdot
.57936 .07807 Mdot
.57948 .0765 Mdot
.5796 .52446 Mdot
.57972 .24595 Mdot
.57984 .12037 Mdot
.57996 .35372 Mdot
.58008 .297 Mdot
.5802 .30664 Mdot
.58032 .27616 Mdot
.58044 .29934 Mdot
.58056 .19089 Mdot
.58068 .34493 Mdot
.58081 .10721 Mdot
.58093 .05181 Mdot
.58105 .02594 Mdot
.58117 .05798 Mdot
.58129 .20057 Mdot
.58141 .1086 Mdot
.58153 .32983 Mdot
.58165 .24416 Mdot
.58177 .30481 Mdot
.58189 .04291 Mdot
.58201 .42783 Mdot
.58214 .06773 Mdot
.58226 .02016 Mdot
.58238 .0517 Mdot
.5825 .0756 Mdot
.58262 .07572 Mdot
.58274 .56409 Mdot
.58286 .60252 Mdot
.58298 .29352 Mdot
.5831 .30679 Mdot
.58322 .2745 Mdot
.58334 .29916 Mdot
.58346 .18407 Mdot
.58359 .35102 Mdot
.58371 .04053 Mdot
.58383 .01937 Mdot
.58395 .05097 Mdot
.58407 .07059 Mdot
.58419 .07416 Mdot
.58431 .58739 Mdot
.58443 .05473 Mdot
.58455 .25036 Mdot
.58467 .30304 Mdot
.58479 .05375 Mdot
.58492 .15047 Mdot
.58504 .3691 Mdot
.58516 .30492 Mdot
.58528 .29787 Mdot
.5854 .30624 Mdot
.58552 .27354 Mdot
.58564 .29908 Mdot
.58576 .17996 Mdot
.58588 .35456 Mdot
.586 .04157 Mdot
.58612 .37049 Mdot
.58624 .10259 Mdot
.58637 .50813 Mdot
.58649 .02155 Mdot
.58661 .0562 Mdot
.58673 .26739 Mdot
.58685 .11712 Mdot
.58697 .33136 Mdot
.58709 .24017 Mdot
.58721 .30667 Mdot
.58733 .03603 Mdot
.58745 .08251 Mdot
.58757 .07794 Mdot
.5877 .35282 Mdot
.58782 .06097 Mdot
.58794 .02014 Mdot
.58806 .05179 Mdot
.58818 .07707 Mdot
.5883 .07618 Mdot
.58842 .54415 Mdot
.58854 .44051 Mdot
.58866 .06339 Mdot
.58878 .02097 Mdot
.5889 .04628 Mdot
.58903 .03083 Mdot
.58915 .0604 Mdot
.58927 .26518 Mdot
.58939 .11699 Mdot
.58951 .3318 Mdot
.58963 .23913 Mdot
.58975 .30719 Mdot
.58987 .03574 Mdot
.58999 .04999 Mdot
.59011 .06755 Mdot
.59023 .46608 Mdot
.59035 .03237 Mdot
.59048 .04237 Mdot
.5906 .02396 Mdot
.59072 .05681 Mdot
.59084 .17309 Mdot
.59096 .10276 Mdot
.59108 .32278 Mdot
.5912 .27627 Mdot
.59132 .2995 Mdot
.59144 .19321 Mdot
.59156 .34282 Mdot
.59168 .13547 Mdot
.59181 .0592 Mdot
.59193 .051 Mdot
.59205 .06781 Mdot
.59217 .46669 Mdot
.59229 .0318 Mdot
.59241 .04267 Mdot
.59253 .0248 Mdot
.59265 .05736 Mdot
.59277 .18625 Mdot
.59289 .10569 Mdot
.59301 .32628 Mdot
.59313 .25835 Mdot
.59326 .30021 Mdot
.59338 .10843 Mdot
.5935 .25476 Mdot
.59362 .1571 Mdot
.59374 .02043 Mdot
.59386 .05103 Mdot
.59398 .06552 Mdot
.5941 .07255 Mdot
.59422 .57316 Mdot
.59434 .55064 Mdot
.59446 .20582 Mdot
.59459 .11418 Mdot
.59471 .35071 Mdot
.59483 .28185 Mdot
.59495 .30085 Mdot
.59507 .21728 Mdot
.59519 .32196 Mdot
.59531 .17246 Mdot
.59543 .06654 Mdot
.59555 .09817 Mdot
.59567 .08258 Mdot
.59579 .07018 Mdot
.59592 .33677 Mdot
.59604 .23167 Mdot
.59616 .31136 Mdot
.59628 .05498 Mdot
.5964 .02895 Mdot
.59652 .03446 Mdot
.59664 .02386 Mdot
.59676 .04059 Mdot
.59688 .01991 Mdot
.597 .05153 Mdot
.59712 .0746 Mdot
.59724 .07541 Mdot
.59737 .57344 Mdot
.59749 .28917 Mdot
.59761 .07239 Mdot
.59773 .07259 Mdot
.59785 .07476 Mdot
.59797 .58533 Mdot
.59809 .08202 Mdot
.59821 .31348 Mdot
.59833 .32441 Mdot
.59845 .34956 Mdot
.59857 .06145 Mdot
.5987 .02034 Mdot
.59882 .05251 Mdot
.59894 .08719 Mdot
.59906 .07929 Mdot
.59918 .17246 Mdot
.5993 .06717 Mdot
.59942 .10626 Mdot
.59954 .08497 Mdot
.59966 .17351 Mdot
.59978 .36104 Mdot
.5999 .13938 Mdot
.60002 .36441 Mdot
.60015 .29532 Mdot
.60027 .24956 Mdot
.60039 .30285 Mdot
.60051 .05956 Mdot
.60063 .3073 Mdot
.60075 .30725 Mdot
.60087 .29049 Mdot
.60099 .30315 Mdot
.60111 .24509 Mdot
.60123 .30459 Mdot
.60135 .0437 Mdot
.60148 .46325 Mdot
.6016 .03513 Mdot
.60172 .04084 Mdot
.60184 .02104 Mdot
.60196 .05418 Mdot
.60208 .11686 Mdot
.6022 .08807 Mdot
.60232 .25562 Mdot
.60244 .30121 Mdot
.60256 .07761 Mdot
.60268 .35525 Mdot
.6028 .30083 Mdot
.60293 .26851 Mdot
.60305 .29895 Mdot
.60317 .1567 Mdot
.60329 .36879 Mdot
.60341 .29242 Mdot
.60353 .30483 Mdot
.60365 .25865 Mdot
.60377 .30017 Mdot
.60389 .10709 Mdot
.60401 .24679 Mdot
.60413 .20661 Mdot
.60426 .11657 Mdot
.60438 .05542 Mdot
.6045 .03619 Mdot
.60462 .06257 Mdot
.60474 .32392 Mdot
.60486 .11478 Mdot
.60498 .29968 Mdot
.6051 .30462 Mdot
.60522 .2631 Mdot
.60534 .29941 Mdot
.60546 .13052 Mdot
.60559 .34937 Mdot
.60571 .28905 Mdot
.60583 .13497 Mdot
.60595 .35751 Mdot
.60607 .28867 Mdot
.60619 .20789 Mdot
.60631 .3299 Mdot
.60643 .21685 Mdot
.60655 .07221 Mdot
.60667 .13406 Mdot
.60679 .09284 Mdot
.60691 .30184 Mdot
.60704 .3055 Mdot
.60716 .27089 Mdot
.60728 .29896 Mdot
.6074 .16828 Mdot
.60752 .3634 Mdot
.60764 .19104 Mdot
.60776 .34377 Mdot
.60788 .12114 Mdot
.608 .0557 Mdot
.60812 .0363 Mdot
.60824 .06261 Mdot
.60837 .32499 Mdot
.60849 .11462 Mdot
.60861 .29704 Mdot
.60873 .30356 Mdot
.60885 .25387 Mdot
.60897 .30138 Mdot
.60909 .08151 Mdot
.60921 .33585 Mdot
.60933 .29233 Mdot
.60945 .0844 Mdot
.60957 .30737 Mdot
.60969 .33614 Mdot
.60982 .34139 Mdot
.60994 .06386 Mdot
.61006 .02239 Mdot
.61018 .05543 Mdot
.6103 .13991 Mdot
.61042 .09446 Mdot
.61054 .30861 Mdot
.61066 .30739 Mdot
.61078 .29424 Mdot
.6109 .30472 Mdot
.61102 .25942 Mdot
.61115 .30001 Mdot
.61127 .11118 Mdot
.61139 .2711 Mdot
.61151 .31878 Mdot
.61163 .33317 Mdot
.61175 .36494 Mdot
.61187 .0559 Mdot
.61199 .0213 Mdot
.61211 .04544 Mdot
.61223 .02765 Mdot
.61235 .05891 Mdot
.61247 .2255 Mdot
.6126 .11285 Mdot
.61272 .3341 Mdot
.61284 .23523 Mdot
.61296 .30928 Mdot
.61308 .04106 Mdot
.6132 .01951 Mdot
.61332 .04974 Mdot
.61344 .05676 Mdot
.61356 .06973 Mdot
.61368 .51561 Mdot
.6138 .03415 Mdot
.61393 .06143 Mdot
.61405 .40417 Mdot
.61417 .08503 Mdot
.61429 .08742 Mdot
.61441 .07932 Mdot
.61453 .18156 Mdot
.61465 .06859 Mdot
.61477 .11732 Mdot
.61489 .08817 Mdot
.61501 .25661 Mdot
.61513 .30092 Mdot
.61526 .08263 Mdot
.61538 .32566 Mdot
.6155 .30382 Mdot
.61562 .07633 Mdot
.61574 .04086 Mdot
.61586 .02128 Mdot
.61598 .04547 Mdot
.6161 .02789 Mdot
.61622 .05904 Mdot
.61634 .22875 Mdot
.61646 .11332 Mdot
.61658 .33438 Mdot
.61671 .23499 Mdot
.61683 .30941 Mdot
.61695 .04172 Mdot
.61707 .01975 Mdot
.61719 .04886 Mdot
.61731 .04867 Mdot
.61743 .06704 Mdot
.61755 .44746 Mdot
.61767 .05005 Mdot
.61779 .03015 Mdot
.61791 .02927 Mdot
.61804 .03164 Mdot
.61816 .02792 Mdot
.61828 .03377 Mdot
.6184 .0249 Mdot
.61852 .03878 Mdot
.61864 .02012 Mdot
.61876 .04865 Mdot
.61888 .04518 Mdot
.619 .06584 Mdot
.61912 .41535 Mdot
.61924 .07732 Mdot
.61936 .03555 Mdot
.61949 .06228 Mdot
.61961 .31406 Mdot
.61973 .11603 Mdot
.61985 .31352 Mdot
.61997 .30591 Mdot
.62009 .30605 Mdot
.62021 .3064 Mdot
.62033 .30581 Mdot
.62045 .30669 Mdot
.62057 .30518 Mdot
.62069 .30724 Mdot
.62082 .30328 Mdot
.62094 .30779 Mdot
.62106 .29632 Mdot
.62118 .30564 Mdot
.6213 .26773 Mdot
.62142 .299 Mdot
.62154 .15367 Mdot
.62166 .3693 Mdot
.62178 .3012 Mdot
.6219 .30792 Mdot
.62202 .29555 Mdot
.62215 .3053 Mdot
.62227 .26468 Mdot
.62239 .29923 Mdot
.62251 .13865 Mdot
.62263 .36267 Mdot
.62275 .29281 Mdot
.62287 .23891 Mdot
.62299 .30766 Mdot
.62311 .03628 Mdot
.62323 .02993 Mdot
.62335 .06014 Mdot
.62347 .26483 Mdot
.6236 .11697 Mdot
.62372 .33188 Mdot
.62384 .23896 Mdot
.62396 .30728 Mdot
.62408 .03576 Mdot
.6242 .0461 Mdot
.62432 .06623 Mdot
.62444 .4313 Mdot
.62456 .06465 Mdot
.62468 .02028 Mdot
.6248 .04848 Mdot
.62493 .04331 Mdot
.62505 .06519 Mdot
.62517 .39752 Mdot
.62529 .08912 Mdot
.62541 .14269 Mdot
.62553 .09513 Mdot
.62565 .31036 Mdot
.62577 .30734 Mdot
.62589 .2994 Mdot
.62601 .3069 Mdot
.62613 .28028 Mdot
.62625 .30002 Mdot
.62638 .20712 Mdot
.6265 .33038 Mdot
.62662 .21681 Mdot
.62674 .0722 Mdot
.62686 .13401 Mdot
.62698 .09283 Mdot
.6271 .30178 Mdot
.62722 .30548 Mdot
.62734 .27067 Mdot
.62746 .29896 Mdot
.62758 .16728 Mdot
.62771 .36403 Mdot
.62783 .20434 Mdot
.62795 .33182 Mdot
.62807 .21397 Mdot
.62819 .07193 Mdot
.62831 .13299 Mdot
.62843 .09255 Mdot
.62855 .30034 Mdot
.62867 .30491 Mdot
.62879 .26557 Mdot
.62891 .29914 Mdot
.62903 .14307 Mdot
.62916 .36659 Mdot
.62928 .29938 Mdot
.6294 .26582 Mdot
.62952 .29911 Mdot
.62964 .14349 Mdot
.62976 .36686 Mdot
.62988 .29998 Mdot
.63 .26837 Mdot
.63012 .29896 Mdot
.63024 .15592 Mdot
.63036 .36897 Mdot
.63049 .29525 Mdot
.63061 .30607 Mdot
.63073 .27019 Mdot
.63085 .29896 Mdot
.63097 .16516 Mdot
.63109 .36528 Mdot
.63121 .22998 Mdot
.63133 .31216 Mdot
.63145 .06143 Mdot
.63157 .03307 Mdot
.63169 .02911 Mdot
.63182 .03172 Mdot
.63194 .02782 Mdot
.63206 .03393 Mdot
.63218 .02469 Mdot
.6323 .03914 Mdot
.63242 .01999 Mdot
.63254 .04925 Mdot
.63266 .05006 Mdot
.63278 .06751 Mdot
.6329 .45981 Mdot
.63302 .03826 Mdot
.63314 .03892 Mdot
.63327 .01984 Mdot
.63339 .05096 Mdot
.63351 .06755 Mdot
.63363 .0732 Mdot
.63375 .58159 Mdot
.63387 .56042 Mdot
.63399 .60332 Mdot
.63411 .28505 Mdot
.63423 .30319 Mdot
.63435 .23957 Mdot
.63447 .30722 Mdot
.6346 .03578 Mdot
.63472 .0443 Mdot
.63484 .0656 Mdot
.63496 .4146 Mdot
.63508 .07787 Mdot
.6352 .03764 Mdot
.63532 .06309 Mdot
.63544 .33645 Mdot
.63556 .11257 Mdot
.63568 .23081 Mdot
.6358 .3135 Mdot
.63592 .08143 Mdot
.63605 .04299 Mdot
.63617 .02022 Mdot
.63629 .04835 Mdot
.63641 .04285 Mdot
.63653 .06503 Mdot
.63665 .39303 Mdot
.63677 .0917 Mdot
.63689 .19099 Mdot
.63701 .1066 Mdot
.63713 .32722 Mdot
.63725 .25409 Mdot
.63738 .30125 Mdot
.6375 .08576 Mdot
.63762 .28975 Mdot
.63774 .36619 Mdot
.63786 .20467 Mdot
.63798 .33151 Mdot
.6381 .21414 Mdot
.63822 .07195 Mdot
.63834 .13307 Mdot
.63846 .09257 Mdot
.63858 .30046 Mdot
.63871 .30496 Mdot
.63883 .26599 Mdot
.63895 .29911 Mdot
.63907 .14515 Mdot
.63919 .36779 Mdot
.63931 .30213 Mdot
.63943 .27828 Mdot
.63955 .2996 Mdot
.63967 .19882 Mdot
.63979 .33774 Mdot
.63991 .19001 Mdot
.64003 .0691 Mdot
.64016 .11631 Mdot
.64028 .08788 Mdot
.6404 .25149 Mdot
.64052 .30263 Mdot
.64064 .05805 Mdot
.64076 .29439 Mdot
.64088 .30262 Mdot
.641 .24525 Mdot
.64112 .30453 Mdot
.64124 .04413 Mdot
.64136 .48229 Mdot
.64149 .0194 Mdot
.64161 .04807 Mdot
.64173 .07027 Mdot
.64185 .07406 Mdot
.64197 .58731 Mdot
.64209 .04452 Mdot
.64221 .52356 Mdot
.64233 .05744 Mdot
.64245 .07009 Mdot
.64257 .58655 Mdot
.64269 .05046 Mdot
.64281 .02425 Mdot
.64294 .04099 Mdot
.64306 .02012 Mdot
.64318 .0524 Mdot
.6433 .08679 Mdot
.64342 .07917 Mdot
.64354 .19005 Mdot
.64366 .0698 Mdot
.64378 .12646 Mdot
.6439 .09075 Mdot
.64402 .28812 Mdot
.64414 .30051 Mdot
.64427 .22341 Mdot
.64439 .31734 Mdot
.64451 .12226 Mdot
.64463 .05615 Mdot
.64475 .03808 Mdot
.64487 .06328 Mdot
.64499 .34375 Mdot
.64511 .11093 Mdot
.64523 .10667 Mdot
.64535 .23577 Mdot
.64547 .35556 Mdot
.64559 .30516 Mdot
.64572 .30372 Mdot
.64584 .30777 Mdot
.64596 .29766 Mdot
.64608 .30621 Mdot
.6462 .27319 Mdot
.64632 .29906 Mdot
.64644 .17844 Mdot
.64656 .35582 Mdot
.64668 .05221 Mdot
.6468 .06084 Mdot
.64692 .31023 Mdot
.64705 .30735 Mdot
.64717 .29945 Mdot
.64729 .30692 Mdot
.64741 .28049 Mdot
.64753 .30007 Mdot
.64765 .20796 Mdot
.64777 .32966 Mdot
.64789 .21599 Mdot
.64801 .07213 Mdot
.64813 .13383 Mdot
.64825 .09278 Mdot
.64838 .30152 Mdot
.6485 .30538 Mdot
.64862 .26978 Mdot
.64874 .29895 Mdot
.64886 .16321 Mdot
.64898 .36632 Mdot
.6491 .25004 Mdot
.64922 .30239 Mdot
.64934 .06882 Mdot
.64946 .33526 Mdot
.64958 .23147 Mdot
.6497 .31149 Mdot
.64983 .05617 Mdot
.64995 .02975 Mdot
.65007 .03339 Mdot
.65019 .02526 Mdot
.65031 .03818 Mdot
.65043 .02041 Mdot
.65055 .04762 Mdot
.65067 .03817 Mdot
.65079 .06333 Mdot
.65091 .34621 Mdot
.65103 .11032 Mdot
.65116 .05409 Mdot
.65128 .12759 Mdot
.6514 .33797 Mdot
.65152 .29898 Mdot
.65164 .03828 Mdot
.65176 .02036 Mdot
.65188 .054 Mdot
.652 .11815 Mdot
.65212 .08844 Mdot
.65224 .26168 Mdot
.65236 .29965 Mdot
.65248 .10937 Mdot
.65261 .26034 Mdot
.65273 .21168 Mdot
.65285 .45808 Mdot
.65297 .01534 Mdot
.65309 .0522 Mdot
.65321 .15209 Mdot
.65333 .09766 Mdot
.65345 .3161 Mdot
.65357 .30231 Mdot
.65369 .30779 Mdot
.65381 .2939 Mdot
.65394 .30458 Mdot
.65406 .25816 Mdot
.65418 .30028 Mdot
.6543 .10445 Mdot
.65442 .23164 Mdot
.65454 .3428 Mdot
.65466 .24922 Mdot
.65478 .30274 Mdot
.6549 .06308 Mdot
.65502 .31974 Mdot
.65514 .28997 Mdot
.65527 .30317 Mdot
.65539 .24474 Mdot
.65551 .30475 Mdot
.65563 .04271 Mdot
.65575 .41825 Mdot
.65587 .07532 Mdot
.65599 .0293 Mdot
.65611 .05963 Mdot
.65623 .2415 Mdot
.65635 .11495 Mdot
.65647 .3347 Mdot
.65659 .23481 Mdot
.65672 .30951 Mdot
.65684 .04223 Mdot
.65696 .01998 Mdot
.65708 .0482 Mdot
.6572 .0435 Mdot
.65732 .06526 Mdot
.65744 .39943 Mdot
.65756 .08798 Mdot
.65768 .12474 Mdot
.6578 .09024 Mdot
.65792 .28304 Mdot
.65805 .29934 Mdot
.65817 .20538 Mdot
.65829 .33191 Mdot
.65841 .21658 Mdot
.65853 .07217 Mdot
.65865 .13383 Mdot
.65877 .09278 Mdot
.65889 .30152 Mdot
.65901 .30538 Mdot
.65913 .26977 Mdot
.65925 .29895 Mdot
.65937 .16319 Mdot
.6595 .36633 Mdot
.65962 .2502 Mdot
.65974 .30233 Mdot
.65986 .06963 Mdot
.65998 .33817 Mdot
.6601 .23275 Mdot
.66022 .31069 Mdot
.66034 .04968 Mdot
.66046 .02516 Mdot
.66058 .03966 Mdot
.6607 .01986 Mdot
.66083 .05033 Mdot
.66095 .06051 Mdot
.66107 .07095 Mdot
.66119 .54319 Mdot
.66131 .18009 Mdot
.66143 .10838 Mdot
.66155 .34113 Mdot
.66167 .24092 Mdot
.66179 .30623 Mdot
.66191 .03688 Mdot
.66203 .13106 Mdot
.66215 .09217 Mdot
.66228 .29944 Mdot
.6624 .30455 Mdot
.66252 .2624 Mdot
.66264 .2995 Mdot
.66276 .12686 Mdot
.66288 .34013 Mdot
.663 .29642 Mdot
.66312 .03779 Mdot
.66324 .17702 Mdot
.66336 .1038 Mdot
.66348 .32424 Mdot
.66361 .26856 Mdot
.66373 .29906 Mdot
.66385 .1599 Mdot
.66397 .36778 Mdot
.66409 .27604 Mdot
.66421 .29977 Mdot
.66433 .19587 Mdot
.66445 .3404 Mdot
.66457 .16459 Mdot
.66469 .06509 Mdot
.66481 .08724 Mdot
.66494 .07929 Mdot
.66506 .179 Mdot
.66518 .0682 Mdot
.6653 .11433 Mdot
.66542 .08731 Mdot
.66554 .24039 Mdot
.66566 .30772 Mdot
.66578 .03703 Mdot
.6659 .0239 Mdot
.66602 .05707 Mdot
.66614 .18527 Mdot
.66626 .10548 Mdot
.66639 .32603 Mdot
.66651 .25955 Mdot
.66663 .29998 Mdot
.66675 .1148 Mdot
.66687 .29129 Mdot
.66699 .37078 Mdot
.66711 .29673 Mdot
.66723 .30671 Mdot
.66735 .27651 Mdot
.66747 .29939 Mdot
.66759 .19233 Mdot
.66772 .34362 Mdot
.66784 .12494 Mdot
.66796 .05667 Mdot
.66808 .03985 Mdot
.6682 .06394 Mdot
.66832 .36186 Mdot
.66844 .10564 Mdot
.66856 .58687 Mdot
.66868 .03628 Mdot
.6688 .05232 Mdot
.66892 .06833 Mdot
.66904 .48628 Mdot
.66917 .01711 Mdot
.66929 .04907 Mdot
.66941 .08886 Mdot
.66953 .07981 Mdot
.66965 .10633 Mdot
.66977 .05249 Mdot
.66989 .02779 Mdot
.67001 .05896 Mdot
.67013 .22579 Mdot
.67025 .11289 Mdot
.67037 .33413 Mdot
.6705 .2352 Mdot
.67062 .30929 Mdot
.67074 .04113 Mdot
.67086 .01953 Mdot
.67098 .04965 Mdot
.6711 .05584 Mdot
.67122 .06943 Mdot
.67134 .50833 Mdot
.67146 .02172 Mdot
.67158 .05628 Mdot
.6717 .26937 Mdot
.67183 .11722 Mdot
.67195 .33089 Mdot
.67207 .24139 Mdot
.67219 .30608 Mdot
.67231 .03721 Mdot
.67243 .14792 Mdot
.67255 .09669 Mdot
.67267 .31465 Mdot
.67279 .30466 Mdot
.67291 .30737 Mdot
.67303 .30274 Mdot
.67315 .30777 Mdot
.67328 .29414 Mdot
.6734 .30469 Mdot
.67352 .25912 Mdot
.67364 .30007 Mdot
.67376 .10957 Mdot
.67388 .26157 Mdot
.674 .22619 Mdot
.67412 .31793 Mdot
.67424 .29874 Mdot
.67436 .30684 Mdot
.67448 .27927 Mdot
.67461 .29982 Mdot
.67473 .20325 Mdot
.67485 .33378 Mdot
.67497 .21251 Mdot
.67509 .07178 Mdot
.67521 .13227 Mdot
.67533 .09235 Mdot
.67545 .29927 Mdot
.67557 .30448 Mdot
.67569 .2618 Mdot
.67581 .29959 Mdot
.67593 .12375 Mdot
.67606 .33035 Mdot
.67618 .30979 Mdot
.6763 .18621 Mdot
.67642 .06871 Mdot
.67654 .11454 Mdot
.67666 .08738 Mdot
.67678 .24166 Mdot
.6769 .30705 Mdot
.67702 .0359 Mdot
.67714 .03778 Mdot
.67726 .06327 Mdot
.67739 .35072 Mdot
.67751 .10911 Mdot
.67763 .10407 Mdot
.67775 .05183 Mdot
.67787 .02638 Mdot
.67799 .05822 Mdot
.67811 .20676 Mdot
.67823 .10976 Mdot
.67835 .33118 Mdot
.67847 .2403 Mdot
.67859 .30661 Mdot
.67871 .03611 Mdot
.67884 .08774 Mdot
.67896 .07954 Mdot
.67908 .11929 Mdot
.6792 .05609 Mdot
.67932 .03859 Mdot
.67944 .06347 Mdot
.67956 .34911 Mdot
.67968 .10956 Mdot
.6798 .04533 Mdot
.67992 .02283 Mdot
.68004 .04305 Mdot
.68017 .02225 Mdot
.68029 .05547 Mdot
.68041 .14274 Mdot
.68053 .09521 Mdot
.68065 .31086 Mdot
.68077 .30725 Mdot
.68089 .30071 Mdot
.68101 .30735 Mdot
.68113 .28575 Mdot
.68125 .30146 Mdot
.68137 .22762 Mdot
.6815 .31439 Mdot
.68162 .08718 Mdot
.68174 .04528 Mdot
.68186 .01992 Mdot
.68198 .05108 Mdot
.6821 .06873 Mdot
.68222 .07357 Mdot
.68234 .58501 Mdot
.68246 .2224 Mdot
.68258 .07193 Mdot
.6827 .12392 Mdot
.68282 .09003 Mdot
.68295 .28134 Mdot
.68307 .29905 Mdot
.68319 .19907 Mdot
.68331 .33752 Mdot
.68343 .19179 Mdot
.68355 .06934 Mdot
.68367 .11799 Mdot
.68379 .08836 Mdot
.68391 .25969 Mdot
.68403 .30009 Mdot
.68415 .09881 Mdot
.68428 .20862 Mdot
.6844 .39743 Mdot
.68452 .04125 Mdot
.68464 .03412 Mdot
.68476 .02352 Mdot
.68488 .04119 Mdot
.685 .02014 Mdot
.68512 .05246 Mdot
.68524 .08758 Mdot
.68536 .07941 Mdot
.68548 .15617 Mdot
.6856 .0643 Mdot
.68573 .08446 Mdot
.68585 .07844 Mdot
.68597 .30847 Mdot
.68609 .07153 Mdot
.68621 .05507 Mdot
.68633 .06915 Mdot
.68645 .49978 Mdot
.68657 .0154 Mdot
.68669 .05257 Mdot
.68681 .17397 Mdot
.68693 .10298 Mdot
.68706 .32306 Mdot
.68718 .27478 Mdot
.6873 .29932 Mdot
.68742 .18713 Mdot
.68754 .34831 Mdot
.68766 .06374 Mdot
.68778 .03409 Mdot
.6879 .02789 Mdot
.68802 .0337 Mdot
.68814 .02501 Mdot
.68826 .0386 Mdot
.68839 .0202 Mdot
.68851 .04834 Mdot
.68863 .04293 Mdot
.68875 .06506 Mdot
.68887 .39386 Mdot
.68899 .09124 Mdot
.68911 .18147 Mdot
.68923 .10457 Mdot
.68935 .32478 Mdot
.68947 .26579 Mdot
.68959 .29918 Mdot
.68971 .14673 Mdot
.68984 .36846 Mdot
.68996 .30375 Mdot
.69008 .28736 Mdot
.6902 .30192 Mdot
.69032 .23305 Mdot
.69044 .3109 Mdot
.69056 .05227 Mdot
.69068 .02705 Mdot
.6908 .03702 Mdot
.69092 .02113 Mdot
.69104 .0458 Mdot
.69117 .02918 Mdot
.69129 .05965 Mdot
.69141 .24506 Mdot
.69153 .11534 Mdot
.69165 .33456 Mdot
.69177 .23493 Mdot
.69189 .30945 Mdot
.69201 .04188 Mdot
.69213 .01982 Mdot
.69225 .04865 Mdot
.69237 .04691 Mdot
.69249 .06644 Mdot
.69262 .43151 Mdot
.69274 .06448 Mdot
.69286 .02033 Mdot
.69298 .04828 Mdot
.6931 .04192 Mdot
.69322 .0647 Mdot
.69334 .38399 Mdot
.69346 .09644 Mdot
.69358 .30995 Mdot
.6937 .11634 Mdot
.69382 .3161 Mdot
.69395 .30244 Mdot
.69407 .30781 Mdot
.69419 .29446 Mdot
.69431 .30482 Mdot
.69443 .26035 Mdot
.69455 .29984 Mdot
.69467 .11614 Mdot
.69479 .29819 Mdot
.69491 .36542 Mdot
.69503 .18452 Mdot
.69515 .3496 Mdot
.69527 .04997 Mdot
.6954 .02503 Mdot
.69552 .03986 Mdot
.69564 .01985 Mdot
.69576 .05065 Mdot
.69588 .06397 Mdot
.696 .07205 Mdot
.69612 .56501 Mdot
.69624 .43672 Mdot
.69636 .06711 Mdot
.69648 .02005 Mdot
.6966 .05033 Mdot
.69673 .05946 Mdot
.69685 .07061 Mdot
.69697 .53577 Mdot
.69709 .12166 Mdot
.69721 .0919 Mdot
.69733 .31322 Mdot
.69745 .3061 Mdot
.69757 .30571 Mdot
.69769 .30681 Mdot
.69781 .30485 Mdot
.69793 .30744 Mdot
.69806 .30217 Mdot
.69818 .3077 Mdot
.6983 .29184 Mdot
.69842 .30371 Mdot
.69854 .25025 Mdot
.69866 .30255 Mdot
.69878 .06367 Mdot
.6989 .32104 Mdot
.69902 .28368 Mdot
.69914 .30104 Mdot
.69926 .22155 Mdot
.69938 .3187 Mdot
.69951 .13808 Mdot
.69963 .05993 Mdot
.69975 .05503 Mdot
.69987 .06915 Mdot
.69999 .50052 Mdot
.70011 .01567 Mdot
.70023 .05283 Mdot
.70035 .18045 Mdot
.70047 .10444 Mdot
.70059 .3248 Mdot
.70071 .26566 Mdot
.70084 .29919 Mdot
.70096 .14609 Mdot
.70108 .36821 Mdot
.7012 .30315 Mdot
.70132 .28376 Mdot
.70144 .30081 Mdot
.70156 .21975 Mdot
.70168 .32005 Mdot
.7018 .15318 Mdot
.70192 .06308 Mdot
.70204 .07381 Mdot
.70216 .07515 Mdot
.70229 .57996 Mdot
.70241 .03627 Mdot
.70253 .05322 Mdot
.70265 .06863 Mdot
.70277 .49373 Mdot
.70289 .01481 Mdot
.70301 .05083 Mdot
.70313 .12986 Mdot
.70325 .09174 Mdot
.70337 .29599 Mdot
.70349 .30317 Mdot
.70362 .25037 Mdot
.70374 .30251 Mdot
.70386 .06413 Mdot
.70398 .32208 Mdot
.7041 .27816 Mdot
.70422 .29979 Mdot
.70434 .20064 Mdot
.70446 .33611 Mdot
.70458 .20159 Mdot
.7047 .07058 Mdot
.70482 .12604 Mdot
.70495 .09063 Mdot
.70507 .28706 Mdot
.70519 .30023 Mdot
.70531 .21974 Mdot
.70543 .32007 Mdot
.70555 .15335 Mdot
.70567 .06311 Mdot
.70579 .07403 Mdot
.70591 .07522 Mdot
.70603 .57872 Mdot
.70615 .04436 Mdot
.70627 .02026 Mdot
.7064 .04754 Mdot
.70652 .03905 Mdot
.70664 .06366 Mdot
.70676 .35521 Mdot
.70688 .1078 Mdot
.707 .43248 Mdot
.70712 .02201 Mdot
.70724 .04697 Mdot
.70736 .05001 Mdot
.70748 .0675 Mdot
.7076 .45976 Mdot
.70773 .0383 Mdot
.70785 .03889 Mdot
.70797 .01984 Mdot
.70809 .0509 Mdot
.70821 .06693 Mdot
.70833 .073 Mdot
.70845 .57932 Mdot
.70857 .60291 Mdot
.70869 .29435 Mdot
.70881 .30714 Mdot
.70893 .27822 Mdot
.70905 .29964 Mdot
.70918 .19919 Mdot
.7093 .3374 Mdot
.70942 .19268 Mdot
.70954 .06946 Mdot
.70966 .11881 Mdot
.70978 .08859 Mdot
.7099 .2633 Mdot
.71002 .29933 Mdot
.71014 .11788 Mdot
.71026 .30656 Mdot
.71038 .35293 Mdot
.71051 .06726 Mdot
.71063 .036 Mdot
.71075 .02569 Mdot
.71087 .03735 Mdot
.71099 .02099 Mdot
.71111 .04612 Mdot
.71123 .03049 Mdot
.71135 .06025 Mdot
.71147 .2611 Mdot
.71159 .11674 Mdot
.71171 .33263 Mdot
.71183 .23747 Mdot
.71196 .30806 Mdot
.71208 .03675 Mdot
.7122 .02551 Mdot
.71232 .058 Mdot
.71244 .20862 Mdot
.71256 .11009 Mdot
.71268 .33156 Mdot
.7128 .23939 Mdot
.71292 .30706 Mdot
.71304 .03575 Mdot
.71316 .0563 Mdot
.71329 .06964 Mdot
.71341 .51802 Mdot
.71353 .04006 Mdot
.71365 .06369 Mdot
.71377 .46208 Mdot
.71389 .03612 Mdot
.71401 .04025 Mdot
.71413 .02042 Mdot
.71425 .05319 Mdot
.71437 .0994 Mdot
.71449 .08297 Mdot
.71462 .08933 Mdot
.71474 .25951 Mdot
.71486 .27508 Mdot
.71498 .33242 Mdot
.7151 .30885 Mdot
.71522 .17136 Mdot
.71534 .06642 Mdot
.71546 .09766 Mdot
.71558 .08243 Mdot
.7157 .06384 Mdot
.71582 .31956 Mdot
.71594 .29082 Mdot
.71607 .30351 Mdot
.71619 .24791 Mdot
.71631 .30343 Mdot
.71643 .05351 Mdot
.71655 .13381 Mdot
.71667 .35311 Mdot
.71679 .28802 Mdot
.71691 .17312 Mdot
.71703 .36016 Mdot
.71715 .12218 Mdot
.71727 .32802 Mdot
.7174 .31359 Mdot
.71752 .2491 Mdot
.71764 .07421 Mdot
.71776 .12791 Mdot
.71788 .09114 Mdot
.718 .29123 Mdot
.71812 .30146 Mdot
.71824 .2341 Mdot
.71836 .31028 Mdot
.71848 .04767 Mdot
.7186 .02366 Mdot
.71872 .04181 Mdot
.71885 .02068 Mdot
.71897 .05363 Mdot
.71909 .10672 Mdot
.71921 .08513 Mdot
.71933 .18096 Mdot
.71945 .35523 Mdot
.71957 .04584 Mdot
.71969 .55678 Mdot
.71981 .32611 Mdot
.71993 .12062 Mdot
.72005 .32193 Mdot
.72018 .28123 Mdot
.7203 .30041 Mdot
.72042 .21246 Mdot
.72054 .32586 Mdot
.72066 .2021 Mdot
.72078 .07069 Mdot
.7209 .12717 Mdot
.72102 .09095 Mdot
.72114 .28974 Mdot
.72126 .30098 Mdot
.72138 .22899 Mdot
.72151 .31348 Mdot
.72163 .07699 Mdot
.72175 .04108 Mdot
.72187 .02115 Mdot
.72199 .04577 Mdot
.72211 .029 Mdot
.72223 .05957 Mdot
.72235 .24285 Mdot
.72247 .1151 Mdot
.72259 .33466 Mdot
.72271 .23485 Mdot
.72283 .30949 Mdot
.72296 .04213 Mdot
.72308 .01993 Mdot
.7232 .04833 Mdot
.72332 .04447 Mdot
.72344 .0656 Mdot
.72356 .40862 Mdot
.72368 .08208 Mdot
.7238 .06104 Mdot
.72392 .07108 Mdot
.72404 .54405 Mdot
.72416 .18792 Mdot
.72429 .11025 Mdot
.72441 .3446 Mdot
.72453 .25258 Mdot
.72465 .30164 Mdot
.72477 .07975 Mdot
.72489 .34775 Mdot
.72501 .29001 Mdot
.72513 .20911 Mdot
.72525 .32884 Mdot
.72537 .21481 Mdot
.72549 .07202 Mdot
.72561 .13351 Mdot
.72574 .09269 Mdot
.72586 .30109 Mdot
.72598 .30521 Mdot
.7261 .26822 Mdot
.72622 .29898 Mdot
.72634 .15593 Mdot
.72646 .36896 Mdot
.72658 .29521 Mdot
.7267 .30606 Mdot
.72682 .27002 Mdot
.72694 .29896 Mdot
.72707 .16441 Mdot
.72719 .36569 Mdot
.72731 .23813 Mdot
.72743 .30748 Mdot
.72755 .03582 Mdot
.72767 .04171 Mdot
.72779 .06469 Mdot
.72791 .38989 Mdot
.72803 .09342 Mdot
.72815 .22962 Mdot
.72827 .11335 Mdot
.72839 .33409 Mdot
.72852 .23527 Mdot
.72864 .30926 Mdot
.72876 .04097 Mdot
.72888 .01949 Mdot
.729 .04987 Mdot
.72912 .05811 Mdot
.72924 .07017 Mdot
.72936 .52591 Mdot
.72948 .06728 Mdot
.7296 .07361 Mdot
.72972 .45544 Mdot
.72985 .01522 Mdot
.72997 .05164 Mdot
.73009 .13774 Mdot
.73021 .09389 Mdot
.73033 .30666 Mdot
.73045 .30709 Mdot
.73057 .28786 Mdot
.73069 .30216 Mdot
.73081 .23534 Mdot
.73093 .30955 Mdot
.73105 .04306 Mdot
.73118 .02044 Mdot
.7313 .04715 Mdot
.73142 .03665 Mdot
.73154 .06276 Mdot
.73166 .33028 Mdot
.73178 .11375 Mdot
.7319 .27763 Mdot
.73202 .2986 Mdot
.73214 .18449 Mdot
.73226 .35066 Mdot
.73238 .04262 Mdot
.7325 .01999 Mdot
.73263 .04819 Mdot
.73275 .04345 Mdot
.73287 .06524 Mdot
.73299 .39886 Mdot
.73311 .08832 Mdot
.73323 .12987 Mdot
.73335 .09166 Mdot
.73347 .29478 Mdot
.73359 .30271 Mdot
.73371 .24621 Mdot
.73383 .30412 Mdot
.73396 .04718 Mdot
.73408 .58454 Mdot
.7342 .3109 Mdot
.73432 .06979 Mdot
.73444 .04458 Mdot
.73456 .06561 Mdot
.73468 .40679 Mdot
.7348 .0833 Mdot
.73492 .07083 Mdot
.73504 .07419 Mdot
.73516 .58734 Mdot
.73528 .04759 Mdot
.73541 .57259 Mdot
.73553 .34029 Mdot
.73565 .06347 Mdot
.73577 .0221 Mdot
.73589 .05515 Mdot
.73601 .13408 Mdot
.73613 .09288 Mdot
.73625 .30232 Mdot
.73637 .30569 Mdot
.73649 .2726 Mdot
.73661 .29902 Mdot
.73674 .17586 Mdot
.73686 .35791 Mdot
.73698 .08066 Mdot
.7371 .33794 Mdot
.73722 .29089 Mdot
.73734 .11098 Mdot
.73746 .26918 Mdot
.73758 .30437 Mdot
.7377 .35923 Mdot
.73782 .05363 Mdot
.73794 .1653 Mdot
.73807 .36613 Mdot
.73819 .24561 Mdot
.73831 .30402 Mdot
.73843 .04971 Mdot
.73855 .41221 Mdot
.73867 .03297 Mdot
.73879 .04062 Mdot
.73891 .02057 Mdot
.73903 .05346 Mdot
.73915 .10393 Mdot
.73927 .08431 Mdot
.73939 .1493 Mdot
.73952 .36879 Mdot
.73964 .30441 Mdot
.73976 .2922 Mdot
.73988 .30378 Mdot
.74 .25113 Mdot
.74012 .30225 Mdot
.74024 .06781 Mdot
.74036 .33188 Mdot
.74048 .23575 Mdot
.7406 .30901 Mdot
.74072 .03986 Mdot
.74085 .01939 Mdot
.74097 .05145 Mdot
.74109 .07683 Mdot
.74121 .07611 Mdot
.74133 .54787 Mdot
.74145 .47973 Mdot
.74157 .0254 Mdot
.74169 .04571 Mdot
.74181 .04152 Mdot
.74193 .06456 Mdot
.74205 .38054 Mdot
.74217 .09809 Mdot
.7423 .35985 Mdot
.74242 .10622 Mdot
.74254 .58266 Mdot
.74266 .05302 Mdot
.74278 .16927 Mdot
.7429 .36386 Mdot
.74302 .19975 Mdot
.74314 .33589 Mdot
.74326 .20041 Mdot
.74338 .07044 Mdot
.7435 .12522 Mdot
.74363 .0904 Mdot
.74375 .28499 Mdot
.74387 .29973 Mdot
.74399 .21243 Mdot
.74411 .3259 Mdot
.74423 .20235 Mdot
.74435 .07072 Mdot
.74447 .12734 Mdot
.74459 .09099 Mdot
.74471 .29011 Mdot
.74483 .3011 Mdot
.74495 .23025 Mdot
.74508 .31266 Mdot
.7452 .06835 Mdot
.74532 .03693 Mdot
.74544 .02467 Mdot
.74556 .03909 Mdot
.74568 .02 Mdot
.7458 .04915 Mdot
.74592 .0492 Mdot
.74604 .06722 Mdot
.74616 .45217 Mdot
.74628 .04557 Mdot
.74641 .03373 Mdot
.74653 .02386 Mdot
.74665 .04059 Mdot
.74677 .01992 Mdot
.74689 .05154 Mdot
.74701 .07478 Mdot
.74713 .07547 Mdot
.74725 .57198 Mdot
.74737 .3849 Mdot
.74749 .04637 Mdot
.74761 .02929 Mdot
.74774 .03085 Mdot
.74786 .02917 Mdot
.74798 .03176 Mdot
.7481 .02774 Mdot
.74822 .03406 Mdot
.74834 .02452 Mdot
.74846 .03943 Mdot
.74858 .01991 Mdot
.7487 .04972 Mdot
.74882 .05431 Mdot
.74894 .06892 Mdot
.74906 .496 Mdot
.74919 .01472 Mdot
.74931 .05143 Mdot
.74943 .14491 Mdot
.74955 .0958 Mdot
.74967 .3124 Mdot
.74979 .30666 Mdot
.74991 .30423 Mdot
.75003 .30768 Mdot
.75015 .29989 Mdot
.75027 .30708 Mdot
.75039 .28239 Mdot
.75052 .30051 Mdot
.75064 .21515 Mdot
.75076 .32366 Mdot
.75088 .18715 Mdot
.751 .06878 Mdot
.75112 .11454 Mdot
.75124 .08737 Mdot
.75136 .24161 Mdot
.75148 .30707 Mdot
.7516 .03592 Mdot
.75172 .03701 Mdot
.75184 .06298 Mdot
.75197 .34272 Mdot
.75209 .11118 Mdot
.75221 .12965 Mdot
.75233 .34348 Mdot
.75245 .29307 Mdot
.75257 .06418 Mdot
.75269 .32203 Mdot
.75281 .27845 Mdot
.75293 .29984 Mdot
.75305 .20178 Mdot
.75317 .33509 Mdot
.7533 .20718 Mdot
.75342 .07122 Mdot
.75354 .12961 Mdot
.75366 .09162 Mdot
.75378 .29475 Mdot
.7539 .3027 Mdot
.75402 .24613 Mdot
.75414 .30415 Mdot
.75426 .04688 Mdot
.75438 .57944 Mdot
.7545 .60287 Mdot
.75463 .29439 Mdot
.75475 .30716 Mdot
.75487 .27841 Mdot
.75499 .29967 Mdot
.75511 .19994 Mdot
.75523 .33673 Mdot
.75535 .19752 Mdot
.75547 .07009 Mdot
.75559 .12296 Mdot
.75571 .08977 Mdot
.75583 .27852 Mdot
.75595 .29869 Mdot
.75608 .18821 Mdot
.7562 .34736 Mdot
.75632 .07505 Mdot
.75644 .03992 Mdot
.75656 .02198 Mdot
.75668 .04401 Mdot
.7568 .02376 Mdot
.75692 .05666 Mdot
.75704 .16927 Mdot
.75716 .10187 Mdot
.75728 .32173 Mdot
.75741 .28176 Mdot
.75753 .30054 Mdot
.75765 .21442 Mdot
.75777 .32425 Mdot
.75789 .19159 Mdot
.75801 .06938 Mdot
.75813 .11879 Mdot
.75825 .08859 Mdot
.75837 .26324 Mdot
.75849 .29934 Mdot
.75861 .11758 Mdot
.75873 .30518 Mdot
.75886 .35528 Mdot
.75898 .03999 Mdot
.7591 .01943 Mdot
.75922 .05182 Mdot
.75934 .08192 Mdot
.75946 .07768 Mdot
.75958 .41098 Mdot
.7597 .03369 Mdot
.75982 .04012 Mdot
.75994 .02019 Mdot
.76006 .05264 Mdot
.76019 .09048 Mdot
.76031 .08029 Mdot
.76043 .06504 Mdot
.76055 .03613 Mdot
.76067 .02545 Mdot
.76079 .03777 Mdot
.76091 .02068 Mdot
.76103 .04688 Mdot
.76115 .03402 Mdot
.76127 .06173 Mdot
.76139 .30174 Mdot
.76151 .11704 Mdot
.76164 .32032 Mdot
.76176 .28893 Mdot
.76188 .30278 Mdot
.762 .24091 Mdot
.76212 .30654 Mdot
.76224 .03605 Mdot
.76236 .08438 Mdot
.76248 .07852 Mdot
.7626 .26499 Mdot
.76272 .07486 Mdot
.76284 .11968 Mdot
.76297 .08883 Mdot
.76309 .26661 Mdot
.76321 .29884 Mdot
.76333 .13482 Mdot
.76345 .3575 Mdot
.76357 .28867 Mdot
.76369 .20786 Mdot
.76381 .32993 Mdot
.76393 .21688 Mdot
.76405 .07221 Mdot
.76417 .13406 Mdot
.7643 .09284 Mdot
.76442 .30185 Mdot
.76454 .30551 Mdot
.76466 .27093 Mdot
.76478 .29896 Mdot
.7649 .16843 Mdot
.76502 .3633 Mdot
.76514 .1889 Mdot
.76526 .3457 Mdot
.76538 .09519 Mdot
.7655 .04795 Mdot
.76562 .02095 Mdot
.76575 .05394 Mdot
.76587 .11169 Mdot
.76599 .08658 Mdot
.76611 .22456 Mdot
.76623 .31785 Mdot
.76635 .13323 Mdot
.76647 .05883 Mdot
.76659 .04945 Mdot
.76671 .06729 Mdot
.76683 .45305 Mdot
.76695 .04473 Mdot
.76708 .03437 Mdot
.7672 .02303 Mdot
.76732 .04206 Mdot
.76744 .02076 Mdot
.76756 .05375 Mdot
.76768 .10888 Mdot
.7678 .08576 Mdot
.76792 .20177 Mdot
.76804 .33676 Mdot
.76816 .20126 Mdot
.76828 .07054 Mdot
.7684 .12576 Mdot
.76853 .09055 Mdot
.76865 .28637 Mdot
.76877 .30006 Mdot
.76889 .21732 Mdot
.76901 .32194 Mdot
.76913 .17231 Mdot
.76925 .06651 Mdot
.76937 .098 Mdot
.76949 .08253 Mdot
.76961 .06801 Mdot
.76973 .3297 Mdot
.76986 .24182 Mdot
.76998 .30588 Mdot
.7701 .03779 Mdot
.77022 .17734 Mdot
.77034 .10387 Mdot
.77046 .32433 Mdot
.77058 .26809 Mdot
.7707 .29907 Mdot
.77082 .15771 Mdot
.77094 .36852 Mdot
.77106 .2881 Mdot
.77119 .30304 Mdot
.77131 .2419 Mdot
.77143 .30606 Mdot
.77155 .03698 Mdot
.77167 .1362 Mdot
.77179 .09358 Mdot
.77191 .30603 Mdot
.77203 .30693 Mdot
.77215 .28571 Mdot
.77227 .30144 Mdot
.77239 .22741 Mdot
.77251 .31453 Mdot
.77264 .08881 Mdot
.77276 .04589 Mdot
.77288 .02001 Mdot
.773 .05177 Mdot
.77312 .0775 Mdot
.77324 .07632 Mdot
.77336 .5368 Mdot
.77348 .36373 Mdot
.7736 .11132 Mdot
.77372 .04266 Mdot
.77384 .02086 Mdot
.77397 .04631 Mdot
.77409 .03222 Mdot
.77421 .06099 Mdot
.77433 .28149 Mdot
.77445 .11753 Mdot
.77457 .32741 Mdot
.77469 .25372 Mdot
.77481 .30135 Mdot
.77493 .08386 Mdot
.77505 .31254 Mdot
.77517 .32617 Mdot
.77529 .35686 Mdot
.77542 .05897 Mdot
.77554 .02007 Mdot
.77566 .04948 Mdot
.77578 .05153 Mdot
.7759 .068 Mdot
.77602 .47259 Mdot
.77614 .02659 Mdot
.77626 .04516 Mdot
.77638 .03687 Mdot
.7765 .06285 Mdot
.77662 .33309 Mdot
.77675 .11324 Mdot
.77687 .2608 Mdot
.77699 .29984 Mdot
.77711 .1045 Mdot
.77723 .23183 Mdot
.77735 .34358 Mdot
.77747 .25188 Mdot
.77759 .30185 Mdot
.77771 .07609 Mdot
.77783 .35621 Mdot
.77795 .3054 Mdot
.77807 .30019 Mdot
.7782 .30714 Mdot
.77832 .28322 Mdot
.77844 .30072 Mdot
.77856 .21823 Mdot
.77868 .32122 Mdot
.7788 .16533 Mdot
.77892 .06533 Mdot
.77904 .08935 Mdot
.77916 .07993 Mdot
.77928 .0994 Mdot
.7794 .05035 Mdot
.77953 .02378 Mdot
.77965 .05663 Mdot
.77977 .16787 Mdot
.77989 .10154 Mdot
.78001 .32134 Mdot
.78013 .28373 Mdot
.78025 .30106 Mdot
.78037 .22174 Mdot
.78049 .31855 Mdot
.78061 .13641 Mdot
.78073 .05955 Mdot
.78086 .05307 Mdot
.78098 .0685 Mdot
.7811 .48438 Mdot
.78122 .01809 Mdot
.78134 .04862 Mdot
.78146 .07993 Mdot
.78158 .07707 Mdot
.7817 .47782 Mdot
.78182 .0282 Mdot
.78194 .05925 Mdot
.78206 .33812 Mdot
.78218 .11224 Mdot
.78231 .21115 Mdot
.78243 .32856 Mdot
.78255 .21827 Mdot
.78267 .07234 Mdot
.78279 .13453 Mdot
.78291 .09297 Mdot
.78303 .30246 Mdot
.78315 .30574 Mdot
.78327 .27311 Mdot
.78339 .29905 Mdot
.78351 .17804 Mdot
.78364 .35616 Mdot
.78376 .0559 Mdot
.78388 .2626 Mdot
.784 .29946 Mdot
.78412 .11463 Mdot
.78424 .29037 Mdot
.78436 .37097 Mdot
.78448 .30098 Mdot
.7846 .30792 Mdot
.78472 .29477 Mdot
.78484 .30496 Mdot
.78496 .26159 Mdot
.78509 .29963 Mdot
.78521 .1227 Mdot
.78533 .32662 Mdot
.78545 .316 Mdot
.78557 .28323 Mdot
.78569 .07361 Mdot
.78581 .08818 Mdot
.78593 .07956 Mdot
.78605 .14477 Mdot
.78617 .06203 Mdot
.78629 .06893 Mdot
.78642 .07362 Mdot
.78654 .58507 Mdot
.78666 .21393 Mdot
.78678 .07117 Mdot
.7869 .12188 Mdot
.78702 .08946 Mdot
.78714 .27495 Mdot
.78726 .29846 Mdot
.78738 .17355 Mdot
.7875 .35971 Mdot
.78762 .11326 Mdot
.78775 .28767 Mdot
.78787 .37064 Mdot
.78799 .30487 Mdot
.78811 .29779 Mdot
.78823 .3062 Mdot
.78835 .27321 Mdot
.78847 .29906 Mdot
.78859 .17853 Mdot
.78871 .35575 Mdot
.78883 .05144 Mdot
.78895 .03665 Mdot
.78907 .02301 Mdot
.7892 .05646 Mdot
.78932 .17073 Mdot
.78944 .10221 Mdot
.78956 .32214 Mdot
.78968 .27966 Mdot
.7898 .30007 Mdot
.78992 .20647 Mdot
.79004 .33095 Mdot
.79016 .21703 Mdot
.79028 .07222 Mdot
.7904 .13403 Mdot
.79053 .09283 Mdot
.79065 .3018 Mdot
.79077 .30549 Mdot
.79089 .27074 Mdot
.79101 .29896 Mdot
.79113 .1676 Mdot
.79125 .36383 Mdot
.79137 .2002 Mdot
.79149 .33548 Mdot
.79161 .20267 Mdot
.79173 .07071 Mdot
.79185 .12682 Mdot
.79198 .09085 Mdot
.7921 .28893 Mdot
.79222 .30074 Mdot
.79234 .22622 Mdot
.79246 .31535 Mdot
.79258 .09843 Mdot
.7927 .04925 Mdot
.79282 .02217 Mdot
.79294 .05533 Mdot
.79306 .13903 Mdot
.79318 .09422 Mdot
.79331 .30782 Mdot
.79343 .3073 Mdot
.79355 .29171 Mdot
.79367 .30364 Mdot
.79379 .24969 Mdot
.79391 .30275 Mdot
.79403 .0611 Mdot
.79415 .3144 Mdot
.79427 .30474 Mdot
.79439 .30732 Mdot
.79451 .30298 Mdot
.79463 .30779 Mdot
.79476 .29512 Mdot
.79488 .30511 Mdot
.795 .26296 Mdot
.79512 .29943 Mdot
.79524 .12984 Mdot
.79536 .34783 Mdot
.79548 .28983 Mdot
.7956 .11679 Mdot
.79572 .30074 Mdot
.79584 .36213 Mdot
.79596 .10669 Mdot
.79609 .24958 Mdot
.79621 .16378 Mdot
.79633 .0275 Mdot
.79645 .05858 Mdot
.79657 .20933 Mdot
.79669 .11022 Mdot
.79681 .33169 Mdot
.79693 .23909 Mdot
.79705 .30722 Mdot
.79717 .03575 Mdot
.79729 .04882 Mdot
.79742 .06715 Mdot
.79754 .45582 Mdot
.79766 .04207 Mdot
.79778 .03633 Mdot
.7979 .02095 Mdot
.79802 .0462 Mdot
.79814 .03086 Mdot
.79826 .06041 Mdot
.79838 .26545 Mdot
.7985 .117 Mdot
.79862 .33174 Mdot
.79874 .23927 Mdot
.79887 .30712 Mdot
.79899 .03574 Mdot
.79911 .05328 Mdot
.79923 .06864 Mdot
.79935 .49388 Mdot
.79947 .01479 Mdot
.79959 .05087 Mdot
.79971 .13079 Mdot
.79983 .09199 Mdot
.79995 .29759 Mdot
.80007 .3038 Mdot
.8002 .25591 Mdot
.80032 .30082 Mdot
.80044 .0923 Mdot
.80056 .22115 Mdot
.80068 .32073 Mdot
.8008 .28856 Mdot
.80092 .30265 Mdot
.80104 .23957 Mdot
.80116 .30722 Mdot
.80128 .03578 Mdot
.8014 .04402 Mdot
.80152 .06551 Mdot
.80165 .412 Mdot
.80177 .07974 Mdot
.80189 .04628 Mdot
.80201 .06619 Mdot
.80213 .42191 Mdot
.80225 .07235 Mdot
.80237 .02356 Mdot
.80249 .05636 Mdot
.80261 .15977 Mdot
.80273 .09957 Mdot
.80285 .3189 Mdot
.80298 .29445 Mdot
.8031 .30504 Mdot
.80322 .26191 Mdot
.80334 .29958 Mdot
.80346 .1244 Mdot
.80358 .33256 Mdot
.8037 .30638 Mdot
.80382 .12593 Mdot
.80394 .05714 Mdot
.80406 .042 Mdot
.80418 .06471 Mdot
.8043 .38334 Mdot
.80443 .09675 Mdot
.80455 .31922 Mdot
.80467 .11533 Mdot
.80479 .30752 Mdot
.80491 .30725 Mdot
.80503 .29057 Mdot
.80515 .30318 Mdot
.80527 .24542 Mdot
.80539 .30445 Mdot
.80551 .04468 Mdot
.80563 .50521 Mdot
.80576 .01845 Mdot
.80588 .05465 Mdot
.806 .22726 Mdot
.80612 .11312 Mdot
.80624 .33433 Mdot
.80636 .23503 Mdot
.80648 .30939 Mdot
.8066 .04162 Mdot
.80672 .01971 Mdot
.80684 .049 Mdot
.80696 .04983 Mdot
.80709 .06743 Mdot
.80721 .45785 Mdot
.80733 .04013 Mdot
.80745 .03768 Mdot
.80757 .02008 Mdot
.80769 .04877 Mdot
.80781 .0462 Mdot
.80793 .0662 Mdot
.80805 .42492 Mdot
.80817 .06996 Mdot
.80829 .02114 Mdot
.80841 .05395 Mdot
.80854 .11052 Mdot
.80866 .08624 Mdot
.80878 .2156 Mdot
.8089 .32482 Mdot
.80902 .20049 Mdot
.80914 .07051 Mdot
.80926 .12612 Mdot
.80938 .09065 Mdot
.8095 .28726 Mdot
.80962 .30028 Mdot
.80974 .22045 Mdot
.80987 .31953 Mdot
.80999 .14754 Mdot
.81011 .06195 Mdot
.81023 .06663 Mdot
.81035 .07289 Mdot
.81047 .57744 Mdot
.81059 .5984 Mdot
.81071 .15629 Mdot
.81083 .36802 Mdot
.81095 .28112 Mdot
.81107 .3008 Mdot
.81119 .21566 Mdot
.81132 .32325 Mdot
.81144 .1838 Mdot
.81156 .06829 Mdot
.81168 .11109 Mdot
.8118 .08638 Mdot
.81192 .21808 Mdot
.81204 .32281 Mdot
.81216 .18515 Mdot
.81228 .06849 Mdot
.8124 .11254 Mdot
.81252 .0868 Mdot
.81265 .22876 Mdot
.81277 .31487 Mdot
.81289 .09724 Mdot
.81301 .04886 Mdot
.81313 .02176 Mdot
.81325 .05493 Mdot
.81337 .13069 Mdot
.81349 .09196 Mdot
.81361 .29725 Mdot
.81373 .30367 Mdot
.81385 .25473 Mdot
.81398 .30113 Mdot
.8141 .08603 Mdot
.81422 .2863 Mdot
.81434 .36943 Mdot
.81446 .27319 Mdot
.81458 .29943 Mdot
.8147 .18425 Mdot
.81482 .35087 Mdot
.81494 .04141 Mdot
.81506 .01951 Mdot
.81518 .04976 Mdot
.8153 .05702 Mdot
.81543 .06981 Mdot
.81555 .51762 Mdot
.81567 .03902 Mdot
.81579 .0633 Mdot
.81591 .45217 Mdot
.81603 .04558 Mdot
.81615 .03372 Mdot
.81627 .02387 Mdot
.81639 .04057 Mdot
.81651 .01991 Mdot
.81663 .05151 Mdot
.81676 .07438 Mdot
.81688 .07534 Mdot
.817 .57513 Mdot
.81712 .17841 Mdot
.81724 .06667 Mdot
.81736 .09501 Mdot
.81748 .08164 Mdot
.8176 .03903 Mdot
.81772 .23289 Mdot
.81784 .11403 Mdot
.81796 .33518 Mdot
.81808 .2345 Mdot
.81821 .30968 Mdot
.81833 .04317 Mdot
.81845 .0205 Mdot
.81857 .04702 Mdot
.81869 .03591 Mdot
.81881 .06247 Mdot
.81893 .32234 Mdot
.81905 .11501 Mdot
.81917 .30301 Mdot
.81929 .30593 Mdot
.81941 .27491 Mdot
.81954 .2992 Mdot
.81966 .18567 Mdot
.81978 .34961 Mdot
.8199 .0506 Mdot
.82002 .02548 Mdot
.82014 .03922 Mdot
.82026 .01992 Mdot
.82038 .04962 Mdot
.8205 .05343 Mdot
.82062 .06863 Mdot
.82074 .48874 Mdot
.82086 .01605 Mdot
.82099 .04963 Mdot
.82111 .10122 Mdot
.82123 .08352 Mdot
.82135 .11527 Mdot
.82147 .28594 Mdot
.82159 .36957 Mdot
.82171 .30265 Mdot
.82183 .28141 Mdot
.82195 .30021 Mdot
.82207 .21089 Mdot
.82219 .32716 Mdot
.82232 .20865 Mdot
.82244 .07142 Mdot
.82256 .13101 Mdot
.82268 .09201 Mdot
.8228 .29724 Mdot
.82292 .30366 Mdot
.82304 .2547 Mdot
.82316 .30114 Mdot
.82328 .08584 Mdot
.8234 .2887 Mdot
.82352 .36734 Mdot
.82365 .23058 Mdot
.82377 .31178 Mdot
.82389 .05787 Mdot
.82401 .03086 Mdot
.82413 .03192 Mdot
.82425 .02735 Mdot
.82437 .03471 Mdot
.82449 .02369 Mdot
.82461 .04087 Mdot
.82473 .02 Mdot
.82485 .05196 Mdot
.82497 .08043 Mdot
.8251 .07722 Mdot
.82522 .4644 Mdot
.82534 .01688 Mdot
.82546 .05382 Mdot
.82558 .19419 Mdot
.8257 .10736 Mdot
.82582 .32835 Mdot
.82594 .2494 Mdot
.82606 .30274 Mdot
.82618 .06254 Mdot
.8263 .31847 Mdot
.82643 .29515 Mdot
.82655 .30534 Mdot
.82667 .26461 Mdot
.82679 .29923 Mdot
.82691 .13831 Mdot
.82703 .36228 Mdot
.82715 .29234 Mdot
.82727 .23666 Mdot
.82739 .3089 Mdot
.82751 .04 Mdot
.82763 .01938 Mdot
.82775 .05125 Mdot
.82788 .07413 Mdot
.828 .07526 Mdot
.82812 .57692 Mdot
.82824 .0895 Mdot
.82836 .04494 Mdot
.82848 .0199 Mdot
.8286 .05051 Mdot
.82872 .06214 Mdot
.82884 .07147 Mdot
.82896 .55399 Mdot
.82908 .29316 Mdot
.82921 .12321 Mdot
.82933 .34297 Mdot
.82945 .24704 Mdot
.82957 .30355 Mdot
.82969 .05372 Mdot
.82981 .14858 Mdot
.82993 .36859 Mdot
.83005 .30397 Mdot
.83017 .28884 Mdot
.83029 .30246 Mdot
.83041 .23854 Mdot
.83054 .30777 Mdot
.83066 .03639 Mdot
.83078 .02854 Mdot
.8309 .05951 Mdot
.83102 .24807 Mdot
.83114 .11565 Mdot
.83126 .33437 Mdot
.83138 .23511 Mdot
.8315 .30935 Mdot
.83162 .0414 Mdot
.83174 .01962 Mdot
.83186 .04929 Mdot
.83199 .05247 Mdot
.83211 .06831 Mdot
.83223 .48062 Mdot
.83235 .02042 Mdot
.83247 .04767 Mdot
.83259 .06384 Mdot
.83271 .07202 Mdot
.83283 .56461 Mdot
.83295 .43109 Mdot
.83307 .07206 Mdot
.83319 .02226 Mdot
.83332 .05525 Mdot
.83344 .13566 Mdot
.83356 .09331 Mdot
.83368 .30429 Mdot
.8338 .3064 Mdot
.83392 .27961 Mdot
.83404 .29988 Mdot
.83416 .20452 Mdot
.83428 .33266 Mdot
.8344 .21543 Mdot
.83452 .07206 Mdot
.83464 .13342 Mdot
.83477 .09267 Mdot
.83489 .30096 Mdot
.83501 .30516 Mdot
.83513 .26778 Mdot
.83525 .299 Mdot
.83537 .15381 Mdot
.83549 .36929 Mdot
.83561 .30091 Mdot
.83573 .30791 Mdot
.83585 .29433 Mdot
.83597 .30477 Mdot
.8361 .25986 Mdot
.83622 .29993 Mdot
.83634 .11355 Mdot
.83646 .28452 Mdot
.83658 .3682 Mdot
.8367 .29951 Mdot
.83682 .26686 Mdot
.83694 .29903 Mdot
.83706 .14861 Mdot
.83718 .369 Mdot
.8373 .30485 Mdot
.83742 .29668 Mdot
.83755 .30573 Mdot
.83767 .26869 Mdot
.83779 .29897 Mdot
.83791 .15822 Mdot
.83803 .36837 Mdot
.83815 .28565 Mdot
.83827 .30215 Mdot
.83839 .23267 Mdot
.83851 .31113 Mdot
.83863 .05414 Mdot
.83875 .02837 Mdot
.83888 .03523 Mdot
.839 .02292 Mdot
.83912 .04225 Mdot
.83924 .02095 Mdot
.83936 .05403 Mdot
.83948 .11393 Mdot
.8396 .08723 Mdot
.83972 .23953 Mdot
.83984 .30819 Mdot
.83996 .03845 Mdot
.84008 .02022 Mdot
.84021 .0538 Mdot
.84033 .11439 Mdot
.84045 .08736 Mdot
.84057 .24232 Mdot
.84069 .3067 Mdot
.84081 .03574 Mdot
.84093 .05129 Mdot
.84105 .06798 Mdot
.84117 .47725 Mdot
.84129 .02284 Mdot
.84141 .04671 Mdot
.84153 .05118 Mdot
.84166 .06789 Mdot
.84178 .47004 Mdot
.8419 .02879 Mdot
.84202 .04416 Mdot
.84214 .03078 Mdot
.84226 .06038 Mdot
.84238 .26503 Mdot
.8425 .11698 Mdot
.84262 .33183 Mdot
.84274 .23906 Mdot
.84286 .30723 Mdot
.84299 .03575 Mdot
.84311 .04837 Mdot
.84323 .067 Mdot
.84335 .45178 Mdot
.84347 .04595 Mdot
.84359 .03344 Mdot
.84371 .02425 Mdot
.84383 .03991 Mdot
.84395 .01985 Mdot
.84407 .05049 Mdot
.84419 .06215 Mdot
.84431 .07147 Mdot
.84444 .55406 Mdot
.84456 .29406 Mdot
.84468 .12319 Mdot
.8448 .34247 Mdot
.84492 .24538 Mdot
.84504 .30422 Mdot
.84516 .04751 Mdot
.84528 .58753 Mdot
.8454 .04365 Mdot
.84552 .4854 Mdot
.84564 .01761 Mdot
.84577 .04883 Mdot
.84589 .08409 Mdot
.84601 .07835 Mdot
.84613 .31369 Mdot
.84625 .07071 Mdot
.84637 .04797 Mdot
.84649 .06678 Mdot
.84661 .43839 Mdot
.84673 .05843 Mdot
.84685 .02352 Mdot
.84697 .04089 Mdot
.8471 .01998 Mdot
.84722 .0519 Mdot
.84734 .07958 Mdot
.84746 .07696 Mdot
.84758 .48966 Mdot
.8477 .05181 Mdot
.84782 .06813 Mdot
.84794 .55717 Mdot
.84806 .33208 Mdot
.84818 .11967 Mdot
.8483 .31807 Mdot
.84842 .29757 Mdot
.84855 .30637 Mdot
.84867 .27441 Mdot
.84879 .29915 Mdot
.84891 .18365 Mdot
.84903 .35139 Mdot
.84915 .03879 Mdot
.84927 .02017 Mdot
.84939 .05372 Mdot
.84951 .11297 Mdot
.84963 .08695 Mdot
.84975 .23347 Mdot
.84988 .31177 Mdot
.85 .0631 Mdot
.85012 .03405 Mdot
.85024 .02791 Mdot
.85036 .03366 Mdot
.85048 .02505 Mdot
.8506 .03853 Mdot
.85072 .02023 Mdot
.85084 .04822 Mdot
.85096 .04205 Mdot
.85108 .06474 Mdot
.8512 .38521 Mdot
.85133 .09583 Mdot
.85145 .29268 Mdot
.85157 .11733 Mdot
.85169 .32346 Mdot
.85181 .27315 Mdot
.85193 .29918 Mdot
.85205 .18031 Mdot
.85217 .35427 Mdot
.85229 .03989 Mdot
.85241 .28623 Mdot
.85253 .11769 Mdot
.85266 .3263 Mdot
.85278 .25875 Mdot
.8529 .30013 Mdot
.85302 .11055 Mdot
.85314 .26738 Mdot
.85326 .28878 Mdot
.85338 .37034 Mdot
.8535 .30437 Mdot
.85362 .29228 Mdot
.85374 .30382 Mdot
.85386 .25144 Mdot
.85398 .30214 Mdot
.85411 .06932 Mdot
.85423 .33703 Mdot
.85435 .2317 Mdot
.85447 .31133 Mdot
.85459 .05477 Mdot
.85471 .0288 Mdot
.85483 .03465 Mdot
.85495 .02361 Mdot
.85507 .04101 Mdot
.85519 .02005 Mdot
.85531 .05218 Mdot
.85544 .08346 Mdot
.85556 .07815 Mdot
.85568 .34605 Mdot
.8558 .06314 Mdot
.85592 .02141 Mdot
.85604 .05438 Mdot
.85616 .11895 Mdot
.85628 .08867 Mdot
.8564 .26506 Mdot
.85652 .29905 Mdot
.85664 .12696 Mdot
.85677 .34038 Mdot
.85689 .29614 Mdot
.85701 .03885 Mdot
.85713 .2301 Mdot
.85725 .11365 Mdot
.85737 .33505 Mdot
.85749 .23455 Mdot
.85761 .30966 Mdot
.85773 .04303 Mdot
.85785 .02042 Mdot
.85797 .04719 Mdot
.85809 .03687 Mdot
.85822 .06284 Mdot
.85834 .3326 Mdot
.85846 .11333 Mdot
.85858 .26415 Mdot
.8587 .29919 Mdot
.85882 .1221 Mdot
.85894 .32438 Mdot
.85906 .31993 Mdot
.85918 .32669 Mdot
.8593 .06763 Mdot
.85942 .0316 Mdot
.85955 .06068 Mdot
.85967 .2706 Mdot
.85979 .11725 Mdot
.85991 .33052 Mdot
.86003 .24242 Mdot
.86015 .30559 Mdot
.86027 .03887 Mdot
.86039 .23136 Mdot
.86051 .11383 Mdot
.86063 .33513 Mdot
.86075 .23452 Mdot
.86087 .30968 Mdot
.861 .04312 Mdot
.86112 .02047 Mdot
.86124 .04708 Mdot
.86136 .03624 Mdot
.86148 .0626 Mdot
.8616 .32595 Mdot
.86172 .11447 Mdot
.86184 .2944 Mdot
.86196 .30255 Mdot
.86208 .24476 Mdot
.8622 .30474 Mdot
.86233 .04273 Mdot
.86245 .41911 Mdot
.86257 .07467 Mdot
.86269 .02773 Mdot
.86281 .05886 Mdot
.86293 .22125 Mdot
.86305 .11221 Mdot
.86317 .33362 Mdot
.86329 .23574 Mdot
.86341 .30899 Mdot
.86353 .03978 Mdot
.86366 .01941 Mdot
.86378 .05158 Mdot
.8639 .07857 Mdot
.86402 .07665 Mdot
.86414 .51496 Mdot
.86426 .17125 Mdot
.86438 .10596 Mdot
.8645 .33582 Mdot
.86462 .23396 Mdot
.86474 .30999 Mdot
.86486 .04498 Mdot
.86498 .0217 Mdot
.86511 .04485 Mdot
.86523 .02655 Mdot
.86535 .05835 Mdot
.86547 .21088 Mdot
.86559 .11049 Mdot
.86571 .33199 Mdot
.86583 .23844 Mdot
.86595 .30755 Mdot
.86607 .03594 Mdot
.86619 .03646 Mdot
.86631 .06277 Mdot
.86644 .33706 Mdot
.86656 .11245 Mdot
.86668 .22392 Mdot
.8668 .31835 Mdot
.86692 .13916 Mdot
.86704 .06017 Mdot
.86716 .05633 Mdot
.86728 .06958 Mdot
.8674 .51099 Mdot
.86752 .02538 Mdot
.86764 .05789 Mdot
.86776 .31167 Mdot
.86789 .11629 Mdot
.86801 .31534 Mdot
.86813 .30375 Mdot
.86825 .30772 Mdot
.86837 .29954 Mdot
.86849 .30696 Mdot
.86861 .28093 Mdot
.86873 .30016 Mdot
.86885 .20961 Mdot
.86897 .32825 Mdot
.86909 .21269 Mdot
.86922 .07182 Mdot
.86934 .13277 Mdot
.86946 .09249 Mdot
.86958 .30002 Mdot
.8697 .30478 Mdot
.86982 .26446 Mdot
.86994 .29925 Mdot
.87006 .13747 Mdot
.87018 .36127 Mdot
.8703 .29126 Mdot
.87042 .23088 Mdot
.87054 .31237 Mdot
.87067 .06586 Mdot
.87079 .0356 Mdot
.87091 .02611 Mdot
.87103 .03665 Mdot
.87115 .02159 Mdot
.87127 .04481 Mdot
.87139 .02585 Mdot
.87151 .05796 Mdot
.87163 .20098 Mdot
.87175 .10868 Mdot
.87187 .32992 Mdot
.872 .24386 Mdot
.87212 .30494 Mdot
.87224 .04212 Mdot
.87236 .39088 Mdot
.87248 .09303 Mdot
.8726 .21992 Mdot
.87272 .11191 Mdot
.87284 .3331 Mdot
.87296 .23646 Mdot
.87308 .3086 Mdot
.8732 .03828 Mdot
.87333 .02045 Mdot
.87345 .05412 Mdot
.87357 .12049 Mdot
.87369 .0891 Mdot
.87381 .27113 Mdot
.87393 .29847 Mdot
.87405 .15659 Mdot
.87417 .36882 Mdot
.87429 .29289 Mdot
.87441 .30504 Mdot
.87453 .26052 Mdot
.87465 .29981 Mdot
.87478 .11709 Mdot
.8749 .30285 Mdot
.87502 .35903 Mdot
.87514 .05145 Mdot
.87526 .03616 Mdot
.87538 .026 Mdot
.8755 .05826 Mdot
.87562 .21496 Mdot
.87574 .11119 Mdot
.87586 .33271 Mdot
.87598 .23707 Mdot
.87611 .30827 Mdot
.87623 .03727 Mdot
.87635 .0229 Mdot
.87647 .05639 Mdot
.87659 .16924 Mdot
.87671 .10187 Mdot
.87683 .32173 Mdot
.87695 .28178 Mdot
.87707 .30054 Mdot
.87719 .21449 Mdot
.87731 .32419 Mdot
.87743 .1912 Mdot
.87756 .06933 Mdot
.87768 .11843 Mdot
.8778 .08849 Mdot
.87792 .26168 Mdot
.87804 .29965 Mdot
.87816 .10937 Mdot
.87828 .26033 Mdot
.8784 .21162 Mdot
.87852 .46634 Mdot
.87864 .01774 Mdot
.87876 .05439 Mdot
.87889 .20914 Mdot
.87901 .1102 Mdot
.87913 .33171 Mdot
.87925 .23903 Mdot
.87937 .30724 Mdot
.87949 .03575 Mdot
.87961 .04762 Mdot
.87973 .06675 Mdot
.87985 .4451 Mdot
.87997 .05227 Mdot
.88009 .02834 Mdot
.88022 .03231 Mdot
.88034 .02699 Mdot
.88046 .03528 Mdot
.88058 .02301 Mdot
.8807 .04208 Mdot
.88082 .02078 Mdot
.88094 .05378 Mdot
.88106 .10934 Mdot
.88118 .0859 Mdot
.8813 .20585 Mdot
.88142 .33312 Mdot
.88154 .21861 Mdot
.88167 .07235 Mdot
.88179 .13425 Mdot
.88191 .09289 Mdot
.88203 .3021 Mdot
.88215 .3056 Mdot
.88227 .27182 Mdot
.88239 .29899 Mdot
.88251 .1724 Mdot
.88263 .36055 Mdot
.88275 .13033 Mdot
.88287 .35097 Mdot
.883 .28844 Mdot
.88312 .15264 Mdot
.88324 .36938 Mdot
.88336 .30314 Mdot
.88348 .30736 Mdot
.8836 .30329 Mdot
.88372 .30779 Mdot
.88384 .29636 Mdot
.88396 .30565 Mdot
.88408 .26789 Mdot
.8842 .299 Mdot
.88432 .15444 Mdot
.88445 .36922 Mdot
.88457 .29952 Mdot
.88469 .30766 Mdot
.88481 .28837 Mdot
.88493 .30235 Mdot
.88505 .23729 Mdot
.88517 .30844 Mdot
.88529 .03812 Mdot
.88541 .02069 Mdot
.88553 .05443 Mdot
.88565 .12659 Mdot
.88578 .09082 Mdot
.8859 .28912 Mdot
.88602 .3008 Mdot
.88614 .22687 Mdot
.88626 .31491 Mdot
.88638 .09321 Mdot
.8865 .04748 Mdot
.88662 .02066 Mdot
.88674 .05348 Mdot
.88686 .10373 Mdot
.88698 .08425 Mdot
.8871 .14683 Mdot
.88723 .36785 Mdot
.88735 .30219 Mdot
.88747 .27863 Mdot
.88759 .29965 Mdot
.88771 .20016 Mdot
.88783 .33653 Mdot
.88795 .1989 Mdot
.88807 .07026 Mdot
.88819 .12404 Mdot
.88831 .09007 Mdot
.88843 .28177 Mdot
.88856 .29912 Mdot
.88868 .20071 Mdot
.8888 .33605 Mdot
.88892 .20195 Mdot
.88904 .07062 Mdot
.88916 .12629 Mdot
.88928 .0907 Mdot
.8894 .28768 Mdot
.88952 .30039 Mdot
.88964 .22191 Mdot
.88976 .31844 Mdot
.88989 .13517 Mdot
.89001 .05927 Mdot
.89013 .05164 Mdot
.89025 .06802 Mdot
.89037 .47221 Mdot
.89049 .02691 Mdot
.89061 .04501 Mdot
.89073 .03589 Mdot
.89085 .06247 Mdot
.89097 .32259 Mdot
.89109 .11498 Mdot
.89121 .30253 Mdot
.89134 .30575 Mdot
.89146 .27319 Mdot
.89158 .29906 Mdot
.8917 .17839 Mdot
.89182 .35586 Mdot
.89194 .05265 Mdot
.89206 .09282 Mdot
.89218 .22479 Mdot
.8923 .33174 Mdot
.89242 .24249 Mdot
.89254 .30555 Mdot
.89267 .03905 Mdot
.89279 .24045 Mdot
.89291 .11498 Mdot
.89303 .33531 Mdot
.89315 .2345 Mdot
.89327 .30969 Mdot
.89339 .04318 Mdot
.89351 .02051 Mdot
.89363 .04701 Mdot
.89375 .03583 Mdot
.89387 .06244 Mdot
.89399 .32154 Mdot
.89412 .11512 Mdot
.89424 .30447 Mdot
.89436 .30644 Mdot
.89448 .28008 Mdot
.8946 .29998 Mdot
.89472 .20634 Mdot
.89484 .33106 Mdot
.89496 .21703 Mdot
.89508 .07222 Mdot
.8952 .13402 Mdot
.89532 .09283 Mdot
.89545 .30179 Mdot
.89557 .30548 Mdot
.89569 .27071 Mdot
.89581 .29896 Mdot
.89593 .16744 Mdot
.89605 .36393 Mdot
.89617 .20236 Mdot
.89629 .33356 Mdot
.89641 .2106 Mdot
.89653 .07159 Mdot
.89665 .13146 Mdot
.89678 .09213 Mdot
.8969 .29799 Mdot
.89702 .30396 Mdot
.89714 .25731 Mdot
.89726 .30047 Mdot
.89738 .09977 Mdot
.8975 .21103 Mdot
.89762 .05072 Mdot
.89774 .027 Mdot
.89786 .03705 Mdot
.89798 .02111 Mdot
.8981 .04585 Mdot
.89823 .02936 Mdot
.89835 .05974 Mdot
.89847 .24736 Mdot
.89859 .11558 Mdot
.89871 .33442 Mdot
.89883 .23506 Mdot
.89895 .30937 Mdot
.89907 .04152 Mdot
.89919 .01967 Mdot
.89931 .04912 Mdot
.89943 .05091 Mdot
.89956 .06779 Mdot
.89968 .46728 Mdot
.8998 .03127 Mdot
.89992 .04294 Mdot
.90004 .02568 Mdot
.90016 .05788 Mdot
.90028 .19917 Mdot
.9004 .10833 Mdot
.90052 .3295 Mdot
.90064 .24522 Mdot
.90076 .30436 Mdot
.90088 .04609 Mdot
.90101 .55801 Mdot
.90113 .34171 Mdot
.90125 .11777 Mdot
.90137 .30632 Mdot
.90149 .30699 Mdot
.90161 .28649 Mdot
.90173 .30169 Mdot
.90185 .23029 Mdot
.90197 .31263 Mdot
.90209 .06802 Mdot
.90221 .03675 Mdot
.90234 .02486 Mdot
.90246 .03878 Mdot
.90258 .02012 Mdot
.9027 .04862 Mdot
.90282 .04501 Mdot
.90294 .06578 Mdot
.90306 .41369 Mdot
.90318 .07853 Mdot
.9033 .04043 Mdot
.90342 .06412 Mdot
.90354 .36517 Mdot
.90366 .10446 Mdot
.90379 .56669 Mdot
.90391 .46095 Mdot
.90403 .04365 Mdot
.90415 .03551 Mdot
.90427 .02171 Mdot
.90439 .04457 Mdot
.90451 .02518 Mdot
.90463 .05757 Mdot
.90475 .19126 Mdot
.90487 .10675 Mdot
.90499 .32757 Mdot
.90512 .25257 Mdot
.90524 .30169 Mdot
.90536 .07794 Mdot
.90548 .35456 Mdot
.9056 .29894 Mdot
.90572 .26004 Mdot
.90584 .2999 Mdot
.90596 .11364 Mdot
.90608 .28505 Mdot
.9062 .36878 Mdot
.90632 .30079 Mdot
.90645 .27239 Mdot
.90657 .29898 Mdot
.90669 .17429 Mdot
.90681 .35913 Mdot
.90693 .10219 Mdot
.90705 .22424 Mdot
.90717 .31974 Mdot
.90729 .2927 Mdot
.90741 .3043 Mdot
.90753 .25513 Mdot
.90765 .30102 Mdot
.90777 .08822 Mdot
.9079 .2595 Mdot
.90802 .27477 Mdot
.90814 .33057 Mdot
.90826 .31184 Mdot
.90838 .22319 Mdot
.9085 .07284 Mdot
.90862 .13658 Mdot
.90874 .09352 Mdot
.90886 .30494 Mdot
.90898 .30661 Mdot
.9091 .28189 Mdot
.90923 .30038 Mdot
.90935 .2132 Mdot
.90947 .32525 Mdot
.90959 .19845 Mdot
.90971 .07026 Mdot
.90983 .12455 Mdot
.90995 .09021 Mdot
.91007 .2832 Mdot
.91019 .29937 Mdot
.91031 .20596 Mdot
.91043 .3314 Mdot
.91055 .21697 Mdot
.91068 .07221 Mdot
.9108 .13398 Mdot
.91092 .09282 Mdot
.91104 .30173 Mdot
.91116 .30546 Mdot
.91128 .2705 Mdot
.9114 .29896 Mdot
.91152 .16651 Mdot
.91164 .3645 Mdot
.91176 .21414 Mdot
.91188 .32358 Mdot
.91201 .18347 Mdot
.91213 .06825 Mdot
.91225 .11072 Mdot
.91237 .08627 Mdot
.91249 .21517 Mdot
.91261 .32517 Mdot
.91273 .20277 Mdot
.91285 .07078 Mdot
.91297 .12768 Mdot
.91309 .09109 Mdot
.91321 .29086 Mdot
.91334 .30134 Mdot
.91346 .23282 Mdot
.91358 .31105 Mdot
.9137 .05349 Mdot
.91382 .02791 Mdot
.91394 .03585 Mdot
.91406 .02224 Mdot
.91418 .04352 Mdot
.9143 .02278 Mdot
.91442 .05592 Mdot
.91454 .15252 Mdot
.91466 .09775 Mdot
.91479 .31624 Mdot
.91491 .30203 Mdot
.91503 .30776 Mdot
.91515 .29279 Mdot
.91527 .30411 Mdot
.91539 .2539 Mdot
.91551 .30137 Mdot
.91563 .08174 Mdot
.91575 .33386 Mdot
.91587 .29403 Mdot
.91599 .06082 Mdot
.91612 .31315 Mdot
.91624 .30603 Mdot
.91636 .30586 Mdot
.91648 .30665 Mdot
.9166 .30528 Mdot
.91672 .30717 Mdot
.91684 .3036 Mdot
.91696 .30778 Mdot
.91708 .29756 Mdot
.9172 .30617 Mdot
.91732 .27277 Mdot
.91744 .29903 Mdot
.91757 .17665 Mdot
.91769 .35728 Mdot
.91781 .07072 Mdot
.91793 .34408 Mdot
.91805 .24828 Mdot
.91817 .30307 Mdot
.91829 .05898 Mdot
.91841 .30331 Mdot
.91853 .30612 Mdot
.91865 .27659 Mdot
.91877 .29939 Mdot
.9189 .19257 Mdot
.91902 .3434 Mdot
.91914 .12785 Mdot
.91926 .05739 Mdot
.91938 .04275 Mdot
.9195 .06498 Mdot
.91962 .39066 Mdot
.91974 .093 Mdot
.91986 .21973 Mdot
.91998 .11188 Mdot
.9201 .33308 Mdot
.92022 .23649 Mdot
.92035 .30858 Mdot
.92047 .03821 Mdot
.92059 .02055 Mdot
.92071 .05425 Mdot
.92083 .1231 Mdot
.92095 .08984 Mdot
.92107 .27988 Mdot
.92119 .29885 Mdot
.92131 .19351 Mdot
.92143 .34256 Mdot
.92155 .13885 Mdot
.92168 .05996 Mdot
.9218 .05492 Mdot
.92192 .06911 Mdot
.92204 .49964 Mdot
.92216 .01536 Mdot
.92228 .05253 Mdot
.9224 .1728 Mdot
.92252 .10271 Mdot
.92264 .32275 Mdot
.92276 .27647 Mdot
.92288 .29953 Mdot
.92301 .19402 Mdot
.92313 .34209 Mdot
.92325 .14475 Mdot
.92337 .06124 Mdot
.92349 .06205 Mdot
.92361 .07143 Mdot
.92373 .55238 Mdot
.92385 .27436 Mdot
.92397 .12295 Mdot
.92409 .35081 Mdot
.92421 .28262 Mdot
.92433 .30106 Mdot
.92446 .22015 Mdot
.92458 .31975 Mdot
.9247 .14983 Mdot
.92482 .06241 Mdot
.92494 .06953 Mdot
.92506 .0738 Mdot
.92518 .58625 Mdot
.9253 .07011 Mdot
.92542 .03639 Mdot
.92554 .02535 Mdot
.92566 .03793 Mdot
.92579 .02057 Mdot
.92591 .04717 Mdot
.92603 .03554 Mdot
.92615 .06233 Mdot
.92627 .3184 Mdot
.92639 .11553 Mdot
.92651 .30913 Mdot
.92663 .30741 Mdot
.92675 .29568 Mdot
.92687 .30535 Mdot
.92699 .26514 Mdot
.92711 .29918 Mdot
.92724 .14096 Mdot
.92736 .36497 Mdot
.92748 .29622 Mdot
.9276 .25318 Mdot
.92772 .30162 Mdot
.92784 .07695 Mdot
.92796 .35606 Mdot
.92808 .30377 Mdot
.9282 .28399 Mdot
.92832 .30088 Mdot
.92844 .22066 Mdot
.92857 .31936 Mdot
.92869 .14562 Mdot
.92881 .06155 Mdot
.92893 .06422 Mdot
.92905 .07212 Mdot
.92917 .56548 Mdot
.92929 .44328 Mdot
.92941 .06107 Mdot
.92953 .02221 Mdot
.92965 .04345 Mdot
.92977 .02253 Mdot
.9299 .05572 Mdot
.93002 .14799 Mdot
.93014 .09659 Mdot
.93026 .3141 Mdot
.93038 .3053 Mdot
.9305 .30687 Mdot
.93062 .30475 Mdot
.93074 .30749 Mdot
.93086 .30182 Mdot
.93098 .30764 Mdot
.9311 .29042 Mdot
.93122 .30313 Mdot
.93135 .24491 Mdot
.93147 .30467 Mdot
.93159 .04318 Mdot
.93171 .43987 Mdot
.93183 .05724 Mdot
.93195 .0244 Mdot
.93207 .03926 Mdot
.93219 .01997 Mdot
.93231 .04935 Mdot
.93243 .05098 Mdot
.93255 .06782 Mdot
.93268 .46786 Mdot
.9328 .03075 Mdot
.93292 .04321 Mdot
.93304 .02661 Mdot
.93316 .05839 Mdot
.93328 .21215 Mdot
.9334 .11071 Mdot
.93352 .33222 Mdot
.93364 .23797 Mdot
.93376 .3078 Mdot
.93388 .03626 Mdot
.934 .0302 Mdot
.93413 .06025 Mdot
.93425 .26796 Mdot
.93437 .11713 Mdot
.93449 .33117 Mdot
.93461 .24064 Mdot
.93473 .30644 Mdot
.93485 .03638 Mdot
.93497 .10374 Mdot
.93509 .08435 Mdot
.93521 .15737 Mdot
.93533 .36905 Mdot
.93546 .29598 Mdot
.93558 .30638 Mdot
.9357 .27322 Mdot
.93582 .29906 Mdot
.93594 .17862 Mdot
.93606 .35568 Mdot
.93618 .05076 Mdot
.9363 .10074 Mdot
.93642 .05075 Mdot
.93654 .0244 Mdot
.93666 .05705 Mdot
.93678 .1777 Mdot
.93691 .10381 Mdot
.93703 .32402 Mdot
.93715 .26972 Mdot
.93727 .29905 Mdot
.93739 .16523 Mdot
.93751 .36524 Mdot
.93763 .2292 Mdot
.93775 .31266 Mdot
.93787 .0662 Mdot
.93799 .03578 Mdot
.93811 .0259 Mdot
.93824 .037 Mdot
.93836 .02128 Mdot
.93848 .04547 Mdot
.9386 .02795 Mdot
.93872 .05906 Mdot
.93884 .22946 Mdot
.93896 .11342 Mdot
.93908 .33443 Mdot
.9392 .23495 Mdot
.93932 .30943 Mdot
.93944 .04183 Mdot
.93957 .0198 Mdot
.93969 .04872 Mdot
.93981 .04748 Mdot
.93993 .06664 Mdot
.94005 .43674 Mdot
.94017 .05991 Mdot
.94029 .02252 Mdot
.94041 .04282 Mdot
.94053 .02155 Mdot
.94065 .05478 Mdot
.94077 .12829 Mdot
.94089 .09129 Mdot
.94102 .29278 Mdot
.94114 .30198 Mdot
.94126 .23938 Mdot
.94138 .30733 Mdot
.9415 .03585 Mdot
.94162 .03992 Mdot
.94174 .06405 Mdot
.94186 .37231 Mdot
.94198 .10169 Mdot
.9421 .47916 Mdot
.94222 .02138 Mdot
.94235 .04729 Mdot
.94247 .0584 Mdot
.94259 .07027 Mdot
.94271 .52843 Mdot
.94283 .07883 Mdot
.94295 .07767 Mdot
.94307 .0361 Mdot
.94319 .09518 Mdot
.94331 .0818 Mdot
.94343 .04811 Mdot
.94355 .58768 Mdot
.94367 .06557 Mdot
.9438 .32936 Mdot
.94392 .24271 Mdot
.94404 .30547 Mdot
.94416 .03939 Mdot
.94428 .25705 Mdot
.9444 .11659 Mdot
.94452 .33387 Mdot
.94464 .23564 Mdot
.94476 .30905 Mdot
.94488 .04 Mdot
.945 .01938 Mdot
.94513 .05124 Mdot
.94525 .07402 Mdot
.94537 .07523 Mdot
.94549 .57763 Mdot
.94561 .06614 Mdot
.94573 .0343 Mdot
.94585 .02772 Mdot
.94597 .03398 Mdot
.94609 .02464 Mdot
.94621 .03923 Mdot
.94633 .01996 Mdot
.94646 .04939 Mdot
.94658 .05131 Mdot
.9467 .06793 Mdot
.94682 .47068 Mdot
.94694 .02824 Mdot
.94706 .04442 Mdot
.94718 .03217 Mdot
.9473 .06098 Mdot
.94742 .28133 Mdot
.94754 .11753 Mdot
.94766 .32746 Mdot
.94778 .2535 Mdot
.94791 .30141 Mdot
.94803 .08273 Mdot
.94815 .32465 Mdot
.94827 .30528 Mdot
.94839 .09766 Mdot
.94851 .04907 Mdot
.94863 .02198 Mdot
.94875 .05515 Mdot
.94887 .13528 Mdot
.94899 .09321 Mdot
.94911 .30384 Mdot
.94924 .30625 Mdot
.94936 .27802 Mdot
.94948 .2996 Mdot
.9496 .19828 Mdot
.94972 .33823 Mdot
.94984 .18594 Mdot
.94996 .06853 Mdot
.95008 .11225 Mdot
.9502 .08671 Mdot
.95032 .2267 Mdot
.95044 .31631 Mdot
.95056 .11463 Mdot
.95069 .05413 Mdot
.95081 .03153 Mdot
.95093 .06068 Mdot
.95105 .27182 Mdot
.95117 .1173 Mdot
.95129 .3302 Mdot
.95141 .24336 Mdot
.95153 .30517 Mdot
.95165 .04086 Mdot
.95177 .33 Mdot
.95189 .11395 Mdot
.95202 .28148 Mdot
.95214 .29906 Mdot
.95226 .19946 Mdot
.95238 .33717 Mdot
.9525 .19441 Mdot
.95262 .06969 Mdot
.95274 .12035 Mdot
.95286 .08903 Mdot
.95298 .26955 Mdot
.9531 .29856 Mdot
.95322 .14918 Mdot
.95334 .36912 Mdot
.95347 .30497 Mdot
.95359 .29901 Mdot
.95371 .3067 Mdot
.95383 .27825 Mdot
.95395 .29964 Mdot
.95407 .19925 Mdot
.95419 .33735 Mdot
.95431 .19306 Mdot
.95443 .06951 Mdot
.95455 .11916 Mdot
.95467 .08869 Mdot
.9548 .26478 Mdot
.95492 .29909 Mdot
.95504 .12554 Mdot
.95516 .33617 Mdot
.95528 .30126 Mdot
.9554 .05361 Mdot
.95552 .02808 Mdot
.95564 .03562 Mdot
.95576 .02249 Mdot
.95588 .04304 Mdot
.956 .02197 Mdot
.95613 .05521 Mdot
.95625 .1371 Mdot
.95637 .0937 Mdot
.95649 .30589 Mdot
.95661 .30689 Mdot
.95673 .28523 Mdot
.95685 .30129 Mdot
.95697 .22563 Mdot
.95709 .31575 Mdot
.95721 .10319 Mdot
.95733 .05078 Mdot
.95745 .02421 Mdot
.95758 .05692 Mdot
.9577 .17468 Mdot
.95782 .10313 Mdot
.95794 .32321 Mdot
.95806 .274 Mdot
.95818 .29925 Mdot
.9583 .1839 Mdot
.95842 .35117 Mdot
.95854 .03977 Mdot
.95866 .01949 Mdot
.95878 .0521 Mdot
.95891 .08607 Mdot
.95903 .07895 Mdot
.95915 .22279 Mdot
.95927 .07335 Mdot
.95939 .14516 Mdot
.95951 .09581 Mdot
.95963 .31224 Mdot
.95975 .30674 Mdot
.95987 .30393 Mdot
.95999 .30774 Mdot
.96011 .29874 Mdot
.96023 .30665 Mdot
.96036 .27764 Mdot
.96048 .29954 Mdot
.9606 .19683 Mdot
.96072 .33954 Mdot
.96084 .17371 Mdot
.96096 .06665 Mdot
.96108 .09852 Mdot
.9612 .08268 Mdot
.96132 .07463 Mdot
.96144 .35207 Mdot
.96156 .28745 Mdot
.96169 .30264 Mdot
.96181 .2383 Mdot
.96193 .30789 Mdot
.96205 .03663 Mdot
.96217 .02634 Mdot
.96229 .05844 Mdot
.96241 .21988 Mdot
.96253 .11199 Mdot
.96265 .33345 Mdot
.96277 .23596 Mdot
.96289 .30887 Mdot
.96302 .03928 Mdot
.96314 .01956 Mdot
.96326 .05236 Mdot
.96338 .08993 Mdot
.9635 .08013 Mdot
.96362 .07741 Mdot
.96374 .04216 Mdot
.96386 .02051 Mdot
.96398 .0474 Mdot
.9641 .03673 Mdot
.96422 .06279 Mdot
.96434 .33111 Mdot
.96447 .1136 Mdot
.96459 .27327 Mdot
.96471 .29842 Mdot
.96483 .16608 Mdot
.96495 .36476 Mdot
.96507 .21944 Mdot
.96519 .31946 Mdot
.96531 .1437 Mdot
.96543 .06115 Mdot
.96555 .06181 Mdot
.96567 .07135 Mdot
.9658 .55084 Mdot
.96592 .25689 Mdot
.96604 .12178 Mdot
.96616 .35379 Mdot
.96628 .29736 Mdot
.9664 .30679 Mdot
.96652 .27769 Mdot
.96664 .29955 Mdot
.96676 .19706 Mdot
.96688 .33933 Mdot
.967 .17577 Mdot
.96712 .06698 Mdot
.96725 .10097 Mdot
.96737 .08341 Mdot
.96749 .10769 Mdot
.96761 .24178 Mdot
.96773 .3124 Mdot
.96785 .32543 Mdot
.96797 .35363 Mdot
.96809 .06009 Mdot
.96821 .02002 Mdot
.96833 .05088 Mdot
.96845 .0657 Mdot
.96858 .07261 Mdot
.9687 .574 Mdot
.96882 .56171 Mdot
.96894 .32937 Mdot
.96906 .12018 Mdot
.96918 .32004 Mdot
.9693 .29022 Mdot
.96942 .30328 Mdot
.96954 .24573 Mdot
.96966 .30432 Mdot
.96978 .04563 Mdot
.9699 .54227 Mdot
.97003 .17125 Mdot
.97015 .10617 Mdot
.97027 .33683 Mdot
.97039 .23416 Mdot
.97051 .30987 Mdot
.97063 .04421 Mdot
.97075 .02117 Mdot
.97087 .04575 Mdot
.97099 .02979 Mdot
.97111 .05994 Mdot
.97123 .25268 Mdot
.97136 .11608 Mdot
.97148 .33391 Mdot
.9716 .23558 Mdot
.97172 .30909 Mdot
.97184 .04017 Mdot
.97196 .01937 Mdot
.97208 .051 Mdot
.9722 .07094 Mdot
.97232 .07427 Mdot
.97244 .58734 Mdot
.97256 .0678 Mdot
.97269 .33692 Mdot
.97281 .23148 Mdot
.97293 .31147 Mdot
.97305 .05596 Mdot
.97317 .02961 Mdot
.97329 .03357 Mdot
.97341 .02501 Mdot
.97353 .03861 Mdot
.97365 .02019 Mdot
.97377 .04835 Mdot
.97389 .04301 Mdot
.97401 .06509 Mdot
.97414 .39465 Mdot
.97426 .09079 Mdot
.97438 .17255 Mdot
.9745 .10256 Mdot
.97462 .32241 Mdot
.97474 .27826 Mdot
.97486 .29981 Mdot
.97498 .20107 Mdot
.9751 .33571 Mdot
.97522 .20389 Mdot
.97534 .07085 Mdot
.97547 .12761 Mdot
.97559 .09107 Mdot
.97571 .2907 Mdot
.97583 .30128 Mdot
.97595 .23227 Mdot
.97607 .31139 Mdot
.97619 .05633 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00k@3oool0202oM00007Bo0?ooo`3oool0okmd0000000007@0_ooo^`3oool00>d0oooo00P0
okmd0000M02oool0oooo0;md0000M;l0oono07Ad_k/0oooo003]0?ooo`060?oOW01804P0W=oo0?oo
g`2LB000B9cO_@3oool00>d0oooo00H0oooO09a80000B7@0_knL04P0B02Lgonm0?ooo`00kP3oool0
1@3OW4P004Qd07A8000007@0_ooo0;d0oooo003^0?ooo`050?noM00007@0_ooo0;md001d_ol0_@3o
ool00>h0oooo00H0oono07@0001d_ol0oooo0;mdB02Lgonl0?ooo`00k`3oool0102oM00007Bo0?oo
_`1d000200000003001d_`3oool0oooo0;P0oooo003_0?ooo`030?noM000B9`0gooo0;h0oooo003_
0?ooo`030?oOW01804P0W=oo0;h0oooo003_0?ooo`030?oog`2LB000B9cO0;h0oooo003`0?ooo`03
0;md0000M;l0oooo0;d0oooo003^0?ooo`050?oog`2LB00000000000M02oool0_@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00540oooo00@0_g@0000000000000M;oo?@3oool00`3OW4P00000000000030000000304RL
g`3oool0oooo0080oooo00@0_g@0000000000000M;oo1@3oool0102oM00000000000001d_ol50?oo
o`040;md00000000000007Booc80oooo00<0oooO09a80018W=l01@3oool0102oM00000000000001d
_ol50?ooo`040;md00000000000007Boo`D0oooo00@0_g@0000000000000M;oo<03oool01@3ooml0
W4P000000000000007Bo00D0oooo00@0_g@0000000000000M;oo1@3oool0102oM00000000000001d
_ol50?ooo`040;md00000000000007Booc00oooo00H0oono07@00000000000000018W03Oool40?oo
o`040;md00000000000007Boo`D0oooo00@0_g@0000000000000M;oo1@3oool0102oM00000000000
001d_ol=0?ooo`00D03oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLgcd0oooo00<0okmd001d_`3o
ool00P3oool02P2oM7@0_ooo0?ooo`3oool0gia8001d_`3oool0omnL04P00018W=l30?ooo`060=nL
B000M;l0oooo0?oOW0180000B9cO0`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLgc80oooo00<0
gia80018W03Oool00`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`<0oooo00H0gia8001d_`3o
ool0omnL04P00018W=l30?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO;`3oool01`3OW4P007Bo
0?ooo`3ookl0M0000018W03Oool00P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`<0oooo00H0
gia8001d_`3oool0omnL04P00018W=l30?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO;P3oool0
0`3ookl0M00004RLg`020?ooo`030=nLB00007@0_ooo0080oooo00H0gia8001d_`3oool0omnL04P0
0018W=l30?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0`3oool01P3OW4P007Bo0?ooo`3ogi`0
B00004RLg``0oooo001?0?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0?@3oool0
0`3o_g@007Bo0?ooo`040?ooo`030?oog`2LB000B9cO0080oooo00L0okmd0000B02Lgol0oooo0?oo
g`2LB000B9cO0080oooo00L0okmd0000B02Lgol0oooo0?oog`2LB000B9cO0080oooo00<0okmd0000
B02Lgol0<@3oool00`3ogi`0B01809cOo`020?ooo`030?oog`2LB000B9cO0080oooo00L0okmd0000
B02Lgol0oooo0?oog`2LB000B9cO0080oooo00L0okmd0000B02Lgol0oooo0?oog`2LB000B9cO0080
oooo00<0okmd0000B02Lgol0;@3oool00`3ooml0W4P007Boo`020?ooo`070?oOW0180000B9cO0?oo
o`3ooml0W4P004RLg`020?ooo`070?noM00004P0W=oo0?ooo`3ooml0W4P004RLg`020?ooo`070?no
M00004P0W=oo0?ooo`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo02d0oooo00<0okmd0018
W03Oool00`3oool01P2oM000B9cO0?ooo`3ooml0W4P004RLg`80oooo00L0okmd0000B02Lgol0oooo
0?oog`2LB000B9cO0080oooo00L0okmd0000B02Lgol0oooo0?oog`2LB000B9cO0080oooo00<0okmd
0000B02Lgol02`3oool004l0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Ooolm
0?ooo`030?noM000M;l0oooo00<0oooo00<0oooO09a80018W=l00P3oool01`3ooml0W4P00018W03O
ool0oooO09a80018W=l00P3oool01`3ooml0W4P00018W03Oool0oooO09a80018W=l00P3oool0103o
oml0W4P00018W03Oool/0?ooo`030?noM0000000000000@0000000D004RL0=ooo`3ooml0W4P004RL
g`020?ooo`070?oog`2LB00004RL0=ooo`3ooml0W4P004RLg`020?ooo`070?oog`2LB00004RL0=oo
o`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooob`0oooo00<0oono07@0001d_ol00`3o
ool01P2oM000001d0;ooo`3ooml0W4P004RLg`80oooo00L0oooO09a80000B9`0gooo0?oog`2LB000
B9cO0080oooo00L0oooO09a80000B9`0gooo0?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0
gooo;03oool00`3o_g@004RL0=ooo`030?ooo`060;md0000M;l0oooo0?oog`2LB000B9cO0P3oool0
1`3ooml0W4P00018W03Oool0oooO09a80018W=l00P3oool01`3ooml0W4P00018W03Oool0oooO09a8
0018W=l00P3oool0103ooml0W4P00018W03Oool:0?ooo`00C`3oool00`3ooml0W4P0001d_`030?oo
o`030=nLB00004P0W=oo03h0oooo00<0okmd04RLg`3oool00P3oool00`3ooml0W4P0001d_`030?oo
o`060=nLB00004P0W=oo0?oog`2LB00007Bo0`3oool01P3OW4P0001809cOo`3ooml0W4P0001d_`<0
oooo00<0gia80000B02Lgol0;03oool00`3ooml0W4Q809cOo`020?ooo`070;md0000M;l0oooo0?oo
o`3ooml0W4P0001d_`030?ooo`060=nLB00004P0W=oo0?oog`2LB00007Bo0`3oool01P3OW4P00018
09cOo`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol0;03oool00`3ooml0W4P0001d_`030?oo
o`060=nLB00004P0W=oo0?oog`2LB00007Bo0`3oool01P3OW4P0001809cOo`3ooml0W4P0001d_`<0
oooo00H0gia80000B02Lgol0oooO09a80000M;l30?ooo`030=nLB00004P0W=oo02`0oooo00<0oooO
09a8001d_ol00P3oool01`3ookl0M00004RLg`3oool0oooO09a80000M;l00`3oool01P3OW4P00018
09cOo`3ooml0W4P0001d_`<0oooo00H0gia80000B02Lgol0oooO09a80000M;l30?ooo`030=nLB000
04P0W=oo00X0oooo001@0?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0?`3oool0
0`3OW4P0B9cO0?ooo`020?ooo`030;md0000B9`0gooo0080oooo00L0omnL04P00018W=l0oooo0;md
0000B9`0gooo0080oooo00L0omnL04P00018W=l0oooo0;md0000B9`0gooo0080oooo00<0omnL04P0
0018W=l0;@3oool01`3ookl0M01d0;ooo`3oool0okmd0018W03Oool00P3oool00`2oM00004RL0=oo
o`020?ooo`070?oOW0180000B9cO0?ooo`2oM00004RL0=ooo`020?ooo`070?oOW0180000B9cO0?oo
o`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO02d0oooo00<0_g@00000M02oool00P3oool0
1`3OW4P0001809cOo`3oool0_g@00018W03Oool00P3oool01`3ogi`0B00004RLg`3oool0_g@00018
W03Oool00P3oool01`3ogi`0B00004RLg`3oool0_g@00018W03Oool00P3oool00`3ogi`0B00004RL
g`0^0?ooo`060;md000004P0W=oO09a8000007@0_ooo0P3oool00`2oM00004RL0=ooo`020?ooo`07
0?oOW0180000B9cO0?ooo`2oM00004RL0=ooo`020?ooo`070?oOW0180000B9cO0?ooo`2oM00004RL
0=ooo`020?ooo`030?oOW0180000B9cO00X0oooo001@0?ooo`030=nLB00004P0W=oo0080oooo00<0
oooO09a80000M;l0@03oool01`2oM000M;oo0?ooo`3oool0gia80000B02Lgol00P3oool01`3ooml0
W4P0001d_`3oool0gia80000B02Lgol00P3oool01`3ooml0W4P0001d_`3oool0gia80000B02Lgol0
0P3oool00`3ooml0W4P0001d_`0^0?ooo`060?oOW018B9`0gooo0?oOW01804P0W=oo0P3oool00`3O
W4P0001809cOo`020?ooo`070?oog`2LB00007Bo0?ooo`3OW4P0001809cOo`020?ooo`070?oog`2L
B00007Bo0?ooo`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo02d0oooo00`0okmd00000018
W=l0oooo0?oog`2LB00004RL0=ooo`3oool0gia80000B02Lgol20?ooo`070?oog`2LB00007Bo0?oo
o`3OW4P0001809cOo`020?ooo`070?oog`2LB00007Bo0?ooo`3OW4P0001809cOo`020?ooo`030?oo
g`2LB00007Bo02l0oooo00D0oooO09a80000000004RL0=ooo`020?ooo`030=nLB00004P0W=oo0080
oooo00L0oooO09a80000M;l0oooo0=nLB00004P0W=oo0080oooo00L0oooO09a80000M;l0oooo0=nL
B00004P0W=oo0080oooo00<0oooO09a80000M;l02P3oool00500oooo00<0omnL04P00018W=l00`3o
ool00`2oM00004RL0=ooo`0o0?ooo`070?oOW01807@0_ooo0?ooo`3ogi`0B00004RLg`030?ooo`06
0;md0000B9`0gooo0?oOW0180000B9cO0`3oool01P2oM00004RL0=ooo`3ogi`0B00004RLg`<0oooo
00<0_g@00018W03Oool0;P3oool01@3o_g@007Bo0?oog`2LB000B9cO0080oooo00<0omnL04P00018
W=l00`3oool01P2oM00004RL0=ooo`3ogi`0B00004RLg`<0oooo00H0_g@00018W03Oool0omnL04P0
0018W=l30?ooo`030;md0000B9`0gooo02`0oooo00<0oooO09a8000000000P0000001`0007@0_ooo
0?ooo`3oool0omnL04P00018W=l00`3oool01P2oM00004RL0=ooo`3ogi`0B00004RLg`<0oooo00H0
_g@00018W03Oool0omnL04P00018W=l30?ooo`030;md0000B9`0gooo02h0oooo00X0_g@00000B02L
gol0omnL04Q8W03Oool0oooo0?oOW0180000B9cO0`3oool01P2oM00004RL0=ooo`3ogi`0B00004RL
g`<0oooo00H0_g@00018W03Oool0omnL04P00018W=l30?ooo`030;md0000B9`0gooo00T0oooo001@
0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0?`3oool0203ooml0W4P007Bo
o`3oool0oooO09a80000B9`0gooo0P3oool01`3OW4P004RL0=ooo`3ooml0W4P00018W03Oool00P3o
ool01`3OW4P004RL0=ooo`3ooml0W4P00018W03Oool00P3oool00`3OW4P004RL0=ooo`0_0?ooo`04
0=nLB018W=l0_g@0001d_`80oooo00@0oooO09a80000B9`0gooo0P3oool01`3OW4P004RL0=ooo`3o
oml0W4P00018W03Oool00P3oool01`3OW4P004RL0=ooo`3ooml0W4P00018W03Oool00P3oool00`3O
W4P004RL0=ooo`0]0?ooo`030?oo_`1d000007Bo00D0oooo00@0oooO09a80000B9`0gooo0P3oool0
1`3OW4P004RL0=ooo`3ooml0W4P00018W03Oool00P3oool01`3OW4P004RL0=ooo`3ooml0W4P00018
W03Oool00P3oool00`3OW4P004RL0=ooo`0]0?ooo`030?oOW0180000M;oo0080oooo00L0okmd04RL
g`3oool0oooO09a80000B9`0gooo0080oooo00L0gia80018W03Oool0oooO09a80000B9`0gooo0080
oooo00L0gia80018W03Oool0oooO09a80000B9`0gooo0080oooo00<0gia80018W03Oool02@3oool0
0540oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`0o0?ooo`030?oo_`1d0000B9cO
0080oooo00<0omnL04P0001d_ol00P3oool01`3OW4P007Bo0?ooo`3oool0omnL04P0001d_ol00P3o
ool01`3OW4P007Bo0?ooo`3oool0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`0`0?ooo`04
0=nLB01dM7@0001d0;ooo`80oooo00<0omnL04P0001d_ol00P3oool01`3OW4P007Bo0?ooo`3oool0
omnL04P0001d_ol00P3oool01`3OW4P007Bo0?ooo`3oool0omnL04P0001d_ol00P3oool00`3OW4P0
07Bo0?ooo`0^0?ooo`030?oOW0180000B9cO00D0oooo00<0omnL04P0001d_ol00P3oool01`3OW4P0
07Bo0?ooo`3oool0omnL04P0001d_ol00P3oool01`3OW4P007Bo0?ooo`3oool0omnL04P0001d_ol0
0P3oool00`3OW4P007Bo0?ooo`0]0?ooo`030?oOW01804P0W=oo0080oooo00L0okmd0018W03Oool0
oooo0?oOW0180000M;oo0080oooo00L0gia8001d_`3oool0oooo0?oOW0180000M;oo0080oooo00L0
gia8001d_`3oool0oooo0?oOW0180000M;oo0080oooo00<0gia8001d_`3oool02@3oool00580oooo
00H0gia80000M02oool0oooO09a80018W=ll0?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cO
o`030?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO0`3oool01P3OW4P0001d0;ooo`3ooml0W4P0
04RLg`<0oooo00H0gia80000M02oool0oooO09a80018W=lb0?ooo`030;md000004P0W=oo00<0oooo
00H0gia80000M02oool0oooO09a80018W=l30?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO0`3o
ool01P3OW4P0001d0;ooo`3ooml0W4P004RLgc00oooo00@0oooO09a8000007@0_ooo103oool01P3O
W4P0001d0;ooo`3ooml0W4P004RLg`<0oooo00H0gia80000M02oool0oooO09a80018W=l30?ooo`06
0=nLB00007@0_ooo0?oog`2LB000B9cO;P3oool00`3ooml0W4P004RLg`020?ooo`030;md0000M;l0
oooo0080oooo00H0gia80000M02oool0oooO09a80018W=l30?ooo`060=nLB00007@0_ooo0?oog`2L
B000B9cO0`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`X0oooo001C0?ooo`040=nLB0000000
0000001d_ch0oooo00D0omnL04P000000000000007Boo`050?ooo`040=nLB00000000000001d_`D0
oooo00@0gia800000000000007Bo1@3oool0103OW4P0000000000000M;lc0?ooo`030?oog`2LB000
B9cO00@0oooo00@0gia800000000000007Bo1@3oool0103OW4P0000000000000M;l50?ooo`040=nL
B00000000000001d_c<0oooo00@0oono07@000000000B9cO0`3oool0103OW4P0000000000000M;l5
0?ooo`040=nLB00000000000001d_`D0oooo00@0gia800000000000007Bo<03oool01@3ooml0W4P0
00000000000007Bo00D0oooo00@0gia800000000000007Bo1@3oool0103OW4P0000000000000M;l5
0?ooo`040=nLB00000000000001d_`/0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo001<0?ooool00000C@00000H0?ooo`00C03oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool00000603oool004`0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool0C@3oool00`000000oooo0?ooo`1=0?ooo`040000003oool0oooo000001P0oooo001<
0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0F0?ooo`00C03oool00`00
0000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool05P3oool004`0oooo00<000000?ooo`3o
ool04@3oool2000002D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02000000`0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`800000203oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool0
0`000000oooo000000050?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0F0?ooo`00C03oool00`000000oooo0?ooo`0:0?ooo`030000003oool00000
00@0oooo0P0000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo00000002
0?ooo`040000003oool0oooo0?ooo`8000000P3oool2000000030?ooo`000000oooo008000000`3o
ool00`000000oooo0?ooo`02000000030?ooo`000000oooo008000000P3oool01P000000oooo0000
00000000oooo00000080oooo0`000000103oool000000?ooo`0000040?ooo`050000003oool0oooo
0?ooo`0000000P3oool01P000000oooo0000003oool000000?ooo`80000000H0oooo000000000000
oooo0000003oool2000000030?ooo`00000000000080000000H0oooo0000003oool0oooo0000003o
ool300000080oooo0P0000020?ooo`030000003oool0oooo00D00000103oool200000080oooo0P00
00000`3oool00000000000030?ooo`060000003oool000000?ooo`000000oooo0P0000080?ooo`03
0000003oool0oooo0080oooo0P0000030?ooo`030000003oool0oooo008000000`3oool800000004
0?ooo`0000000000000000<0oooo00D000000?ooo`000000oooo000000020?ooo`80000000@0oooo
0000003oool0oooo100000020?ooo`040000003oool0oooo0?ooo`X0000000H0oooo000000000000
oooo0000003oool2000000030?ooo`0000000000008000000`3oool010000000oooo0?ooo`3oool2
000000030?ooo`000000oooo00@0oooo00D000000?ooo`00000000000?ooo`0700000080oooo1000
0000103oool000000000000000030?ooo`8000000P3oool010000000oooo0000003oool2000000D0
oooo0`0000001@3oool000000?ooo`000000oooo008000000`3oool6000000P0oooo00<000000?oo
o`3oool05P3oool004`0oooo0P0000070?ooo`L0000000<0oooo0000000000001P3oool00`000000
oooo00000003000000040?ooo`000000oooo00000080oooo0P0000020?ooo`8000000P3oool20000
00030?ooo`000000oooo0080000000<0oooo0000003oool0100000020?ooo`@000000P3oool60000
00030?ooo`00000000000080000000@0oooo00000000000000001P3oool010000000oooo00000000
00030?ooo`<0000000@0oooo000000000000oooo300000001P3oool000000000003oool000000?oo
o`L000000P3oool00`000000oooo0?ooo`07000000030?ooo`00000000000080oooo00@000000?oo
o`000000oooo0P0000020?ooo`H0000000@0oooo00000000000000000`3oool3000000040?ooo`00
000000000?ooo`80000000H0oooo0000003oool000000?ooo`0000020?ooo`80000000<0oooo0000
003oool0200000000`3oool0000000000002000000030?ooo`00000000000080000000@0oooo0000
003oool0oooo0P0000001P3oool000000?ooo`3oool000000?ooo`8000000P3oool2000000030?oo
o`000000000000D000000P3oool7000000030?ooo`000000000000D000000P3oool2000000030?oo
o`000000oooo0080000000@0oooo0000003oool0oooo0P0000000`3oool000000000000200000003
0?ooo`000000000000D0000000<0oooo000000000000200000000`3oool000000000000200000005
0?ooo`000000oooo0000003oool00`0000020?ooo`040000003oool000000?ooo`<0000000<0oooo
0000000000000P0000020?ooo`L000001`3oool2000001P0oooo000^0?ooo`030=nLB00000000000
00<0000000H0B9cO0?ooo`3oool0omnL04P0001d_ol20?ooo`060?oOW0180000000000000000B9`0
gooo2P3oool00`000000oooo0?ooo`060?ooo`@0000000@0oooo0000003oool0oooo0P0000060?oo
o`030000003oool0000000800000103oool200000080oooo00<000000?ooo`3oool01@0000000`3o
ool000000?ooo`040?ooo`030000003oool0000000<0000000<0oooo0000003oool00`0000020?oo
o`80000000<0oooo0000000000000P3oool3000000<0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`02000000<0oooo00H000000?ooo`3oool0oooo0000003oool8000000040?oo
o`000000oooo00000080oooo0`0000000`3oool0000000000003000000L0oooo0`0000020?ooo`80
000000<0oooo0000003oool00P3oool010000000oooo0000003oool200000080oooo1@0000020?oo
o`030000003oool0000000<0oooo0`0000000`3oool0000000000003000000030?ooo`000000oooo
008000000P3oool01@000000oooo0000003oool000000080oooo0P0000020?ooo`030000003oool0
000000<0000000<0oooo0000003oool0100000040?ooo`040000003oool0oooo00000080oooo00T0
00000?ooo`3oool000000?ooo`000000oooo0000003oool01@000000203oool000000?ooo`3oool0
00000?ooo`000000oooo0P0000040?ooo`030000003oool00000008000000P3oool2000000040?oo
o`000000oooo0?ooo`8000000`3oool2000000060?ooo`00000000000?ooo`000000oooo10000002
0?ooo`030000003oool0000000H000000P3oool6000000D0oooo0`0000020?ooo`040000003oool0
oooo0?ooo`H0000000L0oooo0000003oool0oooo0000003oool000000080oooo0P0000080?ooo`03
0000003oool0oooo01H0oooo000_0?ooo`030?noM000M;l0oooo0080oooo00H0_gAd0;ooo`3oool0
omnL04P0001d_ol20?ooo`060?noM0000000M;oo0?ooo`3ogi`0B7Bo2P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`00000000000P3oool00`000000oooo
0?ooo`05000000030?ooo`000000oooo00H0oooo100000000`3oool000000?ooo`02000000<0oooo
00<000000?ooo`3oool01@3oool2000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`02000000<0oooo0P0000020?ooo`040000003oool000000?ooo`80000000H0oooo0000003o
ool000000?ooo`0000050?ooo`80000000<0oooo000000000000100000060?ooo`<000001P3oool0
20000000oooo0?ooo`000000oooo0000003oool000000`3oool2000000030?ooo`00000000000080
oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0?oo
o`000000oooo0P0000020?ooo`030000003oool000000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`03000000@0oooo0`0000030?ooo`8000000P3oool01@000000oooo0?oo
o`000000oooo0080000000<0oooo0000000000000P3oool00`000000oooo0?ooo`02000000030?oo
o`000000oooo00<0oooo00@000000?ooo`3oool000001P3oool300000080oooo0P0000040?ooo`<0
0000103oool00`000000oooo0?ooo`040?ooo`<0000000@0oooo0000003oool0oooo0`0000000`3o
ool00000000000020?ooo`D0000000D0oooo0000003oool0oooo000000020?ooo`<000000P3oool0
1P000000oooo0?ooo`3oool000000?ooo`<000000P3oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`00<03oool00`3o_g@0
07Bo0?ooo`0>0?ooo`030?noM018W=l0oooo00P0oooo00<000000?ooo`3oool01@3oool200000080
oooo00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3oool0203oool200000003
0?ooo`000000oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool0000000T0oooo00@00000
0?ooo`3oool0oooo1@00000F0?ooo`040000003oool00000000000D0oooo00D000000?ooo`3oool0
00000?ooo`03000000070?ooo`000000oooo0?ooo`000000oooo000000060?ooo`040000003oool0
oooo0?ooo`@000001P3oool3000000H0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`3oool2000000060?ooo`000000oooo0000003oool00000103oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo
0`0000050?ooo`80000000<0oooo0000003oool00`3oool3000000030?ooo`000000oooo00800000
1@3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000040?ooo`80
00001`3oool00`000000oooo000000020?ooo`8000000P3oool2000000030?ooo`000000000000D0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo0`0000020?ooo`80000000<0oooo0000003oool00`3oool2000000P0oooo00<000000?oo
o`3oool05P3oool00340oooo00<0okmd001d_`3oool03@3oool00`3ookl0M01d0;ooo`080?ooo`03
0000003oool0oooo00D0oooo0P0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool000000P3o
ool01P000000oooo0000003oool000000?ooo`8000000`3oool020000000oooo0?ooo`3oool00000
0?ooo`000000oooo0P0000020?ooo`80000000<0oooo0000000000001@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000P0000020?ooo`030000003o
ool0oooo00@0oooo0P0000020?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000
0P3oool3000000030?ooo`000000oooo00<0oooo00<000000?ooo`0000000P0000000`3oool00000
0?ooo`050?ooo`800000203oool01`000000oooo0000003oool000000?ooo`000000103oool00`00
0000oooo0?ooo`0200000080oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000<0oooo0P0000050?ooo`80000000@0oooo0000003oool000000`3oool2
000000030?ooo`000000oooo008000001@3oool00`000000oooo0?ooo`080?ooo`8000001`3oool0
0`000000oooo0?ooo`060?ooo`040000003oool00000000000<0oooo00<000000?ooo`0000000P3o
ool00`000000oooo0?ooo`040?ooo`<00000103oool00`000000oooo000000040?ooo`<0000000D0
oooo000000000000oooo000000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`00
00001P3oool00`000000oooo0000000200000080oooo0P0000000`3oool000000?ooo`030?ooo`80
0000203oool00`000000oooo0?ooo`0F0?ooo`008@3oool00`3ooml0W4P0000000070000000304RL
g`3oool0oooo00@0oooo00<0okmd04RLg`3oool0303oool00`3ooml0W4P007Boo`080?ooo`030000
003oool0oooo00D0oooo00@000000?ooo`000000oooo0P0000020?ooo`80000000<0oooo0000003o
ool00`0000000`3oool00000000000030?ooo`030000003oool0000000D0oooo00<000000?ooo`00
00000P0000001@3oool00000000000000000oooo00@0000000<0oooo0000003oool0100000001@3o
ool00000000000000000oooo00@0000000<0oooo0000000000000P000000103oool000000000003o
ool200000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0200000080oooo0`00
00020?ooo`030000003oool0000000@000000P3oool2000000<0oooo0P0000020?ooo`030000003o
ool0oooo00<0000000<0oooo0000003oool00P0000000`3oool000000?ooo`03000000030?ooo`00
000000000080000000<0oooo0000003oool00P0000000`3oool0000000000006000000030?ooo`00
0000000000<000001@3oool00`000000oooo0000000200000080oooo0P000000103oool000000000
003oool4000000030?ooo`00000000000080oooo0`000000103oool000000?ooo`3oool200000007
0?ooo`000000oooo0000003oool000000?ooo`02000000030?ooo`000000oooo00<000000P3oool0
0`000000oooo000000020?ooo`L0000000@0oooo00000000000000000`3oool00`000000oooo0000
0002000000<0oooo00H000000?ooo`000000oooo0000003oool300000080oooo1P0000040?ooo`03
0000003oool000000080000000T0oooo0000003oool0oooo0000003oool000000?ooo`0000000P3o
ool3000000050?ooo`00000000000000003oool00P000000103oool000000000003oool200000004
0?ooo`00000000000?ooo`<000000P3oool01@000000oooo0000003oool000000080oooo1@000002
0?ooo`040000003oool0000000000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0F0?ooo`00<`3oool00`3OW4P0B9cO0?ooo`0;0?ooo`030?oo_`1d0000B9cO00P0oooo0`000005
0?ooo`030000003oool000000080oooo0P0000000`3oool0000000000002000000040?ooo`000000
000000000080oooo0P0000040?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`80
00000P3oool2000000030?ooo`000000oooo00@0000000@0oooo00000000000000000P3oool20000
00030?ooo`000000000000<0000000H0oooo000000000000oooo0000003oool7000000T0oooo0`00
00020?ooo`<000000P3oool010000000oooo0000003oool800000080oooo00H000000?ooo`3oool0
oooo0000003oool4000000030?ooo`000000oooo0080000000L0oooo0000003oool000000?ooo`00
0000oooo00@0000000H0oooo0000003oool0oooo0000003oool8000000030?ooo`000000000000D0
00000`3oool01P000000oooo0000003oool000000?ooo`D000000P3oool4000000030?ooo`000000
00000080oooo1@0000000`3oool00000000000020?ooo`040000003oool000000?ooo`@0000000@0
oooo0000003oool0oooo0P0000001@3oool000000000003oool000000080oooo1`0000001`3oool0
0000000000000000oooo0000003oool01`0000001@3oool00000000000000000oooo00D0000000D0
oooo00000000000000000?ooo`03000000@0oooo00<000000?ooo`0000000P3oool2000000030?oo
o`000000000000D0000000<0oooo0000003oool0200000000`3oool00000000000020?ooo`050000
003oool000000000003oool00P0000030?ooo`060000003oool000000?ooo`000000oooo1`000002
0?ooo`<0000000<0oooo0000000000001P3oool3000001P0oooo000d0?ooo`030;md001d_ol0oooo
00X0oooo00<0okmd0000001d_ol0203oool00`000000oooo0?ooo`060?ooo`060000003oool00000
0000003oool000000P3oool2000000H0oooo00<000000?ooo`0000000`0000020?ooo`@0000000<0
oooo0000003oool00P3oool00`000000oooo00000004000000030?ooo`000000oooo00@0000000<0
oooo0000003oool00`3oool2000000050?ooo`000000oooo0000003oool0100000000`3oool00000
00000002000000030?ooo`000000000000H0oooo0P000000103oool000000000000000020?ooo`80
00000P3oool2000000030?ooo`00000000000080000000<0oooo0000000000000`000000203oool0
00000?ooo`3oool000000?ooo`000000oooo1P0000040?ooo`030000003oool0000000@000001`3o
ool00`000000oooo0?ooo`050?ooo`H0000000@0oooo0000000000000000103oool01`000000oooo
0?ooo`000000oooo0000003oool00`0000030?ooo`050000003oool000000?ooo`0000000`3oool7
000000030?ooo`000000oooo00<000000P3oool3000000040?ooo`000000oooo0?ooo`80000000<0
oooo0000003oool00P3oool300000080oooo00D000000?ooo`3oool000000?ooo`0500000080oooo
0P0000000`3oool000000000000:00000080oooo0P0000001@3oool000000?ooo`3oool0000000H0
oooo00<000000?ooo`0000000P0000000`3oool0000000000003000000030?ooo`000000oooo00X0
000000D0oooo0000003oool0oooo000000030?ooo`030000003oool00000008000000P3oool00`00
0000oooo000000020?ooo`80000000<0oooo0000000000000`000000103oool00000000000000002
0?ooo`800000203oool00`000000oooo0?ooo`0F0?ooo`00=03oool00`3ogi`0B01d0;ooo`070?oo
o`060?oOg`3Oool0okmd0000000007@0_ooo203oool00`000000oooo0?ooo`060?ooo`030000003o
ool0000000<000000P3oool02P000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool4
00000080oooo00<000000?ooo`0000000P3oool01P000000oooo0?ooo`3oool000000?ooo`800000
00<0oooo0000000000000P3oool00`000000oooo0?ooo`05000000<0oooo00<000000?ooo`000000
103oool01`000000oooo000000000000oooo0000003oool00P0000020?ooo`800000103oool30000
00040?ooo`000000000000000080oooo0P0000020?ooo`80000000<0oooo0000000000000`000000
103oool000000000003oool300000080oooo0`000000103oool000000000003oool4000000<0oooo
00<000000?ooo`000000100000030?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo1P000000103oool000000000000000030?ooo`800000103oool00`000000oooo0000
0002000000L0oooo00<000000?ooo`000000100000020?ooo`040000003oool0000000000080oooo
00@000000?ooo`3oool0oooo0`000000103oool000000?ooo`3oool2000000040?ooo`000000oooo
0?ooo`<000001P3oool2000000040?ooo`0000000000000000<0oooo0`0000001@3oool000000000
00000000oooo00<0000000D0oooo00000000000000000?ooo`03000000030?ooo`000000oooo0080
00001P3oool500000080oooo00@000000?ooo`3oool0oooo0P0000001`3oool00000000000000000
oooo0000003oool0100000001P3oool000000?ooo`3oool000000?ooo`<0000000@0oooo00000000
000000000P3oool010000000oooo0000003oool3000000050?ooo`00000000000?ooo`0000000P3o
ool00`000000oooo00000004000000P0oooo00<000000?ooo`3oool05P3oool003@0oooo00<0oooO
09a8001d_ol01`3oool01@3ookl0M0000000000004P0W=oo00T0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`03000000D0oooo0P000000103oool000000?ooo`0000020?ooo`<00000
0`3oool010000000oooo0?ooo`0000030?ooo`80000000H0oooo00000000000000000?ooo`000002
0?ooo`040000003oool0oooo0?ooo`80000000<0oooo000000000000103oool010000000oooo0?oo
o`3oool2000000030?ooo`00000000000080oooo0`000000103oool000000?ooo`0000040?ooo`06
0000003oool000000?ooo`000000oooo0P0000000`3oool00000000000030?ooo`050000003oool0
00000000003oool0100000020?ooo`<000000P3oool3000000030?ooo`000000000000H000000P3o
ool010000000oooo0000003oool3000000<0oooo00@000000?ooo`000000oooo0`0000001@3oool0
00000?ooo`000000oooo0080000000D0oooo0000003oool000000?ooo`02000000<0oooo0`000003
0?ooo`030000003oool0oooo00<0000000D0oooo0000003oool000000?ooo`03000000030?ooo`00
0000000000D000000P3oool2000000H0oooo0`000000103oool000000?ooo`3oool2000000060?oo
o`000000oooo0?ooo`000000oooo0P0000020?ooo`030000003oool0oooo0080000000<0oooo0000
000000000P0000000`3oool0000000000002000000050?ooo`00000000000000003oool01`000000
1`3oool000000?ooo`000000oooo0000003oool0100000030?ooo`H0000000@0oooo000000000000
00000P3oool200000080oooo100000000`3oool000000?ooo`02000000@0oooo00<000000?ooo`00
00000P0000000`3oool00000000000070?ooo`030000003oool0000000D000000P3oool00`000000
oooo0?ooo`04000000P0oooo00<000000?ooo`3oool05P3oool003@0oooo00<0oono07@00018W=l0
203oool00`3OW9`0_ooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`000000
103oool2000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo0000
00<0oooo0P0000020?ooo`80000000<0oooo0000003oool00P0000030?ooo`030000003oool0oooo
0080000000<0oooo0000000000000P0000020?ooo`80000000D0oooo0000003oool000000?ooo`04
000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`02
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000001`0000001@3oool000000000
00000000oooo0080000000<0oooo00000000000010000000103oool000000000000000040?ooo`D0
00000`3oool300000080oooo100000001`3oool000000000003oool000000?ooo`0000000`3oool2
000000<0oooo0P0000000`3oool000000?ooo`0200000080oooo0`0000001@3oool000000?ooo`00
0000oooo00<0000000D0oooo00000000000000000?ooo`0:000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`80000000<0oooo0000000000000P3oool300000080oooo00<000000?ooo`3o
ool02@0000000`3oool000000?ooo`02000000030?ooo`000000oooo0080000000<0oooo00000000
00000P0000030?ooo`040000003oool000000?ooo`@000000P3oool4000000040?ooo`0000000000
0?ooo`L000000P3oool4000000040?ooo`000000oooo000000<0oooo00@000000?ooo`000000oooo
0`0000000`3oool00000000000030?ooo`040000003oool0oooo00000080oooo0P000000103oool0
00000000000000020?ooo`<0000000@0oooo0000000000000000203oool00`000000oooo0?ooo`0F
0?ooo`00<03oool01`3o_g@004RL0=ooo`3oool0gia80000B02Lgol0203oool00`3ogi`0M9cO0?oo
o`0:0?ooo`030000003oool0oooo00L0oooo1P0000001@3oool000000000003oool0000000@0oooo
00<000000?ooo`0000000P0000020?ooo`<000000P3oool200000080oooo0P0000030?ooo`030000
003oool0000000<0000000<0oooo0000003oool0103oool00`000000oooo0000000300000080oooo
0P0000001@3oool000000?ooo`000000oooo008000001@3oool00`000000oooo000000030?ooo`H0
00000`3oool2000000040?ooo`00000000000?ooo`<0000000<0oooo0000000000001P0000000`3o
ool0000000000004000000030?ooo`00000000000080oooo00<000000?ooo`0000000`3oool30000
00030?ooo`00000000000080000000<0oooo0000000000001`000000103oool000000?ooo`000002
0?ooo`8000000P3oool200000080oooo0P0000000`3oool0000000000002000000040?ooo`000000
00000?ooo`@000000`3oool2000000030?ooo`000000000000<000000P3oool8000000030?ooo`00
0000000000H0oooo00<000000?ooo`3oool01@0000030?ooo`<0000000<0oooo0000000000000`00
00020?ooo`80000000<0oooo0000000000000P0000030?ooo`030000003oool000000080000000@0
oooo0000003oool0oooo0P0000000`3oool000000?ooo`05000000040?ooo`00000000000?ooo`@0
000000<0oooo0000000000001@000000103oool000000000003oool4000000030?ooo`0000000000
0080oooo0`0000001P3oool00000000000000000oooo000000@0oooo00D000000?ooo`0000000000
0?ooo`0200000080oooo10000000103oool000000000000000020?ooo`<000001`3oool00`000000
oooo0?ooo`0F0?ooo`00<@3oool01@3ogi`0B000000000000000M;oo00X0oooo00D0_g@000000000
0000000004RLg`070?ooo`8000001@3oool00`000000oooo0?ooo`03000000040?ooo`000000oooo
0?ooo`8000001P3oool500000080oooo100000020?ooo`030000003oool0000000<0000000<0oooo
0000003oool0100000020?ooo`030000003oool0000000<0000000<0oooo0000003oool00P000004
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo00000002
0?ooo`<0000000@0oooo00000000000000000`3oool2000000040?ooo`00000000000?ooo`<00000
0`3oool4000000030?ooo`000000oooo00D0000000<0oooo0000000000000P0000030?ooo`800000
0P3oool300000080oooo0`0000000`3oool000000?ooo`02000000030?ooo`000000oooo00800000
0P3oool00`000000oooo0?ooo`03000000<0oooo00<000000?ooo`3oool01@0000000`3oool00000
0?ooo`03000000030?ooo`0000000000008000000P3oool2000000<0oooo0P0000000`3oool00000
0?ooo`08000000040?ooo`0000000000000000L0oooo1@000000103oool000000?ooo`3oool30000
00040?ooo`00000000000?ooo`80000000<0oooo0000000000000`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`04000000050?ooo`00000000000000003oool00`0000001P3oool000000?ooo`3oool00000
0?ooo`80000000H0oooo0000003oool0oooo0000003oool2000000030?ooo`000000000000@00000
0P3oool200000080oooo00<000000?ooo`0000000P3oool4000000040?ooo`00000000000?ooo`80
00000P3oool01@000000oooo0000003oool000000080oooo0`0000060?ooo`800000603oool004`0
oooo00<000000?ooo`3oool0103oool300000080oooo00D000000?ooo`3oool0oooo000000040?oo
o`040000003oool0oooo0?ooo`8000000`3oool01P000000oooo000000000000oooo00000080oooo
00h000000?ooo`00000000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0
oooo100000000`3oool0000000000004000000<0oooo00<000000?ooo`0000000`3oool010000000
oooo0?ooo`3oool3000000030?ooo`000000oooo00<000000P3oool00`000000oooo000000040?oo
o`80000000<0oooo0000003oool01@0000040?ooo`040000003oool0oooo0?ooo`D0000000<0oooo
0000000000000`0000020?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0000000<0
oooo0000003oool00`3oool00`000000oooo00000006000000050?ooo`000000oooo0000003oool0
0P000000103oool000000000003oool2000000080?ooo`00000000000?ooo`000000oooo0000003o
ool3000000030?ooo`000000oooo00D0000000@0oooo0000003oool000000P3oool3000000<0oooo
0P0000000`3oool00000000000020?ooo`060000003oool0oooo0?ooo`000000oooo0P0000030?oo
o`030000003oool0oooo0080000000<0oooo000000000000203oool00`000000oooo000000020?oo
o`060000003oool000000?ooo`000000oooo0`0000000`3oool000000?ooo`03000000040?ooo`00
00000000000000<0oooo0`0000030?ooo`H00000103oool2000000040?ooo`000000oooo000000<0
oooo2@0000000`3oool00000000000030?ooo`@000002@3oool00`000000oooo0?ooo`0F0?ooo`00
C03oool00`000000oooo0?ooo`050?ooo`8000000P3oool00`000000oooo0?ooo`05000000030?oo
o`000000oooo0080oooo0P0000030?ooo`040000003oool00000000000@0oooo00<000000?ooo`3o
ool00P3oool01P000000oooo0?ooo`3oool000000?ooo`<000000`3oool7000000030?ooo`000000
0000008000000P3oool010000000oooo0000000000020?ooo`<0000000<0oooo0000000000000P00
00000`3oool000000000000200000080oooo0`0000020?ooo`050000003oool0oooo0000003oool0
100000000`3oool0000000000002000000H0oooo100000020?ooo`<0000000@0oooo0000003oool0
oooo100000040?ooo`040000003oool0oooo000000<0oooo0P0000000`3oool000000?ooo`020?oo
o`090000003oool0oooo0000003oool000000?ooo`000000oooo008000000`3oool01`000000oooo
0?ooo`000000oooo0000003oool01P000000103oool000000000003oool2000000040?ooo`000000
00000?ooo`D000000P3oool01P000000oooo0000003oool000000?ooo`80000000T0oooo00000000
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo00000004000000060?ooo`00
0000oooo0?ooo`000000oooo0P0000000`3oool0000000000003000000030?ooo`00000000000080
oooo0P0000001@3oool000000000003oool000000080oooo0P0000000`3oool000000?ooo`030?oo
o`8000000P3oool010000000oooo0000003oool3000000040?ooo`000000000000000080oooo0`00
00020?ooo`80000000<0oooo0000003oool0100000000`3oool000000?ooo`040?ooo`8000000P3o
ool00`000000oooo0?ooo`020?ooo`D0000000<0oooo0000003oool0100000040?ooo`80000000<0
oooo0000003oool01`3oool00`000000oooo0?ooo`0F0?ooo`00C03oool00`000000oooo0?ooo`05
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo00000002000000030?ooo`00
0000oooo00T0oooo00<000000?ooo`3oool00P3oool2000000<0oooo0P000000103oool000000000
000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0100000000`3oool00000
0?ooo`0200000080oooo00@000000?ooo`3oool000000P3oool3000000080?ooo`00000000000?oo
o`000000oooo0000003oool200000080oooo0`0000020?ooo`050000003oool000000000003oool0
100000020?ooo`@00000103oool00`000000oooo00000003000000D0oooo00H000000?ooo`3oool0
oooo0000003oool6000000030?ooo`000000oooo0080oooo00<000000?ooo`0000000P0000030?oo
o`80000000D0oooo000000000000oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P0000000`3oool0000000000003000000050?ooo`00000000000000003oool00P00
0000103oool000000000003oool6000000060?ooo`00000000000000003oool000000P3oool01P00
0000oooo000000000000oooo00000080oooo0P0000020?ooo`D0000000D0oooo0000000000000000
0?ooo`05000000030?ooo`000000000000H000000P3oool;000000030?ooo`000000oooo00800000
00H0oooo00000000000000000?ooo`0000020?ooo`T000000`3oool00`000000oooo0?ooo`040000
00030?ooo`000000000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02
00000080oooo00@000000?ooo`3oool000000P3oool2000000030?ooo`000000000000<000000`3o
ool00`000000oooo00000002000000P0oooo00<000000?ooo`3oool05P3oool004`0oooo00<00000
0?ooo`3oool0203oool00`000000oooo000000040?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`00000000001P3oool01@000000oooo0?ooo`000000oooo0080000000@0oooo0000003o
ool0oooo0P0000030?ooo`8000000`3oool00`000000oooo0?ooo`02000000<0oooo00@000000?oo
o`3oool0oooo100000020?ooo`@000000P3oool2000000<0oooo00H000000?ooo`3oool000000?oo
o`0000070?ooo`@0000000<0oooo0000000000000P3oool010000000oooo0?ooo`0000020?ooo`<0
00000P3oool00`000000oooo0000000300000080oooo0P0000001@3oool00000000000000000oooo
00L0000000@0oooo0000003oool000000P3oool2000000<0oooo1@0000000`3oool000000?ooo`03
00000080oooo00<000000?ooo`0000000P3oool2000000H0oooo0P0000001P3oool000000000003o
ool000000?ooo`80000000<0oooo0000000000000P3oool3000000030?ooo`000000000000800000
0`3oool3000000060?ooo`00000000000?ooo`000000oooo0P0000000`3oool000000?ooo`020?oo
o`030000003oool0000000<0000000D0oooo00000000000000000?ooo`08000000030?ooo`000000
000000/000000P3oool2000000050?ooo`000000oooo0000003oool00P0000001@3oool000000000
00000000oooo00H0000000<0oooo0000000000000P3oool3000000040?ooo`000000oooo00000080
oooo00<000000?ooo`3oool00P000000103oool000000000003oool300000080oooo0`0000001P3o
ool000000000003oool000000?ooo`H000000P3oool5000000P0oooo00<000000?ooo`3oool05P3o
ool004`0oooo00<000000?ooo`3oool01P3oool010000000oooo0000003oool2000000060?ooo`00
0000oooo0?ooo`000000oooo0P0000000`3oool000000?ooo`02000000<0oooo00@000000?ooo`3o
ool000000P3oool400000080oooo00@000000?ooo`0000000000103oool00`000000oooo0?ooo`04
0?ooo`80000000<0oooo0000003oool00P3oool01P000000oooo000000000000oooo00000080oooo
100000020?ooo`8000000`3oool4000000030?ooo`000000oooo00<0oooo00@000000?ooo`3oool0
oooo0P000000103oool000000?ooo`0000020?ooo`060000003oool000000?ooo`000000oooo0P00
00030?ooo`030000003oool0000000<000000`3oool00`000000oooo00000003000000<0oooo0`00
00020?ooo`030000003oool0oooo00@0oooo00/000000?ooo`00000000000?ooo`000000oooo0000
003oool000000?ooo`02000000030?ooo`000000000000800000103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo008000000`3oool2000000D0oooo00<000000?ooo`0000000P3oool2
00000080oooo00<000000?ooo`000000103oool010000000oooo0000003oool2000000040?ooo`00
0000oooo0?ooo`8000000`3oool2000000040?ooo`000000000000000080oooo1@0000000`3oool0
000000000006000000050?ooo`00000000000000003oool00P000000103oool000000?ooo`000003
0?ooo`@000000`3oool00`000000oooo00000003000000030?ooo`000000000000<000000P3oool2
000000070?ooo`000000oooo0?ooo`000000oooo000000020?ooo`80000000D0oooo000000000000
oooo000000030?ooo`@0000000@0oooo00000000000000000`3oool200000080oooo00<000000?oo
o`0000001@0000080?ooo`030000003oool0oooo01H0oooo001<0?ooo`030000003oool0oooo00D0
oooo0P0000030?ooo`D0000000<0oooo0000003oool00P0000000`3oool000000?ooo`02000000<0
oooo0`0000030?ooo`80000000D0oooo0000003oool0oooo000000020?ooo`<000002@3oool01000
0000oooo0?ooo`0000020?ooo`80000000<0oooo0000003oool01@3oool00`000000oooo00000002
0?ooo`80000000<0oooo0000003oool00`0000020?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo0P0000001@3oool000000?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`80000000<0oooo0000003o
ool00P3oool2000000X0oooo00@000000?ooo`00000000000`3oool01@000000oooo0?ooo`3oool0
00000080oooo100000040?ooo`030000003oool0000000<0oooo0P0000001@3oool000000?ooo`3o
ool000000080oooo0P0000050?ooo`@0000000@0oooo000000000000oooo0P0000020?ooo`800000
0P3oool02@000000oooo000000000000oooo0000003oool000000?ooo`02000000L0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0000000200000080oooo0P0000020?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`<000000P3oool00`000000oooo00000004000000<0oooo
00H000000?ooo`3oool000000?ooo`0000020?ooo`@000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030000
00@0oooo0P0000040?ooo`030000003oool0oooo0080oooo0P0000000`3oool00000000000090?oo
o`030000003oool0oooo01H0oooo001<0?ooo`8000001P3oool00`000000oooo0?ooo`040?ooo`D0
000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`020?ooo`<000000P3oool00`000000
oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`8000001P3oool00`000000oooo0?ooo`030?oo
o`030000003oool000000080000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`050?oo
o`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00H000000?ooo`3oool0oooo0000003oool2000000P0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool00`3oool6
000000050?ooo`000000oooo0?ooo`0000001P3oool2000000050?ooo`00000000000?ooo`000000
0P3oool3000000<0oooo0P0000050?ooo`030000003oool0000000<0oooo00H000000?ooo`3oool0
00000?ooo`0000020?ooo`030000003oool0000000D0oooo0P0000040?ooo`8000000`3oool01@00
0000oooo0000003oool000000080oooo0`0000020?ooo`060000003oool000000000003oool00000
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00800000103oool200000080oooo
00<000000?ooo`000000303oool2000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`8000002`3oool2000001P0oooo001<0?ooo`030000003oool0oooo00T0oooo00D0
00000?ooo`3oool000000?ooo`03000000040?ooo`000000oooo000000L0oooo0P0000030?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`0000030?ooo`040000003oool00000
00000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`800000103oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080000000<0oooo0000000000000P3oool0
1P000000oooo0?ooo`3oool000000?ooo`80000000D0oooo0000003oool0oooo000000020?ooo`04
0000003oool00000000000D0oooo00@000000?ooo`3oool000002@3oool01@000000oooo0?ooo`3o
ool000000080oooo00D000000?ooo`3oool000000?ooo`02000000<0oooo00<000000?ooo`3oool0
0P0000000`3oool0000000000003000000060?ooo`000000oooo0000003oool000000`3oool00`00
0000oooo0?ooo`02000000050?ooo`000000oooo0?ooo`0000000P3oool200000080oooo00<00000
0?ooo`0000001P3oool00`000000oooo000000060?ooo`030000003oool000000080oooo00<00000
0?ooo`0000002@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo0P00
00000`3oool000000?ooo`03000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool00P3o
ool2000000030?ooo`000000oooo00@0oooo0P0000020?ooo`030000003oool0000000`0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`8000000`3oool2000000030?ooo`00
0000oooo00T0oooo00<000000?ooo`3oool05P3oool004`0oooo00<000000?ooo`3oool02@3oool4
000000030?ooo`000000oooo00<0000000<0oooo0000003oool02`3oool00`000000oooo00000002
0?ooo`030000003oool0000000<0oooo0P000000103oool000000000000000040?ooo`040000003o
ool0oooo00000080oooo00P000000?ooo`000000oooo0000003oool000000?ooo`80000000D0oooo
000000000000oooo000000030?ooo`070000003oool0oooo0000003oool000000?ooo`02000000<0
oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`<0000000H0oooo0000
003oool000000?ooo`0000020?ooo`030000003oool0000000@0oooo0P0000000`3oool000000000
00030?ooo`<000000P3oool200000080oooo00<000000?ooo`3oool00`3oool01`000000oooo0?oo
o`3oool000000?ooo`000000103oool3000000<0oooo00<000000?ooo`3oool00P0000000`3oool0
00000?ooo`0200000080oooo00D000000?ooo`000000oooo000000030?ooo`80000000<0oooo0000
003oool0103oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`0000001P3oool00`00
0000oooo0000000=0?ooo`030000003oool0oooo00L0oooo0P0000000`3oool000000?ooo`020?oo
o`8000001P3oool4000000030?ooo`000000oooo00T0oooo1P0000060?ooo`050000003oool00000
0?ooo`0000001`3oool00`000000oooo000000070?ooo`030000003oool0000000D0oooo00<00000
0?ooo`3oool00`0000020?ooo`80000000<0oooo0000003oool02@3oool00`000000oooo0?ooo`0F
0?ooo`00C03oool00`000000oooo0?ooo`0:0?ooo`<000000P3oool400000080oooo00@000000?oo
o`3oool00000103oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo008000000`3oool2000000H0oooo0P000000103oool00000
0?ooo`3oool200000080oooo0P0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool30000
0080oooo0P0000070?ooo`040000003oool0oooo00000080oooo00D000000?ooo`00000000000?oo
o`03000000D0oooo0P0000030?ooo`D000000`3oool3000000<0oooo00@000000?ooo`3oool00000
1@3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
008000001`3oool2000000040?ooo`000000oooo00000080oooo00@000000?ooo`3oool0oooo0`00
00020?ooo`040000003oool000000?ooo`<0000000<0oooo0000000000000P0000070?ooo`040000
003oool00000000000@0oooo00<000000?ooo`0000000`3oool010000000oooo0000003oool40000
00050?ooo`000000oooo0?ooo`0000001P3oool300000080oooo00<000000?ooo`0000000P3oool2
00000080oooo00<000000?ooo`0000001@3oool3000000030?ooo`000000oooo00D0oooo0P000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2000000030?ooo`000000
000000`0oooo00<000000?ooo`3oool05P3oool004`0oooo00<000000?ooo`3oool01P3oool40000
00050?ooo`000000oooo0000003oool00P0000020?ooo`<000000P3oool2000000070?ooo`000000
oooo0000003oool000000?ooo`02000000060?ooo`00000000000000003oool000001`3oool01000
0000oooo0000003oool2000000L0oooo0P0000020?ooo`050000003oool000000000003oool00P00
00050?ooo`040000003oool0oooo0?ooo`80000000@0oooo0000003oool000000P3oool00`000000
oooo000000020?ooo`<00000103oool2000000060?ooo`000000oooo0?ooo`000000oooo0`000002
0?ooo`030000003oool0oooo00<000000`3oool300000080oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000050?ooo`080000003oool000000?ooo`000000oooo0000003oool20000
0080oooo00@000000?ooo`3oool0oooo0`0000070?ooo`030000003oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`@000001P3oool300000080oooo00<0
00000?ooo`3oool00P0000020?ooo`80000000L0oooo00000000000000000?ooo`000000oooo00<0
000000<0oooo0000000000000`0000020?ooo`030000003oool000000080000000L0oooo00000000
000000000?ooo`000000oooo008000000P3oool00`000000oooo00000004000000060?ooo`000000
00000?ooo`000000oooo100000001`3oool000000?ooo`3oool000000?ooo`0000000P3oool01000
0000oooo0000003oool3000000@0oooo00@000000?ooo`3oool0oooo1@0000000`3oool000000000
0002000000<0oooo0`0000000`3oool000000?ooo`050?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool05P3oool004`0oooo
00<000000?ooo`3oool01P3oool6000000040?ooo`000000oooo00000080oooo0`0000000`3oool0
00000?ooo`02000000030?ooo`00000000000080oooo00<000000?ooo`3oool01@0000000`3oool0
00000?ooo`030?ooo`070000003oool000000000003oool000000?ooo`0200000080oooo00D00000
0?ooo`3oool000000?ooo`0200000080oooo0P0000020?ooo`@0000000<0oooo0000003oool01P3o
ool00`000000oooo0?ooo`02000000<0oooo0P0000000`3oool0000000000002000000060?ooo`00
0000oooo0000003oool000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool2
000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo0?ooo`<00000
0P3oool020000000oooo0?ooo`3oool000000?ooo`000000oooo0`0000000`3oool0000000000002
00000080oooo00@000000?ooo`000000oooo0`0000000`3oool000000?ooo`060?ooo`050000003o
ool0oooo0000003oool00P0000020?ooo`030000003oool0oooo0080oooo0P0000000`3oool00000
0?ooo`070?ooo`800000103oool200000080oooo0P0000000`3oool00000000000020?ooo`030000
003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`040000003oool000000000
00<0oooo0P0000000`3oool000000000000200000080oooo00D000000?ooo`00000000000?ooo`05
000000<0oooo00H000000?ooo`00000000000?ooo`0000020?ooo`060000003oool000000000003o
ool000000P3oool2000000@0oooo00<000000?ooo`3oool00`3oool200000080oooo00<000000?oo
o`0000000`0000030?ooo`<0000000<0oooo0000003oool01@3oool2000000030?ooo`000000oooo
00800000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo001<0?ooo`80
00002@3oool400000080oooo0P000000103oool000000000003oool400000080oooo00<000000?oo
o`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo0P0000020?ooo`060000003oool0
oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080
oooo0P0000001P3oool00000000000000000oooo00000080oooo00@000000?ooo`00000000001`3o
ool00`000000oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`000000
103oool00`000000oooo0?ooo`030?ooo`<0000000<0oooo0000003oool01`3oool2000000<0oooo
00<000000?ooo`3oool00`0000020?ooo`040000003oool000000?ooo`8000000P3oool2000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo000000020?ooo`8000000P3oool010000000
oooo0?ooo`3oool200000080oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0200000080oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`3oool2000000<0oooo00@000000?ooo`3oool0
0000103oool3000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`800000103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`00
0000oooo000000040?ooo`030000003oool0oooo0080oooo0`000000103oool0000000000000000;
0?ooo`800000603oool004`0oooo00<000000?ooo`3oool02P3oool01P000000oooo0?ooo`3oool0
00000?ooo`<0000000D0oooo000000000000oooo000000020?ooo`8000000`3oool00`000000oooo
0?ooo`040?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`00
0000oooo000000030?ooo`030000003oool0oooo00<0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000001@0oooo00<000000?ooo`0000000`3oool2000000<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0000000000030?ooo`800000103oool00`000000oooo0000000200000080
oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000<0oooo0P0000000`3o
ool0000000000002000000030?ooo`000000oooo00<0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0000000000050?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00`3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`80
00000`3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`0000004P3oool00`000000
oooo0?ooo`030?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`070000003oool0
00000?ooo`000000oooo000000040?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool0
5P3oool004`0oooo00<000000?ooo`3oool02P3oool00`000000oooo000000030?ooo`<0000000<0
oooo0000003oool0103oool2000000@0oooo00@000000?ooo`3oool000001@3oool010000000oooo
0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000<0oooo0P000000103oool000000?ooo`0000030?ooo`030000003o
ool0000000@0oooo10000000103oool000000?ooo`0000030?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo00000000
00090?ooo`030000003oool0oooo00H0oooo0P0000050?ooo`80000000D0oooo0000003oool00000
0?ooo`02000000P0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool000000?oo
o`000000503oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo008000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool000000080oooo0P0000020?ooo`050000003oool0oooo0?ooo`000000
1@3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00P0000040?ooo`040000003oool0oooo0?ooo`<00000103oool200000080oooo00<000000?oo
o`000000203oool00`000000oooo0?ooo`0F0?ooo`00C03oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`0000000000103oool00`000000oooo0?oo
o`030?ooo`<000000P3oool00`000000oooo000000060?ooo`80000000@0oooo0000003oool00000
1@3oool00`000000oooo0?ooo`030?ooo`D0000000<0oooo0000003oool00P3oool200000080oooo
0P00000B0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`05
0000003oool0oooo0?ooo`0000000`3oool2000000<0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`02000000@0oooo00H000000?ooo`00000000000?ooo`0000040?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
000000@0oooo000000000000oooo0P00000:0?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00`0000020?ooo`030000003oool0oooo008000000P3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00@0oooo0P0000080?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`0000002@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`800000
1@3oool200000080oooo0`0000080?ooo`030000003oool0oooo01H0oooo001<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000000`3oool0000000000004000000P0oooo
00D000000?ooo`000000oooo000000060?ooo`8000001@3oool3000000L0oooo00<000000?ooo`3o
ool00P0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`050?ooo`8000000`3oool2000000D0oooo0P000000103oool000000?ooo`3oool20000
00@0oooo0P0000000`3oool000000?ooo`050?ooo`060000003oool0oooo0000003oool000001@3o
ool2000000050?ooo`000000oooo0?ooo`0000000`3oool010000000oooo0000000000020?ooo`03
0000003oool0oooo00D0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0
00000080000000<0oooo0000003oool01`3oool01`000000oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool010000000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3oool01P3oool01P000000
oooo0?ooo`3oool000000?ooo`@000001@3oool01@000000oooo0000003oool0000000H0oooo00<0
00000?ooo`3oool02@3oool2000000T0oooo00<000000?ooo`3oool05P3oool004`0oooo00<00000
0?ooo`3oool0303oool2000000T0oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3o
ool0000000@0oooo0P0000000`3oool000000?ooo`02000000040?ooo`000000oooo0?ooo`<00000
0P3oool2000000030?ooo`000000000000<0oooo00<000000?ooo`0000001`3oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`800000103oool01`00
0000oooo0?ooo`3oool000000?ooo`0000001P3oool01@000000oooo0000003oool0000000X0oooo
00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`<0000000L0oooo0000003oool0
00000?ooo`000000oooo00800000103oool010000000oooo0?ooo`3oool3000000T0oooo00<00000
0?ooo`3oool01@3oool200000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`03
0?ooo`8000001P3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool0
0P0000000`3oool000000?ooo`090?ooo`040000003oool0oooo0?ooo`80000000<0oooo00000000
0000103oool00`000000oooo0?ooo`020?ooo`<0000000D0oooo000000000000oooo000000020?oo
o`030000003oool0oooo00<0000000<0oooo0000003oool0103oool2000000<0oooo1P0000000`3o
ool0000000000002000000D0oooo00D000000?ooo`000000oooo000000020?ooo`070000003oool0
oooo0?ooo`000000oooo000000030?ooo`8000000P3oool2000000/0oooo00<000000?ooo`3oool0
5P3oool004`0oooo0P0000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo000000030?ooo`060000003oool000000000003oool000001@3oool01@000000
oooo0?ooo`3oool0000000<0oooo1P0000000`3oool000000?ooo`050?ooo`030000003oool0oooo
0080000000H0oooo00000000000000000?ooo`0000020?ooo`8000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool000000080oooo00H000000?ooo`000000oooo0000003oool200000004
0?ooo`00000000000?ooo`8000000P3oool00`000000oooo000000020?ooo`8000000`3oool40000
00030?ooo`000000oooo00@0oooo00<000000?ooo`3oool0100000020?ooo`050000003oool00000
0?ooo`000000103oool01@000000oooo0000003oool000000080oooo0`0000020?ooo`040000003o
ool000000?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
0P0000020?ooo`040000003oool00000000000<0oooo00<000000?ooo`0000000P3oool500000003
0?ooo`000000000000<0oooo0P0000050?ooo`030000003oool0oooo00@00000103oool2000000D0
oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`040?ooo`090000003oool0oooo
0000003oool000000?ooo`000000oooo00@000000P3oool2000000050?ooo`000000oooo0000003o
ool00P0000030?ooo`@000000P3oool00`000000oooo00000006000000@0oooo0P000000103oool0
00000?ooo`0000040?ooo`030000003oool000000080oooo0P0000000`3oool000000?ooo`020000
0080oooo0P0000000`3oool000000?ooo`070?ooo`800000603oool004`0oooo00<000000?ooo`3o
ool01@3oool200000080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`0000000`3oool01P000000oooo000000000000oooo000000X0oooo00@0
00000?ooo`3oool000000P3oool01`000000oooo0000003oool000000?ooo`0000001@3oool30000
00<0oooo100000020?ooo`8000000P3oool2000000030?ooo`00000000000080oooo00D000000?oo
o`3oool000000?ooo`02000000<0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`060000003o
ool0oooo0000003oool000000P3oool2000000<0oooo0`0000020?ooo`800000103oool01P000000
oooo0?ooo`3oool000000?ooo`8000001@3oool00`000000oooo0?ooo`090?ooo`040000003oool0
00000?ooo`8000000`3oool2000000060?ooo`00000000000000003oool00000103oool00`000000
oooo0?ooo`0200000080oooo0P0000000`3oool0000000000003000000<0oooo00<000000?ooo`3o
ool00P3oool3000000030?ooo`000000oooo00800000103oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000P3oool00`000000oooo00000002000000030?ooo`000000oooo00800000103oool2
000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo00000002000000<0oooo00@00000
0?ooo`3oool000000`3oool2000000030?ooo`000000oooo00<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0000000D0000000<0oooo0000003oool00P0000030?ooo`800000
00<0oooo0000000000001`3oool010000000oooo0?ooo`0000020?ooo`@00000103oool2000000T0
oooo00<000000?ooo`3oool05P3oool003`0oooo00<0gia80000000000000`0000000`18W=l0oooo
0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P0000060?ooo`030000
003oool0oooo00X0oooo0P0000030?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3o
ool00P0000070?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`030000003oool0000000@0
oooo00@000000?ooo`3oool000000P3oool200000080oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000050?ooo`040000003oool0oooo000000@0oooo0P0000001@3oool000000?oo
o`3oool0000000@0oooo00@000000?ooo`3oool0oooo0`00000:0?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool02`3oool00`000000oooo000000040?ooo`040000003oool0oooo0?oo
o`8000001P3oool00`000000oooo0?ooo`02000000@0oooo0P0000000`3oool000000?ooo`020000
00T0oooo00<000000?ooo`0000002@3oool00`000000oooo000000080?ooo`030000003oool00000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000002`3oool3000000<0oooo00<00000
0?ooo`3oool00P00000=0?ooo`030000003oool0oooo0080oooo1P0000040?ooo`8000001`3oool0
0`000000oooo0?ooo`030?ooo`8000001`3oool3000000<0oooo0P00000:0?ooo`030000003oool0
oooo01H0oooo000m0?ooo`030?noM000M;l0oooo0080oooo00<0_gAd0;ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`8000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool00000
00L0oooo00@000000?ooo`3oool00000203oool2000000d0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool000000?oo
o`0000040?ooo`030000003oool0000000D0oooo00<000000?ooo`0000001`3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0000000T0oooo0P00000:0?ooo`030000003oool0oooo00P0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`060000003oool0oooo0000003oool00000
103oool010000000oooo0?ooo`0000030?ooo`8000001`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`0000001P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`3oool2000000H0oooo00<000000?ooo`3oool00P0000090?ooo`8000000P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo01H0oooo000n0?ooo`030?noM000M;l0oooo
00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`<000000`3oool20000
00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000>0?ooo`030000003oool0oooo
0140oooo00H000000?ooo`3oool000000?ooo`0000070?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`030?ooo`040000003oool00000000000@0oooo00@000000?ooo`3o
ool0oooo0P0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool04P3oool0
1`000000oooo0?ooo`000000oooo0000003oool00P0000020?ooo`030000003oool0000000L0oooo
00@000000?ooo`3oool0oooo0P0000070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool01P000000oooo0?ooo`000000oooo000000l0oooo00<000000?ooo`3oool01`3oool2
000000H0oooo0P0000000`3oool000000?ooo`050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo000o0?oo
o`030?noM000M;l0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool2000000H0oooo00<000000?oo
o`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`0000003P3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`070?ooo`040000003oool0oooo000000H0oooo00@000000?ooo`3oool000002@3oool010000000
oooo0000000000040?ooo`030000003oool0oooo00H0oooo0P0000050?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`0000030?ooo`050000
003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`020?ooo`8000000`3oool01P000000
oooo0?ooo`3oool000000?ooo`800000303oool3000000@0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`060?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01H0oooo000_0?ooo`030?oog`2LB000000000L0000000<0B9cO0?ooo`3oool0103oool0
0`3o_g@0B9cO0?ooo`090?ooo`030000003oool0oooo00H0oooo0`0000040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000L0oooo0P00
00020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0000000>0?ooo`030000
003oool000000080oooo0P0000050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000040?ooo`040000003oool0oooo0?ooo`8000004@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000001@3oool02@000000oooo0?ooo`3o
ool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00@000000P3oool00`000000
oooo0?ooo`070?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0000003oool00P0000040?ooo`8000000P3oool2000000D0oooo00@000000?ooo`00
0000oooo0P0000040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0203oool0
10000000oooo0?ooo`3oool2000000040?ooo`000000oooo000000@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01H0oooo00110?ooo`030=nLB018
W=l0oooo00P0oooo0`0000060?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool000000080oooo0P0000020?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo008000000`3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`000000
103oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000050?oo
o`040000003oool00000000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`@000007P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`02000000030?ooo`000000oooo00L0oooo0P000000103oool000000?ooo`3oool20000
00030?ooo`000000oooo00X0oooo00@000000?ooo`00000000002P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`0000000`3oool2000000`0oooo00<000000?ooo`000000303o
ool3000001P0oooo00120?ooo`030;md001d_ol0oooo00L0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
000@0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo008000001`3oool2000000`0oooo00<000000?ooo`3oool07P3o
ool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000006@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0000000X0oooo0P00000<0?ooo`030000003oool0oooo
0080oooo0P0000090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05P3oool00480
oooo00<0omnL04P0M02oool01`3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?oo
o`000000oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo0P0000090?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo000000040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0;0?ooo`040000003oool0
oooo000000<0oooo0P0000000`3oool000000?ooo`0?0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0@0?ooo`800000303oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01H0oooo00120?ooo`030?oog`2LB000M;oo00L0oooo00<00000
0?ooo`3oool01`3oool2000000030?ooo`000000000000<0oooo00P000000?ooo`3oool000000?oo
o`000000oooo000000`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0000000B0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool2000000T0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool02`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`0000002@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo01H0oooo00120?ooo`03
0?oo_`1d0000B9cO00L0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`0000001@3oool00`000000oooo0?ooo`050?ooo`<000004P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000303oool010000000oooo
0?ooo`00000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`00000?0?ooo`030000003oool0oooo00T0oooo0`0000070?ooo`030000003oool00000
00d0oooo00<000000?ooo`3oool05P3oool003h0oooo00L0okmd0018W03Oool0oooo0=nLB00004P0
W=oo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`040000003oool0
oooo000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo0`00000;0?ooo`800000103oool00`000000oooo0?ooo`040?ooo`040000003o
ool000000?ooo`8000002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`<00000303oool2000000030?oo
o`000000oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00L0oooo0P00000:0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3o
ool0oooo0P0000070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05P3oool003l0
oooo00D0omnL04P000000000000007Boo`080?ooo`800000203oool00`000000oooo0?ooo`020?oo
o`030000003oool000000080oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo00D0oooo0P00000=0?ooo`80000000D0oooo0000003oool0oooo0000
00080?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo
000000030?ooo`030000003oool0oooo00L0oooo0P000000103oool000000?ooo`0000030?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
01H0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo0P0000060?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06@3oool2
000001P0oooo001<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`0000001P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo0080000000<0oooo0000003oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000
000=0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`02000000X0oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00L0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00l0
oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00D0oooo0P00000;0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0F0?ooo`00C03oool00`000000oooo0?ooo`0:0?ooo`070000003oool0
00000?ooo`000000oooo000000020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`00
0000203oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo0P0000001`3oool000000?ooo`3oool0
00000?ooo`0000000P3oool00`000000oooo0?ooo`02000001/0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080000000<0oooo0000003oool0103o
ool300000080oooo00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3oool02@3o
ool010000000oooo0?ooo`00000C0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo001<0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000200000080oooo0P00
00050?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`090?ooo`8000001P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool000000?ooo`0200000100oooo00<000000?ooo`3oool0303oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000001@3oool00`000000oooo000000030?ooo`040000
003oool0oooo0?ooo`8000000P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool0oooo0P00000D0?ooo`050000003oool0oooo0?ooo`000000303oool0
0`000000oooo0?ooo`030?ooo`030000003oool0000002`0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0F0?ooo`00C03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00800000103oool200000080oooo0P0000050?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0P00000B0?oo
o`050000003oool000000000003oool00P00000@0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool04@3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo
0000000G0?ooo`030000003oool0oooo00@0oooo0P0000050?ooo`040000003oool0oooo0?ooo`80
0000503oool01@000000oooo0?ooo`3oool0000000P0oooo00@000000?ooo`3oool0oooo0P000002
0?ooo`030000003oool000000200oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0F
0?ooo`00C03oool00`000000oooo0?ooo`090?ooo`800000103oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo
00/0oooo00H000000?ooo`3oool0oooo0000003oool2000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
103oool010000000oooo0?ooo`00000H0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`0000002@3oool00`00
0000oooo0?ooo`0F0?ooo`00C03oool200000100oooo00<000000?ooo`3oool00`3oool00`000000
oooo0000000L0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000203oool01@000000
oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0100oooo0P0000000`3oool000000?ooo`0K0?ooo`030000003oool0oooo
00H0oooo0P0000070?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000005
0?ooo`800000603oool01`000000oooo0?ooo`3oool000000?ooo`0000001`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P0000070?ooo`800000
603oool004`0oooo00<000000?ooo`3oool05@3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00`0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`8000004`3oool00`000000oooo
0?ooo`040?ooo`80000000<0oooo0000003oool04`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`050?ooo`060000
003oool0oooo0000003oool000002P3oool01`000000oooo0000003oool000000?ooo`000000203o
ool00`000000oooo0?ooo`0F0?ooo`00C03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`8000000`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo000000030?ooo`8000001P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool03`3oool00`000000oooo000000040?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool00P3oool3000000X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo0P0000090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00<0oooo0P0000050?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?oo
o`0F0?ooo`00C03oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`000000203o
ool010000000oooo0?ooo`0000070?ooo`8000000P3oool2000000030?ooo`000000oooo01l0oooo
0P0000060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool2000000T0oooo
00<000000?ooo`3oool01P3oool02@000000oooo0?ooo`000000oooo0000003oool000000?ooo`02
000000030?ooo`000000oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003o
ool0oooo0180oooo0P0000090?ooo`030000003oool0oooo00L0oooo0P00000=0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool2000001@0oooo00<000000?ooo`3oool05P3o
ool004`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0000000K0?ooo`80000000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`0:0?ooo`<0000000<0oooo0000003oool01@3oool00`000000oooo
000000060?ooo`080000003oool0oooo0000003oool000000?ooo`0000020?ooo`050000003oool0
00000?ooo`0000002`3oool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`000000
1P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`00
0000203oool01@000000oooo0?ooo`3oool0000001T0oooo0P0000000`3oool000000?ooo`070?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00000=
0?ooo`030000003oool0oooo01H0oooo001<0?ooo`030000003oool0oooo00/0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool02P3oool200000080oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000103oool01P000000oooo0?ooo`000000oooo000000T0
oooo00H000000?ooo`00000000000?ooo`0000030?ooo`030000003oool000000180oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01@0oooo00D00000
0?ooo`3oool0oooo0000000G0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000
2@3oool010000000oooo0?ooo`0000050?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool0303oool2000000030?ooo`000000oooo02T0oooo00@000000?ooo`3oool000003@3oool00`00
0000oooo0?ooo`0F0?ooo`00C03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0000000D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0000000;0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<000001P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`<000001`3oool00`000000oooo0?ooo`030?ooo`8000001P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01H0oooo001<0?ooo`8000003`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000002P3oool010000000oooo0?ooo`0000060?ooo`030000
003oool0oooo00L0oooo00L000000?ooo`000000oooo0000003oool0000000d0oooo00<000000?oo
o`3oool03P3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool03P3oool01`000000oooo0000003oool000000?ooo`0000001P3oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`060?ooo`<000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`8000002@3oool00`00
0000oooo0?ooo`0<0?ooo`800000603oool004`0oooo00<000000?ooo`3oool03P3oool2000000`0
oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00P0oooo00L00000
0?ooo`000000oooo0000003oool0000000d0oooo00D000000?ooo`3oool0oooo000000090?ooo`04
0000003oool0oooo00000140oooo00<000000?ooo`3oool03P3oool00`000000oooo0000000;0?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000>0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool00P0000080?ooo`80000000@0oooo0000
003oool000002`3oool00`000000oooo0?ooo`0F0?ooo`00C03oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3o
ool000000100oooo00<000000?ooo`3oool03P3oool00`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`8000002P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool200000080oooo00D000000?oo
o`3oool0oooo0000000<0?ooo`80000000@0oooo0000003oool000000P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01H0oooo001<0?ooo`030000003oool0oooo01D0oooo00@00000
0?ooo`3oool000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`0000003P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3o
ool000001P3oool2000000<0oooo00<000000?ooo`3oool0103oool200000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo0P0000000`3o
ool00000000000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo001<0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0203oool00`000000oooo000000030?ooo`8000001P3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`070?oo
o`030000003oool0000000@0oooo00<000000?ooo`0000002@3oool01@000000oooo0?ooo`3oool0
000000<0oooo0P0000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo000000T0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000001`3oool01@000000
oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00`3oool2000000d0oooo00<000000?oo
o`3oool01@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0303oool01P000000oooo0?ooo`000000oooo000000@0oooo0P00000C0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool05P3oool004`0oooo00<000000?ooo`3oool01P3o
ool200000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`030000
003oool0oooo00X0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01`3oool00`000000oooo000000040?ooo`<000002@3oool01@000000
oooo0?ooo`3oool0000000<0oooo0P00000;0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0303oool00`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo008000000P3oool01@000000oooo0000003o
ool0000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02000000H0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`0000060?ooo`030000003oool0000000P0oooo
00D000000?ooo`3oool0oooo000000090?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`000000203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00800000103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool05P3oool004`0
oooo0P0000080?ooo`80000000D0oooo0000003oool0oooo0000000>0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00<0oooo0P00000:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0H0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000180oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo
0P0000070?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00P0000060?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool200000080oooo00<000000?ooo`3o
ool00`3oool200000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`80
0000603oool002h0oooo00<0oono07@0000000000P0000001`18W=l0oooo0?ooo`3oool0omnL04P0
001d_ol00P3oool01P3ogi`0B00000000000000004RL0=ooo`X0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0000000:0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000070?ooo`050000003oool0oooo0?ooo`0000001P3oool200000180oooo00@000000?ooo`3o
ool000002P3oool300000080oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo000000030?oo
o`040000003oool0oooo000000L0oooo00<000000?ooo`0000001`3oool01P000000oooo00000000
0000oooo000000X0oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool2
000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo00000005
0?ooo`070000003oool000000?ooo`000000oooo000000050?ooo`030000003oool0000000H0oooo
0P0000030?ooo`050000003oool0oooo0?ooo`0000002@3oool2000000030?ooo`000000000000H0
oooo00<000000?ooo`3oool00P0000060?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool05P3oool00300oooo00<0okmd0000001d_ol0103oool00`3ogi`0B00007Boo`020?ooo`060?no
M0000000M;oo0?ooo`3ogi`0B7Bo2P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00T0oooo00D000000?ooo`000000oooo000000060?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`00000:0?ooo`8000000`3oool01P000000oooo
000000000000oooo000000<0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000000`0000000`3oool000000?oo
o`040?ooo`030000003oool0oooo008000000P3oool010000000oooo0?ooo`0000060?ooo`030000
003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`00000>0?ooo`8000001P3oool00`000000oooo0?ooo`05
0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`80000000<0oooo000000000000
1@3oool2000000L0oooo00<000000?ooo`3oool02@3oool4000000@0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`00000=0?ooo`8000002`3oool00`000000oooo0?ooo`0F0?ooo`00
<03oool00`3ooml0W4P0001d_`0>0?ooo`030?noM018W=l0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`02000000d0oooo00<000000?ooo`3oool0103oool200000080oooo
00<000000?ooo`3oool04`3oool2000000P0oooo0P0000020?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000020?ooo`8000000P3oool00`000000oooo
0?ooo`0H0?ooo`800000203oool01P000000oooo0?ooo`000000oooo000000X0oooo00<000000?oo
o`3oool01@3oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool00`0000001@3o
ool000000?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo00<0oooo0`00000D0?ooo`030000003oool0oooo008000000P3oool0
10000000oooo0?ooo`0000020?ooo`800000403oool010000000oooo0?ooo`0000020?ooo`060000
003oool0oooo0000003oool00000103oool00`000000oooo0?ooo`02000000030?ooo`000000oooo
00P0oooo0`00000;0?ooo`030000003oool0oooo01H0oooo000a0?ooo`030=nLB000B9`0gooo00d0
oooo00<0oono07@0M02oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0
oooo00L000000?ooo`3oool000000?ooo`000000oooo008000000P3oool00`000000oooo0?ooo`0@
0?ooo`040000003oool00000000000T0oooo0P0000020?ooo`030000003oool0oooo00<0oooo00D0
00000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
2@3oool010000000oooo0000000000080?ooo`<000000P3oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`050000003oool00000
0?ooo`0000001@3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
4@3oool2000000L0oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
203oool2000000d0oooo00<000000?ooo`3oool05P3oool00240oooo00<0oooO09a8000000001`00
00000`18W=l0oooo0?ooo`030?ooo`030?oOW01804P0W=oo00d0oooo00<0oooO09a8001d_ol0203o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3o
ool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`0000000`3oool3000000h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0
oooo0P0000000`3oool000000?ooo`080?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000020?ooo`<000001P3oool200000080oooo0P00000>0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool03@3oool2000000T0oooo00<000000?ooo`3oool01@3oool20000
0080oooo00<000000?ooo`3oool06@3oool00`000000oooo000000060?ooo`070000003oool0oooo
0?ooo`000000oooo0000000A0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000103o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool05P3o
ool00340oooo00<0oono07@0001d_ol03@3oool00`3ookl0M00004RLg`080?ooo`<000004P3oool0
10000000oooo0?ooo`00000@0?ooo`8000000P3oool2000000X0oooo00<000000?ooo`3oool01P3o
ool4000000@0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`0000070?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0
oooo00800000203oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000001@3oool010000000oooo0?ooo`00000<0?ooo`030000003oool0000000D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool0oooo00L0oooo0`0000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`050?ooo`<00000603oool00380oooo00<0_g@0001d_`3o
ool0303oool00`3o_g@0000007Boo`080?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3o
ool00000203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool00P00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00@000000?ooo`00000000002P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00D000000?ooo`000000oooo0000
00070?ooo`040000003oool0000000000140oooo00<000000?ooo`000000103oool2000000<0oooo
0P00000@0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`040?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool00000008000002@3oool0
0`000000oooo0?ooo`060?ooo`@000001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`3oool4000000040?ooo`00
0000oooo000000H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0F0?ooo`00
<P3oool00`3OW4P004RL0=ooo`090?ooo`060?oOg`3Oool0okmd0000000007@0_ooo203oool00`00
0000oooo0?ooo`060?ooo`040000003oool0oooo000000`0oooo00`000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000004@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000
203oool010000000oooo0000000000050?ooo`030000003oool000000080oooo00@000000?ooo`3o
ool0oooo100000000`3oool000000?ooo`070?ooo`050000003oool0oooo0?ooo`0000001`3oool3
000000<0oooo00@000000?ooo`3oool000001P3oool2000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`030000003oool0oooo0080oooo0`0000040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000000d0oooo00<000000?ooo`00
0000203oool010000000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo0180oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool000000?ooo`00
00000`3oool00`000000oooo00000003000000030?ooo`00000000000080oooo00H000000?ooo`3o
ool000000?ooo`0000040?ooo`030000003oool0000000@0oooo0P0000000`3oool000000?ooo`04
0?ooo`060000003oool0oooo0000003oool000001`3oool00`000000oooo0?ooo`0F0?ooo`00<P3o
ool00`3ogi`0B01809cOo`090?ooo`050?oo_`1d000000000000B02Lgol02@3oool00`000000oooo
0?ooo`050?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo
0?ooo`020?ooo`070000003oool000000?ooo`000000oooo000000030?ooo`8000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo000000T0oooo0P0000000`3oool000000?ooo`0:0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0000000P3oool2000000040?ooo`00000000000?ooo`@00000
5@3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool00P3oool01000
0000oooo0000000000050?ooo`040000003oool00000000000P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`8000000`3oool2000000<0oooo0P000000103oool000000?oo
o`3oool2000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`000000103oool010000000oooo0000000000020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00P3oool2000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`08
0?ooo`@000001P3oool3000000030?ooo`000000000000H0oooo0P0000001P3oool0000000000000
0000oooo00000080oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`040000
003oool00000000000D0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0F0?oo
o`00<P3oool00`3ookl0M00007Boo`0:0?ooo`030=nLW02oool0oooo00X0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0P00000:0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`80
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo0`00000;0?ooo`03
0000003oool0oooo00X0oooo00@000000?ooo`00000000000`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0000000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00D0oooo00@000000?ooo`3oool0oooo0P0000040?ooo`030000003oool000000080oooo0P00
000:0?ooo`040000003oool0oooo000000L0oooo0P0000000`3oool000000?ooo`03000000X0oooo
00@000000?ooo`3oool0oooo0P0000070?ooo`060000003oool0oooo0?ooo`000000oooo0P000007
0?ooo`<00000203oool00`000000oooo0?ooo`02000000D0oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00<000000?ooo`3oool02`3oool01P000000oooo000000000000oooo0000
00<0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`0F0?ooo`00<`3oool00`2oM000
07Bo0?ooo`090?ooo`030?oOW01dW=l0oooo00X0oooo00<000000?ooo`3oool0403oool01@000000
oooo0?ooo`3oool0000000T0oooo00<000000?ooo`0000004P3oool2000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`8000000`3oool00`000000oooo000000070?oo
o`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00L0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080000000<0
oooo0000003oool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`800000
103oool2000000<0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0000000@0
oooo00D000000?ooo`000000oooo000000070?ooo`030000003oool0oooo00D0oooo0P0000050?oo
o`800000303oool010000000oooo0?ooo`3oool2000000@0oooo0P0000040?ooo`030000003oool0
oooo00P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`800000103oool2000000X0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`3oool2000000@0oooo0P0000020?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`3oool000002@3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01H0oooo000a
0?ooo`050?oo_`1d000000000000M02oool02P3oool01@2oM0000000000000000000B9cO00L0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`00
00002`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool000000080oooo0P0000030?ooo`05
0000003oool0oooo0?ooo`0000000P3oool2000000`0oooo0P0000030?ooo`030000003oool0oooo
00<0oooo0P000000103oool000000?ooo`0000020?ooo`030000003oool0oooo00L0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P0000040?oo
o`030000003oool0oooo0080oooo00@000000?ooo`000000oooo0P0000030?ooo`<000000`3oool0
1P000000oooo000000000000oooo00000080oooo00<000000?ooo`3oool00P0000080?ooo`800000
1@3oool2000000`0oooo00D000000?ooo`000000oooo0000000;0?ooo`030000003oool0oooo00D0
oooo0P0000040?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool02P3oool200000080
oooo00<000000?ooo`3oool0103oool3000000<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`090?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0F0?ooo`00C03oool2000000D0oooo
0P00000F0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool010000000oooo
0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000<0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`080?ooo`8000000`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P0000050?ooo`050000003oool0oooo
0?ooo`0000003@3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool2000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:
0?ooo`080000003oool0oooo0000003oool000000?ooo`00000<0?ooo`8000000`3oool200000003
0?ooo`000000oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`80
00002@3oool00`000000oooo000000060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo0P00000H0?ooo`00
C03oool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo000000050?ooo`050000
003oool0oooo0?ooo`0000001@3oool2000000@0oooo0P00000:0?ooo`030000003oool0oooo0080
0000103oool00`000000oooo0?ooo`030?ooo`<0000000<0oooo0000000000001`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo0P0000030?ooo`030000003oool000000080
oooo00<000000?ooo`3oool00P3oool01`000000oooo0000003oool000000?ooo`0000001`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`080?ooo`<000003P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0000000P0oooo0P0000060?ooo`030000003oool0oooo00X0oooo0P0000060?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02@3oool2000000H0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00h0oooo0P0000000`3oool00000
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01H0oooo001<0?ooo`030000003oool0oooo00H0oooo00D0
00000?ooo`3oool000000?ooo`02000000@0oooo00L000000?ooo`3oool0oooo0000003oool00000
00<0oooo0`0000020?ooo`<000003@3oool2000000@0oooo100000030?ooo`80000000<0oooo0000
000000001P3oool2000000@0oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool0
000000X0oooo00<000000?ooo`3oool00P3oool3000000L0oooo00L000000?ooo`3oool0oooo0000
003oool0000000L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`08
0000003oool0oooo0000003oool000000?ooo`0000060?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00/0oooo
00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`3oool00P3oool20000
00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0F0?ooo`00C03oool00`000000
oooo0?ooo`060?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000003@3oool0
1@000000oooo0000003oool0000000@0oooo100000040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`0000004`3oool01`000000oooo0?ooo`3oool000000?ooo`0000003P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000020?ooo`8000002`3oool2000000<0oooo00@000000?ooo`00000000000P3oool0
10000000oooo0?ooo`0000050?ooo`800000503oool00`000000oooo000000050?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`8000001@3o
ool00`000000oooo0?ooo`02000000/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01H0oooo001<0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`80000000<0oooo0000003oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04P3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000P3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0103oool2000000030?ooo`00000000000080oooo
0P0000000`3oool000000?ooo`040?ooo`8000001P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000D0
oooo00<000000?ooo`0000000P3oool2000000P0oooo00@000000?ooo`3oool0oooo0P0000000`3o
ool00000000000020?ooo`040000003oool0oooo000000@0oooo0`00000=0?ooo`030000003oool0
000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000070?ooo`060000003oool0
oooo0000003oool00000103oool200000080oooo00@000000?ooo`0000000000203oool2000000D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01H0
oooo001<0?ooo`030000003oool0oooo00L0oooo00H000000?ooo`3oool000000?ooo`0000020?oo
o`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo008000000`3oool20000
00030?ooo`000000oooo00<0oooo00@000000?ooo`3oool00000103oool3000000@0oooo00<00000
0?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool00000000000X0oooo00D000000?ooo`3oool0oooo000000040?oo
o`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000001@3oool2000000<0oooo00<0
00000?ooo`3oool00P0000000`3oool000000?ooo`040?ooo`040000003oool0oooo000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`8000000P3oool00`000000oooo0?ooo`090?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool01P3oool2000000<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`80000000D0oooo0000003oool0oooo00000007
0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00L0oooo00D000000?ooo`000000oooo000000040?ooo`040000
003oool0oooo0?ooo`800000203oool01P000000oooo0?ooo`000000oooo000000<0oooo0`000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05P3oool004`0oooo0P000007
0?ooo`8000000P3oool00`000000oooo000000020?ooo`040000003oool0oooo0?ooo`80000000D0
oooo0000003oool0oooo000000030?ooo`040000003oool0oooo0?ooo`8000000P3oool00`000000
oooo0?ooo`02000000050?ooo`000000oooo0?ooo`0000000P3oool3000000<0oooo0P0000000`3o
ool000000?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool000000080oooo00`000000?ooo`00000000000?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`030000003oool0000000T0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`050000
003oool000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?oo
o`3oool000000`3oool3000000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`80000000H0
oooo0000003oool0oooo0000003oool200000080oooo00@000000?ooo`3oool000000`3oool20000
0080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000080?ooo`050000003oool0
oooo0?ooo`0000001`3oool3000000H0oooo00@000000?ooo`3oool000002`3oool2000000@0oooo
00<000000?ooo`000000103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01@3oool2000000@0oooo00<000000?ooo`3oool0303oool2000001P0
oooo001<0?ooo`030000003oool0oooo00H0oooo00L000000?ooo`3oool0oooo0000003oool00000
00H0oooo100000040?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo0000
00020?ooo`80000000<0oooo0000003oool00P0000080?ooo`80000000<0oooo0000003oool0103o
ool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000P3oool3000000030?oo
o`000000oooo00H0000000<0oooo0000003oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0000000D0oooo00<000000?ooo`3oool01P3oool200000080oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`<000001P3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo0P0000000`3oool000000?ooo`030?ooo`800000103oool20000
00<0oooo0P0000020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P0000080?oo
o`030000003oool0oooo00<0oooo0`0000070?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool2
00000080oooo00D000000?ooo`000000oooo000000050?ooo`8000000`3oool2000000040?ooo`00
0000oooo000000/0oooo00<000000?ooo`3oool05P3oool004`0oooo00<000000?ooo`3oool0303o
ool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000000T0oooo0P0000020?ooo`800000103oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000D0oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`80000000<0oooo0000
003oool00P0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000303oool200000080oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00H000000?ooo`00000000000?ooo`0000040?oo
o`030000003oool0oooo0080oooo0`0000040?ooo`800000203oool00`000000oooo0?ooo`020?oo
o`<0000000<0oooo0000003oool0403oool00`000000oooo0?ooo`030?ooo`8000001P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool20000
00P0oooo00<000000?ooo`000000203oool2000000T0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`8000000P3oool3000000<0oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`00
0000oooo000000/0oooo00<000000?ooo`3oool05P3oool004`0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`@000000P3oool2000000X0oooo00D000000?ooo`3oool0oooo
000000030?ooo`8000000`3oool2000000@0oooo0P00000=0?ooo`80000000D0oooo000000000000
oooo000000070?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`8000001P3oool00`000000oooo000000020?ooo`030000003oool0oooo
00P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000005000000030?ooo`000000
000000<0oooo0`0000000`3oool000000?ooo`030?ooo`040000003oool0oooo000000D0oooo00@0
00000?ooo`3oool0oooo0`0000020?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0
oooo000000070?ooo`8000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?oo
o`000000oooo000000050?ooo`030000003oool0oooo00@0oooo0P0000090?ooo`8000002@3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool02P3oool010000000oooo0?oo
o`0000030?ooo`040000003oool0oooo0?ooo`800000203oool2000000040?ooo`000000oooo0000
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`00C03oool00`000000
oooo0?ooo`050?ooo`050000003oool000000?ooo`000000103oool2000000030?ooo`000000oooo
008000000`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`8000000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01`3oool2
00000080oooo0`00000;0?ooo`080000003oool000000000003oool000000?ooo`0000020?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo0`0000030?ooo`030000003oool0oooo00<0oooo00H000000?ooo`00
0000oooo0000003oool4000000d0oooo00H000000?ooo`3oool0oooo0000003oool2000000030?oo
o`000000oooo00<0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0000000H0oooo00<00000
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo0`0000050?ooo`80000000@0
oooo0000003oool000001P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00T0
oooo00@000000?ooo`3oool000000P3oool2000000030?ooo`000000oooo0080oooo0P0000020?oo
o`8000001`3oool3000000040?ooo`000000oooo00000080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0F0?ooo`00C03oool00`000000oooo0?ooo`050?ooo`050000003oool00000
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000001@3oool01P000000oooo0?ooo`3oool000000?ooo`800000103oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000T0oooo00@000000?ooo`0000000000103oool00`000000
oooo0?ooo`060?ooo`040000003oool0oooo0?ooo`8000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?oo
o`030000003oool000000080oooo0`0000030?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00P3oool3000000H0oooo0P0000000`3oool000000?ooo`050?ooo`040000003oool0
oooo0?ooo`<000001`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo008000000P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000
003oool0oooo00D0oooo00D000000?ooo`000000oooo000000040?ooo`D00000203oool200000003
0?ooo`000000oooo00<0oooo0P0000040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`020?ooo`<000000`3oool00`000000oooo000000050?oo
o`040000003oool00000000000h0oooo00<000000?ooo`3oool05P3oool001D0oooo00<0gia80000
M02oool0=03oool2000000H0oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`80000000<0oooo0000
003oool00P3oool010000000oooo0000000000040?ooo`030000003oool0000000@0oooo0P000003
0?ooo`080000003oool0oooo0000003oool000000?ooo`0000050?ooo`050000003oool0oooo0?oo
o`0000000`3oool300000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`80000000H0oooo0000003oool000000?ooo`0000030?ooo`030000003oool00000008000000`3o
ool2000000030?ooo`000000oooo00D0oooo00H000000?ooo`3oool000000?ooo`0000090?ooo`03
0000003oool0000000H0oooo100000060?ooo`040000003oool0oooo0?ooo`8000000`3oool20000
00<0oooo00@000000?ooo`3oool00000103oool01@000000oooo000000000000oooo00<0000000@0
oooo0000003oool000001P3oool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0?oo
o`0000002`3oool010000000oooo0?ooo`0000020?ooo`<000000`3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0000000000020?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`040000003oool000000?ooo`80000000<0oooo
0000003oool00P0000040?ooo`030000003oool0oooo00L0oooo0`0000030?ooo`8000001`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0000000/0oooo0P00000H0?ooo`003P3oool00`3o
okl0M7Bo0?ooo`040?ooo`030?oo_`1dB9`0gooo03@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`02000000H0oooo0P0000030?ooo`060000003oool0oooo0?ooo`000000oooo0P00
00000`3oool0000000000003000000040?ooo`000000oooo000000D0oooo00<000000?ooo`000000
0`3oool200000080oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00<0oooo
0P0000020?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`040000003oool0oooo
000000D0oooo100000000`3oool000000?ooo`040?ooo`030000003oool0oooo008000000`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080000000<0oooo0000003oool01`3oool0
0`000000oooo0?ooo`030?ooo`8000000`3oool00`000000oooo0?ooo`090?ooo`040000003oool0
oooo0?ooo`<000000P3oool5000000050?ooo`000000oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool2000000030?ooo`000000000000P0
oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000000L0oooo00H00000
0?ooo`3oool000000?ooo`0000020?ooo`@0000000<0oooo0000003oool00P0000000`3oool00000
0?ooo`040?ooo`040000003oool00000000000<0oooo0P0000001@3oool00000000000000000oooo
00800000103oool3000000L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool3
000000<0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00L0oooo00D0
00000?ooo`000000oooo000000080?ooo`030000003oool0oooo01H0oooo000>0?ooo`030?oOW018
07@0_ooo00<0oooo00<0okmd0000M02oool0=@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo0`0000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`000000oooo
100000000`3oool0000000000003000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo
0000000000020?ooo`<0000000@0oooo00000000000000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool200000080oooo00D000000?oo
o`3oool0oooo000000040?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080
oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`000000oooo008000002@3oool60000
00P0oooo00<000000?ooo`3oool00`0000040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`03000000040?ooo`00000000000?ooo`8000000P3oool0
0`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool00P3oool2000000D0oooo0P000000
0`3oool00000000000030?ooo`040000003oool000000?ooo`800000103oool01`000000oooo0?oo
o`3oool000000?ooo`0000001P3oool00`000000oooo000000020?ooo`030000003oool0000000@0
000000L0oooo00000000000000000?ooo`000000oooo008000002@3oool00`000000oooo0?ooo`02
000000030?ooo`000000000000H0oooo0P0000001P3oool000000?ooo`3oool000000?ooo`800000
0P3oool00`000000oooo0?ooo`02000000X0oooo00@000000?ooo`0000000000103oool010000000
oooo0?ooo`0000080?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool05P3oool000h0
oooo00L0omnL04P000000000001809cOo`3ogi`0B7Bo03L0oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`0000020?ooo`@0000000<0oooo0000003oool00P3oool00`000000oooo0000
0002000000030?ooo`0000000000008000000`3oool2000000L0oooo00@000000?ooo`000000oooo
0P0000020?ooo`8000000P3oool2000000<0oooo00<000000?ooo`3oool00P3oool4000000040?oo
o`0000000000000000<0oooo0`0000000`3oool00000000000070?ooo`030000003oool0oooo0080
000000<0oooo0000000000000P0000000`3oool000000?ooo`070?ooo`030000003oool000000080
oooo0`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`0000070?ooo`D0
000000D0oooo0000003oool000000?ooo`03000000@0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`030?ooo`<0000000L0oooo0000003oool0oooo0000003oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`<00000103oool2000000030?oo
o`00000000000080oooo0P0000001`3oool000000?ooo`3oool000000?ooo`0000000P3oool00`00
0000oooo0?ooo`02000000030?ooo`000000oooo00D0oooo00H000000?ooo`3oool000000?ooo`00
00050?ooo`030000003oool0000000D0oooo0P0000090?ooo`80000000<0oooo0000003oool00P00
00030?ooo`030000003oool0oooo00<0000000@0oooo000000000000oooo0`000000103oool00000
0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00H000000?ooo`3oool0oooo0000003o
ool200000080oooo00H000000?ooo`3oool000000?ooo`0000070?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool05P3oool00100oooo00<0oono07@0000000000P0000000`1d_ol0oooo
0?ooo`0d0?ooo`030000003oool0oooo00@0oooo3P0000000`3oool0000000000008000000030?oo
o`000000000000H0000000D0oooo00000000000000000?ooo`0900000080oooo1P0000000`3oool0
00000000000:000000030?ooo`000000000000T0000000<0oooo0000003oool02@000000103oool0
00000000003oool2000000<0oooo0P0000000`3oool0000000000004000000030?ooo`0000000000
0080oooo2`0000000`3oool000000?ooo`0@000000030?ooo`000000oooo00<0000000<0oooo0000
000000002`0000000`3oool000000?ooo`02000000030?ooo`00000000000080000000L0oooo0000
0000000000000?ooo`000000oooo00@0000000<0oooo0000000000000P3oool5000000030?ooo`00
0000oooo0080000000@0oooo000000000000oooo20000000103oool000000000003oool500000003
0?ooo`0000000000008000000`3oool010000000oooo0000003oool200000080oooo00<000000?oo
o`0000000P0000000`3oool000000000000<000000050?ooo`00000000000000003oool00`000002
0?ooo`8000000P3oool500000080oooo00D000000?ooo`00000000000?ooo`0500000080oooo2@00
00000`3oool00000000000020?ooo`D0000000D0oooo0000003oool0oooo000000080?ooo`030000
003oool0oooo01H0oooo000?0?ooo`090?oo_`1d07@0_ooo0?ooo`3ooml0W4P00000000007@0_ooo
03@0oooo00<000000?ooo`3oool0103ooolI000000030?ooo`000000000000H0000000<0oooo0000
000000002`0000000`3oool000000000000B00000080oooo5P000000103oool000000000003oool2
000000030?ooo`00000000000080000000<0oooo000000000000100000001@3oool0000000000000
0000oooo00/0000000<0oooo0000003oool0400000000`3oool000000?ooo`0O000000030?ooo`00
0000oooo00@0000000@0oooo000000000000oooo1P0000000`3oool000000?ooo`0>000000040?oo
o`00000000000?ooo`X0000000<0oooo0000000000001`0000000`3oool000000?ooo`0F00000003
0?ooo`000000000000D0000000<0oooo0000000000001@0000000`3oool000000?ooo`0800000003
0?ooo`000000000000`0000000<0oooo0000000000001P0000000`3oool000000?ooo`070?ooo`03
0000003oool0oooo01H0oooo000>0?ooo`030?oo_`1d07@0_ooo00@0oooo00<0omnL04Qd_`3oool0
=03oool00`000000oooo0?ooo`040?oooaT0000000<0oooo0000000000000`000000103oool00000
0000003oool5000000030?ooo`000000000000P0000000<0oooo0000000000000`0000020?ooo`@0
000000<0oooo0000000000000P0000000`3oool0000000000002000000050?ooo`00000000000000
003oool00P000000103oool000000000000000020?ooo`L0000000<0oooo00000000000020000000
0`3oool000000?ooo`08000000@0oooo0`0000000`3oool0000000000002000000030?ooo`000000
000000T0000000<0oooo00000000000010000000103oool000000000003oool3000000030?ooo`00
0000000000@000000P3oool5000000030?ooo`000000000000P0000000<0oooo0000003oool00P00
00000`3oool000000000000300000080oooo1P0000000`3oool0000000000003000000030?ooo`00
000000000080000000<0oooo0000000000000`0000000`3oool000000000000200000080oooo1@00
00000`3oool0000000000002000000030?ooo`000000000000@000000`3oool2000000040?ooo`00
000000000?ooo`80000000<0oooo0000003oool0200000020?ooo`030000003oool0000000T00000
00<0oooo0000003oool00P0000001@3oool00000000000000000oooo00H0000000<0oooo00000000
00001@0000000`3oool0000000000002000000030?ooo`000000000000P000002P3oool00`000000
oooo0?ooo`0F0?ooo`003P3oool00`3o_g@0000007Boo`030?ooo`030?oo_`1dB9`0gooo03D0oooo
0P0000060?oooad000000P3oool6000000040?ooo`000000oooo0?ooo`80000000<0oooo00000000
00000`0000020?ooo`D000000P3oool4000000030?ooo`000000oooo0080000000<0oooo00000000
00000P0000001P3oool00000000000000000oooo000000<0oooo0`000000103oool000000000003o
ool4000000050?ooo`00000000000000003oool0200000001@3oool00000000000000000oooo00<0
00000`3oool00`000000oooo00000002000000030?ooo`00000000000180000000<0oooo00000000
00000`0000001P3oool000000000003oool000000?ooo`<0000000@0oooo000000000000oooo1@00
00020?ooo`h0000000<0oooo0000000000000`0000020?ooo`D0000000<0oooo0000000000001000
00000`3oool0000000000002000000030?ooo`000000000000T0000000<0oooo0000000000000P00
00020?ooo`@0000000P0oooo00000000000000000?ooo`000000oooo00000080oooo0P000000103o
ool000000000003oool2000000030?ooo`000000oooo00P000000`3oool2000000030?ooo`000000
000000@0000000@0oooo0000003oool0oooo1`000000103oool000000000003oool5000000030?oo
o`000000000000<0000000<0oooo000000000000300000000`3oool000000?ooo`070?ooo`800000
603oool003`0oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`080?ooo`030000003o
ool0oooo00D0oooo1@000000103oool000000?ooo`3oool6000000030?ooo`00000000000080oooo
2@0000000`3oool000000000000300000080oooo0P0000030?ooo`060000003oool0oooo0?ooo`00
0000oooo0P0000020?ooo`80000000@0oooo0000003oool0oooo0P0000001@3oool000000?ooo`00
0000oooo0080000000<0oooo0000003oool00P0000000`3oool00000000000020?ooo`050000003o
ool0oooo0000003oool00P000000103oool000000000003oool4000000030?ooo`000000000000<0
oooo1`0000000`3oool00000000000030?ooo`80000000@0oooo0000003oool000000P3oool00`00
0000oooo00000006000000050?ooo`00000000000000003oool01P0000002`3oool000000000003o
ool000000?ooo`000000oooo0000003oool000000080oooo0`0000030?ooo`8000000`3oool30000
00<0oooo0`0000000`3oool0000000000003000000030?ooo`000000000000P0oooo00@000000?oo
o`3oool0oooo0P000000203oool00000000000000000oooo0000003oool000000P3oool200000005
0?ooo`00000000000000003oool010000000103oool000000000003oool4000000<0oooo20000002
0?ooo`80000000<0oooo0000003oool01P3oool010000000oooo0?ooo`0000020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo00000005000000<0oooo2@0000020?ooo`050000
003oool0oooo0000003oool00P0000000`3oool000000?ooo`03000000030?ooo`000000oooo00<0
000000<0oooo0000003oool00`3oool2000000030?ooo`0000000000008000001`3oool00`000000
oooo0?ooo`0F0?ooo`005P3oool0103o_g@000000000M02ooolT0?ooo`030?noM0000000M;oo00/0
oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo
0?ooo`0000000P3oool2000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo00000002
00000080oooo00<000000?ooo`3oool02@3oool01@000000oooo000000000000oooo008000000`3o
ool01P000000oooo0?ooo`3oool000000?ooo`8000000`3oool020000000oooo0?ooo`000000oooo
0000003oool000000P3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D000000`3oool00`000000
oooo000000030?ooo`80000000<0oooo0000000000000P3oool01@000000oooo0000003oool00000
0080oooo00@000000?ooo`000000oooo0P0000000`3oool000000000000<0?ooo`8000000`3oool0
0`000000oooo0?ooo`040?ooo`080000003oool0oooo0?ooo`000000oooo0000003oool4000000`0
oooo00<000000?ooo`3oool0103oool200000080oooo00<000000?ooo`0000000`3oool01@000000
oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000P3oool3000000H0oooo0P000003
0?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`8000000P3oool010000000oooo
0?ooo`0000050?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030000
00@0oooo0P0000040?ooo`030000003oool0oooo0080oooo00@000000?ooo`000000oooo0P000003
0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`00000000000P3oool010000000oooo
0000000000070?ooo`030000003oool0oooo01H0oooo000?0?ooo`040?oog`2LW;l0oooO09a800<0
000000<007Bo0?ooo`3oool09@3oool00`3ooml0W4P0001d_`0;0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool000000080
oooo0P0000020?ooo`<000000P3oool00`000000oooo0?ooo`02000000H0oooo0P0000070?ooo`<0
000000<0oooo0000003oool00`3oool3000000030?ooo`000000oooo00D0oooo00T000000?ooo`3o
ool000000?ooo`000000oooo0000003oool00P0000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0303oool010000000oooo0000000000090?ooo`8000000P3oool00`000000oooo
000000060?ooo`D0000000<0oooo0000003oool00P0000050?ooo`030000003oool0oooo00X0oooo
00@000000?ooo`3oool0oooo100000000`3oool00000000000040?ooo`030000003oool000000140
oooo00@000000?ooo`00000000001`3oool010000000oooo0?ooo`0000050?ooo`80000000<0oooo
0000003oool00P3oool00`000000oooo000000050?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool2000000D0oooo0P000007
0?ooo`040000003oool0oooo0?ooo`8000001P3oool00`000000oooo000000020?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool05P3oool000l0oooo00@0oono07@0000004P0W=oo0P3o
ool00`2oW9`0gooo0?ooo`0W0?ooo`030=nLB000B9`0gooo00X0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`03000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool0103o
ool01@000000oooo0?ooo`3oool000000080oooo0`0000000`3oool00000000000030?ooo`040000
003oool0oooo000000<0oooo0P0000060?ooo`80000000<0oooo0000003oool00`3oool00`000000
oooo0?ooo`02000000/0oooo00<000000?ooo`3oool00`3oool2000000<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`080?ooo`800000103oool3000000T0oooo1P0000050?ooo`@0
000000<0oooo0000003oool02@3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000
oooo0?ooo`03000000030?ooo`000000000000<000000P3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`3oool01@3oool300000080oooo00<00000
0?ooo`0000002P3oool2000000040?ooo`000000000000000080oooo0P0000020?ooo`030000003o
ool0oooo00<0000000L0oooo0000003oool0oooo0000003oool0000000H0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00@000000?ooo`3oool0oooo0P0000040?ooo`030000003o
ool0oooo00<0oooo0P00000;0?ooo`80000000<0oooo0000003oool01`3oool00`000000oooo0?oo
o`0F0?ooo`004`3oool01@3Ogml0_g@000000000000007Bo01L0oooo00<0oooO09a8000000001`00
00000`18W=l0oooo0?ooo`030?ooo`030?oOW01804P0W=oo00X0oooo00<000000?ooo`3oool01@3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool2000000H0oooo0P0000000`3o
ool000000?ooo`02000000<0oooo00<000000?ooo`3oool00P0000000`3oool00000000000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool2000000040?ooo`000000oooo
00000080oooo0P0000050?ooo`040000003oool0oooo000000L0oooo0P0000040?ooo`<0000000<0
oooo0000003oool00`3oool00`000000oooo0?ooo`03000000040?ooo`000000oooo000000@0oooo
00<000000?ooo`0000002@3oool2000000P0oooo0P0000050?ooo`030000003oool0000000<00000
0P3oool7000000H0oooo00<000000?ooo`3oool0103oool300000080oooo0P00000>0?ooo`040000
003oool0oooo000000L0oooo0P0000020?ooo`<000000P3oool00`000000oooo000000090?ooo`<0
000000@0oooo0000003oool000000P3oool200000080oooo00@000000?ooo`3oool000000P3oool2
00000080oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000050?ooo`040000003o
ool0oooo0?ooo`800000103oool300000080oooo0P0000030?ooo`040000003oool0oooo000000<0
oooo00H000000?ooo`3oool000000?ooo`0000080?ooo`030000003oool0oooo01H0oooo000B0?oo
o`030?oog`2LB000M;oo0080oooo00<0gia80000M02oool09@3oool00`3ookl0M00007Boo`0:0?oo
o`<000001@3oool00`000000oooo0?ooo`02000000L0oooo00@000000?ooo`3oool000000P3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00@000000?ooo`3oool00000103oool01@000000oooo
0?ooo`000000oooo00<000000P3oool010000000oooo0?ooo`3oool4000000040?ooo`0000000000
000000@0oooo00<000000?ooo`3oool02P3oool2000000030?ooo`000000oooo00<0oooo00<00000
0?ooo`3oool00`3oool200000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0?ooo`0000000`3oool3000000<0oooo00D000000?ooo`3oool0oooo
000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000P3oool2000000@0oooo
00<000000?ooo`3oool0203oool00`000000oooo000000090?ooo`8000003P3oool300000080oooo
0P0000000`3oool000000?ooo`050?ooo`030000003oool0oooo00H0oooo0P0000060?ooo`800000
0P3oool00`000000oooo0?ooo`030?ooo`8000001`3oool01@000000oooo0000003oool0000000<0
oooo00@000000?ooo`000000oooo0P0000070?ooo`8000000`3oool2000000L0oooo0P0000001@3o
ool000000000003oool000000080oooo00D000000?ooo`3oool0oooo000000040?ooo`@000000P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool0
0000203oool3000001P0oooo000B0?ooo`030?oog`2LM9`0gooo0080oooo00<0giad09cOo`3oool0
9P3oool00`2oM00007Bo0?ooo`090?ooo`030000003oool0oooo00D0oooo0P0000000`3oool00000
000000030?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00T0oooo00@000000?ooo`3oool0oooo0P000000103oool00000000000000002
0?ooo`<000001P3oool3000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`020?ooo`080000003oool0oooo0000003oool000000?ooo`0000020?ooo`80
00001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00000P3oool200000080oooo100000000`3oool000000?ooo`04000000030?ooo`000000oooo00<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool00P3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool00000008000002P3oool00`000000oooo0000000200000080oooo00D000000?ooo`3o
ool0oooo000000050?ooo`060000003oool000000?ooo`000000oooo0P0000000`3oool000000?oo
o`090?ooo`800000203oool01@000000oooo000000000000oooo008000001`3oool00`000000oooo
00000003000000L0oooo00<000000?ooo`3oool0100000030?ooo`8000002P3oool00`000000oooo
0?ooo`0F0?ooo`00@03oool00`3OW4P004RL0=ooo`090?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000000P3oool2000000D0oooo00L000000?ooo`000000oooo0000003oool0000000<0
oooo00<000000?ooo`0000000`3oool2000000H0oooo00H000000?ooo`3oool000000?ooo`000003
0?ooo`<0000000<0oooo0000003oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`0000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo100000040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`05
0000003oool0oooo0000003oool00P000000103oool000000?ooo`0000040?ooo`040000003oool0
00000?ooo`<0000000P0oooo000000000000oooo0000003oool000000?ooo`@0000000<0oooo0000
000000000`3oool01P000000oooo0?ooo`3oool000000?ooo`80000000<0oooo0000003oool00P3o
ool00`000000oooo0?ooo`04000000030?ooo`000000oooo00800000103oool010000000oooo0000
000000020?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0?oo
o`@000000`3oool00`000000oooo0?ooo`040?ooo`8000000P3oool01P000000oooo000000000000
oooo000000L0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0000000<00000
203oool2000000040?ooo`000000oooo000000<0oooo0`0000000`3oool0000000000002000000<0
oooo10000000103oool000000000003oool2000000<0oooo0`0000000`3oool000000?ooo`020000
0080oooo100000090?ooo`030000003oool0oooo01H0oooo00100?ooo`030?oOW01804P0W=oo00T0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool000000080
oooo00<000000?ooo`0000000P3oool01@000000oooo0000003oool000000080oooo00L000000?oo
o`000000oooo0000003oool0000000<0oooo0`0000060?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool000000?ooo`02000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0
1P3oool010000000oooo0?ooo`3oool3000000<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo0P0000060?oo
o`050000003oool0oooo0000003oool00P000000103oool000000?ooo`0000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00H000000?ooo`3oool000000?ooo`00
00020?ooo`050000003oool0oooo0?ooo`0000002@3oool2000000050?ooo`000000oooo0?ooo`00
00000`3oool2000000030?ooo`000000oooo00<0oooo00<000000?ooo`0000000`3oool300000080
oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000P3oool00`000000oooo000000040?ooo`@000000P3oool00`000000oooo0000
00020?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00<0
00000?ooo`0000000`0000030?ooo`030000003oool0oooo0080oooo0P0000001@3oool000000?oo
o`000000oooo00D0000000<0oooo0000000000000P0000000`3oool0000000000003000000D0oooo
0P0000030?ooo`050000003oool000000?ooo`0000000P3oool2000000040?ooo`000000oooo0?oo
o`800000203oool00`000000oooo0?ooo`0F0?ooo`00@03oool00`3ookl0M00007Boo`090?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000040?oo
o`050000003oool000000?ooo`0000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P000004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`00000000002`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0oooo00D0oooo00@0
00000?ooo`3oool000001P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
0000203oool200000080oooo0P000000103oool000000000000000060?ooo`030000003oool0oooo
00@0oooo0P0000040?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool02@3oool3000000030?ooo`000000oooo00D0oooo0`00000B0?ooo`@00000
0P3oool3000000P0oooo00<000000?ooo`3oool05P3oool00440oooo00<0_g@0001d_`3oool0203o
ool00`000000oooo0?ooo`0=0?ooo`<000003@3oool00`000000oooo0?ooo`080?ooo`050000003o
ool0oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0000000P0oooo0P0000070?ooo`05
0000003oool0oooo0000003oool00`00000?0?ooo`8000000P3oool2000000P0oooo00@000000?oo
o`3oool000000P3oool3000000L0oooo0P0000030?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`0000002`3oool200000080oooo0P0000060?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0?ooo`80000000@0
oooo00000000000000005P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
0P00000?0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000>0?ooo`03
0000003oool0oooo00<0oooo0P0000080?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0F0?ooo`00?`3oool01@3ookl0M0000000000007@0_ooo
00P0oooo0P00000>0?ooo`8000003P3oool200000080oooo0P0000090?ooo`030000003oool00000
0180oooo0P00000:0?ooo`030000003oool00000008000002P3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo000000L0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003o
ool0000000D0oooo00<000000?ooo`3oool00P0000090?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool01@3oool200000080oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`02000000L0oooo0P0000050?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
2@3oool020000000oooo000000000000oooo0000003oool000004P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0oooo0080oooo
0`00000H0?ooo`800000603oool004`0oooo00<000000?ooo`3oool02`3oool01P000000oooo0000
00000000oooo000000/0oooo00<000000?ooo`0000000P3oool3000000P0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`000000503oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001`3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0080oooo0P0000000`3oool0000000000002000000D0oooo
0P0000070?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00800000
2`3oool00`000000oooo000000080?ooo`060000003oool0oooo0000003oool000002@3oool00`00
0000oooo0?ooo`080?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0F0?ooo`00C03oool00`000000oooo0?ooo`0;0?ooo`060000003oool0oooo
0000003oool000002`3oool00`000000oooo0?ooo`020?ooo`<00000203oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool200000080oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000
oooo000000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04`3oool200000003
0?ooo`000000oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`05
0000003oool000000?ooo`0000004@3oool2000000@0oooo00<000000?ooo`3oool00P0000020?oo
o`030000003oool0oooo01D0oooo00H000000?ooo`3oool000000?ooo`0000090?ooo`040000003o
ool0oooo000000L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo0P00000<0?ooo`030000003oool0oooo01H0oooo001<0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`0000000P3oool2000000H0oooo00D000000?ooo`000000oooo
000000040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000
oooo0?ooo`3oool2000000D0oooo00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`00
00090?ooo`8000000P3oool00`000000oooo0?ooo`050?ooo`8000000`3oool00`000000oooo0000
000<0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000001`3oool00000
0?ooo`3oool000000?ooo`0000001P3oool01`000000oooo0?ooo`3oool000000?ooo`0000002@3o
ool00`000000oooo000000060?ooo`@0000000<0oooo0000003oool00P0000001@3oool000000?oo
o`3oool0000000d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`040000
003oool000000?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000T0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?oo
o`0000001`3oool4000000X0oooo00<000000?ooo`3oool05P3oool004`0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool00`3oool2000000H0oooo00D000000?oo
o`3oool0oooo000000060?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`0000000P00
00020?ooo`8000001P3oool01@000000oooo0?ooo`3oool0000000L0oooo0P0000030?ooo`030000
003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo0?oo
o`800000103oool2000000H0oooo00<000000?ooo`3oool0303oool01@000000oooo0000003oool0
000000H0oooo00<000000?ooo`3oool00`0000000`3oool00000000000040?ooo`800000303oool0
0`000000oooo0?ooo`0A0?ooo`040000003oool000000?ooo`800000103oool00`000000oooo0?oo
o`050?ooo`8000000`3oool2000000030?ooo`000000000001D0oooo00<000000?ooo`3oool02P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool00000
00T0oooo0P00000:0?ooo`030000003oool0oooo01H0oooo001<0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo000000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
00001`3oool00`000000oooo0?ooo`0200000080oooo0P0000040?ooo`030000003oool0000000L0
oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`050?ooo`030000003oool0000000`0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`030?ooo`<000001P3oool010000000oooo0?ooo`3oool2
000000030?ooo`000000000001X0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`00
00040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0F0?ooo`00C03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000001@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`02000000<0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo00000004
0?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`04
0?ooo`8000001`3oool00`000000oooo000000040?ooo`80000000<0oooo0000003oool0203oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`8000004@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01H0oooo001<
0?ooo`8000001@3oool00`000000oooo000000030?ooo`030000003oool000000080oooo00@00000
0?ooo`3oool0oooo0P0000040?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo000000020?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo000000050?ooo`040000003oool0oooo0?ooo`8000000`3oool010000000
oooo0?ooo`3oool2000000040?ooo`000000oooo00000080oooo0P0000040?ooo`030000003oool0
oooo0140oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@000000?ooo`3oool0
00001P3oool01@000000oooo0000003oool0000000`0oooo00<000000?ooo`3oool00`3oool30000
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00T0oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool000000000003oool00P00
00020?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool01P3oool00`000000oooo
0?ooo`080?ooo`040000003oool0oooo0?ooo`8000001`3oool00`000000oooo000000050?ooo`03
0000003oool0000000P0oooo0P00000F0?ooo`060000003oool0oooo0000003oool00000103oool0
1@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0203oool2000001P0oooo001<
0?ooo`030000003oool0oooo00H0oooo0`000000103oool000000?ooo`0000020?ooo`040000003o
ool0oooo0?ooo`80000000D0oooo0000003oool0oooo000000020?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000P3oool2000000<0oooo0`0000040?oo
o`030000003oool0oooo00<0oooo0`0000020?ooo`040000003oool0oooo000000<0oooo0P000003
0?ooo`8000000P3oool2000000030?ooo`000000000000<0000000<0oooo0000000000002`3oool0
0`000000oooo000000020?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`040000003oool0
00000?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`050000003oool000000?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P0000001@3oool0
00000?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0
000000`0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`050000003o
ool0oooo0000003oool00P0000020?ooo`040000003oool0oooo0?ooo`<000001`3oool200000003
0?ooo`000000oooo00L0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01@3oool2000000060?ooo`00000000000?ooo`000000oooo0P00
00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P0000050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P0000040?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool05P3oool004`0oooo00<000000?ooo`3oool01`3oool2000000<0oooo00<00000
0?ooo`3oool00P3oool300000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000030?ooo`<00000
2`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`3oool2000000<0oooo00D000000?ooo`00000000000?ooo`0200000080oooo00<00000
0?ooo`3oool0203oool2000000050?ooo`00000000000?ooo`0000001@3oool00`000000oooo0?oo
o`030?ooo`80000000<0oooo0000003oool02@3oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`3oool0oooo000000060?ooo`040000003oool0oooo000000P0oooo00D000000?oo
o`3oool0oooo000000050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000001@3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool01@3o
ool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0?ooo`0000002P3oool010000000
oooo0?ooo`3oool2000000L0oooo0P0000001P3oool000000?ooo`3oool000000?ooo`800000103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo008000001@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0F0?ooo`00C03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo0P00000P
0?ooo`800000<`3oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000@`3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05P3o
ool004`0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo01H0oooo001<0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1X0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0F0?ooo`00C03oool2000003@0oooo00<000000?ooo`3oool0NP3oool00`000000
oooo000000080?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0000000B0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0;P3oool2000001P0
oooo001<0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`000000;`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo01H0oooo001<0?ooo`030000003oool0oooo06@0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01H0oooo001<
0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0F
0?ooo`00C03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool0DP3oool01@000000oooo0?ooo`3oool0000000l0oooo0P00001N0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool05P3oool004`0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`290?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo001<0?ooo`800000Z`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`1E0?ooo`800000603oool004`0oooo00<000000?ooo`3oool0b03oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool05P3oool00300oooo00@0
_g@0000000000000M;oo0`3oool00`3ogi`0B00007Boo`020?ooo`060?oOW0180000000000000000
B9`0gooo2P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0N03oool00`000000oooo0?ooo`0Q0?ooo`050000003oool0oooo0?ooo`000000E`3oool0
0`000000oooo0?ooo`0F0?ooo`00;`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`80oooo00<0
omnL04P0001d_ol00P3oool01P3o_g@0000007Boo`3oool0omnL04Qd_`X0oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool05P3oool002h0oooo00<0oooO09a80018W=l00P3oool00`3o_g@0001809cOo`0;0?ooo`030?no
M018W=l0oooo00P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo01H0oooo000^0?ooo`030?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0gooo
2P3oool00`3ookl0M01d0;ooo`080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`030?oog`2L
B000000000L0000000H0B9cO0?ooo`3oool0oooO09a80000M;l30?ooo`030=nLB00004P0W=oo00X0
oooo00<0oooO09a8001d_ol0203oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0F0?ooo`00;`3oool00`2oM00004RL
0=ooo`020?ooo`030?oOW0180000B9cO00X0oooo00<0oono07@00018W=l0203oool3000003L0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0000003d0oooo
0`00000H0?ooo`00;`3oool00`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo00X0oooo00<0
okmd0000001d_ol0203oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool05P3oool002l0oooo00<0omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`06
0?ooo`060?oOg`3Oool0okmd0000000007@0_ooo203oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo0640oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo01H0oooo000_0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0
1P3oool01@3ookl0M0000000000004P0W=oo00T0oooo00<000000?ooo`3oool0BP3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo0000000Y0?oo
o`030000003oool0oooo03D0oooo00<000000?ooo`3oool05P3oool00300oooo00<0omnL04P0001d
_ol00P3oool00`3OW4P007Bo0?ooo`070?ooo`030=nLW02oool0oooo00X0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0503oool200000080oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01H0oooo000a0?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO203oool00`3o
gi`0M9cO0?ooo`0:0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0Z`3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool000004`3oool0
0`000000oooo0?ooo`0F0?ooo`00<P3oool0103OW4P0000000000000M;l:0?ooo`050;md00000000
000000000018W=l01`3oool2000006T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000
000U0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`0H0?ooo`8000005@3oool2000001P0oooo001<0?ooo`030000003oool0oooo06P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0000000R0?ooo`040000003oool0oooo000002D0oooo00<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool05P3oool004`0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0F
0?ooo`00C03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool0903oool00`000000oooo0000000H0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0F0?ooo`00C03oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0000000X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo06l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0F0?ooo`00
C03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0
oooo0000000o0?ooo`030000003oool0oooo01H0oooo001<0?ooo`800000;03oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool01@000000oooo
0?ooo`3oool0000001l0oooo00<000000?ooo`3oool0703oool2000001P0oooo001<0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`2E0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0000000T0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0F0?ooo`00C03o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`1Y0?ooo`040000003oool0oooo000002D0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0F0?ooo`00C03oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1Y0?ooo`030000003o
ool0oooo0500oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0F0?ooo`00C03oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01H0oooo001<0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`00C03oool2000004X0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0100
oooo0P00000H0?ooo`00C03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000P0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool05P3oool004`0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000c0?ooo`03
0000003oool0oooo01H0oooo001<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01H0oooo001<0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo05h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo01H0oooo001<0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool05P3oool004`0oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00L0oooo00D00000
0?ooo`3oool0oooo0000000O0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool05P3o
ool004`0oooo0P00002d0?ooo`030000003oool0oooo02X0oooo00D000000?ooo`3oool0oooo0000
000?0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool05P3oool2000001P0oooo000n
0?ooo`040;md00000000000007Boo`X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`1l0?ooo`040000003oool0oooo00000540oooo00D000000?ooo`3oool0oooo000000190?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool05P3oool003d0oooo00H0gia8001d_`3oool0
omnL04P00018W=l90?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool00000N03oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01H0oooo000l0?ooo`030?oog`2LB000B9cO
0080oooo00<0okmd0000B02Lgol0203oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0F0?ooo`00?03oool00`3ooml0
W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooo`L0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool05P3oool003`0
oooo00<0oooO09a80000M;l00`3oool00`3OW4P0001809cOo`070?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`000000:`3oool00`000000oooo0?ooo`0F0?ooo`00?@3oool00`2oM00004RL
0=ooo`020?ooo`030?oOW0180000B9cO00L0ooooo`00001=000001P0oooo000m0?ooo`030=nLB000
04P0W=oo0080oooo00<0oooO09a80000M;l01`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo01H0oooo000m0?ooo`030?oOW0180000B9cO00<0oooo00<0_g@00018W03Oool01P3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo01H0oooo000m0?ooo`040?oog`2LB00004RL
0=ooo`80oooo00<0gia80018W03Oool01P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05P3oool003h0oooo00<0omnL04P0001d_ol00P3oool00`3O
W4P007Bo0?ooo`060?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0X0?ooo`800000B`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool05P3oool003l0oooo00H0gia80000M02oool0oooO09a80018W=l7
0?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool00000<03oool01@000000oooo0?oo
o`3oool0000000H0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`2@0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool05P3oool00400oooo00@0gia800000000000007Bo
203oool2000000h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo04P0oooo0P00000H0?ooo`00C03oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`0000006`3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo01H0oooo001<0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0F0?ooo`00C03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
05d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01H0oooo001<0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`0F0?ooo`00C03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01H0oooo
001<0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0F0?ooo`00C03oool200000180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`02
0?ooo`800000603oool00`000000oooo0?ooo`0F0?ooo`800000603oool004`0oooo00<000000?oo
o`3oool0C03oool01@000000oooo0?ooo`3oool0000002<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05P3oool0
04`0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0;0?ooo`8000009P3oool00`00
0000oooo000000050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01H0oooo001<0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo0000
00d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool05P3oool004`0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`1G0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool05P3oool01000
0000oooo0?ooo`00000=0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0F0?ooo`00C03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03D0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1J0?ooo`050000003oool0
oooo0?ooo`000000D`3oool00`000000oooo0?ooo`0F0?ooo`00C03oool2000002@0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`1E0?ooo`800000;@3oool01@000000oooo0?oo
o`3oool0000001H0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`070?ooo`800000
603oool004`0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`3oool000005`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool0903oool2000002<0oooo00<000000?ooo`3oool0
803oool00`000000oooo000000030?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01H0oooo001<0?ooo`030000003o
ool0oooo03X0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`040000003oool0oooo000001L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0D0?ooo`<000003P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01H0oooo001<0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0200oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000L0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool05P3oool004`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool2000000H0oooo00<000000?oo
o`3oool04@3oool010000000oooo0?ooo`00000H0?ooo`030000003oool0oooo00H0oooo00D00000
0?ooo`3oool0oooo0000000>0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo
0000000@0?ooo`80000000<0oooo0000003oool03@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool05P3oool004`0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`8000001P3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo00`0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool05P3oool004`0oooo0P00000k0?ooo`030000003oool0oooo05d0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`2E0?ooo`800000603oool004`0oooo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0Z`3oool00`000000oooo0?ooo`0F0?ooo`00<03oool0102oM00000000000001d_ol3
0?ooo`030?oOW0180000M;oo0080oooo00H0omnL04P00000000000000018W03Oool:0?ooo`030000
003oool0oooo07`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo03`0oooo00<000000?ooo`3oool05P3oool002l0oooo00H0gia8001d_`3oool0omnL
04P00018W=l20?ooo`030?oOW0180000M;oo0080oooo00H0okmd0000001d_ol0oooo0?oOW018M;l:
0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool05P3oool002h0oooo00<0oooO09a8
0018W=l00P3oool00`3o_g@0001809cOo`0;0?ooo`030?noM018W=l0oooo00P0oooo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`0F0?ooo`00;P3oool00`3ooml0W4P004RLg`020?ooo`04
0?oog`2LB00004RL0=ooo`X0oooo00<0oono07@0M02oool0203oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo07l0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0F0?oo
o`00;P3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00004P0W=oo00X0oooo00<0oooO09a8001d
_ol0203oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool05P3oool002l0oooo
00<0_g@00018W03Oool00P3oool00`3ogi`0B00004RLg`0:0?ooo`030?oo_`1d0000B9cO00P0oooo
0`0000050?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo1000000H0?ooo`00;`3oool00`3OW4P0001809cO
o`020?ooo`030?oog`2LB00007Bo00X0oooo00<0okmd0000001d_ol0203oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool00000603oool002l0oooo00<0
omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`060?ooo`060?oOg`3Oool0okmd0000000007@0
_ooo203ooooo000004d00000603oool002l0oooo00@0oooO09a80000B9`0gooo0P3oool00`3OW4P0
04RL0=ooo`060?ooo`050?oo_`1d000000000000B02Lgol0o`3ooom^0?ooo`00<03oool00`3ogi`0
B00007Boo`020?ooo`030=nLB000M;l0oooo00L0oooo00<0gibL0;ooo`3oool0o`3ooom_0?ooo`00
<@3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`P0oooo00<0omnL07BLg`3oool0o`3ooom_0?oo
o`00<P3oool0103OW4P0000000000000M;l:0?ooo`050;md00000000000000000018W=l0o`3ooom/
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2107.69, -3.51989, 37.4581, \
0.0237294}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.000120876 0.319531 0.141477 [
[.02381 -0.0125 -5 -15.6875 ]
[.02381 -0.0125 5 0 ]
[.26556 -0.0125 -14 -15.6875 ]
[.26556 -0.0125 14 0 ]
[.50731 -0.0125 -14 -15.6875 ]
[.50731 -0.0125 14 0 ]
[.74906 -0.0125 -14 -15.6875 ]
[.74906 -0.0125 14 0 ]
[.99082 -0.0125 -14 -15.6875 ]
[.99082 -0.0125 14 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4.9375 -31.375 ]
[.5 -0.0125 4.9375 -15.6875 ]
[-0.0125 .03658 -18.6875 -7.84375 ]
[-0.0125 .03658 0 7.84375 ]
[-0.0125 .17805 -18.6875 -7.84375 ]
[-0.0125 .17805 0 7.84375 ]
[-0.0125 .31953 -10 -7.84375 ]
[-0.0125 .31953 0 7.84375 ]
[-0.0125 .46101 -10 -7.84375 ]
[-0.0125 .46101 0 7.84375 ]
[-0.0125 .60249 -10 -7.84375 ]
[-0.0125 .60249 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.375 -7.125 ]
[-0.01875 .30902 -18.6875 7.125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.26556 0 m
.26556 .00625 L
s
gsave
.26556 -0.0125 -75 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
1.000 setlinewidth
grestore
.50731 0 m
.50731 .00625 L
s
gsave
.50731 -0.0125 -75 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4000) show
1.000 setlinewidth
grestore
.74906 0 m
.74906 .00625 L
s
gsave
.74906 -0.0125 -75 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6000) show
1.000 setlinewidth
grestore
.99082 0 m
.99082 .00625 L
s
gsave
.99082 -0.0125 -75 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8000) show
1.000 setlinewidth
grestore
.125 Mabswid
.08425 0 m
.08425 .00375 L
s
.14469 0 m
.14469 .00375 L
s
.20512 0 m
.20512 .00375 L
s
.326 0 m
.326 .00375 L
s
.38644 0 m
.38644 .00375 L
s
.44688 0 m
.44688 .00375 L
s
.56775 0 m
.56775 .00375 L
s
.62819 0 m
.62819 .00375 L
s
.68863 0 m
.68863 .00375 L
s
.8095 0 m
.8095 .00375 L
s
.86994 0 m
.86994 .00375 L
s
.93038 0 m
.93038 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65.9375 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
68.875 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .03658 m
.00625 .03658 L
s
gsave
-0.0125 .03658 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .17805 m
.00625 .17805 L
s
gsave
-0.0125 .17805 -79.6875 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.688 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .31953 m
.00625 .31953 L
s
gsave
-0.0125 .31953 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .46101 m
.00625 .46101 L
s
gsave
-0.0125 .46101 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .60249 m
.00625 .60249 L
s
gsave
-0.0125 .60249 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .06487 m
.00375 .06487 L
s
0 .09317 m
.00375 .09317 L
s
0 .12146 m
.00375 .12146 L
s
0 .14976 m
.00375 .14976 L
s
0 .20635 m
.00375 .20635 L
s
0 .23464 m
.00375 .23464 L
s
0 .26294 m
.00375 .26294 L
s
0 .29124 m
.00375 .29124 L
s
0 .34783 m
.00375 .34783 L
s
0 .37612 m
.00375 .37612 L
s
0 .40442 m
.00375 .40442 L
s
0 .43271 m
.00375 .43271 L
s
0 .4893 m
.00375 .4893 L
s
0 .5176 m
.00375 .5176 L
s
0 .54589 m
.00375 .54589 L
s
0 .57419 m
.00375 .57419 L
s
0 .00828 m
.00375 .00828 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -94.6563 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.125 11.8438 translate
90 rotate
-68.125 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
68.563 18.625 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
68.563 11.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\242) show
73.250 15.813 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.26556 .61178 m
.26556 .61803 L
s
.50731 .61178 m
.50731 .61803 L
s
.74906 .61178 m
.74906 .61803 L
s
.99082 .61178 m
.99082 .61803 L
s
.125 Mabswid
.08425 .61428 m
.08425 .61803 L
s
.14469 .61428 m
.14469 .61803 L
s
.20512 .61428 m
.20512 .61803 L
s
.326 .61428 m
.326 .61803 L
s
.38644 .61428 m
.38644 .61803 L
s
.44688 .61428 m
.44688 .61803 L
s
.56775 .61428 m
.56775 .61803 L
s
.62819 .61428 m
.62819 .61803 L
s
.68863 .61428 m
.68863 .61803 L
s
.8095 .61428 m
.8095 .61803 L
s
.86994 .61428 m
.86994 .61803 L
s
.93038 .61428 m
.93038 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03658 m
1 .03658 L
s
.99375 .17805 m
1 .17805 L
s
.99375 .31953 m
1 .31953 L
s
.99375 .46101 m
1 .46101 L
s
.99375 .60249 m
1 .60249 L
s
.125 Mabswid
.99625 .06487 m
1 .06487 L
s
.99625 .09317 m
1 .09317 L
s
.99625 .12146 m
1 .12146 L
s
.99625 .14976 m
1 .14976 L
s
.99625 .20635 m
1 .20635 L
s
.99625 .23464 m
1 .23464 L
s
.99625 .26294 m
1 .26294 L
s
.99625 .29124 m
1 .29124 L
s
.99625 .34783 m
1 .34783 L
s
.99625 .37612 m
1 .37612 L
s
.99625 .40442 m
1 .40442 L
s
.99625 .43271 m
1 .43271 L
s
.99625 .4893 m
1 .4893 L
s
.99625 .5176 m
1 .5176 L
s
.99625 .54589 m
1 .54589 L
s
.99625 .57419 m
1 .57419 L
s
.99625 .00828 m
1 .00828 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .31953 m
1 .31953 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02393 .27469 Mdot
.02405 .5351 Mdot
.02417 .42074 Mdot
.02429 .29285 Mdot
.02441 .49013 Mdot
.02453 .26905 Mdot
.02466 .45077 Mdot
.02478 .42783 Mdot
.0249 .30735 Mdot
.02502 .4889 Mdot
.02514 .26926 Mdot
.02526 .46282 Mdot
.02538 .35412 Mdot
.0255 .43283 Mdot
.02562 .30187 Mdot
.02574 .49987 Mdot
.02586 .26899 Mdot
.02599 .29554 Mdot
.02611 .2025 Mdot
.02623 .48939 Mdot
.02635 .03369 Mdot
.02647 .55851 Mdot
.02659 .3397 Mdot
.02671 .48602 Mdot
.02683 .2699 Mdot
.02695 .4859 Mdot
.02707 .38765 Mdot
.02719 .36983 Mdot
.02731 .38008 Mdot
.02744 .36703 Mdot
.02756 .38744 Mdot
.02768 .35603 Mdot
.0278 .40578 Mdot
.02792 .33138 Mdot
.02804 .44876 Mdot
.02816 .28854 Mdot
.02828 .52202 Mdot
.0284 .28396 Mdot
.02852 .05045 Mdot
.02864 .52141 Mdot
.02877 .03692 Mdot
.02889 .53441 Mdot
.02901 .41532 Mdot
.02913 .32152 Mdot
.02925 .46473 Mdot
.02937 .27816 Mdot
.02949 .53609 Mdot
.02961 .34914 Mdot
.02973 .50281 Mdot
.02985 .26985 Mdot
.02997 .22789 Mdot
.0301 .3571 Mdot
.03022 .46145 Mdot
.03034 .20857 Mdot
.03046 .48866 Mdot
.03058 .02724 Mdot
.0307 .55669 Mdot
.03082 .33869 Mdot
.03094 .50093 Mdot
.03106 .26932 Mdot
.03118 .27019 Mdot
.0313 .27261 Mdot
.03142 .47889 Mdot
.03155 .03732 Mdot
.03167 .53418 Mdot
.03179 .41706 Mdot
.03191 .31942 Mdot
.03203 .46836 Mdot
.03215 .27625 Mdot
.03227 .53649 Mdot
.03239 .38096 Mdot
.03251 .38004 Mdot
.03263 .36456 Mdot
.03275 .39169 Mdot
.03288 .35 Mdot
.033 .41614 Mdot
.03312 .31911 Mdot
.03324 .47023 Mdot
.03336 .27534 Mdot
.03348 .53594 Mdot
.0336 .40216 Mdot
.03372 .32526 Mdot
.03384 .44772 Mdot
.03396 .28932 Mdot
.03408 .52066 Mdot
.0342 .28193 Mdot
.03433 .05023 Mdot
.03445 .52055 Mdot
.03457 .03788 Mdot
.03469 .53391 Mdot
.03481 .42112 Mdot
.03493 .31468 Mdot
.03505 .47646 Mdot
.03517 .27268 Mdot
.03529 .52857 Mdot
.03541 .50804 Mdot
.03553 .27961 Mdot
.03566 .10459 Mdot
.03578 .50164 Mdot
.0359 .36065 Mdot
.03602 .45578 Mdot
.03614 .2619 Mdot
.03626 .48055 Mdot
.03638 .03234 Mdot
.0365 .53694 Mdot
.03662 .3891 Mdot
.03674 .3591 Mdot
.03686 .39991 Mdot
.03698 .33889 Mdot
.03711 .43554 Mdot
.03723 .29944 Mdot
.03735 .50379 Mdot
.03747 .26974 Mdot
.03759 .21416 Mdot
.03771 .37748 Mdot
.03783 .45337 Mdot
.03795 .27165 Mdot
.03807 .47905 Mdot
.03819 .04179 Mdot
.03831 .53195 Mdot
.03844 .44532 Mdot
.03856 .29117 Mdot
.03868 .51598 Mdot
.0388 .27652 Mdot
.03892 .05506 Mdot
.03904 .5107 Mdot
.03916 .06932 Mdot
.03928 .52088 Mdot
.0394 .30003 Mdot
.03952 .20136 Mdot
.03964 .48959 Mdot
.03977 .0346 Mdot
.03989 .55869 Mdot
.04001 .34044 Mdot
.04013 .48193 Mdot
.04025 .27093 Mdot
.04037 .51026 Mdot
.04049 .59178 Mdot
.04061 .11974 Mdot
.04073 .4681 Mdot
.04085 .30705 Mdot
.04097 .4728 Mdot
.04109 .10107 Mdot
.04122 .51102 Mdot
.04134 .21289 Mdot
.04146 .34895 Mdot
.04158 .02651 Mdot
.0417 .5407 Mdot
.04182 .36073 Mdot
.04194 .41619 Mdot
.04206 .31892 Mdot
.04218 .47068 Mdot
.0423 .27513 Mdot
.04242 .53571 Mdot
.04255 .40788 Mdot
.04267 .31393 Mdot
.04279 .46362 Mdot
.04291 .27876 Mdot
.04303 .53563 Mdot
.04315 .34087 Mdot
.04327 .53018 Mdot
.04339 .30626 Mdot
.04351 .13899 Mdot
.04363 .45216 Mdot
.04375 .36251 Mdot
.04387 .45582 Mdot
.044 .26047 Mdot
.04412 .48077 Mdot
.04424 .03117 Mdot
.04436 .53764 Mdot
.04448 .38312 Mdot
.0446 .36945 Mdot
.04472 .38301 Mdot
.04484 .36255 Mdot
.04496 .39482 Mdot
.04508 .34568 Mdot
.0452 .42364 Mdot
.04533 .31099 Mdot
.04545 .48421 Mdot
.04557 .27022 Mdot
.04569 .49914 Mdot
.04581 .52447 Mdot
.04593 .30786 Mdot
.04605 .11296 Mdot
.04617 .47026 Mdot
.04629 .3004 Mdot
.04641 .47411 Mdot
.04653 .08727 Mdot
.04666 .51502 Mdot
.04678 .18421 Mdot
.0469 .05334 Mdot
.04702 .52453 Mdot
.04714 .46646 Mdot
.04726 .27691 Mdot
.04738 .53632 Mdot
.0475 .35502 Mdot
.04762 .47827 Mdot
.04774 .27221 Mdot
.04786 .52297 Mdot
.04798 .55791 Mdot
.04811 .53702 Mdot
.04823 .37383 Mdot
.04835 .40227 Mdot
.04847 .33471 Mdot
.04859 .44328 Mdot
.04871 .2928 Mdot
.04883 .51494 Mdot
.04895 .2756 Mdot
.04907 .05908 Mdot
.04919 .50684 Mdot
.04931 .08919 Mdot
.04944 .51447 Mdot
.04956 .2013 Mdot
.04968 .05661 Mdot
.0498 .56216 Mdot
.04992 .43422 Mdot
.05004 .30098 Mdot
.05016 .49954 Mdot
.05028 .26895 Mdot
.0504 .30237 Mdot
.05052 .18111 Mdot
.05064 .49305 Mdot
.05076 .05742 Mdot
.05089 .5599 Mdot
.05101 .52294 Mdot
.05113 .28394 Mdot
.05125 .05078 Mdot
.05137 .52216 Mdot
.05149 .03636 Mdot
.05161 .53471 Mdot
.05173 .41199 Mdot
.05185 .32567 Mdot
.05197 .45756 Mdot
.05209 .28242 Mdot
.05222 .53148 Mdot
.05234 .30929 Mdot
.05246 .18857 Mdot
.05258 .40742 Mdot
.0527 .43392 Mdot
.05282 .36253 Mdot
.05294 .45614 Mdot
.05306 .2578 Mdot
.05318 .48117 Mdot
.0533 .02915 Mdot
.05342 .53893 Mdot
.05354 .37331 Mdot
.05367 .38817 Mdot
.05379 .35465 Mdot
.05391 .40818 Mdot
.05403 .32843 Mdot
.05415 .45395 Mdot
.05427 .28482 Mdot
.05439 .52796 Mdot
.05451 .29663 Mdot
.05463 .05762 Mdot
.05475 .50805 Mdot
.05487 .08329 Mdot
.055 .51627 Mdot
.05512 .13124 Mdot
.05524 .44418 Mdot
.05536 .4493 Mdot
.05548 .26339 Mdot
.0556 .48032 Mdot
.05572 .03347 Mdot
.05584 .53628 Mdot
.05596 .39509 Mdot
.05608 .34947 Mdot
.0562 .41624 Mdot
.05633 .31901 Mdot
.05645 .4704 Mdot
.05657 .27527 Mdot
.05669 .53586 Mdot
.05681 .40424 Mdot
.05693 .321 Mdot
.05705 .45383 Mdot
.05717 .28489 Mdot
.05729 .52778 Mdot
.05741 .29612 Mdot
.05753 .05623 Mdot
.05765 .50941 Mdot
.05778 .07628 Mdot
.0579 .51852 Mdot
.05802 .05452 Mdot
.05814 .51173 Mdot
.05826 .06059 Mdot
.05838 .52404 Mdot
.0585 .52938 Mdot
.05862 .5188 Mdot
.05874 .30225 Mdot
.05886 .05664 Mdot
.05898 .50896 Mdot
.05911 .07883 Mdot
.05923 .51769 Mdot
.05935 .05804 Mdot
.05947 .52699 Mdot
.05959 .04388 Mdot
.05971 .53099 Mdot
.05983 .46047 Mdot
.05995 .28035 Mdot
.06007 .53303 Mdot
.06019 .31739 Mdot
.06031 .35441 Mdot
.06043 .02534 Mdot
.06056 .54162 Mdot
.06068 .35607 Mdot
.0608 .42814 Mdot
.06092 .30636 Mdot
.06104 .49228 Mdot
.06116 .26886 Mdot
.06128 .42431 Mdot
.0614 .16065 Mdot
.06152 .27837 Mdot
.06164 .47171 Mdot
.06176 .02059 Mdot
.06189 .547 Mdot
.06201 .34045 Mdot
.06213 .48146 Mdot
.06225 .27106 Mdot
.06237 .51235 Mdot
.06249 .59296 Mdot
.06261 .21008 Mdot
.06273 .17193 Mdot
.06285 .0231 Mdot
.06297 .54043 Mdot
.06309 .33996 Mdot
.06322 .48376 Mdot
.06334 .27043 Mdot
.06346 .50075 Mdot
.06358 .5412 Mdot
.0637 .37532 Mdot
.06382 .39716 Mdot
.06394 .34118 Mdot
.06406 .43186 Mdot
.06418 .30284 Mdot
.0643 .49807 Mdot
.06442 .26881 Mdot
.06454 .33086 Mdot
.06467 .08717 Mdot
.06479 .51495 Mdot
.06491 .17504 Mdot
.06503 .13951 Mdot
.06515 .496 Mdot
.06527 .15842 Mdot
.06539 .1853 Mdot
.06551 .48462 Mdot
.06563 .07449 Mdot
.06575 .55628 Mdot
.06587 .14094 Mdot
.066 .37286 Mdot
.06612 .46274 Mdot
.06624 .0782 Mdot
.06636 .51786 Mdot
.06648 .05143 Mdot
.0666 .52427 Mdot
.06672 .0316 Mdot
.06684 .5374 Mdot
.06696 .38579 Mdot
.06708 .36474 Mdot
.0672 .39061 Mdot
.06732 .35154 Mdot
.06745 .41347 Mdot
.06757 .32216 Mdot
.06769 .46493 Mdot
.06781 .27805 Mdot
.06793 .53615 Mdot
.06805 .35063 Mdot
.06817 .49675 Mdot
.06829 .26904 Mdot
.06841 .34904 Mdot
.06853 .03749 Mdot
.06865 .53403 Mdot
.06878 .41608 Mdot
.0689 .32059 Mdot
.06902 .46634 Mdot
.06914 .27729 Mdot
.06926 .53648 Mdot
.06938 .36194 Mdot
.0695 .44916 Mdot
.06962 .28824 Mdot
.06974 .52322 Mdot
.06986 .28596 Mdot
.06998 .05048 Mdot
.0701 .52145 Mdot
.07023 .03694 Mdot
.07035 .53439 Mdot
.07047 .41547 Mdot
.07059 .32134 Mdot
.07071 .46505 Mdot
.07083 .27798 Mdot
.07095 .53619 Mdot
.07107 .35151 Mdot
.07119 .49311 Mdot
.07131 .26907 Mdot
.07143 .4079 Mdot
.07156 .16938 Mdot
.07168 .05855 Mdot
.0718 .52208 Mdot
.07192 .49704 Mdot
.07204 .26823 Mdot
.07216 .36003 Mdot
.07228 .02151 Mdot
.0724 .5454 Mdot
.07252 .34295 Mdot
.07264 .47018 Mdot
.07276 .27543 Mdot
.07289 .53588 Mdot
.07301 .40381 Mdot
.07313 .32187 Mdot
.07325 .4526 Mdot
.07337 .28575 Mdot
.07349 .52644 Mdot
.07361 .29263 Mdot
.07373 .05101 Mdot
.07385 .51635 Mdot
.07397 .04772 Mdot
.07409 .52926 Mdot
.07421 .48699 Mdot
.07434 .26915 Mdot
.07446 .48497 Mdot
.07458 .38082 Mdot
.0747 .38896 Mdot
.07482 .35238 Mdot
.07494 .41224 Mdot
.07506 .32359 Mdot
.07518 .46244 Mdot
.0753 .27945 Mdot
.07542 .53507 Mdot
.07554 .33371 Mdot
.07567 .5334 Mdot
.07579 .43382 Mdot
.07591 .2768 Mdot
.07603 .51024 Mdot
.07615 .27223 Mdot
.07627 .10086 Mdot
.07639 .47853 Mdot
.07651 .26056 Mdot
.07663 .48076 Mdot
.07675 .03172 Mdot
.07687 .53731 Mdot
.07699 .38592 Mdot
.07712 .36451 Mdot
.07724 .39098 Mdot
.07736 .35101 Mdot
.07748 .41438 Mdot
.0776 .32111 Mdot
.07772 .46675 Mdot
.07784 .27708 Mdot
.07796 .53653 Mdot
.07808 .36561 Mdot
.0782 .43434 Mdot
.07832 .30034 Mdot
.07845 .50296 Mdot
.07857 .26954 Mdot
.07869 .23159 Mdot
.07881 .35111 Mdot
.07893 .46335 Mdot
.07905 .19096 Mdot
.07917 .49157 Mdot
.07929 .04254 Mdot
.07941 .5598 Mdot
.07953 .35901 Mdot
.07965 .42064 Mdot
.07978 .31405 Mdot
.0799 .47912 Mdot
.08002 .27172 Mdot
.08014 .52172 Mdot
.08026 .56621 Mdot
.08038 .6026 Mdot
.0805 .18105 Mdot
.08062 .49357 Mdot
.08074 .05114 Mdot
.08086 .56017 Mdot
.08098 .42389 Mdot
.0811 .3116 Mdot
.08123 .48168 Mdot
.08135 .27091 Mdot
.08147 .51219 Mdot
.08159 .59295 Mdot
.08171 .20939 Mdot
.08183 .16191 Mdot
.08195 .11429 Mdot
.08207 .50237 Mdot
.08219 .21083 Mdot
.08231 .13679 Mdot
.08243 .45123 Mdot
.08256 .36613 Mdot
.08268 .45403 Mdot
.0828 .27266 Mdot
.08292 .47889 Mdot
.08304 .04296 Mdot
.08316 .53139 Mdot
.08328 .45316 Mdot
.0834 .2852 Mdot
.08352 .52583 Mdot
.08364 .29119 Mdot
.08376 .05037 Mdot
.08388 .51824 Mdot
.08401 .04258 Mdot
.08413 .53159 Mdot
.08425 .45137 Mdot
.08437 .28649 Mdot
.08449 .52374 Mdot
.08461 .28689 Mdot
.08473 .05041 Mdot
.08485 .52125 Mdot
.08497 .03718 Mdot
.08509 .53427 Mdot
.08521 .4169 Mdot
.08534 .31961 Mdot
.08546 .46803 Mdot
.08558 .27642 Mdot
.0857 .53653 Mdot
.08582 .3776 Mdot
.08594 .39081 Mdot
.08606 .34956 Mdot
.08618 .41717 Mdot
.0863 .31796 Mdot
.08642 .47223 Mdot
.08654 .27443 Mdot
.08666 .53462 Mdot
.08679 .42946 Mdot
.08691 .28159 Mdot
.08703 .50384 Mdot
.08715 .26969 Mdot
.08727 .21444 Mdot
.08739 .37711 Mdot
.08751 .45355 Mdot
.08763 .27046 Mdot
.08775 .47923 Mdot
.08787 .04049 Mdot
.08799 .53258 Mdot
.08812 .43683 Mdot
.08824 .29853 Mdot
.08836 .50366 Mdot
.08848 .2697 Mdot
.0886 .21709 Mdot
.08872 .37338 Mdot
.08884 .45524 Mdot
.08896 .25873 Mdot
.08908 .48103 Mdot
.0892 .02981 Mdot
.08932 .5385 Mdot
.08945 .37645 Mdot
.08957 .3819 Mdot
.08969 .36377 Mdot
.08981 .39283 Mdot
.08993 .34842 Mdot
.09005 .41888 Mdot
.09017 .31607 Mdot
.09029 .47549 Mdot
.09041 .27306 Mdot
.09053 .53042 Mdot
.09065 .4873 Mdot
.09077 .25841 Mdot
.0909 .09787 Mdot
.09102 .48053 Mdot
.09114 .24972 Mdot
.09126 .4824 Mdot
.09138 .02454 Mdot
.0915 .54238 Mdot
.09162 .35364 Mdot
.09174 .43481 Mdot
.09186 .30005 Mdot
.09198 .50296 Mdot
.0921 .26954 Mdot
.09223 .23156 Mdot
.09235 .35117 Mdot
.09247 .46333 Mdot
.09259 .19113 Mdot
.09271 .49154 Mdot
.09283 .04236 Mdot
.09295 .55979 Mdot
.09307 .35823 Mdot
.09319 .42262 Mdot
.09331 .31196 Mdot
.09343 .48271 Mdot
.09355 .27062 Mdot
.09368 .50736 Mdot
.0938 .58539 Mdot
.09392 .34575 Mdot
.09404 .4613 Mdot
.09416 .28016 Mdot
.09428 .5345 Mdot
.0944 .32815 Mdot
.09452 .50817 Mdot
.09464 .59049 Mdot
.09476 .53787 Mdot
.09488 .38048 Mdot
.09501 .3815 Mdot
.09513 .36247 Mdot
.09525 .39516 Mdot
.09537 .34522 Mdot
.09549 .42444 Mdot
.09561 .31016 Mdot
.09573 .48563 Mdot
.09585 .26988 Mdot
.09597 .48997 Mdot
.09609 .42288 Mdot
.09621 .29753 Mdot
.09634 .48699 Mdot
.09646 .26957 Mdot
.09658 .48017 Mdot
.0967 .35422 Mdot
.09682 .47295 Mdot
.09694 .27424 Mdot
.09706 .53356 Mdot
.09718 .44635 Mdot
.0973 .26572 Mdot
.09742 .52818 Mdot
.09754 .29695 Mdot
.09766 .05854 Mdot
.09779 .50721 Mdot
.09791 .08786 Mdot
.09803 .51487 Mdot
.09815 .19139 Mdot
.09827 .01656 Mdot
.09839 .54687 Mdot
.09851 .34317 Mdot
.09863 .49981 Mdot
.09875 .26919 Mdot
.09887 .2925 Mdot
.09899 .2117 Mdot
.09912 .48792 Mdot
.09924 .02704 Mdot
.09936 .55661 Mdot
.09948 .33872 Mdot
.0996 .5011 Mdot
.09972 .26935 Mdot
.09984 .2667 Mdot
.09996 .28104 Mdot
.10008 .47763 Mdot
.1002 .04619 Mdot
.10032 .52991 Mdot
.10044 .47542 Mdot
.10057 .2727 Mdot
.10069 .53188 Mdot
.10081 .46957 Mdot
.10093 .25558 Mdot
.10105 .48541 Mdot
.10117 .38228 Mdot
.10129 .38474 Mdot
.10141 .35825 Mdot
.10153 .40222 Mdot
.10165 .33589 Mdot
.10177 .44083 Mdot
.1019 .29483 Mdot
.10202 .51154 Mdot
.10214 .27309 Mdot
.10226 .08476 Mdot
.10238 .4887 Mdot
.1025 .20253 Mdot
.10262 .48968 Mdot
.10274 .03122 Mdot
.10286 .55793 Mdot
.10298 .33861 Mdot
.1031 .49434 Mdot
.10322 .26888 Mdot
.10335 .39239 Mdot
.10347 .08784 Mdot
.10359 .54893 Mdot
.10371 .02711 Mdot
.10383 .54039 Mdot
.10395 .36465 Mdot
.10407 .40688 Mdot
.10419 .32984 Mdot
.10431 .45157 Mdot
.10443 .28648 Mdot
.10455 .52535 Mdot
.10468 .29014 Mdot
.1048 .05021 Mdot
.10492 .5193 Mdot
.10504 .04024 Mdot
.10516 .53272 Mdot
.10528 .43597 Mdot
.1054 .29933 Mdot
.10552 .50232 Mdot
.10564 .26939 Mdot
.10576 .24512 Mdot
.10588 .32709 Mdot
.10601 .46947 Mdot
.10613 .12754 Mdot
.10625 .50426 Mdot
.10637 .15621 Mdot
.10649 .21276 Mdot
.10661 .47942 Mdot
.10673 .0425 Mdot
.10685 .55981 Mdot
.10697 .35873 Mdot
.10709 .42135 Mdot
.10721 .31329 Mdot
.10733 .48042 Mdot
.10746 .2713 Mdot
.10758 .51729 Mdot
.1077 .58615 Mdot
.10782 .3693 Mdot
.10794 .397 Mdot
.10806 .34246 Mdot
.10818 .42934 Mdot
.1083 .30525 Mdot
.10842 .49398 Mdot
.10854 .26876 Mdot
.10866 .40047 Mdot
.10879 .12918 Mdot
.10891 .45069 Mdot
.10903 .45061 Mdot
.10915 .24314 Mdot
.10927 .48336 Mdot
.10939 .02156 Mdot
.10951 .54549 Mdot
.10963 .34329 Mdot
.10975 .46882 Mdot
.10987 .27609 Mdot
.10999 .53637 Mdot
.11011 .38784 Mdot
.11024 .35984 Mdot
.11036 .39477 Mdot
.11048 .34584 Mdot
.1106 .42335 Mdot
.11072 .31129 Mdot
.11084 .4837 Mdot
.11096 .27035 Mdot
.11108 .50211 Mdot
.1112 .55386 Mdot
.11132 .46794 Mdot
.11144 .25557 Mdot
.11157 .49489 Mdot
.11169 .47323 Mdot
.11181 .2567 Mdot
.11193 .4911 Mdot
.11205 .43195 Mdot
.11217 .28538 Mdot
.11229 .50211 Mdot
.11241 .2693 Mdot
.11253 .25035 Mdot
.11265 .31686 Mdot
.11277 .47157 Mdot
.1129 .10468 Mdot
.11302 .51003 Mdot
.11314 .20648 Mdot
.11326 .17665 Mdot
.11338 .1282 Mdot
.1135 .49903 Mdot
.11362 .18236 Mdot
.11374 .02489 Mdot
.11386 .55913 Mdot
.11398 .36924 Mdot
.1141 .42469 Mdot
.11422 .30962 Mdot
.11435 .48704 Mdot
.11447 .26959 Mdot
.11459 .47935 Mdot
.11471 .35099 Mdot
.11483 .48238 Mdot
.11495 .27086 Mdot
.11507 .50749 Mdot
.11519 .58584 Mdot
.11531 .35138 Mdot
.11543 .44252 Mdot
.11555 .29341 Mdot
.11568 .51415 Mdot
.1158 .27495 Mdot
.11592 .06323 Mdot
.11604 .50342 Mdot
.11616 .10908 Mdot
.11628 .50889 Mdot
.1164 .19696 Mdot
.11652 .16756 Mdot
.11664 .0525 Mdot
.11676 .52464 Mdot
.11688 .45819 Mdot
.117 .28179 Mdot
.11713 .53107 Mdot
.11725 .30746 Mdot
.11737 .15658 Mdot
.11749 .43821 Mdot
.11761 .39388 Mdot
.11773 .4345 Mdot
.11785 .36321 Mdot
.11797 .4558 Mdot
.11809 .2602 Mdot
.11821 .48081 Mdot
.11833 .03096 Mdot
.11846 .53777 Mdot
.11858 .38205 Mdot
.1187 .37137 Mdot
.11882 .37995 Mdot
.11894 .36714 Mdot
.11906 .38728 Mdot
.11918 .35627 Mdot
.1193 .40537 Mdot
.11942 .3319 Mdot
.11954 .44786 Mdot
.11966 .28921 Mdot
.11978 .52091 Mdot
.11991 .28228 Mdot
.12003 .05027 Mdot
.12015 .52076 Mdot
.12027 .0376 Mdot
.12039 .53405 Mdot
.12051 .4194 Mdot
.12063 .31665 Mdot
.12075 .47309 Mdot
.12087 .27405 Mdot
.12099 .53379 Mdot
.12111 .44296 Mdot
.12124 .26833 Mdot
.12136 .52349 Mdot
.12148 .28626 Mdot
.1216 .05049 Mdot
.12172 .52148 Mdot
.12184 .03693 Mdot
.12196 .5344 Mdot
.12208 .41539 Mdot
.1222 .32144 Mdot
.12232 .46488 Mdot
.12244 .27807 Mdot
.12257 .53614 Mdot
.12269 .35026 Mdot
.12281 .49828 Mdot
.12293 .26913 Mdot
.12305 .32037 Mdot
.12317 .12162 Mdot
.12329 .50552 Mdot
.12341 .1719 Mdot
.12353 .0384 Mdot
.12365 .53134 Mdot
.12377 .38414 Mdot
.12389 .36762 Mdot
.12402 .38594 Mdot
.12414 .35823 Mdot
.12426 .40205 Mdot
.12438 .3361 Mdot
.1245 .44045 Mdot
.12462 .29515 Mdot
.12474 .51101 Mdot
.12486 .27276 Mdot
.12498 .09065 Mdot
.1251 .48497 Mdot
.12522 .22497 Mdot
.12535 .48614 Mdot
.12547 .02042 Mdot
.12559 .55192 Mdot
.12571 .33864 Mdot
.12583 .50118 Mdot
.12595 .26937 Mdot
.12607 .26491 Mdot
.12619 .28525 Mdot
.12631 .47698 Mdot
.12643 .05131 Mdot
.12655 .5277 Mdot
.12667 .51043 Mdot
.1268 .27168 Mdot
.12692 .10384 Mdot
.12704 .47665 Mdot
.12716 .27013 Mdot
.12728 .47928 Mdot
.1274 .04084 Mdot
.12752 .53241 Mdot
.12764 .43906 Mdot
.12776 .29651 Mdot
.12788 .50704 Mdot
.128 .2708 Mdot
.12813 .15047 Mdot
.12825 .44405 Mdot
.12837 .38188 Mdot
.12849 .44449 Mdot
.12861 .32518 Mdot
.12873 .46882 Mdot
.12885 .14329 Mdot
.12897 .50071 Mdot
.12909 .12173 Mdot
.12921 .48385 Mdot
.12933 .42944 Mdot
.12946 .36193 Mdot
.12958 .45649 Mdot
.1297 .25509 Mdot
.12982 .48158 Mdot
.12994 .02731 Mdot
.13006 .5402 Mdot
.13018 .36498 Mdot
.1303 .40613 Mdot
.13042 .33076 Mdot
.13054 .44995 Mdot
.13066 .28765 Mdot
.13078 .52346 Mdot
.13091 .2864 Mdot
.13103 .05045 Mdot
.13115 .52137 Mdot
.13127 .03704 Mdot
.13139 .53435 Mdot
.13151 .41603 Mdot
.13163 .32066 Mdot
.13175 .46622 Mdot
.13187 .27735 Mdot
.13199 .53646 Mdot
.13211 .36094 Mdot
.13224 .45332 Mdot
.13236 .28529 Mdot
.13248 .5279 Mdot
.1326 .29646 Mdot
.13272 .05714 Mdot
.13284 .50851 Mdot
.13296 .08089 Mdot
.13308 .51703 Mdot
.1332 .08806 Mdot
.13332 .51832 Mdot
.13344 .24144 Mdot
.13356 .48367 Mdot
.13369 .02153 Mdot
.13381 .54555 Mdot
.13393 .34318 Mdot
.13405 .46928 Mdot
.13417 .27586 Mdot
.13429 .53624 Mdot
.13441 .39298 Mdot
.13453 .34633 Mdot
.13465 .41575 Mdot
.13477 .31959 Mdot
.13489 .46936 Mdot
.13502 .27577 Mdot
.13514 .53627 Mdot
.13526 .39179 Mdot
.13538 .34935 Mdot
.1355 .41105 Mdot
.13562 .32504 Mdot
.13574 .45987 Mdot
.13586 .28098 Mdot
.13598 .53338 Mdot
.1361 .3196 Mdot
.13622 .397 Mdot
.13634 .12031 Mdot
.13647 .48899 Mdot
.13659 .42343 Mdot
.13671 .3801 Mdot
.13683 .44637 Mdot
.13695 .31599 Mdot
.13707 .47098 Mdot
.13719 .11995 Mdot
.13731 .50609 Mdot
.13743 .1733 Mdot
.13755 .02945 Mdot
.13767 .53628 Mdot
.1378 .35273 Mdot
.13792 .43735 Mdot
.13804 .29779 Mdot
.13816 .50677 Mdot
.13828 .2707 Mdot
.1384 .15536 Mdot
.13852 .44011 Mdot
.13864 .39004 Mdot
.13876 .43802 Mdot
.13888 .35135 Mdot
.139 .46081 Mdot
.13913 .22109 Mdot
.13925 .4867 Mdot
.13937 .02144 Mdot
.13949 .55329 Mdot
.13961 .33907 Mdot
.13973 .50227 Mdot
.13985 .26958 Mdot
.13997 .24203 Mdot
.14009 .33286 Mdot
.14021 .46817 Mdot
.14033 .14159 Mdot
.14045 .50107 Mdot
.14058 .12534 Mdot
.1407 .46914 Mdot
.14082 .44169 Mdot
.14094 .30786 Mdot
.14106 .47273 Mdot
.14118 .10081 Mdot
.1413 .5111 Mdot
.14142 .21329 Mdot
.14154 .38148 Mdot
.14166 .06682 Mdot
.14178 .55858 Mdot
.14191 .19488 Mdot
.14203 .01702 Mdot
.14215 .55507 Mdot
.14227 .37278 Mdot
.14239 .41345 Mdot
.14251 .32165 Mdot
.14263 .46621 Mdot
.14275 .27736 Mdot
.14287 .53646 Mdot
.14299 .36092 Mdot
.14311 .45338 Mdot
.14323 .28525 Mdot
.14336 .52796 Mdot
.14348 .29663 Mdot
.1436 .05764 Mdot
.14372 .50804 Mdot
.14384 .0834 Mdot
.14396 .51624 Mdot
.14408 .13305 Mdot
.1442 .43792 Mdot
.14432 .45188 Mdot
.14444 .24168 Mdot
.14456 .48358 Mdot
.14469 .02115 Mdot
.14481 .54608 Mdot
.14493 .34205 Mdot
.14505 .47397 Mdot
.14517 .27374 Mdot
.14529 .53249 Mdot
.14541 .46145 Mdot
.14553 .25755 Mdot
.14565 .53179 Mdot
.14577 .47267 Mdot
.14589 .25532 Mdot
.14602 .4448 Mdot
.14614 .491 Mdot
.14626 .26852 Mdot
.14638 .4472 Mdot
.1465 .46232 Mdot
.14662 .27925 Mdot
.14674 .53439 Mdot
.14686 .32714 Mdot
.14698 .49987 Mdot
.1471 .54615 Mdot
.14722 .40563 Mdot
.14734 .31696 Mdot
.14747 .45927 Mdot
.14759 .28134 Mdot
.14771 .53287 Mdot
.14783 .31647 Mdot
.14795 .33576 Mdot
.14807 .06665 Mdot
.14819 .52172 Mdot
.14831 .43385 Mdot
.14843 .13322 Mdot
.14855 .45894 Mdot
.14867 .34098 Mdot
.1488 .46422 Mdot
.14892 .19079 Mdot
.14904 .4916 Mdot
.14916 .04272 Mdot
.14928 .55982 Mdot
.1494 .35977 Mdot
.14952 .41872 Mdot
.14964 .31613 Mdot
.14976 .47553 Mdot
.14988 .27304 Mdot
.15 .53035 Mdot
.15012 .48821 Mdot
.15025 .25887 Mdot
.15037 .08313 Mdot
.15049 .48983 Mdot
.15061 .1952 Mdot
.15073 .49089 Mdot
.15085 .03771 Mdot
.15097 .55923 Mdot
.15109 .34476 Mdot
.15121 .46346 Mdot
.15133 .27891 Mdot
.15145 .53567 Mdot
.15158 .3415 Mdot
.1517 .5287 Mdot
.15182 .30075 Mdot
.15194 .07855 Mdot
.15206 .49247 Mdot
.15218 .17963 Mdot
.1523 .49359 Mdot
.15242 .0562 Mdot
.15254 .55999 Mdot
.15266 .50215 Mdot
.15278 .26877 Mdot
.1529 .25974 Mdot
.15303 .29705 Mdot
.15315 .4751 Mdot
.15327 .06814 Mdot
.15339 .52127 Mdot
.15351 .35847 Mdot
.15363 .02773 Mdot
.15375 .53982 Mdot
.15387 .36596 Mdot
.15399 .40389 Mdot
.15411 .33354 Mdot
.15423 .44504 Mdot
.15436 .29139 Mdot
.15448 .5173 Mdot
.1546 .27783 Mdot
.15472 .05193 Mdot
.15484 .51466 Mdot
.15496 .05283 Mdot
.15508 .52709 Mdot
.1552 .52053 Mdot
.15532 .28048 Mdot
.15544 .0502 Mdot
.15556 .52035 Mdot
.15569 .03812 Mdot
.15581 .53378 Mdot
.15593 .42257 Mdot
.15605 .31305 Mdot
.15617 .47923 Mdot
.15629 .27168 Mdot
.15641 .52138 Mdot
.15653 .56823 Mdot
.15665 .6031 Mdot
.15677 .32922 Mdot
.15689 .46601 Mdot
.15701 .18038 Mdot
.15714 .49342 Mdot
.15726 .05563 Mdot
.15738 .56003 Mdot
.1575 .49189 Mdot
.15762 .2684 Mdot
.15774 .43698 Mdot
.15786 .52668 Mdot
.15798 .54389 Mdot
.1581 .41034 Mdot
.15822 .3082 Mdot
.15834 .47094 Mdot
.15847 .27499 Mdot
.15859 .5356 Mdot
.15871 .41039 Mdot
.15883 .30935 Mdot
.15895 .4697 Mdot
.15907 .27558 Mdot
.15919 .53618 Mdot
.15931 .39506 Mdot
.15943 .34123 Mdot
.15955 .42366 Mdot
.15967 .311 Mdot
.15979 .48415 Mdot
.15992 .27024 Mdot
.16004 .49952 Mdot
.16016 .52856 Mdot
.16028 .32052 Mdot
.1604 .38672 Mdot
.16052 .07098 Mdot
.16064 .55751 Mdot
.16076 .19333 Mdot
.16088 .12655 Mdot
.161 .45941 Mdot
.16112 .44758 Mdot
.16125 .26767 Mdot
.16137 .47967 Mdot
.16149 .03742 Mdot
.16161 .53413 Mdot
.16173 .41765 Mdot
.16185 .31871 Mdot
.16197 .46957 Mdot
.16209 .27566 Mdot
.16221 .53621 Mdot
.16233 .39421 Mdot
.16245 .34329 Mdot
.16258 .42046 Mdot
.1627 .31439 Mdot
.16282 .47835 Mdot
.16294 .27199 Mdot
.16306 .52399 Mdot
.16318 .55038 Mdot
.1633 .46047 Mdot
.16342 .25749 Mdot
.16354 .53249 Mdot
.16366 .4636 Mdot
.16378 .25686 Mdot
.1639 .52556 Mdot
.16403 .53888 Mdot
.16415 .37974 Mdot
.16427 .38241 Mdot
.16439 .36114 Mdot
.16451 .39739 Mdot
.16463 .3422 Mdot
.16475 .42973 Mdot
.16487 .30488 Mdot
.16499 .49461 Mdot
.16511 .26873 Mdot
.16523 .39083 Mdot
.16536 .08059 Mdot
.16548 .5536 Mdot
.1656 .05055 Mdot
.16572 .56013 Mdot
.16584 .41807 Mdot
.16596 .31822 Mdot
.16608 .4704 Mdot
.1662 .27526 Mdot
.16632 .53586 Mdot
.16644 .40418 Mdot
.16656 .32111 Mdot
.16668 .45367 Mdot
.16681 .285 Mdot
.16693 .52761 Mdot
.16705 .29564 Mdot
.16717 .05509 Mdot
.16729 .51059 Mdot
.16741 .07048 Mdot
.16753 .52048 Mdot
.16765 .24587 Mdot
.16777 .33324 Mdot
.16789 .46805 Mdot
.16801 .14306 Mdot
.16814 .50075 Mdot
.16826 .12222 Mdot
.16838 .48201 Mdot
.1685 .43134 Mdot
.16862 .35526 Mdot
.16874 .45936 Mdot
.16886 .23301 Mdot
.16898 .48489 Mdot
.1691 .01988 Mdot
.16922 .54933 Mdot
.16934 .3385 Mdot
.16946 .4945 Mdot
.16959 .26888 Mdot
.16971 .3899 Mdot
.16983 .07646 Mdot
.16995 .55556 Mdot
.17007 .11022 Mdot
.17019 .51768 Mdot
.17031 .35077 Mdot
.17043 .45992 Mdot
.17055 .23091 Mdot
.17067 .4852 Mdot
.17079 .01987 Mdot
.17092 .55007 Mdot
.17104 .33835 Mdot
.17116 .49719 Mdot
.17128 .26891 Mdot
.1714 .34393 Mdot
.17152 .0493 Mdot
.17164 .52849 Mdot
.17176 .49404 Mdot
.17188 .26826 Mdot
.172 .4083 Mdot
.17212 .17143 Mdot
.17225 .04147 Mdot
.17237 .52979 Mdot
.17249 .39788 Mdot
.17261 .3452 Mdot
.17273 .4236 Mdot
.17285 .31104 Mdot
.17297 .48413 Mdot
.17309 .27024 Mdot
.17321 .49963 Mdot
.17333 .5298 Mdot
.17345 .32479 Mdot
.17357 .46149 Mdot
.1737 .3527 Mdot
.17382 .43676 Mdot
.17394 .2983 Mdot
.17406 .5059 Mdot
.17418 .27038 Mdot
.1743 .17176 Mdot
.17442 .42573 Mdot
.17454 .41364 Mdot
.17466 .40948 Mdot
.17478 .41707 Mdot
.1749 .40485 Mdot
.17503 .42323 Mdot
.17515 .39269 Mdot
.17527 .4363 Mdot
.17539 .35719 Mdot
.17551 .45849 Mdot
.17563 .24017 Mdot
.17575 .48381 Mdot
.17587 .02082 Mdot
.17599 .54662 Mdot
.17611 .34107 Mdot
.17623 .47841 Mdot
.17635 .27205 Mdot
.17648 .52332 Mdot
.1766 .55543 Mdot
.17672 .50991 Mdot
.17684 .28417 Mdot
.17696 .09726 Mdot
.17708 .50999 Mdot
.1772 .31491 Mdot
.17732 .47093 Mdot
.17744 .12324 Mdot
.17756 .50529 Mdot
.17768 .16587 Mdot
.17781 .09496 Mdot
.17793 .50855 Mdot
.17805 .13686 Mdot
.17817 .42345 Mdot
.17829 .45632 Mdot
.17841 .19604 Mdot
.17853 .4907 Mdot
.17865 .03737 Mdot
.17877 .55917 Mdot
.17889 .34414 Mdot
.17901 .46583 Mdot
.17914 .27761 Mdot
.17926 .53642 Mdot
.17938 .35929 Mdot
.1795 .4602 Mdot
.17962 .28087 Mdot
.17974 .534 Mdot
.17986 .32405 Mdot
.17998 .46645 Mdot
.1801 .3404 Mdot
.18022 .47941 Mdot
.18034 .27171 Mdot
.18046 .52023 Mdot
.18059 .57451 Mdot
.18071 .55849 Mdot
.18083 .51326 Mdot
.18095 .29084 Mdot
.18107 .07393 Mdot
.18119 .52456 Mdot
.18131 .13346 Mdot
.18143 .50295 Mdot
.18155 .14199 Mdot
.18167 .36383 Mdot
.18179 .46336 Mdot
.18192 .06814 Mdot
.18204 .52126 Mdot
.18216 .3606 Mdot
.18228 .02484 Mdot
.1824 .54203 Mdot
.18252 .35421 Mdot
.18264 .43323 Mdot
.18276 .3015 Mdot
.18288 .50051 Mdot
.183 .26908 Mdot
.18312 .28257 Mdot
.18324 .24031 Mdot
.18337 .4836 Mdot
.18349 .02016 Mdot
.18361 .54805 Mdot
.18373 .33927 Mdot
.18385 .48816 Mdot
.18397 .2695 Mdot
.18409 .46819 Mdot
.18421 .34023 Mdot
.18433 .48025 Mdot
.18445 .27143 Mdot
.18457 .51726 Mdot
.1847 .58622 Mdot
.18482 .37102 Mdot
.18494 .39332 Mdot
.18506 .34743 Mdot
.18518 .42064 Mdot
.1853 .31416 Mdot
.18542 .47878 Mdot
.18554 .27184 Mdot
.18566 .52275 Mdot
.18578 .55945 Mdot
.1859 .55392 Mdot
.18602 .50177 Mdot
.18615 .27143 Mdot
.18627 .09558 Mdot
.18639 .51167 Mdot
.18651 .30282 Mdot
.18663 .47351 Mdot
.18675 .09537 Mdot
.18687 .51263 Mdot
.18699 .2177 Mdot
.18711 .31792 Mdot
.18723 .10847 Mdot
.18735 .50887 Mdot
.18748 .20074 Mdot
.1876 .20592 Mdot
.18772 .16421 Mdot
.18784 .42793 Mdot
.18796 .41126 Mdot
.18808 .41323 Mdot
.1882 .4114 Mdot
.18832 .41418 Mdot
.18844 .40979 Mdot
.18856 .41656 Mdot
.18868 .40575 Mdot
.18881 .42208 Mdot
.18893 .39514 Mdot
.18905 .43399 Mdot
.18917 .36469 Mdot
.18929 .45509 Mdot
.18941 .26514 Mdot
.18953 .48005 Mdot
.18965 .03519 Mdot
.18977 .53532 Mdot
.18989 .4046 Mdot
.19001 .33549 Mdot
.19013 .44048 Mdot
.19026 .29513 Mdot
.19038 .51104 Mdot
.1905 .27278 Mdot
.19062 .09034 Mdot
.19074 .48516 Mdot
.19086 .22382 Mdot
.19098 .48631 Mdot
.1911 .02064 Mdot
.19122 .55229 Mdot
.19134 .33875 Mdot
.19146 .5016 Mdot
.19159 .26944 Mdot
.19171 .25621 Mdot
.19183 .3047 Mdot
.19195 .4738 Mdot
.19207 .08102 Mdot
.19219 .51697 Mdot
.19231 .08733 Mdot
.19243 .51882 Mdot
.19255 .2354 Mdot
.19267 .48459 Mdot
.19279 .02019 Mdot
.19291 .54795 Mdot
.19304 .33936 Mdot
.19316 .48757 Mdot
.19328 .2696 Mdot
.1934 .47348 Mdot
.19352 .33808 Mdot
.19364 .50452 Mdot
.19376 .27015 Mdot
.19388 .19552 Mdot
.194 .40105 Mdot
.19412 .43909 Mdot
.19424 .34449 Mdot
.19437 .46326 Mdot
.19449 .1992 Mdot
.19461 .49019 Mdot
.19473 .03434 Mdot
.19485 .55864 Mdot
.19497 .34021 Mdot
.19509 .48316 Mdot
.19521 .27059 Mdot
.19533 .50412 Mdot
.19545 .56933 Mdot
.19557 .60331 Mdot
.1957 .29255 Mdot
.19582 .47511 Mdot
.19594 .08489 Mdot
.19606 .51576 Mdot
.19618 .15426 Mdot
.1963 .3281 Mdot
.19642 .46731 Mdot
.19654 .04168 Mdot
.19666 .53199 Mdot
.19678 .44438 Mdot
.1969 .29194 Mdot
.19702 .51469 Mdot
.19715 .27538 Mdot
.19727 .0603 Mdot
.19739 .50579 Mdot
.19751 .09509 Mdot
.19763 .51274 Mdot
.19775 .21768 Mdot
.19787 .29881 Mdot
.19799 .17194 Mdot
.19811 .49472 Mdot
.19823 .07114 Mdot
.19835 .5574 Mdot
.19848 .19033 Mdot
.1986 .09251 Mdot
.19872 .54683 Mdot
.19884 .06914 Mdot
.19896 .52097 Mdot
.19908 .29995 Mdot
.1992 .20162 Mdot
.19932 .48954 Mdot
.19944 .03438 Mdot
.19956 .55865 Mdot
.19968 .34024 Mdot
.1998 .48297 Mdot
.19993 .27064 Mdot
.20005 .5051 Mdot
.20017 .57536 Mdot
.20029 .57311 Mdot
.20041 .60205 Mdot
.20053 .1782 Mdot
.20065 .49408 Mdot
.20077 .0551 Mdot
.20089 .56005 Mdot
.20101 .48255 Mdot
.20113 .27023 Mdot
.20126 .51159 Mdot
.20138 .59281 Mdot
.2015 .19479 Mdot
.20162 .01687 Mdot
.20174 .55492 Mdot
.20186 .37243 Mdot
.20198 .41455 Mdot
.2021 .32041 Mdot
.20222 .46837 Mdot
.20234 .27625 Mdot
.20246 .53649 Mdot
.20258 .38116 Mdot
.20271 .37941 Mdot
.20283 .36546 Mdot
.20295 .39021 Mdot
.20307 .35208 Mdot
.20319 .41254 Mdot
.20331 .32323 Mdot
.20343 .46305 Mdot
.20355 .2791 Mdot
.20367 .53539 Mdot
.20379 .33754 Mdot
.20391 .53531 Mdot
.20404 .34809 Mdot
.20416 .50693 Mdot
.20428 .27116 Mdot
.2044 .14692 Mdot
.20452 .44683 Mdot
.20464 .3756 Mdot
.20476 .4487 Mdot
.20488 .30439 Mdot
.205 .47339 Mdot
.20512 .09393 Mdot
.20524 .51305 Mdot
.20537 .21675 Mdot
.20549 .05682 Mdot
.20561 .52497 Mdot
.20573 .05119 Mdot
.20585 .52777 Mdot
.20597 .51079 Mdot
.20609 .27187 Mdot
.20621 .09903 Mdot
.20633 .47969 Mdot
.20645 .25444 Mdot
.20657 .48169 Mdot
.20669 .02726 Mdot
.20682 .54024 Mdot
.20694 .36476 Mdot
.20706 .40662 Mdot
.20718 .33015 Mdot
.2073 .45102 Mdot
.20742 .28687 Mdot
.20754 .52473 Mdot
.20766 .28882 Mdot
.20778 .05023 Mdot
.2079 .52033 Mdot
.20802 .03843 Mdot
.20815 .53362 Mdot
.20827 .4245 Mdot
.20839 .31091 Mdot
.20851 .48285 Mdot
.20863 .27057 Mdot
.20875 .50664 Mdot
.20887 .58274 Mdot
.20899 .34797 Mdot
.20911 .48889 Mdot
.20923 .26943 Mdot
.20935 .46039 Mdot
.20947 .36408 Mdot
.2096 .40779 Mdot
.20972 .32873 Mdot
.20984 .45352 Mdot
.20996 .28511 Mdot
.21008 .52751 Mdot
.2102 .29538 Mdot
.21032 .05454 Mdot
.21044 .5112 Mdot
.21056 .06762 Mdot
.21068 .52148 Mdot
.2108 .3732 Mdot
.21093 .02145 Mdot
.21105 .55349 Mdot
.21117 .33939 Mdot
.21129 .50264 Mdot
.21141 .26967 Mdot
.21153 .23428 Mdot
.21165 .34659 Mdot
.21177 .46466 Mdot
.21189 .1781 Mdot
.21201 .49383 Mdot
.21213 .05885 Mdot
.21225 .55977 Mdot
.21238 .53772 Mdot
.2125 .36292 Mdot
.21262 .44513 Mdot
.21274 .29128 Mdot
.21286 .5182 Mdot
.21298 .27882 Mdot
.2131 .05081 Mdot
.21322 .51681 Mdot
.21334 .0459 Mdot
.21346 .53006 Mdot
.21358 .47427 Mdot
.21371 .27317 Mdot
.21383 .53342 Mdot
.21395 .44856 Mdot
.21407 .26418 Mdot
.21419 .53097 Mdot
.21431 .30662 Mdot
.21443 .14314 Mdot
.21455 .44902 Mdot
.21467 .37062 Mdot
.21479 .45164 Mdot
.21491 .28772 Mdot
.21504 .47643 Mdot
.21516 .06345 Mdot
.21528 .52296 Mdot
.2154 .49709 Mdot
.21552 .47164 Mdot
.21564 .25701 Mdot
.21576 .50455 Mdot
.21588 .5709 Mdot
.216 .60287 Mdot
.21612 .33165 Mdot
.21624 .46523 Mdot
.21636 .18792 Mdot
.21649 .4921 Mdot
.21661 .04599 Mdot
.21673 .56005 Mdot
.21685 .37725 Mdot
.21697 .38044 Mdot
.21709 .36596 Mdot
.21721 .38923 Mdot
.21733 .35347 Mdot
.21745 .41016 Mdot
.21757 .32605 Mdot
.21769 .45812 Mdot
.21782 .28207 Mdot
.21794 .53197 Mdot
.21806 .31162 Mdot
.21818 .23408 Mdot
.2183 .34432 Mdot
.21842 .4653 Mdot
.21854 .17156 Mdot
.21866 .49503 Mdot
.21878 .06872 Mdot
.2189 .55807 Mdot
.21902 .21621 Mdot
.21914 .49097 Mdot
.21927 .48052 Mdot
.21939 .25629 Mdot
.21951 .37714 Mdot
.21963 .03258 Mdot
.21975 .55834 Mdot
.21987 .3389 Mdot
.21999 .49151 Mdot
.22011 .26905 Mdot
.22023 .43195 Mdot
.22035 .26364 Mdot
.22047 .29712 Mdot
.2206 .47508 Mdot
.22072 .06851 Mdot
.22084 .52114 Mdot
.22096 .34309 Mdot
.22108 .0624 Mdot
.2212 .52327 Mdot
.22132 .51932 Mdot
.22144 .58681 Mdot
.22156 .38687 Mdot
.22168 .36309 Mdot
.2218 .39329 Mdot
.22193 .3478 Mdot
.22205 .41995 Mdot
.22217 .31491 Mdot
.22229 .4775 Mdot
.22241 .27229 Mdot
.22253 .52621 Mdot
.22265 .53141 Mdot
.22277 .34397 Mdot
.22289 .52234 Mdot
.22301 .28547 Mdot
.22313 .05035 Mdot
.22325 .52106 Mdot
.22338 .03734 Mdot
.2235 .53419 Mdot
.22362 .41786 Mdot
.22374 .31847 Mdot
.22386 .46999 Mdot
.22398 .27546 Mdot
.2241 .53605 Mdot
.22422 .39913 Mdot
.22434 .3318 Mdot
.22446 .43804 Mdot
.22458 .29723 Mdot
.22471 .50745 Mdot
.22483 .27097 Mdot
.22495 .14319 Mdot
.22507 .4497 Mdot
.22519 .36863 Mdot
.22531 .45273 Mdot
.22543 .28102 Mdot
.22555 .47755 Mdot
.22567 .05351 Mdot
.22579 .52679 Mdot
.22591 .52355 Mdot
.22603 .28497 Mdot
.22616 .05082 Mdot
.22628 .52221 Mdot
.2264 .03637 Mdot
.22652 .5347 Mdot
.22664 .41204 Mdot
.22676 .32561 Mdot
.22688 .45768 Mdot
.227 .28235 Mdot
.22712 .53158 Mdot
.22724 .30975 Mdot
.22736 .19724 Mdot
.22749 .39747 Mdot
.22761 .4418 Mdot
.22773 .33351 Mdot
.22785 .46662 Mdot
.22797 .1663 Mdot
.22809 .49603 Mdot
.22821 .07736 Mdot
.22833 .55511 Mdot
.22845 .09511 Mdot
.22857 .54206 Mdot
.22869 .121 Mdot
.22881 .50591 Mdot
.22894 .16967 Mdot
.22906 .05632 Mdot
.22918 .52302 Mdot
.2293 .48281 Mdot
.22942 .27016 Mdot
.22954 .51032 Mdot
.22966 .59184 Mdot
.22978 .0954 Mdot
.2299 .48328 Mdot
.23002 .2318 Mdot
.23014 .48509 Mdot
.23027 .01987 Mdot
.23039 .54959 Mdot
.23051 .33843 Mdot
.23063 .4955 Mdot
.23075 .26887 Mdot
.23087 .37363 Mdot
.23099 .02655 Mdot
.23111 .55652 Mdot
.23123 .33899 Mdot
.23135 .50192 Mdot
.23147 .26951 Mdot
.2316 .24952 Mdot
.23172 .3185 Mdot
.23184 .47125 Mdot
.23196 .10816 Mdot
.23208 .5091 Mdot
.2322 .19937 Mdot
.23232 .19262 Mdot
.23244 .15889 Mdot
.23256 .151 Mdot
.23268 .49229 Mdot
.2328 .13501 Mdot
.23292 .41655 Mdot
.23305 .45848 Mdot
.23317 .14979 Mdot
.23329 .49931 Mdot
.23341 .10845 Mdot
.23353 .52151 Mdot
.23365 .33137 Mdot
.23377 .46658 Mdot
.23389 .16976 Mdot
.23401 .49537 Mdot
.23413 .0716 Mdot
.23425 .55726 Mdot
.23438 .18414 Mdot
.2345 .03509 Mdot
.23462 .56134 Mdot
.23474 .34435 Mdot
.23486 .4975 Mdot
.23498 .26898 Mdot
.2351 .33736 Mdot
.23522 .06727 Mdot
.23534 .5215 Mdot
.23546 .41343 Mdot
.23558 .17948 Mdot
.2357 .01568 Mdot
.23583 .55394 Mdot
.23595 .37226 Mdot
.23607 .41507 Mdot
.23619 .31983 Mdot
.23631 .46938 Mdot
.23643 .27575 Mdot
.23655 .53626 Mdot
.23667 .39211 Mdot
.23679 .34853 Mdot
.23691 .41233 Mdot
.23703 .32354 Mdot
.23716 .46249 Mdot
.23728 .27942 Mdot
.2374 .53509 Mdot
.23752 .33402 Mdot
.23764 .53394 Mdot
.23776 .42492 Mdot
.23788 .28719 Mdot
.238 .49692 Mdot
.23812 .2687 Mdot
.23824 .35319 Mdot
.23836 .02977 Mdot
.23849 .53845 Mdot
.23861 .37509 Mdot
.23873 .38458 Mdot
.23885 .35983 Mdot
.23897 .39941 Mdot
.23909 .33953 Mdot
.23921 .43441 Mdot
.23933 .30046 Mdot
.23945 .50207 Mdot
.23957 .26934 Mdot
.23969 .25019 Mdot
.23981 .31718 Mdot
.23994 .47151 Mdot
.24006 .10534 Mdot
.24018 .50986 Mdot
.2403 .20518 Mdot
.24042 .21539 Mdot
.24054 .21946 Mdot
.24066 .43262 Mdot
.24078 .30149 Mdot
.2409 .50211 Mdot
.24102 .26936 Mdot
.24114 .24921 Mdot
.24127 .31912 Mdot
.24139 .47112 Mdot
.24151 .1095 Mdot
.24163 .50875 Mdot
.24175 .1965 Mdot
.24187 .16257 Mdot
.24199 .10542 Mdot
.24211 .5051 Mdot
.24223 .21662 Mdot
.24235 .06988 Mdot
.24247 .52486 Mdot
.24259 .11205 Mdot
.24272 .50814 Mdot
.24284 .19013 Mdot
.24296 .09078 Mdot
.24308 .54852 Mdot
.2432 .04577 Mdot
.24332 .53014 Mdot
.24344 .47415 Mdot
.24356 .27322 Mdot
.24368 .53355 Mdot
.2438 .44657 Mdot
.24392 .26557 Mdot
.24405 .52846 Mdot
.24417 .29778 Mdot
.24429 .06145 Mdot
.24441 .50471 Mdot
.24453 .10214 Mdot
.24465 .51076 Mdot
.24477 .21081 Mdot
.24489 .13379 Mdot
.24501 .45351 Mdot
.24513 .36004 Mdot
.24525 .45696 Mdot
.24537 .25226 Mdot
.2455 .482 Mdot
.24562 .0256 Mdot
.24574 .5415 Mdot
.24586 .35781 Mdot
.24598 .42357 Mdot
.2461 .31097 Mdot
.24622 .4844 Mdot
.24634 .27017 Mdot
.24646 .49801 Mdot
.24658 .51188 Mdot
.2467 .27987 Mdot
.24683 .10072 Mdot
.24695 .50634 Mdot
.24707 .3377 Mdot
.24719 .4648 Mdot
.24731 .18688 Mdot
.24743 .49228 Mdot
.24755 .04724 Mdot
.24767 .56011 Mdot
.24779 .38611 Mdot
.24791 .36423 Mdot
.24803 .39143 Mdot
.24816 .35038 Mdot
.24828 .41547 Mdot
.2484 .31988 Mdot
.24852 .4689 Mdot
.24864 .27599 Mdot
.24876 .53639 Mdot
.24888 .38677 Mdot
.249 .36281 Mdot
.24912 .3902 Mdot
.24924 .3522 Mdot
.24936 .41233 Mdot
.24948 .32349 Mdot
.24961 .46261 Mdot
.24973 .27935 Mdot
.24985 .53516 Mdot
.24997 .33478 Mdot
.25009 .53497 Mdot
.25021 .40435 Mdot
.25033 .32079 Mdot
.25045 .45414 Mdot
.25057 .28468 Mdot
.25069 .5281 Mdot
.25081 .29703 Mdot
.25094 .05886 Mdot
.25106 .50692 Mdot
.25118 .08945 Mdot
.2513 .51439 Mdot
.25142 .20289 Mdot
.25154 .07367 Mdot
.25166 .55881 Mdot
.25178 .1866 Mdot
.2519 .05464 Mdot
.25202 .56237 Mdot
.25214 .4045 Mdot
.25226 .33566 Mdot
.25239 .44017 Mdot
.25251 .29538 Mdot
.25263 .51061 Mdot
.25275 .27252 Mdot
.25287 .0955 Mdot
.25299 .48191 Mdot
.25311 .24238 Mdot
.25323 .4835 Mdot
.25335 .02155 Mdot
.25347 .54552 Mdot
.25359 .34324 Mdot
.25372 .46902 Mdot
.25384 .27599 Mdot
.25396 .53632 Mdot
.25408 .39009 Mdot
.2542 .35377 Mdot
.25432 .40417 Mdot
.25444 .33347 Mdot
.25456 .44507 Mdot
.25468 .29137 Mdot
.2548 .51733 Mdot
.25492 .27786 Mdot
.25505 .05188 Mdot
.25517 .51474 Mdot
.25529 .05257 Mdot
.25541 .5272 Mdot
.25553 .51899 Mdot
.25565 .2786 Mdot
.25577 .05045 Mdot
.25589 .51784 Mdot
.25601 .04315 Mdot
.25613 .53132 Mdot
.25625 .45521 Mdot
.25637 .28377 Mdot
.2565 .5281 Mdot
.25662 .29701 Mdot
.25674 .0588 Mdot
.25686 .50698 Mdot
.25698 .08913 Mdot
.2571 .51449 Mdot
.25722 .20092 Mdot
.25734 .05289 Mdot
.25746 .56234 Mdot
.25758 .38776 Mdot
.2577 .36141 Mdot
.25783 .39607 Mdot
.25795 .344 Mdot
.25807 .42658 Mdot
.25819 .30799 Mdot
.25831 .48933 Mdot
.25843 .2692 Mdot
.25855 .45848 Mdot
.25867 .37357 Mdot
.25879 .38738 Mdot
.25891 .35579 Mdot
.25903 .40624 Mdot
.25915 .33082 Mdot
.25928 .44975 Mdot
.2594 .2878 Mdot
.25952 .52323 Mdot
.25964 .28597 Mdot
.25976 .05048 Mdot
.25988 .52145 Mdot
.26 .03695 Mdot
.26012 .53439 Mdot
.26024 .41547 Mdot
.26036 .32133 Mdot
.26048 .46506 Mdot
.26061 .27798 Mdot
.26073 .53619 Mdot
.26085 .3516 Mdot
.26097 .49274 Mdot
.26109 .26909 Mdot
.26121 .41312 Mdot
.26133 .19646 Mdot
.26145 .16285 Mdot
.26157 .1021 Mdot
.26169 .50615 Mdot
.26181 .20796 Mdot
.26193 .14067 Mdot
.26206 .3621 Mdot
.26218 .4633 Mdot
.2623 .06557 Mdot
.26242 .52218 Mdot
.26254 .45018 Mdot
.26266 .46513 Mdot
.26278 .27764 Mdot
.2629 .53589 Mdot
.26302 .34506 Mdot
.26314 .51808 Mdot
.26326 .27939 Mdot
.26339 .05075 Mdot
.26351 .51695 Mdot
.26363 .04553 Mdot
.26375 .53023 Mdot
.26387 .47166 Mdot
.26399 .27432 Mdot
.26411 .53567 Mdot
.26423 .40909 Mdot
.26435 .31169 Mdot
.26447 .46662 Mdot
.26459 .27713 Mdot
.26472 .53651 Mdot
.26484 .36393 Mdot
.26496 .44105 Mdot
.26508 .29455 Mdot
.2652 .51272 Mdot
.26532 .27387 Mdot
.26544 .07346 Mdot
.26556 .49607 Mdot
.26568 .15565 Mdot
.2658 .49816 Mdot
.26592 .09617 Mdot
.26604 .54089 Mdot
.26617 .13932 Mdot
.26629 .50166 Mdot
.26641 .12879 Mdot
.26653 .4528 Mdot
.26665 .44982 Mdot
.26677 .2502 Mdot
.26689 .48231 Mdot
.26701 .02441 Mdot
.26713 .5425 Mdot
.26725 .35315 Mdot
.26737 .43621 Mdot
.2675 .29879 Mdot
.26762 .50509 Mdot
.26774 .27011 Mdot
.26786 .18783 Mdot
.26798 .40962 Mdot
.2681 .43184 Mdot
.26822 .36895 Mdot
.26834 .45294 Mdot
.26846 .27937 Mdot
.26858 .47782 Mdot
.2687 .05126 Mdot
.26882 .52772 Mdot
.26895 .51013 Mdot
.26907 .27152 Mdot
.26919 .10808 Mdot
.26931 .47394 Mdot
.26943 .28326 Mdot
.26955 .47716 Mdot
.26967 .05765 Mdot
.26979 .52515 Mdot
.26991 .53768 Mdot
.27003 .3621 Mdot
.27015 .44851 Mdot
.27028 .28871 Mdot
.2704 .52244 Mdot
.27052 .28464 Mdot
.27064 .05049 Mdot
.27076 .5215 Mdot
.27088 .03685 Mdot
.271 .53444 Mdot
.27112 .41492 Mdot
.27124 .32201 Mdot
.27136 .46389 Mdot
.27148 .27862 Mdot
.27161 .53577 Mdot
.27173 .34309 Mdot
.27185 .52436 Mdot
.27197 .28926 Mdot
.27209 .0502 Mdot
.27221 .51963 Mdot
.27233 .03961 Mdot
.27245 .53303 Mdot
.27257 .43189 Mdot
.27269 .30324 Mdot
.27281 .49577 Mdot
.27293 .26872 Mdot
.27306 .37216 Mdot
.27318 .02443 Mdot
.2733 .55556 Mdot
.27342 .33946 Mdot
.27354 .50259 Mdot
.27366 .26966 Mdot
.27378 .23532 Mdot
.2739 .34481 Mdot
.27402 .46515 Mdot
.27414 .17314 Mdot
.27426 .49474 Mdot
.27439 .06624 Mdot
.27451 .55864 Mdot
.27463 .17052 Mdot
.27475 .18578 Mdot
.27487 .48548 Mdot
.27499 .07377 Mdot
.27511 .55654 Mdot
.27523 .15217 Mdot
.27535 .26136 Mdot
.27547 .47222 Mdot
.27559 .02015 Mdot
.27571 .55139 Mdot
.27584 .3385 Mdot
.27596 .50047 Mdot
.27608 .26925 Mdot
.2762 .27964 Mdot
.27632 .24826 Mdot
.27644 .48244 Mdot
.27656 .02193 Mdot
.27668 .54503 Mdot
.2768 .34443 Mdot
.27692 .46442 Mdot
.27704 .27837 Mdot
.27717 .53605 Mdot
.27729 .34826 Mdot
.27741 .50628 Mdot
.27753 .27091 Mdot
.27765 .15868 Mdot
.27777 .43733 Mdot
.27789 .39529 Mdot
.27801 .43313 Mdot
.27813 .36746 Mdot
.27825 .45371 Mdot
.27837 .27445 Mdot
.27849 .4786 Mdot
.27862 .04505 Mdot
.27874 .53043 Mdot
.27886 .46746 Mdot
.27898 .27638 Mdot
.2791 .53651 Mdot
.27922 .3634 Mdot
.27934 .4432 Mdot
.27946 .2928 Mdot
.27958 .51566 Mdot
.2797 .27623 Mdot
.27982 .05614 Mdot
.27995 .50958 Mdot
.28007 .07475 Mdot
.28019 .51903 Mdot
.28031 .07986 Mdot
.28043 .49282 Mdot
.28055 .17313 Mdot
.28067 .49478 Mdot
.28079 .06575 Mdot
.28091 .55874 Mdot
.28103 .13762 Mdot
.28115 .42031 Mdot
.28128 .45708 Mdot
.2814 .18704 Mdot
.28152 .49224 Mdot
.28164 .04717 Mdot
.28176 .5601 Mdot
.28188 .38558 Mdot
.282 .36516 Mdot
.28212 .38992 Mdot
.28224 .35251 Mdot
.28236 .41181 Mdot
.28248 .3241 Mdot
.2826 .46154 Mdot
.28273 .27998 Mdot
.28285 .53453 Mdot
.28297 .32842 Mdot
.28309 .51016 Mdot
.28321 .59255 Mdot
.28333 .15138 Mdot
.28345 .34772 Mdot
.28357 .46583 Mdot
.28369 .05829 Mdot
.28381 .5249 Mdot
.28393 .53777 Mdot
.28406 .38288 Mdot
.28418 .37412 Mdot
.2843 .37316 Mdot
.28442 .37778 Mdot
.28454 .37043 Mdot
.28466 .38197 Mdot
.28478 .36408 Mdot
.2849 .3923 Mdot
.28502 .34916 Mdot
.28514 .41759 Mdot
.28526 .31749 Mdot
.28538 .47304 Mdot
.28551 .27407 Mdot
.28563 .53384 Mdot
.28575 .44215 Mdot
.28587 .26899 Mdot
.28599 .52235 Mdot
.28611 .28431 Mdot
.28623 .05051 Mdot
.28635 .52155 Mdot
.28647 .0368 Mdot
.28659 .53447 Mdot
.28671 .41458 Mdot
.28684 .32243 Mdot
.28696 .46317 Mdot
.28708 .27903 Mdot
.2872 .53544 Mdot
.28732 .33827 Mdot
.28744 .53463 Mdot
.28756 .33684 Mdot
.28768 .53567 Mdot
.2878 .35992 Mdot
.28792 .45757 Mdot
.28804 .28249 Mdot
.28817 .53197 Mdot
.28829 .31164 Mdot
.28841 .23446 Mdot
.28853 .34366 Mdot
.28865 .46548 Mdot
.28877 .16975 Mdot
.28889 .49537 Mdot
.28901 .07164 Mdot
.28913 .55725 Mdot
.28925 .18359 Mdot
.28937 .03152 Mdot
.28949 .56074 Mdot
.28962 .3523 Mdot
.28974 .47815 Mdot
.28986 .2722 Mdot
.28998 .52366 Mdot
.2901 .55287 Mdot
.29022 .48376 Mdot
.29034 .25707 Mdot
.29046 .15816 Mdot
.29058 .43801 Mdot
.2907 .39398 Mdot
.29082 .43441 Mdot
.29095 .3635 Mdot
.29107 .45566 Mdot
.29119 .26116 Mdot
.29131 .48066 Mdot
.29143 .03173 Mdot
.29155 .5373 Mdot
.29167 .38594 Mdot
.29179 .36448 Mdot
.29191 .39102 Mdot
.29203 .35095 Mdot
.29215 .41448 Mdot
.29227 .32099 Mdot
.2924 .46696 Mdot
.29252 .27697 Mdot
.29264 .53654 Mdot
.29276 .36745 Mdot
.29288 .42717 Mdot
.293 .30708 Mdot
.29312 .49151 Mdot
.29324 .26893 Mdot
.29336 .4341 Mdot
.29348 .42739 Mdot
.2936 .16876 Mdot
.29373 .20349 Mdot
.29385 .48214 Mdot
.29397 .05155 Mdot
.29409 .56017 Mdot
.29421 .42874 Mdot
.29433 .30643 Mdot
.29445 .49039 Mdot
.29457 .26905 Mdot
.29469 .44724 Mdot
.29481 .46181 Mdot
.29493 .27955 Mdot
.29505 .53405 Mdot
.29518 .32436 Mdot
.2953 .47043 Mdot
.29542 .33744 Mdot
.29554 .50102 Mdot
.29566 .26933 Mdot
.29578 .26842 Mdot
.2959 .27693 Mdot
.29602 .47825 Mdot
.29614 .04163 Mdot
.29626 .53202 Mdot
.29638 .44425 Mdot
.29651 .29205 Mdot
.29663 .51451 Mdot
.29675 .27523 Mdot
.29687 .06124 Mdot
.29699 .50501 Mdot
.29711 .09963 Mdot
.29723 .51145 Mdot
.29735 .2147 Mdot
.29747 .46074 Mdot
.29759 .34492 Mdot
.29771 .46127 Mdot
.29784 .28017 Mdot
.29796 .53448 Mdot
.29808 .32795 Mdot
.2982 .50661 Mdot
.29832 .58705 Mdot
.29844 .37674 Mdot
.29856 .38169 Mdot
.29868 .36408 Mdot
.2988 .39232 Mdot
.29892 .34913 Mdot
.29904 .41765 Mdot
.29916 .31743 Mdot
.29929 .47314 Mdot
.29941 .27403 Mdot
.29953 .53373 Mdot
.29965 .44386 Mdot
.29977 .26761 Mdot
.29989 .52476 Mdot
.30001 .28869 Mdot
.30013 .05025 Mdot
.30025 .52048 Mdot
.30037 .0382 Mdot
.30049 .53374 Mdot
.30062 .42307 Mdot
.30074 .31248 Mdot
.30086 .48019 Mdot
.30098 .27137 Mdot
.3011 .51813 Mdot
.30122 .58347 Mdot
.30134 .33954 Mdot
.30146 .4935 Mdot
.30158 .26892 Mdot
.3017 .40483 Mdot
.30182 .15277 Mdot
.30194 .25363 Mdot
.30207 .4732 Mdot
.30219 .02124 Mdot
.30231 .5531 Mdot
.30243 .33904 Mdot
.30255 .50224 Mdot
.30267 .26957 Mdot
.30279 .24282 Mdot
.30291 .33141 Mdot
.30303 .46851 Mdot
.30315 .13798 Mdot
.30327 .50187 Mdot
.3034 .13312 Mdot
.30352 .42857 Mdot
.30364 .45648 Mdot
.30376 .17837 Mdot
.30388 .49377 Mdot
.304 .0586 Mdot
.30412 .5598 Mdot
.30424 .53672 Mdot
.30436 .34056 Mdot
.30448 .53088 Mdot
.3046 .30935 Mdot
.30473 .19061 Mdot
.30485 .40515 Mdot
.30497 .43587 Mdot
.30509 .3561 Mdot
.30521 .45895 Mdot
.30533 .23644 Mdot
.30545 .48437 Mdot
.30557 .02015 Mdot
.30569 .54806 Mdot
.30581 .33926 Mdot
.30593 .48821 Mdot
.30605 .26949 Mdot
.30618 .4677 Mdot
.3063 .34103 Mdot
.30642 .47659 Mdot
.30654 .2727 Mdot
.30666 .5279 Mdot
.30678 .51497 Mdot
.3069 .29301 Mdot
.30702 .065 Mdot
.30714 .52633 Mdot
.30726 .07755 Mdot
.30738 .51812 Mdot
.30751 .05018 Mdot
.30763 .52251 Mdot
.30775 .03176 Mdot
.30787 .53731 Mdot
.30799 .38657 Mdot
.30811 .3634 Mdot
.30823 .3928 Mdot
.30835 .34847 Mdot
.30847 .41878 Mdot
.30859 .31618 Mdot
.30871 .4753 Mdot
.30883 .27313 Mdot
.30896 .53074 Mdot
.30908 .48354 Mdot
.3092 .25686 Mdot
.30932 .18305 Mdot
.30944 .41496 Mdot
.30956 .42653 Mdot
.30968 .38334 Mdot
.3098 .44397 Mdot
.30992 .32731 Mdot
.31004 .46828 Mdot
.31016 .14902 Mdot
.31029 .49949 Mdot
.31041 .10982 Mdot
.31053 .51858 Mdot
.31065 .34662 Mdot
.31077 .46154 Mdot
.31089 .21727 Mdot
.31101 .48729 Mdot
.31113 .02275 Mdot
.31125 .55441 Mdot
.31137 .33928 Mdot
.31149 .50249 Mdot
.31161 .26963 Mdot
.31174 .23743 Mdot
.31186 .34115 Mdot
.31198 .46613 Mdot
.3121 .16315 Mdot
.31222 .49664 Mdot
.31234 .08287 Mdot
.31246 .55227 Mdot
.31258 .0289 Mdot
.3127 .5572 Mdot
.31282 .33845 Mdot
.31294 .49851 Mdot
.31307 .26901 Mdot
.31319 .31905 Mdot
.31331 .12604 Mdot
.31343 .50445 Mdot
.31355 .16207 Mdot
.31367 .13988 Mdot
.31379 .49524 Mdot
.31391 .15805 Mdot
.31403 .1899 Mdot
.31415 .48369 Mdot
.31427 .06806 Mdot
.3144 .55824 Mdot
.31452 .21749 Mdot
.31464 .20769 Mdot
.31476 .37844 Mdot
.31488 .45308 Mdot
.315 .27339 Mdot
.31512 .47877 Mdot
.31524 .04377 Mdot
.31536 .53101 Mdot
.31548 .45868 Mdot
.3156 .28148 Mdot
.31572 .53151 Mdot
.31585 .30941 Mdot
.31597 .19076 Mdot
.31609 .40499 Mdot
.31621 .43601 Mdot
.31633 .35563 Mdot
.31645 .45914 Mdot
.31657 .23491 Mdot
.31669 .4846 Mdot
.31681 .01999 Mdot
.31693 .54863 Mdot
.31705 .33883 Mdot
.31718 .49132 Mdot
.3173 .26907 Mdot
.31742 .43429 Mdot
.31754 .43886 Mdot
.31766 .49562 Mdot
.31778 .45581 Mdot
.3179 .26367 Mdot
.31802 .53457 Mdot
.31814 .32781 Mdot
.31826 .50544 Mdot
.31838 .58318 Mdot
.3185 .34355 Mdot
.31863 .4976 Mdot
.31875 .26898 Mdot
.31887 .33569 Mdot
.31899 .07221 Mdot
.31911 .51977 Mdot
.31923 .20118 Mdot
.31935 .39884 Mdot
.31947 .44055 Mdot
.31959 .33877 Mdot
.31971 .46509 Mdot
.31983 .18174 Mdot
.31996 .49318 Mdot
.32008 .05379 Mdot
.3202 .56011 Mdot
.32032 .46068 Mdot
.32044 .28022 Mdot
.32056 .53319 Mdot
.32068 .31834 Mdot
.3208 .37319 Mdot
.32092 .02891 Mdot
.32104 .55735 Mdot
.32116 .33853 Mdot
.32129 .49979 Mdot
.32141 .26915 Mdot
.32153 .29357 Mdot
.32165 .20847 Mdot
.32177 .48843 Mdot
.32189 .02913 Mdot
.32201 .55733 Mdot
.32213 .33846 Mdot
.32225 .49868 Mdot
.32237 .26903 Mdot
.32249 .3157 Mdot
.32261 .13726 Mdot
.32274 .50184 Mdot
.32286 .1374 Mdot
.32298 .4001 Mdot
.3231 .46047 Mdot
.32322 .11755 Mdot
.32334 .50668 Mdot
.32346 .17884 Mdot
.32358 .01491 Mdot
.3237 .5524 Mdot
.32382 .36597 Mdot
.32394 .43524 Mdot
.32407 .29958 Mdot
.32419 .5041 Mdot
.32431 .26983 Mdot
.32443 .20782 Mdot
.32455 .386 Mdot
.32467 .44898 Mdot
.32479 .29846 Mdot
.32491 .47452 Mdot
.32503 .08209 Mdot
.32515 .51663 Mdot
.32527 .10664 Mdot
.32539 .49946 Mdot
.32552 .37039 Mdot
.32564 .45054 Mdot
.32576 .29514 Mdot
.32588 .47513 Mdot
.326 .076 Mdot
.32612 .51859 Mdot
.32624 .05962 Mdot
.32636 .50698 Mdot
.32648 .08432 Mdot
.3266 .51595 Mdot
.32672 .14808 Mdot
.32685 .3682 Mdot
.32697 .46421 Mdot
.32709 .08206 Mdot
.32721 .51663 Mdot
.32733 .10501 Mdot
.32745 .5017 Mdot
.32757 .36145 Mdot
.32769 .45538 Mdot
.32781 .26466 Mdot
.32793 .48013 Mdot
.32805 .03475 Mdot
.32817 .53556 Mdot
.3283 .40215 Mdot
.32842 .33895 Mdot
.32854 .43444 Mdot
.32866 .30044 Mdot
.32878 .50211 Mdot
.3289 .26935 Mdot
.32902 .24936 Mdot
.32914 .31883 Mdot
.32926 .47118 Mdot
.32938 .10887 Mdot
.3295 .50892 Mdot
.32963 .19786 Mdot
.32975 .17714 Mdot
.32987 .01649 Mdot
.32999 .55494 Mdot
.33011 .37602 Mdot
.33023 .40339 Mdot
.33035 .33355 Mdot
.33047 .44525 Mdot
.33059 .29123 Mdot
.33071 .51757 Mdot
.33083 .27812 Mdot
.33096 .05151 Mdot
.33108 .51536 Mdot
.3312 .05041 Mdot
.33132 .5281 Mdot
.33144 .50545 Mdot
.33156 .2696 Mdot
.33168 .19064 Mdot
.3318 .40657 Mdot
.33192 .43458 Mdot
.33204 .36044 Mdot
.33216 .45709 Mdot
.33228 .25083 Mdot
.33241 .48222 Mdot
.33253 .02482 Mdot
.33265 .54214 Mdot
.33277 .35473 Mdot
.33289 .43178 Mdot
.33301 .30286 Mdot
.33313 .49821 Mdot
.33325 .26882 Mdot
.33337 .32814 Mdot
.33349 .09593 Mdot
.33361 .51235 Mdot
.33374 .21763 Mdot
.33386 .26067 Mdot
.33398 .28046 Mdot
.3341 .47772 Mdot
.33422 .04525 Mdot
.33434 .53033 Mdot
.33446 .46887 Mdot
.33458 .27566 Mdot
.3347 .53654 Mdot
.33482 .3768 Mdot
.33494 .39345 Mdot
.33506 .34604 Mdot
.33519 .42331 Mdot
.33531 .31134 Mdot
.33543 .48362 Mdot
.33555 .27037 Mdot
.33567 .50254 Mdot
.33579 .55753 Mdot
.33591 .50585 Mdot
.33603 .2772 Mdot
.33615 .10591 Mdot
.33627 .49988 Mdot
.33639 .36785 Mdot
.33652 .45201 Mdot
.33664 .28645 Mdot
.33676 .47664 Mdot
.33688 .06148 Mdot
.337 .52369 Mdot
.33712 .52336 Mdot
.33724 .56887 Mdot
.33736 .60286 Mdot
.33748 .33895 Mdot
.3376 .46264 Mdot
.33772 .21175 Mdot
.33785 .48816 Mdot
.33797 .02535 Mdot
.33809 .55589 Mdot
.33821 .33904 Mdot
.33833 .50205 Mdot
.33845 .26954 Mdot
.33857 .24669 Mdot
.33869 .32407 Mdot
.33881 .47011 Mdot
.33893 .12052 Mdot
.33905 .50595 Mdot
.33917 .17202 Mdot
.3393 .03756 Mdot
.33942 .53177 Mdot
.33954 .38062 Mdot
.33966 .37397 Mdot
.33978 .37586 Mdot
.3399 .37342 Mdot
.34002 .37722 Mdot
.34014 .37129 Mdot
.34026 .38059 Mdot
.34038 .36615 Mdot
.3405 .38888 Mdot
.34063 .35397 Mdot
.34075 .40931 Mdot
.34087 .32707 Mdot
.34099 .45633 Mdot
.34111 .28322 Mdot
.34123 .53036 Mdot
.34135 .30458 Mdot
.34147 .11505 Mdot
.34159 .46895 Mdot
.34171 .30586 Mdot
.34183 .47304 Mdot
.34195 .09853 Mdot
.34208 .51173 Mdot
.3422 .21623 Mdot
.34232 .49624 Mdot
.34244 .5375 Mdot
.34256 .3564 Mdot
.34268 .47199 Mdot
.3428 .2747 Mdot
.34292 .53441 Mdot
.34304 .43306 Mdot
.34316 .27759 Mdot
.34328 .50913 Mdot
.34341 .27166 Mdot
.34353 .11652 Mdot
.34365 .46845 Mdot
.34377 .30742 Mdot
.34389 .47273 Mdot
.34401 .10191 Mdot
.34413 .51079 Mdot
.34425 .21153 Mdot
.34437 .21003 Mdot
.34449 .375 Mdot
.34461 .45467 Mdot
.34473 .26256 Mdot
.34486 .48045 Mdot
.34498 .03287 Mdot
.3451 .53663 Mdot
.34522 .39189 Mdot
.34534 .35454 Mdot
.34546 .40759 Mdot
.34558 .32916 Mdot
.3457 .45266 Mdot
.34582 .28571 Mdot
.34594 .52657 Mdot
.34606 .29295 Mdot
.34619 .05124 Mdot
.34631 .51587 Mdot
.34643 .04924 Mdot
.34655 .5286 Mdot
.34667 .49752 Mdot
.34679 .26825 Mdot
.34691 .35147 Mdot
.34703 .03279 Mdot
.34715 .53661 Mdot
.34727 .38998 Mdot
.34739 .35765 Mdot
.34752 .40234 Mdot
.34764 .33574 Mdot
.34776 .44108 Mdot
.34788 .29462 Mdot
.348 .5119 Mdot
.34812 .27332 Mdot
.34824 .08105 Mdot
.34836 .49107 Mdot
.34848 .18772 Mdot
.3486 .49217 Mdot
.34872 .04581 Mdot
.34884 .56004 Mdot
.34897 .37607 Mdot
.34909 .38274 Mdot
.34921 .36254 Mdot
.34933 .39488 Mdot
.34945 .3456 Mdot
.34957 .42378 Mdot
.34969 .31084 Mdot
.34981 .48447 Mdot
.34993 .27016 Mdot
.35005 .49758 Mdot
.35017 .50708 Mdot
.3503 .2727 Mdot
.35042 .09337 Mdot
.35054 .51364 Mdot
.35066 .28664 Mdot
.35078 .47653 Mdot
.3509 .06497 Mdot
.35102 .5224 Mdot
.35114 .46485 Mdot
.35126 .35818 Mdot
.35138 .42208 Mdot
.3515 .31252 Mdot
.35162 .48174 Mdot
.35175 .27089 Mdot
.35187 .51191 Mdot
.35199 .59291 Mdot
.35211 .20575 Mdot
.35223 .11033 Mdot
.35235 .51786 Mdot
.35247 .35621 Mdot
.35259 .45756 Mdot
.35271 .2494 Mdot
.35283 .48243 Mdot
.35295 .0241 Mdot
.35308 .54277 Mdot
.3532 .35199 Mdot
.35332 .43957 Mdot
.35344 .29587 Mdot
.35356 .51001 Mdot
.35368 .27219 Mdot
.3538 .10322 Mdot
.35392 .47704 Mdot
.35404 .2682 Mdot
.35416 .47958 Mdot
.35428 .03879 Mdot
.35441 .53342 Mdot
.35453 .42602 Mdot
.35465 .30928 Mdot
.35477 .48562 Mdot
.35489 .26988 Mdot
.35501 .49007 Mdot
.35513 .42383 Mdot
.35525 .29615 Mdot
.35537 .48871 Mdot
.35549 .26926 Mdot
.35561 .46511 Mdot
.35573 .34682 Mdot
.35586 .45481 Mdot
.35598 .28425 Mdot
.3561 .52905 Mdot
.35622 .29993 Mdot
.35634 .07238 Mdot
.35646 .49662 Mdot
.35658 .15293 Mdot
.3567 .49871 Mdot
.35682 .10145 Mdot
.35694 .5339 Mdot
.35706 .2317 Mdot
.35719 .48516 Mdot
.35731 .01989 Mdot
.35743 .54921 Mdot
.35755 .33854 Mdot
.35767 .49398 Mdot
.35779 .26889 Mdot
.35791 .39782 Mdot
.35803 .1151 Mdot
.35815 .50543 Mdot
.35827 .39325 Mdot
.35839 .43176 Mdot
.35851 .37203 Mdot
.35864 .45123 Mdot
.35876 .28988 Mdot
.35888 .47606 Mdot
.359 .06693 Mdot
.35912 .5217 Mdot
.35924 .40494 Mdot
.35936 .13337 Mdot
.35948 .42691 Mdot
.3596 .4568 Mdot
.35972 .17409 Mdot
.35984 .49455 Mdot
.35997 .06493 Mdot
.36009 .5589 Mdot
.36021 .0735 Mdot
.36033 .52543 Mdot
.36045 .12401 Mdot
.36057 .50516 Mdot
.36069 .16318 Mdot
.36081 .12644 Mdot
.36093 .4989 Mdot
.36105 .18667 Mdot
.36117 .05564 Mdot
.36129 .56232 Mdot
.36142 .41731 Mdot
.36154 .31913 Mdot
.36166 .46884 Mdot
.36178 .27602 Mdot
.3619 .53641 Mdot
.36202 .38602 Mdot
.36214 .36494 Mdot
.36226 .38695 Mdot
.36238 .35685 Mdot
.3625 .40438 Mdot
.36262 .33315 Mdot
.36275 .44566 Mdot
.36287 .29091 Mdot
.36299 .5181 Mdot
.36311 .2787 Mdot
.36323 .0509 Mdot
.36335 .51659 Mdot
.36347 .04656 Mdot
.36359 .52977 Mdot
.36371 .47889 Mdot
.36383 .27139 Mdot
.36395 .52465 Mdot
.36408 .54511 Mdot
.3642 .41867 Mdot
.36432 .29475 Mdot
.36444 .48752 Mdot
.36456 .26946 Mdot
.36468 .47586 Mdot
.3648 .34123 Mdot
.36492 .50375 Mdot
.36504 .26996 Mdot
.36516 .21082 Mdot
.36528 .38202 Mdot
.3654 .45112 Mdot
.36553 .28597 Mdot
.36565 .47673 Mdot
.36577 .06069 Mdot
.36589 .52398 Mdot
.36601 .52966 Mdot
.36613 .51584 Mdot
.36625 .29502 Mdot
.36637 .05784 Mdot
.36649 .52607 Mdot
.36661 .04862 Mdot
.36673 .52887 Mdot
.36686 .49353 Mdot
.36698 .26828 Mdot
.3671 .41551 Mdot
.36722 .20744 Mdot
.36734 .11945 Mdot
.36746 .47539 Mdot
.36758 .42412 Mdot
.3677 .38052 Mdot
.36782 .44607 Mdot
.36794 .31748 Mdot
.36806 .47065 Mdot
.36818 .12358 Mdot
.36831 .50521 Mdot
.36843 .1651 Mdot
.36855 .10368 Mdot
.36867 .50572 Mdot
.36879 .2135 Mdot
.36891 .21916 Mdot
.36903 .43526 Mdot
.36915 .29918 Mdot
.36927 .50605 Mdot
.36939 .27044 Mdot
.36951 .16883 Mdot
.36964 .42843 Mdot
.36976 .40984 Mdot
.36988 .41542 Mdot
.37 .40779 Mdot
.37012 .41937 Mdot
.37024 .40058 Mdot
.37036 .4283 Mdot
.37048 .38073 Mdot
.3706 .4458 Mdot
.37072 .31886 Mdot
.37084 .47034 Mdot
.37097 .12699 Mdot
.37109 .50439 Mdot
.37121 .15744 Mdot
.37133 .19759 Mdot
.37145 .48219 Mdot
.37157 .05826 Mdot
.37169 .55984 Mdot
.37181 .53386 Mdot
.37193 .31643 Mdot
.37205 .33384 Mdot
.37217 .07235 Mdot
.37229 .51973 Mdot
.37242 .19551 Mdot
.37254 .40526 Mdot
.37266 .43547 Mdot
.37278 .35754 Mdot
.3729 .45835 Mdot
.37302 .2412 Mdot
.37314 .48366 Mdot
.37326 .02107 Mdot
.37338 .54621 Mdot
.3735 .34179 Mdot
.37362 .4751 Mdot
.37375 .27329 Mdot
.37387 .53078 Mdot
.37399 .48305 Mdot
.37411 .2567 Mdot
.37423 .19609 Mdot
.37435 .40075 Mdot
.37447 .4393 Mdot
.37459 .34368 Mdot
.37471 .46353 Mdot
.37483 .19669 Mdot
.37495 .4906 Mdot
.37507 .03665 Mdot
.3752 .55906 Mdot
.37532 .34294 Mdot
.37544 .47058 Mdot
.37556 .27524 Mdot
.37568 .53567 Mdot
.3758 .4089 Mdot
.37592 .31204 Mdot
.37604 .46616 Mdot
.37616 .27737 Mdot
.37628 .53644 Mdot
.3764 .35994 Mdot
.37653 .45747 Mdot
.37665 .28256 Mdot
.37677 .53188 Mdot
.37689 .31119 Mdot
.37701 .22537 Mdot
.37713 .35874 Mdot
.37725 .46093 Mdot
.37737 .21321 Mdot
.37749 .48793 Mdot
.37761 .0246 Mdot
.37773 .55552 Mdot
.37785 .33916 Mdot
.37798 .50228 Mdot
.3781 .26959 Mdot
.37822 .24186 Mdot
.37834 .33317 Mdot
.37846 .4681 Mdot
.37858 .14238 Mdot
.3787 .5009 Mdot
.37882 .12366 Mdot
.37894 .47628 Mdot
.37906 .43652 Mdot
.37918 .33419 Mdot
.37931 .46647 Mdot
.37943 .16767 Mdot
.37955 .49577 Mdot
.37967 .07506 Mdot
.37979 .55606 Mdot
.37991 .13182 Mdot
.38003 .43638 Mdot
.38015 .4548 Mdot
.38027 .1995 Mdot
.38039 .49013 Mdot
.38051 .03419 Mdot
.38064 .55861 Mdot
.38076 .34008 Mdot
.38088 .48386 Mdot
.381 .27041 Mdot
.38112 .50019 Mdot
.38124 .53559 Mdot
.38136 .34764 Mdot
.38148 .50907 Mdot
.3816 .27215 Mdot
.38172 .11204 Mdot
.38184 .47138 Mdot
.38196 .29494 Mdot
.38209 .47513 Mdot
.38221 .07689 Mdot
.38233 .5183 Mdot
.38245 .05134 Mdot
.38257 .51582 Mdot
.38269 .04505 Mdot
.38281 .53045 Mdot
.38293 .46828 Mdot
.38305 .27596 Mdot
.38317 .53656 Mdot
.38329 .371 Mdot
.38342 .4138 Mdot
.38354 .32112 Mdot
.38366 .46723 Mdot
.38378 .27683 Mdot
.3839 .53655 Mdot
.38402 .36998 Mdot
.38414 .41758 Mdot
.38426 .31696 Mdot
.38438 .47448 Mdot
.3845 .27346 Mdot
.38462 .53203 Mdot
.38474 .46751 Mdot
.38487 .25591 Mdot
.38499 .50399 Mdot
.38511 .56705 Mdot
.38523 .59955 Mdot
.38535 .0249 Mdot
.38547 .54222 Mdot
.38559 .35602 Mdot
.38571 .42828 Mdot
.38583 .30622 Mdot
.38595 .49251 Mdot
.38607 .26884 Mdot
.3862 .4212 Mdot
.38632 .21262 Mdot
.38644 .20732 Mdot
.38656 .34678 Mdot
.38668 .02962 Mdot
.3868 .53855 Mdot
.38692 .37432 Mdot
.38704 .38611 Mdot
.38716 .3576 Mdot
.38728 .40316 Mdot
.3874 .33468 Mdot
.38753 .44296 Mdot
.38765 .29307 Mdot
.38777 .5145 Mdot
.38789 .27522 Mdot
.38801 .0613 Mdot
.38813 .50496 Mdot
.38825 .0999 Mdot
.38837 .51138 Mdot
.38849 .21433 Mdot
.38861 .44481 Mdot
.38873 .43301 Mdot
.38885 .30214 Mdot
.38898 .49766 Mdot
.3891 .26878 Mdot
.38922 .33863 Mdot
.38934 .0636 Mdot
.38946 .52282 Mdot
.38958 .50376 Mdot
.3897 .54696 Mdot
.38982 .41117 Mdot
.38994 .30679 Mdot
.39006 .47276 Mdot
.39018 .27417 Mdot
.39031 .53419 Mdot
.39043 .43669 Mdot
.39055 .2739 Mdot
.39067 .51443 Mdot
.39079 .27506 Mdot
.39091 .06193 Mdot
.39103 .50445 Mdot
.39115 .10292 Mdot
.39127 .51054 Mdot
.39139 .20942 Mdot
.39151 .05189 Mdot
.39163 .5145 Mdot
.39176 .05891 Mdot
.39188 .52468 Mdot
.392 .53673 Mdot
.39212 .41754 Mdot
.39224 .29755 Mdot
.39236 .48448 Mdot
.39248 .27012 Mdot
.3926 .49785 Mdot
.39272 .51009 Mdot
.39284 .27699 Mdot
.39296 .10093 Mdot
.39309 .50612 Mdot
.39321 .33895 Mdot
.39333 .46439 Mdot
.39345 .19074 Mdot
.39357 .49161 Mdot
.39369 .04277 Mdot
.39381 .55982 Mdot
.39393 .35996 Mdot
.39405 .41824 Mdot
.39417 .31665 Mdot
.39429 .47462 Mdot
.39441 .2734 Mdot
.39454 .53182 Mdot
.39466 .47023 Mdot
.39478 .2555 Mdot
.3949 .47813 Mdot
.39502 .34609 Mdot
.39514 .49492 Mdot
.39526 .26892 Mdot
.39538 .38211 Mdot
.3955 .04669 Mdot
.39562 .56015 Mdot
.39574 .3808 Mdot
.39587 .37373 Mdot
.39599 .37624 Mdot
.39611 .37283 Mdot
.39623 .37815 Mdot
.39635 .36987 Mdot
.39647 .38286 Mdot
.39659 .36274 Mdot
.39671 .3945 Mdot
.39683 .34612 Mdot
.39695 .42288 Mdot
.39707 .31179 Mdot
.3972 .48285 Mdot
.39732 .27058 Mdot
.39744 .50663 Mdot
.39756 .58272 Mdot
.39768 .34815 Mdot
.3978 .48846 Mdot
.39792 .2695 Mdot
.39804 .46453 Mdot
.39816 .34846 Mdot
.39828 .4495 Mdot
.3984 .28799 Mdot
.39852 .52314 Mdot
.39865 .28583 Mdot
.39877 .05049 Mdot
.39889 .52147 Mdot
.39901 .03692 Mdot
.39913 .53441 Mdot
.39925 .41533 Mdot
.39937 .32151 Mdot
.39949 .46476 Mdot
.39961 .27814 Mdot
.39973 .5361 Mdot
.39985 .3493 Mdot
.39998 .50216 Mdot
.4001 .2697 Mdot
.40022 .2414 Mdot
.40034 .33403 Mdot
.40046 .4679 Mdot
.40058 .14454 Mdot
.4007 .50044 Mdot
.40082 .11911 Mdot
.40094 .49315 Mdot
.40106 .41755 Mdot
.40118 .39443 Mdot
.4013 .43489 Mdot
.40143 .36179 Mdot
.40155 .45647 Mdot
.40167 .25542 Mdot
.40179 .48153 Mdot
.40191 .02752 Mdot
.40203 .54005 Mdot
.40215 .36592 Mdot
.40227 .40398 Mdot
.40239 .33342 Mdot
.40251 .44525 Mdot
.40263 .29123 Mdot
.40276 .51757 Mdot
.40288 .27812 Mdot
.403 .05152 Mdot
.40312 .51535 Mdot
.40324 .05044 Mdot
.40336 .52809 Mdot
.40348 .50561 Mdot
.4036 .26964 Mdot
.40372 .18749 Mdot
.40384 .41 Mdot
.40396 .43149 Mdot
.40408 .36999 Mdot
.40421 .45238 Mdot
.40433 .28285 Mdot
.40445 .47725 Mdot
.40457 .0561 Mdot
.40469 .52576 Mdot
.40481 .53471 Mdot
.40493 .32185 Mdot
.40505 .43464 Mdot
.40517 .51633 Mdot
.40529 .59237 Mdot
.40541 .13539 Mdot
.40554 .42926 Mdot
.40566 .45475 Mdot
.40578 .21352 Mdot
.4059 .48787 Mdot
.40602 .02449 Mdot
.40614 .55547 Mdot
.40626 .33918 Mdot
.40638 .50231 Mdot
.4065 .26959 Mdot
.40662 .24136 Mdot
.40674 .3341 Mdot
.40687 .46788 Mdot
.40699 .14471 Mdot
.40711 .5004 Mdot
.40723 .11874 Mdot
.40735 .49437 Mdot
.40747 .41564 Mdot
.40759 .39848 Mdot
.40771 .43083 Mdot
.40783 .37395 Mdot
.40795 .45012 Mdot
.40807 .29628 Mdot
.40819 .47492 Mdot
.40832 .07806 Mdot
.40844 .51792 Mdot
.40856 .05105 Mdot
.40868 .52387 Mdot
.4088 .03144 Mdot
.40892 .5375 Mdot
.40904 .38495 Mdot
.40916 .36621 Mdot
.40928 .38821 Mdot
.4094 .35494 Mdot
.40952 .40764 Mdot
.40965 .3291 Mdot
.40977 .45278 Mdot
.40989 .28563 Mdot
.41001 .5267 Mdot
.41013 .29327 Mdot
.41025 .05151 Mdot
.41037 .51535 Mdot
.41049 .05094 Mdot
.41061 .52787 Mdot
.41073 .50895 Mdot
.41085 .27094 Mdot
.41097 .12599 Mdot
.4111 .46209 Mdot
.41122 .33161 Mdot
.41134 .46701 Mdot
.41146 .16313 Mdot
.41158 .49664 Mdot
.4117 .08289 Mdot
.41182 .55226 Mdot
.41194 .02879 Mdot
.41206 .55717 Mdot
.41218 .33845 Mdot
.4123 .49867 Mdot
.41243 .26902 Mdot
.41255 .31589 Mdot
.41267 .13664 Mdot
.41279 .50198 Mdot
.41291 .13874 Mdot
.41303 .39016 Mdot
.41315 .46139 Mdot
.41327 .1014 Mdot
.41339 .51092 Mdot
.41351 .21248 Mdot
.41363 .31042 Mdot
.41376 .13319 Mdot
.41388 .50276 Mdot
.414 .14639 Mdot
.41412 .32314 Mdot
.41424 .46619 Mdot
.41436 .03598 Mdot
.41448 .53488 Mdot
.4146 .40898 Mdot
.41472 .32957 Mdot
.41484 .45079 Mdot
.41496 .28704 Mdot
.41508 .52445 Mdot
.41521 .28826 Mdot
.41533 .05028 Mdot
.41545 .52066 Mdot
.41557 .03794 Mdot
.41569 .53388 Mdot
.41581 .42148 Mdot
.41593 .31427 Mdot
.41605 .47715 Mdot
.41617 .27242 Mdot
.41629 .52705 Mdot
.41641 .52349 Mdot
.41654 .3155 Mdot
.41666 .27068 Mdot
.41678 .26687 Mdot
.4169 .47974 Mdot
.41702 .03228 Mdot
.41714 .53697 Mdot
.41726 .38879 Mdot
.41738 .35962 Mdot
.4175 .39905 Mdot
.41762 .34002 Mdot
.41774 .43355 Mdot
.41786 .30126 Mdot
.41799 .50074 Mdot
.41811 .26911 Mdot
.41823 .27793 Mdot
.41835 .25285 Mdot
.41847 .48177 Mdot
.41859 .02368 Mdot
.41871 .54316 Mdot
.41883 .35042 Mdot
.41895 .44426 Mdot
.41907 .292 Mdot
.41919 .5165 Mdot
.41932 .27703 Mdot
.41944 .05357 Mdot
.41956 .5124 Mdot
.41968 .06168 Mdot
.4198 .52363 Mdot
.41992 .51985 Mdot
.42004 .58517 Mdot
.42016 .35188 Mdot
.42028 .44102 Mdot
.4204 .29465 Mdot
.42052 .51207 Mdot
.42064 .27343 Mdot
.42077 .07939 Mdot
.42089 .49215 Mdot
.42101 .18087 Mdot
.42113 .49337 Mdot
.42125 .0545 Mdot
.42137 .56008 Mdot
.42149 .47227 Mdot
.42161 .27404 Mdot
.42173 .53529 Mdot
.42185 .41728 Mdot
.42197 .29797 Mdot
.4221 .48398 Mdot
.42222 .27025 Mdot
.42234 .50087 Mdot
.42246 .54241 Mdot
.42258 .38214 Mdot
.4227 .37498 Mdot
.42282 .37185 Mdot
.42294 .37987 Mdot
.42306 .36724 Mdot
.42318 .38712 Mdot
.4233 .3565 Mdot
.42343 .40498 Mdot
.42355 .33239 Mdot
.42367 .44699 Mdot
.42379 .28987 Mdot
.42391 .51982 Mdot
.42403 .28079 Mdot
.42415 .05017 Mdot
.42427 .5196 Mdot
.42439 .03939 Mdot
.42451 .53314 Mdot
.42463 .43049 Mdot
.42475 .30464 Mdot
.42488 .49342 Mdot
.425 .26878 Mdot
.42512 .40864 Mdot
.42524 .1733 Mdot
.42536 .02914 Mdot
.42548 .53647 Mdot
.4256 .35189 Mdot
.42572 .43981 Mdot
.42584 .29566 Mdot
.42596 .51035 Mdot
.42608 .27238 Mdot
.42621 .09867 Mdot
.42633 .47991 Mdot
.42645 .25329 Mdot
.42657 .48186 Mdot
.42669 .02654 Mdot
.42681 .54077 Mdot
.42693 .36167 Mdot
.42705 .4139 Mdot
.42717 .32152 Mdot
.42729 .46616 Mdot
.42741 .27739 Mdot
.42753 .53645 Mdot
.42766 .3605 Mdot
.42778 .45512 Mdot
.4279 .28408 Mdot
.42802 .52972 Mdot
.42814 .30224 Mdot
.42826 .08994 Mdot
.42838 .48512 Mdot
.4285 .22478 Mdot
.42862 .48616 Mdot
.42874 .02045 Mdot
.42886 .55198 Mdot
.42899 .33865 Mdot
.42911 .50126 Mdot
.42923 .26938 Mdot
.42935 .26337 Mdot
.42947 .28882 Mdot
.42959 .47643 Mdot
.42971 .05602 Mdot
.42983 .52579 Mdot
.42995 .53445 Mdot
.43007 .32009 Mdot
.43019 .405 Mdot
.43032 .16346 Mdot
.43044 .12247 Mdot
.43056 .50003 Mdot
.43068 .19499 Mdot
.4308 .14595 Mdot
.43092 .30954 Mdot
.43104 .46706 Mdot
.43116 .02904 Mdot
.43128 .53899 Mdot
.4314 .37269 Mdot
.43152 .38942 Mdot
.43164 .35288 Mdot
.43177 .41123 Mdot
.43189 .32478 Mdot
.43201 .46034 Mdot
.43213 .28069 Mdot
.43225 .53373 Mdot
.43237 .322 Mdot
.43249 .4375 Mdot
.43261 .53707 Mdot
.43273 .34688 Mdot
.43285 .51155 Mdot
.43297 .27358 Mdot
.4331 .08164 Mdot
.43322 .49069 Mdot
.43334 .19012 Mdot
.43346 .49175 Mdot
.43358 .04305 Mdot
.4337 .55985 Mdot
.43382 .36121 Mdot
.43394 .41515 Mdot
.43406 .32009 Mdot
.43418 .46864 Mdot
.4343 .27612 Mdot
.43442 .53645 Mdot
.43455 .38397 Mdot
.43467 .37089 Mdot
.43479 .37796 Mdot
.43491 .37029 Mdot
.43503 .38217 Mdot
.43515 .36377 Mdot
.43527 .3928 Mdot
.43539 .34846 Mdot
.43551 .41881 Mdot
.43563 .31615 Mdot
.43575 .47535 Mdot
.43588 .27311 Mdot
.436 .53066 Mdot
.43612 .4845 Mdot
.43624 .2572 Mdot
.43636 .15819 Mdot
.43648 .43799 Mdot
.4366 .39403 Mdot
.43672 .43436 Mdot
.43684 .36365 Mdot
.43696 .45559 Mdot
.43708 .26167 Mdot
.4372 .48059 Mdot
.43733 .03214 Mdot
.43745 .53705 Mdot
.43757 .38807 Mdot
.43769 .36084 Mdot
.43781 .39702 Mdot
.43793 .34271 Mdot
.43805 .42883 Mdot
.43817 .30576 Mdot
.43829 .49312 Mdot
.43841 .2688 Mdot
.43853 .41282 Mdot
.43866 .19495 Mdot
.43878 .14609 Mdot
.4389 .30803 Mdot
.43902 .46719 Mdot
.43914 .02841 Mdot
.43926 .53942 Mdot
.43938 .36977 Mdot
.4395 .39553 Mdot
.43962 .34444 Mdot
.43974 .42587 Mdot
.43986 .3087 Mdot
.43999 .48812 Mdot
.44011 .26939 Mdot
.44023 .4701 Mdot
.44035 .33808 Mdot
.44047 .49236 Mdot
.44059 .26898 Mdot
.44071 .42097 Mdot
.44083 .21392 Mdot
.44095 .22302 Mdot
.44107 .4079 Mdot
.44119 .32643 Mdot
.44131 .45866 Mdot
.44144 .28173 Mdot
.44156 .53243 Mdot
.44168 .31399 Mdot
.4418 .28372 Mdot
.44192 .2323 Mdot
.44204 .48477 Mdot
.44216 .01999 Mdot
.44228 .55083 Mdot
.4424 .33838 Mdot
.44252 .49927 Mdot
.44264 .26909 Mdot
.44277 .30418 Mdot
.44289 .17529 Mdot
.44301 .4941 Mdot
.44313 .06582 Mdot
.44325 .55873 Mdot
.44337 .14259 Mdot
.44349 .39778 Mdot
.44361 .46107 Mdot
.44373 .13211 Mdot
.44385 .50319 Mdot
.44397 .14617 Mdot
.44409 .32538 Mdot
.44422 .46602 Mdot
.44434 .03728 Mdot
.44446 .53419 Mdot
.44458 .41662 Mdot
.4447 .31994 Mdot
.44482 .46746 Mdot
.44494 .27671 Mdot
.44506 .53656 Mdot
.44518 .37207 Mdot
.4453 .40993 Mdot
.44542 .32554 Mdot
.44555 .45947 Mdot
.44567 .28123 Mdot
.44579 .53308 Mdot
.44591 .31769 Mdot
.44603 .36041 Mdot
.44615 .02023 Mdot
.44627 .5475 Mdot
.44639 .33953 Mdot
.44651 .48649 Mdot
.44663 .26981 Mdot
.44675 .48232 Mdot
.44688 .36455 Mdot
.447 .43995 Mdot
.44712 .29549 Mdot
.44724 .51099 Mdot
.44736 .27275 Mdot
.44748 .09083 Mdot
.4476 .48485 Mdot
.44772 .22564 Mdot
.44784 .48603 Mdot
.44796 .02031 Mdot
.44808 .5517 Mdot
.4482 .33857 Mdot
.44833 .50088 Mdot
.44845 .26931 Mdot
.44857 .27117 Mdot
.44869 .27018 Mdot
.44881 .47925 Mdot
.44893 .0351 Mdot
.44905 .53536 Mdot
.44917 .40412 Mdot
.44929 .33616 Mdot
.44941 .4393 Mdot
.44953 .29613 Mdot
.44966 .50936 Mdot
.44978 .27185 Mdot
.4499 .11233 Mdot
.45002 .47119 Mdot
.45014 .29576 Mdot
.45026 .47498 Mdot
.45038 .07839 Mdot
.4505 .51781 Mdot
.45062 .05285 Mdot
.45074 .52532 Mdot
.45086 .03296 Mdot
.45098 .5366 Mdot
.45111 .3929 Mdot
.45123 .35291 Mdot
.45135 .41035 Mdot
.45147 .32583 Mdot
.45159 .45851 Mdot
.45171 .28182 Mdot
.45183 .53231 Mdot
.45195 .31333 Mdot
.45207 .26966 Mdot
.45219 .26979 Mdot
.45231 .47931 Mdot
.45244 .03471 Mdot
.45256 .53558 Mdot
.45268 .40191 Mdot
.4528 .33929 Mdot
.45292 .43386 Mdot
.45304 .30097 Mdot
.45316 .50121 Mdot
.45328 .26919 Mdot
.4534 .26819 Mdot
.45352 .27749 Mdot
.45364 .47817 Mdot
.45376 .04223 Mdot
.45389 .53174 Mdot
.45401 .44825 Mdot
.45413 .28885 Mdot
.45425 .51986 Mdot
.45437 .28083 Mdot
.45449 .05017 Mdot
.45461 .51964 Mdot
.45473 .03931 Mdot
.45485 .53318 Mdot
.45497 .42999 Mdot
.45509 .30515 Mdot
.45522 .49256 Mdot
.45534 .26883 Mdot
.45546 .42057 Mdot
.45558 .21577 Mdot
.4557 .18042 Mdot
.45582 .09124 Mdot
.45594 .51021 Mdot
.45606 .08061 Mdot
.45618 .52264 Mdot
.4563 .17963 Mdot
.45642 .49364 Mdot
.45655 .05563 Mdot
.45667 .56003 Mdot
.45679 .49193 Mdot
.45691 .2684 Mdot
.45703 .43659 Mdot
.45715 .52018 Mdot
.45727 .58375 Mdot
.45739 .34009 Mdot
.45751 .48786 Mdot
.45763 .26955 Mdot
.45775 .47087 Mdot
.45787 .33764 Mdot
.458 .49632 Mdot
.45812 .26888 Mdot
.45824 .35977 Mdot
.45836 .02171 Mdot
.45848 .54515 Mdot
.4586 .34352 Mdot
.45872 .46792 Mdot
.45884 .27653 Mdot
.45896 .53652 Mdot
.45908 .37844 Mdot
.4592 .38804 Mdot
.45933 .35333 Mdot
.45945 .41066 Mdot
.45957 .32545 Mdot
.45969 .45917 Mdot
.45981 .28141 Mdot
.45993 .53284 Mdot
.46005 .31629 Mdot
.46017 .33202 Mdot
.46029 .07788 Mdot
.46041 .51788 Mdot
.46053 .0501 Mdot
.46065 .51849 Mdot
.46078 .03778 Mdot
.4609 .53396 Mdot
.46102 .42049 Mdot
.46114 .3154 Mdot
.46126 .47523 Mdot
.46138 .27316 Mdot
.4615 .53087 Mdot
.46162 .48198 Mdot
.46174 .25638 Mdot
.46186 .22567 Mdot
.46198 .36111 Mdot
.46211 .46007 Mdot
.46223 .22074 Mdot
.46235 .48675 Mdot
.46247 .02155 Mdot
.46259 .5534 Mdot
.46271 .3391 Mdot
.46283 .50232 Mdot
.46295 .26959 Mdot
.46307 .24115 Mdot
.46319 .33448 Mdot
.46331 .46779 Mdot
.46344 .14569 Mdot
.46356 .50019 Mdot
.46368 .1167 Mdot
.4638 .50079 Mdot
.46392 .40389 Mdot
.46404 .41866 Mdot
.46416 .40237 Mdot
.46428 .42623 Mdot
.4644 .38586 Mdot
.46452 .44205 Mdot
.46464 .33561 Mdot
.46476 .46602 Mdot
.46489 .17246 Mdot
.46501 .49487 Mdot
.46513 .06729 Mdot
.46525 .55841 Mdot
.46537 .20999 Mdot
.46549 .17011 Mdot
.46561 .03329 Mdot
.46573 .53404 Mdot
.46585 .36436 Mdot
.46597 .40751 Mdot
.46609 .32907 Mdot
.46622 .45293 Mdot
.46634 .28552 Mdot
.46646 .52687 Mdot
.46658 .29368 Mdot
.4667 .05193 Mdot
.46682 .51464 Mdot
.46694 .05343 Mdot
.46706 .52685 Mdot
.46718 .52381 Mdot
.4673 .2854 Mdot
.46742 .05081 Mdot
.46754 .52218 Mdot
.46767 .03639 Mdot
.46779 .53469 Mdot
.46791 .41221 Mdot
.46803 .32539 Mdot
.46815 .45804 Mdot
.46827 .28212 Mdot
.46839 .5319 Mdot
.46851 .31127 Mdot
.46863 .22711 Mdot
.46875 .35596 Mdot
.46887 .46185 Mdot
.469 .2049 Mdot
.46912 .48925 Mdot
.46924 .02975 Mdot
.46936 .55752 Mdot
.46948 .33845 Mdot
.4696 .49763 Mdot
.46972 .26894 Mdot
.46984 .33591 Mdot
.46996 .07157 Mdot
.47008 .52 Mdot
.4702 .23095 Mdot
.47032 .35854 Mdot
.47045 .46091 Mdot
.47057 .21361 Mdot
.47069 .48787 Mdot
.47081 .02439 Mdot
.47093 .55542 Mdot
.47105 .33919 Mdot
.47117 .50233 Mdot
.47129 .2696 Mdot
.47141 .24092 Mdot
.47153 .33491 Mdot
.47165 .46769 Mdot
.47178 .14677 Mdot
.4719 .49996 Mdot
.47202 .11446 Mdot
.47214 .50721 Mdot
.47226 .38844 Mdot
.47238 .43654 Mdot
.4725 .3572 Mdot
.47262 .45848 Mdot
.47274 .24022 Mdot
.47286 .4838 Mdot
.47298 .02083 Mdot
.47311 .5466 Mdot
.47323 .3411 Mdot
.47335 .47825 Mdot
.47347 .2721 Mdot
.47359 .52378 Mdot
.47371 .55196 Mdot
.47383 .47497 Mdot
.47395 .25521 Mdot
.47407 .38871 Mdot
.47419 .0699 Mdot
.47431 .55781 Mdot
.47443 .20651 Mdot
.47456 .17753 Mdot
.47468 .11939 Mdot
.4748 .50149 Mdot
.47492 .20066 Mdot
.47504 .20518 Mdot
.47516 .08089 Mdot
.47528 .4897 Mdot
.4754 .20096 Mdot
.47552 .48993 Mdot
.47564 .03249 Mdot
.47576 .55824 Mdot
.47589 .33902 Mdot
.47601 .49055 Mdot
.47613 .26915 Mdot
.47625 .44339 Mdot
.47637 .50337 Mdot
.47649 .26905 Mdot
.47661 .23342 Mdot
.47673 .34808 Mdot
.47685 .46424 Mdot
.47697 .18229 Mdot
.47709 .49308 Mdot
.47721 .05307 Mdot
.47734 .56014 Mdot
.47746 .44969 Mdot
.47758 .28774 Mdot
.4777 .52167 Mdot
.47782 .28339 Mdot
.47794 .0504 Mdot
.47806 .52127 Mdot
.47818 .03704 Mdot
.4783 .53434 Mdot
.47842 .41606 Mdot
.47854 .32062 Mdot
.47867 .46629 Mdot
.47879 .27732 Mdot
.47891 .53647 Mdot
.47903 .36152 Mdot
.47915 .45089 Mdot
.47927 .28699 Mdot
.47939 .52524 Mdot
.47951 .28989 Mdot
.47963 .0502 Mdot
.47975 .51952 Mdot
.47987 .03983 Mdot
.48 .53292 Mdot
.48012 .43327 Mdot
.48024 .30189 Mdot
.48036 .49803 Mdot
.48048 .26881 Mdot
.4806 .33171 Mdot
.48072 .08448 Mdot
.48084 .51578 Mdot
.48096 .13633 Mdot
.48108 .42558 Mdot
.4812 .45577 Mdot
.48132 .20234 Mdot
.48145 .48966 Mdot
.48157 .03179 Mdot
.48169 .55807 Mdot
.48181 .33876 Mdot
.48193 .49277 Mdot
.48205 .26895 Mdot
.48217 .41536 Mdot
.48229 .20688 Mdot
.48241 .152 Mdot
.48253 .34438 Mdot
.48265 .46614 Mdot
.48278 .05531 Mdot
.4829 .52606 Mdot
.48302 .53183 Mdot
.48314 .30673 Mdot
.48326 .14355 Mdot
.48338 .4487 Mdot
.4835 .3714 Mdot
.48362 .4512 Mdot
.48374 .29035 Mdot
.48386 .47598 Mdot
.48398 .0677 Mdot
.4841 .52143 Mdot
.48423 .37605 Mdot
.48435 .02444 Mdot
.48447 .55556 Mdot
.48459 .33944 Mdot
.48471 .50258 Mdot
.48483 .26965 Mdot
.48495 .23549 Mdot
.48507 .34452 Mdot
.48519 .46523 Mdot
.48531 .17233 Mdot
.48543 .49489 Mdot
.48556 .0675 Mdot
.48568 .55837 Mdot
.4858 .21341 Mdot
.48592 .21845 Mdot
.48604 .44288 Mdot
.48616 .2929 Mdot
.48628 .51666 Mdot
.4864 .27719 Mdot
.48652 .05318 Mdot
.48664 .51289 Mdot
.48676 .05963 Mdot
.48688 .52441 Mdot
.48701 .53452 Mdot
.48713 .45574 Mdot
.48725 .25997 Mdot
.48737 .53664 Mdot
.48749 .36481 Mdot
.48761 .43755 Mdot
.48773 .29751 Mdot
.48785 .50774 Mdot
.48797 .27109 Mdot
.48809 .13816 Mdot
.48821 .45345 Mdot
.48834 .35868 Mdot
.48846 .45757 Mdot
.48858 .24767 Mdot
.4887 .48269 Mdot
.48882 .02331 Mdot
.48894 .54352 Mdot
.48906 .34909 Mdot
.48918 .44841 Mdot
.4893 .28879 Mdot
.48942 .52182 Mdot
.48954 .28365 Mdot
.48967 .05043 Mdot
.48979 .52133 Mdot
.48991 .03698 Mdot
.49003 .53437 Mdot
.49015 .41569 Mdot
.49027 .32107 Mdot
.49039 .46552 Mdot
.49051 .27773 Mdot
.49063 .53632 Mdot
.49075 .35517 Mdot
.49087 .47764 Mdot
.49099 .27243 Mdot
.49112 .52475 Mdot
.49124 .54423 Mdot
.49136 .41259 Mdot
.49148 .30433 Mdot
.4916 .47585 Mdot
.49172 .27289 Mdot
.49184 .52987 Mdot
.49196 .49368 Mdot
.49208 .26245 Mdot
.4922 .05063 Mdot
.49232 .52209 Mdot
.49245 .03573 Mdot
.49257 .53504 Mdot
.49269 .40834 Mdot
.49281 .33042 Mdot
.49293 .44932 Mdot
.49305 .28812 Mdot
.49317 .5227 Mdot
.49329 .28506 Mdot
.49341 .0505 Mdot
.49353 .52152 Mdot
.49365 .03685 Mdot
.49377 .53444 Mdot
.4939 .4149 Mdot
.49402 .32203 Mdot
.49414 .46385 Mdot
.49426 .27864 Mdot
.49438 .53576 Mdot
.4945 .34285 Mdot
.49462 .52508 Mdot
.49474 .29082 Mdot
.49486 .05036 Mdot
.49498 .51824 Mdot
.4951 .04255 Mdot
.49523 .53161 Mdot
.49535 .45115 Mdot
.49547 .28666 Mdot
.49559 .52347 Mdot
.49571 .28641 Mdot
.49583 .05045 Mdot
.49595 .52138 Mdot
.49607 .03704 Mdot
.49619 .53435 Mdot
.49631 .416 Mdot
.49643 .32069 Mdot
.49656 .46617 Mdot
.49668 .27738 Mdot
.4968 .53645 Mdot
.49692 .36055 Mdot
.49704 .45492 Mdot
.49716 .28421 Mdot
.49728 .52953 Mdot
.4974 .30154 Mdot
.49752 .08393 Mdot
.49764 .48897 Mdot
.49776 .20163 Mdot
.49788 .48982 Mdot
.49801 .03194 Mdot
.49813 .55811 Mdot
.49825 .33881 Mdot
.49837 .49231 Mdot
.49849 .26898 Mdot
.49861 .42163 Mdot
.49873 .20935 Mdot
.49885 .16022 Mdot
.49897 .1352 Mdot
.49909 .49639 Mdot
.49921 .16804 Mdot
.49934 .07185 Mdot
.49946 .51677 Mdot
.49958 .52083 Mdot
.4997 .58156 Mdot
.49982 .35088 Mdot
.49994 .48152 Mdot
.50006 .27111 Mdot
.50018 .51157 Mdot
.5003 .5928 Mdot
.50042 .19418 Mdot
.50054 .01579 Mdot
.50066 .55363 Mdot
.50079 .36839 Mdot
.50091 .42741 Mdot
.50103 .30691 Mdot
.50115 .49167 Mdot
.50127 .26891 Mdot
.50139 .43211 Mdot
.50151 .27703 Mdot
.50163 .26544 Mdot
.50175 .47995 Mdot
.50187 .03131 Mdot
.50199 .53755 Mdot
.50212 .38382 Mdot
.50224 .36819 Mdot
.50236 .38502 Mdot
.50248 .35958 Mdot
.5026 .39979 Mdot
.50272 .33904 Mdot
.50284 .43527 Mdot
.50296 .29968 Mdot
.50308 .50339 Mdot
.5032 .26964 Mdot
.50332 .22253 Mdot
.50344 .36541 Mdot
.50357 .4585 Mdot
.50369 .23386 Mdot
.50381 .48476 Mdot
.50393 .01992 Mdot
.50405 .54903 Mdot
.50417 .33862 Mdot
.50429 .49319 Mdot
.50441 .26893 Mdot
.50453 .40946 Mdot
.50465 .17766 Mdot
.50477 .01492 Mdot
.5049 .54965 Mdot
.50502 .35395 Mdot
.50514 .47341 Mdot
.50526 .27404 Mdot
.50538 .53302 Mdot
.5055 .45416 Mdot
.50562 .2608 Mdot
.50574 .53611 Mdot
.50586 .34699 Mdot
.50598 .51113 Mdot
.5061 .27331 Mdot
.50623 .08601 Mdot
.50635 .4879 Mdot
.50647 .20745 Mdot
.50659 .48888 Mdot
.50671 .02768 Mdot
.50683 .55685 Mdot
.50695 .33861 Mdot
.50707 .50052 Mdot
.50719 .26926 Mdot
.50731 .27861 Mdot
.50743 .25104 Mdot
.50755 .48204 Mdot
.50768 .02292 Mdot
.5078 .54391 Mdot
.50792 .34774 Mdot
.50804 .45279 Mdot
.50816 .28563 Mdot
.50828 .52692 Mdot
.5084 .29382 Mdot
.50852 .05208 Mdot
.50864 .5144 Mdot
.50876 .0543 Mdot
.50888 .52649 Mdot
.50901 .52823 Mdot
.50913 .29488 Mdot
.50925 .05308 Mdot
.50937 .51297 Mdot
.50949 .0599 Mdot
.50961 .5243 Mdot
.50973 .53332 Mdot
.50985 .47246 Mdot
.50997 .25532 Mdot
.51009 .44803 Mdot
.51021 .4565 Mdot
.51033 .2829 Mdot
.51046 .52947 Mdot
.51058 .30132 Mdot
.5107 .0821 Mdot
.51082 .49015 Mdot
.51094 .19429 Mdot
.51106 .49104 Mdot
.51118 .03862 Mdot
.5113 .55936 Mdot
.51142 .34666 Mdot
.51154 .45669 Mdot
.51166 .28301 Mdot
.51179 .53087 Mdot
.51191 .3066 Mdot
.51203 .14312 Mdot
.51215 .44903 Mdot
.51227 .37058 Mdot
.51239 .45166 Mdot
.51251 .28758 Mdot
.51263 .47645 Mdot
.51275 .06322 Mdot
.51287 .52304 Mdot
.51299 .50102 Mdot
.51312 .51786 Mdot
.51324 .29131 Mdot
.51336 .06995 Mdot
.51348 .5256 Mdot
.5136 .10612 Mdot
.51372 .5097 Mdot
.51384 .20289 Mdot
.51396 .22267 Mdot
.51408 .40652 Mdot
.5142 .32799 Mdot
.51432 .45589 Mdot
.51444 .28351 Mdot
.51457 .52994 Mdot
.51469 .303 Mdot
.51481 .09731 Mdot
.51493 .48043 Mdot
.51505 .25114 Mdot
.51517 .48219 Mdot
.51529 .0253 Mdot
.51541 .54175 Mdot
.51553 .35659 Mdot
.51565 .42677 Mdot
.51577 .30772 Mdot
.5159 .48996 Mdot
.51602 .26911 Mdot
.51614 .45193 Mdot
.51626 .41788 Mdot
.51638 .31841 Mdot
.5165 .47013 Mdot
.51662 .27539 Mdot
.51674 .53599 Mdot
.51686 .40082 Mdot
.51698 .32811 Mdot
.5171 .44353 Mdot
.51722 .29261 Mdot
.51735 .5152 Mdot
.51747 .27582 Mdot
.51759 .05793 Mdot
.51771 .50787 Mdot
.51783 .08359 Mdot
.51795 .51618 Mdot
.51807 .13624 Mdot
.51819 .42594 Mdot
.51831 .45568 Mdot
.51843 .2034 Mdot
.51855 .48949 Mdot
.51868 .03095 Mdot
.5188 .55786 Mdot
.51892 .33856 Mdot
.51904 .49502 Mdot
.51916 .26887 Mdot
.51928 .38146 Mdot
.5194 .04468 Mdot
.51952 .56004 Mdot
.51964 .36829 Mdot
.51976 .39883 Mdot
.51988 .34004 Mdot
.52 .43359 Mdot
.52013 .30122 Mdot
.52025 .5008 Mdot
.52037 .26912 Mdot
.52049 .27662 Mdot
.52061 .2563 Mdot
.52073 .48128 Mdot
.52085 .02534 Mdot
.52097 .54171 Mdot
.52109 .35677 Mdot
.52121 .42629 Mdot
.52133 .3082 Mdot
.52146 .48914 Mdot
.52158 .26923 Mdot
.5217 .4604 Mdot
.52182 .36404 Mdot
.52194 .4079 Mdot
.52206 .32859 Mdot
.52218 .45377 Mdot
.5223 .28494 Mdot
.52242 .52777 Mdot
.52254 .29609 Mdot
.52266 .05615 Mdot
.52279 .50948 Mdot
.52291 .07589 Mdot
.52303 .51865 Mdot
.52315 .0589 Mdot
.52327 .50759 Mdot
.52339 .08099 Mdot
.52351 .517 Mdot
.52363 .08973 Mdot
.52375 .51714 Mdot
.52387 .25497 Mdot
.52399 .48162 Mdot
.52411 .02828 Mdot
.52424 .53952 Mdot
.52436 .3693 Mdot
.52448 .39655 Mdot
.5246 .34307 Mdot
.52472 .42826 Mdot
.52484 .30631 Mdot
.52496 .49219 Mdot
.52508 .26887 Mdot
.5252 .42549 Mdot
.52532 .12141 Mdot
.52544 .47205 Mdot
.52557 .42882 Mdot
.52569 .36673 Mdot
.52581 .45417 Mdot
.52593 .27131 Mdot
.52605 .4791 Mdot
.52617 .04144 Mdot
.52629 .53212 Mdot
.52641 .44299 Mdot
.52653 .2931 Mdot
.52665 .51275 Mdot
.52677 .27389 Mdot
.52689 .07328 Mdot
.52702 .4962 Mdot
.52714 .15484 Mdot
.52726 .49833 Mdot
.52738 .09774 Mdot
.5275 .539 Mdot
.52762 .16721 Mdot
.52774 .49596 Mdot
.52786 .07438 Mdot
.52798 .55632 Mdot
.5281 .14264 Mdot
.52822 .35835 Mdot
.52835 .46373 Mdot
.52847 .06263 Mdot
.52859 .52325 Mdot
.52871 .5107 Mdot
.52883 .58876 Mdot
.52895 .44466 Mdot
.52907 .2917 Mdot
.52919 .51502 Mdot
.52931 .27565 Mdot
.52943 .05876 Mdot
.52955 .50712 Mdot
.52968 .08766 Mdot
.5298 .51493 Mdot
.52992 .18961 Mdot
.53004 .02152 Mdot
.53016 .54187 Mdot
.53028 .33874 Mdot
.5304 .49156 Mdot
.53052 .26905 Mdot
.53064 .43125 Mdot
.53076 .20194 Mdot
.53088 .39778 Mdot
.531 .44133 Mdot
.53113 .33558 Mdot
.53125 .46604 Mdot
.53137 .17229 Mdot
.53149 .4949 Mdot
.53161 .06755 Mdot
.53173 .55835 Mdot
.53185 .21409 Mdot
.53197 .22455 Mdot
.53209 .41015 Mdot
.53221 .32395 Mdot
.53233 .46306 Mdot
.53246 .2791 Mdot
.53258 .53539 Mdot
.5327 .33761 Mdot
.53282 .53525 Mdot
.53294 .34688 Mdot
.53306 .51153 Mdot
.53318 .27357 Mdot
.5333 .08185 Mdot
.53342 .49056 Mdot
.53354 .19097 Mdot
.53366 .49161 Mdot
.53378 .04212 Mdot
.53391 .55976 Mdot
.53403 .35728 Mdot
.53415 .4251 Mdot
.53427 .3094 Mdot
.53439 .48709 Mdot
.53451 .26958 Mdot
.53463 .47898 Mdot
.53475 .34966 Mdot
.53487 .48604 Mdot
.53499 .26996 Mdot
.53511 .48502 Mdot
.53524 .38127 Mdot
.53536 .38766 Mdot
.53548 .35417 Mdot
.5356 .40916 Mdot
.53572 .32724 Mdot
.53584 .45603 Mdot
.53596 .28342 Mdot
.53608 .53007 Mdot
.5362 .30349 Mdot
.53632 .10241 Mdot
.53644 .47718 Mdot
.53656 .2681 Mdot
.53669 .4796 Mdot
.53681 .03869 Mdot
.53693 .53347 Mdot
.53705 .4254 Mdot
.53717 .30994 Mdot
.53729 .4845 Mdot
.53741 .27015 Mdot
.53753 .49744 Mdot
.53765 .5054 Mdot
.53777 .27056 Mdot
.53789 .0857 Mdot
.53802 .51925 Mdot
.53814 .22598 Mdot
.53826 .48602 Mdot
.53838 .02016 Mdot
.5385 .55135 Mdot
.53862 .33848 Mdot
.53874 .50031 Mdot
.53886 .26922 Mdot
.53898 .28302 Mdot
.5391 .23905 Mdot
.53922 .48378 Mdot
.53935 .02002 Mdot
.53947 .5485 Mdot
.53959 .33891 Mdot
.53971 .49065 Mdot
.53983 .26914 Mdot
.53995 .44225 Mdot
.54007 .5152 Mdot
.54019 .27492 Mdot
.54031 .05975 Mdot
.54043 .50626 Mdot
.54055 .09243 Mdot
.54067 .51351 Mdot
.5408 .21457 Mdot
.54092 .22468 Mdot
.54104 .4834 Mdot
.54116 .27097 Mdot
.54128 .49766 Mdot
.5414 .50809 Mdot
.54152 .27407 Mdot
.54164 .0969 Mdot
.54176 .5104 Mdot
.54188 .31221 Mdot
.542 .47154 Mdot
.54213 .11663 Mdot
.54225 .50692 Mdot
.54237 .18074 Mdot
.54249 .01843 Mdot
.54261 .55638 Mdot
.54273 .37789 Mdot
.54285 .39773 Mdot
.54297 .3407 Mdot
.54309 .43263 Mdot
.54321 .30211 Mdot
.54333 .49929 Mdot
.54345 .26892 Mdot
.54358 .30722 Mdot
.5437 .16541 Mdot
.54382 .49597 Mdot
.54394 .08183 Mdot
.54406 .55287 Mdot
.54418 .03716 Mdot
.5443 .5591 Mdot
.54442 .34406 Mdot
.54454 .46612 Mdot
.54466 .27746 Mdot
.54478 .53647 Mdot
.54491 .36172 Mdot
.54503 .45009 Mdot
.54515 .28756 Mdot
.54527 .52432 Mdot
.54539 .28801 Mdot
.54551 .0503 Mdot
.54563 .52079 Mdot
.54575 .03776 Mdot
.54587 .53397 Mdot
.54599 .42035 Mdot
.54611 .31555 Mdot
.54624 .47497 Mdot
.54636 .27326 Mdot
.54648 .53129 Mdot
.5466 .47682 Mdot
.54672 .25543 Mdot
.54684 .36308 Mdot
.54696 .02005 Mdot
.54708 .54797 Mdot
.5472 .3391 Mdot
.54732 .4893 Mdot
.54744 .26932 Mdot
.54756 .45702 Mdot
.54769 .38184 Mdot
.54781 .37158 Mdot
.54793 .37963 Mdot
.54805 .36763 Mdot
.54817 .38648 Mdot
.54829 .35743 Mdot
.54841 .40342 Mdot
.54853 .33436 Mdot
.54865 .44352 Mdot
.54877 .29261 Mdot
.54889 .51527 Mdot
.54902 .27588 Mdot
.54914 .05765 Mdot
.54926 .50812 Mdot
.54938 .08223 Mdot
.5495 .51661 Mdot
.54962 .11224 Mdot
.54974 .49072 Mdot
.54986 .39709 Mdot
.54998 .42831 Mdot
.5501 .38124 Mdot
.55022 .44544 Mdot
.55034 .32055 Mdot
.55047 .46994 Mdot
.55059 .13125 Mdot
.55071 .5034 Mdot
.55083 .14792 Mdot
.55095 .30767 Mdot
.55107 .46743 Mdot
.55119 .02837 Mdot
.55131 .53945 Mdot
.55143 .36961 Mdot
.55155 .39587 Mdot
.55167 .34398 Mdot
.5518 .42668 Mdot
.55192 .30789 Mdot
.55204 .48951 Mdot
.55216 .26917 Mdot
.55228 .4567 Mdot
.5524 .3838 Mdot
.55252 .36808 Mdot
.55264 .38521 Mdot
.55276 .3593 Mdot
.55288 .40026 Mdot
.553 .33842 Mdot
.55312 .43636 Mdot
.55325 .2987 Mdot
.55337 .50504 Mdot
.55349 .2701 Mdot
.55361 .18879 Mdot
.55373 .40859 Mdot
.55385 .43279 Mdot
.55397 .36609 Mdot
.55409 .45442 Mdot
.55421 .26973 Mdot
.55433 .47935 Mdot
.55445 .03973 Mdot
.55458 .53295 Mdot
.5547 .43194 Mdot
.55482 .30319 Mdot
.55494 .49585 Mdot
.55506 .26872 Mdot
.55518 .37077 Mdot
.5553 .02279 Mdot
.55542 .55458 Mdot
.55554 .3396 Mdot
.55566 .50272 Mdot
.55578 .26969 Mdot
.55591 .23253 Mdot
.55603 .34954 Mdot
.55615 .46381 Mdot
.55627 .18646 Mdot
.55639 .49235 Mdot
.55651 .04777 Mdot
.55663 .56012 Mdot
.55675 .39023 Mdot
.55687 .35728 Mdot
.55699 .40295 Mdot
.55711 .33496 Mdot
.55723 .44246 Mdot
.55736 .29347 Mdot
.55748 .51382 Mdot
.5576 .27468 Mdot
.55772 .06532 Mdot
.55784 .50183 Mdot
.55796 .11886 Mdot
.55808 .50639 Mdot
.5582 .17525 Mdot
.55832 .02027 Mdot
.55844 .54269 Mdot
.55856 .33824 Mdot
.55869 .49817 Mdot
.55881 .26898 Mdot
.55893 .32554 Mdot
.55905 .10441 Mdot
.55917 .50997 Mdot
.55929 .20866 Mdot
.55941 .06111 Mdot
.55953 .52558 Mdot
.55965 .06596 Mdot
.55977 .52207 Mdot
.55989 .43027 Mdot
.56001 .0751 Mdot
.56014 .52488 Mdot
.56026 .13618 Mdot
.56038 .50234 Mdot
.5605 .13599 Mdot
.56062 .40998 Mdot
.56074 .45936 Mdot
.56086 .13602 Mdot
.56098 .5023 Mdot
.5611 .13756 Mdot
.56122 .3989 Mdot
.56134 .46059 Mdot
.56147 .11549 Mdot
.56159 .5072 Mdot
.56171 .18347 Mdot
.56183 .03098 Mdot
.56195 .56063 Mdot
.56207 .35367 Mdot
.56219 .47417 Mdot
.56231 .27372 Mdot
.56243 .53199 Mdot
.56255 .468 Mdot
.56267 .25582 Mdot
.5628 .50008 Mdot
.56292 .53223 Mdot
.56304 .33376 Mdot
.56316 .53222 Mdot
.56328 .45091 Mdot
.5634 .26267 Mdot
.56352 .53358 Mdot
.56364 .32023 Mdot
.56376 .40807 Mdot
.56388 .17978 Mdot
.564 .0162 Mdot
.56412 .55458 Mdot
.56425 .37444 Mdot
.56437 .40825 Mdot
.56449 .32767 Mdot
.56461 .45564 Mdot
.56473 .28368 Mdot
.56485 .52969 Mdot
.56497 .30209 Mdot
.56509 .08862 Mdot
.56521 .48596 Mdot
.56533 .21985 Mdot
.56545 .48692 Mdot
.56558 .02167 Mdot
.5657 .55352 Mdot
.56582 .33913 Mdot
.56594 .50236 Mdot
.56606 .2696 Mdot
.56618 .2403 Mdot
.5663 .33602 Mdot
.56642 .46742 Mdot
.56654 .14963 Mdot
.56666 .49936 Mdot
.56678 .1086 Mdot
.5669 .5212 Mdot
.56703 .33309 Mdot
.56715 .46608 Mdot
.56727 .17486 Mdot
.56739 .49442 Mdot
.56751 .06359 Mdot
.56763 .55914 Mdot
.56775 .08885 Mdot
.56787 .48724 Mdot
.56799 .20831 Mdot
.56811 .48874 Mdot
.56823 .02714 Mdot
.56836 .55665 Mdot
.56848 .3387 Mdot
.5686 .50102 Mdot
.56872 .26934 Mdot
.56884 .26833 Mdot
.56896 .27714 Mdot
.56908 .47822 Mdot
.5692 .04186 Mdot
.56932 .53191 Mdot
.56944 .44577 Mdot
.56956 .2908 Mdot
.56968 .51659 Mdot
.56981 .2771 Mdot
.56993 .05337 Mdot
.57005 .51265 Mdot
.57017 .06062 Mdot
.57029 .52403 Mdot
.57041 .52914 Mdot
.57053 .52131 Mdot
.57065 .30906 Mdot
.57077 .13082 Mdot
.57089 .45804 Mdot
.57101 .3455 Mdot
.57114 .46271 Mdot
.57126 .20489 Mdot
.57138 .48926 Mdot
.5715 .02975 Mdot
.57162 .55752 Mdot
.57174 .33845 Mdot
.57186 .49762 Mdot
.57198 .26894 Mdot
.5721 .33597 Mdot
.57222 .07138 Mdot
.57234 .52006 Mdot
.57247 .23935 Mdot
.57259 .34478 Mdot
.57271 .46512 Mdot
.57283 .17369 Mdot
.57295 .49464 Mdot
.57307 .06539 Mdot
.57319 .55882 Mdot
.57331 .10874 Mdot
.57343 .49641 Mdot
.57355 .38104 Mdot
.57367 .44335 Mdot
.57379 .33096 Mdot
.57392 .46732 Mdot
.57404 .15915 Mdot
.57416 .49742 Mdot
.57428 .0901 Mdot
.5744 .54702 Mdot
.57452 .04689 Mdot
.57464 .52964 Mdot
.57476 .48199 Mdot
.57488 .2704 Mdot
.575 .514 Mdot
.57512 .59224 Mdot
.57525 .09992 Mdot
.57537 .50791 Mdot
.57549 .33025 Mdot
.57561 .46703 Mdot
.57573 .16465 Mdot
.57585 .49635 Mdot
.57597 .0802 Mdot
.57609 .55376 Mdot
.57621 .05482 Mdot
.57633 .56003 Mdot
.57645 .47904 Mdot
.57657 .27133 Mdot
.5767 .52424 Mdot
.57682 .54841 Mdot
.57694 .44377 Mdot
.57706 .26697 Mdot
.57718 .52542 Mdot
.5773 .29006 Mdot
.57742 .0502 Mdot
.57754 .51945 Mdot
.57766 .03995 Mdot
.57778 .53286 Mdot
.5779 .4341 Mdot
.57803 .3011 Mdot
.57815 .49936 Mdot
.57827 .26893 Mdot
.57839 .30589 Mdot
.57851 .16974 Mdot
.57863 .49514 Mdot
.57875 .07455 Mdot
.57887 .55626 Mdot
.57899 .13991 Mdot
.57911 .38118 Mdot
.57923 .46212 Mdot
.57936 .08866 Mdot
.57948 .5146 Mdot
.5796 .19589 Mdot
.57972 .01985 Mdot
.57984 .55698 Mdot
.57996 .37443 Mdot
.58008 .4083 Mdot
.5802 .32761 Mdot
.58032 .45575 Mdot
.58044 .28361 Mdot
.58056 .52979 Mdot
.58068 .30247 Mdot
.58081 .0921 Mdot
.58093 .48374 Mdot
.58105 .23276 Mdot
.58117 .48495 Mdot
.58129 .01989 Mdot
.58141 .54923 Mdot
.58153 .33853 Mdot
.58165 .4941 Mdot
.58177 .26889 Mdot
.58189 .39607 Mdot
.58201 .10602 Mdot
.58214 .52631 Mdot
.58226 .30082 Mdot
.58238 .47386 Mdot
.5825 .09233 Mdot
.58262 .51352 Mdot
.58274 .21389 Mdot
.58286 .22308 Mdot
.58298 .40772 Mdot
.5831 .32664 Mdot
.58322 .45829 Mdot
.58334 .28196 Mdot
.58346 .53212 Mdot
.58359 .31238 Mdot
.58371 .24978 Mdot
.58383 .31477 Mdot
.58395 .47198 Mdot
.58407 .10019 Mdot
.58419 .51127 Mdot
.58431 .21421 Mdot
.58443 .43898 Mdot
.58455 .49174 Mdot
.58467 .26844 Mdot
.58479 .43847 Mdot
.58492 .53757 Mdot
.58504 .39177 Mdot
.58516 .34938 Mdot
.58528 .411 Mdot
.5854 .3251 Mdot
.58552 .45976 Mdot
.58564 .28105 Mdot
.58576 .5333 Mdot
.58588 .31908 Mdot
.586 .38745 Mdot
.58612 .07366 Mdot
.58624 .55664 Mdot
.58637 .15477 Mdot
.58649 .23061 Mdot
.58661 .47649 Mdot
.58673 .0297 Mdot
.58685 .55752 Mdot
.58697 .33845 Mdot
.58709 .49781 Mdot
.58721 .26895 Mdot
.58733 .33244 Mdot
.58745 .08218 Mdot
.58757 .5165 Mdot
.5877 .0956 Mdot
.58782 .51226 Mdot
.58794 .30031 Mdot
.58806 .47401 Mdot
.58818 .09014 Mdot
.5883 .51416 Mdot
.58842 .2057 Mdot
.58854 .10912 Mdot
.58866 .52069 Mdot
.58878 .343 Mdot
.5889 .46284 Mdot
.58903 .20579 Mdot
.58915 .48911 Mdot
.58927 .02909 Mdot
.58939 .55732 Mdot
.58951 .33846 Mdot
.58963 .49874 Mdot
.58975 .26903 Mdot
.58987 .31453 Mdot
.58999 .14118 Mdot
.59011 .50097 Mdot
.59023 .12901 Mdot
.59035 .45169 Mdot
.59048 .45024 Mdot
.5906 .24653 Mdot
.59072 .48286 Mdot
.59084 .02276 Mdot
.59096 .54409 Mdot
.59108 .34718 Mdot
.5912 .45466 Mdot
.59132 .28436 Mdot
.59144 .52889 Mdot
.59156 .29943 Mdot
.59168 .06938 Mdot
.59181 .49871 Mdot
.59193 .13945 Mdot
.59205 .50158 Mdot
.59217 .12938 Mdot
.59229 .44974 Mdot
.59241 .45094 Mdot
.59253 .24014 Mdot
.59265 .48381 Mdot
.59277 .02077 Mdot
.59289 .5467 Mdot
.59301 .34094 Mdot
.59313 .47901 Mdot
.59326 .27184 Mdot
.59338 .5215 Mdot
.5935 .56755 Mdot
.59362 .60332 Mdot
.59374 .30342 Mdot
.59386 .47283 Mdot
.59398 .10892 Mdot
.5941 .5089 Mdot
.59422 .19773 Mdot
.59434 .17573 Mdot
.59446 .01472 Mdot
.59459 .55171 Mdot
.59471 .36333 Mdot
.59483 .44383 Mdot
.59495 .29232 Mdot
.59507 .51631 Mdot
.59519 .27684 Mdot
.59531 .05407 Mdot
.59543 .5118 Mdot
.59555 .06427 Mdot
.59567 .52268 Mdot
.59579 .47788 Mdot
.59592 .33977 Mdot
.59604 .50502 Mdot
.59616 .27032 Mdot
.59628 .18524 Mdot
.5964 .41236 Mdot
.59652 .42921 Mdot
.59664 .3764 Mdot
.59676 .44866 Mdot
.59688 .30435 Mdot
.597 .4734 Mdot
.59712 .09383 Mdot
.59724 .51308 Mdot
.59737 .21664 Mdot
.59749 .06744 Mdot
.59761 .52529 Mdot
.59773 .09712 Mdot
.59785 .51218 Mdot
.59797 .21717 Mdot
.59809 .49337 Mdot
.59821 .50731 Mdot
.59833 .273 Mdot
.59845 .09427 Mdot
.59857 .51285 Mdot
.5987 .29332 Mdot
.59882 .47533 Mdot
.59894 .07654 Mdot
.59906 .51841 Mdot
.59918 .05366 Mdot
.5993 .51268 Mdot
.59942 .05652 Mdot
.59954 .52561 Mdot
.59966 .53617 Mdot
.59978 .33419 Mdot
.5999 .53418 Mdot
.60002 .42056 Mdot
.60015 .29313 Mdot
.60027 .4898 Mdot
.60039 .26909 Mdot
.60051 .45425 Mdot
.60063 .40007 Mdot
.60075 .34189 Mdot
.60087 .42936 Mdot
.60099 .30524 Mdot
.60111 .494 Mdot
.60123 .26875 Mdot
.60135 .4001 Mdot
.60148 .1272 Mdot
.6016 .46058 Mdot
.60172 .44648 Mdot
.60184 .27687 Mdot
.60196 .47822 Mdot
.60208 .04777 Mdot
.6022 .52922 Mdot
.60232 .48645 Mdot
.60244 .26926 Mdot
.60256 .48899 Mdot
.60268 .41349 Mdot
.6028 .31269 Mdot
.60293 .46721 Mdot
.60305 .27683 Mdot
.60317 .53655 Mdot
.60329 .36926 Mdot
.60341 .42028 Mdot
.60353 .31408 Mdot
.60365 .47948 Mdot
.60377 .2716 Mdot
.60389 .52055 Mdot
.60401 .57287 Mdot
.60413 .59212 Mdot
.60426 .08261 Mdot
.60438 .49115 Mdot
.6045 .18368 Mdot
.60462 .49287 Mdot
.60474 .05081 Mdot
.60486 .56017 Mdot
.60498 .41992 Mdot
.6051 .31606 Mdot
.60522 .47409 Mdot
.60534 .27362 Mdot
.60546 .53258 Mdot
.60559 .46024 Mdot
.60571 .258 Mdot
.60583 .534 Mdot
.60595 .44201 Mdot
.60607 .26911 Mdot
.60619 .52214 Mdot
.60631 .28398 Mdot
.60643 .05049 Mdot
.60655 .5215 Mdot
.60667 .03683 Mdot
.60679 .53445 Mdot
.60691 .41481 Mdot
.60704 .32215 Mdot
.60716 .46366 Mdot
.60728 .27875 Mdot
.6074 .53567 Mdot
.60752 .34148 Mdot
.60764 .52874 Mdot
.60776 .30087 Mdot
.60788 .07943 Mdot
.608 .4919 Mdot
.60812 .18329 Mdot
.60824 .49294 Mdot
.60837 .05129 Mdot
.60849 .56017 Mdot
.60861 .42567 Mdot
.60873 .30966 Mdot
.60885 .48495 Mdot
.60897 .27004 Mdot
.60909 .49458 Mdot
.60921 .47241 Mdot
.60933 .25685 Mdot
.60945 .49849 Mdot
.60957 .51504 Mdot
.60969 .28555 Mdot
.60982 .09011 Mdot
.60994 .51618 Mdot
.61006 .2619 Mdot
.61018 .48056 Mdot
.6103 .03377 Mdot
.61042 .53611 Mdot
.61054 .39672 Mdot
.61066 .34697 Mdot
.61078 .42054 Mdot
.6109 .31427 Mdot
.61102 .47858 Mdot
.61115 .27191 Mdot
.61127 .52333 Mdot
.61139 .5553 Mdot
.61151 .50857 Mdot
.61163 .28174 Mdot
.61175 .10253 Mdot
.61187 .50422 Mdot
.61199 .34878 Mdot
.61211 .46091 Mdot
.61223 .22217 Mdot
.61235 .48654 Mdot
.61247 .02114 Mdot
.6126 .55296 Mdot
.61272 .33897 Mdot
.61284 .50211 Mdot
.61296 .26955 Mdot
.61308 .24542 Mdot
.6132 .3265 Mdot
.61332 .4696 Mdot
.61344 .12615 Mdot
.61356 .50459 Mdot
.61368 .15934 Mdot
.6138 .17386 Mdot
.61393 .48705 Mdot
.61405 .09237 Mdot
.61417 .54495 Mdot
.61429 .07644 Mdot
.61441 .51849 Mdot
.61453 .05181 Mdot
.61465 .51507 Mdot
.61477 .04749 Mdot
.61489 .52935 Mdot
.61501 .4854 Mdot
.61513 .2695 Mdot
.61526 .49611 Mdot
.61538 .48989 Mdot
.6155 .25841 Mdot
.61562 .13454 Mdot
.61574 .45625 Mdot
.61586 .35048 Mdot
.61598 .46091 Mdot
.6161 .22077 Mdot
.61622 .48675 Mdot
.61634 .02153 Mdot
.61646 .55338 Mdot
.61658 .3391 Mdot
.61671 .50231 Mdot
.61683 .26959 Mdot
.61695 .24126 Mdot
.61707 .33428 Mdot
.61719 .46784 Mdot
.61731 .14517 Mdot
.61743 .5003 Mdot
.61755 .11778 Mdot
.61767 .49747 Mdot
.61779 .41036 Mdot
.61791 .40846 Mdot
.61804 .41877 Mdot
.61816 .4017 Mdot
.61828 .42703 Mdot
.6184 .38392 Mdot
.61852 .44352 Mdot
.61864 .32933 Mdot
.61876 .46776 Mdot
.61888 .15456 Mdot
.619 .49834 Mdot
.61912 .09882 Mdot
.61924 .5376 Mdot
.61936 .18644 Mdot
.61949 .49246 Mdot
.61961 .04651 Mdot
.61973 .56007 Mdot
.61985 .38072 Mdot
.61997 .37387 Mdot
.62009 .37602 Mdot
.62021 .37317 Mdot
.62033 .37761 Mdot
.62045 .3707 Mdot
.62057 .38154 Mdot
.62069 .36472 Mdot
.62082 .39123 Mdot
.62094 .35064 Mdot
.62106 .41502 Mdot
.62118 .32038 Mdot
.6213 .46802 Mdot
.62142 .27642 Mdot
.62154 .53653 Mdot
.62166 .37761 Mdot
.62178 .39078 Mdot
.6219 .34961 Mdot
.62202 .41708 Mdot
.62215 .31806 Mdot
.62227 .47206 Mdot
.62239 .2745 Mdot
.62251 .53477 Mdot
.62263 .42693 Mdot
.62275 .28463 Mdot
.62287 .50003 Mdot
.62299 .26895 Mdot
.62311 .29351 Mdot
.62323 .20867 Mdot
.62335 .4884 Mdot
.62347 .02899 Mdot
.6236 .55729 Mdot
.62372 .33847 Mdot
.62384 .4989 Mdot
.62396 .26905 Mdot
.62408 .3115 Mdot
.6242 .15129 Mdot
.62432 .4988 Mdot
.62444 .10817 Mdot
.62456 .5221 Mdot
.62468 .328 Mdot
.6248 .46754 Mdot
.62493 .15996 Mdot
.62505 .49726 Mdot
.62517 .0886 Mdot
.62529 .54827 Mdot
.62541 .03259 Mdot
.62553 .53683 Mdot
.62565 .39127 Mdot
.62577 .35553 Mdot
.62589 .40591 Mdot
.62601 .33123 Mdot
.62613 .44902 Mdot
.62625 .28834 Mdot
.62638 .52234 Mdot
.6265 .28448 Mdot
.62662 .05048 Mdot
.62674 .52149 Mdot
.62686 .03686 Mdot
.62698 .53444 Mdot
.6271 .41495 Mdot
.62722 .32197 Mdot
.62734 .46397 Mdot
.62746 .27858 Mdot
.62758 .5358 Mdot
.62771 .34364 Mdot
.62783 .5227 Mdot
.62795 .28608 Mdot
.62807 .05034 Mdot
.62819 .52101 Mdot
.62831 .03742 Mdot
.62843 .53415 Mdot
.62855 .41832 Mdot
.62867 .31792 Mdot
.62879 .47092 Mdot
.62891 .27502 Mdot
.62903 .53558 Mdot
.62916 .4109 Mdot
.62928 .30846 Mdot
.6294 .47086 Mdot
.62952 .27503 Mdot
.62964 .53565 Mdot
.62976 .40943 Mdot
.62988 .31107 Mdot
.63 .46744 Mdot
.63012 .2767 Mdot
.63024 .53656 Mdot
.63036 .37136 Mdot
.63049 .41248 Mdot
.63061 .32261 Mdot
.63073 .46462 Mdot
.63085 .27822 Mdot
.63097 .53605 Mdot
.63109 .34837 Mdot
.63121 .50584 Mdot
.63133 .27075 Mdot
.63145 .16692 Mdot
.63157 .43016 Mdot
.63169 .40726 Mdot
.63182 .41909 Mdot
.63194 .40118 Mdot
.63206 .42762 Mdot
.63218 .38246 Mdot
.6323 .44458 Mdot
.63242 .32456 Mdot
.63254 .46898 Mdot
.63266 .14164 Mdot
.63278 .50106 Mdot
.6329 .12522 Mdot
.63302 .4697 Mdot
.63314 .44132 Mdot
.63327 .30991 Mdot
.63339 .47231 Mdot
.63351 .10533 Mdot
.63363 .50986 Mdot
.63375 .20518 Mdot
.63387 .21541 Mdot
.63399 .21966 Mdot
.63411 .43069 Mdot
.63423 .30323 Mdot
.63435 .49915 Mdot
.63447 .26891 Mdot
.6346 .30998 Mdot
.63472 .15631 Mdot
.63484 .49777 Mdot
.63496 .09838 Mdot
.63508 .53817 Mdot
.6352 .17872 Mdot
.63532 .49383 Mdot
.63544 .05659 Mdot
.63556 .55996 Mdot
.63568 .50897 Mdot
.6358 .27094 Mdot
.63592 .12573 Mdot
.63605 .46227 Mdot
.63617 .33099 Mdot
.63629 .46718 Mdot
.63641 .16135 Mdot
.63653 .49699 Mdot
.63665 .08608 Mdot
.63677 .55018 Mdot
.63689 .02044 Mdot
.63701 .54754 Mdot
.63713 .33999 Mdot
.63725 .48387 Mdot
.63738 .2704 Mdot
.6375 .5001 Mdot
.63762 .53473 Mdot
.63774 .34391 Mdot
.63786 .5225 Mdot
.63798 .28575 Mdot
.6381 .05035 Mdot
.63822 .52104 Mdot
.63834 .03737 Mdot
.63846 .53417 Mdot
.63858 .41804 Mdot
.63871 .31824 Mdot
.63883 .47037 Mdot
.63895 .27528 Mdot
.63907 .53588 Mdot
.63919 .40382 Mdot
.63931 .32184 Mdot
.63943 .45264 Mdot
.63955 .28572 Mdot
.63967 .52649 Mdot
.63979 .29275 Mdot
.63991 .05109 Mdot
.64003 .51618 Mdot
.64016 .04825 Mdot
.64028 .52902 Mdot
.6404 .49072 Mdot
.64052 .26854 Mdot
.64064 .45046 Mdot
.64076 .43072 Mdot
.64088 .3044 Mdot
.641 .49386 Mdot
.64112 .26876 Mdot
.64124 .40225 Mdot
.64136 .13877 Mdot
.64149 .38971 Mdot
.64161 .46143 Mdot
.64173 .1007 Mdot
.64185 .51112 Mdot
.64197 .21356 Mdot
.64209 .40096 Mdot
.64221 .16418 Mdot
.64233 .11387 Mdot
.64245 .50256 Mdot
.64257 .21145 Mdot
.64269 .20235 Mdot
.64281 .38555 Mdot
.64294 .44943 Mdot
.64306 .29574 Mdot
.64318 .47502 Mdot
.6433 .07704 Mdot
.64342 .51825 Mdot
.64354 .05065 Mdot
.64366 .5171 Mdot
.64378 .04126 Mdot
.6439 .53222 Mdot
.64402 .44258 Mdot
.64414 .29344 Mdot
.64427 .51217 Mdot
.64439 .27349 Mdot
.64451 .07843 Mdot
.64463 .49277 Mdot
.64475 .17689 Mdot
.64487 .49409 Mdot
.64499 .0601 Mdot
.64511 .55964 Mdot
.64523 .52136 Mdot
.64535 .57954 Mdot
.64547 .39014 Mdot
.64559 .36355 Mdot
.64572 .38972 Mdot
.64584 .35286 Mdot
.64596 .4112 Mdot
.64608 .32482 Mdot
.6462 .46029 Mdot
.64632 .28072 Mdot
.64644 .53369 Mdot
.64656 .32171 Mdot
.64668 .43293 Mdot
.6468 .45859 Mdot
.64692 .39114 Mdot
.64705 .35564 Mdot
.64717 .40574 Mdot
.64729 .33144 Mdot
.64741 .44865 Mdot
.64753 .28862 Mdot
.64765 .52189 Mdot
.64777 .28375 Mdot
.64789 .05044 Mdot
.64801 .52136 Mdot
.64813 .03696 Mdot
.64825 .53439 Mdot
.64838 .41555 Mdot
.6485 .32123 Mdot
.64862 .46523 Mdot
.64874 .27788 Mdot
.64886 .53624 Mdot
.64898 .3529 Mdot
.6491 .48728 Mdot
.64922 .26978 Mdot
.64934 .47418 Mdot
.64946 .33872 Mdot
.64958 .50521 Mdot
.6497 .27038 Mdot
.64983 .18159 Mdot
.64995 .41614 Mdot
.65007 .4253 Mdot
.65019 .38631 Mdot
.65031 .44173 Mdot
.65043 .33695 Mdot
.65055 .46563 Mdot
.65067 .1764 Mdot
.65079 .49414 Mdot
.65091 .0613 Mdot
.65103 .55949 Mdot
.65116 .44092 Mdot
.65128 .53265 Mdot
.6514 .4805 Mdot
.65152 .25601 Mdot
.65164 .26683 Mdot
.65176 .28156 Mdot
.65188 .47755 Mdot
.652 .04681 Mdot
.65212 .52964 Mdot
.65224 .47975 Mdot
.65236 .2711 Mdot
.65248 .52214 Mdot
.65261 .56358 Mdot
.65273 .59204 Mdot
.65285 .15729 Mdot
.65297 .30556 Mdot
.65309 .46913 Mdot
.65321 .0286 Mdot
.65333 .53929 Mdot
.65345 .37067 Mdot
.65357 .39362 Mdot
.65369 .34703 Mdot
.65381 .42134 Mdot
.65394 .31342 Mdot
.65406 .48006 Mdot
.65418 .27141 Mdot
.6543 .51859 Mdot
.65442 .58181 Mdot
.65454 .34805 Mdot
.65466 .48867 Mdot
.65478 .26947 Mdot
.6549 .46247 Mdot
.65502 .35538 Mdot
.65514 .42939 Mdot
.65527 .30514 Mdot
.65539 .49434 Mdot
.65551 .26874 Mdot
.65563 .39496 Mdot
.65575 .1004 Mdot
.65587 .53546 Mdot
.65599 .214 Mdot
.65611 .4879 Mdot
.65623 .02355 Mdot
.65635 .55493 Mdot
.65647 .33927 Mdot
.65659 .50245 Mdot
.65672 .26962 Mdot
.65684 .23823 Mdot
.65696 .33975 Mdot
.65708 .46649 Mdot
.6572 .15939 Mdot
.65732 .49737 Mdot
.65744 .08968 Mdot
.65756 .54738 Mdot
.65768 .04242 Mdot
.6578 .53168 Mdot
.65792 .45099 Mdot
.65805 .28677 Mdot
.65817 .52329 Mdot
.65829 .28607 Mdot
.65841 .05048 Mdot
.65853 .52144 Mdot
.65865 .03696 Mdot
.65877 .53439 Mdot
.65889 .41555 Mdot
.65901 .32123 Mdot
.65913 .46524 Mdot
.65925 .27788 Mdot
.65937 .53624 Mdot
.6595 .35294 Mdot
.65962 .4871 Mdot
.65974 .26981 Mdot
.65986 .47569 Mdot
.65998 .34092 Mdot
.6601 .50411 Mdot
.66022 .27006 Mdot
.66034 .20354 Mdot
.66046 .39143 Mdot
.66058 .44576 Mdot
.6607 .31538 Mdot
.66083 .47112 Mdot
.66095 .11841 Mdot
.66107 .50647 Mdot
.66119 .17675 Mdot
.66131 .01616 Mdot
.66143 .54709 Mdot
.66155 .3448 Mdot
.66167 .49688 Mdot
.66179 .26895 Mdot
.66191 .3487 Mdot
.66203 .03821 Mdot
.66215 .53366 Mdot
.66228 .42036 Mdot
.6624 .31555 Mdot
.66252 .47498 Mdot
.66264 .27326 Mdot
.66276 .53128 Mdot
.66288 .47695 Mdot
.663 .25545 Mdot
.66312 .3599 Mdot
.66324 .02187 Mdot
.66336 .54495 Mdot
.66348 .344 Mdot
.66361 .46603 Mdot
.66373 .27751 Mdot
.66385 .53646 Mdot
.66397 .36096 Mdot
.66409 .45321 Mdot
.66421 .28536 Mdot
.66433 .52779 Mdot
.66445 .29614 Mdot
.66457 .05628 Mdot
.66469 .50935 Mdot
.66481 .07656 Mdot
.66494 .51843 Mdot
.66506 .05227 Mdot
.66518 .51443 Mdot
.6653 .04977 Mdot
.66542 .52837 Mdot
.66554 .50112 Mdot
.66566 .2686 Mdot
.66578 .28107 Mdot
.6659 .24444 Mdot
.66602 .48299 Mdot
.66614 .02088 Mdot
.66626 .54652 Mdot
.66639 .34124 Mdot
.66651 .47759 Mdot
.66663 .27234 Mdot
.66675 .52554 Mdot
.66687 .53749 Mdot
.66699 .37228 Mdot
.66711 .40784 Mdot
.66723 .32798 Mdot
.66735 .45519 Mdot
.66747 .28398 Mdot
.66759 .52924 Mdot
.66772 .30056 Mdot
.66784 .07649 Mdot
.66796 .49383 Mdot
.66808 .17091 Mdot
.6682 .49519 Mdot
.66832 .06923 Mdot
.66844 .55794 Mdot
.66856 .21256 Mdot
.66868 .30973 Mdot
.6688 .13552 Mdot
.66892 .50223 Mdot
.66904 .1413 Mdot
.66917 .36967 Mdot
.66929 .46296 Mdot
.66941 .07449 Mdot
.66953 .51909 Mdot
.66965 .09238 Mdot
.66977 .48505 Mdot
.66989 .22159 Mdot
.67001 .48665 Mdot
.67013 .02117 Mdot
.67025 .553 Mdot
.67037 .33898 Mdot
.6705 .50213 Mdot
.67062 .26955 Mdot
.67074 .24498 Mdot
.67086 .32735 Mdot
.67098 .46941 Mdot
.6711 .12816 Mdot
.67122 .50411 Mdot
.67134 .15483 Mdot
.67146 .2296 Mdot
.67158 .47664 Mdot
.6717 .03028 Mdot
.67183 .55768 Mdot
.67195 .33847 Mdot
.67207 .49669 Mdot
.67219 .26889 Mdot
.67231 .35303 Mdot
.67243 .03002 Mdot
.67255 .53829 Mdot
.67267 .37629 Mdot
.67279 .38222 Mdot
.67291 .36331 Mdot
.67303 .3936 Mdot
.67315 .34735 Mdot
.67328 .42073 Mdot
.6734 .31407 Mdot
.67352 .47894 Mdot
.67364 .27178 Mdot
.67376 .52227 Mdot
.67388 .56267 Mdot
.674 .58541 Mdot
.67412 .36508 Mdot
.67424 .40647 Mdot
.67436 .33032 Mdot
.67448 .45071 Mdot
.67461 .2871 Mdot
.67473 .52437 Mdot
.67485 .2881 Mdot
.67497 .05029 Mdot
.67509 .52075 Mdot
.67521 .03782 Mdot
.67533 .53394 Mdot
.67545 .42074 Mdot
.67557 .31512 Mdot
.67569 .47571 Mdot
.67581 .27297 Mdot
.67593 .53002 Mdot
.67606 .49196 Mdot
.67618 .26117 Mdot
.6763 .05146 Mdot
.67642 .51547 Mdot
.67654 .0496 Mdot
.67666 .52844 Mdot
.67678 .50001 Mdot
.6769 .26845 Mdot
.67702 .30372 Mdot
.67714 .17681 Mdot
.67726 .49382 Mdot
.67739 .06354 Mdot
.67751 .55915 Mdot
.67763 .09476 Mdot
.67775 .48362 Mdot
.67787 .22996 Mdot
.67799 .48537 Mdot
.67811 .01989 Mdot
.67823 .55024 Mdot
.67835 .33835 Mdot
.67847 .4977 Mdot
.67859 .26894 Mdot
.67871 .33459 Mdot
.67884 .07554 Mdot
.67896 .51865 Mdot
.67908 .08035 Mdot
.6792 .49251 Mdot
.67932 .17511 Mdot
.67944 .49441 Mdot
.67956 .06274 Mdot
.67968 .55928 Mdot
.6798 .22051 Mdot
.67992 .37418 Mdot
.68004 .45479 Mdot
.68017 .26206 Mdot
.68029 .48053 Mdot
.68041 .03245 Mdot
.68053 .53687 Mdot
.68065 .38966 Mdot
.68077 .35818 Mdot
.68089 .40146 Mdot
.68101 .33687 Mdot
.68113 .43909 Mdot
.68125 .29631 Mdot
.68137 .50906 Mdot
.6815 .2717 Mdot
.68162 .11675 Mdot
.68174 .4683 Mdot
.68186 .30805 Mdot
.68198 .4726 Mdot
.6821 .1033 Mdot
.68222 .51041 Mdot
.68234 .20909 Mdot
.68246 .05136 Mdot
.68258 .52143 Mdot
.6827 .0429 Mdot
.68282 .53144 Mdot
.68295 .45364 Mdot
.68307 .28486 Mdot
.68319 .52638 Mdot
.68331 .29247 Mdot
.68343 .05091 Mdot
.68355 .51659 Mdot
.68367 .04701 Mdot
.68379 .52957 Mdot
.68391 .48201 Mdot
.68403 .27039 Mdot
.68415 .51389 Mdot
.68428 .59232 Mdot
.6844 .12058 Mdot
.68452 .47404 Mdot
.68464 .42648 Mdot
.68476 .37383 Mdot
.68488 .4503 Mdot
.685 .29518 Mdot
.68512 .47512 Mdot
.68524 .07607 Mdot
.68536 .51857 Mdot
.68548 .0587 Mdot
.6856 .50776 Mdot
.68573 .08006 Mdot
.68585 .51729 Mdot
.68597 .07431 Mdot
.68609 .52516 Mdot
.68621 .13006 Mdot
.68633 .50374 Mdot
.68645 .14957 Mdot
.68657 .29015 Mdot
.68669 .46903 Mdot
.68681 .02257 Mdot
.68693 .54428 Mdot
.68706 .34649 Mdot
.68718 .45698 Mdot
.6873 .28282 Mdot
.68742 .53113 Mdot
.68754 .30775 Mdot
.68766 .16139 Mdot
.68778 .43408 Mdot
.6879 .40118 Mdot
.68802 .42678 Mdot
.68814 .38464 Mdot
.68826 .44298 Mdot
.68839 .33166 Mdot
.68851 .46713 Mdot
.68863 .16109 Mdot
.68875 .49704 Mdot
.68887 .08654 Mdot
.68899 .54985 Mdot
.68911 .02146 Mdot
.68923 .54575 Mdot
.68935 .34306 Mdot
.68947 .46976 Mdot
.68959 .27563 Mdot
.68971 .53607 Mdot
.68984 .3986 Mdot
.68996 .333 Mdot
.69008 .43624 Mdot
.6902 .29882 Mdot
.69032 .50477 Mdot
.69044 .27002 Mdot
.69056 .19413 Mdot
.69068 .40264 Mdot
.6908 .43784 Mdot
.69092 .34915 Mdot
.69104 .46164 Mdot
.69117 .21391 Mdot
.69129 .48782 Mdot
.69141 .02424 Mdot
.69153 .55533 Mdot
.69165 .33921 Mdot
.69177 .50236 Mdot
.69189 .2696 Mdot
.69201 .24027 Mdot
.69213 .33608 Mdot
.69225 .4674 Mdot
.69237 .14979 Mdot
.69249 .49933 Mdot
.69262 .10829 Mdot
.69274 .52185 Mdot
.69286 .32946 Mdot
.69298 .46713 Mdot
.6931 .16416 Mdot
.69322 .49644 Mdot
.69334 .08106 Mdot
.69346 .5533 Mdot
.69358 .04485 Mdot
.6937 .55994 Mdot
.69382 .371 Mdot
.69395 .39303 Mdot
.69407 .34784 Mdot
.69419 .41993 Mdot
.69431 .31493 Mdot
.69443 .47747 Mdot
.69455 .2723 Mdot
.69467 .5263 Mdot
.69479 .53063 Mdot
.69491 .34081 Mdot
.69503 .531 Mdot
.69515 .30999 Mdot
.69527 .20283 Mdot
.6954 .39062 Mdot
.69552 .44632 Mdot
.69564 .31255 Mdot
.69576 .47173 Mdot
.69588 .11177 Mdot
.696 .50816 Mdot
.69612 .19155 Mdot
.69624 .1067 Mdot
.69636 .52592 Mdot
.69648 .31316 Mdot
.6966 .47125 Mdot
.69673 .12052 Mdot
.69685 .50595 Mdot
.69697 .17199 Mdot
.69709 .03777 Mdot
.69721 .53166 Mdot
.69733 .3815 Mdot
.69745 .37235 Mdot
.69757 .3784 Mdot
.69769 .36951 Mdot
.69781 .38344 Mdot
.69793 .36189 Mdot
.69806 .39593 Mdot
.69818 .34418 Mdot
.6983 .42627 Mdot
.69842 .3083 Mdot
.69854 .4888 Mdot
.69866 .26928 Mdot
.69878 .46375 Mdot
.6989 .3509 Mdot
.69902 .44202 Mdot
.69914 .29381 Mdot
.69926 .51346 Mdot
.69938 .27441 Mdot
.69951 .06775 Mdot
.69963 .50005 Mdot
.69975 .13007 Mdot
.69987 .5037 Mdot
.69999 .15003 Mdot
.70011 .28515 Mdot
.70023 .46954 Mdot
.70035 .02148 Mdot
.70047 .54559 Mdot
.70059 .34302 Mdot
.70071 .46993 Mdot
.70084 .27555 Mdot
.70096 .53599 Mdot
.70108 .4007 Mdot
.7012 .32837 Mdot
.70132 .44315 Mdot
.70144 .29291 Mdot
.70156 .51469 Mdot
.70168 .27538 Mdot
.7018 .06031 Mdot
.70192 .50578 Mdot
.70204 .09515 Mdot
.70216 .51272 Mdot
.70229 .2177 Mdot
.70241 .31044 Mdot
.70253 .13343 Mdot
.70265 .5027 Mdot
.70277 .14586 Mdot
.70289 .32839 Mdot
.70301 .4658 Mdot
.70313 .0391 Mdot
.70325 .53326 Mdot
.70337 .42775 Mdot
.70349 .30745 Mdot
.70362 .4887 Mdot
.70374 .26929 Mdot
.70386 .46476 Mdot
.70398 .34779 Mdot
.7041 .45164 Mdot
.70422 .28644 Mdot
.70434 .52564 Mdot
.70446 .29077 Mdot
.70458 .05028 Mdot
.7047 .51869 Mdot
.70482 .04153 Mdot
.70495 .53209 Mdot
.70507 .44439 Mdot
.70519 .29193 Mdot
.70531 .51471 Mdot
.70543 .27539 Mdot
.70555 .06024 Mdot
.70567 .50584 Mdot
.70579 .09481 Mdot
.70591 .51282 Mdot
.70603 .21758 Mdot
.70615 .22903 Mdot
.70627 .34525 Mdot
.7064 .4651 Mdot
.70652 .17342 Mdot
.70664 .49469 Mdot
.70676 .06581 Mdot
.70688 .55873 Mdot
.707 .14167 Mdot
.70712 .40226 Mdot
.70724 .46044 Mdot
.70736 .14173 Mdot
.70748 .50103 Mdot
.7076 .12519 Mdot
.70773 .46983 Mdot
.70785 .44124 Mdot
.70797 .3104 Mdot
.70809 .47221 Mdot
.70821 .10642 Mdot
.70833 .50957 Mdot
.70845 .20299 Mdot
.70857 .22316 Mdot
.70869 .40481 Mdot
.70881 .32994 Mdot
.70893 .45242 Mdot
.70905 .28588 Mdot
.70918 .52632 Mdot
.7093 .29233 Mdot
.70942 .05082 Mdot
.70954 .51679 Mdot
.70966 .04641 Mdot
.70978 .52983 Mdot
.7099 .47786 Mdot
.71002 .27176 Mdot
.71014 .52724 Mdot
.71026 .52174 Mdot
.71038 .31027 Mdot
.71051 .15319 Mdot
.71063 .44092 Mdot
.71075 .38867 Mdot
.71087 .43919 Mdot
.71099 .34707 Mdot
.71111 .46237 Mdot
.71123 .20741 Mdot
.71135 .48885 Mdot
.71147 .02798 Mdot
.71159 .55695 Mdot
.71171 .33857 Mdot
.71183 .50021 Mdot
.71196 .26921 Mdot
.71208 .28512 Mdot
.7122 .23317 Mdot
.71232 .48465 Mdot
.71244 .01993 Mdot
.71256 .55053 Mdot
.71268 .33835 Mdot
.7128 .49852 Mdot
.71292 .26901 Mdot
.71304 .31888 Mdot
.71316 .12659 Mdot
.71329 .50431 Mdot
.71341 .16083 Mdot
.71353 .15521 Mdot
.71365 .49136 Mdot
.71377 .12658 Mdot
.71389 .46357 Mdot
.71401 .44495 Mdot
.71413 .28761 Mdot
.71425 .47646 Mdot
.71437 .06295 Mdot
.71449 .52314 Mdot
.71462 .50543 Mdot
.71474 .56164 Mdot
.71486 .55282 Mdot
.71498 .49041 Mdot
.7151 .26051 Mdot
.71522 .05429 Mdot
.71534 .51159 Mdot
.71546 .0648 Mdot
.71558 .52249 Mdot
.7157 .46537 Mdot
.71582 .3561 Mdot
.71594 .42751 Mdot
.71607 .30698 Mdot
.71619 .49121 Mdot
.71631 .26896 Mdot
.71643 .43775 Mdot
.71655 .53468 Mdot
.71667 .45248 Mdot
.71679 .26172 Mdot
.71691 .53501 Mdot
.71703 .33193 Mdot
.71715 .52865 Mdot
.71727 .49523 Mdot
.7174 .26372 Mdot
.71752 .05502 Mdot
.71764 .52552 Mdot
.71776 .04039 Mdot
.71788 .53265 Mdot
.718 .437 Mdot
.71812 .29837 Mdot
.71824 .50392 Mdot
.71836 .26977 Mdot
.71848 .21157 Mdot
.7186 .38103 Mdot
.71872 .45163 Mdot
.71885 .28282 Mdot
.71897 .47725 Mdot
.71909 .05602 Mdot
.71921 .52579 Mdot
.71933 .53448 Mdot
.71945 .32032 Mdot
.71957 .4092 Mdot
.71969 .18565 Mdot
.71981 .04723 Mdot
.71993 .56242 Mdot
.72005 .34981 Mdot
.72018 .44641 Mdot
.7203 .29032 Mdot
.72042 .51931 Mdot
.72054 .28014 Mdot
.72066 .05023 Mdot
.72078 .51886 Mdot
.7209 .04082 Mdot
.72102 .53243 Mdot
.72114 .43972 Mdot
.72126 .29592 Mdot
.72138 .50802 Mdot
.72151 .27121 Mdot
.72163 .13341 Mdot
.72175 .45689 Mdot
.72187 .34863 Mdot
.72199 .4616 Mdot
.72211 .21483 Mdot
.72223 .48768 Mdot
.72235 .02381 Mdot
.72247 .55509 Mdot
.72259 .33925 Mdot
.72271 .50243 Mdot
.72283 .26962 Mdot
.72296 .23882 Mdot
.72308 .33869 Mdot
.7232 .46676 Mdot
.72332 .15659 Mdot
.72344 .49793 Mdot
.72356 .09493 Mdot
.72368 .5423 Mdot
.7238 .11762 Mdot
.72392 .50675 Mdot
.72404 .17731 Mdot
.72416 .0153 Mdot
.72429 .54861 Mdot
.72441 .34984 Mdot
.72453 .48503 Mdot
.72465 .27018 Mdot
.72477 .49213 Mdot
.72489 .44511 Mdot
.72501 .27166 Mdot
.72513 .52144 Mdot
.72525 .28292 Mdot
.72537 .05037 Mdot
.72549 .52117 Mdot
.72561 .03713 Mdot
.72574 .5343 Mdot
.72586 .41659 Mdot
.72598 .31998 Mdot
.7261 .46738 Mdot
.72622 .27675 Mdot
.72634 .53656 Mdot
.72646 .37133 Mdot
.72658 .4126 Mdot
.7267 .32248 Mdot
.72682 .46486 Mdot
.72694 .27809 Mdot
.72707 .53613 Mdot
.72719 .3501 Mdot
.72731 .49893 Mdot
.72743 .26919 Mdot
.72755 .30765 Mdot
.72767 .16398 Mdot
.72779 .49625 Mdot
.72791 .08432 Mdot
.72803 .55137 Mdot
.72815 .02173 Mdot
.72827 .55346 Mdot
.72839 .33897 Mdot
.72852 .50208 Mdot
.72864 .26954 Mdot
.72876 .24606 Mdot
.72888 .32528 Mdot
.729 .46986 Mdot
.72912 .1233 Mdot
.72924 .50527 Mdot
.72936 .16576 Mdot
.72948 .0962 Mdot
.7296 .50814 Mdot
.72972 .15571 Mdot
.72985 .31755 Mdot
.72997 .46814 Mdot
.73009 .03482 Mdot
.73021 .53552 Mdot
.73033 .40234 Mdot
.73045 .33867 Mdot
.73057 .43494 Mdot
.73069 .29999 Mdot
.73081 .50287 Mdot
.73093 .26951 Mdot
.73105 .23351 Mdot
.73118 .34791 Mdot
.7313 .46429 Mdot
.73142 .18182 Mdot
.73154 .49316 Mdot
.73166 .0537 Mdot
.73178 .56012 Mdot
.7319 .45924 Mdot
.73202 .28112 Mdot
.73214 .532 Mdot
.73226 .31174 Mdot
.73238 .2366 Mdot
.7325 .33989 Mdot
.73263 .46647 Mdot
.73275 .15956 Mdot
.73287 .49734 Mdot
.73299 .08936 Mdot
.73311 .54765 Mdot
.73323 .03925 Mdot
.73335 .53322 Mdot
.73347 .4302 Mdot
.73359 .30494 Mdot
.73371 .49292 Mdot
.73383 .26881 Mdot
.73396 .41567 Mdot
.73408 .2082 Mdot
.7342 .0762 Mdot
.73432 .52303 Mdot
.73444 .15656 Mdot
.73456 .49802 Mdot
.73468 .09388 Mdot
.7348 .54342 Mdot
.73492 .10003 Mdot
.73504 .51138 Mdot
.73516 .21377 Mdot
.73528 .41452 Mdot
.73541 .21652 Mdot
.73553 .09 Mdot
.73565 .51554 Mdot
.73577 .26508 Mdot
.73589 .48006 Mdot
.73601 .03675 Mdot
.73613 .53448 Mdot
.73625 .41365 Mdot
.73637 .32358 Mdot
.73649 .46118 Mdot
.73661 .28019 Mdot
.73674 .5343 Mdot
.73686 .32638 Mdot
.73698 .49277 Mdot
.7371 .46832 Mdot
.73722 .25786 Mdot
.73734 .5233 Mdot
.73746 .55683 Mdot
.73758 .52514 Mdot
.7377 .32329 Mdot
.73782 .43731 Mdot
.73794 .53731 Mdot
.73807 .35181 Mdot
.73819 .49184 Mdot
.73831 .26916 Mdot
.73843 .42526 Mdot
.73855 .12942 Mdot
.73867 .45008 Mdot
.73879 .44637 Mdot
.73891 .28471 Mdot
.73903 .47694 Mdot
.73915 .05857 Mdot
.73927 .52479 Mdot
.73939 .53752 Mdot
.73952 .39562 Mdot
.73964 .33985 Mdot
.73976 .42579 Mdot
.73988 .30882 Mdot
.74 .48788 Mdot
.74012 .26943 Mdot
.74024 .47226 Mdot
.74036 .33749 Mdot
.74048 .50172 Mdot
.7406 .26946 Mdot
.74072 .25379 Mdot
.74085 .30981 Mdot
.74097 .47289 Mdot
.74109 .09049 Mdot
.74121 .51406 Mdot
.74133 .20739 Mdot
.74145 .13259 Mdot
.74157 .42464 Mdot
.74169 .45726 Mdot
.74181 .16535 Mdot
.74193 .4962 Mdot
.74205 .07918 Mdot
.74217 .55427 Mdot
.7423 .06825 Mdot
.74242 .55815 Mdot
.74254 .21762 Mdot
.74266 .43381 Mdot
.74278 .53682 Mdot
.7429 .34288 Mdot
.74302 .52499 Mdot
.74314 .29062 Mdot
.74326 .05032 Mdot
.74338 .51845 Mdot
.7435 .04205 Mdot
.74363 .53184 Mdot
.74375 .44785 Mdot
.74387 .28915 Mdot
.74399 .51934 Mdot
.74411 .28017 Mdot
.74423 .05023 Mdot
.74435 .51891 Mdot
.74447 .04072 Mdot
.74459 .53248 Mdot
.74471 .43906 Mdot
.74483 .29651 Mdot
.74495 .50704 Mdot
.74508 .2708 Mdot
.7452 .15051 Mdot
.74532 .44402 Mdot
.74544 .38194 Mdot
.74556 .44445 Mdot
.74568 .32538 Mdot
.7458 .46877 Mdot
.74592 .14381 Mdot
.74604 .50059 Mdot
.74616 .12061 Mdot
.74628 .48795 Mdot
.74641 .42471 Mdot
.74653 .37656 Mdot
.74665 .44867 Mdot
.74677 .30422 Mdot
.74689 .47343 Mdot
.74701 .09356 Mdot
.74713 .51315 Mdot
.74725 .21628 Mdot
.74737 .11424 Mdot
.74749 .48589 Mdot
.74761 .40678 Mdot
.74774 .41554 Mdot
.74786 .40785 Mdot
.74798 .41927 Mdot
.7481 .40077 Mdot
.74822 .42809 Mdot
.74834 .38128 Mdot
.74846 .44542 Mdot
.74858 .32067 Mdot
.7487 .46991 Mdot
.74882 .13155 Mdot
.74894 .50333 Mdot
.74906 .14725 Mdot
.74919 .31454 Mdot
.74931 .46686 Mdot
.74943 .03146 Mdot
.74955 .53745 Mdot
.74967 .38446 Mdot
.74979 .36707 Mdot
.74991 .38682 Mdot
.75003 .35695 Mdot
.75015 .40423 Mdot
.75027 .33333 Mdot
.75039 .44533 Mdot
.75052 .29117 Mdot
.75064 .51767 Mdot
.75076 .27823 Mdot
.75088 .05138 Mdot
.751 .5156 Mdot
.75112 .04961 Mdot
.75124 .52844 Mdot
.75136 .50005 Mdot
.75148 .26846 Mdot
.7516 .30287 Mdot
.75172 .17955 Mdot
.75184 .49333 Mdot
.75197 .05959 Mdot
.75209 .55969 Mdot
.75221 .53344 Mdot
.75233 .47128 Mdot
.75245 .2554 Mdot
.75257 .46497 Mdot
.75269 .34794 Mdot
.75281 .45116 Mdot
.75293 .28678 Mdot
.75305 .52509 Mdot
.75317 .28958 Mdot
.7533 .0502 Mdot
.75342 .51978 Mdot
.75354 .03935 Mdot
.75366 .53316 Mdot
.75378 .43025 Mdot
.7539 .30489 Mdot
.75402 .49301 Mdot
.75414 .2688 Mdot
.75426 .41448 Mdot
.75438 .20292 Mdot
.7545 .22321 Mdot
.75463 .40466 Mdot
.75475 .33011 Mdot
.75487 .45211 Mdot
.75499 .2861 Mdot
.75511 .52597 Mdot
.75523 .29152 Mdot
.75535 .05046 Mdot
.75547 .51785 Mdot
.75559 .04354 Mdot
.75571 .53114 Mdot
.75583 .45787 Mdot
.75595 .28199 Mdot
.75608 .53078 Mdot
.7562 .30621 Mdot
.75632 .13719 Mdot
.75644 .4535 Mdot
.75656 .35886 Mdot
.75668 .45749 Mdot
.7568 .24826 Mdot
.75692 .4826 Mdot
.75704 .02357 Mdot
.75716 .54327 Mdot
.75728 .35002 Mdot
.75741 .44549 Mdot
.75753 .29103 Mdot
.75765 .51812 Mdot
.75777 .27873 Mdot
.75789 .05088 Mdot
.75801 .51663 Mdot
.75813 .04642 Mdot
.75825 .52983 Mdot
.75837 .47793 Mdot
.75849 .27173 Mdot
.75861 .52708 Mdot
.75873 .52326 Mdot
.75886 .31479 Mdot
.75898 .25382 Mdot
.7591 .30606 Mdot
.75922 .47357 Mdot
.75934 .08332 Mdot
.75946 .51624 Mdot
.75958 .12866 Mdot
.7597 .45245 Mdot
.75982 .44505 Mdot
.75994 .29341 Mdot
.76006 .47545 Mdot
.76019 .0726 Mdot
.76031 .51973 Mdot
.76043 .15722 Mdot
.76055 .44122 Mdot
.76067 .38713 Mdot
.76079 .44049 Mdot
.76091 .3421 Mdot
.76103 .46404 Mdot
.76115 .19194 Mdot
.76127 .49141 Mdot
.76139 .04147 Mdot
.76151 .5597 Mdot
.76164 .35486 Mdot
.76176 .43161 Mdot
.76188 .30302 Mdot
.762 .49794 Mdot
.76212 .2688 Mdot
.76224 .33323 Mdot
.76236 .07973 Mdot
.76248 .51728 Mdot
.7626 .05869 Mdot
.76272 .52708 Mdot
.76284 .04581 Mdot
.76297 .53011 Mdot
.76309 .47388 Mdot
.76321 .27334 Mdot
.76333 .53385 Mdot
.76345 .44202 Mdot
.76357 .2691 Mdot
.76369 .52216 Mdot
.76381 .284 Mdot
.76393 .05049 Mdot
.76405 .5215 Mdot
.76417 .03683 Mdot
.7643 .53446 Mdot
.76442 .41478 Mdot
.76454 .32218 Mdot
.76466 .46361 Mdot
.76478 .27878 Mdot
.7649 .53565 Mdot
.76502 .34115 Mdot
.76514 .52953 Mdot
.76526 .30372 Mdot
.76538 .1059 Mdot
.7655 .47494 Mdot
.76562 .27911 Mdot
.76575 .47784 Mdot
.76587 .05179 Mdot
.76599 .5275 Mdot
.76611 .51351 Mdot
.76623 .27359 Mdot
.76635 .07068 Mdot
.76647 .49798 Mdot
.76659 .1433 Mdot
.76671 .50074 Mdot
.76683 .12114 Mdot
.76695 .48604 Mdot
.76708 .42701 Mdot
.7672 .36979 Mdot
.76732 .45259 Mdot
.76744 .28148 Mdot
.76756 .47747 Mdot
.76768 .05415 Mdot
.7678 .52654 Mdot
.76792 .52681 Mdot
.76804 .29139 Mdot
.76816 .05029 Mdot
.76828 .51862 Mdot
.7684 .04171 Mdot
.76853 .532 Mdot
.76865 .44556 Mdot
.76877 .29098 Mdot
.76889 .5163 Mdot
.76901 .27683 Mdot
.76913 .0541 Mdot
.76925 .51176 Mdot
.76937 .06444 Mdot
.76949 .52261 Mdot
.76961 .47385 Mdot
.76973 .33766 Mdot
.76986 .49632 Mdot
.76998 .26888 Mdot
.7701 .35963 Mdot
.77022 .02181 Mdot
.77034 .54502 Mdot
.77046 .34383 Mdot
.77058 .46668 Mdot
.7707 .27717 Mdot
.77082 .53653 Mdot
.77094 .36658 Mdot
.77106 .43055 Mdot
.77119 .30383 Mdot
.77131 .49703 Mdot
.77143 .26876 Mdot
.77155 .35008 Mdot
.77167 .03541 Mdot
.77179 .53514 Mdot
.77191 .40408 Mdot
.77203 .33622 Mdot
.77215 .43921 Mdot
.77227 .29621 Mdot
.77239 .50922 Mdot
.77251 .27178 Mdot
.77264 .11437 Mdot
.77276 .46986 Mdot
.77288 .30152 Mdot
.773 .47389 Mdot
.77312 .08952 Mdot
.77324 .51435 Mdot
.77336 .20219 Mdot
.77348 .06585 Mdot
.7736 .56095 Mdot
.77372 .23402 Mdot
.77384 .3538 Mdot
.77397 .46246 Mdot
.77409 .19949 Mdot
.77421 .49014 Mdot
.77433 .0341 Mdot
.77445 .55859 Mdot
.77457 .34001 Mdot
.77469 .48427 Mdot
.77481 .2703 Mdot
.77493 .49771 Mdot
.77505 .50853 Mdot
.77517 .27469 Mdot
.77529 .09813 Mdot
.77542 .50916 Mdot
.77554 .32068 Mdot
.77566 .46956 Mdot
.77578 .13805 Mdot
.7759 .50186 Mdot
.77602 .13296 Mdot
.77614 .42957 Mdot
.77626 .45629 Mdot
.77638 .18096 Mdot
.7765 .49331 Mdot
.77662 .055 Mdot
.77675 .56006 Mdot
.77687 .48081 Mdot
.77699 .27075 Mdot
.77711 .51862 Mdot
.77723 .58171 Mdot
.77735 .34922 Mdot
.77747 .48582 Mdot
.77759 .27 Mdot
.77771 .48666 Mdot
.77783 .39356 Mdot
.77795 .35464 Mdot
.77807 .40362 Mdot
.7782 .33416 Mdot
.77832 .44384 Mdot
.77844 .29235 Mdot
.77856 .5157 Mdot
.77868 .27627 Mdot
.7788 .05599 Mdot
.77892 .50973 Mdot
.77904 .07401 Mdot
.77916 .51928 Mdot
.77928 .10005 Mdot
.7794 .48035 Mdot
.77953 .24841 Mdot
.77965 .4826 Mdot
.77977 .02389 Mdot
.77989 .54297 Mdot
.78001 .3512 Mdot
.78013 .44192 Mdot
.78025 .2939 Mdot
.78037 .51332 Mdot
.78049 .27431 Mdot
.78061 .06872 Mdot
.78073 .49935 Mdot
.78086 .13452 Mdot
.78098 .50268 Mdot
.7811 .14014 Mdot
.78122 .37919 Mdot
.78134 .46227 Mdot
.78146 .08603 Mdot
.78158 .51539 Mdot
.7817 .16928 Mdot
.78182 .19833 Mdot
.78194 .48308 Mdot
.78206 .05737 Mdot
.78218 .55991 Mdot
.78231 .52199 Mdot
.78243 .28248 Mdot
.78255 .05057 Mdot
.78267 .52174 Mdot
.78279 .03658 Mdot
.78291 .53459 Mdot
.78303 .4133 Mdot
.78315 .32401 Mdot
.78327 .46043 Mdot
.78339 .28064 Mdot
.78351 .53379 Mdot
.78364 .32243 Mdot
.78376 .44395 Mdot
.78388 .47857 Mdot
.784 .27152 Mdot
.78412 .52545 Mdot
.78424 .53836 Mdot
.78436 .37693 Mdot
.78448 .39163 Mdot
.7846 .34844 Mdot
.78472 .41913 Mdot
.78484 .3158 Mdot
.78496 .47596 Mdot
.78509 .27287 Mdot
.78521 .52956 Mdot
.78533 .49718 Mdot
.78545 .26551 Mdot
.78557 .06482 Mdot
.78569 .52649 Mdot
.78581 .07547 Mdot
.78593 .5188 Mdot
.78605 .06372 Mdot
.78617 .50375 Mdot
.78629 .10306 Mdot
.78642 .5105 Mdot
.78654 .20917 Mdot
.78666 .05081 Mdot
.78678 .52006 Mdot
.7869 .04427 Mdot
.78702 .5308 Mdot
.78714 .46297 Mdot
.78726 .27886 Mdot
.78738 .53479 Mdot
.7875 .33076 Mdot
.78762 .52396 Mdot
.78775 .5409 Mdot
.78787 .39129 Mdot
.78799 .34916 Mdot
.78811 .41124 Mdot
.78823 .32482 Mdot
.78835 .46026 Mdot
.78847 .28074 Mdot
.78859 .53367 Mdot
.78871 .32155 Mdot
.78883 .43042 Mdot
.78895 .28232 Mdot
.78907 .25173 Mdot
.7892 .48194 Mdot
.78932 .02324 Mdot
.78944 .54359 Mdot
.78956 .34886 Mdot
.78968 .44913 Mdot
.7898 .28826 Mdot
.78992 .5227 Mdot
.79004 .28506 Mdot
.79016 .0505 Mdot
.79028 .52152 Mdot
.7904 .03685 Mdot
.79053 .53444 Mdot
.79065 .41491 Mdot
.79077 .32202 Mdot
.79089 .46387 Mdot
.79101 .27863 Mdot
.79113 .53576 Mdot
.79125 .34295 Mdot
.79137 .52477 Mdot
.79149 .29014 Mdot
.79161 .05025 Mdot
.79173 .51891 Mdot
.79185 .04104 Mdot
.79198 .53233 Mdot
.7921 .44115 Mdot
.79222 .29467 Mdot
.79234 .51012 Mdot
.79246 .27225 Mdot
.79258 .10174 Mdot
.7927 .47797 Mdot
.79282 .26345 Mdot
.79294 .48032 Mdot
.79306 .03419 Mdot
.79318 .53587 Mdot
.79331 .39905 Mdot
.79343 .34346 Mdot
.79355 .42661 Mdot
.79367 .30796 Mdot
.79379 .48939 Mdot
.79391 .26919 Mdot
.79403 .45796 Mdot
.79415 .37639 Mdot
.79427 .3818 Mdot
.79439 .36394 Mdot
.79451 .39256 Mdot
.79463 .34879 Mdot
.79476 .41823 Mdot
.79488 .31679 Mdot
.795 .47425 Mdot
.79512 .27356 Mdot
.79524 .53235 Mdot
.79536 .46327 Mdot
.79548 .25696 Mdot
.7956 .52676 Mdot
.79572 .528 Mdot
.79584 .33068 Mdot
.79596 .51958 Mdot
.79609 .57105 Mdot
.79621 .60244 Mdot
.79633 .22513 Mdot
.79645 .48629 Mdot
.79657 .01995 Mdot
.79669 .55064 Mdot
.79681 .33836 Mdot
.79693 .49879 Mdot
.79705 .26903 Mdot
.79717 .31365 Mdot
.79729 .14412 Mdot
.79742 .50033 Mdot
.79754 .12281 Mdot
.79766 .47969 Mdot
.79778 .43356 Mdot
.7979 .34676 Mdot
.79802 .46254 Mdot
.79814 .20569 Mdot
.79826 .48913 Mdot
.79838 .02917 Mdot
.7985 .55734 Mdot
.79862 .33846 Mdot
.79874 .49862 Mdot
.79887 .26902 Mdot
.79899 .31687 Mdot
.79911 .13333 Mdot
.79923 .50273 Mdot
.79935 .14595 Mdot
.79947 .32751 Mdot
.79959 .46586 Mdot
.79971 .03856 Mdot
.79983 .53353 Mdot
.79995 .4244 Mdot
.80007 .31102 Mdot
.8002 .48267 Mdot
.80032 .27062 Mdot
.80044 .50756 Mdot
.80056 .58606 Mdot
.80068 .35485 Mdot
.8008 .43237 Mdot
.80092 .3023 Mdot
.80104 .49916 Mdot
.80116 .26891 Mdot
.80128 .30974 Mdot
.8014 .15711 Mdot
.80152 .49761 Mdot
.80165 .09688 Mdot
.80177 .54006 Mdot
.80189 .15186 Mdot
.80201 .49899 Mdot
.80213 .10264 Mdot
.80225 .53207 Mdot
.80237 .25112 Mdot
.80249 .48222 Mdot
.80261 .02606 Mdot
.80273 .54113 Mdot
.80285 .35971 Mdot
.80298 .41873 Mdot
.8031 .31611 Mdot
.80322 .47556 Mdot
.80334 .27303 Mdot
.80346 .5303 Mdot
.80358 .48876 Mdot
.8037 .25917 Mdot
.80382 .07561 Mdot
.80394 .49472 Mdot
.80406 .16406 Mdot
.80418 .4965 Mdot
.8043 .08071 Mdot
.80443 .55349 Mdot
.80455 .0488 Mdot
.80467 .56011 Mdot
.80479 .40007 Mdot
.80491 .34198 Mdot
.80503 .42917 Mdot
.80515 .30542 Mdot
.80527 .49368 Mdot
.80539 .26877 Mdot
.80551 .40484 Mdot
.80563 .15281 Mdot
.80576 .25317 Mdot
.80588 .47326 Mdot
.806 .02133 Mdot
.80612 .5532 Mdot
.80624 .33907 Mdot
.80636 .50228 Mdot
.80648 .26958 Mdot
.8066 .2419 Mdot
.80672 .33311 Mdot
.80684 .46811 Mdot
.80696 .14221 Mdot
.80709 .50094 Mdot
.80721 .12403 Mdot
.80733 .47474 Mdot
.80745 .43774 Mdot
.80757 .32853 Mdot
.80769 .46801 Mdot
.80781 .15172 Mdot
.80793 .49893 Mdot
.80805 .1044 Mdot
.80817 .52916 Mdot
.80829 .27807 Mdot
.80841 .47797 Mdot
.80854 .05276 Mdot
.80866 .5271 Mdot
.80878 .51936 Mdot
.8089 .27902 Mdot
.80902 .05028 Mdot
.80914 .51854 Mdot
.80926 .04148 Mdot
.80938 .53211 Mdot
.8095 .44405 Mdot
.80962 .29221 Mdot
.80974 .51423 Mdot
.80987 .275 Mdot
.80999 .0628 Mdot
.81011 .50376 Mdot
.81023 .10704 Mdot
.81035 .50943 Mdot
.81047 .20129 Mdot
.81059 .21091 Mdot
.81071 .53437 Mdot
.81083 .36309 Mdot
.81095 .44448 Mdot
.81107 .29179 Mdot
.81119 .51735 Mdot
.81132 .27789 Mdot
.81144 .05185 Mdot
.81156 .51479 Mdot
.81168 .05237 Mdot
.8118 .52728 Mdot
.81192 .51782 Mdot
.81204 .27732 Mdot
.81216 .05165 Mdot
.81228 .51513 Mdot
.8124 .05118 Mdot
.81252 .52777 Mdot
.81265 .51048 Mdot
.81277 .2717 Mdot
.81289 .10319 Mdot
.81301 .47706 Mdot
.81313 .26806 Mdot
.81325 .4796 Mdot
.81337 .03864 Mdot
.81349 .5335 Mdot
.81361 .42513 Mdot
.81373 .31024 Mdot
.81385 .48399 Mdot
.81398 .27027 Mdot
.8141 .50045 Mdot
.81422 .5382 Mdot
.81434 .35973 Mdot
.81446 .45767 Mdot
.81458 .28243 Mdot
.8147 .53207 Mdot
.81482 .3121 Mdot
.81494 .24394 Mdot
.81506 .32634 Mdot
.81518 .46964 Mdot
.8153 .1256 Mdot
.81543 .50472 Mdot
.81555 .16059 Mdot
.81567 .15826 Mdot
.81579 .49063 Mdot
.81591 .1206 Mdot
.81603 .48798 Mdot
.81615 .42468 Mdot
.81627 .37665 Mdot
.81639 .44861 Mdot
.81651 .30451 Mdot
.81663 .47337 Mdot
.81676 .09417 Mdot
.81688 .51298 Mdot
.817 .217 Mdot
.81712 .05329 Mdot
.81724 .51229 Mdot
.81736 .0676 Mdot
.81748 .52148 Mdot
.8176 .37382 Mdot
.81772 .02197 Mdot
.81784 .55396 Mdot
.81796 .33951 Mdot
.81808 .50271 Mdot
.81821 .26968 Mdot
.81833 .23292 Mdot
.81845 .34888 Mdot
.81857 .464 Mdot
.81869 .18459 Mdot
.81881 .49268 Mdot
.81893 .0501 Mdot
.81905 .56017 Mdot
.81917 .41208 Mdot
.81929 .32558 Mdot
.81941 .45772 Mdot
.81954 .28232 Mdot
.81966 .53162 Mdot
.81978 .30992 Mdot
.8199 .2005 Mdot
.82002 .39351 Mdot
.82014 .44449 Mdot
.82026 .32149 Mdot
.82038 .46973 Mdot
.8205 .13356 Mdot
.82062 .50287 Mdot
.82074 .1428 Mdot
.82086 .35677 Mdot
.82099 .46384 Mdot
.82111 .06112 Mdot
.82123 .52382 Mdot
.82135 .52691 Mdot
.82147 .54253 Mdot
.82159 .40146 Mdot
.82171 .32537 Mdot
.82183 .44738 Mdot
.82195 .28958 Mdot
.82207 .52023 Mdot
.82219 .28133 Mdot
.82232 .05018 Mdot
.82244 .5201 Mdot
.82256 .03854 Mdot
.82268 .53357 Mdot
.8228 .42515 Mdot
.82292 .31022 Mdot
.82304 .48403 Mdot
.82316 .27026 Mdot
.82328 .50021 Mdot
.8234 .53581 Mdot
.82352 .34858 Mdot
.82365 .50533 Mdot
.82377 .27058 Mdot
.82389 .1766 Mdot
.82401 .4211 Mdot
.82413 .41961 Mdot
.82425 .39867 Mdot
.82437 .43042 Mdot
.82449 .3751 Mdot
.82461 .44943 Mdot
.82473 .30014 Mdot
.82485 .47421 Mdot
.82497 .08537 Mdot
.8251 .51561 Mdot
.82522 .16117 Mdot
.82534 .27393 Mdot
.82546 .47218 Mdot
.82558 .02011 Mdot
.8257 .54815 Mdot
.82582 .33916 Mdot
.82594 .48888 Mdot
.82606 .26938 Mdot
.82618 .46126 Mdot
.8263 .36023 Mdot
.82643 .41695 Mdot
.82655 .31807 Mdot
.82667 .47215 Mdot
.82679 .27446 Mdot
.82691 .53469 Mdot
.82703 .42824 Mdot
.82715 .28304 Mdot
.82727 .502 Mdot
.82739 .26927 Mdot
.82751 .25278 Mdot
.82763 .31191 Mdot
.82775 .47251 Mdot
.82788 .09456 Mdot
.828 .51286 Mdot
.82812 .21733 Mdot
.82824 .11423 Mdot
.82836 .4676 Mdot
.82848 .31325 Mdot
.8286 .4715 Mdot
.82872 .11523 Mdot
.82884 .50727 Mdot
.82896 .18388 Mdot
.82908 .03358 Mdot
.82921 .56111 Mdot
.82933 .34746 Mdot
.82945 .4909 Mdot
.82957 .26917 Mdot
.82969 .43838 Mdot
.82981 .53742 Mdot
.82993 .3977 Mdot
.83005 .33501 Mdot
.83017 .43319 Mdot
.83029 .30161 Mdot
.83041 .50009 Mdot
.83054 .26902 Mdot
.83066 .29118 Mdot
.83078 .21563 Mdot
.8309 .4873 Mdot
.83102 .02486 Mdot
.83114 .55566 Mdot
.83126 .33912 Mdot
.83138 .50221 Mdot
.8315 .26957 Mdot
.83162 .24329 Mdot
.83174 .33053 Mdot
.83186 .46871 Mdot
.83199 .13582 Mdot
.83211 .50235 Mdot
.83223 .13785 Mdot
.83235 .39682 Mdot
.83247 .46079 Mdot
.83259 .11197 Mdot
.83271 .5081 Mdot
.83283 .19126 Mdot
.83295 .10338 Mdot
.83307 .53218 Mdot
.83319 .2637 Mdot
.83332 .48028 Mdot
.83344 .0359 Mdot
.83356 .53493 Mdot
.83368 .40871 Mdot
.8338 .32993 Mdot
.83392 .45017 Mdot
.83404 .28749 Mdot
.83416 .52372 Mdot
.83428 .28687 Mdot
.8344 .05042 Mdot
.83452 .52125 Mdot
.83464 .03718 Mdot
.83477 .53427 Mdot
.83489 .41688 Mdot
.83501 .31963 Mdot
.83513 .46799 Mdot
.83525 .27644 Mdot
.83537 .53653 Mdot
.83549 .3772 Mdot
.83561 .39213 Mdot
.83573 .34779 Mdot
.83585 .42025 Mdot
.83597 .31459 Mdot
.8361 .47805 Mdot
.83622 .27209 Mdot
.83634 .5248 Mdot
.83646 .54381 Mdot
.83658 .40971 Mdot
.8367 .30932 Mdot
.83682 .46949 Mdot
.83694 .27568 Mdot
.83706 .53625 Mdot
.83718 .39264 Mdot
.8373 .34719 Mdot
.83742 .41442 Mdot
.83755 .32111 Mdot
.83767 .46671 Mdot
.83779 .2771 Mdot
.83791 .53652 Mdot
.83803 .36526 Mdot
.83815 .43575 Mdot
.83827 .29908 Mdot
.83839 .50508 Mdot
.83851 .27011 Mdot
.83863 .18792 Mdot
.83875 .40952 Mdot
.83888 .43193 Mdot
.839 .36867 Mdot
.83912 .45309 Mdot
.83924 .27842 Mdot
.83936 .47797 Mdot
.83948 .05001 Mdot
.8396 .52825 Mdot
.83972 .50186 Mdot
.83984 .26873 Mdot
.83996 .2655 Mdot
.84008 .28392 Mdot
.84021 .47719 Mdot
.84033 .04965 Mdot
.84045 .5284 Mdot
.84057 .49942 Mdot
.84069 .26839 Mdot
.84081 .3155 Mdot
.84093 .13801 Mdot
.84105 .50167 Mdot
.84117 .13579 Mdot
.84129 .41138 Mdot
.84141 .45918 Mdot
.84153 .13885 Mdot
.84166 .50167 Mdot
.84178 .13141 Mdot
.8419 .43866 Mdot
.84202 .45424 Mdot
.84214 .20599 Mdot
.84226 .48907 Mdot
.84238 .02905 Mdot
.8425 .55731 Mdot
.84262 .33846 Mdot
.84274 .4988 Mdot
.84286 .26904 Mdot
.84299 .3133 Mdot
.84311 .14528 Mdot
.84323 .50008 Mdot
.84335 .12038 Mdot
.84347 .48879 Mdot
.84359 .42365 Mdot
.84371 .3795 Mdot
.84383 .44677 Mdot
.84395 .314 Mdot
.84407 .47142 Mdot
.84419 .11521 Mdot
.84431 .50728 Mdot
.84444 .18393 Mdot
.84456 .03391 Mdot
.84468 .56116 Mdot
.8448 .34673 Mdot
.84492 .49258 Mdot
.84504 .26902 Mdot
.84516 .41701 Mdot
.84528 .21332 Mdot
.8454 .39657 Mdot
.84552 .14066 Mdot
.84564 .37475 Mdot
.84577 .4626 Mdot
.84589 .08043 Mdot
.84601 .51715 Mdot
.84613 .07657 Mdot
.84625 .52437 Mdot
.84637 .14724 Mdot
.84649 .49993 Mdot
.84661 .11237 Mdot
.84673 .51264 Mdot
.84685 .37134 Mdot
.84697 .44958 Mdot
.8471 .30073 Mdot
.84722 .4741 Mdot
.84734 .08655 Mdot
.84746 .51524 Mdot
.84758 .17632 Mdot
.8477 .12648 Mdot
.84782 .49947 Mdot
.84794 .18603 Mdot
.84806 .04998 Mdot
.84818 .56247 Mdot
.8483 .36332 Mdot
.84842 .41012 Mdot
.84855 .32593 Mdot
.84867 .45845 Mdot
.84879 .28186 Mdot
.84891 .53225 Mdot
.84903 .31303 Mdot
.84915 .26343 Mdot
.84927 .28488 Mdot
.84939 .47704 Mdot
.84951 .05076 Mdot
.84963 .52793 Mdot
.84975 .50687 Mdot
.84988 .27008 Mdot
.85 .1627 Mdot
.85012 .4339 Mdot
.85024 .40129 Mdot
.85036 .42666 Mdot
.85048 .38493 Mdot
.8506 .44276 Mdot
.85072 .3326 Mdot
.85084 .46687 Mdot
.85096 .16378 Mdot
.85108 .49651 Mdot
.8512 .08173 Mdot
.85133 .55293 Mdot
.85145 .0381 Mdot
.85157 .55924 Mdot
.85169 .34587 Mdot
.85181 .45945 Mdot
.85193 .28127 Mdot
.85205 .53321 Mdot
.85217 .3185 Mdot
.85229 .37632 Mdot
.85241 .03559 Mdot
.85253 .55895 Mdot
.85266 .34113 Mdot
.85278 .47854 Mdot
.8529 .272 Mdot
.85302 .52292 Mdot
.85314 .55825 Mdot
.85326 .54075 Mdot
.85338 .39502 Mdot
.8535 .33989 Mdot
.85362 .4256 Mdot
.85374 .30901 Mdot
.85386 .48755 Mdot
.85398 .26949 Mdot
.85411 .47511 Mdot
.85423 .33994 Mdot
.85435 .50499 Mdot
.85447 .27031 Mdot
.85459 .18591 Mdot
.85471 .41166 Mdot
.85483 .4299 Mdot
.85495 .3745 Mdot
.85507 .44981 Mdot
.85519 .29801 Mdot
.85531 .47461 Mdot
.85544 .08129 Mdot
.85556 .51688 Mdot
.85568 .09207 Mdot
.8558 .51533 Mdot
.85592 .27359 Mdot
.85604 .47871 Mdot
.85616 .04624 Mdot
.85628 .52989 Mdot
.8564 .47577 Mdot
.85652 .27256 Mdot
.85664 .53133 Mdot
.85677 .47653 Mdot
.85689 .25541 Mdot
.85701 .36978 Mdot
.85713 .02157 Mdot
.85725 .55361 Mdot
.85737 .33943 Mdot
.85749 .50267 Mdot
.85761 .26967 Mdot
.85773 .23367 Mdot
.85785 .34763 Mdot
.85797 .46437 Mdot
.85809 .18102 Mdot
.85822 .49331 Mdot
.85834 .05478 Mdot
.85846 .56007 Mdot
.85858 .47691 Mdot
.8587 .27211 Mdot
.85882 .5293 Mdot
.85894 .50019 Mdot
.85906 .26868 Mdot
.85918 .08286 Mdot
.8593 .52089 Mdot
.85942 .20272 Mdot
.85955 .48969 Mdot
.85967 .03065 Mdot
.85979 .55778 Mdot
.85991 .33851 Mdot
.86003 .49574 Mdot
.86015 .26887 Mdot
.86027 .36966 Mdot
.86039 .02175 Mdot
.86051 .55377 Mdot
.86063 .33948 Mdot
.86075 .50269 Mdot
.86087 .26968 Mdot
.861 .23319 Mdot
.86112 .34844 Mdot
.86124 .46413 Mdot
.86136 .18332 Mdot
.86148 .4929 Mdot
.8616 .05172 Mdot
.86172 .56016 Mdot
.86184 .43105 Mdot
.86196 .30408 Mdot
.86208 .49434 Mdot
.8622 .26874 Mdot
.86233 .39506 Mdot
.86245 .1009 Mdot
.86257 .53474 Mdot
.86269 .2225 Mdot
.86281 .48657 Mdot
.86293 .0207 Mdot
.86305 .55238 Mdot
.86317 .33878 Mdot
.86329 .50168 Mdot
.86341 .26946 Mdot
.86353 .25442 Mdot
.86366 .30849 Mdot
.86378 .47313 Mdot
.8639 .08797 Mdot
.86402 .51481 Mdot
.86414 .19077 Mdot
.86426 .01794 Mdot
.86438 .54517 Mdot
.8645 .33978 Mdot
.86462 .50315 Mdot
.86474 .26979 Mdot
.86486 .22365 Mdot
.86498 .36371 Mdot
.86511 .45914 Mdot
.86523 .22861 Mdot
.86535 .48555 Mdot
.86547 .02001 Mdot
.86559 .55087 Mdot
.86571 .33839 Mdot
.86583 .49936 Mdot
.86595 .2691 Mdot
.86607 .30224 Mdot
.86619 .18151 Mdot
.86631 .49297 Mdot
.86644 .05687 Mdot
.86656 .55994 Mdot
.86668 .51399 Mdot
.8668 .27393 Mdot
.86692 .06713 Mdot
.86704 .5005 Mdot
.86716 .12719 Mdot
.86728 .50438 Mdot
.8674 .15648 Mdot
.86752 .20951 Mdot
.86764 .47999 Mdot
.86776 .04549 Mdot
.86789 .56003 Mdot
.86801 .37391 Mdot
.86813 .38702 Mdot
.86825 .35629 Mdot
.86837 .40539 Mdot
.86849 .33187 Mdot
.86861 .4479 Mdot
.86873 .28918 Mdot
.86885 .52097 Mdot
.86897 .28236 Mdot
.86909 .05028 Mdot
.86922 .52081 Mdot
.86934 .03754 Mdot
.86946 .53408 Mdot
.86958 .41904 Mdot
.8697 .31708 Mdot
.86982 .47237 Mdot
.86994 .27436 Mdot
.87006 .5345 Mdot
.87018 .43146 Mdot
.8703 .27933 Mdot
.87042 .50679 Mdot
.87054 .27063 Mdot
.87067 .15609 Mdot
.87079 .4395 Mdot
.87091 .39122 Mdot
.87103 .43698 Mdot
.87115 .35504 Mdot
.87127 .45937 Mdot
.87139 .23308 Mdot
.87151 .48488 Mdot
.87163 .01988 Mdot
.87175 .5493 Mdot
.87187 .33851 Mdot
.872 .49438 Mdot
.87212 .26888 Mdot
.87224 .39173 Mdot
.87236 .08478 Mdot
.87248 .55112 Mdot
.8726 .02067 Mdot
.87272 .55216 Mdot
.87284 .33862 Mdot
.87296 .50108 Mdot
.87308 .26935 Mdot
.8732 .26708 Mdot
.87333 .28013 Mdot
.87345 .47777 Mdot
.87357 .04515 Mdot
.87369 .53038 Mdot
.87381 .46813 Mdot
.87393 .27603 Mdot
.87405 .53656 Mdot
.87417 .36958 Mdot
.87429 .41906 Mdot
.87441 .31537 Mdot
.87453 .47725 Mdot
.87465 .27238 Mdot
.87478 .52681 Mdot
.8749 .52577 Mdot
.87502 .32287 Mdot
.87514 .43041 Mdot
.87526 .29016 Mdot
.87538 .23014 Mdot
.8755 .4851 Mdot
.87562 .02021 Mdot
.87574 .55148 Mdot
.87586 .33851 Mdot
.87598 .50055 Mdot
.87611 .26926 Mdot
.87623 .27802 Mdot
.87635 .25261 Mdot
.87647 .48181 Mdot
.87659 .02357 Mdot
.87671 .54327 Mdot
.87683 .35003 Mdot
.87695 .44546 Mdot
.87707 .29106 Mdot
.87719 .51808 Mdot
.87731 .27868 Mdot
.87743 .05092 Mdot
.87756 .51654 Mdot
.87768 .04668 Mdot
.8778 .52971 Mdot
.87792 .47975 Mdot
.87804 .2711 Mdot
.87816 .52214 Mdot
.87828 .56358 Mdot
.8784 .59207 Mdot
.87852 .16231 Mdot
.87864 .26396 Mdot
.87876 .4733 Mdot
.87889 .01993 Mdot
.87901 .55061 Mdot
.87913 .33836 Mdot
.87925 .49883 Mdot
.87937 .26904 Mdot
.87949 .31272 Mdot
.87961 .14723 Mdot
.87973 .49966 Mdot
.87985 .11637 Mdot
.87997 .50177 Mdot
.88009 .4018 Mdot
.88022 .42156 Mdot
.88034 .39672 Mdot
.88046 .43241 Mdot
.88058 .36946 Mdot
.8807 .45265 Mdot
.88082 .28119 Mdot
.88094 .47752 Mdot
.88106 .05375 Mdot
.88118 .5267 Mdot
.8813 .52481 Mdot
.88142 .28721 Mdot
.88154 .05061 Mdot
.88167 .52176 Mdot
.88179 .03673 Mdot
.88191 .53451 Mdot
.88203 .41418 Mdot
.88215 .32292 Mdot
.88227 .46233 Mdot
.88239 .27951 Mdot
.88251 .535 Mdot
.88263 .33298 Mdot
.88275 .53181 Mdot
.88287 .45697 Mdot
.883 .25939 Mdot
.88312 .53662 Mdot
.88324 .38102 Mdot
.88336 .37982 Mdot
.88348 .36487 Mdot
.8836 .39118 Mdot
.88372 .35071 Mdot
.88384 .41491 Mdot
.88396 .32051 Mdot
.88408 .46781 Mdot
.8842 .27653 Mdot
.88432 .53655 Mdot
.88445 .37544 Mdot
.88457 .39805 Mdot
.88469 .34005 Mdot
.88481 .43384 Mdot
.88493 .30099 Mdot
.88505 .50119 Mdot
.88517 .26918 Mdot
.88529 .26863 Mdot
.88541 .27643 Mdot
.88553 .47833 Mdot
.88565 .04111 Mdot
.88578 .53227 Mdot
.8859 .44082 Mdot
.88602 .29495 Mdot
.88614 .50964 Mdot
.88626 .27199 Mdot
.88638 .10832 Mdot
.8865 .47378 Mdot
.88662 .284 Mdot
.88674 .47703 Mdot
.88686 .05875 Mdot
.88698 .52472 Mdot
.8871 .53728 Mdot
.88723 .40362 Mdot
.88735 .32223 Mdot
.88747 .45208 Mdot
.88759 .28611 Mdot
.88771 .52586 Mdot
.88783 .29128 Mdot
.88795 .05039 Mdot
.88807 .51814 Mdot
.88819 .04281 Mdot
.88831 .53148 Mdot
.88843 .45297 Mdot
.88856 .28534 Mdot
.88868 .52562 Mdot
.8888 .29071 Mdot
.88892 .05027 Mdot
.88904 .51876 Mdot
.88916 .04137 Mdot
.88928 .53217 Mdot
.8894 .44333 Mdot
.88952 .29281 Mdot
.88964 .51323 Mdot
.88976 .27423 Mdot
.88989 .06947 Mdot
.89001 .49882 Mdot
.89013 .1379 Mdot
.89025 .50192 Mdot
.89037 .13273 Mdot
.89049 .43096 Mdot
.89061 .456 Mdot
.89073 .1846 Mdot
.89085 .49266 Mdot
.89097 .05021 Mdot
.89109 .56017 Mdot
.89121 .41326 Mdot
.89134 .32408 Mdot
.89146 .46031 Mdot
.89158 .28071 Mdot
.8917 .5337 Mdot
.89182 .3218 Mdot
.89194 .43433 Mdot
.89206 .50916 Mdot
.89218 .58416 Mdot
.8923 .33947 Mdot
.89242 .49564 Mdot
.89254 .26887 Mdot
.89267 .37116 Mdot
.89279 .02322 Mdot
.89291 .55487 Mdot
.89303 .33959 Mdot
.89315 .50271 Mdot
.89327 .26968 Mdot
.89339 .23286 Mdot
.89351 .34898 Mdot
.89363 .46398 Mdot
.89375 .18486 Mdot
.89387 .49263 Mdot
.89399 .04975 Mdot
.89412 .56017 Mdot
.89424 .40838 Mdot
.89436 .33038 Mdot
.89448 .44938 Mdot
.8946 .28807 Mdot
.89472 .52277 Mdot
.89484 .28518 Mdot
.89496 .0505 Mdot
.89508 .52152 Mdot
.8952 .03686 Mdot
.89532 .53444 Mdot
.89545 .41493 Mdot
.89557 .32199 Mdot
.89569 .46392 Mdot
.89581 .27861 Mdot
.89593 .53578 Mdot
.89605 .34331 Mdot
.89617 .52372 Mdot
.89629 .28796 Mdot
.89641 .05024 Mdot
.89653 .52041 Mdot
.89665 .03828 Mdot
.89678 .5337 Mdot
.8969 .42355 Mdot
.89702 .31196 Mdot
.89714 .48108 Mdot
.89726 .27109 Mdot
.89738 .51473 Mdot
.8975 .59143 Mdot
.89762 .19845 Mdot
.89774 .40223 Mdot
.89786 .43794 Mdot
.89798 .34885 Mdot
.8981 .46174 Mdot
.89823 .21297 Mdot
.89835 .48797 Mdot
.89847 .02471 Mdot
.89859 .55558 Mdot
.89871 .33914 Mdot
.89883 .50225 Mdot
.89895 .26958 Mdot
.89907 .24248 Mdot
.89919 .33204 Mdot
.89931 .46836 Mdot
.89943 .13954 Mdot
.89956 .50152 Mdot
.89968 .12974 Mdot
.8998 .44786 Mdot
.89992 .45158 Mdot
.90004 .23407 Mdot
.90016 .48472 Mdot
.90028 .01992 Mdot
.9004 .549 Mdot
.90052 .33863 Mdot
.90064 .49307 Mdot
.90076 .26893 Mdot
.90088 .41115 Mdot
.90101 .1865 Mdot
.90113 .05456 Mdot
.90125 .56237 Mdot
.90137 .40348 Mdot
.90149 .33709 Mdot
.90161 .43768 Mdot
.90173 .29753 Mdot
.90185 .507 Mdot
.90197 .27079 Mdot
.90209 .15124 Mdot
.90221 .44344 Mdot
.90234 .3832 Mdot
.90246 .44353 Mdot
.90258 .3295 Mdot
.9027 .46771 Mdot
.90282 .15506 Mdot
.90294 .49824 Mdot
.90306 .09785 Mdot
.90318 .53885 Mdot
.9033 .16927 Mdot
.90342 .49557 Mdot
.90354 .07095 Mdot
.90366 .55746 Mdot
.90379 .19286 Mdot
.90391 .12113 Mdot
.90403 .4839 Mdot
.90415 .43085 Mdot
.90427 .35666 Mdot
.90439 .45879 Mdot
.90451 .2376 Mdot
.90463 .4842 Mdot
.90475 .02032 Mdot
.90487 .54762 Mdot
.90499 .3397 Mdot
.90512 .48552 Mdot
.90524 .27001 Mdot
.90536 .4895 Mdot
.90548 .41833 Mdot
.9056 .30454 Mdot
.90572 .47808 Mdot
.90584 .27206 Mdot
.90596 .52486 Mdot
.90608 .54333 Mdot
.9062 .40655 Mdot
.90632 .31514 Mdot
.90645 .46176 Mdot
.90657 .27983 Mdot
.90669 .53463 Mdot
.90681 .32931 Mdot
.90693 .51614 Mdot
.90705 .5856 Mdot
.90717 .3583 Mdot
.90729 .42307 Mdot
.90741 .31148 Mdot
.90753 .48353 Mdot
.90765 .27039 Mdot
.90777 .50305 Mdot
.9079 .56165 Mdot
.90802 .55308 Mdot
.90814 .49305 Mdot
.90826 .26244 Mdot
.90838 .05092 Mdot
.9085 .52259 Mdot
.90862 .0355 Mdot
.90874 .53517 Mdot
.90886 .40702 Mdot
.90898 .33218 Mdot
.9091 .44626 Mdot
.90923 .29044 Mdot
.90935 .51887 Mdot
.90947 .2796 Mdot
.90959 .05038 Mdot
.90971 .51812 Mdot
.90983 .04248 Mdot
.90995 .53164 Mdot
.91007 .45074 Mdot
.91019 .28696 Mdot
.91031 .52298 Mdot
.91043 .28553 Mdot
.91055 .0505 Mdot
.91068 .52151 Mdot
.9108 .03688 Mdot
.91092 .53443 Mdot
.91104 .41507 Mdot
.91116 .32183 Mdot
.91128 .46421 Mdot
.9114 .27844 Mdot
.91152 .5359 Mdot
.91164 .34534 Mdot
.91176 .51709 Mdot
.91188 .27828 Mdot
.91201 .0519 Mdot
.91213 .51471 Mdot
.91225 .05267 Mdot
.91237 .52716 Mdot
.91249 .51961 Mdot
.91261 .27933 Mdot
.91273 .05021 Mdot
.91285 .519 Mdot
.91297 .04051 Mdot
.91309 .53259 Mdot
.91321 .43769 Mdot
.91334 .29774 Mdot
.91346 .50498 Mdot
.91358 .27008 Mdot
.9137 .19005 Mdot
.91382 .40721 Mdot
.91394 .43402 Mdot
.91406 .36224 Mdot
.91418 .45627 Mdot
.9143 .25682 Mdot
.91442 .48132 Mdot
.91454 .02846 Mdot
.91466 .53939 Mdot
.91479 .37014 Mdot
.91491 .39475 Mdot
.91503 .34549 Mdot
.91515 .42403 Mdot
.91527 .31059 Mdot
.91539 .4849 Mdot
.91551 .27005 Mdot
.91563 .49491 Mdot
.91575 .47611 Mdot
.91587 .25634 Mdot
.91599 .4574 Mdot
.91612 .38106 Mdot
.91624 .37301 Mdot
.91636 .37738 Mdot
.91648 .37106 Mdot
.9166 .38095 Mdot
.91672 .36561 Mdot
.91684 .38978 Mdot
.91696 .35269 Mdot
.91708 .4115 Mdot
.9172 .32447 Mdot
.91732 .4609 Mdot
.91744 .28036 Mdot
.91757 .53412 Mdot
.91769 .32491 Mdot
.91781 .47702 Mdot
.91793 .34829 Mdot
.91805 .48962 Mdot
.91817 .26933 Mdot
.91829 .45281 Mdot
.91841 .41083 Mdot
.91853 .32711 Mdot
.91865 .4551 Mdot
.91877 .28404 Mdot
.9189 .52914 Mdot
.91902 .30025 Mdot
.91914 .07438 Mdot
.91926 .49525 Mdot
.91938 .16178 Mdot
.9195 .49694 Mdot
.91962 .08476 Mdot
.91974 .55108 Mdot
.91986 .02065 Mdot
.91998 .55214 Mdot
.9201 .33861 Mdot
.92022 .50105 Mdot
.92035 .26934 Mdot
.92047 .26775 Mdot
.92059 .27854 Mdot
.92071 .47801 Mdot
.92083 .04336 Mdot
.92095 .5312 Mdot
.92107 .45586 Mdot
.92119 .28333 Mdot
.92131 .52878 Mdot
.92143 .29906 Mdot
.92155 .0674 Mdot
.92168 .50014 Mdot
.9218 .13031 Mdot
.92192 .50365 Mdot
.92204 .14948 Mdot
.92216 .29108 Mdot
.92228 .46894 Mdot
.9224 .0228 Mdot
.92252 .54403 Mdot
.92264 .34727 Mdot
.92276 .45434 Mdot
.92288 .28457 Mdot
.92301 .52856 Mdot
.92313 .29841 Mdot
.92325 .06424 Mdot
.92337 .5025 Mdot
.92349 .1155 Mdot
.92361 .50724 Mdot
.92373 .1828 Mdot
.92385 .02711 Mdot
.92397 .55976 Mdot
.92409 .36376 Mdot
.92421 .44242 Mdot
.92433 .29345 Mdot
.92446 .51441 Mdot
.92458 .27516 Mdot
.9247 .06175 Mdot
.92482 .5046 Mdot
.92494 .10205 Mdot
.92506 .51078 Mdot
.92518 .21095 Mdot
.9253 .14785 Mdot
.92542 .4424 Mdot
.92554 .38647 Mdot
.92566 .44099 Mdot
.92579 .34014 Mdot
.92591 .46466 Mdot
.92603 .18596 Mdot
.92615 .49244 Mdot
.92627 .04837 Mdot
.92639 .56014 Mdot
.92651 .39532 Mdot
.92663 .34915 Mdot
.92675 .41678 Mdot
.92687 .3184 Mdot
.92699 .47147 Mdot
.92711 .27477 Mdot
.92724 .53523 Mdot
.92736 .41837 Mdot
.92748 .29632 Mdot
.9276 .48597 Mdot
.92772 .26977 Mdot
.92784 .488 Mdot
.92796 .40463 Mdot
.92808 .32961 Mdot
.9282 .44269 Mdot
.92832 .29329 Mdot
.92844 .51407 Mdot
.92857 .27488 Mdot
.92869 .06373 Mdot
.92881 .50304 Mdot
.92893 .11141 Mdot
.92905 .50828 Mdot
.92917 .1919 Mdot
.92929 .11058 Mdot
.92941 .51723 Mdot
.92953 .3591 Mdot
.92965 .45621 Mdot
.92977 .25921 Mdot
.9299 .48096 Mdot
.93002 .0302 Mdot
.93014 .53825 Mdot
.93026 .37832 Mdot
.93038 .3783 Mdot
.9305 .36919 Mdot
.93062 .38399 Mdot
.93074 .36107 Mdot
.93086 .39729 Mdot
.93098 .34235 Mdot
.9311 .42946 Mdot
.93122 .30514 Mdot
.93135 .49418 Mdot
.93147 .26875 Mdot
.93159 .39745 Mdot
.93171 .11315 Mdot
.93183 .51067 Mdot
.93195 .37814 Mdot
.93207 .44502 Mdot
.93219 .32369 Mdot
.93231 .46919 Mdot
.93243 .13938 Mdot
.93255 .50156 Mdot
.93268 .13009 Mdot
.9328 .446 Mdot
.93292 .45217 Mdot
.93304 .22818 Mdot
.93316 .48561 Mdot
.93328 .02006 Mdot
.9334 .55107 Mdot
.93352 .33842 Mdot
.93364 .49977 Mdot
.93376 .26915 Mdot
.93388 .29392 Mdot
.934 .2074 Mdot
.93413 .4886 Mdot
.93425 .02988 Mdot
.93437 .55756 Mdot
.93449 .33845 Mdot
.93461 .49738 Mdot
.93473 .26893 Mdot
.93485 .34046 Mdot
.93497 .05846 Mdot
.93509 .52477 Mdot
.93521 .53781 Mdot
.93533 .37196 Mdot
.93546 .4103 Mdot
.93558 .32511 Mdot
.9357 .46023 Mdot
.93582 .28076 Mdot
.93594 .53364 Mdot
.93606 .32141 Mdot
.93618 .42812 Mdot
.9363 .09851 Mdot
.93642 .48125 Mdot
.93654 .24357 Mdot
.93666 .48332 Mdot
.93678 .02193 Mdot
.93691 .54503 Mdot
.93703 .34443 Mdot
.93715 .46442 Mdot
.93727 .27838 Mdot
.93739 .53605 Mdot
.93751 .34821 Mdot
.93763 .50646 Mdot
.93775 .27098 Mdot
.93787 .15531 Mdot
.93799 .44014 Mdot
.93811 .38998 Mdot
.93824 .43808 Mdot
.93836 .35116 Mdot
.93848 .46089 Mdot
.9386 .22047 Mdot
.93872 .4868 Mdot
.93884 .02162 Mdot
.93896 .55348 Mdot
.93908 .33912 Mdot
.9392 .50234 Mdot
.93932 .2696 Mdot
.93944 .2406 Mdot
.93957 .33549 Mdot
.93969 .46755 Mdot
.93981 .14826 Mdot
.93993 .49965 Mdot
.94005 .11139 Mdot
.94017 .51501 Mdot
.94029 .36235 Mdot
.94041 .45464 Mdot
.94053 .27004 Mdot
.94065 .4793 Mdot
.94077 .04007 Mdot
.94089 .53278 Mdot
.94102 .4341 Mdot
.94114 .3011 Mdot
.94126 .49936 Mdot
.94138 .26893 Mdot
.9415 .30593 Mdot
.94162 .16963 Mdot
.94174 .49516 Mdot
.94186 .07473 Mdot
.94198 .55619 Mdot
.9421 .13702 Mdot
.94222 .40296 Mdot
.94235 .46017 Mdot
.94247 .12266 Mdot
.94259 .50542 Mdot
.94271 .16734 Mdot
.94283 .07902 Mdot
.94295 .5141 Mdot
.94307 .34147 Mdot
.94319 .06703 Mdot
.94331 .52159 Mdot
.94343 .42097 Mdot
.94355 .2146 Mdot
.94367 .46569 Mdot
.9438 .33767 Mdot
.94392 .4955 Mdot
.94404 .26886 Mdot
.94416 .3738 Mdot
.94428 .02682 Mdot
.9444 .55662 Mdot
.94452 .33893 Mdot
.94464 .50176 Mdot
.94476 .26948 Mdot
.94488 .25274 Mdot
.945 .31199 Mdot
.94513 .47249 Mdot
.94525 .09473 Mdot
.94537 .51281 Mdot
.94549 .21744 Mdot
.94561 .15661 Mdot
.94573 .435 Mdot
.94585 .40027 Mdot
.94597 .4278 Mdot
.94609 .38211 Mdot
.94621 .44483 Mdot
.94633 .3234 Mdot
.94646 .46926 Mdot
.94658 .13859 Mdot
.9467 .50174 Mdot
.94682 .1318 Mdot
.94694 .43646 Mdot
.94706 .45479 Mdot
.94718 .19967 Mdot
.9473 .4901 Mdot
.94742 .03404 Mdot
.94754 .55858 Mdot
.94766 .33996 Mdot
.94778 .48451 Mdot
.94791 .27025 Mdot
.94803 .49623 Mdot
.94815 .49144 Mdot
.94827 .2591 Mdot
.94839 .10262 Mdot
.94851 .47753 Mdot
.94863 .26551 Mdot
.94875 .48 Mdot
.94887 .0361 Mdot
.94899 .53482 Mdot
.94911 .40986 Mdot
.94924 .32841 Mdot
.94936 .45281 Mdot
.94948 .2856 Mdot
.9496 .52674 Mdot
.94972 .29335 Mdot
.94984 .05159 Mdot
.94996 .51521 Mdot
.95008 .05142 Mdot
.9502 .52768 Mdot
.95032 .51199 Mdot
.95044 .27258 Mdot
.95056 .08483 Mdot
.95069 .48865 Mdot
.95081 .20279 Mdot
.95093 .48963 Mdot
.95105 .03102 Mdot
.95117 .55787 Mdot
.95129 .33857 Mdot
.95141 .49486 Mdot
.95153 .26887 Mdot
.95165 .38414 Mdot
.95177 .05346 Mdot
.95189 .56018 Mdot
.95202 .4535 Mdot
.95214 .28496 Mdot
.95226 .5262 Mdot
.95238 .29205 Mdot
.9525 .05068 Mdot
.95262 .51717 Mdot
.95274 .04532 Mdot
.95286 .53032 Mdot
.95298 .47019 Mdot
.9531 .27501 Mdot
.95322 .5363 Mdot
.95334 .39091 Mdot
.95347 .35162 Mdot
.95359 .40752 Mdot
.95371 .32929 Mdot
.95383 .4524 Mdot
.95395 .28589 Mdot
.95407 .52629 Mdot
.95419 .29227 Mdot
.95431 .05079 Mdot
.95443 .51687 Mdot
.95455 .04616 Mdot
.95467 .52994 Mdot
.9548 .47611 Mdot
.95492 .27242 Mdot
.95504 .53077 Mdot
.95516 .48329 Mdot
.95528 .25678 Mdot
.9554 .18957 Mdot
.95552 .40807 Mdot
.95564 .43324 Mdot
.95576 .36471 Mdot
.95588 .45509 Mdot
.956 .26512 Mdot
.95613 .48006 Mdot
.95625 .03516 Mdot
.95637 .53533 Mdot
.95649 .40446 Mdot
.95661 .33569 Mdot
.95673 .44013 Mdot
.95685 .29542 Mdot
.95697 .51055 Mdot
.95709 .27249 Mdot
.95721 .09626 Mdot
.95733 .48143 Mdot
.95745 .24503 Mdot
.95758 .4831 Mdot
.9577 .02245 Mdot
.95782 .54442 Mdot
.95794 .34615 Mdot
.95806 .45817 Mdot
.95818 .28207 Mdot
.9583 .53218 Mdot
.95842 .31265 Mdot
.95854 .25538 Mdot
.95866 .30302 Mdot
.95878 .4741 Mdot
.95891 .07793 Mdot
.95903 .51796 Mdot
.95915 .05054 Mdot
.95927 .52319 Mdot
.95939 .03145 Mdot
.95951 .5375 Mdot
.95963 .38499 Mdot
.95975 .36614 Mdot
.95987 .38833 Mdot
.95999 .35477 Mdot
.96011 .40793 Mdot
.96023 .32875 Mdot
.96036 .4534 Mdot
.96048 .2852 Mdot
.9606 .52738 Mdot
.96072 .29501 Mdot
.96084 .05383 Mdot
.96096 .51202 Mdot
.96108 .06391 Mdot
.9612 .52281 Mdot
.96132 .4855 Mdot
.96144 .36676 Mdot
.96156 .43275 Mdot
.96169 .30183 Mdot
.96181 .5003 Mdot
.96193 .26905 Mdot
.96205 .28694 Mdot
.96217 .22798 Mdot
.96229 .48542 Mdot
.96241 .02057 Mdot
.96253 .55219 Mdot
.96265 .33872 Mdot
.96277 .5015 Mdot
.96289 .26942 Mdot
.96302 .2583 Mdot
.96314 .30019 Mdot
.96326 .47458 Mdot
.96338 .07324 Mdot
.9635 .51951 Mdot
.96362 .132 Mdot
.96374 .45985 Mdot
.96386 .33792 Mdot
.96398 .46518 Mdot
.9641 .18153 Mdot
.96422 .49322 Mdot
.96434 .05408 Mdot
.96447 .5601 Mdot
.96459 .46534 Mdot
.96471 .27751 Mdot
.96483 .53596 Mdot
.96495 .34631 Mdot
.96507 .51364 Mdot
.96519 .27509 Mdot
.96531 .06469 Mdot
.96543 .5023 Mdot
.96555 .11596 Mdot
.96567 .50712 Mdot
.9658 .18177 Mdot
.96592 .02214 Mdot
.96604 .55819 Mdot
.96616 .3748 Mdot
.96628 .40714 Mdot
.9664 .32899 Mdot
.96652 .4533 Mdot
.96664 .28526 Mdot
.96676 .52728 Mdot
.96688 .29474 Mdot
.967 .05337 Mdot
.96712 .51259 Mdot
.96725 .06147 Mdot
.96737 .52371 Mdot
.96749 .52207 Mdot
.96761 .57601 Mdot
.96773 .50826 Mdot
.96785 .27399 Mdot
.96797 .09641 Mdot
.96809 .51087 Mdot
.96821 .3088 Mdot
.96833 .47228 Mdot
.96845 .10861 Mdot
.96858 .50899 Mdot
.9687 .19841 Mdot
.96882 .18281 Mdot
.96894 .04868 Mdot
.96906 .56247 Mdot
.96918 .3559 Mdot
.9693 .4288 Mdot
.96942 .30571 Mdot
.96954 .49338 Mdot
.96966 .26878 Mdot
.96978 .40916 Mdot
.9699 .17605 Mdot
.97003 .01762 Mdot
.97015 .54524 Mdot
.97027 .34048 Mdot
.97039 .50296 Mdot
.97051 .26975 Mdot
.97063 .22742 Mdot
.97075 .35785 Mdot
.97087 .46121 Mdot
.97099 .21081 Mdot
.97111 .48831 Mdot
.97123 .02589 Mdot
.97136 .55614 Mdot
.97148 .33894 Mdot
.9716 .50182 Mdot
.97172 .26949 Mdot
.97184 .25155 Mdot
.97196 .31442 Mdot
.97208 .47204 Mdot
.9722 .09962 Mdot
.97232 .51143 Mdot
.97244 .21497 Mdot
.97256 .47019 Mdot
.97269 .33981 Mdot
.97281 .50517 Mdot
.97293 .27037 Mdot
.97305 .18222 Mdot
.97317 .41549 Mdot
.97329 .426 Mdot
.97341 .38465 Mdot
.97353 .443 Mdot
.97365 .33157 Mdot
.97377 .46716 Mdot
.97389 .16084 Mdot
.97401 .49709 Mdot
.97414 .08699 Mdot
.97426 .54952 Mdot
.97438 .02297 Mdot
.9745 .54394 Mdot
.97462 .34814 Mdot
.97474 .45145 Mdot
.97486 .28657 Mdot
.97498 .52543 Mdot
.9751 .29031 Mdot
.97522 .05022 Mdot
.97534 .51915 Mdot
.97547 .04056 Mdot
.97559 .53256 Mdot
.97571 .43799 Mdot
.97583 .29747 Mdot
.97595 .50543 Mdot
.97607 .27022 Mdot
.97619 .18111 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00i`3oool0202oM00007Bo0?ooo`3oool0okmd0000000007@0_ooo`@3oool00>L0oooo00P0
okmd0000M02oool0oooo0;md0000M;l0oono07Ad_l40oooo003W0?ooo`060?oOW01804P0W=oo0?oo
g`2LB000B9cO``3oool00>L0oooo00H0oooO09a80000B7@0_knL04P0B02Lgoo30?ooo`00j03oool0
1@3OW4P004Qd07A8000007@0_ooo0<<0oooo003X0?ooo`050?noM00007@0_ooo0;md001d_ol0``3o
ool00>P0oooo00H0oono07@0001d_ol0oooo0;mdB02Lgoo20?ooo`00j@3oool0102oM00007Bo0?oo
_`1d000200000003001d_`3oool0oooo0;h0oooo003Y0?ooo`030?noM000B9`0gooo0<@0oooo003Y
0?ooo`030?oOW01804P0W=oo0<@0oooo003Y0?ooo`030?oog`2LB000B9cO0<@0oooo003Z0?ooo`03
0;md0000M;l0oooo0<<0oooo003X0?ooo`050?oog`2LB00000000000M02oool0``3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool004P0oooo00@0_g@0000000000000M;oo?P3oool00`3OW4P00000000000030000000304RL
g`3oool0oooo0080oooo00@0_g@0000000000000M;oo1@3oool0102oM00000000000001d_ol50?oo
o`040;md00000000000007Booc<0oooo00<0oooO09a80018W=l01@3oool0102oM00000000000001d
_ol50?ooo`040;md00000000000007Boo`D0oooo00@0_g@0000000000000M;oo<P3oool01@3ooml0
W4P000000000000007Bo00D0oooo00@0_g@0000000000000M;oo1@3oool0102oM00000000000001d
_ol50?ooo`040;md00000000000007Booc40oooo00H0oono07@00000000000000018W03Oool40?oo
o`040;md00000000000007Boo`D0oooo00@0_g@0000000000000M;oo1@3oool0102oM00000000000
001d_olA0?ooo`00A`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLgch0oooo00<0okmd001d_`3o
ool00P3oool02P2oM7@0_ooo0?ooo`3oool0gia8001d_`3oool0omnL04P00018W=l30?ooo`060=nL
B000M;l0oooo0?oOW0180000B9cO0`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLgc<0oooo00<0
gia80018W03Oool00`3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`<0oooo00H0gia8001d_`3o
ool0omnL04P00018W=l30?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO<@3oool01`3OW4P007Bo
0?ooo`3ookl0M0000018W03Oool00P3oool01P3OW4P007Bo0?ooo`3ogi`0B00004RLg`<0oooo00H0
gia8001d_`3oool0omnL04P00018W=l30?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO;`3oool0
0`3ookl0M00004RLg`020?ooo`030=nLB00007@0_ooo0080oooo00H0gia8001d_`3oool0omnL04P0
0018W=l30?ooo`060=nLB000M;l0oooo0?oOW0180000B9cO0`3oool01P3OW4P007Bo0?ooo`3ogi`0
B00004RLga00oooo00160?ooo`030?oog`2LB000B9cO0080oooo00<0okmd0000B02Lgol0?P3oool0
0`3o_g@007Bo0?ooo`040?ooo`030?oog`2LB000B9cO0080oooo00L0okmd0000B02Lgol0oooo0?oo
g`2LB000B9cO0080oooo00L0okmd0000B02Lgol0oooo0?oog`2LB000B9cO0080oooo00<0okmd0000
B02Lgol0<P3oool00`3ogi`0B01809cOo`020?ooo`030?oog`2LB000B9cO0080oooo00L0okmd0000
B02Lgol0oooo0?oog`2LB000B9cO0080oooo00L0okmd0000B02Lgol0oooo0?oog`2LB000B9cO0080
oooo00<0okmd0000B02Lgol0;`3oool00`3ooml0W4P007Boo`020?ooo`070?oOW0180000B9cO0?oo
o`3ooml0W4P004RLg`020?ooo`070?noM00004P0W=oo0?ooo`3ooml0W4P004RLg`020?ooo`070?no
M00004P0W=oo0?ooo`3ooml0W4P004RLg`020?ooo`030?noM00004P0W=oo02h0oooo00<0okmd0018
W03Oool00`3oool01P2oM000B9cO0?ooo`3ooml0W4P004RLg`80oooo00L0okmd0000B02Lgol0oooo
0?oog`2LB000B9cO0080oooo00L0okmd0000B02Lgol0oooo0?oog`2LB000B9cO0080oooo00<0okmd
0000B02Lgol03`3oool004H0oooo00<0oooO09a80018W=l00P3oool0103ooml0W4P00018W03Oooln
0?ooo`030?noM000M;l0oooo00<0oooo00<0oooO09a80018W=l00P3oool01`3ooml0W4P00018W03O
ool0oooO09a80018W=l00P3oool01`3ooml0W4P00018W03Oool0oooO09a80018W=l00P3oool0103o
oml0W4P00018W03Oool]0?ooo`030?noM0000000000000@0000000D004RL0=ooo`3ooml0W4P004RL
g`020?ooo`070?oog`2LB00004RL0=ooo`3ooml0W4P004RLg`020?ooo`070?oog`2LB00004RL0=oo
o`3ooml0W4P004RLg`020?ooo`040?oog`2LB00004RL0=ooobh0oooo00<0oono07@0001d_ol00`3o
ool01P2oM000001d0;ooo`3ooml0W4P004RLg`80oooo00L0oooO09a80000B9`0gooo0?oog`2LB000
B9cO0080oooo00L0oooO09a80000B9`0gooo0?oog`2LB000B9cO0080oooo00@0oooO09a80000B9`0
gooo;@3oool00`3o_g@004RL0=ooo`030?ooo`060;md0000M;l0oooo0?oog`2LB000B9cO0P3oool0
1`3ooml0W4P00018W03Oool0oooO09a80018W=l00P3oool01`3ooml0W4P00018W03Oool0oooO09a8
0018W=l00P3oool0103ooml0W4P00018W03Oool>0?ooo`00AP3oool00`3ooml0W4P0001d_`030?oo
o`030=nLB00004P0W=oo03l0oooo00<0okmd04RLg`3oool00P3oool00`3ooml0W4P0001d_`030?oo
o`060=nLB00004P0W=oo0?oog`2LB00007Bo0`3oool01P3OW4P0001809cOo`3ooml0W4P0001d_`<0
oooo00<0gia80000B02Lgol0;@3oool00`3ooml0W4Q809cOo`020?ooo`070;md0000M;l0oooo0?oo
o`3ooml0W4P0001d_`030?ooo`060=nLB00004P0W=oo0?oog`2LB00007Bo0`3oool01P3OW4P00018
09cOo`3ooml0W4P0001d_`<0oooo00<0gia80000B02Lgol0;P3oool00`3ooml0W4P0001d_`030?oo
o`060=nLB00004P0W=oo0?oog`2LB00007Bo0`3oool01P3OW4P0001809cOo`3ooml0W4P0001d_`<0
oooo00H0gia80000B02Lgol0oooO09a80000M;l30?ooo`030=nLB00004P0W=oo02d0oooo00<0oooO
09a8001d_ol00P3oool01`3ookl0M00004RLg`3oool0oooO09a80000M;l00`3oool01P3OW4P00018
09cOo`3ooml0W4P0001d_`<0oooo00H0gia80000B02Lgol0oooO09a80000M;l30?ooo`030=nLB000
04P0W=oo00h0oooo00170?ooo`030;md0000B9`0gooo0080oooo00<0omnL04P00018W=l0@03oool0
0`3OW4P0B9cO0?ooo`020?ooo`030;md0000B9`0gooo0080oooo00L0omnL04P00018W=l0oooo0;md
0000B9`0gooo0080oooo00L0omnL04P00018W=l0oooo0;md0000B9`0gooo0080oooo00<0omnL04P0
0018W=l0;P3oool01`3ookl0M01d0;ooo`3oool0okmd0018W03Oool00P3oool00`2oM00004RL0=oo
o`020?ooo`070?oOW0180000B9cO0?ooo`2oM00004RL0=ooo`020?ooo`070?oOW0180000B9cO0?oo
o`2oM00004RL0=ooo`020?ooo`030?oOW0180000B9cO02l0oooo00<0_g@00000M02oool00P3oool0
1`3OW4P0001809cOo`3oool0_g@00018W03Oool00P3oool01`3ogi`0B00004RLg`3oool0_g@00018
W03Oool00P3oool01`3ogi`0B00004RLg`3oool0_g@00018W03Oool00P3oool00`3ogi`0B00004RL
g`0_0?ooo`060;md000004P0W=oO09a8000007@0_ooo0P3oool00`2oM00004RL0=ooo`020?ooo`07
0?oOW0180000B9cO0?ooo`2oM00004RL0=ooo`020?ooo`070?oOW0180000B9cO0?ooo`2oM00004RL
0=ooo`020?ooo`030?oOW0180000B9cO00h0oooo00170?ooo`030=nLB00004P0W=oo0080oooo00<0
oooO09a80000M;l0@@3oool01`2oM000M;oo0?ooo`3oool0gia80000B02Lgol00P3oool01`3ooml0
W4P0001d_`3oool0gia80000B02Lgol00P3oool01`3ooml0W4P0001d_`3oool0gia80000B02Lgol0
0P3oool00`3ooml0W4P0001d_`0_0?ooo`060?oOW018B9`0gooo0?oOW01804P0W=oo0P3oool00`3O
W4P0001809cOo`020?ooo`070?oog`2LB00007Bo0?ooo`3OW4P0001809cOo`020?ooo`070?oog`2L
B00007Bo0?ooo`3OW4P0001809cOo`020?ooo`030?oog`2LB00007Bo02l0oooo00`0okmd00000018
W=l0oooo0?oog`2LB00004RL0=ooo`3oool0gia80000B02Lgol20?ooo`070?oog`2LB00007Bo0?oo
o`3OW4P0001809cOo`020?ooo`070?oog`2LB00007Bo0?ooo`3OW4P0001809cOo`020?ooo`030?oo
g`2LB00007Bo0300oooo00D0oooO09a80000000004RL0=ooo`020?ooo`030=nLB00004P0W=oo0080
oooo00L0oooO09a80000M;l0oooo0=nLB00004P0W=oo0080oooo00L0oooO09a80000M;l0oooo0=nL
B00004P0W=oo0080oooo00<0oooO09a80000M;l03P3oool004L0oooo00<0omnL04P00018W=l00`3o
ool00`2oM00004RL0=ooo`100?ooo`070?oOW01807@0_ooo0?ooo`3ogi`0B00004RLg`030?ooo`06
0;md0000B9`0gooo0?oOW0180000B9cO0`3oool01P2oM00004RL0=ooo`3ogi`0B00004RLg`<0oooo
00<0_g@00018W03Oool0;`3oool01@3o_g@007Bo0?oog`2LB000B9cO0080oooo00<0omnL04P00018
W=l00`3oool01P2oM00004RL0=ooo`3ogi`0B00004RLg`<0oooo00H0_g@00018W03Oool0omnL04P0
0018W=l30?ooo`030;md0000B9`0gooo02h0oooo00<0oooO09a8000000000P0000001`0007@0_ooo
0?ooo`3oool0omnL04P00018W=l00`3oool01P2oM00004RL0=ooo`3ogi`0B00004RLg`<0oooo00H0
_g@00018W03Oool0omnL04P00018W=l30?ooo`030;md0000B9`0gooo02l0oooo00X0_g@00000B02L
gol0omnL04Q8W03Oool0oooo0?oOW0180000B9cO0`3oool01P2oM00004RL0=ooo`3ogi`0B00004RL
g`<0oooo00H0_g@00018W03Oool0omnL04P00018W=l30?ooo`030;md0000B9`0gooo00d0oooo0017
0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0gia80018W03Oool0@03oool0203ooml0W4P007Bo
o`3oool0oooO09a80000B9`0gooo0P3oool01`3OW4P004RL0=ooo`3ooml0W4P00018W03Oool00P3o
ool01`3OW4P004RL0=ooo`3ooml0W4P00018W03Oool00P3oool00`3OW4P004RL0=ooo`0`0?ooo`04
0=nLB018W=l0_g@0001d_`80oooo00@0oooO09a80000B9`0gooo0P3oool01`3OW4P004RL0=ooo`3o
oml0W4P00018W03Oool00P3oool01`3OW4P004RL0=ooo`3ooml0W4P00018W03Oool00P3oool00`3O
W4P004RL0=ooo`0_0?ooo`030?oo_`1d000007Bo00D0oooo00@0oooO09a80000B9`0gooo0P3oool0
1`3OW4P004RL0=ooo`3ooml0W4P00018W03Oool00P3oool01`3OW4P004RL0=ooo`3ooml0W4P00018
W03Oool00P3oool00`3OW4P004RL0=ooo`0^0?ooo`030?oOW0180000M;oo0080oooo00L0okmd04RL
g`3oool0oooO09a80000B9`0gooo0080oooo00L0gia80018W03Oool0oooO09a80000B9`0gooo0080
oooo00L0gia80018W03Oool0oooO09a80000B9`0gooo0080oooo00<0gia80018W03Oool03@3oool0
04P0oooo00<0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`100?ooo`030?oo_`1d0000B9cO
0080oooo00<0omnL04P0001d_ol00P3oool01`3OW4P007Bo0?ooo`3oool0omnL04P0001d_ol00P3o
ool01`3OW4P007Bo0?ooo`3oool0omnL04P0001d_ol00P3oool00`3OW4P007Bo0?ooo`0a0?ooo`04
0=nLB01dM7@0001d0;ooo`80oooo00<0omnL04P0001d_ol00P3oool01`3OW4P007Bo0?ooo`3oool0
omnL04P0001d_ol00P3oool01`3OW4P007Bo0?ooo`3oool0omnL04P0001d_ol00P3oool00`3OW4P0
07Bo0?ooo`0`0?ooo`030?oOW0180000B9cO00D0oooo00<0omnL04P0001d_ol00P3oool01`3OW4P0
07Bo0?ooo`3oool0omnL04P0001d_ol00P3oool01`3OW4P007Bo0?ooo`3oool0omnL04P0001d_ol0
0P3oool00`3OW4P007Bo0?ooo`0^0?ooo`030?oOW01804P0W=oo0080oooo00L0okmd0018W03Oool0
oooo0?oOW0180000M;oo0080oooo00L0gia8001d_`3oool0oooo0?oOW0180000M;oo0080oooo00L0
gia8001d_`3oool0oooo0?oOW0180000M;oo0080oooo00<0gia8001d_`3oool03@3oool004T0oooo
00H0gia80000M02oool0oooO09a80018W=lm0?ooo`070?noM000B9`0gooo0?ooo`3OW4P0001809cO
o`030?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO0`3oool01P3OW4P0001d0;ooo`3ooml0W4P0
04RLg`<0oooo00H0gia80000M02oool0oooO09a80018W=lc0?ooo`030;md000004P0W=oo00<0oooo
00H0gia80000M02oool0oooO09a80018W=l30?ooo`060=nLB00007@0_ooo0?oog`2LB000B9cO0`3o
ool01P3OW4P0001d0;ooo`3ooml0W4P004RLgc80oooo00@0oooO09a8000007@0_ooo103oool01P3O
W4P0001d0;ooo`3ooml0W4P004RLg`<0oooo00H0gia80000M02oool0oooO09a80018W=l30?ooo`06
0=nLB00007@0_ooo0?oog`2LB000B9cO;`3oool00`3ooml0W4P004RLg`020?ooo`030;md0000M;l0
oooo0080oooo00H0gia80000M02oool0oooO09a80018W=l30?ooo`060=nLB00007@0_ooo0?oog`2L
B000B9cO0`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`h0oooo001:0?ooo`040=nLB0000000
0000001d_cl0oooo00D0omnL04P000000000000007Boo`050?ooo`040=nLB00000000000001d_`D0
oooo00@0gia800000000000007Bo1@3oool0103OW4P0000000000000M;ld0?ooo`030?oog`2LB000
B9cO00@0oooo00@0gia800000000000007Bo1@3oool0103OW4P0000000000000M;l50?ooo`040=nL
B00000000000001d_cD0oooo00@0oono07@000000000B9cO0`3oool0103OW4P0000000000000M;l5
0?ooo`040=nLB00000000000001d_`D0oooo00@0gia800000000000007Bo<@3oool01@3ooml0W4P0
00000000000007Bo00D0oooo00@0gia800000000000007Bo1@3oool0103OW4P0000000000000M;l5
0?ooo`040=nLB00000000000001d_`l0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo00130?ooool00000DP00000L0?ooo`00@`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool00000703oool004<0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`1>0?ooo`040000003oool0oooo000001`0oooo0013
0?ooo`800000o`3ooom>0?ooo`800000703oool004<0oooo00<000000?ooo`3oool0o`3ooom>0?oo
o`030000003oool0oooo01X0oooo00130?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0000000h0?ooo`030000003oool0000001<0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`0J0?ooo`00@`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000=0?ooo`030000
003oool0oooo00L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000080?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0403oool3000000X0oooo0P0000000`3oool0
00000?ooo`040?ooo`030000003oool0oooo0080oooo0P0000030?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?oo
o`0000005`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01X0oooo000b0?ooo`03
0=nLB0000000000000<0000000<0B9cO0?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`04
0000003oool0oooo000000`0oooo00<000000?ooo`3oool00P3oool020000000oooo0?ooo`000000
oooo0000003oool000001`3oool00`000000oooo000000020?ooo`040000003oool00000000000D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool2000000030?ooo`000000000000d0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo0`0000020?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo000000060?ooo`03
0000003oool0oooo0080000000@0oooo0000003oool0oooo0P0000000`3oool000000?ooo`030?oo
o`8000000P3oool00`000000oooo0?ooo`040?ooo`8000001P3oool00`000000oooo0?ooo`060?oo
o`<000000P3oool00`000000oooo0?ooo`02000000<0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00
00030?ooo`040000003oool0oooo000000T0oooo00D000000?ooo`00000000000?ooo`04000000H0
oooo0P0000050?ooo`040000003oool0oooo0?ooo`<000001@3oool00`000000oooo000000020000
00030?ooo`000000oooo00L0oooo00<000000?ooo`3oool06P3oool003<0oooo00<0okmd001d_`3o
ool00P3oool00`2oM7@0_ooo0?ooo`080?ooo`030000003oool0oooo0100oooo0P0000020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool2000000<0oooo00P000000?ooo`3o
ool000000?ooo`000000oooo000000T0oooo00<000000?ooo`0000000P3oool2000000D0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo000000040?ooo`040000003oool00000000000P0oooo
00@000000?ooo`3oool000001P3oool00`000000oooo000000040?ooo`030000003oool0oooo00@0
oooo0P0000020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00<0oooo0P0000020?ooo`040000003oool000000?ooo`8000000`3oool2
000000H0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00H0oooo0P00
00000`3oool000000?ooo`070?ooo`030000003oool0oooo00@0oooo0P0000060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`0000000P0000050?ooo`<000000P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0000000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000`3oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0000000<0oooo0P0000040?ooo`050000003oool000000?oo
o`0000001@3oool00`000000oooo0?ooo`020?ooo`8000001@3oool01@000000oooo000000000000
oooo00800000203oool00`000000oooo0?ooo`0J0?ooo`00=03oool00`3o_g@007Bo0?ooo`0<0?oo
o`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0
oooo00P0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`000000303oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000@0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`0;0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo0P0000050?ooo`050000003oool0oooo0000003oool00P0000080?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`070?ooo`80
00002`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000002`3oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`07
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00050?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01X0oooo000e0?ooo`030?noM000M;l0oooo00/0oooo00<0
00000?ooo`3oool01P3oool010000000oooo0?ooo`3oool200000080oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool3000000@0oooo00L000000?oo
o`3oool0oooo0000003oool0000000D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`060?ooo`030000003oool000000100oooo0P0000040?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo000000020?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0
oooo000000050?ooo`<000000`3oool00`000000oooo000000080?ooo`060000003oool0oooo0?oo
o`000000oooo0P0000040?ooo`8000002`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0100oooo00D000000?ooo`3oool000000?ooo`02000000<0oooo00<000000?ooo`0000000P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01X0oooo000U0?ooo`030?oog`2LB000
000000L0000000<0B9cO0?ooo`3oool0103oool00`3o_g@0B9cO0?ooo`0:0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P000000103oool000000?ooo`3oool200000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?ooo`0000001P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo0P0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000001@3oool2000000X0oooo00<000000?ooo`0000001P3oool010000000
oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`02
0?ooo`80000000@0oooo0000003oool000001@3oool2000000@0oooo00<000000?ooo`3oool0303o
ool010000000oooo0?ooo`0000040?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00d0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000090?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E0?ooo`80
0000103oool200000080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0J0?ooo`00
=`3oool00`3OW4P0B9cO0?ooo`090?ooo`<000001@3oool5000000<0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo0P0000020?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`3oool20000
00030?ooo`000000oooo00D0oooo0`0000020?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00/0oooo00H000000?ooo`3oool0oooo0000
003oool2000000P0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`800000
1P3oool010000000oooo0000003oool200000080oooo00<000000?ooo`0000000P3oool2000000<0
oooo0`00000?0?ooo`8000004`3oool2000000@0oooo0P0000030?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000050?ooo`030000003oool0oooo
00H0oooo00D000000?ooo`000000oooo000000080?ooo`030000003oool0oooo0080000000@0oooo
0000003oool0oooo0P00000;0?ooo`<000000P3oool010000000oooo0?ooo`0000050?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0
oooo00@000000?ooo`3oool00000303oool3000001`0oooo000h0?ooo`030;md001d_ol0oooo00P0
oooo00<000000?ooo`3oool01P3oool2000000D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`80000000<0oooo00000000
00001P3oool2000000030?ooo`000000oooo00@0oooo00D000000?ooo`3oool0oooo000000050?oo
o`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0oooo00D0oooo00@000000?oo
o`3oool0oooo0P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool0oooo0`0000040?oo
o`030000003oool0oooo00H0oooo00@000000?ooo`00000000000P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`0000000`3oool010000000oooo0000000000020?ooo`80000000<0oooo0000003o
ool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool010000000oooo0?ooo`0000020?ooo`800000103oool2000000D0oooo
00D000000?ooo`3oool0oooo000000030?ooo`8000000`3oool2000000T0oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool06P3oool003P0oooo00<0omnL04P0M02oool0203oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool3000000030?ooo`000000oooo0080oooo
0P0000040?ooo`030000003oool0000000H0oooo00<000000?ooo`0000001@3oool00`000000oooo
0?ooo`050?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00D0oooo0P0000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`02000000D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo01@0oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo
00<000000?ooo`3oool0103oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`0000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`090?ooo`8000000P3oool010000000oooo0?ooo`3oool200000080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool06P3oool003P0oooo00<0oooO09a8001d_ol0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool200000080oooo00H0
00000?ooo`3oool000000?ooo`00000=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`030?ooo`800000203oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02000000`0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000h0oooo00<000000?oo
o`3oool01P3oool01@000000oooo0000003oool0000000P0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0000000:0?ooo`040000003oool0oooo0?ooo`@0000000<0oooo0000003oool0
103oool2000000D0oooo00<000000?ooo`3oool03@3oool01P000000oooo0?ooo`3oool000000?oo
o`8000000P3oool2000000H0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool06P3oool003P0oooo00<0oono07@00018W=l0203oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0;0?ooo`800000203oool2000000D0oooo00<000000?ooo`3oool00P3oool20000
0100oooo00@000000?ooo`3oool0oooo0P0000040?ooo`8000001@3oool01@000000oooo0?ooo`3o
ool0000002T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00L0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`050000003oool0oooo0?ooo`00
0000103oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000000X0oooo00D000000?ooo`000000oooo000000070?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`060000
003oool0oooo0?ooo`000000oooo0P0000050?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool06P3oool003@0oooo00L0okmd0018W03Oool0oooo0=nLB00004P0W=oo00P0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo0P000000
0`3oool000000?ooo`02000000H0oooo00@000000?ooo`3oool0oooo100000000`3oool000000?oo
o`060?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`80000000@0oooo0000003o
ool0oooo0P0000060?ooo`030000003oool0oooo0080000000@0oooo00000000000000000`3oool2
00000080oooo00D000000?ooo`000000oooo000000070?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool2000000D0oooo00L000000?ooo`3oool000000?ooo`000000oooo00<0
000000D0oooo0000003oool0oooo000000090?ooo`050000003oool000000?ooo`0000000`3oool0
10000000oooo0?ooo`3oool3000000<0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?oo
o`3oool0000000H0oooo00<000000?ooo`3oool01P3oool3000000030?ooo`000000oooo0080oooo
00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool000000080
oooo0P0000000`3oool000000?ooo`050?ooo`030000003oool000000080oooo00<000000?ooo`00
00001@3oool00`000000oooo0?ooo`03000000030?ooo`000000000000@0oooo00@000000?ooo`00
00000000103oool300000080oooo0P0000030?ooo`<0000000<0oooo0000000000000`3oool00`00
0000oooo000000020?ooo`040000003oool000000?ooo`@000000`3oool2000000@0oooo00<00000
0?ooo`3oool01@3oool2000000070?ooo`000000oooo0?ooo`000000oooo000000080?ooo`030000
003oool0oooo01X0oooo000e0?ooo`050?oOW018000000000000001d_ol02@3oool00`000000oooo
0?ooo`050?ooo`050000003oool000000?ooo`0000000P3oool2000000040?ooo`000000oooo0?oo
o`80000000<0oooo0000003oool00P0000060?ooo`040000003oool0oooo0?ooo`@0000000<0oooo
0000003oool01P3oool200000080oooo00<000000?ooo`3oool0203oool00`000000oooo00000003
00000080oooo0P0000080?ooo`<0000000@0oooo0000000000000000103oool020000000oooo0?oo
o`000000oooo0000003oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0080oooo0P0000060?ooo`070000003oool0oooo0000003oool000000?ooo`03000000030?oo
o`000000000000800000203oool4000000040?ooo`000000oooo0?ooo`<0000000<0oooo00000000
00000P0000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000
oooo000000050?ooo`030000003oool0000000<0000000<0oooo0000003oool00P3oool010000000
oooo0?ooo`3oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`0000000P3oool20000
00030?ooo`000000oooo00D0oooo00@000000?ooo`000000oooo0P000000103oool000000?ooo`00
00030?ooo`030000003oool0oooo00<0000000T0oooo00000000000000000?ooo`000000oooo0000
003oool00P0000050?ooo`80000000@0oooo00000000000000000`3oool200000080oooo0P000002
0?ooo`80000000@0oooo0000003oool0oooo0`0000000`3oool000000000000300000080oooo0P00
000<0?ooo`80000000@0oooo00000000000000000P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01X0oooo00130?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@00
00030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool010000000oooo0?oo
o`0000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool0203oool01@000000oooo
0000003oool0000000@0oooo0P0000070?ooo`800000103oool00`000000oooo0?ooo`02000000H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`050000003oool000000?oo
o`0000002P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo0?ooo`040?oo
o`030000003oool000000080oooo00P000000?ooo`3oool000000?ooo`000000oooo000000H0oooo
00P000000?ooo`3oool000000?ooo`000000oooo000000H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo000000050?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo0P0000030?ooo`040000003oool0
oooo000000L0oooo0`000000103oool0000000000000000;0?ooo`030000003oool0oooo00/0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo000000040?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03000000/0oooo00<000000?ooo`3o
ool06P3oool004<0oooo00<000000?ooo`3oool0303oool5000000<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0303oool01P000000oooo0?ooo`000000oooo000000D0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool00P0000040?ooo`030000003o
ool0000000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo000000040?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000180
oooo00<000000?ooo`3oool0103oool020000000oooo0?ooo`000000oooo0000003oool000000`3o
ool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000
oooo0?ooo`090?ooo`060000003oool0oooo0000003oool00000103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo0P00000<0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`050000003o
ool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01X0oooo
00130?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool000004`3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo0080oooo0P0000000`3oool000000?ooo`060?ooo`050000
003oool000000?ooo`0000003@3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool0103oool3000000P0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P0000070?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`000000203oool2000000H0oooo0P0000020?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00@000000?oo
o`3oool000008P3oool2000000X0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0J
0?ooo`00@`3oool2000002@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000D0?oo
o`80000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`060?ooo`070000003oool0oooo
0?ooo`000000oooo000000080?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo0P0000080?ooo`060000
003oool0oooo0000003oool000001P3oool2000001X0oooo0P0000080?ooo`040000003oool00000
00000140oooo0P0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000403oool0
0`000000oooo0?ooo`0?0?ooo`<00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000X0oooo0P00000L0?ooo`00@`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0200oooo00@000000?ooo`0000000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00H000000?ooo`3oool0oooo0000003oool2000000@0oooo00<000000?ooo`000000
1P3oool01`000000oooo0?ooo`3oool000000?ooo`000000203oool010000000oooo0?ooo`00000;
0?ooo`040000003oool0oooo000001/0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0000000G0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P00000:0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0J0?ooo`00
@`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02<0oooo00H000000?ooo`3oool0
00000?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool20000
00@0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo0P00000<0?ooo`8000000`3oool00`000000oooo0?ooo`0N0?ooo`800000203oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo01X0oooo00130?ooo`030000003oool0oooo00l0oooo00@000000?oo
o`3oool000007`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo000000020?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0
00002@3oool2000000<0oooo00@000000?ooo`3oool000007@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00D0oooo0`0000090?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool2
00000080oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0J0?ooo`00@`3oool0
0`000000oooo0?ooo`0?0?ooo`80000000<0oooo0000003oool06`3oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00l0oooo0P0000070?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000oooo
0?ooo`3oool0000001@0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`060?oo
o`8000001P3oool200000080oooo00@000000?ooo`3oool000003`3oool010000000oooo0?ooo`00
000;0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo01X0oooo00130?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`0000005P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`8000001P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo00000008
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`090?ooo`8000002P3o
ool01P000000oooo0?ooo`000000oooo00000100oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo0P0000000`3oool000000?ooo`0K0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0J0?ooo`00
@`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
203oool01P000000oooo0?ooo`000000oooo000000D0oooo00<000000?ooo`3oool01P3oool20000
01/0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`3oool2000000H0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000080?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0F0?ooo`060000003oool0oooo
0000003oool000002`3oool00`000000oooo0?ooo`070?ooo`8000003P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo0P0000000`3oool00000000000040?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo01X0oooo00130?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`080?ooo`<000002@3oool01P000000oooo0?ooo`000000oooo000000h0oooo
0P00000V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?oo
o`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool06P3oool004<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000001P3oool010000000oooo0?ooo`00
000B0?ooo`800000403oool01@000000oooo0000003oool0000003T0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`060?ooo`80000000@0oooo0000003oool000000P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000006
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool00`000000oooo0000000:
0?ooo`040000003oool0oooo000001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool06P3oool004<0oooo0P00000=
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04`3oool01P000000oooo0?ooo`00
0000oooo000000`0oooo00D000000?ooo`000000oooo0000000O0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000F0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01@3oool2000000030?ooo`000000oooo0080000000D0oooo0000
003oool0oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool0203oool0
1@000000oooo0?ooo`3oool0000001D0oooo00D000000?ooo`000000oooo000000080?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0]0?ooo`800000
703oool004<0oooo00<000000?ooo`3oool0=`3oool200000080oooo00<000000?ooo`3oool00P00
00000`3oool000000?ooo`060?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo
0000000F0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00X0oooo0P0000001@3oool000000?ooo`3oool0000000D0
oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`0000070?ooo`8000001@3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0K0?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01X0oooo
00130?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool200000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3o
ool000003`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01/0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00T0oooo00D000000?ooo`000000oooo0000
00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00D0oooo0P0000050?ooo`050000003oool000000?ooo`000000
3@3oool2000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00P0oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`3oool20000
00T0oooo00<000000?ooo`3oool06P3oool004<0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00X0oooo0P0000040?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0303oool200000080oooo0P00000:0?ooo`8000001P3oool01@000000oooo0?ooo`3oool0
00000240oooo00@000000?ooo`3oool000003@3oool00`000000oooo000000090?ooo`030000003o
ool0000000D0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool02`3oool200000080oooo00<000000?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool004<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0000000;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool000000240oooo0`0000040?ooo`030000003oool0oooo01<0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02000000<0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`0000000P3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0J0?ooo`00@`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01L0oooo0P0000030?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0303oool0
10000000oooo0?ooo`0000080?ooo`030000003oool0oooo0100oooo0`0000000`3oool000000?oo
o`090?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0303oool01P000000oooo0?oo
o`000000oooo00000080oooo00D000000?ooo`000000oooo000000090?ooo`040000003oool0oooo
000001<0oooo0P0000030?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02`3oool2
000000H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool06P3oool004<0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`02000000L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo000000090?oo
o`030000003oool0oooo01@0oooo0P0000030?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo00@000000?oo
o`3oool000002@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01X0oooo00130?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01D0oooo0P00000E0?ooo`030000003oool0oooo00P0oooo00H000000?oo
o`3oool000000?ooo`0000070?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0403o
ool2000000<0oooo0P00000K0?ooo`80000000<0oooo0000003oool04`3oool00`000000oooo0?oo
o`0J0?ooo`00@`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo0P00
000:0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo01X0oooo00130?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool00P3oool2000000P0oooo00<000000?ooo`3oool0203oool00`000000oooo0000
000B0?ooo`050000003oool0oooo0?ooo`0000005@3oool00`000000oooo0?ooo`030?ooo`800000
4P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00h0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0J0?ooo`00@`3oool2000000/0oooo
00<000000?ooo`3oool0603oool00`000000oooo000000020?ooo`030000003oool0oooo00L0oooo
00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`0000001`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo0000000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0@0?ooo`800000703oool004<0oooo00<000000?ooo`3oool09@3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`09
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo00@0oooo0P00000G0?ooo`030000003oool0000000@0oooo00<00000
0?ooo`3oool0503oool01`000000oooo0?ooo`3oool000000?ooo`0000002P3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06P3oool004<0oooo00<0
00000?ooo`3oool0803oool00`000000oooo000000080?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00D0
00000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo03X0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`040?ooo`8000002`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000070?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
01X0oooo00130?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0000000c0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool010000000
oooo0?ooo`00000G0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000<
0?ooo`8000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000
1P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo01X0oooo00130?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0000000:0?ooo`030000003oool0oooo00h0oooo
00D000000?ooo`3oool0oooo0000000C0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000203o
ool00`000000oooo000000050?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01X0oooo00130?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo000000090?ooo`800000403oool01@000000oooo0?ooo`3oool0000000/0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`8000002`3oool00`000000
oooo0?ooo`0<0?ooo`040000003oool0oooo000001H0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo0P00000A0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool00000
00D0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool000000140oooo00<00000
0?ooo`3oool06P3oool004<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01T0oooo0P0000040?ooo`030000003oool0oooo00D0oooo00@000000?oo
o`3oool000000P3oool2000001d0oooo00<000000?ooo`3oool0503oool00`000000oooo00000009
0?ooo`030000003oool0oooo00/0oooo0P0000050?ooo`030000003oool0oooo008000003@3oool0
10000000oooo0?ooo`0000080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool000000100oooo00<000000?ooo`3oool00P00
000?0?ooo`040000003oool0oooo000000X0oooo00H000000?ooo`3oool000000?ooo`00000A0?oo
o`030000003oool0oooo01X0oooo00130?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`000000203oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`8000003`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`0000002`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo008000003@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0J0?ooo`00@`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`050?ooo`050000003oool000000?ooo`000000
1@3oool00`000000oooo0?ooo`02000000H0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00`0oooo0P0000050?ooo`030000003oool0oooo00L0
oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000001`3oool2000000X0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01X0oooo00130?ooo`80
0000:03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`02000000H0oooo00@000000?ooo`3oool000006@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0503oool00`00
0000oooo000000020?ooo`030000003oool0oooo00`0oooo0P00000@0?ooo`030000003oool0oooo
00`0oooo0P00000:0?ooo`030000003oool0oooo00/0oooo0P0000040?ooo`030000003oool0oooo
0140oooo0P00000L0?ooo`00@`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool0303oool00`000000oooo000000050?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo0100oooo0`00000O0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01X0oooo00130?ooo`030000003oool0oooo
0200oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool01`000000oooo0?ooo`3oool000000?ooo`000000
1@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo0P0000020?ooo`030000
003oool0oooo008000005P3oool3000001<0oooo0P00000:0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0J0?ooo`00@`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool000001P3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?ooo`05
0000003oool0oooo0?ooo`000000203oool00`000000oooo000000050?ooo`030000003oool0oooo
00<0oooo0P0000040?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool000000P3oool2
000000P0oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool000000140oooo0P00
000:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?oo
o`0J0?ooo`00@`3oool00`000000oooo0?ooo`0A0?ooo`800000103oool00`000000oooo0?ooo`0`
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`8000004P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`030?ooo`8000002@3oool2000000L0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0J0?ooo`00<P3oool00`3ookl0M000000000020000000304RLg`3oool0oooo00T0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool03@3oool01`000000oooo0?ooo`3oool000000?ooo`0000003P3oool3
000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0180oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool06P3oool003@0oooo00<0okmd0000001d_ol0303oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool000003@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0
oooo0000000@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01X0oooo000d0?ooo`030?oog`2LB00007Bo00`0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`000000303oool01`000000oooo0?ooo`3oool000000?ooo`000000303oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000001P0oooo00D000000?ooo`3oool0oooo0000000L
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06P3oool003D0oooo00<0gia80018
W03Oool02`3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo00000100oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`8000001P3oool00`000000oooo0?ooo`04
0?ooo`070000003oool0oooo0?ooo`000000oooo0000000<0?ooo`030000003oool000000080oooo
00<000000?ooo`0000003P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000180
oooo00<000000?ooo`3oool02P3oool2000000D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000603oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0J0?oo
o`009@3oool00`3ooml0W4P0000000070000000304RLg`3oool0oooo00<0oooo00<0omnL04P0B02L
gol02`3oool00`000000oooo0?ooo`0A0?ooo`8000003`3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?oo
o`030000003oool000000100oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`060000003o
ool0oooo0000003oool000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`800000103oool01@000000
oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0J0?oo
o`00=@3oool00`3ookl0M00007Boo`0;0?ooo`<000004P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`0000003@3oool01@000000oooo0?ooo`3oool00000
00L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`030000003oool00000
02D0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool03`3oool010000000oooo0000000000080?ooo`030000003oool0oooo00/0oooo00H0
00000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo00<0oooo0P00000>0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool01P3oool3000001`0oooo000f0?ooo`030;md
0000M;l0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0000000=0?ooo`050000
003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0000000<0
oooo0P00000P0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool2000000h0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01T0
oooo0`00000C0?ooo`030000003oool0oooo00X0oooo1@0000080?ooo`030000003oool0oooo01X0
oooo000f0?ooo`030=nLB000B9`0gooo00X0oooo00<000000?ooo`3oool0303oool2000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
00D000000?ooo`3oool0oooo0000000Q0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000/0oooo00D000000?ooo`00
0000oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0503oool01@00
0000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3o
ool0000000@0oooo0P0000020?ooo`@00000203oool2000000030?ooo`000000oooo00H0oooo0P00
000;0?ooo`D00000203oool00`000000oooo0?ooo`0J0?ooo`00=P3oool00`3ogi`0B01809cOo`0:
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo00<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo
00<000000?ooo`0000000P3oool00`000000oooo0000000C0?ooo`050000003oool0oooo0?ooo`00
00003P3oool00`000000oooo0?ooo`0_0?ooo`8000003@3oool00`000000oooo000000040?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool07P3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`00000000000P3oool00`000000oooo0?ooo`090?ooo`80000000<0oooo
0000003oool01`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01X0oooo000f0?oo
o`030?oo_`1d0000M;oo00X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool2000000030?ooo`000000oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002P3o
ool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool07@3oool2000000H0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`000000203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01X0oooo
000g0?ooo`030;md0000M;l0oooo00T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000h0oooo00@000000?ooo`00000000000P3oool00`000000oooo
0?ooo`0:0?ooo`8000002@3oool01@000000oooo0?ooo`3oool0000001<0oooo00D000000?ooo`3o
ool0oooo000000050?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02P3oool20000
00030?ooo`000000oooo0180oooo00D000000?ooo`3oool0oooo000000050?ooo`800000=03oool0
0`000000oooo0000000E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01X0oooo000e0?ooo`050?oo_`1d0000
00000000M02oool02@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00H0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000001`3oool00`000000oooo000000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0;0?ooo`8000004P3oool010000000
oooo0?ooo`00000C0?ooo`050000003oool0oooo0?ooo`0000005P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool06P3oool004<0oooo00<000000?oo
o`3oool02@3oool01@000000oooo0?ooo`3oool0000001D0oooo00<000000?ooo`3oool04P3oool0
1P000000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool000000180oooo00D000000?ooo`3oool0oooo0000000=0?ooo`80
000000<0oooo0000003oool07P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0>@3oool010000000oooo0?ooo`0000090?ooo`040000003oool0oooo
000001T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool06P3oool004<0oooo00<000000?ooo`3oool01@3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0J
0?ooo`050000003oool000000?ooo`0000002P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`800000103o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3o
ool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0:0?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0>0?ooo`8000001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01X0
oooo00130?ooo`8000001P3oool00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`00
0000603oool01@000000oooo0?ooo`3oool0000000d0oooo00@000000?ooo`3oool000003P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02D0oooo00D000000?ooo`000000oooo0000
00040?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00d0oooo0P00000L0?ooo`00
@`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00@000000?ooo`000000
00001P3oool00`000000oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`00
0000603oool2000000040?ooo`000000oooo000000D0oooo00<000000?ooo`0000004@3oool00`00
0000oooo0?ooo`02000000D0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00000@
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000?
0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`00@`3oool0
0`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?oo
o`030?ooo`800000103oool010000000oooo0?ooo`00000]0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool03`3oool010000000oooo0000000000040?ooo`030000003oool0000000H0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000H0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`080?ooo`030000003oool000000140oooo00@000000?oo
o`3oool000004P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`0000003`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000`0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`00@`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0000000d0oooo0P0000030?ooo`040000003oool0oooo000000X0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`8000004@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0000000H0oooo0P0000020?ooo`030000003oool0oooo00800000
103oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3o
ool000003@3oool2000000l0oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3o
ool0000000L0oooo00<000000?ooo`3oool01P3oool2000000<0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01X0oooo00130?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool03P3oool200000100oooo00<000000?ooo`3oool03@3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0080oooo0P0000050?ooo`040000003oool0oooo000000P0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000=0?ooo`8000000`3oool00`00
0000oooo0?ooo`090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool02@3oool0
1P000000oooo0?ooo`000000oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`80
00005`3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool07P3oool20000
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`00@`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05@3oool20000
00D0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`050000003oool0
oooo0?ooo`0000001P3oool00`000000oooo000000080?ooo`030000003oool0oooo008000005`3o
ool01@000000oooo0?ooo`3oool0000002@0oooo00<000000?ooo`0000004P3oool00`000000oooo
0?ooo`0J0?ooo`00@`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03`0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0
oooo000000050?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`070?ooo`8000001@3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo
0?ooo`000000203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0240oooo0P00000H
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool06P3oool004<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool01@000000oooo0?oo
o`3oool0000000D0oooo00@000000?ooo`00000000003@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo01<0oooo0P00000P0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool06P3oool004<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01@0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo00L0oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0?ooo`0J0?ooo`00@`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0000001`0oooo00<000000?ooo`0000002@3oool00`000000oooo00000005
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;
0?ooo`<0000000@0oooo0000003oool000001@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool06P3oool004<0oooo0P00000G0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000=0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00/0oooo0P0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000
803oool2000001`0oooo00130?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool010000000oooo00000000000h0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool0
0000>03oool200000200oooo00<000000?ooo`3oool06P3oool004<0oooo00<000000?ooo`3oool0
:@3oool010000000oooo00000000000:0?ooo`040000003oool0oooo000001H0oooo00<000000?oo
o`3oool03P3oool010000000oooo0?ooo`00000C0?ooo`030000003oool0000000L0oooo00<00000
0?ooo`0000004P3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo00H0oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool07@3oool2000000/0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0J0?ooo`00@`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000L0oooo00@0
00000?ooo`00000000001`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0000000L0
oooo00<000000?ooo`0000004P3oool010000000oooo0?ooo`00000N0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000?0?ooo`030000003oool00000
00H0oooo00<000000?ooo`3oool08`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool02@3oool2000000D0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0J0?ooo`00@`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool00000
0180oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
01X0oooo00130?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0U0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000004@3oool2
000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0000001H0oooo00@000000?ooo`3oool00000;@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool004<0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`02000000L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`070?ooo`8000001P3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0000001/0oooo00<000000?ooo`0000005P3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`8000001P3o
ool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000005P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool004<0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo000000L0oooo00<000000?oo
o`3oool03@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01<0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo000000050?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0
0P0000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000006@3oool01`000000oooo0?ooo`3oool00000
0?ooo`000000303oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00L0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo
00H000000?ooo`3oool000000?ooo`00000=0?ooo`030000003oool0oooo01X0oooo00130?ooo`03
0000003oool0oooo00/0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo
0`0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0000000G0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0;0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000002`3oool00`000000
oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo008000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00`0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000004@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool0
0`000000oooo0000000A0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`000000oooo0P00
000<0?ooo`030000003oool0oooo01X0oooo00130?ooo`8000002@3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000
003oool0oooo00L0oooo0P00000F0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo0000000K0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00/0oooo0P0000000`3oool000000?ooo`0B0?oo
o`030000003oool0000000/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0@0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool2000001`0oooo00130?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0000000L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0I
0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool00P00000C0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0000000;0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000<0?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00X0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0J0?oo
o`00@`3oool00`000000oooo0?ooo`040?ooo`<000001P3oool01@000000oooo0?ooo`000000oooo
00D00000103oool3000000050?ooo`00000000000?ooo`0000000P3oool2000000@0oooo00H00000
0?ooo`000000oooo0000003oool3000000030?ooo`00000000000080oooo0P0000000`3oool00000
000000040?ooo`<0000000<0oooo0000003oool00P3oool5000000@0oooo0P0000030?ooo`800000
0P3oool01@000000oooo0?ooo`000000oooo00<0000000<0oooo0000003oool00P0000001P3oool0
0000000000000000oooo00000080oooo00@000000?ooo`00000000000P3oool01@000000oooo0?oo
o`3oool000000080oooo0P000000103oool000000000003oool2000000050?ooo`00000000000000
003oool00P0000020?ooo`<0000000<0oooo0000000000000P0000000`3oool000000?ooo`030000
00030?ooo`000000000000@0oooo100000020?ooo`80000000@0oooo000000000000oooo1@000000
1@3oool00000000000000000oooo00<0000000<0oooo0000000000000`0000030?ooo`<0000000H0
oooo00000000000000000?ooo`0000020?ooo`040000003oool0000000000080oooo0`0000001`3o
ool000000000003oool000000?ooo`000000103oool01@000000oooo0000003oool000000080oooo
0P0000000`3oool000000?ooo`05000000<0oooo0P000000103oool000000000003oool2000000<0
oooo00<000000?ooo`3oool01@0000020?ooo`8000000P3oool300000080oooo0P0000020?ooo`03
0000003oool000000080000000<0oooo0000000000000P0000000`3oool000000?ooo`04000000D0
oooo0P0000020?ooo`P0000000D0oooo0000003oool000000?ooo`02000000T0oooo00<000000?oo
o`3oool06P3oool004<0oooo00<000000?ooo`3oool0103oool3000000040?ooo`00000000000?oo
o`<000000P3oool8000000030?ooo`000000000000<0000000<0oooo0000000000000`000000103o
ool000000000000000020?ooo`80000000<0oooo0000003oool01@0000001@3oool0000000000000
0000oooo00/000000P3oool8000000050?ooo`000000oooo0000003oool00P0000000`3oool00000
0?ooo`0200000080oooo0P0000000`3oool000000?ooo`03000000030?ooo`000000oooo00<00000
00<0oooo0000000000000`0000000`3oool0000000000002000000040?ooo`000000000000000080
oooo0P0000000`3oool000000000000=00000080oooo200000000`3oool000000?ooo`0300000003
0?ooo`0000000000008000000P3oool400000080oooo0P000000103oool000000000003oool50000
00050?ooo`00000000000000003oool02@0000000`3oool0000000000007000000030?ooo`000000
oooo00D0000000<0oooo0000000000001@0000000`3oool0000000000003000000030?ooo`000000
00000080000000<0oooo0000003oool02`0000000`3oool000000?ooo`05000000030?ooo`000000
00000080000000@0oooo0000003oool0oooo1@0000001@3oool00000000000000000oooo00P00000
00<0oooo000000000000100000000`3oool0000000000002000000030?ooo`000000oooo00H00000
00<0oooo0000000000000P0000000`3oool0000000000009000000030?ooo`000000oooo00<00000
203oool00`000000oooo0?ooo`0J0?ooo`00@`3oool00`000000oooo0?ooo`040?ooo`T000000P3o
ool00`000000oooo000000020?ooo`80000000<0oooo000000000000100000000`3oool000000?oo
o`02000000030?ooo`000000oooo00<000000P3oool00`000000oooo0?ooo`02000000030?ooo`00
0000000000<0000000@0oooo000000000000oooo2P000000103oool000000?ooo`3oool3000000@0
oooo0P0000000`3oool000000?ooo`020?ooo`8000000P3oool2000000030?ooo`00000000000080
oooo0P0000001@3oool000000000003oool000000080oooo00P000000?ooo`3oool0oooo0000003o
ool000000?ooo`<000000P3oool3000000030?ooo`000000oooo00P000000P3oool00`000000oooo
0000000300000080oooo0P0000020?ooo`<000000P3oool01@000000oooo0?ooo`3oool0000000@0
oooo0P0000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool000000?ooo`040000
00030?ooo`000000oooo00@000000`3oool2000000D0oooo0P0000000`3oool00000000000020000
0080oooo00D000000?ooo`3oool000000?ooo`02000000030?ooo`00000000000080000000@0oooo
00000000000000000P3oool01`000000oooo000000000000oooo0000003oool010000000103oool0
00000?ooo`3oool3000000H0oooo00H000000?ooo`3oool0oooo0000003oool2000000030?ooo`00
0000000000<000000P3oool4000000040?ooo`000000000000000080oooo0P0000020?ooo`800000
0`3oool4000000030?ooo`000000000000<000000P3oool200000080oooo00D000000?ooo`000000
00000?ooo`0200000080oooo0P0000030?ooo`030000003oool0oooo00@000000P3oool4000000P0
oooo00<000000?ooo`3oool06P3oool004<0oooo00<000000?ooo`3oool0103oool00`000000oooo
00000004000000080?ooo`000000oooo0?ooo`000000oooo0000003oool4000000080?ooo`000000
00000000003oool000000?ooo`0000020?ooo`040000003oool000000?ooo`80000000<0oooo0000
000000000P3oool3000000060?ooo`00000000000000003oool000000`3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00D00000
0?ooo`3oool000000?ooo`03000000030?ooo`000000000000<0oooo0P0000000`3oool000000?oo
o`04000000050?ooo`00000000000?ooo`000000103oool3000000030?ooo`000000oooo00800000
0`3oool01@000000oooo0?ooo`3oool000000080oooo1`0000050?ooo`80000000<0oooo0000003o
ool00P0000020?ooo`030000003oool0oooo00<000001@3oool00`000000oooo0?ooo`0200000003
0?ooo`000000oooo008000000`3oool2000000040?ooo`000000000000000080oooo100000020?oo
o`80000000<0oooo0000000000001`3oool5000000@0oooo00@000000?ooo`00000000000P3oool0
10000000oooo0000000000030?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<000001P3oool2000000L0oooo00@000000?ooo`3oool0oooo0`0000000`3oool00000
00000002000000<0oooo00@000000?ooo`000000oooo0P0000040?ooo`030000003oool0oooo0080
00001@3oool010000000oooo0?ooo`3oool400000080oooo0P0000070?ooo`030000003oool0oooo
00<000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`8000002P3oool0
0`000000oooo0?ooo`0J0?ooo`00@`3oool00`000000oooo0?ooo`060?ooo`D0000000<0oooo0000
003oool00P3oool2000000030?ooo`0000000000008000000P3oool00`000000oooo0?ooo`020000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`<0000000<0oooo0000000000000`000000
0`3oool000000?ooo`040?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo008000000P3oool4000000030?ooo`00000000000080000000<0
oooo0000000000000P000000103oool000000000000000050?ooo`030000003oool000000080oooo
0`0000000`3oool000000?ooo`050?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000
oooo0?ooo`000000oooo008000001@3oool00`000000oooo00000003000000<0oooo00<000000?oo
o`3oool00`0000050?ooo`030000003oool0oooo00@0000000@0oooo0000003oool000000P3oool2
00000080oooo0P0000030?ooo`030000003oool0000000D0oooo0P0000040?ooo`050000003oool0
oooo0000003oool00`0000040?ooo`040000003oool00000000000@0oooo0`0000020?ooo`<00000
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool000000080000000@0oooo0000003oool0
00000P3oool010000000oooo0000003oool300000080oooo00<000000?ooo`0000000P0000050?oo
o`8000000`3oool010000000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3oool00`3oool6
000000030?ooo`000000000000<0oooo0`0000000`3oool00000000000040?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0J0?ooo`00@`3oool00`00
0000oooo0?ooo`050?ooo`060000003oool000000000003oool000000P3oool010000000oooo0?oo
o`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000D0oooo0P0000050?ooo`03
0000003oool0oooo00@000001P3oool3000000H0oooo00@000000?ooo`3oool0oooo0P0000020?oo
o`050000003oool0oooo0?ooo`0000000P3oool2000000050?ooo`000000oooo0000003oool00P00
00000`3oool000000?ooo`03000000030?ooo`000000000000D0oooo00<000000?ooo`0000000`3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`040?ooo`<000000P3oool3000000070?ooo`00000000000?ooo`00
0000oooo000000030?ooo`040000003oool0oooo0?ooo`<000000`3oool3000000D0oooo0`000008
0?ooo`030000003oool0oooo0080oooo0`0000000`3oool000000?ooo`030?ooo`030000003oool0
000000@0oooo00<000000?ooo`3oool00`3oool3000000@0oooo0P0000050?ooo`030000003oool0
oooo00P0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000`3oool200000003
0?ooo`000000000000@0oooo100000050?ooo`040000003oool000000?ooo`<00000103oool00`00
0000oooo0?ooo`02000000@0oooo1`0000000`3oool00000000000030?ooo`<0000000<0oooo0000
00000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool06P3oool004<0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000050?ooo`<0
00000`3oool00`000000oooo000000020?ooo`8000001@3oool00`000000oooo0?ooo`0500000003
0?ooo`000000oooo0080oooo00<000000?ooo`3oool01@3oool01P000000oooo0?ooo`000000oooo
000000P0oooo0P0000000`3oool000000?ooo`02000000<0oooo00H000000?ooo`3oool0oooo0000
003oool2000000<0oooo00<000000?ooo`3oool00P3oool2000000l0oooo00P000000?ooo`000000
00000?ooo`000000oooo00000080oooo00D000000?ooo`3oool0oooo000000060?ooo`070000003o
ool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo0?ooo`8000000P3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool3000000<0oooo0`000002
0?ooo`040000003oool0oooo0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`8000000P3o
ool00`000000oooo0?ooo`020?ooo`<000000P3oool00`000000oooo000000030?ooo`040000003o
ool0oooo00000080oooo00L000000?ooo`000000oooo0000003oool000000080oooo0P0000040?oo
o`80000000L0oooo000000000000oooo0000003oool0000000@0oooo00@000000?ooo`3oool0oooo
0P0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`00000000001`3oool01@000000
oooo0000003oool000000080oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo0`0000000`3oool000000?ooo`030?ooo`030000003oool0oooo
00<000001`3oool700000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0J0?oo
o`006@3oool00`3OW4P0001d0;ooo`0W0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
00001P3oool2000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`05
0000003oool0oooo0000003oool00`0000000`3oool000000?ooo`020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool02`3oool300000080oooo0P0000030?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool02@3o
ool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`0000002P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool2000000P0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`040000003oool000000?ooo`<000000`3oool2000000<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00L000000?ooo`3oool0
oooo0000003oool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00800000103oool2000000050?ooo`00000000000?ooo`0000001P3o
ool200000080oooo0P00000;0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo00<0oooo00T000000?ooo`3oool000000?ooo`000000oooo
0000003oool00P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool3
000000040?ooo`000000000000000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0J0?ooo`004P3oool00`3ookl0M7Bo0?ooo`040?ooo`030?oo_`1dB9`0gooo02L0oooo0P000005
0?ooo`80000000@0oooo0000003oool000000P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`8000000`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`3oool3000000d0oooo0P0000030?ooo`040000003oool0oooo000000D0
oooo0P0000000`3oool000000?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool2000000L0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`050000003oool00000
0000003oool00P0000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000000`000005
0?ooo`<000000P3oool2000000@0oooo00<000000?ooo`0000001P3oool00`000000oooo00000005
0?ooo`<00000203oool01P000000oooo0?ooo`3oool000000?ooo`800000203oool00`000000oooo
0?ooo`02000000@0oooo0P0000001@3oool000000000003oool0000000L0oooo00<000000?ooo`3o
ool0100000000`3oool00000000000020?ooo`050000003oool0oooo0?ooo`0000001@3oool20000
00<0oooo00<000000?ooo`000000303oool010000000oooo0?ooo`0000030?ooo`040000003oool0
0000000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo0P0000060?ooo`03
0000003oool0oooo00D0oooo0P00000L0?ooo`004P3oool00`3ogi`0B01d0;ooo`030?ooo`030?no
M00007@0_ooo02P0oooo00<000000?ooo`3oool0103oool2000000<0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo0P0000040?oo
o`040000003oool0oooo000000T0oooo00D000000?ooo`3oool0oooo000000040?ooo`060000003o
ool0oooo0000003oool00000103oool00`000000oooo0?ooo`0;0?ooo`8000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool01000
0000oooo0000000000040?ooo`80000000@0oooo0000003oool0oooo0P0000040?ooo`030000003o
ool0000000@0oooo00@000000?ooo`00000000000P3oool00`000000oooo000000060?ooo`800000
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000@0oooo00D000000?ooo`000000
00000?ooo`03000000H0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`050?ooo`<0
00001`3oool00`000000oooo0?ooo`020?ooo`<000001P3oool00`000000oooo0?ooo`020?ooo`80
0000103oool3000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`04000000050?ooo`00000000000000003oool00P0000030?ooo`030000003oool0oooo
0080oooo0P0000050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P00000:0?oo
o`<0000000<0oooo0000003oool0103oool4000000030?ooo`000000oooo00X0oooo00<000000?oo
o`3oool06P3oool00180oooo00L0omnL04P000000000001809cOo`3ogi`0B7Bo02X0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`8000002P3oool00`000000oooo00000003
000000H0oooo0`000000103oool000000?ooo`0000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000001@3oool00`000000oooo000000040?ooo`030000003oool0oooo008000001P3o
ool00`000000oooo0000000200000080oooo0P00000A0?ooo`<000001P3oool00`000000oooo0000
00020?ooo`<000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool0
oooo0`0000060?ooo`8000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`8000005P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool200000005
0?ooo`000000oooo0?ooo`0000001P3oool2000000L0oooo00<000000?ooo`3oool01P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00020?ooo`<0000000<0oooo0000003oool01P3oool2000000050?ooo`000000oooo0?ooo`000000
203oool00`000000oooo0?ooo`0J0?ooo`00503oool00`3ookl0M000000000020000000307Boo`3o
ool0oooo02L0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool2000000030?oo
o`000000oooo0080000000<0oooo0000003oool0103oool010000000oooo0?ooo`3oool400000003
0?ooo`000000oooo00H0oooo0P000000103oool000000?ooo`0000020?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool00000103oool2000000H0oooo0P0000040?ooo`<0000000@0oooo
0000003oool000000`3oool00`000000oooo0?ooo`0@0?ooo`8000002@3oool01@000000oooo0?oo
o`3oool0000000H0oooo0P0000080?ooo`80000000<0oooo0000003oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool010000000oooo
0?ooo`0000070?ooo`040000003oool0oooo000000<0oooo00P000000?ooo`3oool0oooo0000003o
ool000000?ooo`800000103oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool00P3oool01P000000oooo0?ooo`3oool000000?ooo`<000001@3oool00`000000oooo
0?ooo`040?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0J0?ooo`00
4`3oool02@3ookl0M01d0;ooo`3oool0oooO09a800000000001d0;ooo`0W0?ooo`030000003oool0
oooo00@0oooo00@000000?ooo`3oool0oooo0P000000103oool000000?ooo`0000020?ooo`800000
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
303oool01@000000oooo0?ooo`3oool0000000D0oooo00@000000?ooo`00000000000P3oool00`00
0000oooo0000000:0?ooo`8000002P3oool00`000000oooo0?ooo`0>0?ooo`80000000D0oooo0000
003oool0oooo000000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool0
10000000oooo0000000000040?ooo`030000003oool0oooo00800000203oool020000000oooo0?oo
o`000000oooo0000003oool000000P3oool2000000030?ooo`000000oooo00<0oooo00@000000?oo
o`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`<0000000<0oooo0000000000000`00
00000`3oool000000?ooo`070?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`00000A0?ooo`8000000`3oool01@000000oooo000000000000oooo
0080000000<0oooo000000000000203oool00`000000oooo0?ooo`030?ooo`050000003oool00000
0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`8000001P3oool00`000000oooo0?ooo`04
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo
0P00000<0?ooo`030000003oool0oooo01X0oooo000B0?ooo`030?oo_`1d07@0_ooo00@0oooo00<0
omnL04Qd_`3oool06@3oool0102oM00000000000001d_ol:0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool2000000040?ooo`000000oooo0?ooo`8000003P3oool010000000
oooo0?ooo`0000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001`3oool20000
00@0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo0P00000<0?ooo`030000003oool0oooo008000003@3oool2000000/0oooo00@00000
0?ooo`3oool0oooo0`0000030?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`02000000040?ooo`000000oooo00000080oooo00D000000?ooo`3o
ool000000?ooo`03000000L0oooo00<000000?ooo`3oool00P3oool3000000X0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`050?ooo`80000000<0oooo0000003oool0103oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0000
0004000000030?ooo`000000oooo00H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000001@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
01X0oooo000B0?ooo`030?noM0000000M;oo00<0oooo00<0oono07A8W03Oool06@3oool01P3OW4P0
07Bo0?ooo`3ogi`0B00004RLg`T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`80000000D0oooo0000003oool0oooo0000000;0?ooo`030000003oool0oooo00<0oooo0P00
00070?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000
2P3oool200000080oooo00D000000?ooo`3oool0oooo000000080?ooo`80000000<0oooo00000000
00001`3oool00`000000oooo0?ooo`02000000L0oooo00<000000?ooo`3oool00`3oool010000000
oooo00000000000=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P000000103o
ool000000?ooo`0000020?ooo`80000000<0oooo0000003oool00P0000050?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`3oool0103oool2000000H0oooo00<000000?ooo`3oool00P3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool6000000030?ooo`000000oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`8000002`3oool00`000000oooo000000020000
0080oooo00@000000?ooo`0000000000103oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`000000403oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0J0?ooo`00<`3oool00`3ooml0W4P004RLg`02
0?ooo`030?noM00004P0W=oo00P0oooo00<000000?ooo`3oool02P3oool2000000030?ooo`000000
oooo00P0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`<000003@3oool3000000<0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3o
ool0oooo0P0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool20000
00H0oooo0P0000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0200000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?oo
o`<000002@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`000000103oool0
10000000oooo0000000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001P3o
ool3000000030?ooo`000000000000H0oooo00@000000?ooo`3oool000004P3oool3000000<0oooo
00<000000?ooo`0000000`0000020?ooo`040000003oool000000?ooo`8000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000002P3oool0
0`000000oooo0?ooo`0J0?ooo`00703oool0103o_g@000000000M02ooolC0?ooo`030?oog`2LB000
B9cO0080oooo00@0oooO09a80000B9`0gooo1`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0000000`0oooo00<000000?ooo`3oool00P0000040?ooo`<0000000<0oooo0000003oool0103o
ool00`000000oooo0?ooo`02000000050?ooo`000000oooo0?ooo`0000000`3oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`8000000P3oool0
10000000oooo0?ooo`3oool2000000@0oooo0P0000060?ooo`030000003oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0000000/0oooo
00<000000?ooo`000000103oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool0
1`3oool010000000oooo0000000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool0100000030?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool00P000000
0`3oool000000?ooo`050?ooo`80000000<0oooo0000003oool0103oool010000000oooo0?ooo`00
000<0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000090?ooo`030000
003oool0oooo01X0oooo000@0?ooo`030=nLB0000000M;oo0080oooo00@0oooO09bL_`3ooml0W4P0
0`0000000`00M;l0oooo0?ooo`0D0?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000B02Lgol0
1`3ooooo000005800000703oool000d0oooo00@0gia800000000000007Bo103oool0103ookl0M000
0000B02Lgol20?ooo`030;nLW03Oool0oooo01H0oooo00<0_g@00018W03Oool00P3oool00`3ogi`0
B00004RLg`070?ooo`030000003oool0oooo00H0oooo0P0000020?ooo`030000003oool0oooo0080
oooo0P0000020?ooo`80000000D0oooo0000003oool0oooo0000000;0?ooo`030000003oool0oooo
00<0000000<0oooo0000003oool0103oool00`000000oooo000000060?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02000000030?ooo`000000oooo
008000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000002P3oool010000000oooo
0000000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`<000000`3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo0?oo
o`<000001P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?oo
o`00000000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00l0oooo00L0
00000?ooo`000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool000000080oooo0`0000090?ooo`030000003oool000000080oooo0P0000040?oo
o`030000003oool0oooo00@0oooo00D000000?ooo`3oool000000?ooo`03000000D0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo01X0oooo000<
0?ooo`040?oo_`1d000004RL0=ooo`T0oooo00D0gmoO0;md000000000000001d_`0F0?ooo`030=nL
B00004P0W=oo0080oooo00<0oooO09a80000M;l01`3oool00`000000oooo0?ooo`060?ooo`800000
1@3oool00`000000oooo000000030?ooo`@000003P3oool00`000000oooo0000000200000080oooo
00<000000?ooo`3oool00`3oool01`000000oooo0000003oool000000?ooo`0000001`3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000000`3oool2000000030?ooo`000000000000h0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool000000080oooo
00<000000?ooo`3oool00P3oool2000000<0oooo0P0000001`3oool000000?ooo`3oool000000?oo
o`0000000`3oool010000000oooo0?ooo`3oool3000000/0oooo00<000000?ooo`3oool00`3oool0
1P000000oooo0?ooo`000000oooo000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`030000003oool000000080000000<0oooo0000003oool00P0000030?ooo`030000
003oool0oooo0140oooo00@000000?ooo`00000000000P3oool00`000000oooo0?ooo`02000000@0
oooo00H000000?ooo`3oool0oooo0000003oool4000000T0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00D000000?ooo`3oool000000?ooo`03000000D0oooo
00<000000?ooo`000000103oool200000080oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0J0?ooo`00603oool00`3ooml0W4P007Boo`020?ooo`030=nLB00007@0_ooo01@0oooo00<0
omnL04P00018W=l00`3oool00`2oM00004RL0=ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00`3oool2000000H0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000070?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
000000050?ooo`050000003oool000000?ooo`0000000P3oool010000000oooo0?ooo`0000030?oo
o`050000003oool0oooo0?ooo`0000002P3oool010000000oooo0?ooo`3oool2000000<0oooo00@0
00000?ooo`3oool00000103oool010000000oooo00000000000M0?ooo`030000003oool0oooo00<0
000000L0oooo0000003oool0oooo0000003oool0000000l0oooo0P000000103oool000000?ooo`3o
ool2000000L0oooo00<000000?ooo`000000103oool3000000P0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo000000090?ooo`03
0000003oool0oooo00H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000T0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
0P0000020?ooo`8000000`3oool00`000000oooo0000000;0?ooo`030000003oool0oooo01X0oooo
000H0?ooo`030?oog`2LM9`0gooo0080oooo00<0giad09cOo`3oool0503oool0103ooml0W4P00018
W03Oool20?ooo`030=nLB000B9`0gooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`050000003oool0oooo0?ooo`0000002@3oool010000000oooo0?ooo`0000040?oo
o`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000`0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000
oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P00000E0?ooo`80
0000203oool00`000000oooo0?ooo`040?ooo`030000003oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00@000002@3oool010000000oooo0000003oool200000080oooo00D00000
0?ooo`3oool0oooo000000050?ooo`040000003oool00000000000@0oooo0P0000020?ooo`030000
003oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0000000D0oooo
0P00000:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000000P0000030?ooo`040000
003oool0oooo000000H0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0J0?ooo`00=@3oool00`3ogi`0B00007Boo`020?oo
o`030=nLB000M;l0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`8000000P3o
ool00`000000oooo0?ooo`0;0?ooo`090000003oool0oooo0000003oool000000?ooo`000000oooo
008000000`3oool010000000oooo00000000000>0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool00000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool00000008000000P3oool00`000000oooo
0?ooo`0:0?ooo`8000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0100
oooo00P000000?ooo`000000oooo0000003oool000000?ooo`8000000`3oool01@000000oooo0?oo
o`3oool0000000D0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool00000
00P0oooo0P0000030?ooo`800000103oool010000000oooo0?ooo`00000:0?ooo`050000003oool0
00000?ooo`0000001@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000L0
oooo0`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01P000000
oooo0?ooo`3oool000000?ooo`@000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0J0?ooo`00=P3oool01P3O
W4P0001d0;ooo`3ooml0W4P004RLg`L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`050?ooo`05
0000003oool0oooo0?ooo`000000203oool010000000oooo0000000000020?ooo`@000002P3oool0
0`000000oooo000000070?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?oo
o`020?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000@0oooo00<000000?ooo`3oool01P3oool01`000000oooo0?ooo`000000oooo
0000003oool00P00000C0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`000000oooo1000
00050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00H0oooo0P0000020?ooo`8000003`3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo0080000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`0000000`3oool00`000000oooo0000000<0?oo
o`030000003oool0oooo01X0oooo000g0?ooo`040=nLB00000000000001d_`P0oooo00<000000?oo
o`3oool01@3oool2000000040?ooo`0000000000000000H0oooo00<000000?ooo`3oool02@3oool3
000000H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000060?ooo`070000003o
ool0oooo0000003oool000000?ooo`02000000030?ooo`00000000000080oooo00@000000?ooo`3o
ool000000P3oool400000080oooo00<000000?ooo`0000001P3oool2000000<0oooo00@000000?oo
o`000000oooo0`0000000`3oool000000?ooo`02000000040?ooo`000000oooo0?ooo`8000000P3o
ool010000000oooo0?ooo`0000060?ooo`8000000P3oool2000000@0oooo00@000000?ooo`000000
00000`3oool010000000oooo0?ooo`3oool5000000090?ooo`000000oooo0000003oool000000?oo
o`000000oooo00800000103oool4000000<0oooo00<000000?ooo`3oool00P0000000`3oool00000
00000002000000050?ooo`00000000000000003oool00`0000030?ooo`D000001@3oool200000080
oooo00D000000?ooo`3oool0oooo000000030?ooo`80000000<0oooo0000000000000`3oool01000
0000oooo0000000000030?ooo`800000103oool200000080oooo00@000000?ooo`00000000000P3o
ool00`000000oooo0?ooo`070?ooo`<000001P3oool2000000030?ooo`000000oooo0080oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00D0000000<0oooo00000000
00000P0000001@3oool000000?ooo`000000oooo0080000000<0oooo0000003oool00`3oool01000
0000oooo0000003oool3000000090?ooo`00000000000000003oool000000?ooo`000000oooo0080
00002@3oool00`000000oooo0?ooo`0J0?ooo`00@`3oool00`000000oooo0?ooo`050?ooo`800000
00@0oooo00000000000000001P3oool010000000oooo0?ooo`0000080?ooo`030000003oool00000
00800000103oool01`000000oooo0?ooo`000000oooo0000003oool00`0000020?ooo`80000000<0
oooo0000000000000P0000000`3oool000000?ooo`02000000030?ooo`000000oooo0080oooo00@0
00000?ooo`3oool000000P3oool2000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0
0`3oool3000000<0oooo00@000000?ooo`3oool0oooo0`0000000`3oool000000?ooo`0200000004
0?ooo`000000oooo0?ooo`8000001@3oool010000000oooo0?ooo`0000020?ooo`<000000P3oool2
000000@0oooo00@000000?ooo`00000000000`3oool00`000000oooo0?ooo`06000000050?ooo`00
0000oooo0000003oool00`0000000`3oool00000000000020?ooo`030000003oool0000000<00000
0`3oool2000000040?ooo`000000oooo0?ooo`@0000000D0oooo00000000000000000?ooo`030000
00<0oooo1@0000001@3oool000000?ooo`000000oooo008000000P3oool200000080oooo0P000002
0?ooo`030000003oool0oooo0080000000H0oooo0000003oool000000?ooo`0000030?ooo`<00000
00@0oooo0000003oool0oooo0P0000020?ooo`040000003oool0000000000080oooo0P0000050?oo
o`80000000@0oooo0000003oool00000103oool4000000030?ooo`000000oooo0080oooo00H00000
0?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00D0000000<0oooo000000000000
0P0000001@3oool000000?ooo`000000oooo0080000000<0oooo0000003oool00`3oool00`000000
oooo00000008000000<0oooo00@000000?ooo`00000000002@3oool00`000000oooo0?ooo`0J0?oo
o`00@`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000001P3oool300000080oooo0P0000070?ooo`040000003oool0oooo0?ooo`<000000P3oool2
00000080oooo0`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P000003
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`00000000000P3oool3000000<0oooo00@0
00000?ooo`3oool000000P3oool3000000030?ooo`000000oooo00@0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00X0oooo0`0000050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P0000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`800000
103oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0
000000L0oooo0P0000060?ooo`8000000P3oool2000000030?ooo`000000oooo00X0oooo00<00000
0?ooo`3oool00`3oool2000000030?ooo`000000oooo00D0oooo0`0000020?ooo`030000003oool0
oooo00X0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`020?ooo`800000103o
ool01@000000oooo0000003oool0000000@0oooo00@000000?ooo`3oool000002`3oool00`000000
oooo0?ooo`0J0?ooo`00@`3oool2000000L0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`05
0000003oool0oooo0?ooo`0000001@3oool4000000@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo00000002
0?ooo`040000003oool0oooo0?ooo`<0000000@0oooo0000003oool000000`3oool2000000H0oooo
0P0000030?ooo`80000000<0oooo0000000000000`3oool01@000000oooo0?ooo`3oool0000000P0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`0000000P3oool2000000/0oooo00<000000?ooo`0000002`3oool00`000000oooo000000020000
00D0oooo0`0000060?ooo`8000000P3oool00`000000oooo0?ooo`02000000@0oooo0P0000030?oo
o`030000003oool0000000D0oooo0P0000020?ooo`040000003oool0oooo000000L0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`80000000@0oooo000000000000oooo
0`0000020?ooo`<0000000<0oooo0000003oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0000000@000001P3oool01P000000oooo0000003oool000000?ooo`80000000H0oooo0000
003oool0oooo0000003oool2000000X0oooo0P0000040?ooo`@0000000D0oooo0000003oool0oooo
000000060?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool2000001`0
oooo00130?ooo`030000003oool0oooo00H0oooo0P0000020?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool0oooo100000020?ooo`<000001P3oool2000000030?ooo`000000oooo0080
oooo0`0000090?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`<00000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000<0000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00@000000?ooo`0000000000203oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`0000001@3oool3000000050?ooo`000000oooo0?ooo`0000001`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00P000000?ooo`000000
00000?ooo`000000oooo00000080oooo1@0000000`3oool000000?ooo`030?ooo`030000003oool0
000000@0oooo00@000000?ooo`000000oooo100000070?ooo`060000003oool000000?ooo`000000
oooo0P0000060?ooo`800000103oool00`000000oooo000000030?ooo`8000001P3oool200000004
0?ooo`000000oooo0?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool06P3oool004<0oooo00<000000?ooo`3oool0103oool010000000
oooo0?ooo`0000040?ooo`050000003oool000000?ooo`0000000P3oool4000000@0oooo0P000005
0?ooo`80000000<0oooo0000003oool00`3oool2000000T0oooo0P0000020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0000000D0oooo000000000000oooo000000040?ooo`040000003oool00000000000L0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03000000030?ooo`000000oooo0140oooo
00P000000?ooo`3oool000000?ooo`000000oooo000000H0oooo00<000000?ooo`0000002P3oool0
1P000000oooo0?ooo`000000oooo000000T0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0?0?ooo`050000003oool000000?ooo`0000001@3oool2000000040?ooo`000000oooo0000
00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo
000000H0oooo0P0000030?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool05@3oool0
1@000000oooo0000003oool0000000/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool06P3oool004<0oooo00<00000
0?ooo`3oool0103oool3000000D0oooo00D000000?ooo`000000oooo0000000:0?ooo`80000000@0
oooo0000003oool000000`3oool00`000000oooo000000090?ooo`030000003oool0oooo0080oooo
00D000000?ooo`000000oooo0000000;0?ooo`030000003oool0oooo00@0oooo00P000000?ooo`3o
ool000000?ooo`000000oooo00000080oooo00<000000?ooo`3oool02P3oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo00D000000P3oool01P000000oooo0?ooo`000000oooo0000
0080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0103oool00`000000oooo000000030?ooo`800000103oool2000000@0oooo00H00000
0?ooo`3oool000000?ooo`0000020?ooo`030000003oool0000000<0oooo00H000000?ooo`3oool0
00000?ooo`00000E0?ooo`030000003oool0oooo00<0oooo0P000000103oool000000?ooo`000003
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0203oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00d0oooo0P00000:0?ooo`8000004@3oool00`000000oooo0?ooo`02000000T0oooo
00<000000?ooo`3oool06P3oool004<0oooo00<000000?ooo`3oool01@3oool2000000040?ooo`00
0000oooo000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0000000000020?ooo`050000003oool000000?ooo`0000000`3o
ool01@000000oooo0000003oool000000080oooo00@000000?ooo`3oool0oooo0`00000B0?ooo`04
0000003oool00000000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`0000000P3oool00`000000oooo000000020000
0080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0000000L0oooo00H0
00000?ooo`000000oooo0000003oool200000080oooo00@000000?ooo`3oool0oooo0P0000020?oo
o`80000000D0oooo0000003oool0oooo000000020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool00`000000oooo000000020?ooo`80000000<0oooo0000000000008`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00P0oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`0000003@3oool00`000000oooo0?ooo`090?ooo`8000001`3oool00`00
0000oooo0?ooo`0:0?ooo`8000002@3oool00`000000oooo0?ooo`0J0?ooo`00@`3oool00`000000
oooo0?ooo`070?ooo`80000000<0oooo0000000000000P3oool00`000000oooo0?ooo`020?ooo`80
000000<0oooo0000000000000P3oool00`000000oooo000000020?ooo`030000003oool000000080
oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool00P3oool200000080oooo00<000000?ooo`3oool00`3oool200000080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0000000200000080oooo0`0000001P3oool000000?ooo`3oool00000
0?ooo`<0000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`80000000<0oooo
0000003oool00`3oool01P000000oooo0?ooo`3oool000000?ooo`8000000P3oool010000000oooo
0?ooo`3oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000060?ooo`030000003oool0oooo00@0oooo0P0000000`3oool000000?ooo`0<0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000000P0oooo00<000000?ooo`3oool04@3oool01@000000oooo0?ooo`3oool0
000000L0oooo00@000000?ooo`3oool000000P3oool2000000<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00H000000?ooo`3oool00000
0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0J0?ooo`00@`3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000<0oooo
00@000000?ooo`3oool000000`3oool200000080oooo00L000000?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo00000002000000L0oooo00<00000
0?ooo`3oool01P3oool010000000oooo0?ooo`0000030?ooo`050000003oool000000000003oool0
0P0000080?ooo`8000000`3oool2000000030?ooo`000000oooo00@0000000@0oooo0000003oool0
00000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`080?ooo`030000003oool000000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`8000001P3oool0
0`000000oooo0000000=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`8000001`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00H0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`<00000
303oool00`000000oooo0?ooo`0J0?ooo`00@`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool01`000000oooo0?ooo`3oool000000?ooo`00
00001`3oool02@000000oooo0000003oool000000?ooo`000000oooo000000070?ooo`030000003o
ool0oooo00d0oooo00@000000?ooo`000000oooo0P0000020?ooo`030000003oool0oooo00/0oooo
00D000000?ooo`3oool000000?ooo`02000000030?ooo`000000oooo00T0oooo0P0000020?ooo`80
00001`3oool00`000000oooo0?ooo`040?ooo`060000003oool0oooo0?ooo`000000oooo0P000000
0`3oool000000?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo0000000?0?ooo`040000
003oool0oooo0?ooo`8000000P3oool00`000000oooo0?ooo`03000000H0oooo0`00000@0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000070?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool2000001H0oooo00<000000?ooo`3o
ool00`3oool2000000@0oooo00@000000?ooo`00000000002P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00L0oooo0P00000<0?ooo`030000003oool0oooo01X0oooo00130?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0
000000L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo008000000`3oool010000000oooo0000000000070?ooo`060000003oool0oooo0000003oool0
00000`3oool00`000000oooo0?ooo`090?ooo`<000000P3oool2000000H0oooo00<000000?ooo`3o
ool01@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`02000000040?ooo`000000oooo000000`0oooo00<000000?ooo`3oool00P3oool2
00000080oooo00<000000?ooo`3oool00P0000070?ooo`@000003`3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000000L0oooo00@000000?ooo`3oool0oooo0P0000070?ooo`030000
003oool0000000P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0E0?ooo`040000
003oool0oooo00000080oooo0P0000040?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000001D0oooo00<000000?ooo`3o
ool06P3oool004<0oooo00<000000?ooo`3oool0303oool00`000000oooo000000020?ooo`800000
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`030?ooo`80000000<0oooo0000003oool01@3oool3000000H0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0000000000030?ooo`030000003oool0oooo00D0oooo0P000002
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`02000000<0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo
00@000000?ooo`3oool000002`3oool00`000000oooo000000020?ooo`8000000P3oool00`000000
oooo000000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0000000L0oooo00@000000?ooo`00000000000`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06P3oool0
04<0oooo0P00000:0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool2
000002D0oooo0P0000030?ooo`8000001@3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0
oooo0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`050000003oool000000000003oool0
0P00000<0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020000
00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P0000000`3o
ool00000000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`020?ooo`8000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00P0oooo0P00000L0?ooo`00@`3oool00`000000oooo0?ooo`050?ooo`050000003oool000000?oo
o`0000002`3oool010000000oooo0?ooo`3oool2000000040?ooo`000000oooo000000D0oooo00@0
00000?ooo`3oool000000P3oool2000000L0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`020?ooo`8000005@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3o
ool0103oool2000000P0oooo0`0000070?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3o
ool0oooo000000070?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`03000000L0oooo00<000000?ooo`0000003@3oool01@000000oooo0?ooo`3oool0
000000`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00H0oooo0P00000:0?ooo`8000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0080oooo0P0000030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool06P3o
ool004<0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000030?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003oool0000000D0oooo00@0
00000?ooo`00000000000P3oool2000000L0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool2000000<0oooo
00D000000?ooo`3oool0oooo000000090?ooo`040000003oool0oooo000000D0oooo0`0000070?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo0?ooo`<000001P3oool00`000000oooo0000000<0?ooo`8000000`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000001P3oool00`000000oooo
0?ooo`060?ooo`8000003P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0J0?ooo`00@`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool00000
00L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0000000;0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0200000080oooo00<00000
0?ooo`3oool01@3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00@0
00000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000000<0oooo0P0000060?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`07
0000003oool0oooo0?ooo`000000oooo0000000:0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01@3oool010000000oooo0?ooo`00000<0?ooo`040000003oool0oooo00000100oooo
00D000000?ooo`3oool0oooo0000000M0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000H0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01X0oooo00130?ooo`03
0000003oool0oooo00D0oooo00@000000?ooo`3oool000001@3oool01@000000oooo0?ooo`3oool0
00000080oooo0P0000020?ooo`030000003oool0oooo00D0oooo00H000000?ooo`3oool000000?oo
o`0000040?ooo`030000003oool0oooo00@0oooo0P0000000`3oool000000?ooo`090?ooo`030000
003oool0oooo0080oooo0P0000080?ooo`<0000000<0oooo0000003oool01P3oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool30000
00070?ooo`000000oooo0?ooo`000000oooo000000060?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`090?ooo`8000001@3oool400000080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0603oool2000000<0
oooo00<000000?ooo`3oool02@3oool00`000000oooo000000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`0J0?ooo`00@`3oool00`000000oooo
0?ooo`070?ooo`8000002@3oool00`000000oooo0?ooo`0200000080oooo0P0000040?ooo`050000
003oool0oooo0?ooo`0000001@3oool00`000000oooo000000060?ooo`80000000@0oooo0000003o
ool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`000000103oool00`000000oooo0?ooo`03000000T0oooo0P000000103oool000000?ooo`000003
0?ooo`030000003oool0oooo00H0oooo0P0000000`3oool00000000000020?ooo`030000003oool0
oooo00`0oooo00@000000?ooo`3oool0oooo0P0000040?ooo`<00000103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`090?ooo`8000001@3oool3000000040?ooo`000000oooo000000<0oooo00@000000?ooo`3oool0
00000`3oool2000000@0oooo00<000000?ooo`3oool0503oool01P000000oooo000000000000oooo
000000P0oooo00<000000?ooo`3oool00P3oool2000000X0oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo01X0oooo00130?ooo`030000003oool0oooo00L0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0000000P0oooo00<000000?ooo`0000000P3o
ool3000000030?ooo`000000oooo00@0oooo0P0000060?ooo`<000000`3oool00`000000oooo0?oo
o`02000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0000000:0?ooo`<000000`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00H0oooo0P0000090?ooo`8000001`3oool00`000000oooo0?ooo`0<0?ooo`800000103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo000000020?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool0oooo0`000000
1@3oool000000?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`090?ooo`040000003oool0oooo0?ooo`8000005`3oool00`000000oooo0?ooo`0J0?ooo`00
@`3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`00
00002P3oool010000000oooo0?ooo`3oool2000000P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool20000
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`0000001`3oool010000000oooo0?ooo`00000<0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`<000004`3oool00`000000oooo0?oo
o`030?ooo`8000000P3oool01P000000oooo0?ooo`3oool000000?ooo`8000000P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000003`3oool00`00
0000oooo0?ooo`080?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool03`3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00@000000?ooo`00000000000`3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000002@3oool010000000
oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0J0?oo
o`00@`3oool00`000000oooo0?ooo`070?ooo`8000000`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0000000D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00L0oooo0P0000030?ooo`030000003oool0oooo01P0oooo00@000000?ooo`00
000000001P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool0103oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`8000000`3oool01@000000oooo
0?ooo`3oool000000080oooo0P0000000`3oool000000?ooo`0;0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000<0?ooo`040000003oool00000
000000<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00`0oooo00D000000?ooo`3oool0oooo000000040?ooo`80000000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0203o
ool010000000oooo0?ooo`3oool200000180oooo00<000000?ooo`3oool06P3oool004<0oooo0P00
00060?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`070?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000040?ooo`04
0000003oool0oooo000000<0oooo00@000000?ooo`3oool000000`3oool300000180oooo0P000000
0`3oool000000?ooo`0<0?ooo`8000000`3oool010000000oooo0?ooo`3oool2000000D0oooo00@0
00000?ooo`3oool0oooo0P000000103oool000000000000000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000050?ooo`8000000`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000503oool0
1`000000oooo0?ooo`000000oooo0000003oool00P0000000`3oool000000?ooo`090?ooo`040000
003oool00000000000<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000000D0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00P0000080?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`800000703oool004<0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`800000103oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`00000000000`3oool2000000D0oooo
00<000000?ooo`3oool02`3oool2000000040?ooo`000000oooo000000/0oooo0P0000030?ooo`03
0000003oool0oooo0080oooo0P0000030?ooo`030000003oool0oooo0080oooo0P000000103oool0
00000000000000080?ooo`030000003oool0oooo008000000P3oool2000000050?ooo`000000oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`800000203oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0
oooo00<000000?ooo`3oool00P3oool2000000/0oooo00P000000?ooo`3oool000000?ooo`000000
oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000:0?ooo`050000
003oool0oooo0?ooo`0000002@3oool00`000000oooo000000050?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0
oooo00H000000?ooo`000000oooo0000003oool3000000@0oooo00<000000?ooo`3oool01P3oool3
000000030?ooo`000000000000X0oooo00<000000?ooo`3oool06P3oool004<0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`02000000D0oooo0P0000090?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`8000000`3oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02P3oool2
000000@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`02000000L0oooo00<00000
0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`040000003oool00000000000<0oooo00<0
00000?ooo`0000000P3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`000000
203oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool20000
00D0oooo00<000000?ooo`3oool00P0000040?ooo`<000002P3oool010000000oooo0?ooo`3oool2
000000<0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000>0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0080oooo0`0000001@3oool000000?ooo`3oool0000000`0oooo00@000000?ooo`000000
oooo0`0000000`3oool000000?ooo`040?ooo`060000003oool0oooo0?ooo`000000oooo0`000000
0`3oool000000000000:0?ooo`030000003oool0oooo01X0oooo00130?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool00`3oool010000000oooo00000000000B0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`8000000`3oool01P000000
oooo0?ooo`3oool000000?ooo`8000000`3oool2000000030?ooo`000000oooo00@0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`@000000P3oool00`000000oooo00000002
0?ooo`030000003oool0000000L0oooo0P0000030?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`060000003oool0oooo0?ooo`000000oooo
0P0000030?ooo`80000000<0oooo000000000000103oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo008000001@3oool010000000oooo0?ooo`0000050?ooo`040000003oool000000000
00T0oooo00<000000?ooo`3oool00P3oool3000000050?ooo`000000oooo0?ooo`000000203oool0
0`000000oooo0?ooo`02000000030?ooo`000000oooo0080oooo00<000000?ooo`0000001@3oool0
1@000000oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool06P3oool004<0oooo00<00000
0?ooo`3oool01P3oool200000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3o
ool2000000050?ooo`000000oooo0?ooo`0000002`3oool00`000000oooo0?ooo`0200000080oooo
00<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<000000P3oool200000080
oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000P3oool010000000
oooo0?ooo`00000A0?ooo`<00000103oool01@000000oooo0?ooo`000000oooo0080000000<0oooo
0000003oool00`3oool010000000oooo0000003oool200000080oooo00<000000?ooo`3oool0203o
ool200000080oooo0`0000060?ooo`030000003oool0oooo01P0oooo00@000000?ooo`0000000000
103oool010000000oooo0000000000020?ooo`030000003oool0oooo008000000P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo008000000`3oool00`000000oooo000000020?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`020000
00030?ooo`000000oooo00/0oooo00<000000?ooo`3oool00P0000050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01X0oooo00130?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000P0000000`3oool0
00000?ooo`030?ooo`040000003oool0oooo0?ooo`8000000P3oool010000000oooo000000000009
0?ooo`8000000P3oool2000000@0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`030000003o
ool0oooo008000002`3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`00
00001P3oool00`000000oooo000000040?ooo`040000003oool0oooo00000140oooo0`0000040?oo
o`030000003oool0oooo00@0000000<0oooo0000003oool00`3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000020?ooo`040000003oool00000000000@0oooo0P0000020?ooo`03
0000003oool0000000H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`@0
00000P3oool2000000060?ooo`000000oooo0000003oool000000P3oool200000080oooo0P000003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`040?ooo`8000000P3oool010000000oooo0?ooo`0000080?ooo`8000002P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo00130?ooo`030000003oool0oooo00@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00`0000030?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`080000003oool0oooo0?oo
o`000000oooo0000003oool200000080oooo0`0000000`3oool000000000000;0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`040000003o
ool0oooo000000P0oooo00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`000000
1@3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
0000103oool010000000oooo00000000000;0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03`3oool400000080oooo00H000000?ooo`3oool000000?ooo`0000060?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`80000000<0oooo0000
003oool0103oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01X0oooo00130?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`040000003oool0
oooo0?ooo`8000000`3oool3000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
00030?ooo`<000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000P0
oooo00<000000?ooo`3oool00P3oool2000000050?ooo`000000oooo0?ooo`0000001@3oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool3
000000040?ooo`000000oooo0?ooo`800000103oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo008000002@3oool2000000T0oooo0P0000030?ooo`030000003oool0oooo00X0oooo1000
00060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000103oool2000000030?ooo`00
0000oooo00D0oooo00@000000?ooo`0000000000203oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01X0oooo00130?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`080?ooo`8000000P3oool00`000000oooo0000000>0?ooo`030000003oool00000
0080oooo0P0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool20000
00@0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo1@0000020?ooo`8000000`3oool2000000h0oooo0P0000020?ooo`030000003oool0
oooo008000000`3oool00`000000oooo0?ooo`030?ooo`8000002@3oool2000000<0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`D000001@3oool010000000oooo0?ooo`00
00050?ooo`050000003oool000000?ooo`0000000P3oool2000000030?ooo`000000000000L0oooo
0`00000H0?ooo`030000003oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo
000000080?ooo`030000003oool0oooo01X0oooo00130?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool02@3oool2000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0000
00040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000
00050?ooo`8000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00@0
00000?ooo`3oool0oooo0P0000040?ooo`800000103oool2000000D0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo00`0oooo0P0000060?ooo`<00000103oool00`000000
oooo00000003000000`0oooo0P0000090?ooo`8000000P3oool01@000000oooo0000003oool00000
0100oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo
0000003oool0000000D0oooo0P0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00000P3oool2000000030?ooo`000000oooo0080oooo00D000000?ooo`3oool0oooo000000080?oo
o`030000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000:0?oo
o`030000003oool0oooo01X0oooo00130?ooo`8000001@3oool01@000000oooo0?ooo`3oool00000
00@0oooo0P0000020?ooo`040000003oool0oooo0?ooo`800000103oool01@000000oooo0?ooo`3o
ool000000080oooo0P00000:0?ooo`030000003oool0oooo00@0oooo00L000000?ooo`3oool0oooo
0000003oool0000000X0oooo00<000000?ooo`3oool00`3oool2000000P0oooo00@000000?ooo`00
00000000103oool2000000<0oooo00<000000?ooo`3oool00P0000001@3oool000000000003oool0
00000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000000D0oooo00@0
00000?ooo`3oool0oooo0`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<000001@3oool00`00
0000oooo0?ooo`0?0?ooo`8000000P3oool00`000000oooo0000000<0?ooo`030000003oool0oooo
00`0oooo0P0000020?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P0000070?ooo`030000003oool000000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080000000H0oooo0000003oool0
00000?ooo`0000030?ooo`050000003oool0oooo0?ooo`000000203oool2000000<0oooo00<00000
0?ooo`0000002`3oool2000001`0oooo00130?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00P3oool2000000H0oooo0P0000030?ooo`8000000`3oool01@000000oooo0?ooo`3oool0
000000H0oooo0`0000001@3oool000000?ooo`3oool0000000@0oooo0P000000103oool000000?oo
o`00000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool010000000oooo
0?ooo`0000040?ooo`8000000`3oool00`000000oooo0?ooo`02000000050?ooo`00000000000?oo
o`0000000P3oool00`000000oooo0?ooo`060?ooo`80000000<0oooo0000000000000P3oool01000
0000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000004
0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`05
0?ooo`040000003oool0oooo00000240oooo0P0000080?ooo`8000000`3oool01@000000oooo0000
003oool000000140oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0080
00000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`00
0000oooo0P0000030?ooo`8000001`3oool400000080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo01X0oooo00130?ooo`030000003oool0oooo01X0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo008000000P3oool30000
00@0oooo00<000000?ooo`3oool00P3oool2000000@0oooo0P0000090?ooo`800000203oool01000
0000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000001P3oool300000080oooo00<00000
0?ooo`3oool01`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool200000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000D0
oooo0P000000103oool000000000000000040?ooo`040000003oool0oooo000000@0oooo00L00000
0?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool06P3oool004<0oooo00<000000?ooo`3oool0303oool00`000000oooo0000000?
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000P0000020?ooo`80000000<0oooo
0000003oool03@3oool3000000T0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`0000000`3oool200000080oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo000000060?ooo`040000003oool0oooo0?ooo`8000002@3oool00`000000
oooo000000060?ooo`800000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0300000080oooo00H000000?ooo`3oool000000?ooo`00
00050?ooo`8000001@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
0P3oool01`000000oooo0?ooo`3oool000000?ooo`0000002@3oool010000000oooo0?ooo`000002
0?ooo`D000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0P000002
0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`8000000P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool2000000@0oooo00<000000?ooo`3oool0103oool2000000<0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool06P3o
ool003<0oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`0000000P3oool00`000000oooo0000000>0?ooo`030000003oool0
oooo00<0oooo0`0000001@3oool000000?ooo`3oool000000080oooo00H000000?ooo`3oool00000
0?ooo`00000;0?ooo`060000003oool0oooo0000003oool000002P3oool01@000000oooo0?ooo`3o
ool0000000L0oooo00<000000?ooo`0000000P3oool300000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`080?ooo`040000003oool00000000000@0oooo0P0000030?ooo`030000
003oool0oooo00<0oooo0P00000=0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo008000000`3oool01P000000oooo0?ooo`000000oooo
000000@0oooo0`0000050?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`070?ooo`030000
003oool0000000<000000P3oool01@000000oooo0000003oool0000000@0oooo100000020?ooo`<0
000000L0oooo0000003oool0oooo0000003oool0000000L0oooo0P0000020?ooo`8000001P3oool0
0`000000oooo000000050?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool0oooo
0P0000000`3oool000000?ooo`030?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool06P3oool003D0oooo00<0
okmd0000001d_ol02`3oool00`000000oooo0?ooo`040?ooo`80000000@0oooo0000003oool00000
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0
oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`060000003oool0
oooo0000003oool000003P3oool010000000oooo0000000000030?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool0oooo0`0000000`3oool00000000000070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`0000002P3oool010000000oooo0000000000080?ooo`80000000L0oooo
0000003oool0oooo0000003oool0000000X0oooo00<000000?ooo`3oool01@3oool010000000oooo
0000003oool2000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo000000060?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`0000000000203oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000040?ooo`@000000P3o
ool200000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool00P0000020?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo000e0?ooo`030?oog`2L
B00007Bo00/0oooo00<000000?ooo`3oool0103oool2000000<0oooo00<000000?ooo`0000000P3o
ool2000000<0oooo00<000000?ooo`0000000P3oool2000000D0oooo00<000000?ooo`0000001P3o
ool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool02P3oool2000000030?oo
o`000000oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`800000
00<0oooo0000000000000P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000<0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0000000:0?ooo`030000003oool00000
0080000000<0oooo0000003oool02`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`000000100000030?ooo`80000000@0oooo0000003oool000001P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000002@3oool010000000oooo0?oo
o`3oool2000000070?ooo`000000oooo0?ooo`000000oooo000000030?ooo`040000003oool0oooo
000000H0oooo00@000000?ooo`000000oooo0P0000060?ooo`040000003oool000000?ooo`@00000
00<0oooo0000003oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000<0oooo
0P0000020?ooo`040000003oool0oooo000000L0oooo00P000000?ooo`3oool000000?ooo`000000
oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`<00000
00@0oooo0000003oool000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01X0
oooo000f0?ooo`030=nLB000B9`0gooo00X0oooo00<000000?ooo`3oool0203oool2000000040?oo
o`000000oooo0?ooo`8000001@3oool00`000000oooo0?ooo`03000000@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool01@3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo0P0000020?ooo`050000
003oool0oooo0000003oool00P0000030?ooo`80000000<0oooo0000003oool00`3oool00`000000
oooo0?ooo`040?ooo`80000000<0oooo0000003oool0103oool010000000oooo0?ooo`0000090?oo
o`040000003oool0oooo0?ooo`@000000P3oool00`000000oooo0?ooo`05000000030?ooo`000000
00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02000000@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000000`3oool2000000H0oooo
00@000000?ooo`000000oooo0P00000:0?ooo`@0000000D0oooo0000003oool0oooo0000000D0?oo
o`800000303oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool00P3oool40000
00050?ooo`00000000000?ooo`0000000P3oool5000000050?ooo`000000oooo0?ooo`000000203o
ool00`000000oooo0?ooo`0J0?ooo`00=P3oool00`3ogi`0B01809cOo`0:0?ooo`030000003oool0
oooo00P0oooo00D000000?ooo`3oool000000?ooo`02000000T0oooo00<000000?ooo`000000203o
ool200000080oooo00<000000?ooo`3oool00`3oool2000000<0oooo00D000000?ooo`3oool00000
0?ooo`02000000<0oooo00<000000?ooo`3oool01P3oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00@000000?ooo`000000oooo0P0000070?ooo`040000003oool00000000000<0oooo0P00
00020?ooo`8000000P3oool00`000000oooo000000020?ooo`8000000P3oool3000000<0oooo00@0
00000?ooo`00000000001P3oool2000000L0oooo00<000000?ooo`3oool00P000000103oool00000
0?ooo`0000020?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo000000020?oo
o`050000003oool000000000003oool00`0000020?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`0000000P3oool2000000040?ooo`000000oooo0?ooo`<0000000D0oooo0000003oool0
oooo000000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool01`000000
oooo0?ooo`3oool000000?ooo`0000002`3oool010000000oooo0?ooo`0000030?ooo`040000003o
ool0oooo0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`0000001P3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`000000
0`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo0?ooo`@0000000D0oooo0000
003oool0oooo000000020?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool06P3o
ool003H0oooo00<0oono07@0001d_ol02P3oool3000000H0oooo00<000000?ooo`3oool0103oool0
1P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo0P0000000`3oool00000000000030?ooo`800000
00<0oooo0000000000000P0000090?ooo`040000003oool0oooo00000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`040000003o
ool000000?ooo`8000000P3oool2000000030?ooo`000000oooo008000000P3oool2000000D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0000000:0?ooo`8000001@3oool00`000000oooo
0?ooo`03000000060?ooo`000000oooo0?ooo`000000oooo0`0000040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000P3oool3000000@0oooo00@000000?ooo`000000oooo0P00
00060?ooo`030000003oool000000080000000<0oooo0000003oool02@3oool2000000D0oooo0P00
00030?ooo`080000003oool0oooo0000003oool000000?ooo`0000030?ooo`800000103oool00`00
0000oooo0?ooo`03000000040?ooo`000000oooo000000@0oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`0000000P0000030?ooo`030000003oool0000000<0oooo
00L000000?ooo`3oool000000?ooo`000000oooo008000000P3oool2000000D0oooo0`0000040?oo
o`030000003oool000000080oooo00<000000?ooo`3oool01@3oool3000001`0oooo000g0?ooo`03
0;md0000M;l0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo000000030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`000000100000040?ooo`800000203oool00`000000
oooo0?ooo`020?ooo`80000000@0oooo00000000000000000`3oool01@000000oooo000000000000
oooo008000000`3oool01@000000oooo0?ooo`000000oooo0080000000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool00`0000001@3oool000000000
00000000oooo008000000`3oool00`000000oooo0?ooo`0400000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000050?ooo`800000103oool00`000000oooo000000030?ooo`800000
1@3oool01@000000oooo0?ooo`3oool0000000D0oooo00H000000?ooo`3oool000000?ooo`000002
0?ooo`040000003oool00000000000P0oooo00<000000?ooo`3oool00P0000070?ooo`030000003o
ool000000080oooo0P0000001@3oool000000?ooo`3oool0000000<0oooo00@000000?ooo`000000
oooo0P0000030?ooo`80000000<0oooo0000003oool01@0000001@3oool000000?ooo`3oool00000
00H0oooo00D000000?ooo`3oool000000?ooo`05000000030?ooo`000000oooo0080000000<0oooo
0000003oool00`3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool010000000
0`3oool00000000000050?ooo`80000000@0oooo0000003oool00000103oool010000000oooo0?oo
o`3oool2000000H0oooo00<000000?ooo`3oool00`0000020?ooo`050000003oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`04000000D0oooo0P0000000`3oool000000?ooo`080?ooo`03
0000003oool0oooo01X0oooo000g0?ooo`030=nLB000B9`0gooo00T0oooo00<000000?ooo`3oool0
103oool010000000oooo0000000000020?ooo`030000003oool0000000H0oooo0P0000001`3oool0
00000?ooo`3oool000000?ooo`0000001@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P0000001P3oool000000000003oool000000?ooo`8000000`3oool300000080
oooo0P0000001`3oool000000?ooo`3oool000000?ooo`0000000`3oool00`000000oooo00000003
0?ooo`030000003oool0oooo0080oooo0P0000000`3oool0000000000006000000<0oooo10000000
1@3oool000000?ooo`3oool0000000D0oooo00D000000?ooo`000000oooo000000050?ooo`@00000
0P3oool01@000000oooo000000000000oooo00<00000103oool3000000040?ooo`00000000000000
00<0oooo00<000000?ooo`0000000P3oool5000000040?ooo`0000000000000000X0oooo0P000003
0?ooo`0:0000003oool000000?ooo`000000oooo0000003oool000000?ooo`8000000`3oool00`00
0000oooo0?ooo`020?ooo`8000000`3oool5000000030?ooo`000000oooo0080oooo0P0000001P3o
ool00000000000000000oooo000000<0oooo00<000000?ooo`3oool00P0000000`3oool000000?oo
o`02000000040?ooo`00000000000?ooo`@0000000<0oooo0000003oool00P3oool200000080oooo
0P0000000`3oool000000?ooo`040?ooo`80000000@0oooo000000000000oooo0P0000020?ooo`80
00000P3oool010000000oooo0000000000030?ooo`030000003oool0oooo008000000`3oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0000000000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`02000000030?ooo`000000oooo00@0oooo0P0000020?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool06P3oool003L0oooo00<0omnL04P0B02Lgol02@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00<000000P3oool010000000oooo0?ooo`3o
ool2000000050?ooo`000000oooo0?ooo`000000103oool00`000000oooo00000002000000@0oooo
1P0000040?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo000000030?ooo`030000
003oool0000000<0oooo00D000000?ooo`3oool000000?ooo`03000000040?ooo`000000oooo0?oo
o`8000000`3oool00`000000oooo0?ooo`020?ooo`8000000P3oool200000080oooo100000050?oo
o`80000000@0oooo00000000000000001@3oool00`000000oooo00000005000000<0oooo00@00000
0?ooo`000000oooo0`0000040?ooo`<0000000<0oooo0000000000000P0000020?ooo`030000003o
ool000000080oooo00@000000?ooo`0000000000103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`020?ooo`040000
003oool000000?ooo`800000203oool01@000000oooo0?ooo`000000oooo00<0000000<0oooo0000
000000000P0000040?ooo`@000000P3oool01@000000oooo0?ooo`000000oooo00@0000000@0oooo
0000000000000000103oool4000000040?ooo`000000oooo0?ooo`<000001@3oool3000000L0oooo
00P000000?ooo`00000000000?ooo`000000oooo00000080oooo10000000103oool000000?ooo`00
00070?ooo`040000003oool0oooo000000D0oooo0P0000050?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool2000000P0oooo00<00000
0?ooo`3oool06P3oool003L0oooo00<0oono07@0001d_ol02@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo008000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo
0080oooo00L000000?ooo`3oool000000?ooo`000000oooo00<0000000H0oooo0000003oool0oooo
0000003oool3000000030?ooo`000000oooo0080oooo0P0000000`3oool000000?ooo`020?ooo`03
0000003oool0oooo00<000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0080000000@0oooo000000000000oooo0P0000030?ooo`050000003oool000000?ooo`0000000P3o
ool01@000000oooo0?ooo`000000oooo008000001P3oool01@000000oooo000000000000oooo00<0
00001@3oool00`000000oooo00000002000000070?ooo`00000000000?ooo`000000oooo00000008
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0=0?ooo`8000000P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool0103oool010000000oooo0000003oool200000080oooo0`0000020?oo
o`030000003oool0oooo0080000000T0oooo0000003oool0oooo0000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`04000000060?ooo`000000oooo0000003oool000001P3oool01P00
0000oooo0?ooo`3oool000000?ooo`<0000000D0oooo0000003oool000000?ooo`03000000D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`<0000000L0oooo00000000000000000?ooo`000000
oooo008000000P3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`000000
2`3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`3oool000000?ooo`020000
00030?ooo`000000000000T0oooo00<000000?ooo`3oool06P3oool003P0oooo00<0_g@0001d_`3o
ool0203oool00`000000oooo0?ooo`080?ooo`040000003oool00000000000D0oooo00<000000?oo
o`3oool01@3oool2000000040?ooo`000000oooo00000080oooo00D000000?ooo`3oool000000?oo
o`02000000<0oooo00<000000?ooo`0000000P00000;0?ooo`@000000P3oool01@000000oooo0?oo
o`000000oooo00<000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool000000080oooo
00<000000?ooo`3oool00P3oool4000000@0oooo0P0000020?ooo`050000003oool000000000003o
ool00P0000000`3oool000000?ooo`02000000030?ooo`00000000000080000000@0oooo0000003o
ool000000P3oool200000080oooo00D000000?ooo`000000oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`000000
103oool3000000@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo0`0000000`3oool00000000000020?ooo`8000000`3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`00000000000P3oool3000000040?ooo`000000
00000?ooo`8000000`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000060?oo
o`030000003oool0000000<0oooo1P0000030?ooo`040000003oool0oooo00000080oooo0`000000
0`3oool00000000000020?ooo`8000000`3oool00`000000oooo00000004000000030?ooo`000000
oooo0080000000@0oooo0000003oool000002@3oool2000000P0oooo0P0000000`3oool000000?oo
o`02000000030?ooo`000000000000T0oooo00<000000?ooo`3oool06P3oool003H0oooo00D0oono
07@000000000001d0;ooo`080?ooo`030000003oool0oooo00H0oooo00@000000?ooo`0000000000
0P3oool010000000oooo0?ooo`0000060?ooo`D0000000P0oooo0000003oool000000?ooo`000000
oooo000000<0oooo0P0000060?ooo`<0000000<0oooo0000000000000`3oool020000000oooo0000
00000000oooo0000003oool000000P3oool01@000000oooo0?ooo`000000oooo00<000003@3oool2
00000080oooo00T000000?ooo`3oool000000?ooo`000000oooo0000003oool00P0000000`3oool0
00000?ooo`020?ooo`040000003oool0000000000080oooo00D000000?ooo`00000000000?ooo`04
000000040?ooo`0000000000000000@0oooo00<000000?ooo`3oool00P0000020?ooo`030000003o
ool0oooo008000000P3oool010000000oooo0?ooo`3oool3000000030?ooo`000000oooo0080oooo
00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool00P0000030?oo
o`030000003oool0oooo008000000P3oool00`000000oooo000000040?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0100000000`3oool00000000000090?ooo`030000003oool0
oooo0080000000D0oooo00000000000000000?ooo`02000000030?ooo`000000000000<0oooo00<0
00000?ooo`3oool00P3oool2000000030?ooo`000000oooo00@0oooo0P0000050?ooo`80000000<0
oooo0000003oool00P3oool00`000000oooo000000020?ooo`80000000H0oooo0000003oool00000
0?ooo`0000050?ooo`@000000P3oool400000080oooo00<000000?ooo`0000000P0000000`3oool0
00000?ooo`050?ooo`030000003oool0oooo00<000001P3oool010000000oooo0000003oool20000
00h0oooo00<000000?ooo`3oool06P3oool004<0oooo00<000000?ooo`3oool01P3oool01@000000
oooo000000000000oooo0080000000D0oooo000000000000oooo000000040?ooo`L0000000<0oooo
0000003oool00`000000103oool000000?ooo`3oool2000000L0oooo00T000000?ooo`0000000000
0?ooo`000000oooo0000003oool00P0000000`3oool000000?ooo`05000000<0oooo00@000000?oo
o`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo008000000P3o
ool3000000070?ooo`000000oooo0?ooo`000000oooo000000030?ooo`030000003oool0000000<0
oooo00@000000?ooo`00000000000P3oool00`000000oooo0?ooo`02000000H0oooo0`0000040?oo
o`80000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`04000000030?ooo`000000oooo
0080oooo00<000000?ooo`3oool00P3oool200000080oooo0P0000001@3oool000000?ooo`000000
oooo00<000000P3oool3000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo00000000
00040?ooo`80000000@0oooo000000000000oooo0P00000<0?ooo`8000000`3oool01@000000oooo
0?ooo`000000oooo00800000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo00@000000?ooo`3oool000000P3oool4000000030?ooo`000000000000<0000000@0oooo0000
003oool000001@3oool3000000@0oooo0P0000030?ooo`040000003oool0000000000080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`060000003oool0oooo0000003oool000000P3oool02000
0000oooo0000003oool000000?ooo`000000oooo0P00000>0?ooo`030000003oool0oooo01X0oooo
00130?ooo`030000003oool0oooo00D0oooo00L000000?ooo`3oool0oooo0000003oool000000080
oooo00<000000?ooo`3oool00P0000020?ooo`<000000P3oool3000000040?ooo`000000oooo0?oo
o`80000000<0oooo0000003oool0100000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`0000020?ooo`030000003oool0000000H000001P3oool00`000000oooo0?ooo`020?oo
o`80000000<0oooo0000003oool00`3oool010000000oooo0000000000040?ooo`8000000`3oool2
000000030?ooo`000000oooo00@0oooo0P0000040?ooo`<00000103oool2000000030?ooo`000000
oooo0080oooo00@000000?ooo`00000000001@3oool400000080oooo00<000000?ooo`0000000P00
00030?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`3oool200000005
0?ooo`000000oooo0000003oool00P0000030?ooo`<000001`3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000001P3oool00`00
0000oooo0?ooo`070?ooo`8000000P3oool00`000000oooo000000090?ooo`050000003oool0oooo
0?ooo`0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`00
00020?ooo`030000003oool00000008000000`3oool010000000oooo0?ooo`00000=0?ooo`050000
003oool000000?ooo`0000001P3oool400000080oooo00@000000?ooo`3oool0oooo100000030?oo
o`030000003oool0000000<00000303oool00`000000oooo0?ooo`0J0?ooo`00@`3oool00`000000
oooo0?ooo`040?ooo`<00000103oool00`000000oooo0?ooo`030?ooo`8000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool00000008000000P3oool2000000<0oooo0P0000001@3oool0
0000000000000000oooo008000000`3oool00`000000oooo0?ooo`0300000080oooo00@000000?oo
o`0000000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool01P000000oooo000000000000oooo000000@0oooo0P0000030?ooo`<000000P3oool010000000
oooo0000003oool2000000<0oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool0
00000080oooo1@0000020?ooo`8000000P3oool2000000L0oooo00@000000?ooo`0000000000103o
ool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`<000000P3o
ool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`0000000P0000020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0000000200000080oooo00@000000?ooo`3oool0
0000103oool01P000000oooo0000003oool000000?ooo`8000000P3oool2000000@0oooo00<00000
0?ooo`0000001P3oool00`000000oooo0?ooo`02000000@0oooo100000030?ooo`80000000D0oooo
000000000000oooo000000020?ooo`8000000P3oool00`000000oooo0?ooo`02000000040?ooo`00
0000oooo000000H0oooo100000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
00000080oooo0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01X0oooo00130?ooo`8000001@3oool300000080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`8000000`3oool5000000<0oooo00<000000?ooo`3oool01@3oool20000
00060?ooo`00000000000000003oool000001P3oool00`000000oooo000000020?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000070?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000
oooo0000003oool2000000D0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003o
ool0oooo00<000000`3oool01@000000oooo0000003oool0000000D0oooo00L000000?ooo`3oool0
oooo0000003oool0000000D0oooo0P0000020?ooo`050000003oool000000?ooo`000000103oool4
000000030?ooo`000000oooo0080000000<0oooo0000000000000P0000000`3oool000000?ooo`04
00000080oooo0`0000040?ooo`8000000`3oool2000000040?ooo`000000000000000080oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`000000oooo00<000000P3oool00`000000oooo
000000050?ooo`060000003oool000000?ooo`000000oooo0`0000000`3oool00000000000030?oo
o`80000000<0oooo0000003oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103o
ool010000000oooo0000000000030?ooo`8000000P3oool300000080oooo0P0000020?ooo`040000
003oool00000000000/0oooo00@000000?ooo`3oool000000`3oool020000000oooo0?ooo`000000
oooo0000003oool000000P3oool2000000H0oooo00<000000?ooo`3oool01P3oool2000001`0oooo
00130?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool000000080oooo00H000000?ooo`3oool0oooo0000003oool2000000<0oooo0P0000000`3o
ool0000000000003000000X0oooo0`0000001@3oool000000?ooo`000000oooo0080000000<0oooo
0000003oool00`3oool00`000000oooo000000030?ooo`040000003oool00000000000<0oooo0P00
00030?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool0oooo0000003oool200000005
0?ooo`000000oooo0000003oool00P0000020?ooo`040000003oool00000000000P0oooo00<00000
0?ooo`0000000P0000002P3oool000000?ooo`3oool000000?ooo`000000oooo0000003oool20000
00040?ooo`000000oooo000000@0oooo0P0000020?ooo`@000000`3oool2000000030?ooo`000000
oooo0080oooo00L000000?ooo`00000000000?ooo`000000oooo00@0000000<0oooo0000003oool0
0P0000000`3oool0000000000002000000040?ooo`000000oooo0?ooo`<000000`3oool010000000
oooo0000003oool3000000<0oooo0`0000000`3oool000000?ooo`02000000D0oooo100000000`3o
ool00000000000040?ooo`030000003oool0000000800000203oool010000000oooo000000000002
0?ooo`030000003oool0000000800000103oool2000000030?ooo`000000oooo0080oooo0P000008
0?ooo`8000000P3oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool3000000030?ooo`000000oooo00D0oooo0P0000000`3oool000000?ooo`02
000000030?ooo`00000000000080oooo0P0000030?ooo`040000003oool00000000000<0oooo00<0
00000?ooo`0000002P3oool00`000000oooo0?ooo`0J0?ooo`00@`3oool00`000000oooo0?ooo`0=
0?ooo`040000003oool0oooo0?ooo`@000000P3oool00`000000oooo0?ooo`050?ooo`<000000`3o
ool00`000000oooo0?ooo`070?ooo`060000003oool000000?ooo`000000oooo0P0000080?ooo`04
0000003oool0oooo0?ooo`<000000`3oool010000000oooo0000000000020?ooo`030000003oool0
oooo0080oooo0P0000020?ooo`030000003oool000000080oooo00@000000?ooo`3oool0oooo0P00
00020?ooo`040000003oool00000000000<0oooo00D000000?ooo`3oool000000?ooo`0200000005
0?ooo`00000000000?ooo`000000103oool00`000000oooo00000003000000030?ooo`000000oooo
008000000`3oool2000000<0oooo00<000000?ooo`0000000`3oool2000000070?ooo`000000oooo
0000003oool000000?ooo`02000000070?ooo`000000oooo0?ooo`000000oooo000000040?ooo`03
0000003oool000000080000000@0oooo00000000000000000`3oool200000080oooo1`0000030?oo
o`<0000000<0oooo0000003oool00P0000000`3oool000000?ooo`020?ooo`050000003oool00000
0000003oool00`0000000`3oool000000?ooo`02000000030?ooo`00000000000080oooo0P000004
0?ooo`070000003oool0oooo0000003oool000000?ooo`04000000040?ooo`000000oooo0?ooo`80
000000<0oooo0000003oool0100000020?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`0000000P3oool3000000030?ooo`000000oooo00D0
oooo0P0000001P3oool000000000003oool000000?ooo`8000000`3oool200000080oooo10000003
0?ooo`050000003oool000000?ooo`000000203oool00`000000oooo0?ooo`0J0?ooo`00@`3oool0
0`000000oooo0?ooo`050?ooo`800000103oool00`000000oooo000000030?ooo`@00000203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<000000`3oool00`000000oooo00000004
0?ooo`030000003oool00000008000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0080oooo100000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P000005
0?ooo`030000003oool0oooo0080oooo0P000000103oool000000000000000020?ooo`80000000<0
oooo0000003oool00P0000000`3oool00000000000050?ooo`8000000P3oool200000080oooo00<0
00000?ooo`0000000P000000103oool000000000003oool2000000<0oooo00T000000?ooo`000000
00000?ooo`000000oooo0000003oool00P0000020?ooo`030000003oool0oooo00<0oooo00T00000
0?ooo`3oool000000?ooo`000000oooo0000003oool00P0000020?ooo`<000000`3oool300000003
0?ooo`0000000000008000000P3oool3000000D0oooo00H000000?ooo`00000000000?ooo`000002
0?ooo`8000001P3oool020000000oooo000000000000oooo0000003oool000000`3oool200000004
0?ooo`000000oooo0?ooo`<000000P3oool01@000000oooo0000003oool000000080oooo0P000000
1P3oool000000?ooo`3oool000000?ooo`@0000000<0oooo0000000000000`3oool5000000070?oo
o`000000oooo0?ooo`000000oooo000000030?ooo`@000000P3oool01@000000oooo000000000000
oooo00<0000000@0oooo00000000000000000`3oool00`000000oooo0?ooo`020?ooo`8000000`3o
ool00`000000oooo00000003000000@0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000
003oool0oooo01X0oooo00130?ooo`030000003oool0oooo00D0oooo0P0000001`3oool000000?oo
o`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`80000000L0oooo00000000
000000000?ooo`000000oooo00D000000P3oool2000000<0oooo00D000000?ooo`000000oooo0000
00020?ooo`050000003oool000000?ooo`0000000P3oool2000000040?ooo`000000oooo000000@0
oooo00<000000?ooo`3oool0103oool010000000oooo0000000000070?ooo`030000003oool0oooo
008000001@3oool01@000000oooo0?ooo`000000oooo008000000P3oool4000000030?ooo`000000
000000D0oooo0P0000000`3oool000000?ooo`020?ooo`<0000000@0oooo0000003oool0oooo0P00
00001@3oool000000?ooo`000000oooo0080000000<0oooo0000000000000`3oool010000000oooo
0000000000030?ooo`030000003oool00000008000000P3oool00`000000oooo0?ooo`030?ooo`07
0000003oool000000?ooo`000000oooo000000050?ooo`060000003oool000000?ooo`000000oooo
1@0000020?ooo`040000003oool0oooo0?ooo`8000001@3oool4000000040?ooo`000000oooo0?oo
o`80000000<0oooo0000003oool00`3oool2000000060?ooo`00000000000000003oool000000P3o
ool010000000oooo0000003oool2000000050?ooo`00000000000000003oool00P0000000`3oool0
0000000000020?ooo`030000003oool0000000800000103oool020000000oooo0?ooo`000000oooo
0000003oool000000P3oool=00000080oooo0`0000030?ooo`@0000000D0oooo0000000000000000
0?ooo`06000000030?ooo`000000oooo00<0oooo0P000000103oool000000000003oool4000000@0
oooo0P0000000`3oool000000?ooo`080?ooo`030000003oool0oooo01X0oooo00130?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`070?ooo`800000
00L0oooo00000000000000000?ooo`000000oooo00D0000000@0oooo0000003oool000000P3oool2
000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo00000002000000030?ooo`000000
00000080000000<0oooo0000000000000P0000040?ooo`80000000<0oooo0000000000000`000000
0`3oool000000?ooo`03000000030?ooo`000000000000H0oooo00<000000?ooo`0000000P3oool0
0`000000oooo00000004000000030?ooo`000000000000<0oooo00D000000?ooo`00000000000?oo
o`03000000050?ooo`000000oooo0000003oool00P0000000`3oool000000?ooo`02000000030?oo
o`000000oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000200000080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00800000
0P3oool6000000P0oooo00<000000?ooo`000000103oool2000000@0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0000000000080oooo0P0000040?ooo`L000000P3oool00`00
0000oooo0000000400000080oooo00@000000?ooo`0000000000203oool01@000000oooo0000003o
ool0000000<0oooo00@000000?ooo`000000oooo200000001@3oool00000000000000000oooo0080
000000<0oooo0000000000000`0000020?ooo`040000003oool0oooo0?ooo`@0000000@0oooo0000
003oool000000P3oool2000000040?ooo`00000000000?ooo`@00000103oool2000000030?ooo`00
0000000000P0oooo00<000000?ooo`3oool06P3oool004<0oooo00<000000?ooo`3oool0203oool2
00000080oooo00<000000?ooo`0000000P0000040?ooo`030000003oool0oooo00<0oooo0`000004
0?ooo`80000000D0oooo0000003oool000000?ooo`02000000030?ooo`000000oooo00P0oooo0`00
00020?ooo`030000003oool000000080000000D0oooo000000000000oooo000000020?ooo`040000
003oool0000000000080oooo100000001P3oool000000?ooo`000000oooo00000080oooo0`000004
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`000000oooo0`000000103oool000000000
000000020?ooo`@000000P3oool200000080oooo00<000000?ooo`3oool00P0000001P3oool00000
0?ooo`000000oooo000000`0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo0P000000103oool000000?ooo`0000020?ooo`8000000P3oool2
000000030?ooo`000000000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo00<00000
0?ooo`3oool00`3oool3000000@0oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`070000
003oool000000000003oool000000?ooo`03000000040?ooo`000000oooo0?ooo`<000001@3oool0
0`000000oooo0?ooo`060?ooo`<00000103oool00`000000oooo000000030?ooo`8000000P3oool0
2@000000oooo000000000000oooo0000003oool000000?ooo`02000000@0oooo0P0000040?ooo`03
0000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool00000
0080oooo0P0000070?ooo`@00000203oool00`000000oooo0?ooo`0J0?ooo`00@`3oool00`000000
oooo0?ooo`080?ooo`<000000`3oool4000000<0oooo00<000000?ooo`0000000`3oool200000003
0?ooo`000000oooo0080oooo0P0000020?ooo`050000003oool0oooo0000003oool00P0000070?oo
o`030000003oool0oooo008000000P3oool2000000030?ooo`000000oooo0080000000<0oooo0000
003oool00P3oool010000000oooo0000000000020?ooo`<0000000<0oooo0000003oool00P3oool2
000000<0oooo0P0000040?ooo`030000003oool0oooo00P0oooo0P0000020?ooo`D00000203oool0
0`000000oooo0?ooo`02000000D0oooo0P000000103oool000000?ooo`0000020?ooo`040000003o
ool0oooo0?ooo`80000000<0oooo0000003oool02@3oool01P000000oooo0?ooo`3oool000000?oo
o`80000000@0oooo000000000000oooo100000020?ooo`040000003oool0oooo00000080oooo00L0
00000?ooo`3oool0oooo0000003oool000000080oooo0P000000103oool000000000000000030?oo
o`030000003oool0oooo00@0oooo0P0000000`3oool00000000000060?ooo`030000003oool0oooo
0080oooo0`0000020?ooo`030000003oool00000008000000P3oool01`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`@000000P3oool01@000000oooo0000
003oool0000000<0oooo00<000000?ooo`0000000`3oool2000000@0oooo00<000000?ooo`3oool0
2P3oool3000000X0oooo00@000000?ooo`00000000000`3oool010000000oooo0000003oool20000
00040?ooo`0000000000000000T0oooo00<000000?ooo`3oool06P3oool004<0oooo00<000000?oo
o`3oool02@3oool2000000060?ooo`000000oooo0?ooo`000000oooo0P0000040?ooo`030000003o
ool0oooo00<0oooo0P0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00L000000?ooo`00000000000?ooo`000000
oooo0080000000<0oooo0000003oool0103oool00`000000oooo0?ooo`020?ooo`D000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000001P3o
ool300000080oooo100000040?ooo`030000003oool0oooo00<0oooo100000030?ooo`080000003o
ool000000000003oool000000?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00@000000?ooo`00000000000P3o
ool00`000000oooo0?ooo`0300000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`3oool2000000030?ooo`00000000000080000000@0oooo00000000000000000P3oool00`00
0000oooo000000070?ooo`<000001P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103o
ool3000000<0oooo00<000000?ooo`3oool00`3oool3000000040?ooo`000000oooo000000@0oooo
0`0000001@3oool000000000003oool0000000H0oooo0P000000103oool000000?ooo`3oool20000
00D0oooo00@000000?ooo`3oool000000P3oool2000000H0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo000000030?ooo`80000000<0oooo0000003oool00`0000000`3oool000000?oo
o`02000000040?ooo`0000000000000000T0oooo00<000000?ooo`3oool06P3oool004<0oooo0P00
000:0?ooo`050000003oool0oooo0000003oool00`0000001@3oool000000?ooo`3oool000000080
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo0?ooo`8000000P3oool2000000D0oooo00<000000?ooo`3oool02@3oool010000000oooo0000
003oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000030?ooo`000000000000@0oooo
0`0000040?ooo`030000003oool0000000<0oooo0P0000050?ooo`@000000P3oool400000080oooo
00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000@0oooo00L000000?oo
o`000000oooo0000003oool000000080oooo00P000000?ooo`00000000000?ooo`000000oooo0000
00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`3oool2000000090?ooo`00
000000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000001`3oool30000
0080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`040000003oool00000000000<0oooo0`00
00000`3oool000000?ooo`020?ooo`030000003oool0oooo0080oooo0`0000020?ooo``0000000<0
oooo0000003oool0103oool2000000@0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000020?ooo`8000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00`0000030?ooo`<000000P3oool200000080oooo0P000000103oool000000?ooo`0000020?oo
o`030000003oool0oooo00D0oooo0P00000L0?ooo`00@`3oool00`000000oooo0?ooo`050?ooo`05
0000003oool000000?ooo`0000000`3oool4000000030?ooo`00000000000080000000<0oooo0000
000000001P3oool2000000<0oooo0P0000020?ooo`8000000P3oool00`000000oooo000000020000
00<0oooo0P0000030?ooo`8000000P3oool00`000000oooo000000020?ooo`<0000000<0oooo0000
000000000P3oool2000000H0oooo100000001`3oool000000?ooo`3oool000000?ooo`000000103o
ool010000000oooo0000000000020?ooo`030000003oool00000008000001P3oool00`000000oooo
0?ooo`0200000080oooo00D000000?ooo`3oool0oooo000000040?ooo`@000000P3oool200000003
0?ooo`000000oooo00L0oooo100000020?ooo`050000003oool0oooo0000003oool01P0000040?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0
oooo00@000000`3oool010000000oooo0000003oool300000080oooo00<000000?ooo`3oool00P00
00030?ooo`@0000000D0oooo0000003oool000000?ooo`02000000040?ooo`00000000000?ooo`80
000000<0oooo0000003oool00P3oool00`000000oooo000000020?ooo`<000001@3oool00`000000
oooo0?ooo`07000000030?ooo`000000000000@0000000<0oooo0000003oool00P3oool200000004
0?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000P3oool0
2@000000oooo0?ooo`000000oooo0000003oool000000?ooo`02000000<0oooo0P0000050?ooo`05
0000003oool0oooo0?ooo`0000000`3oool020000000oooo000000000000oooo0000003oool00000
203oool00`000000oooo0?ooo`0J0?ooo`00@`3oool00`000000oooo0?ooo`050?ooo`060000003o
ool000000?ooo`000000oooo0`000000103oool000000?ooo`3oool300000080oooo0P0000060?oo
o`040000003oool0oooo0?ooo`<000000P3oool00`000000oooo0?ooo`030?ooo`<000000P3oool2
00000080oooo00@000000?ooo`0000000000103oool00`000000oooo00000003000000030?ooo`00
0000000000@0000000<0oooo0000003oool0103oool200000080oooo00@000000?ooo`3oool0oooo
0`0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0000000<0oooo0000003oool0103oool2000000050?oo
o`000000oooo0?ooo`0000000P3oool2000000030?ooo`000000oooo00P0oooo0P0000020?ooo`<0
000000<0oooo0000003oool01P0000020?ooo`030000003oool0000000@0oooo00D000000?ooo`3o
ool000000?ooo`02000000<0oooo00<000000?ooo`3oool0100000030?ooo`030000003oool00000
0080oooo0P0000000`3oool000000?ooo`020?ooo`8000000`3oool01@000000oooo000000000000
oooo00<00000103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo1000
0000103oool000000?ooo`3oool400000080oooo00<000000?ooo`0000000P000000103oool00000
0?ooo`3oool2000000050?ooo`00000000000?ooo`0000000`3oool00`000000oooo0?ooo`030000
00<0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01@000000oooo
0?ooo`000000oooo008000000P3oool200000080oooo0`0000070?ooo`030000003oool0000000D0
oooo0P0000000`3oool000000?ooo`090?ooo`030000003oool0oooo01X0oooo00130?ooo`030000
003oool0oooo00/0oooo1P0000001@3oool000000000003oool000000080oooo00<000000?ooo`3o
ool0103oool01P000000oooo0?ooo`3oool000000?ooo`80000000<0oooo0000003oool00P3oool0
10000000oooo0?ooo`3oool2000000030?ooo`00000000000080oooo00@000000?ooo`0000000000
1P3oool4000000030?ooo`0000000000008000000`3oool01@000000oooo0?ooo`000000oooo00<0
000000<0oooo0000000000000`3oool3000000<0oooo00<000000?ooo`0000001`3oool00`000000
oooo000000020?ooo`030000003oool000000080oooo0`0000070?ooo`80000000<0oooo0000003o
ool00`0000000`3oool00000000000030?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`04
0000003oool000000?ooo`80000000<0oooo0000000000000P0000030?ooo`030000003oool00000
0080oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`090000003oool0oooo
0?ooo`000000oooo0000003oool0000000<0oooo0`0000030?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000050?ooo`040000003oool0000000000080oooo00<000000?oo
o`3oool00P0000020?ooo`050000003oool0oooo0000003oool0100000040?ooo`@000000P3oool3
000000040?ooo`0000000000000000@0oooo0`0000000`3oool000000?ooo`020?ooo`8000000P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<000001P3oool00`000000oooo
0?ooo`03000000030?ooo`00000000000080oooo0`0000070?ooo`030000003oool0oooo0080oooo
0P0000000`3oool000000?ooo`02000000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool0
6P3oool004<0oooo00<000000?ooo`3oool0203oool00`000000oooo000000030?ooo`<00000103o
ool01P000000oooo0?ooo`000000oooo00000080oooo0`0000030?ooo`060000003oool0oooo0000
003oool000000`3oool00`000000oooo00000006000000030?ooo`000000oooo00T0oooo00@00000
0?ooo`00000000000P3oool2000000D0oooo00D000000?ooo`000000oooo000000020?ooo`<00000
0P3oool00`000000oooo0?ooo`050?ooo`<0000000<0oooo0000003oool00`3oool200000080oooo
0`0000020?ooo`@000000P3oool010000000oooo0?ooo`0000060?ooo`050000003oool000000?oo
o`0000000`3oool2000000030?ooo`000000oooo00<0oooo00H000000?ooo`3oool000000?ooo`00
00030?ooo`8000000P3oool00`000000oooo000000030?ooo`<000000P3oool01@000000oooo0?oo
o`3oool0000000L0oooo00@000000?ooo`000000oooo1@0000020?ooo`030000003oool0000000<0
00000P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000`3oool30000
00040?ooo`00000000000?ooo`8000000P3oool01`000000oooo0?ooo`000000oooo0000003oool0
0P0000050?ooo`030000003oool0oooo0080oooo0`0000000`3oool00000000000050?ooo`800000
0P3oool010000000oooo0000003oool200000080oooo00<000000?ooo`3oool0103oool01@000000
oooo0?ooo`000000oooo00800000103oool2000000040?ooo`000000oooo000000L0oooo00<00000
0?ooo`0000000P0000080?ooo`80000000@0oooo0000003oool000000P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01X0oooo00130?ooo`030000003oool0oooo00P0oooo0`000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000P3oool300000080oooo0`00
00030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`04000000030?oo
o`00000000000080oooo00<000000?ooo`0000001@3oool01P000000oooo0?ooo`3oool000000?oo
o`80000000<0oooo0000000000000`3oool00`000000oooo000000030?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`000000oooo0P0000020?ooo`<0000000H0oooo0000003oool00000
0?ooo`0000030?ooo`070000003oool000000000003oool000000?ooo`02000000040?ooo`000000
00000?ooo`<0000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0000000H0oooo000000000000oooo0000003oool2000000030?ooo`000000oooo0080
00000P3oool200000080oooo00<000000?ooo`0000000P3oool4000000<0oooo00<000000?ooo`3o
ool00P0000020?ooo`050000003oool0oooo0000003oool00P0000000`3oool00000000000040000
00030?ooo`000000oooo0080oooo0P0000020?ooo`030000003oool0oooo00D0oooo00P000000?oo
o`000000oooo0000003oool000000?ooo`<0000000@0oooo000000000000oooo0P0000020?ooo`80
000000D0oooo0000003oool000000?ooo`0300000080oooo0P0000020?ooo`80000000P0oooo0000
0000000000000?ooo`000000oooo000000@0oooo0`0000002@3oool00000000000000000oooo0000
003oool000000?ooo`0200000080oooo00@000000?ooo`3oool000000P3oool4000000@0oooo0P00
00000`3oool0000000000002000000030?ooo`000000oooo0080oooo0P000000103oool000000000
000000030?ooo`030000003oool0000000<0oooo0P0000050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool06P3oool004<0oooo00<000000?ooo`3oool0103oool00`000000oooo0000
0004000000040?ooo`00000000000?ooo`8000000P3oool4000000030?ooo`00000000000080oooo
10000000103oool000000?ooo`3oool2000000030?ooo`00000000000080000000<0oooo00000000
00001`0000030?ooo`0<0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0P0000000`3oool00000000000020?ooo`80000000<0oooo0000003oool01P0000000`3oool0
00000000000:000000<0oooo0`000000103oool000000?ooo`3oool5000000050?ooo`0000000000
0?ooo`0000000P3oool5000000030?ooo`00000000000080000000@0oooo0000003oool0oooo0P00
00000`3oool0000000000003000000030?ooo`000000000000H0000000<0oooo0000000000000P3o
ool2000000030?ooo`0000000000008000000P3oool200000080oooo00T000000?ooo`3oool00000
0?ooo`000000oooo0000003oool00P0000020?ooo`090000003oool000000000003oool000000?oo
o`000000oooo00800000103oool4000000<0oooo100000020?ooo`030000003oool0000000800000
00@0oooo00000000000000000`3oool00`000000oooo0000000300000080oooo0`0000030?ooo`P0
000000@0oooo000000000000oooo0P0000020?ooo`040000003oool0000000000080oooo20000000
1@3oool00000000000000000oooo00<0000000@0oooo00000000000000000`3oool3000000040?oo
o`000000oooo0?ooo`8000000P3oool600000080oooo0`0000001@3oool000000000003oool00000
0080oooo00H000000?ooo`000000oooo0000003oool200000080oooo00@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`0J0?ooo`00@`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool000000080000000<0oooo000000000000100000020?ooo`D0000000H0oooo0000000000000000
0?ooo`0000040?ooo`030000003oool0oooo008000000P3oool3000000040?ooo`00000000000?oo
o`H000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000`3o
ool200000080oooo0P0000030?ooo`80000000L0oooo00000000000000000?ooo`000000oooo00P0
000000<0oooo0000000000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool00000
00800000103oool010000000oooo0?ooo`3oool7000000050?ooo`000000oooo0000003oool00`00
00000`3oool0000000000009000000050?ooo`000000oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`04000000030?ooo`000000000000<0oooo00H000000?ooo`00000000000?ooo`0000030?oo
o`030000003oool0000000/0oooo00<000000?ooo`3oool00P3oool400000080oooo1@0000000`3o
ool00000000000020?ooo`030000003oool0000000@0000000D0oooo0000003oool0oooo00000002
0?ooo`050000003oool0oooo0?ooo`000000103oool2000000050?ooo`00000000000000003oool0
0`0000000`3oool000000?ooo`030?ooo`040000003oool0000000000080oooo1@0000050?ooo`80
00000P3oool6000000L0oooo00<000000?ooo`3oool00P0000020?ooo`8000000P3oool00`000000
oooo0?ooo`0600000080oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool000000080
000000<0oooo0000003oool02P3oool00`000000oooo0?ooo`0J0?ooo`00@`3oool00`000000oooo
0?ooo`0:0?ooo`<0000000<0oooo0000003oool00`0000030?ooo`040000003oool0oooo0?ooo`<0
00000P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001`3oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000001@3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?oo
o`050000003oool000000000003oool00P00000D0?ooo`060000003oool0oooo0?ooo`000000oooo
100000060?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00L000000?ooo`3oool0oooo0000003oool0
00000100oooo00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3oool02@3oool2
000000@0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0J0?ooo`00@`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo
0P0000020?ooo`030000003oool0oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool00000
00H0oooo0P0000070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool20000
0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo
000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`80000000<0oooo
0000003oool0203oool00`000000oooo0?ooo`070?ooo`8000001@3oool01@000000oooo0000003o
ool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`8000000`3o
ool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001`3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo0000
00080?ooo`030000003oool0oooo01X0oooo00130?ooo`8000004P3oool010000000oooo0?ooo`00
00080?ooo`050000003oool0oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000003oool00000
00h0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`070?ooo`050000003oool0
oooo0?ooo`0000003P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0000
00P0oooo0P0000040?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`040?ooo`040000003oool00000000000H0oooo0P0000030?ooo`030000003o
ool0oooo00D0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool000000080
oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040000003oool0oooo000000T0oooo00D00000
0?ooo`3oool0oooo000000080?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo0P00000L0?ooo`00
@`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000
3@3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`0000000P3oool01P000000
oooo0?ooo`000000oooo000000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`<000001`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool00000
203oool2000000040?ooo`000000oooo0?ooo`8000002@3oool01@000000oooo0?ooo`3oool00000
00H0oooo00@000000?ooo`00000000000`3oool01@000000oooo0?ooo`3oool0000000L0oooo00@0
00000?ooo`3oool0oooo0P0000000`3oool000000?ooo`0C0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool02P3oool00`000000oooo00000003000000H0oooo0P0000040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01X0oooo00130?ooo`030000003oool0oooo01l0oooo00<000000?ooo`000000103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0`0000040?ooo`030000003o
ool0000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000=0?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
00002P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo000000040?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`0000002P3oool00`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`8000001P3oool00`000000oooo0?ooo`08
0?ooo`040000003oool0oooo000000<0oooo0P0000060?ooo`8000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`080?ooo`040000003oool000000?ooo`80000000<0oooo0000000000000P0000060?ooo`04
0000003oool0oooo00000080oooo0P0000030?ooo`030000003oool0000000L0oooo00D000000?oo
o`3oool0oooo000000080?ooo`030000003oool0oooo01X0oooo00130?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`8000001@3oool01P000000oooo00000000
0000oooo00000080oooo00<000000?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool0
0`3oool3000000`0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00@000000?ooo`3oool0
00000P3oool2000000030?ooo`000000oooo00800000303oool2000000P0oooo0`0000040?ooo`03
0000003oool0oooo00T0oooo00@000000?ooo`00000000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000L0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
00000080oooo0`000000103oool000000000003oool2000000L0oooo0P0000020?ooo`030000003o
ool0oooo00P0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`030000003oool0oooo00<0oooo
00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`0000004P3oool00`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo00000002000000<0oooo00<000000?ooo`3oool00`3oool01`000000oooo0000003o
ool000000?ooo`0000000`3oool01P000000oooo0?ooo`3oool000000?ooo`<000001@3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo01X0oooo00130?ooo`030000003oool0oooo
00D0oooo0P0000020?ooo`030000003oool0oooo00800000103oool00`000000oooo0?ooo`020?oo
o`060000003oool0oooo0?ooo`000000oooo0P000000103oool000000?ooo`0000090?ooo`050000
003oool000000000003oool00P000000103oool000000000003oool400000080oooo00@000000?oo
o`00000000000P3oool010000000oooo0000000000020?ooo`<000000`3oool00`000000oooo0000
00060?ooo`080000003oool000000000003oool000000?ooo`0000020?ooo`030000003oool0oooo
0080000000H0oooo0000003oool0oooo0000003oool200000080oooo00D000000?ooo`3oool0oooo
000000030?ooo`@000000`3oool2000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool01P000000oooo0000003oool00000
0?ooo`@00000103oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool00`00
00020?ooo`080000003oool0oooo0?ooo`000000oooo0000003oool5000000030?ooo`0000000000
00@0oooo00P000000?ooo`00000000000?ooo`000000oooo000000<0oooo00P000000?ooo`3oool0
00000?ooo`000000oooo000000<0oooo0P0000000`3oool00000000000030?ooo`030000003oool0
oooo0080oooo0P0000030?ooo`080000003oool0oooo0000003oool000000?ooo`0000020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`0000001@3oool00`000000oooo000000040?oo
o`050000003oool0oooo0?ooo`0000000P3oool01P000000oooo0?ooo`3oool000000?ooo`800000
00<0oooo0000003oool01P3oool3000000030?ooo`000000oooo00D0oooo0P000000103oool00000
0?ooo`3oool4000000@0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`0J0?ooo`00
@`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool000000?ooo`0000002@3oool0
1P000000oooo000000000000oooo00000080oooo00@000000?ooo`3oool0oooo0`0000020?ooo`03
0000003oool0000000<0oooo00@000000?ooo`0000000000103oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000040?ooo`080000003oool000000000003oool000000?ooo`000002
0?ooo`070000003oool0oooo0?ooo`000000oooo000000080?ooo`050000003oool0oooo0?ooo`00
00000`3oool2000000030?ooo`000000oooo0080oooo0P0000080?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo100000040?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool200000080oooo00X0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0P0000080?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`000000oooo00800000103o
ool00`000000oooo00000002000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000
003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
00<0oooo0P0000000`3oool000000?ooo`060?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool2000000030?ooo`000000oooo0080000000<0oooo0000003oool00P3oool0
10000000oooo0?ooo`3oool2000000040?ooo`000000oooo000000D0oooo0P0000060?ooo`800000
103oool2000000X0oooo00<000000?ooo`3oool06P3oool004<0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0000000Q0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool000000140oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`020?ooo`8000002P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0000001@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0J0?ooo`00@`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo01X0oooo00130?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0J0?ooo`00@`3oool2000003X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07l0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`110?ooo`800000703oool004<0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08D0oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01X0oooo
00130?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`1Z0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06P3oool004<0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0;P3oool010000000oooo0?ooo`00000Y0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0J0?ooo`00@`3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000005P3oool00`000000oooo0?oo
o`050?ooo`050000003oool0oooo0?ooo`0000006@3oool2000000D0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0J0?ooo`00<`3oool00`3OW4P00000000000030000000304RLg`3o
ool0oooo00L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000001H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01X0oooo000d0?ooo`030?noM000M;l0oooo0080oooo00<0_gAd0;ooo`3oool01`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0J0?ooo`00=@3oool00`3o_g@007Bo0?ooo`0;0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0J0?ooo`00=P3oool00`3o
_g@007Bo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`0J0?oo
o`00=`3oool00`3o_g@0B9cO0?ooo`090?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo01X0oooo000h0?ooo`030=nL
B018W=l0oooo00P0oooo0`00000G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
2P3oool2000000D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`100?ooo`<00000
703oool003T0oooo00<0_g@007Boo`3oool01`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool06P3oool003T0oooo00<0omnL04P0M02oool01`3oool0
0`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool06P3oool003T0oooo00<0oooO09a8
001d_ol01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo04h0oooo00@000000?oo
o`3oool00000703oool003T0oooo00<0oono07@00018W=l01`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0140oooo00@000000?ooo`3oool00000703oool003D0oooo00L0okmd0018
W03Oool0oooo0=nLB00004P0W=oo00L0ooooo`00001B000001`0oooo000f0?ooo`050?oOW0180000
00000000001d_ol0o`3ooomf0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-1847.09, -3.33499, 36.86, \
0.0314926}}]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises", "ExerciseMain"],

Cell[CellGroupData[{

Cell["Energy and period for conservative systems", "ExerciseTitle"],

Cell["\<\
a) Find the relationship between the total energy and the area enclosed by a \
closed curve in phase space for free vibrations of conservative Duffing \
oscillators.\
\>", "ExerciseText"],

Cell[TextData[{
  "b) Write a function which calculates the period for conservative \
anharmonic motion.  Plot the period as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " for fixed total energy."
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Functions that use rules instead of positional arguments", 
  "ExerciseTitle"],

Cell["\<\
Write similar functions in which the parameters are given in the form of a \
list of replacement rules rather than as positional parameters.  The virtue \
of this technique is that the user is not required to remember the order of \
those arguments.  On the other hand, it is still necessary to specify them \
all.  If you get ambitious, design your function to test for the presence of \
an adequate number of replacement rules and to verify their validity.\
\>", "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Basin of attraction", "ExerciseTitle"],

Cell["\<\
Demonstrate graphically the existence of a basin of attraction within which \
all initial points are attracted to the same limiting orbit in phase space. \
\
\>", "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Variant of Duffing equation", "ExerciseTitle"],

Cell["\<\
A closely related variant of the form of Duffing's equation presented above \
is\
\>", "ExerciseText"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[\(\[PartialD]\^2 x\), \(\[PartialD]t\^2\),
            MultilineFunction->None], "+", 
          RowBox[{"\[Gamma]", " ", 
            FractionBox[\(\[PartialD]x\), \(\[PartialD]t\),
              MultilineFunction->None]}], "-", 
          " ", \(x\ \((1 - \[Alpha]\ x\^2)\)\)}], 
        "\[Equal]", \(f\ Cos[\[Omega]\ t]\)}], 
      TraditionalForm]], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Show that for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] > 0\)]],
  " this equation describes motion in a potential with two attractive wells.  \
\na) Determine the characteristic frequency for free, undamped, \
small-amplitude oscillations.\nb) Display and describe phase diagrams for \
representative choices of parameters covering the various qualitatively \
distinct phenomena.  Include cases where the total energy is less than, equal \
to, and greater than the potential energy for ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  "."
}], "ExerciseText",
  CellDingbat->None]
}, Closed]],

Cell[CellGroupData[{

Cell["An acoustic equation due to Lord Rayleigh ", "ExerciseTitle"],

Cell["\<\
Lord Rayleigh applied the following equation with nonlinear damping \
\>", "ExerciseText"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[\(\[PartialD]\^2 x\), \(\[PartialD]t\^2\),
            MultilineFunction->None], "+", " ", \(\(\[Omega]\_0\^2\) x\), " ",
           "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{\(\[Gamma]\_1\), "-", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{\(\[Gamma]\_2\), 
                      RowBox[{"(", 
                        FractionBox[\(\[PartialD]x\), \(\[PartialD]t\),
                          MultilineFunction->None], ")"}]}], ")"}], "2"]}], 
              ")"}], " ", 
            FractionBox[\(\[PartialD]x\), \(\[PartialD]t\),
              MultilineFunction->None]}]}], " ", "\[Equal]", " ", "0"}], 
      TraditionalForm]], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "to a problem in acoustics.  Dimensional analysis suggests that there are \
two characteristic times, ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]/\[Omega]\_0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\_1\)]],
  ", and a characteristic length, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptL]\_0 = \@\(\[Gamma]\_1/\((\(\[Gamma]\_2\) \
\[Omega]\_0\^2)\)\)\)]],
  ".  Study the behavior of this system for representative choices of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_0\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0/\[ScriptL]\_0\)]],
  "."
}], "ExerciseText",
  CellDingbat->None]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 952}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{1392, 912},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Visible->True,
ShowSelection->True,
ShowCellLabel->False,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->PaperWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}, {
        Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {0, 0}},
    CellGroupingRules->"TitleGrouping",
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    ShowCellBracket->True,
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{9, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->0.5,
    CellMargins->{{25, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.700008, 0.4]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{25, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{25, 0}, {6, 6}}],
  
  Cell[StyleData["Input", "Printout"],
    CellFrame->0.5,
    CellMargins->{{25, 0}, {6, 6}},
    Background->None]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->True,
    CellMargins->{{25, 10}, {8, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{25, Inherited}, {12, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{10, 4}, {2, 10}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{12, 10}, {2, 12}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {1, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->9],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{9, 0}, {4, 12}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    CellMargins->{{10, 10}, {40, 2}},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{12, 10}, {50, 2}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Example",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Definition",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Definition", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Theorem",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Theorem", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.4]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caution"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Caution",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.996109, 0, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Caution", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Caution", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Caution", "Printout"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Advice"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Advice",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0, 1, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Advice", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Advice", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Advice", "Printout"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->"NormalGrouping",
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseMain"],
    CellFrame->{{6, 0}, {0, 1}},
    CellMargins->{{12, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseMain", "Presentation"],
    CellMargins->{{18, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["ExerciseMain", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["ExerciseMain", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseTitle"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseTitle", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["ExerciseTitle", "Condensed"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["ExerciseTitle", "Printout"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{32, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExcersiceText",
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{32, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{32, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{32, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Problem"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Problem", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Problem", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Problem", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{12, 10}, {Inherited, 6}},
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{13, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{62, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{74, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    CellMargins->{{52, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"]],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"]],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation package. These \
styles serve to make visible otherwise invisible tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 82, 2, 81, "Title"],
Cell[1861, 57, 455, 15, 85, "Author"],

Cell[CellGroupData[{
Cell[2341, 76, 31, 0, 83, "Section"],
Cell[2375, 78, 123, 5, 41, "Text"],
Cell[2501, 85, 554, 14, 64, "DisplayFormula",
  Evaluatable->False],
Cell[3058, 101, 1130, 24, 145, "Text"],
Cell[4191, 127, 304, 7, 88, "DisplayFormula",
  Evaluatable->False],
Cell[4498, 136, 724, 15, 93, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5259, 156, 33, 0, 51, "Section"],
Cell[5295, 158, 119, 2, 99, "Input"],
Cell[5417, 162, 146, 4, 95, "Input"],
Cell[5566, 168, 187, 3, 125, "Input"],
Cell[5756, 173, 421, 13, 73, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6214, 191, 33, 0, 51, "Section"],
Cell[6250, 193, 155, 3, 41, "Text"],
Cell[6408, 198, 663, 11, 177, "Input"],

Cell[CellGroupData[{
Cell[7096, 213, 85, 1, 73, "Input"],
Cell[7184, 216, 570, 10, 116, "Output"]
}, Closed]],
Cell[7769, 229, 758, 18, 95, "Text"],
Cell[8530, 249, 918, 15, 255, "Input"],
Cell[9451, 266, 1823, 47, 176, "Text"],
Cell[11277, 315, 1132, 18, 333, "Input"],
Cell[12412, 335, 198, 4, 41, "Text"],
Cell[12613, 341, 155, 2, 96, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[12805, 348, 27, 0, 51, "Section"],

Cell[CellGroupData[{
Cell[12857, 352, 42, 0, 68, "Subsection"],
Cell[12902, 354, 310, 5, 67, "Text"],

Cell[CellGroupData[{
Cell[13237, 363, 153, 3, 93, "Input"],
Cell[13393, 368, 72, 1, 80, "Output"]
}, Closed]],
Cell[13480, 372, 1143, 25, 145, "Text"],

Cell[CellGroupData[{
Cell[14648, 401, 312, 7, 99, "Input"],
Cell[14963, 410, 59299, 1426, 279, 18988, 924, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[74277, 1839, 391, 8, 67, "Text"],

Cell[CellGroupData[{
Cell[74693, 1851, 729, 15, 177, "Input"],
Cell[75425, 1868, 117091, 2608, 444, 28240, 1506, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[192531, 4479, 280, 6, 41, "Text"],

Cell[CellGroupData[{
Cell[192836, 4489, 321, 7, 127, "Input"],
Cell[193160, 4498, 78416, 1834, 279, 23334, 1149, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[271613, 6337, 739, 15, 234, "Input"],
Cell[272355, 6354, 142307, 3241, 444, 34912, 1910, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[414711, 9601, 48, 0, 68, "Subsection"],

Cell[CellGroupData[{
Cell[414784, 9605, 44, 0, 55, "Subsubsection"],
Cell[414831, 9607, 192, 4, 41, "Text"],

Cell[CellGroupData[{
Cell[415048, 9615, 136, 2, 73, "Input"],
Cell[415187, 9619, 115364, 2883, 444, 33305, 1865, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[530588, 12507, 133, 2, 73, "Input"],
Cell[530724, 12511, 124147, 3927, 444, 52230, 3035, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[654886, 16441, 439, 9, 69, "Text"],

Cell[CellGroupData[{
Cell[655350, 16454, 138, 2, 73, "Input"],
Cell[655491, 16458, 344326, 7987, 444, 78353, 4699, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[999832, 24448, 98, 2, 41, "Text"],

Cell[CellGroupData[{
Cell[999955, 24454, 465, 8, 151, "Input"],
Cell[1000423, 24464, 80537, 2063, 444, 28834, 1420, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1080975, 26530, 384, 8, 67, "Text"],

Cell[CellGroupData[{
Cell[1081384, 26542, 324, 6, 99, "Input"],

Cell[CellGroupData[{
Cell[1081733, 26552, 55684, 1426, 279, 20742, 990, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1137420, 27980, 55932, 1422, 279, 20500, 980, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],
Cell[1193379, 29406, 263, 5, 67, "Text"],

Cell[CellGroupData[{
Cell[1193667, 29415, 179, 3, 73, "Input"],
Cell[1193849, 29420, 64296, 1689, 279, 24308, 1191, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1258160, 31112, 866, 19, 119, "Text"],

Cell[CellGroupData[{
Cell[1259051, 31135, 222, 4, 73, "Input"],
Cell[1259276, 31141, 71181, 1772, 444, 24641, 1193, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1330506, 32919, 46, 0, 55, "Subsubsection"],
Cell[1330555, 32921, 384, 8, 67, "Text"],

Cell[CellGroupData[{
Cell[1330964, 32933, 163, 3, 74, "Input"],

Cell[CellGroupData[{
Cell[1331152, 32940, 168177, 3400, 444, 32522, 1721, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1499332, 36342, 174716, 3570, 444, 32811, 1813, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1674051, 39914, 246406, 4543, 444, 35537, 1935, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],
Cell[1920484, 44461, 498, 11, 67, "Text"],

Cell[CellGroupData[{
Cell[1921007, 44476, 452, 9, 151, "Input"],
Cell[1921462, 44487, 67390, 2082, 237, 32688, 1649, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[1988889, 46574, 302, 6, 99, "Input"],

Cell[CellGroupData[{
Cell[1989216, 46584, 112586, 2583, 352, 31037, 1572, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2101805, 49169, 108986, 2556, 352, 32259, 1604, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2210840, 51731, 179, 3, 73, "Input"],
Cell[2211022, 51736, 61151, 1425, 420, 18286, 891, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[2272188, 53164, 225, 4, 67, "Text"],

Cell[CellGroupData[{
Cell[2272438, 53172, 123, 2, 74, "Input"],
Cell[2272564, 53176, 195604, 3740, 444, 31488, 1709, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[2468183, 56919, 264, 5, 67, "Text"],

Cell[CellGroupData[{
Cell[2468472, 56928, 591, 11, 177, "Input"],
Cell[2469066, 56941, 76000, 2042, 279, 32334, 1498, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[2545103, 58988, 235, 4, 73, "Input"],

Cell[CellGroupData[{
Cell[2545363, 58996, 62340, 1577, 279, 22557, 1081, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2607706, 60575, 55261, 1492, 279, 22075, 1078, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2662970, 62069, 54296, 1416, 279, 21588, 1008, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2717339, 63493, 29, 0, 68, "Subsection"],
Cell[2717371, 63495, 262, 7, 41, "Text"],

Cell[CellGroupData[{
Cell[2717658, 63506, 79, 1, 73, "Input"],
Cell[2717740, 63509, 131112, 2930, 444, 33768, 1724, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2848901, 66445, 59, 0, 68, "Subsection"],
Cell[2848963, 66447, 258, 5, 67, "Text"],

Cell[CellGroupData[{
Cell[2849246, 66456, 58, 0, 55, "Subsubsection"],
Cell[2849307, 66458, 940, 22, 119, "Text"],

Cell[CellGroupData[{
Cell[2850272, 66484, 181, 3, 73, "Input"],
Cell[2850456, 66489, 136735, 3482, 357, 41822, 2306, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[2987206, 69974, 370, 7, 67, "Text"],
Cell[2987579, 69983, 267, 5, 99, "Input"],

Cell[CellGroupData[{
Cell[2987871, 69992, 131, 2, 73, "Input"],
Cell[2988005, 69996, 847241, 51474, 226, 801883, 50909, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[3835261, 121473, 157, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[3835443, 121480, 268, 5, 125, "Input"],
Cell[3835714, 121487, 2690, 48, 336, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3838453, 121541, 55, 0, 55, "Subsubsection"],
Cell[3838511, 121543, 249, 4, 67, "Text"],

Cell[CellGroupData[{
Cell[3838785, 121551, 141, 2, 73, "Input"],
Cell[3838929, 121555, 232663, 5702, 444, 62008, 3590, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[4071607, 127260, 150, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[4071782, 127268, 143, 2, 73, "Input"],
Cell[4071928, 127272, 119612, 4182, 444, 58593, 3424, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[4191555, 131457, 106, 3, 41, "Text"],
Cell[4191664, 131462, 548, 10, 125, "Input"],

Cell[CellGroupData[{
Cell[4192237, 131476, 190, 3, 73, "Input"],
Cell[4192430, 131481, 330752, 16268, 444, 246034, 15217, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[4523197, 147752, 277, 5, 67, "Text"],

Cell[CellGroupData[{
Cell[4523499, 147761, 163, 2, 73, "Input"],
Cell[4523665, 147765, 225025, 5968, 444, 67883, 4023, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[4748705, 153736, 303, 5, 67, "Text"],
Cell[4749011, 153743, 390, 7, 99, "Input"],

Cell[CellGroupData[{
Cell[4749426, 153754, 64, 1, 73, "Input"],
Cell[4749493, 153757, 724024, 30450, 618, 421596, 26712, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5473578, 184214, 94, 2, 68, "Subsection"],
Cell[5473675, 184218, 107, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[5473807, 184225, 182, 3, 74, "Input"],
Cell[5473992, 184230, 353701, 7855, 444, 73157, 4387, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[5827708, 192088, 844, 17, 119, "Text"],

Cell[CellGroupData[{
Cell[5828577, 192109, 455, 9, 151, "Input"],
Cell[5829035, 192120, 232633, 9704, 348, 170164, 8928, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[6061705, 201829, 302, 6, 99, "Input"],

Cell[CellGroupData[{
Cell[6062032, 201839, 330943, 10857, 279, 168372, 8845, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6392978, 212698, 360857, 11112, 279, 165297, 8693, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6753908, 223818, 33, 0, 54, "ExerciseMain"],

Cell[CellGroupData[{
Cell[6753966, 223822, 67, 0, 58, "ExerciseTitle"],
Cell[6754036, 223824, 197, 4, 41, "ExerciseText"],
Cell[6754236, 223830, 245, 6, 41, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[6754518, 223841, 84, 1, 58, "ExerciseTitle"],
Cell[6754605, 223844, 490, 7, 93, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[6755132, 223856, 44, 0, 58, "ExerciseTitle"],
Cell[6755179, 223858, 188, 4, 41, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[6755404, 223867, 52, 0, 58, "ExerciseTitle"],
Cell[6755459, 223869, 112, 3, 41, "ExerciseText"],
Cell[6755574, 223874, 524, 14, 64, "DisplayFormula",
  Evaluatable->False],
Cell[6756101, 223890, 618, 14, 135, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[6756756, 223909, 67, 0, 58, "ExerciseTitle"],
Cell[6756826, 223911, 100, 2, 41, "ExerciseText"],
Cell[6756929, 223915, 879, 22, 65, "DisplayFormula",
  Evaluatable->False],
Cell[6757811, 223939, 735, 23, 67, "ExerciseText"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

