(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    217875,       5264]*)
(*NotebookOutlinePosition[    251799,       6487]*)
(*  CellTagsIndexPosition[    251755,       6483]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Frequency Analysis of Time Series", "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "from ",
  StyleBox[ButtonBox["Essential Mathematica for Students of Science",
    Active->False,
    ButtonData:>{
      URL[ 
      "http://www.physics.umd.edu/courses/CourseWare/EssentialMathematica/"], 
      None},
    Active->False,
    ButtonStyle->"Hyperlink"],
    Active->False],
  "\n\[Copyright] James J. Kelly, 1998\nLast revised: January, 2006"
}], "Author",
  Active->True,
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
  "An important method for evaluating the dynamics of a system is Fourier \
analysis of time series.  Suppose that a sequence of ",
  StyleBox["n",
    FontSlant->"Italic"],
  " measurements ",
  Cell[BoxData[
      \(TraditionalForm\`x\_m = \(x[t\_m] = x[\((m - 1)\)\ \[Tau]]\)\)]],
  " is made at equally spaced times covering an observation period ",
  Cell[BoxData[
      \(TraditionalForm\`T = \((n - 1)\)\ \[Tau]\)]],
  ".  The Fourier series is then"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`x\&~\_k = \(1\/\@n\) \(\[Sum]\+\(m = 1\)\%n\( x\_m\) 
            Exp[\(\(2  \[Pi]\ \[ImaginaryI]\)\/n\) \((m - 1)\) \((k - 
                    1)\)]\)\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Center,
  TextJustification->0],

Cell["such that", "Text"],

Cell[BoxData[
    \(TraditionalForm\`x\_m = \(1\/\@n\) \(\[Sum]\+\(k = 1\)\%n\( x\&~\_k\) 
            Exp[\(-\(\(2  \[Pi]\ \[ImaginaryI]\)\/n\)\) \((k - 1)\) \((m - 
                    1)\)]\)\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "is represented as a sum over Fourier components with amplitudes ",
  Cell[BoxData[
      \(TraditionalForm\`x\&~\_k\)]],
  " and frequencies ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\_k = \(k - 1\)\/T\)]],
  ".  Note that the Fourier series can be defined without explicit reference \
to the time scale by choosing units in which ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] \[Rule] 1\)]],
  ".  The sampling rate is given by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\^\(-1\)\)]],
  " and the maximum frequency for which meaningful information can be \
extracted is ",
  Cell[BoxData[
      \(TraditionalForm\`\((2  \[Tau])\)\^\(-1\)\)]],
  " because a minimum of two samples per period are needed to determine a \
Fourier amplitude.  This critical or maximum frequency is known in the \
literature as the ",
  StyleBox["Nyquist frequency",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell["\<\
If the input signal is periodic and the measurements cover an integral number \
of periods, the Fourier series will be strongly dominated by that frequency.  \
The Fourier spectrum of a quasi-periodic signal typically exhibits a strong \
peak and several smaller peaks at multiples of the fundamental frequency.  \
Random or chaotic signals, on the hand, tend to produce broad, nearly \
featureless, spectral distributions.  Therefore, Fourier analysis provides a \
valuable technique for isolating periodic components from background noise.  \
Signal processing can be performed automatically by specialized electronic \
equipment or numerically by analyzing data for sampled signals.  Electronic \
or numerical algorithms can be used to filter the signals and to compensate \
for distortion or bandwidth limitations.  In this notebook we will examine \
the spectral properties of several types of time signals, but will not \
explore the more sophisticated techniques available to modern signal \
processing.\
\>", "Text"],

Cell["\<\
Although frequency distributions are generally complex functions, the \
relative strength of various frequency components can be assessed using the \
power spectrum \
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`P\_k = \(\(2\/n\) \[LeftBracketingBar]x\&~\_k\
\[RightBracketingBar]\^2 = \(2\/n\) 
          x\&~\_k\ \(x\&~\_k\^*\)\)\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "which has been normalized so that a sinusoidal function with frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\_k\)]],
  " and unit amplitude has unit power divided equally between the peak at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\_k\)]],
  " and its reflection at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\_\(1 + n - k\)\)]],
  ".  [The reflection symmetry is discussed later.]  This definition is \
similar to that used for mechanical or electrical oscillations for which the \
energy is proportional to the square of the displacement, hence the \
description of this quantity as power, but perhaps it should be more \
accurately named ",
  StyleBox["spectral intensity",
    FontSlant->"Italic"],
  " because it is can also be used for quantities without an associated \
energy."
}], "Text"],

Cell[TextData[{
  "The function ",
  StyleBox[ButtonBox["Fourier",
    ButtonStyle->"RefGuideLink"],
    FontWeight->"Bold"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["TimeSeries",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " accepts a list of ",
  StyleBox["n",
    FontSlant->"Italic"],
  " equally spaced time samples ",
  Cell[BoxData[
      \(TraditionalForm\`x\_m\)]],
  " and returns a list of Fourier amplitudes ",
  StyleBox[Cell[BoxData[
      FormBox[
        StyleBox[\(x\&~\_k\),
          FontWeight->"Plain"], TraditionalForm]], "InlineInput"], 
    "InlineInput"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`t\_m = \((m - 1)\) \[Tau]\)]],
  " are times and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\_k = \(k - 1\)\/T\)]],
  "are frequencies expressed in terms of the unspecified time interval ",
  Cell[BoxData[
      \(TraditionalForm\`T = \((n - 1)\) \[Tau]\)]],
  ".  The function ",
  StyleBox[ButtonBox["InverseFourier",
    ButtonStyle->"RefGuideLink"],
    FontWeight->"Bold"],
  StyleBox["[",
    FontWeight->"Bold"],
  StyleBox["FrequencySeries",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " accepts a list of equally spaced Fourier amplitudes and returns a time \
series constructed by inverse Fourier transformation."
}], "Text"],

Cell[TextData[{
  "Obviously, the Fourier series is closely related to the Fourier transform \
and is often called the discrete Fourier transform.  Although the \
mathematical properties of Fourier integrals are simpler in many respects \
than those of Fourier series, the series is directly applicable to data or to \
approximate numerical calculations for which observations or functional \
values are available only for discrete times.  The Fourier transformation, on \
the other hand, requires continuous functions that can be evaluated for any \
value of their arguments.  Another important difference is that Fourier \
series implicitly assume that signals are periodic in time whereas Fourier \
transformations over an infinite domain apply equally well to nonperiodic \
signals.  Nevertheless, Fourier series can be used to analyze nonperiodic \
signals within the observation period ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " provided that one does not expect that representation to apply to times \
outside the observed range."
}], "Text"],

Cell[TextData[{
  "A valuable reference which provides greater mathematical and technical \
detail and extensive references to the technical literature is:\n\t",
  StyleBox["Numerical Recipes \[LongDash]",
    FontSlant->"Italic"],
  " ",
  StyleBox["the Art of Scientific Computing",
    FontSlant->"Italic"],
  ", by W.H. Press, B.P. Flannery, S.A. Teukolsky, and W.T. Vetterling \
(Cambridge University Press, Cambridge, 1989)."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[BoxData[{
    \(\(ClearAll["\<Global`*\>"];\)\), "\n", 
    \(\(Off[General::spell, \ General::spell1];\)\), "\n", 
    \(\($TextStyle = {FontFamily \[Rule] "\<Times\>", 
          FontSize \[Rule] 12};\)\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Graphics`\>"];\)\), "\n", 
    \(Needs["\<Utilities`FilterOptions`\>"]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Implementation", "Section"],

Cell[TextData[{
  "It is useful to define functions which evaluate and plot the power \
spectrum for a given time series.  The function ",
  StyleBox["PowerSpectrum", "InlineInput",
    FontWeight->"Bold"],
  " evaluates the power spectrum.  The option ",
  StyleBox["ScaleType\[Rule]Symmetric", "InlineInput",
    FontWeight->"Bold"],
  " transforms the frequency scale to the range \[PlusMinus]",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  ", whereas ",
  StyleBox["ScaleType\[Rule]Unity", "InlineInput",
    FontWeight->"Bold"],
  " maps frequency onto the range {0,1}.  The function ",
  StyleBox["PlotPowerSpectrum", "InlineInput",
    FontWeight->"Bold"],
  " produces the plot.  The option ",
  StyleBox["PlotType\[Rule]ListPlot", "InlineInput",
    FontWeight->"Bold"],
  " yields a linear plot while the default ",
  StyleBox["PlotType\[Rule]LogListPlot", "InlineInput",
    FontWeight->"Bold"],
  " yields a semi-log plot."
}], "Text"],

Cell[BoxData[
    \(spectrum[TimeSeries_List, opts___Rule] := 
      Module[{FrequencyDistribution, PowerDistribution}, 
        FrequencyDistribution = Fourier[TimeSeries]; 
        PowerDistribution = 
          FrequencyDistribution\ Conjugate[FrequencyDistribution] 
            2/Length[TimeSeries]; 
        LogListPlot[\ PowerDistribution, \ opts\ ]\ ]\)], "Input"],

Cell[BoxData[{
    \(\(PowerSpectrum::usage = \*"\"\<PowerSpectrum[TimeSeries,opts___] \
evaluates the spectral intensity for a list of samples equally spaced in \
time.  The option ScaleType can be used to transform the frequency index. \\n \
ScaleType\[Rule]Symmetric displays frequencies on the scale \
{-\!\(1\/2\),\!\(1\/2\)}. \\n ScaleType\[Rule]Unity displays frequencies \
{0,1}.\>\"";\)\n\t\), "\n", 
    \(\(\(Options[PowerSpectrum] = {ScaleType \[Rule] Natural};\)\(\n\)
    \)\), "\n", 
    \(PowerSpectrum[TimeSeries_List, opts___Rule] := 
      Module[{FrequencyDistribution, PowerDistribution, n, frequencies, 
          type}, n = Length[TimeSeries]; 
        FrequencyDistribution = Fourier[TimeSeries]; 
        type = \(ScaleType /. {opts}\) /. Options[PowerSpectrum]; 
        frequencies = 
          Switch[ToString[type], "\<Unity\>", 
            Table[i\/n, {i, 0, n - 1}], "\<Symmetric\>", 
            Table[If[
                i \[LessEqual] 
                  1 + n\/2, \(i - 1. \)\/\(n - 1. \), \(i - 1.  - n\)\/\(n - \
1. \)], {i, 1, n}], _, Range[n]]; PowerDistribution = {}; 
        Do[AppendTo[
            PowerDistribution, {frequencies\[LeftDoubleBracket]
                i\[RightDoubleBracket], \(2\/n\) 
                FrequencyDistribution\[LeftDoubleBracket]
                  i\[RightDoubleBracket]\ Conjugate[
                  FrequencyDistribution\[LeftDoubleBracket]
                    i\[RightDoubleBracket]]}], {i, 1, n}]; 
        Return[PowerDistribution];\ ]\)}], "Input"],

Cell[BoxData[{
    \(\(\(PlotPowerSpectrum::usage = "\<PlotPowerSpectrum[PowerData,opts] \
plots a list of data for a power spectrum.  The option \
PlotType\[Rule]LogListPlot or PlotType\[Rule]ListPlot distinguishes between \
semi-log and linear plots, with LogListPlot being the default.  Additional \
options are passed to the plotting function.\>";\)\(\n\)
    \)\), "\n", 
    \(\(\(Options[
          PlotPowerSpectrum] = {PlotType \[Rule] LogListPlot};\)\(\n\)
    \)\), "\n", 
    \(PlotPowerSpectrum[data_List, opts___Rule] := 
      Module[{type, PlotFunction, optPlot}, 
        PlotFunction = \(PlotType /. {opts}\) /. Options[PlotPowerSpectrum]; 
        optPlot = FilterOptions[PlotFunction, opts]; 
        PlotFunction[data, optPlot, Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<frequency\>", "\<power\>"}]]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["General characteristics of Fourier series", "Section"],

Cell["\<\
To interpret power spectra, one must be aware of several important properties \
of discrete Fourier series.  Although they can be derived rigorously, we \
prefer to provide examples which illustrate these properties in action.  When \
evaluating these examples, please identify the relevant property.\
\>", "Text"],

Cell[TextData[{
  "Superposition: if ",
  Cell[BoxData[
      \(TraditionalForm\`f\_m = x\_m + y\_m\)]],
  " is the sum of two input signals, its Fourier transform ",
  Cell[BoxData[
      \(TraditionalForm\`f\&~\_m = x\&~\_m + y\&~\_m\)]],
  "  is the sum of the Fourier transforms of each signal independently."
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`{x\_k}\)]],
  " is purely real, the Fourier components satisfy the reflection symmetry ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\&~\_k\^*\) = \ x\&~\_\(n + 1 - k\)\)]],
  ".  Consequently, the power spectrum for a real function is symmetric about \
its midpoint and the maximum frequency that contains independent information \
is ",
  Cell[BoxData[
      \(TraditionalForm\`n/\((2  T)\)\)]],
  "."
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell["The inverse Fourier transform", "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TraditionalForm\`x\_m = \(1\/\@n\) \(\[Sum]\+\(k = 1\)\%n\( x\&~\_k\) 
            Exp[\(-\(\(2  \[Pi]\ \[ImaginaryI]\)\/n\)\) \((k - 1)\) \((m - 
                    1)\)]\)\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "is a periodic function, such that ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(n + m\) = x\_m\)]],
  ".  Therefore, if the input signal is composed of harmonic functions and \
the data cover an integral number of periods, the Fourier series consists of \
spikes at each input frequency and its reflection.  However, if any period is \
truncated a broad background is produced because suppression of the \
background involves delicate cancellations which require the presence of full \
periods sampled uniformly."
}], "Text",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell["General properties", "Subsection"],

Cell["Use the simple gaussian function ", "Text"],

Cell[BoxData[
    \(gaussian[t_, \[Tau]_, \[Sigma]_]\  := \ 
      Exp[\(-\((t - \[Tau])\)\^2\)/\((2  \[Sigma]\^2)\)]\)], "Input"],

Cell[TextData[{
  "for the following exercises.  When evaluating list plots, it will often be \
necessary to select the appropriate ranges and sometimes it is useful to \
connect the dots.  Often it is necessary to use ",
  StyleBox["PlotRange\[Rule]All", "InlineInput",
    FontWeight->"Bold"],
  " in order to identify the region of interest.  Also, make sure that your \
data are approximate real numbers instead of exact symbolic numbers."
}], "Text"],

Cell[TextData[{
  "Construct a table of 100 input data using \[Tau]\[Rule]70 and \[Sigma]\
\[Rule]20.  Use ",
  StyleBox["ListPlot", "InlineInput",
    FontWeight->"Bold"],
  " to view the data."
}], "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Evaluate the discrete Fourier transform of these data.  Compare the first \
element of the transform with the sum of the input data and explain the ratio \
between them.  [Hint: look at the symbolic expression for ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(x\&~\_1\),
          FontWeight->"Plain"], TraditionalForm]]],
  ".]"
}], "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Add elements 2 through 100 to a list with elements 100 to 2 in reversed \
order.  What happens to the imaginary parts?  What happens to the real parts?\
\
\>", "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Construct the inverse Fourier transform explicitly ",
  StyleBox["without",
    FontSlant->"Italic"],
  " using the built-in function.  Plot the inverse Fourier series for ",
  Cell[BoxData[
      \(TraditionalForm\`{t, 1, 200}\)]],
  " and compare with the original function.  [Hint: construct a table and use \
",
  StyleBox["ListPlot", "InlineInput",
    FontWeight->"Bold"],
  ".]"
}], "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "How does the Fourier transform depend upon the width \[Sigma]?  The option \
",
  StyleBox["ScaleType\[Rule]Symmetric", "InlineInput",
    FontWeight->"Bold"],
  " is useful here."
}], "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Periodic functions", "Subsection"],

Cell[TextData[{
  "Consider the simple sinusoidal function with period ",
  StyleBox["\[Lambda]",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    \(f[\[Lambda]_, t_] := Sin[\(2  \[Pi]\)\/\[Lambda]\ t]\)], "Input"],

Cell[TextData[{
  "Suppose that the period is \[Lambda]\[Rule]20.  Compare frequency spectra \
for observation times of ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " equal to 1, 2, 5, and 10 periods with 20 points sampled per period.  \
Interpret the result.  [Hint: remember that if the signal is real, the power \
spectrum must be symmetric.]"
}], "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Again suppose that the period is \[Lambda]\[Rule]20 but now the \
observation period ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " is  2.25, 5.25, or 10.25 periods.  How is the spectrum affected by \
truncation of a cycle?  Show that a single missing point matters also.  What \
is the effect of increasing ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  "?"
}], "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell["Evaluate the Fourier series for the function ", "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TraditionalForm\`g[
        t]\  = \ \[Sum]\+\(p = 1\)\%10 p\^\(-2\)\ Sin[\(\(2  \[Pi]\)\/\
\[Lambda]\) p\ t]\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "where \[Lambda]\[Rule]20 and ",
  Cell[BoxData[
      \(TraditionalForm\`n \[Rule] 50  \[Lambda]\)]],
  ".  Interpret the result.  What is the effect of truncation?  Compare the \
inverse Fourier series with the input function."
}], "Text",
  CellDingbat->None,
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Wave packets", "Subsection"],

Cell["\<\
Consider a simple wave packet constructed by modulating a sinusoidal signal \
with a gaussian envelope.\
\>", "Text"],

Cell[BoxData[
    \(packet[t_, \[Lambda]_, \[Tau]_, \[Sigma]_] := 
      f[\[Lambda], t]\ gaussian[t, \[Tau], \[Sigma]]\)], "Input"],

Cell["\<\
Construct and plot 1000 input data using {\[Lambda]\[Rule]100, \
\[Tau]\[Rule]500, \[Sigma]\[Rule]100}.\
\>", "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell["Evaluate and plot the power spectrum.  Interpret the result.", "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Study the dependence of the power spectrum upon \[Sigma].  What is the effect \
of decreasing \[Sigma]?\
\>", "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Show that changing \[Tau] does not affect the power spectrum (provided that \
the function is not cut off) \[LongDash] the position of the peak affects the \
phase but not the intensity of the Fourier transform.\
\>", "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Noise", "Subsection"],

Cell[TextData[{
  "Now suppose that our instrument receives noise in addition to the signal \
of interest.  Although the correlation between noise signals at neighboring \
time intervals depends upon details of instrumentation and mechanism far \
beyond the scope of this study, it is of interest to consider the effect of \
the simplest type of noise.  ",
  StyleBox["White noise",
    FontSlant->"Italic"],
  " is characterized by a uniform",
  StyleBox[" ",
    FontSlant->"Italic"],
  "power distribution and corresponds to random, uncorrelated, signals in \
each time interval.  Random signals usually follow a ",
  StyleBox["normal",
    FontSlant->"Italic"],
  " or ",
  StyleBox["Gaussian",
    FontSlant->"Italic"],
  " distribution.  It is useful to load a couple of packages."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Statistics`ContinuousDistributions`\>"];\)\), "\n", 
    \(Needs["\<Statistics`DataManipulation`\>"]\)}], "Input"],

Cell[TextData[{
  "Suppose that the noise is characterized by a width ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma] = 0.1\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "compared to a unit signal.  "
}], "Text"],

Cell[BoxData[
    \(NoiseSignal[\[Sigma]_] := 
      Random[\ NormalDistribution[0. , \[Sigma]]\ ]\)], "Input"],

Cell["\<\
It is instructive to use a histogram of the noise signal to verify that our \
noise function is distributed normally.\
\>", "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(\(histo = 
        BinCounts[\ 
          Table[NoiseSignal[0.1], {1000}], \ {\(-0.4\), 0.4, 
            0.05}];\)\), "\[IndentingNewLine]", 
    \(\(bins = Range[\(-0.375\), 0.375, 0.05];\)\), "\[IndentingNewLine]", 
    \(\(histodata = 
        Transpose[{bins, histo}] /. {x_, y_} \[Rule] {x, y, 
              0.05};\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(GeneralizedBarChart[histodata, PlotRange \[Rule] All, 
        Frame \[Rule] True\ ];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 1.19048 0.0147151 0.00314761 [
[.02381 -0.0125 -13.6563 -15.6875 ]
[.02381 -0.0125 13.6563 0 ]
[.2619 -0.0125 -13.6563 -15.6875 ]
[.2619 -0.0125 13.6563 0 ]
[.5 -0.0125 -5 -15.6875 ]
[.5 -0.0125 5 0 ]
[.7381 -0.0125 -9.5 -15.6875 ]
[.7381 -0.0125 9.5 0 ]
[.97619 -0.0125 -9.5 -15.6875 ]
[.97619 -0.0125 9.5 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -10 -7.84375 ]
[-0.0125 .01472 0 7.84375 ]
[-0.0125 .09341 -16 -7.84375 ]
[-0.0125 .09341 0 7.84375 ]
[-0.0125 .1721 -16 -7.84375 ]
[-0.0125 .1721 0 7.84375 ]
[-0.0125 .25079 -16 -7.84375 ]
[-0.0125 .25079 0 7.84375 ]
[-0.0125 .32948 -22 -7.84375 ]
[-0.0125 .32948 0 7.84375 ]
[-0.0125 .40817 -22 -7.84375 ]
[-0.0125 .40817 0 7.84375 ]
[-0.0125 .48686 -22 -7.84375 ]
[-0.0125 .48686 0 7.84375 ]
[-0.0125 .56555 -22 -7.84375 ]
[-0.0125 .56555 0 7.84375 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -74.6563 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.313 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -74.6563 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.313 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .09341 m
.00625 .09341 L
s
gsave
-0.0125 .09341 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
0 .1721 m
.00625 .1721 L
s
gsave
-0.0125 .1721 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
0 .25079 m
.00625 .25079 L
s
gsave
-0.0125 .25079 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(75) show
1.000 setlinewidth
grestore
0 .32948 m
.00625 .32948 L
s
gsave
-0.0125 .32948 -83 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
0 .40817 m
.00625 .40817 L
s
gsave
-0.0125 .40817 -83 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(125) show
1.000 setlinewidth
grestore
0 .48686 m
.00625 .48686 L
s
gsave
-0.0125 .48686 -83 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
0 .56555 m
.00625 .56555 L
s
gsave
-0.0125 .56555 -83 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(175) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03045 m
.00375 .03045 L
s
0 .04619 m
.00375 .04619 L
s
0 .06193 m
.00375 .06193 L
s
0 .07767 m
.00375 .07767 L
s
0 .10914 m
.00375 .10914 L
s
0 .12488 m
.00375 .12488 L
s
0 .14062 m
.00375 .14062 L
s
0 .15636 m
.00375 .15636 L
s
0 .18783 m
.00375 .18783 L
s
0 .20357 m
.00375 .20357 L
s
0 .21931 m
.00375 .21931 L
s
0 .23505 m
.00375 .23505 L
s
0 .26652 m
.00375 .26652 L
s
0 .28226 m
.00375 .28226 L
s
0 .298 m
.00375 .298 L
s
0 .31374 m
.00375 .31374 L
s
0 .34521 m
.00375 .34521 L
s
0 .36095 m
.00375 .36095 L
s
0 .37669 m
.00375 .37669 L
s
0 .39243 m
.00375 .39243 L
s
0 .4239 m
.00375 .4239 L
s
0 .43964 m
.00375 .43964 L
s
0 .45538 m
.00375 .45538 L
s
0 .47112 m
.00375 .47112 L
s
0 .5026 m
.00375 .5026 L
s
0 .51833 m
.00375 .51833 L
s
0 .53407 m
.00375 .53407 L
s
0 .54981 m
.00375 .54981 L
s
0 .58129 m
.00375 .58129 L
s
0 .59702 m
.00375 .59702 L
s
0 .61276 m
.00375 .61276 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09341 m
1 .09341 L
s
.99375 .1721 m
1 .1721 L
s
.99375 .25079 m
1 .25079 L
s
.99375 .32948 m
1 .32948 L
s
.99375 .40817 m
1 .40817 L
s
.99375 .48686 m
1 .48686 L
s
.99375 .56555 m
1 .56555 L
s
.125 Mabswid
.99625 .03045 m
1 .03045 L
s
.99625 .04619 m
1 .04619 L
s
.99625 .06193 m
1 .06193 L
s
.99625 .07767 m
1 .07767 L
s
.99625 .10914 m
1 .10914 L
s
.99625 .12488 m
1 .12488 L
s
.99625 .14062 m
1 .14062 L
s
.99625 .15636 m
1 .15636 L
s
.99625 .18783 m
1 .18783 L
s
.99625 .20357 m
1 .20357 L
s
.99625 .21931 m
1 .21931 L
s
.99625 .23505 m
1 .23505 L
s
.99625 .26652 m
1 .26652 L
s
.99625 .28226 m
1 .28226 L
s
.99625 .298 m
1 .298 L
s
.99625 .31374 m
1 .31374 L
s
.99625 .34521 m
1 .34521 L
s
.99625 .36095 m
1 .36095 L
s
.99625 .37669 m
1 .37669 L
s
.99625 .39243 m
1 .39243 L
s
.99625 .4239 m
1 .4239 L
s
.99625 .43964 m
1 .43964 L
s
.99625 .45538 m
1 .45538 L
s
.99625 .47112 m
1 .47112 L
s
.99625 .5026 m
1 .5026 L
s
.99625 .51833 m
1 .51833 L
s
.99625 .53407 m
1 .53407 L
s
.99625 .54981 m
1 .54981 L
s
.99625 .58129 m
1 .58129 L
s
.99625 .59702 m
1 .59702 L
s
.99625 .61276 m
1 .61276 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.02381 .01472 m
.02381 .01472 L
.08333 .01472 L
.08333 .01472 L
F
0 g
.5 Mabswid
.02381 .01472 m
.02381 .01472 L
.08333 .01472 L
.08333 .01472 L
.02381 .01472 L
s
1 0 0 r
.08333 .01472 m
.08333 .01472 L
.14286 .01472 L
.14286 .01472 L
F
0 g
.08333 .01472 m
.08333 .01472 L
.14286 .01472 L
.14286 .01472 L
.08333 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .02731 L
.20238 .02731 L
.20238 .01472 L
F
0 g
.14286 .01472 m
.14286 .02731 L
.20238 .02731 L
.20238 .01472 L
.14286 .01472 L
s
1 0 0 r
.20238 .01472 m
.20238 .06822 L
.2619 .06822 L
.2619 .01472 L
F
0 g
.20238 .01472 m
.20238 .06822 L
.2619 .06822 L
.2619 .01472 L
.20238 .01472 L
s
1 0 0 r
.2619 .01472 m
.2619 .15006 L
.32143 .15006 L
.32143 .01472 L
F
0 g
.2619 .01472 m
.2619 .15006 L
.32143 .15006 L
.32143 .01472 L
.2619 .01472 L
s
1 0 0 r
.32143 .01472 m
.32143 .26967 L
.38095 .26967 L
.38095 .01472 L
F
0 g
.32143 .01472 m
.32143 .26967 L
.38095 .26967 L
.38095 .01472 L
.32143 .01472 L
s
1 0 0 r
.38095 .01472 m
.38095 .55925 L
.44048 .55925 L
.44048 .01472 L
F
0 g
.38095 .01472 m
.38095 .55925 L
.44048 .55925 L
.44048 .01472 L
.38095 .01472 L
s
1 0 0 r
.44048 .01472 m
.44048 .60332 L
.5 .60332 L
.5 .01472 L
F
0 g
.44048 .01472 m
.44048 .60332 L
.5 .60332 L
.5 .01472 L
.44048 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .58758 L
.55952 .58758 L
.55952 .01472 L
F
0 g
.5 .01472 m
.5 .58758 L
.55952 .58758 L
.55952 .01472 L
.5 .01472 L
s
1 0 0 r
.55952 .01472 m
.55952 .47427 L
.61905 .47427 L
.61905 .01472 L
F
0 g
.55952 .01472 m
.55952 .47427 L
.61905 .47427 L
.61905 .01472 L
.55952 .01472 L
s
1 0 0 r
.61905 .01472 m
.61905 .30115 L
.67857 .30115 L
.67857 .01472 L
F
0 g
.61905 .01472 m
.61905 .30115 L
.67857 .30115 L
.67857 .01472 L
.61905 .01472 L
s
1 0 0 r
.67857 .01472 m
.67857 .16265 L
.7381 .16265 L
.7381 .01472 L
F
0 g
.67857 .01472 m
.67857 .16265 L
.7381 .16265 L
.7381 .01472 L
.67857 .01472 L
s
1 0 0 r
.7381 .01472 m
.7381 .08396 L
.79762 .08396 L
.79762 .01472 L
F
0 g
.7381 .01472 m
.7381 .08396 L
.79762 .08396 L
.79762 .01472 L
.7381 .01472 L
s
1 0 0 r
.79762 .01472 m
.79762 .03045 L
.85714 .03045 L
.85714 .01472 L
F
0 g
.79762 .01472 m
.79762 .03045 L
.85714 .03045 L
.85714 .01472 L
.79762 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .02101 L
.91667 .02101 L
.91667 .01472 L
F
0 g
.85714 .01472 m
.85714 .02101 L
.91667 .02101 L
.91667 .01472 L
.85714 .01472 L
s
1 0 0 r
.91667 .01472 m
.91667 .01472 L
.97619 .01472 L
.97619 .01472 L
F
0 g
.91667 .01472 m
.91667 .01472 L
.97619 .01472 L
.97619 .01472 L
.91667 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00;@3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00<0okmd0000001d_ol01@3oool0
103ooml0W4P00018W03Ooom80?ooo`050?oOW018000000000000M02oool00`3oool01@3o_g@00000
07Boo`3oool0_g@000H0000000<0B9cO0?ooo`3oool0AP3oool01@3ogi`0B0000000000007@0_ooo
0500oooo00D0omnL04P000000000001d0;ooo`030?ooo`050?noM0000000M;oo0?ooo`2oM0001P00
00000`18W=l0oooo0?ooo`150?ooo`050?oOW018000000000000M02oool00`3oool00`3o_g@00000
07Boo`050?ooo`040?oog`2LB00004RL0=ooo`L0oooo000/0?ooo`070?oo_`1d0000M;oo0?ooo`3o
_g@0001d0;ooo`020?ooo`030?noM0000000M;oo00D0oooo00@0oooO09a80000B9`0goooA`3oool0
1`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Boo`020?ooo`030=nL
B0000000000000<0000000<004RL0=ooo`3oool0A@3oool01`3ookl0M00007Boo`3oool0okmd0000
M02oool0CP3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Bo
o`020?ooo`030=nLB0000000000000<0000000<004RL0=ooo`3oool0A03oool01`3ookl0M00007Bo
o`3oool0okmd0000M02oool00P3oool00`3o_g@0000007Boo`050?ooo`040?oog`2LB00004RL0=oo
o`L0oooo000/0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool02@3oool0103ooml0
W4P00018W03Ooom70?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool01`3oool00`3O
W4P0B9cO0?ooo`020?ooo`030=nLM02Lgol0oooo04D0oooo00<0_g@00018W03Oool00P3oool00`2o
M00007Bo0?ooo`1=0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool01`3oool00`3O
W4P0B9cO0?ooo`020?ooo`030=nLM02Lgol0oooo04@0oooo00<0_g@00018W03Oool00P3oool00`2o
M00007Bo0?ooo`090?ooo`040?oog`2LB00004RL0=ooo`L0oooo000[0?ooo`030?oo_`1d0000B9cO
00<0oooo00<0gia80000M02oool01@3oool00`2oM0000000000000050000000307Boo`3oool0oooo
04<0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`080?ooo`030=nLB01d_ol0oooo
04P0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`1<0?ooo`030?oo_`1d0000B9cO
00<0oooo00<0gia80000M02oool0203oool00`3OW4P0M;oo0?ooo`170?ooo`030?oo_`1d0000B9cO
00<0oooo00<0gia80000M02oool01@3oool00`2oM0000000000000050000000307Boo`3oool0oooo
00@0oooo000O0?ooo`030?oog`2LB000000000L0000000D0B9cO0?ooo`3ogi`0B00007Boo`030?oo
o`030?noM00004P0W=oo00D0oooo00P0omnL07BLg`3oool0oooo0?oog`2LB00004RL0=ooocT0oooo
00<0oooO09a8000000001`0000001P18W=l0oooo0?ooo`3ogi`0B00007Boo`<0oooo00<0okmd0000
B02Lgol02@3oool00`2oM4P0W=oo0?ooo`170?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000
B02Lgol0C03oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00T0oooo00<0_gA809cO
o`3oool0AP3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00P0omnL07BL
g`3oool0oooo0?oog`2LB00004RL0=ooo`L0oooo000[0?ooo`030?oOW0180000M;oo00<0oooo00<0
okmd0000B02Lgol01P3oool01`3OW4P0M;oo0?ooo`3ooml0W4P00018W03Oool0AP3oool00`3ogi`0
B00007Boo`030?ooo`030?noM00004P0W=oo00T0oooo00<0oooO09a8M02oool0A`3oool00`3ogi`0
B00007Boo`030?ooo`030?noM00004P0W=oo04`0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0
001809cOo`090?ooo`030?oog`2LB7@0_ooo04H0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0
001809cOo`060?ooo`070=nLB01d_ol0oooo0?oog`2LB00004RL0=ooo`070?ooo`00:`3oool00`3o
gi`0B00007Boo`030?ooo`030?noM00004P0W=oo00H0oooo00L0oooO09a8M02oool0oooO09a80000
B9`0gooo04H0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0:0?ooo`030?noM000
M;l0oooo04H0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`1<0?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol02P3oool00`3o_g@007Bo0?ooo`150?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol01P3oool01`3ooml0W4Qd0;ooo`3ooml0W4P00018W03O
ool01`3oool002/0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`060?oO
W018M;l0oooO09a80000B9`0goooAP3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo
00X0oooo00<0oono07@0B02Lgol0AP3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo
04`0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0:0?ooo`030?oo_`1d04P0W=oo
04D0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`070?ooo`060?oOW018M;l0oooO
09a80000B9`0gooo1`3oool002/0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`08
0?ooo`050=nLB01d_ml0W4P00018W03Oool0AP3oool00`3ookl0M00004RLg`030?ooo`030=nLB000
07@0_ooo00X0oooo00<0oono07@00018W=l0AP3oool00`3ookl0M00004RLg`030?ooo`030=nLB000
07@0_ooo04`0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`0:0?ooo`030?oo_`1d
0000B9cO04D0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`080?ooo`050=nLB01d
_ml0W4P00018W03Oool01`3oool002`0oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?oo
o`080?ooo`050?oog`2LB4P0B4P00018W03Oool0A`3oool00`3OW4P004RL0=ooo`020?ooo`030;md
0000M;l0oooo00D0oooo00<0oknL09cOo`3oool00P3oool00`3ogi`0B00004RLg`170?ooo`030=nL
B000B9`0gooo0080oooo00<0_g@0001d_`3oool0C@3oool00`3OW4P004RL0=ooo`020?ooo`030;md
0000M;l0oooo00D0oooo00<0oknL09cOo`3oool00P3oool00`3ogi`0B00004RLg`160?ooo`030=nL
B000B9`0gooo0080oooo00<0_g@0001d_`3oool0203oool01@3ooml0W4Q804Q80000B9`0gooo00L0
oooo000/0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`0:0?ooo`040?oOW018000004RL
0=ooodL0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00H0oooo00P0oooO09a8B02Lgol0
oooo0?oo_`1d0000001d0;ooodL0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo04h0oooo
00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00H0oooo00P0oooO09a8B02Lgol0oooo0?oo_`1d
0000001d0;ooodH0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00X0oooo00@0omnL04P0
0000B9`0gooo1`3oool002d0oooo00D0oono07@000000000001d0;ooo`0<0?ooo`030=nLB000B9`0
gooo04P0oooo00D0oono07@000000000001d0;ooo`080?ooo`060?oog`2LB00000000000000007@0
_oooB@3oool01@3ookl0M0000000000007@0_ooo0500oooo00D0oono07@000000000001d0;ooo`08
0?ooo`060?oog`2LB00000000000000007@0_oooB03oool01@3ookl0M0000000000007@0_ooo00`0
oooo00<0gia80018W03Oool01`3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool002L0ooooo`000023000000L0oooo000H0?ooo`050?oOW018
000000000000M02oool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`005`3oool01`3ookl0M00007Bo
o`3oool0okmd0000M02oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05T0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`005`3oool00`2oM00004RL
0=ooo`020?ooo`030;md0000M;l0oooo00P0oooo00<000000?ooo`3oool0_@3oool00`000000oooo
0?ooo`2n0?ooo`030000003oool0oooo00D0oooo000F0?ooo`030?oo_`1d0000B9cO00<0oooo00<0
gia80000M02oool0203oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0;h0oooo00<0
00000?ooo`3oool01@3oool001H0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`08
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool001H0oooo00<0omnL04P0
001d_ol00`3oool00`3o_g@0001809cOo`080?ooool00000P`0000070?ooo`005P3oool00`3ogi`0
B00007Boo`030?ooo`030?noM00004P0W=oo00P0oooo00<000000?ooo`3oool0=03oool00`000000
o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000
o`000?l0000D0?l000030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000
o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000
o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000
o`000?l0000C0?l000030000003oool0oooo01h0oooo00<000000?ooo`3oool01@3oool001H0oooo
00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`080?ooo`030000003oool0oooo03@0oooo
00<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`00
00<000000?l0003o0000503o00000`000000o`000?l0000C0?l000030000003o0000o`0001@0o`00
00<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`00
00<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`00
5`00000P0?ooo`030000003oool0oooo00D0oooo000F0?ooo`030?oo_`1d0000B9cO00<0oooo00<0
gia80000M02oool0203oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0001@0o`0000<0
00000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<0
00000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<0
00000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<0
00000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo03@0oooo00<0
00000?ooo`3oool01@3oool001L0oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`08
0?ooo`030000003oool0oooo03@0oooo6000000F0?l000030000003o0000o`0001@0o`0000<00000
0?l0003o0000503o00000`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<00000
0?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<00000
0?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`050?ooo`005`3oool01`3ookl0M00007Boo`3oool0
okmd0000M02oool02@3oool00`000000oooo0?ooo`1;0?ooo`030000003o0000o`0001@0o`0000<0
00000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001<0o`0000<0
00000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<0
00000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<0
00000?l0003o0000503o00000`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00D0oooo000H
0?ooo`050?oo_`1d000000000000M02oool02P3oool3000004/0oooo00<000000?l0003o0000503o
00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o00004`3o
00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o
00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o
000H000003@0oooo0`0000070?ooo`009`3oool00`000000oooo0?ooo`1;0?ooo`030000003o0000
o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000
o`0001<0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000
o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000
o`0001@0o`0000<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`050?ooo`009`3oool00`00
0000oooo0?ooo`1;0?ooo`030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`050?ooo`009`3oool00`000000oooo0?ooo`1;0?ooo`030000003o0000o`0001@0
o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001<0
o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0
o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0
o`0000<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`050?ooo`009`3oool00`000000oooo
0?ooo`1;0?ooo`030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`00
0?l0000D0?l000030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000o`00
0?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`00
0?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`050?ooo`009`3oool00`000000oooo0?ooo`1;0?ooo`030000003o0000o`0001@0o`0000<0
00000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001<0o`0000<0
00000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<0
00000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`050?ooo`009`3oool3000004/0oooo00<00000
0?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<00000
0?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<00000
0?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<00000
0?l0003o0000503o00000`000000oooo0?ooo`190?ooo`<000001`3oool002L0oooo00<000000?oo
o`3oool0B`3oool00`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0
003o0000503o00000`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0
003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0
003o0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo04/0oooo00<000000?oo
o`3oool01@3oool002L0oooo00<000000?ooo`3oool0B`3oool00`000000o`000?l0000D0?l00003
0000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000C0?l00003
0000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l00003
0000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l00003
0000003oool0oooo04/0oooo00<000000?ooo`3oool01@3oool002L0oooo00<000000?ooo`3oool0
B`3oool00`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000
503o00000`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000
503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000
503o00000`000000o`000?l0000D0?l000030000003oool0oooo04/0oooo00<000000?ooo`3oool0
1@3oool002L0oooo00<000000?ooo`3oool0B`3oool00`000000o`000?l0000D0?l000030000003o
0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000C0?l000030000003o
0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o
0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o
ool0oooo04/0oooo00<000000?ooo`3oool01@3oool002L0oooo00<000000?ooo`3oool0B`3oool0
0`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o0000
0`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o0000
0`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o0000
0`000000o`000?l0000D0?l000030000003oool0oooo04/0oooo00<000000?ooo`3oool01@3oool0
02L0oooo0`00001;0?ooo`030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0B@3oool30000
00L0oooo000W0?ooo`030000003oool0oooo04/0oooo00<000000?l0003o0000503o00000`000000
o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o00004`3o00000`000000
o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000
o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo00D0oooo000W0?ooo`030000003oool0oooo04/0oooo
6000000F0?l000030000003o0000o`0001@0o`0000<000000?l0003o00004`3o00000`000000o`00
0?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`00
0?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo00D0oooo000W0?ooo`030000003oool0oooo0680oooo00<0
00000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001<0o`0000<0
00000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<0
00000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`050?ooo`009`3oool00`000000oooo0?ooo`1R
0?ooo`030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000C
0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D
0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D
0?l000030000003oool0oooo04/0oooo00<000000?ooo`3oool01@3oool002L0oooo00<000000?oo
o`3oool0HP3oool00`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0
003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0
003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0
003o0000503o00000`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00D0oooo000W0?ooo`<0
0000HP3oool00`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o
00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o
0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o
0000503o00000`000000oooo0?ooo`190?ooo`<000001`3oool000d0oooo00<0_g@0000000000000
100000001018W=l0oooo0?oog`2LB0030000000307Boo`3oool0oooo00T0oooo00<000000?ooo`3o
ool0HP3oool00`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o
00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o
0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o
0000503o00000`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00D0oooo000>0?ooo`030=nL
B0000000000000<0000000D004RL0=ooo`3ooml0W4Qd0;ooo`020?ooo`030;md001d_ol0oooo00T0
oooo00<000000?ooo`3oool0HP3oool00`000000o`000?l0000D0?l000030000003o0000o`0001@0
o`0000<000000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0
o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0
o`006000001=0?ooo`030000003oool0oooo00D0oooo000?0?ooo`030=nLB018W=l0oooo0080oooo
00<0giad09cOo`3oool0103oool00`3ooml0W4Qd0;ooo`090?ooo`030000003oool0oooo0680oooo
00<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001<0o`00
00<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`00
00<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo0680oooo
00<000000?ooo`3oool01@3oool00100oooo00<0gia807Boo`3oool02@3oool00`2oM000M;oo0?oo
o`080?ooo`030000003oool0oooo0680oooo00<000000?l0003o0000503o00000`000000o`000?l0
000D0?l000030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000o`000?l0
000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0
000D0?l000030000003oool0oooo0680oooo00<000000?ooo`3oool01@3oool00140oooo00<0_gA8
09cOo`3oool01`3oool00`3ooml0W4P004RLg`090?ooo`030000003oool0oooo0680oooo00<00000
0?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001<0o`0000<00000
0?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<00000
0?l0003o0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo0680oooo00<00000
0?ooo`3oool01@3oool00140oooo00<0oooO09a8M02oool01`3oool00`3OW4P0000007Boo`090?oo
o`@00000H@3oool00`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0
003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0
003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?oo
o`3oool0G`3oool4000000L0oooo000B0?ooo`030?noM000M;l0oooo0080oooo00L0gmoO0?ooo`3o
okl0M0000000000007@0_ooo00T0oooo00<000000?ooo`3oool0HP3oool00`000000o`000?l0000D
0?l000030000003o0000o`0001@0o`0000<000000?l0003o00004`3o00000`000000o`000?l0000D
0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D
0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`05
0?ooo`004P3oool00`3ookl0M01809cOo`020?ooo`060=nLB000000000000000000004P0W=oo2P3o
ool00`000000oooo0?ooo`1R0?ooo`030000003o0000o`0001@0o`0000<000000?l0003o0000503o
00000`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o
00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o
00000`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00D0oooo000B0?ooo`030?oo_`1d0000
B9cO0080oooo00@0oono07@000000000B9cO303oool00`000000oooo0?ooo`1R0?ooo`030000003o
0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000C0?l000030000003o
0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o
0000o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`1R0?ooo`030000003o
ool0oooo00D0oooo000=0?ooo`030?noW02Lgol0oooo0080oooo00<0omnL04P00018W=l00`3oool0
0`2oM000M;oo0?ooo`0<0?ooo`030000003oool0oooo0680oooo00<000000?l0003o0000503o0000
0`000000o`000?l0000D0?l000030000003o0000o`0001<0o`0000<000000?l0003o0000503o0000
0`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o0000
0`000000o`000?l0000D0?l000030000003oool0oooo0680oooo00<000000?ooo`3oool01@3oool0
00d0oooo00P0oooO09a8B02Lgol0oooo0?oo_`1d0000001d0;ooo`<0oooo00H0omnL04P000000000
00000000B02Lgol90?ooo`030000003oool0oooo0680oooo00<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003oool0oooo0680oooo00<000000?ooo`3oool01@3oool000h0
oooo00H0oooO09a80000000000000000M02oool50?ooo`050;md00000000000000000018W=l02@3o
ool300000680oooo00<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o
0000o`0001<0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o
0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o
ool0oooo0600oooo0`0000070?ooo`009`3oool00`000000oooo0?ooo`1R0?ooo`030000003o0000
o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000C0?l000030000003o0000
o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000
o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`1R0?ooo`030000003oool0
oooo00D0oooo000W0?ooo`030000003oool0oooo0680oooo00<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003oool0oooo0680oooo00<000000?ooo`3oool01@3oool002L0
oooo00<000000?ooo`3oool0HP3oool00`000000o`000?l0000D0?l000030000003o0000o`0001@0
o`0000<000000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0
o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0
o`0000<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`050?ooo`009`3oool00`000000oooo
0?ooo`1R0?ooo`030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`00
0?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`00
0?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo
0?ooo`1R0?ooo`030000003oool0oooo00D0oooo000W0?ooo`030000003oool0oooo0680oooo00<0
00000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001<0o`0000<0
00000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<0
00000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo0680oooo00<0
00000?ooo`3oool01@3oool002L0oooo0`00001R0?ooo`030000003o0000o`0001@0o`0000<00000
0?l0003o0000503o00000`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<00000
0?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<00000
0?l0003o0000503o00000`000000oooo0?ooo`1P0?ooo`<000001`3oool002L0oooo00<000000?oo
o`3oool0HP3oool00`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0
003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0
003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?oo
o`3oool0HP3oool00`000000oooo0?ooo`050?ooo`009`3oool00`000000oooo0?ooo`1R0?ooo`03
0000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000C0?l00003
0000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l00003
0000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`1R0?ooo`03
0000003oool0oooo00D0oooo000W0?ooo`030000003oool0oooo0680oooo00<000000?l0003o0000
503o00000`000000o`000?l0000D0?l000030000003o0000o`0001<0o`0000<000000?l0003o0000
503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000
503o00000`000000o`000?l0000D0?l000030000003oool0oooo0680oooo00<000000?ooo`3oool0
1@3oool002L0oooo00<000000?ooo`3oool0HP3oool00`000000o`000?l0000D0?l000030000003o
0000o`0001@0o`0000<000000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o
0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o
0000o`0001@0o`0000<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`050?ooo`009`3oool0
0`000000oooo0?ooo`1R0?ooo`030000003o0000o`0001@0o`0000<000000?l0003o0000503o0000
0`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o0000
0`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o0000
0`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00D0oooo000W0?ooo`<00000HP3oool00`00
0000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o00004`3o00000`00
0000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0H03oool30000
00L0oooo000W0?ooo`030000003oool0oooo0680oooo00<000000?l0003o0000503o00000`000000
o`000?l0000D0?l000030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000
o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000
o`000?l0000D0?l000030000003oool0oooo0680oooo00<000000?ooo`3oool01@3oool002L0oooo
00<000000?ooo`3oool0HP3oool00`000000o`000?l0000D0?l000030000003o0000o`0001@0o`00
00<000000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`00
00<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`00
00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`050?ooo`009`3oool00`000000oooo0?oo
o`1R0?ooo`030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0
000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0
000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo00D0oooo000W0?ooo`030000003oool0oooo0680oooo6000000F
0?l000030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D
0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D
0?l000030000003oool0oooo0680oooo00<000000?ooo`3oool01@3oool002L0oooo00<000000?oo
o`3oool0N@3oool00`000000o`000?l0000D0?l000030000003o0000o`0001<0o`0000<000000?l0
003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0
003o0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo0680oooo00<000000?oo
o`3oool01@3oool002L0oooo0`00001i0?ooo`030000003o0000o`0001@0o`0000<000000?l0003o
00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o
0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3o
ool0H03oool3000000L0oooo000=0?ooo`030?oog`2LB00000000080000000<0M;oo0?ooo`3oool0
0`3oool01@3ogi`0B0000000000007@0_ooo00X0oooo00<000000?ooo`3oool0N@3oool00`000000
o`000?l0000D0?l000030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000
o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000
o`000?l0000D0?l000030000003oool0oooo0680oooo00<000000?ooo`3oool01@3oool000d0oooo
00<0oooO09a8M02oool00P3oool00`2oM000M;oo0?ooo`020?ooo`070?oo_`1d0000M;oo0?ooo`3o
_g@0001d0;ooo`090?ooo`030000003oool0oooo07T0oooo00<000000?l0003o0000503o00000`00
0000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003o0000o`0001@0o`006000001T0?ooo`030000003oool0oooo
00D0oooo000B0?ooo`030?oog`2LB7@0_ooo0080oooo00<0_g@00018W03Oool00P3oool00`2oM000
07Bo0?ooo`080?ooo`030000003oool0oooo07T0oooo00<000000?l0003o0000503o00000`000000
o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000
o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`050?ooo`004`3oool01P2oM000M;oo0?ooo`3ookl0M00004RLg`<0oooo00<0gia80000
M02oool0203oool00`000000oooo0?ooo`1i0?ooo`030000003o0000o`0001@0o`0000<000000?l0
003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0
003o0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo07T0oooo00<000000?oo
o`3oool01@3oool00180oooo00L0oooO09a80018W=l0oooo0?oOW0180000M;oo00<0oooo00<0okmd
0000B02Lgol0203oool00`000000oooo0?ooo`1i0?ooo`030000003o0000o`0001@0o`0000<00000
0?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<00000
0?l0003o0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo07T0oooo00<00000
0?ooo`3oool01@3oool00180oooo00L0gia80000001d_ol0oooo0?oOW0180000M;oo00<0oooo00<0
okmd0000B02Lgol0203oool4000007P0oooo00<000000?l0003o0000503o00000`000000o`000?l0
000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0
000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0MP3oool4000000L0oooo000>
0?ooo`0;0=oOg`3oool0oono07@000000000001d0;ooo`3oool0omnL04P0001d_ol00`3oool00`3o
_g@0001809cOo`080?ooo`030000003oool0oooo07T0oooo00<000000?l0003o0000503o00000`00
0000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`050?ooo`003P3oool01P3OW4P00000000000000000001809cOo`80oooo00<0omnL
04P0001d_ol00`3oool00`3o_g@0001809cOo`080?ooo`030000003oool0oooo07T0oooo00<00000
0?l0003o0000503o00000`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<00000
0?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`050?ooo`003P3oool0103ookl0M00000000018W=l4
0?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0203oool00`000000oooo0?ooo`1i
0?ooo`030000003o0000o`0001@0o`0000<000000?l0003o00004`3o00000`000000o`000?l0000D
0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D
0?l000030000003oool0oooo07T0oooo00<000000?ooo`3oool01@3oool000l0oooo00<0_g@007Bo
o`3oool01@3oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00P0oooo00<000000?oo
o`3oool0N@3oool00`000000o`000?l0000D0?l000030000003o0000o`0001<0o`0000<000000?l0
003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0
003o0000503o00000`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00D0oooo000?0?ooo`06
0?oOW018000000000000000004P0W=oo0P3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool0
2@3oool00`000000oooo0?ooo`1i0?ooo`030000003o0000o`0001@0o`0000<000000?l0003o0000
4`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000
503o00000`000000o`000?l0000D0?l000030000003oool0oooo07T0oooo00<000000?ooo`3oool0
1@3oool00100oooo00D0_g@0000000000000000004RLg`030?ooo`050?oo_`1d000000000000M02o
ool02P3oool3000007T0oooo00<000000?l0003o0000503o00000`000000o`000?l0000C0?l00003
0000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l00003
0000003o0000o`0001@0o`0000<000000?ooo`3oool0M`3oool3000000L0oooo000W0?ooo`030000
003oool0oooo07T0oooo00<000000?l0003o0000503o00000`000000o`000?l0000C0?l000030000
003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000
003o0000o`0001@0o`0000<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`050?ooo`009`3o
ool00`000000oooo0?ooo`1i0?ooo`030000003o0000o`0001@0o`0000<000000?l0003o00004`3o
00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o
00000`000000o`000?l0000D0?l000030000003oool0oooo07T0oooo00<000000?ooo`3oool01@3o
ool002L0oooo00<000000?ooo`3oool0N@3oool00`000000o`000?l0000D0?l000030000003o0000
o`0001<0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000
o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`1i0?ooo`030000003oool0
oooo00D0oooo000W0?ooo`030000003oool0oooo07T0oooo00<000000?l0003o0000503o00000`00
0000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`050?ooo`009`3oool00`000000oooo0?ooo`1i0?ooo`030000003o0000o`0001@0
o`0000<000000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0
o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo07T0
oooo00<000000?ooo`3oool01@3oool002L0oooo0`00001i0?ooo`030000003o0000o`0001@0o`00
00<000000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`00
00<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo07L0oooo
0`0000070?ooo`009`3oool00`000000oooo0?ooo`1i0?ooo`030000003o0000o`0001@0o`0000<0
00000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<0
00000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo07T0oooo00<0
00000?ooo`3oool01@3oool002L0oooo00<000000?ooo`3oool0N@3oool00`000000o`000?l0000D
0?l000030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D
0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo00D0oooo000W0?ooo`030000003oool0oooo07T0oooo00<000000?l0
003o0000503o00000`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0
003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?oo
o`3oool0N@3oool00`000000oooo0?ooo`050?ooo`009`3oool00`000000oooo0?ooo`1i0?ooo`03
0000003o0000o`0001@0o`0000<000000?l0003o00004`3o00000`000000o`000?l0000D0?l00003
0000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l00003
0000003oool0oooo07T0oooo00<000000?ooo`3oool01@3oool002L0oooo00<000000?ooo`3oool0
N@3oool00`000000o`000?l0000D0?l000030000003o0000o`0001<0o`0000<000000?l0003o0000
503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000
503o00000`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00D0oooo000W0?ooo`<00000N@3o
ool00`000000o`000?l0000D0?l000030000003o0000o`0001<0o`0000<000000?l0003o0000503o
00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o
00000`000000oooo0?ooo`1g0?ooo`<000001`3oool002L0oooo00<000000?ooo`3oool0N@3oool0
0`000000o`000?l0000D0?l000030000003o0000o`0001<0o`0000<000000?l0003o0000503o0000
0`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o0000
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00D0oooo000W0?ooo`030000003oool0oooo
07T0oooo00<000000?l0003o0000503o00000`000000o`000?l0000C0?l000030000003o0000o`00
01@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`00
01@0o`0000<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`050?ooo`009`3oool00`000000
oooo0?ooo`1i0?ooo`030000003o0000o`0001@0o`0000<000000?l0003o00004`3o00000`000000
o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000
o`000?l0000D0?l000030000003oool0oooo07T0oooo00<000000?ooo`3oool01@3oool002L0oooo
00<000000?ooo`3oool0N@3oool00`000000o`000?l0000D0?l000030000003o0000o`0001<0o`00
00<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`00
00<000000?l0003o0000503o00000`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00D0oooo
000W0?ooo`030000003oool0oooo07T0oooo00<000000?l0003o0000503o00000`000000o`000?l0
000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0
000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`050?ooo`009`3oool3000007T0oooo00<000000?l0003o0000503o00000`000000o`000?l0000C
0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D
0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0M`3oool3000000L0oooo000@0?oo
o`030=nLB018W=l0oooo00<0oooo00<0oooO09a8000000000P0000000`1d_ol0oooo0?ooo`090?oo
o`030000003oool0oooo07T0oooo00<000000?l0003o0000503o00000`000000o`000?l0000C0?l0
00030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l0
00030000003o0000o`0001@0o`0000<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`050?oo
o`00403oool00`3ogi`0B4RL0=ooo`030?ooo`030?oog`2LB7@0_ooo0080oooo00<0_g@007Boo`3o
ool02@3oool00`000000oooo0?ooo`1i0?ooo`030000003o0000o`0001@0o`0000<000000?l0003o
00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o
0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo07T0oooo00<000000?ooo`3o
ool01@3oool00100oooo00<0oooO09a8B02Lgol0203oool00`3ooml0W4Qd0;ooo`090?ooo`030000
003oool0oooo07T0oooo00<000000?l0003o0000503o00000`000000o`000?l0000C0?l000030000
003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000
003o0000o`0001@0o`0000<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`050?ooo`004@3o
ool00`3OW4P0B9cO0?ooo`080?ooo`030;md001d_ol0oooo00P0oooo00<000000?ooo`3oool0N@3o
ool00`000000o`000?l0000D0?l000030000003o0000o`0001<0o`0000<000000?l0003o0000503o
00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o
00000`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00D0oooo000A0?ooo`030?oOW018B9`0
gooo00L0oooo00<0oooO09a80018W=l02@3oool00`000000oooo0?ooo`1i0?ooo`030000003o0000
o`0001@0o`0000<000000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000
o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003oool0
oooo07T0oooo00<000000?ooo`3oool01@3oool00140oooo00<0oooO09a8B02Lgol01`3oool00`3O
W4P0000007Boo`090?ooo`@00000N03oool00`000000o`000?l0000D0?l000030000003o0000o`00
01<0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`00
01@0o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`1f0?ooo`@000001`3oool00180
oooo00<0gia8001d_`3oool00P3oool01`3Ogml0oooo0?oo_`1d000000000000M02oool02@3oool0
0`000000oooo0?ooo`1i0?ooo`030000003o0000o`0001@0o`0000<000000?l0003o00004`3o0000
0`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o0000
0`000000o`000?l0000D0?l000030000003oool0oooo07T0oooo00<000000?ooo`3oool01@3oool0
0180oooo00<0oono07@0M02oool00P3oool01P3OW4P00000000000000000001809cOo`X0oooo00<0
00000?ooo`3oool0N@3oool00`000000o`000?l0000D0?l000030000003o0000o`0001<0o`0000<0
00000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<0
00000?l0003o0000503o00000`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00D0oooo000=
0?ooo`030?oOg`3Oool0oooo00<0oooo00P0_g@007Boo`3oool0oooo0?oo_`1d0000000004RLg``0
oooo00<000000?ooo`3oool0N@3oool00`000000o`000?l0000D0?l000030000003o0000o`0001<0
o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0
o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00D0
oooo000=0?ooo`030?oo_`1dB9`0gooo00<0oooo00<0okmd001d_`3oool00P3oool00`2oM000M;oo
0?ooo`0<0?ooo`030000003oool0oooo07T0oooo00<000000?l0003o0000503o00000`000000o`00
0?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`00
0?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0N@3oool00`000000oooo
0?ooo`050?ooo`003P3oool00`2oM000000000000003000000060000M02oool0oooo0?ooo`3ogi`0
B0000P0000000`0004P0W=oo0?ooo`080?ooo`030000003oool0oooo07T0oooo00<000000?l0003o
0000503o00000`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o
0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3o
ool0N@3oool00`000000oooo0?ooo`050?ooo`003P3oool00`3o_g@00000000000040000000507Bo
o`3oool0oooo0?ooo`2oM0000`0000000`18W=l0oooo0?ooo`070?ooo`<00000N@3oool00`000000
o`000?l0000D0?l000030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000
o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000
oooo0?ooo`1g0?ooo`<000001`3oool002L0oooo00<000000?ooo`3oool0N@3oool00`000000o`00
0?l0000D0?l000030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000o`00
0?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo00D0oooo000W0?ooo`030000003oool0oooo07T0oooo6000
000E0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0
000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`050?ooo`009`3oool00`000000oooo0?ooo`2@0?ooo`030000003o0000o`0001<0o`0000<00000
0?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<00000
0?l0003o0000503o00000`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00D0oooo000W0?oo
o`030000003oool0oooo0900oooo00<000000?l0003o00004`3o00000`000000o`000?l0000D0?l0
00030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l0
00030000003oool0oooo07T0oooo00<000000?ooo`3oool01@3oool002L0oooo00<000000?ooo`3o
ool0T03oool00`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o
0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3o
ool0N@3oool00`000000oooo0?ooo`050?ooo`009`3oool300000900oooo00<000000?l0003o0000
4`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000
503o00000`000000o`000?l0000D0?l000030000003oool0oooo07L0oooo0`0000070?ooo`009`3o
ool00`000000oooo0?ooo`2@0?ooo`030000003o0000o`0001<0o`0000<000000?l0003o0000503o
00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o
00000`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00D0oooo000W0?ooo`030000003oool0
oooo0900oooo00<000000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000
o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003oool0
oooo07T0oooo00<000000?ooo`3oool01@3oool002L0oooo00<000000?ooo`3oool0T03oool00`00
0000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`050?ooo`009`3oool00`000000oooo0?ooo`2@0?ooo`030000003o0000o`0001<0
o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0
o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00D0
oooo000W0?ooo`030000003oool0oooo0900oooo00<000000?l0003o00004`3o00000`000000o`00
0?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`00
0?l0000D0?l000030000003oool0oooo07T0oooo00<000000?ooo`3oool01@3oool002L0oooo0`00
002@0?ooo`030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000o`000?l0
000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo0?oo
o`1g0?ooo`<000001`3oool002L0oooo00<000000?ooo`3oool0T03oool00`000000o`000?l0000C
0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D
0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`05
0?ooo`009`3oool00`000000oooo0?ooo`2@0?ooo`030000003o0000o`0001<0o`0000<000000?l0
003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`006000001k0?oo
o`030000003oool0oooo00D0oooo000W0?ooo`030000003oool0oooo0900oooo00<000000?l0003o
00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o
0000503o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00D0oooo000W0?ooo`030000
003oool0oooo0900oooo00<000000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000
003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`2@0?ooo`030000
003oool0oooo00D0oooo000W0?ooo`030000003oool0oooo0900oooo00<000000?l0003o00004`3o
00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o
00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00D0oooo000W0?ooo`030000003oool0
oooo0900oooo00<000000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000
o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo00D0oooo000W0?ooo`<00000T03oool00`000000o`000?l0000C0?l000030000003o0000o`00
01@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo
08h0oooo0`0000070?ooo`001P3oool01P2oM000000000000000000004RL0=ooo`<0oooo00D0omnL
04P000000000001d0;ooo`040?ooo`050?oOW018000000000000M02oool02P3oool00`000000oooo
0?ooo`2@0?ooo`030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000o`00
0?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0T03oool00`000000oooo
0?ooo`050?ooo`001`3oool00`3ogi`0B00007Boo`040?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0
001d0;ooo`020?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`090?ooo`030000003oool0
oooo0900oooo00<000000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000
o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo00D0oooo00070?ooo`030?oOW0180000M;oo00@0oooo00<0_g@00018W03Oool00P3oool01`2o
M00007Bo0?ooo`3oool0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`080?ooo`030000003o
ool0oooo0900oooo00<000000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o
0000o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo00D0oooo00070?ooo`030?oOW0180000M;oo00<0oooo00<0oono07@00018W=l00`3oool0
1P3OW4P0001d0;ooo`3ookl0M00004RLg`<0oooo00<0gia80000M02oool0203oool00`000000oooo
0?ooo`2@0?ooo`030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000o`00
0?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0T03oool00`000000oooo
0?ooo`050?ooo`001`3oool00`3ogi`0B00007Boo`030?ooo`030?oOW0180000M;oo00<0oooo00H0
okmd0000B02Lgol0omnL04P0001d_ol30?ooo`030?noM00004P0W=oo00P0oooo00<000000?ooo`3o
ool0T03oool00`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o
0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo0900oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<0omnL04P0001d_ol00`3oool00`3ogi`0B00007Boo`030?ooo`060?no
M00004P0W=oo0?oOW0180000M;oo0`3oool00`3o_g@0001809cOo`080?ooo`@00000S`3oool00`00
0000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003oool0oooo08d0oooo100000070?ooo`001`3oool00`3ogi`0
B00007Boo`030?ooo`030?oOW0180000M;oo00<0oooo00H0okmd0000B02Lgol0omnL04P0001d_ol3
0?ooo`030?noM00004P0W=oo00P0oooo00<000000?ooo`3oool0T03oool00`000000o`000?l0000C
0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D
0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool01@3oool000L0oooo00<0omnL04P0
001d_ol00`3oool00`3ogi`0B00007Boo`030?ooo`060?noM00004P0W=oo0?oOW0180000M;oo0`3o
ool00`3o_g@0001809cOo`080?ooo`030000003oool0oooo0900oooo00<000000?l0003o00004`3o
00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o
00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00D0oooo00070?ooo`030?oOW0180000
M;oo00<0oooo00<0oono07@00018W=l00`3oool01P3OW4P0001d0;ooo`3ookl0M00004RLg`<0oooo
00<0gia80000M02oool0203oool00`000000oooo0?ooo`2@0?ooo`030000003o0000o`0001<0o`00
00<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`00
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`050?ooo`001`3oool00`3ogi`0B00007Bo
o`040?ooo`030=nLB000B9`0gooo0080oooo00L0_g@0001d_`3oool0oooo0=nLB000B9`0gooo0080
oooo00<0_g@0001d_`3oool0203oool00`000000oooo0?ooo`2@0?ooo`030000003o0000o`0001<0
o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0
o`0000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`050?ooo`001@3oool01@3ooml0W4P0
000000000000M;oo00@0oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00L0oono
07@0001d_ol0oooo0?noM00007@0_ooo00T0oooo00<000000?ooo`3oool0T03oool00`000000o`00
0?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`00
0?l0000D0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool01@3oool000L0oooo00<0
okmd0000001d_ol01@3oool01@3ookl0M0000000000007@0_ooo00@0oooo00D0oono07@000000000
001d0;ooo`0:0?ooo`<00000T03oool00`000000o`000?l0000C0?l000030000003o0000o`0001@0
o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo08h0
oooo0`0000070?ooo`009`3oool00`000000oooo0?ooo`2@0?ooo`030000003o0000o`0001<0o`00
00<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`00
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`050?ooo`009`3oool00`000000oooo0?oo
o`2@0?ooo`030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000o`000?l0
000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`050?ooo`009`3oool00`000000oooo0?ooo`2@0?ooo`030000003o0000o`0001<0o`0000<00000
0?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`050?ooo`009`3oool00`000000oooo0?ooo`2@0?oo
o`030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l0
00030000003o0000o`0001@0o`0000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`050?oo
o`009`3oool00`000000oooo0?ooo`2@0?ooo`030000003o0000o`0001<0o`0000<000000?l0003o
0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3o
ool0T03oool00`000000oooo0?ooo`050?ooo`009`3oool300000900oooo00<000000?l0003o0000
4`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000
503o00000`000000oooo0?ooo`2>0?ooo`<000001`3oool002L0oooo00<000000?ooo`3oool0T03o
ool00`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o
00000`000000o`000?l0000D0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool01@3o
ool002L0oooo00<000000?ooo`3oool0T03oool00`000000o`000?l0000C0?l000030000003o0000
o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003oool0
oooo0900oooo00<000000?ooo`3oool01@3oool002L0oooo00<000000?ooo`3oool0T03oool00`00
0000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool01@3oool002L0
oooo00<000000?ooo`3oool0T03oool00`000000o`000?l0000C0?l000030000003o0000o`0001@0
o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo0900
oooo00<000000?ooo`3oool01@3oool002L0oooo00<000000?ooo`3oool0T03oool00`000000o`00
0?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`00
0?l0000D0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool01@3oool002L0oooo0`00
002@0?ooo`030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000o`000?l0
000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0SP3oool3000000L0oooo000W
0?ooo`030000003oool0oooo0900oooo00<000000?l0003o00004`3o00000`000000o`000?l0000D
0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo00D0oooo000W0?ooo`030000003oool0oooo0900oooo00<000000?l0
003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0
003o0000503o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00D0oooo000W0?ooo`03
0000003oool0oooo0900oooo00<000000?l0003o00004`3o00000`000000o`000?l0000D0?l00003
0000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo00D0oooo000W0?ooo`030000003oool0oooo0900oooo00<000000?l0003o0000
4`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000
503o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00D0oooo000W0?ooo`030000003o
ool0oooo0900oooo00<000000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o
0000o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo00D0oooo000W0?ooo`<00000T03oool00`000000o`000?l0000C0?l000030000003o0000
o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003oool0
oooo08h0oooo0`0000070?ooo`001P3oool0202oM000000000000000000004RL0=ooo`3oool0_g@0
1P0000001018W=l0oooo0?oog`2LB0030000000307Boo`3oool0oooo00T0oooo00<000000?ooo`3o
ool0T03oool00`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o
0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo0900oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<0omnL04P0001d_ol0103oool00`3OW4P0000000000003000000050018
W03Oool0oooO09a8M02oool00P3oool00`2oM000M;oo0?ooo`090?ooo`030000003oool0oooo0900
oooo00<000000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0
o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00D0
oooo00070?ooo`030?oOW0180000M;oo00D0oooo00<0gia804RLg`3oool00P3oool00`3OW7@0W=oo
0?ooo`040?ooo`030?oog`2LB7@0_ooo00T0oooo00<000000?ooo`3oool0T03oool00`000000o`00
0?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`00
0?l0000D0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool01@3oool000L0oooo00<0
omnL04P0001d_ol01P3oool00`3OW4P0M;oo0?ooo`090?ooo`030;md001d_ol0oooo00P0oooo00<0
00000?ooo`3oool0T03oool00`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<0
00000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo0900oooo00<0
00000?ooo`3oool01@3oool000L0oooo00<0omnL04P0001d_ol01`3oool00`2oM4P0W=oo0?ooo`07
0?ooo`030?oog`2LB000B9cO00T0oooo00<000000?ooo`3oool0T03oool00`000000o`000?l0000C
0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D
0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool01@3oool000L0oooo00<0omnL04P0
001d_ol01`3oool00`3ooml0W4Qd0;ooo`070?ooo`030=nLB0000000M;oo00T0oooo1000002?0?oo
o`030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l0
00030000003o0000o`0001@0o`0000<000000?ooo`3oool0S@3oool4000000L0oooo00070?ooo`03
0?oOW0180000M;oo00P0oooo00<0okmd001d_`3oool00P3oool01`3Ogml0oooo0?oo_`1d00000000
0000M02oool02@3oool00`000000oooo0?ooo`2@0?ooo`030000003o0000o`0001<0o`0000<00000
0?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`050?ooo`001`3oool00`3ogi`0B00007Boo`080?oo
o`030?oo_`1d04P0W=oo0080oooo00H0gia800000000000000000000B02Lgol:0?ooo`030000003o
ool0oooo0900oooo00<000000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o
0000o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo00D0oooo00070?ooo`030?oOW0180000M;oo00P0oooo00<0oono07@00018W=l00P3oool0
103ookl0M00000000018W=l<0?ooo`030000003oool0oooo0900oooo00<000000?l0003o00004`3o
00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o
00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00D0oooo00070?ooo`030?oOW0180000
M;oo00<0oooo00<0oknL09cOo`3oool00P3oool00`3ogi`0B00004RLg`030?ooo`030;md001d_ol0
oooo00`0oooo00<000000?ooo`3oool0T03oool00`000000o`000?l0000C0?l000030000003o0000
o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003oool0
oooo0900oooo00<000000?ooo`3oool01@3oool000D0oooo00D0oooO09a800000000000007Boo`03
0?ooo`080?oog`2LB4P0W=oo0?ooo`3ookl0M0000000M02oool30?ooo`060?oOW018000000000000
000004P0W=oo2@3oool00`000000oooo0?ooo`2@0?ooo`030000003o0000o`0001<0o`0000<00000
0?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`050?ooo`001`3oool00`3o_g@0000007Boo`040?oo
o`060?oog`2LB00000000000000007@0_ooo1@3oool01@2oM0000000000000000000B9cO00T0oooo
0`00002@0?ooo`030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000o`00
0?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0SP3oool3000000L0oooo
000W0?ooo`030000003oool0oooo0900oooo00<000000?l0003o00004`3o00000`000000o`000?l0
000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo0?oo
o`2@0?ooo`030000003oool0oooo00D0oooo000W0?ooo`030000003oool0oooo0900oooo00<00000
0?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<00000
0?l0003o0000503o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00D0oooo000W0?oo
o`030000003oool0oooo0900oooo00<000000?l0003o00004`3o00000`000000o`000?l0000D0?l0
00030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00D0oooo000W0?ooo`030000003oool0oooo0900oooo00<000000?l0003o
00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?l0003o
0000503o00000`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00D0oooo000W0?ooo`030000
003oool0oooo0900oooo00<000000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000
003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`2@0?ooo`030000
003oool0oooo00D0oooo000W0?ooo`<00000T03oool00`000000o`000?l0000C0?l000030000003o
0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o
ool0oooo08h0oooo0`0000070?ooo`009`3oool00`000000oooo0?ooo`2@0?ooo`030000003o0000
o`0001<0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000
o`0001@0o`0000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`050?ooo`009`3oool00`00
0000oooo0?ooo`2@0?ooo`030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0T03oool00`00
0000oooo0?ooo`050?ooo`009`3oool00`000000oooo0?ooo`2@0?ooo`030000003o0000o`0001<0
o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0
o`0000<000000?ooo`3oool0T03oool00`000000oooo0?ooo`050?ooo`009`3oool00`000000oooo
0?ooo`2@0?ooo`030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000o`00
0?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0T03oool00`000000oooo
0?ooo`050?ooo`009`3oool00`000000oooo0?ooo`2@0?ooo`030000003o0000o`0001<0o`0000<0
00000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<0
00000?ooo`3oool0T03oool00`000000oooo0?ooo`050?ooo`009`3oool300000900oooo00<00000
0?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<00000
0?l0003o0000503o00000`000000oooo0?ooo`2>0?ooo`<000001`3oool002L0oooo00<000000?oo
o`3oool0T03oool00`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0
003o0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo0900oooo00<000000?oo
o`3oool01@3oool002L0oooo00<000000?ooo`3oool0T03oool00`000000o`000?l0000C0?l00003
0000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l00003
0000003oool0oooo0900oooo00<000000?ooo`3oool01@3oool002L0oooo00<000000?ooo`3oool0
T03oool00`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000
503o00000`000000o`000?l0000D0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool0
1@3oool002L0oooo00<000000?ooo`3oool0T03oool00`000000o`000?l0000C0?l000030000003o
0000o`0001@0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003o
ool0oooo0900oooo00<000000?ooo`3oool01@3oool002L0oooo00<000000?ooo`3oool0T03oool0
0`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o0000
0`000000o`000?l0000D0?l000030000003oool0oooo0900oooo00<000000?ooo`3oool01@3oool0
02L0oooo0`00002@0?ooo`030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0SP3oool30000
00L0oooo00060?ooo`090;md00000000000000000000B9`0gooo0?ooo`3ooml0W4P000<0000000<0
M;oo0?ooo`3oool00`3oool01@3ogi`0B0000000000007@0_ooo00X0oooo00<000000?ooo`3oool0
T03oool00`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000
503o000H00000980oooo00<000000?ooo`3oool01@3oool000L0oooo00<0omnL04P0001d_ol00`3o
ool00`3ooml0W4Qd0;ooo`020?ooo`030;md001d_ol0oooo0080oooo00L0oono07@0001d_ol0oooo
0?noM00007@0_ooo00T0oooo00<000000?ooo`3oool0T03oool00`000000o`000?l0000C0?l00003
0000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`2W0?ooo`03
0000003oool0oooo00D0oooo00070?ooo`030?oOW0180000M;oo00P0oooo00<0oooO09a8M02oool0
0P3oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo00P0oooo00<000000?ooo`3oool0
T03oool00`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000
503o00000`000000oooo0?ooo`2W0?ooo`030000003oool0oooo00D0oooo00070?ooo`030?oOW018
0000M;oo00T0oooo00H0_g@007Boo`3oool0oono07@00018W=l30?ooo`030=nLB00007@0_ooo00P0
oooo00<000000?ooo`3oool0T03oool00`000000o`000?l0000C0?l000030000003o0000o`0001@0
o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`2W0?ooo`030000003oool0oooo00D0
oooo00070?ooo`030?oOW0180000M;oo00P0oooo00L0oooO09a80018W=l0oooo0?oOW0180000M;oo
00<0oooo00<0okmd0000B02Lgol0203oool00`000000oooo0?ooo`2@0?ooo`030000003o0000o`00
01<0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo
0:L0oooo00<000000?ooo`3oool01@3oool000L0oooo00<0omnL04P0001d_ol0203oool01`3OW4P0
000007Boo`3oool0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`080?ooo`@00000S`3oool0
0`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o0000
0`000000oooo0?ooo`2T0?ooo`@000001`3oool000L0oooo00<0omnL04P0001d_ol0103oool02`3O
gml0oooo0?oo_`1d000000000000M02oool0oooo0?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol0203oool00`000000oooo0?ooo`2@0?ooo`030000003o0000o`0001<0o`0000<000000?l0003o
0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<0omnL04P0001d_ol0103oool01P3OW4P00000000000000000001809cO
o`80oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`080?ooo`030000003oool0oooo
0900oooo00<000000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`00
01@0o`0000<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`3ogi`0
B00007Boo`040?ooo`040?oo_`1d0000000004RLg`@0oooo00<0oono07@00018W=l00`3oool00`3O
W4P0001d0;ooo`080?ooo`030000003oool0oooo0900oooo00<000000?l0003o00004`3o00000`00
0000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0Y`3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`3ogi`0B00007Boo`050?ooo`030;md001d_ol0oooo00D0
oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`080?ooo`030000003oool0oooo0900
oooo00<000000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0
o`0000<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`050?ooo`001@3oool01@3ooml0W4P0
000000000000M;oo00D0oooo00H0omnL04P00000000000000000B02Lgol20?ooo`070?oo_`1d0000
M;oo0?ooo`3o_g@0001d0;ooo`090?ooo`030000003oool0oooo0900oooo00<000000?l0003o0000
4`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0
Y`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`3o_g@0000007Boo`060?ooo`050;md0000
0000000000000018W=l00`3oool01@3ookl0M0000000000007@0_ooo00X0oooo0`00002@0?ooo`03
0000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l00003
0000003oool0oooo0:D0oooo0`0000070?ooo`009`3oool00`000000oooo0?ooo`2@0?ooo`030000
003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000
003oool0oooo0:L0oooo00<000000?ooo`3oool01@3oool002L0oooo00<000000?ooo`3oool0T03o
ool00`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o
00000`000000oooo0?ooo`2W0?ooo`030000003oool0oooo00D0oooo000W0?ooo`030000003oool0
oooo0900oooo00<000000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000
o`0001@0o`0000<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`050?ooo`009`3oool00`00
0000oooo0?ooo`2@0?ooo`030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`00
0000o`000?l0000D0?l000030000003oool0oooo0:L0oooo00<000000?ooo`3oool01@3oool002L0
oooo00<000000?ooo`3oool0T03oool00`000000o`000?l0000C0?l000030000003o0000o`0001@0
o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`2W0?ooo`030000003oool0oooo00D0
oooo000W0?ooo`<00000T03oool00`000000o`000?l0000C0?l000030000003o0000o`0001@0o`00
00<000000?l0003o0000503o00000`000000oooo0?ooo`2U0?ooo`<000001`3oool002L0oooo00<0
00000?ooo`3oool0T03oool00`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<0
00000?l0003o0000503o00000`000000oooo0?ooo`2W0?ooo`030000003oool0oooo00D0oooo000W
0?ooo`030000003oool0oooo0900oooo00<000000?l0003o00004`3o00000`000000o`000?l0000D
0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`05
0?ooo`009`3oool00`000000oooo0?ooo`2@0?ooo`030000003o0000o`0001<0o`0000<000000?l0
003o0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo0:L0oooo00<000000?oo
o`3oool01@3oool002L0oooo00<000000?ooo`3oool0T03oool00`000000o`000?l0000C0?l00003
0000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`2W0?ooo`03
0000003oool0oooo00D0oooo000W0?ooo`030000003oool0oooo0900oooo00<000000?l0003o0000
4`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0
Y`3oool00`000000oooo0?ooo`050?ooo`009`3oool300000900oooo00<000000?l0003o00004`3o
00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0Y@3o
ool3000000L0oooo000W0?ooo`030000003oool0oooo0900oooo00<000000?l0003o00004`3o0000
0`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0Y`3oool0
0`000000oooo0?ooo`050?ooo`009`3oool00`000000oooo0?ooo`2@0?ooo`030000003o0000o`00
01<0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo
0:L0oooo00<000000?ooo`3oool01@3oool002L0oooo00<000000?ooo`3oool0T03oool00`000000
o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o00000`000000
oooo0?ooo`2W0?ooo`030000003oool0oooo00D0oooo000W0?ooo`030000003oool0oooo0900oooo
00<000000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`0001@0o`00
00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`050?ooo`009`3oool00`000000oooo0?oo
o`2@0?ooo`030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000o`000?l0
000D0?l000030000003oool0oooo0:L0oooo00<000000?ooo`3oool01@3oool002L0oooo0`00002@
0?ooo`030000003o0000o`0001<0o`0000<000000?l0003o0000503o00000`000000o`000?l0000D
0?l000030000003oool0oooo0:D0oooo0`0000070?ooo`001P3oool01P2oM0000000000000000000
04RL0=ooo`@0oooo00<0gia804RLg`3oool00`3oool00`3ooml0W4P0000000020000000307Boo`3o
ool0oooo00T0oooo00<000000?ooo`3oool0T03oool00`000000o`000?l0000C0?l000030000003o
0000o`0001@0o`0000<000000?l0003o0000503o00000`000000oooo0?ooo`2W0?ooo`030000003o
ool0oooo00D0oooo00070?ooo`030?oOW0180000M;oo00H0oooo00<0omnL04Q8W03Oool00`3oool0
0`3ooml0W4Qd0;ooo`020?ooo`030;md001d_ol0oooo00T0oooo00<000000?ooo`3oool0T03oool0
0`000000o`000?l0000C0?l000030000003o0000o`0001@0o`0000<000000?l0003o0000503o0000
0`000000oooo0?ooo`2W0?ooo`030000003oool0oooo00D0oooo00070?ooo`030?oOW0180000M;oo
00H0oooo00<0oooO09a8B02Lgol0203oool00`3ooml0W4Qd0;ooo`090?ooo`030000003oool0oooo
0900oooo00<000000?l0003o00004`3o00000`000000o`000?l0000D0?l000030000003o0000o`00
01@0o`0000<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`3ogi`0
B00007Boo`070?ooo`030=nLB018W=l0oooo00P0oooo00<0_g@007Boo`3oool0203oool00`000000
oooo0?ooo`2@0?oooaL000005P3o00000`000000o`000?l0000D0?l000030000003oool0oooo0:L0
oooo00<000000?ooo`3oool01@3oool000L0oooo00<0omnL04P0001d_ol01`3oool00`3ogi`0B4RL
0=ooo`070?ooo`030?oog`2LB000B9cO00T0oooo00<000000?ooo`3oool0YP3oool00`000000o`00
0?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0Y`3oool00`000000oooo
0?ooo`050?ooo`001`3oool00`3ogi`0B00007Boo`070?ooo`030?oog`2LB4P0W=oo00L0oooo00<0
gia80000001d_ol02@3oool400000:D0oooo00<000000?l0003o0000503o00000`000000o`000?l0
000D0?l000030000003oool0oooo0:@0oooo100000070?ooo`001`3oool00`3ogi`0B00007Boo`08
0?ooo`030=nLB000M;l0oooo0080oooo00L0gmoO0?ooo`3ookl0M0000000000007@0_ooo00T0oooo
00<000000?ooo`3oool0YP3oool00`000000o`000?l0000D0?l000030000003o0000o`0001@0o`00
00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`3ogi`0B00007Bo
o`080?ooo`030?oo_`1d07@0_ooo0080oooo00H0gia800000000000000000000B02Lgol:0?ooo`03
0000003oool0oooo0:H0oooo00<000000?l0003o0000503o00000`000000o`000?l0000D0?l00003
0000003oool0oooo0:L0oooo00<000000?ooo`3oool01@3oool000L0oooo00<0omnL04P0001d_ol0
0`3oool00`3ogml0gooo0?ooo`030?ooo`080;md001d_ol0oooo0?ooo`3ookl0M00000000018W=l<
0?ooo`030000003oool0oooo0:H0oooo00<000000?l0003o0000503o00000`000000o`000?l0000D
0?l000030000003oool0oooo0:L0oooo00<000000?ooo`3oool01@3oool000L0oooo00<0omnL04P0
001d_ol00`3oool00`3ookl0M4RL0=ooo`030?ooo`030?noM000M;l0oooo0080oooo00<0_g@007Bo
o`3oool0303oool00`000000oooo0?ooo`2V0?ooo`030000003o0000o`0001@0o`0000<000000?l0
003o0000503o00000`000000oooo0?ooo`2W0?ooo`030000003oool0oooo00D0oooo00050?ooo`05
0?oog`2LB00000000000001d_ol0103oool00`2oM000000000000003000000060000M02oool0oooo
0?ooo`3ogi`0B0000P0000000`0004P0W=oo0?ooo`080?ooo`030000003oool0oooo0:H0oooo00<0
00000?l0003o0000503o00000`000000o`000?l0000D0?l000030000003oool0oooo0:L0oooo00<0
00000?ooo`3oool01@3oool000L0oooo00<0okmd0000001d_ol0103oool00`3o_g@0000000000004
0000000507Boo`3oool0oooo0?ooo`2oM0000`0000000`18W=l0oooo0?ooo`070?ooo`<00000YP3o
ool00`000000o`000?l0000D0?l000030000003o0000o`0001@0o`0000<000000?ooo`3oool0Y@3o
ool3000000L0oooo000W0?ooo`030000003oool0oooo0:H0oooo00<000000?l0003o0000503o0000
0`000000o`000?l0000D0?l000030000003oool0oooo0:L0oooo00<000000?ooo`3oool01@3oool0
02L0oooo00<000000?ooo`3oool0YP3oool00`000000o`000?l0000D0?l000030000003o0000o`00
01@0o`0000<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`050?ooo`009`3oool00`000000
oooo0?ooo`2V0?ooo`030000003o0000o`0001@0o`006000002Y0?ooo`030000003oool0oooo00D0
oooo000W0?ooo`030000003oool0oooo0:H0oooo00<000000?l0003o0000503o00000`000000oooo
0?ooo`2n0?ooo`030000003oool0oooo00D0oooo000W0?ooo`030000003oool0oooo0:H0oooo00<0
00000?l0003o0000503o00000`000000oooo0?ooo`2n0?ooo`030000003oool0oooo00D0oooo000W
0?ooo`<00000YP3oool00`000000o`000?l0000D0?l000030000003oool0oooo0;`0oooo0`000007
0?ooo`009`3oool00`000000oooo0?ooo`2V0?ooo`030000003o0000o`0001@0o`0000<000000?oo
o`3oool0_P3oool00`000000oooo0?ooo`050?ooo`009`3oool00`000000oooo0?ooo`2V0?ooo`03
0000003o0000o`0001@0o`0000<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`050?ooo`00
9`3oool00`000000oooo0?ooo`2V0?oooaP00000`03oool00`000000oooo0?ooo`050?ooo`009`3o
ool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool01@3o
ool002L0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0
oooo00D0oooo000W0?ooo`<000001P3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
00D0oooo0`0000070?ooo`009`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`009`3ooooo000008<00000
1`3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.506721, -28.0983, \
0.00327829, 1.23991}}]
}, Closed]],

Cell["\<\
Plot the power spectrum for the noise signal alone.  How does the amplitude \
depend upon the number of samples?\
\>", "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Now suppose that the noise signal is added to a sinusoidal input signal.  \
What is the effect upon the power spectrum?  Why do long observation periods \
clean up the spectrum?\
\>", "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Sampling errors", "Subsection"],

Cell["\<\
Even if noise is suppressed, experimental observations are still subject to \
random errors.  Suppose that the random error is proportional to the size of \
the signal itself.  \
\>", "Text"],

Cell["\<\
Construct 1000 perfect data for a wave packet using {\[Lambda]\[Rule]100, \
\[Tau]\[Rule]500, \[Sigma]\[Rule]100}.\
\>", "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Apply random \[PlusMinus]10% errors using the normal distribution.  Compare \
the imprecise data with the perfect data.\
\>", "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Plot the interesting range of the power spectrum and interpret the result.\
\>", "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Repeat previous two steps several times and comment.  How would averaging \
several measurements help?\
\>", "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Spectral analysis of van der Pol oscillator", "Section"],

Cell[TextData[{
  "As an example of an anharmonic periodic signal, consider the ",
  ButtonBox["van der Pol",
    ButtonData:>{"Applications/van der Pol.nb", None},
    ButtonStyle->"Hyperlink"],
  " oscillator whose phase-space trajectory is given by the following \
function:"
}], "Text"],

Cell[BoxData[
    RowBox[{\(trajectory[\[Tau]_, \[CurlyEpsilon]_, x0_, y0_, tmax_]\), ":=", 
      
      RowBox[{\({x[\[Tau]], y[\[Tau]]}\), "/.", 
        RowBox[{
          RowBox[{"NDSolve", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      SuperscriptBox["x", "\[Prime]",
                        MultilineFunction->None], "[", "t", "]"}], 
                    "\[Equal]", \(y[t]\)}], ",", 
                  RowBox[{
                    RowBox[{
                      SuperscriptBox["y", "\[Prime]",
                        MultilineFunction->None], "[", "t", "]"}], 
                    "\[Equal]", \(\(-x[
                          t]\) + \[CurlyEpsilon]\ \((1 - x[t]\^2)\)\ y[t]\)}],
                   ",", \(x[0] \[Equal] x0\), ",", \(y[0] \[Equal] y0\)}], 
                "}"}], ",", \({x, y}\), ",", \({t, 0, tmax}\), 
              ",", \(MaxSteps \[Rule] 10\^5\)}], "]"}], 
          "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}]], "Input"],

Cell[TextData[{
  "It is useful to perform a Fourier analysis of the motion on the limit \
cycle.  Because we have already determined that for a given ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyEpsilon]\)]],
  " the system will reach the same limit cycle for any initial conditions, we \
choose fixed initial conditions.  The time interval ",
  StyleBox["{tmin,tmax,tstep}", "InlineInput",
    FontWeight->"Bold"],
  " should be chosen to begin after the limit cycle has been reached and to \
include a large enough number of cycles with enough points per cycle to \
produce a stable power spectrum."
}], "Text"],

Cell[BoxData[
    \(vdPolPower[\[CurlyEpsilon]_, tmin_, tmax_, tstep_, opts___Rule] := 
      Module[{sample, spectrum, optPowerSpectrum}, 
        optPowerSpectrum = FilterOptions[PowerSpectrum, opts]; 
        sample = 
          Table[Evaluate[\(trajectory[t, \[CurlyEpsilon], 1. , 0. , 
                  tmax]\)\[LeftDoubleBracket]1\[RightDoubleBracket]], {t, 
              tmin, tmax, tstep}]; 
        spectrum = PowerSpectrum[sample, optPowerSpectrum]; 
        PlotPowerSpectrum[spectrum, opts, Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<frequency\>", "\<power\>"}, 
          PlotLabel \[Rule] "\<van der Pol oscillator, \[CurlyEpsilon]=\>" <> 
              ToString[\[CurlyEpsilon]]]]\)], "Input"],

Cell["\<\
The figure below shows the spectrum for a large damping parameter.  We have \
used a large integration range and offset to ensure that the periodicity \
emerges clearly.  \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(vdPolPower[10. , 100, 500, 0.1, 
        PlotRange \[Rule] {{1, 300}, {10\^\(-6\), 10}}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00334448 0.00334448 0.529743 0.0882906 [
[.16388 -0.0125 -8 -15.6875 ]
[.16388 -0.0125 8 0 ]
[.3311 -0.0125 -11 -15.6875 ]
[.3311 -0.0125 11 0 ]
[.49833 -0.0125 -11 -15.6875 ]
[.49833 -0.0125 11 0 ]
[.66555 -0.0125 -11 -15.6875 ]
[.66555 -0.0125 11 0 ]
[.83278 -0.0125 -11 -15.6875 ]
[.83278 -0.0125 11 0 ]
[1 -0.0125 -11 -15.6875 ]
[1 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -25.625 -31.375 ]
[.5 -0.0125 25.625 -15.6875 ]
[-0.0125 0 -46.625 -7.84375 ]
[-0.0125 0 0 7.84375 ]
[-0.0125 .17658 -37 -7.84375 ]
[-0.0125 .17658 0 7.84375 ]
[-0.0125 .35316 -25 -7.84375 ]
[-0.0125 .35316 0 7.84375 ]
[-0.0125 .52974 -10 -7.84375 ]
[-0.0125 .52974 0 7.84375 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -62.3125 -16.9063 ]
[-0.01875 .30902 -46.625 16.9063 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -70.1875 0 ]
[.5 .63053 70.1875 15.6875 ]
[ -0.0005 0 0 0 ]
[ 1.0005 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16388 0 m
.16388 .00625 L
s
gsave
.16388 -0.0125 -69 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.3311 0 m
.3311 .00625 L
s
gsave
.3311 -0.0125 -72 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.49833 0 m
.49833 .00625 L
s
gsave
.49833 -0.0125 -72 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.66555 0 m
.66555 .00625 L
s
gsave
.66555 -0.0125 -72 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.83278 0 m
.83278 .00625 L
s
gsave
.83278 -0.0125 -72 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(250) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -72 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
1.000 setlinewidth
grestore
.125 Mabswid
.0301 0 m
.0301 .00375 L
s
.06355 0 m
.06355 .00375 L
s
.09699 0 m
.09699 .00375 L
s
.13043 0 m
.13043 .00375 L
s
.19732 0 m
.19732 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26421 0 m
.26421 .00375 L
s
.29766 0 m
.29766 .00375 L
s
.36455 0 m
.36455 .00375 L
s
.39799 0 m
.39799 .00375 L
s
.43144 0 m
.43144 .00375 L
s
.46488 0 m
.46488 .00375 L
s
.53177 0 m
.53177 .00375 L
s
.56522 0 m
.56522 .00375 L
s
.59866 0 m
.59866 .00375 L
s
.63211 0 m
.63211 .00375 L
s
.699 0 m
.699 .00375 L
s
.73244 0 m
.73244 .00375 L
s
.76589 0 m
.76589 .00375 L
s
.79933 0 m
.79933 .00375 L
s
.86622 0 m
.86622 .00375 L
s
.89967 0 m
.89967 .00375 L
s
.93311 0 m
.93311 .00375 L
s
.96656 0 m
.96656 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -86.625 -35.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(frequency) show
110.250 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
gsave
-0.0125 0 -107.625 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
72.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
73.813 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
83.313 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
95.313 10.938 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
95.313 10.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 10.938 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
105.125 10.938 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .17658 m
.00625 .17658 L
s
gsave
-0.0125 .17658 -98 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
96.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .35316 m
.00625 .35316 L
s
gsave
-0.0125 .35316 -86 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
84.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .52974 m
.00625 .52974 L
s
gsave
-0.0125 .52974 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .09528 m
.00375 .09528 L
s
0 .12023 m
.00375 .12023 L
s
0 .13522 m
.00375 .13522 L
s
0 .14596 m
.00375 .14596 L
s
0 .15435 m
.00375 .15435 L
s
0 .16123 m
.00375 .16123 L
s
0 .16705 m
.00375 .16705 L
s
0 .17211 m
.00375 .17211 L
s
0 .27186 m
.00375 .27186 L
s
0 .29681 m
.00375 .29681 L
s
0 .3118 m
.00375 .3118 L
s
0 .32254 m
.00375 .32254 L
s
0 .33093 m
.00375 .33093 L
s
0 .33781 m
.00375 .33781 L
s
0 .34364 m
.00375 .34364 L
s
0 .34869 m
.00375 .34869 L
s
0 .44844 m
.00375 .44844 L
s
0 .47339 m
.00375 .47339 L
s
0 .48838 m
.00375 .48838 L
s
0 .49913 m
.00375 .49913 L
s
0 .50751 m
.00375 .50751 L
s
0 .51439 m
.00375 .51439 L
s
0 .52022 m
.00375 .52022 L
s
0 .52528 m
.00375 .52528 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -132.375 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
77.9063 11.8438 translate
90 rotate
-77.9063 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(power) show
92.813 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.16388 .61178 m
.16388 .61803 L
s
.3311 .61178 m
.3311 .61803 L
s
.49833 .61178 m
.49833 .61803 L
s
.66555 .61178 m
.66555 .61803 L
s
.83278 .61178 m
.83278 .61803 L
s
.125 Mabswid
.0301 .61428 m
.0301 .61803 L
s
.06355 .61428 m
.06355 .61803 L
s
.09699 .61428 m
.09699 .61803 L
s
.13043 .61428 m
.13043 .61803 L
s
.19732 .61428 m
.19732 .61803 L
s
.23077 .61428 m
.23077 .61803 L
s
.26421 .61428 m
.26421 .61803 L
s
.29766 .61428 m
.29766 .61803 L
s
.36455 .61428 m
.36455 .61803 L
s
.39799 .61428 m
.39799 .61803 L
s
.43144 .61428 m
.43144 .61803 L
s
.46488 .61428 m
.46488 .61803 L
s
.53177 .61428 m
.53177 .61803 L
s
.56522 .61428 m
.56522 .61803 L
s
.59866 .61428 m
.59866 .61803 L
s
.63211 .61428 m
.63211 .61803 L
s
.699 .61428 m
.699 .61803 L
s
.73244 .61428 m
.73244 .61803 L
s
.76589 .61428 m
.76589 .61803 L
s
.79933 .61428 m
.79933 .61803 L
s
.86622 .61428 m
.86622 .61803 L
s
.89967 .61428 m
.89967 .61803 L
s
.93311 .61428 m
.93311 .61803 L
s
.96656 .61428 m
.96656 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .17658 m
1 .17658 L
s
.99375 .35316 m
1 .35316 L
s
.99375 .52974 m
1 .52974 L
s
.001 w
.99625 .09528 m
1 .09528 L
s
.99625 .12023 m
1 .12023 L
s
.99625 .13522 m
1 .13522 L
s
.99625 .14596 m
1 .14596 L
s
.99625 .15435 m
1 .15435 L
s
.99625 .16123 m
1 .16123 L
s
.99625 .16705 m
1 .16705 L
s
.99625 .17211 m
1 .17211 L
s
.99625 .27186 m
1 .27186 L
s
.99625 .29681 m
1 .29681 L
s
.99625 .3118 m
1 .3118 L
s
.99625 .32254 m
1 .32254 L
s
.99625 .33093 m
1 .33093 L
s
.99625 .33781 m
1 .33781 L
s
.99625 .34364 m
1 .34364 L
s
.99625 .34869 m
1 .34869 L
s
.99625 .44844 m
1 .44844 L
s
.99625 .47339 m
1 .47339 L
s
.99625 .48838 m
1 .48838 L
s
.99625 .49913 m
1 .49913 L
s
.99625 .50751 m
1 .50751 L
s
.99625 .51439 m
1 .51439 L
s
.99625 .52022 m
1 .52022 L
s
.99625 .52528 m
1 .52528 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -131.188 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(van) show
83.250 15.813 moveto
(der) show
101.438 15.813 moveto
(Pol) show
120.438 15.813 moveto
(oscillator) show
164.813 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
170.813 15.813 moveto
%%IncludeResource: font Mathematica3
%%IncludeFont: Mathematica3
/Mathematica3 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\266) show
176.563 15.813 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
184.375 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10.) show
199.375 15.813 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
0 .0948 Mdot
.00334 .095 Mdot
.00669 .09562 Mdot
.01003 .09665 Mdot
.01338 .09814 Mdot
.01672 .09993 Mdot
.02007 .10234 Mdot
.02341 .10524 Mdot
.02676 .10867 Mdot
.0301 .11272 Mdot
.03344 .11745 Mdot
.03679 .12296 Mdot
.04013 .12938 Mdot
.04348 .1369 Mdot
.04682 .14578 Mdot
.05017 .15637 Mdot
.05351 .16928 Mdot
.05686 .18549 Mdot
.0602 .20686 Mdot
.06355 .23757 Mdot
.06689 .29122 Mdot
.07023 .56112 Mdot
.07358 .28598 Mdot
.07692 .23367 Mdot
.08027 .20285 Mdot
.08361 .18102 Mdot
.08696 .16421 Mdot
.0903 .15064 Mdot
.09365 .13935 Mdot
.09699 .12979 Mdot
.10033 .12159 Mdot
.10368 .1145 Mdot
.10702 .10834 Mdot
.11037 .10298 Mdot
.11371 .09834 Mdot
.11706 .09434 Mdot
.1204 .09089 Mdot
.12375 .08777 Mdot
.12709 .08606 Mdot
.13043 .08406 Mdot
.13378 .08265 Mdot
.13712 .08173 Mdot
.14047 .08127 Mdot
.14381 .08127 Mdot
.14716 .08173 Mdot
.1505 .08266 Mdot
.15385 .08403 Mdot
.15719 .08609 Mdot
.16054 .08848 Mdot
.16388 .09148 Mdot
.16722 .09508 Mdot
.17057 .09935 Mdot
.17391 .10435 Mdot
.17726 .11019 Mdot
.1806 .11698 Mdot
.18395 .12493 Mdot
.18729 .13428 Mdot
.19064 .14542 Mdot
.19398 .15894 Mdot
.19732 .17587 Mdot
.20067 .19812 Mdot
.20401 .23013 Mdot
.20736 .28673 Mdot
.2107 .4683 Mdot
.21405 .27384 Mdot
.21739 .22412 Mdot
.22074 .19458 Mdot
.22408 .17369 Mdot
.22742 .15767 Mdot
.23077 .14481 Mdot
.23411 .13419 Mdot
.23746 .12525 Mdot
.2408 .11764 Mdot
.24415 .1111 Mdot
.24749 .10546 Mdot
.25084 .1006 Mdot
.25418 .09641 Mdot
.25753 .09282 Mdot
.26087 .08976 Mdot
.26421 .08697 Mdot
.26756 .0855 Mdot
.2709 .08379 Mdot
.27425 .08261 Mdot
.27759 .08186 Mdot
.28094 .08153 Mdot
.28428 .08162 Mdot
.28763 .08212 Mdot
.29097 .08304 Mdot
.29431 .08438 Mdot
.29766 .0863 Mdot
.301 .08859 Mdot
.30435 .09142 Mdot
.30769 .09483 Mdot
.31104 .09886 Mdot
.31438 .1036 Mdot
.31773 .10915 Mdot
.32107 .11565 Mdot
.32441 .12329 Mdot
.32776 .13232 Mdot
.3311 .14315 Mdot
.33445 .1564 Mdot
.33779 .17312 Mdot
.34114 .19532 Mdot
.34448 .22768 Mdot
.34783 .28646 Mdot
.35117 .42346 Mdot
.35452 .26379 Mdot
.35786 .21551 Mdot
.3612 .18622 Mdot
.36455 .16527 Mdot
.36789 .14908 Mdot
.37124 .136 Mdot
.37458 .12515 Mdot
.37793 .11597 Mdot
.38127 .10813 Mdot
.38462 .10138 Mdot
.38796 .09555 Mdot
.3913 .09052 Mdot
.39465 .08619 Mdot
.39799 .08249 Mdot
.40134 .07933 Mdot
.40468 .07637 Mdot
.40803 .07502 Mdot
.41137 .07331 Mdot
.41472 .07216 Mdot
.41806 .07147 Mdot
.4214 .07122 Mdot
.42475 .07142 Mdot
.42809 .07206 Mdot
.43144 .07314 Mdot
.43478 .07465 Mdot
.43813 .07678 Mdot
.44147 .0793 Mdot
.44482 .08238 Mdot
.44816 .08604 Mdot
.45151 .09035 Mdot
.45485 .09538 Mdot
.45819 .10123 Mdot
.46154 .10805 Mdot
.46488 .11601 Mdot
.46823 .1254 Mdot
.47157 .13661 Mdot
.47492 .15028 Mdot
.47826 .1675 Mdot
.48161 .19036 Mdot
.48495 .22382 Mdot
.48829 .28573 Mdot
.49164 .39185 Mdot
.49498 .25446 Mdot
.49833 .2081 Mdot
.50167 .17963 Mdot
.50502 .15918 Mdot
.50836 .14334 Mdot
.51171 .13053 Mdot
.51505 .11988 Mdot
.51839 .11088 Mdot
.52174 .10317 Mdot
.52508 .09652 Mdot
.52843 .09077 Mdot
.53177 .0858 Mdot
.53512 .0815 Mdot
.53846 .07781 Mdot
.54181 .07463 Mdot
.54515 .07146 Mdot
.54849 .0703 Mdot
.55184 .06854 Mdot
.55518 .06732 Mdot
.55853 .06656 Mdot
.56187 .06624 Mdot
.56522 .06635 Mdot
.56856 .0669 Mdot
.57191 .06788 Mdot
.57525 .06924 Mdot
.5786 .07138 Mdot
.58194 .0738 Mdot
.58528 .07679 Mdot
.58863 .08038 Mdot
.59197 .08462 Mdot
.59532 .0896 Mdot
.59866 .09541 Mdot
.60201 .1022 Mdot
.60535 .11017 Mdot
.6087 .11959 Mdot
.61204 .13087 Mdot
.61538 .14467 Mdot
.61873 .16211 Mdot
.62207 .18538 Mdot
.62542 .21974 Mdot
.62876 .28487 Mdot
.63211 .36606 Mdot
.63545 .24441 Mdot
.6388 .1997 Mdot
.64214 .17189 Mdot
.64548 .15182 Mdot
.64883 .13625 Mdot
.65217 .12365 Mdot
.65552 .11319 Mdot
.65886 .10434 Mdot
.66221 .09678 Mdot
.66555 .09028 Mdot
.6689 .08467 Mdot
.67224 .07982 Mdot
.67559 .07564 Mdot
.67893 .07207 Mdot
.68227 .06901 Mdot
.68562 .0658 Mdot
.68896 .06483 Mdot
.69231 .06319 Mdot
.69565 .06205 Mdot
.699 .06136 Mdot
.70234 .06109 Mdot
.70569 .06125 Mdot
.70903 .06184 Mdot
.71237 .06285 Mdot
.71572 .06421 Mdot
.71906 .06634 Mdot
.72241 .06875 Mdot
.72575 .07172 Mdot
.7291 .07527 Mdot
.73244 .07946 Mdot
.73579 .08438 Mdot
.73913 .09013 Mdot
.74247 .09685 Mdot
.74582 .10475 Mdot
.74916 .1141 Mdot
.75251 .12534 Mdot
.75585 .13912 Mdot
.7592 .15663 Mdot
.76254 .18014 Mdot
.76589 .21524 Mdot
.76923 .28375 Mdot
.77258 .3432 Mdot
.77592 .23331 Mdot
.77926 .18987 Mdot
.78261 .16243 Mdot
.78595 .14245 Mdot
.7893 .12686 Mdot
.79264 .11418 Mdot
.79599 .10361 Mdot
.79933 .09464 Mdot
.80268 .08694 Mdot
.80602 .0803 Mdot
.80936 .07456 Mdot
.81271 .06958 Mdot
.81605 .06529 Mdot
.8194 .06161 Mdot
.82274 .05846 Mdot
.82609 .05486 Mdot
.82943 .0541 Mdot
.83278 .05241 Mdot
.83612 .05125 Mdot
.83946 .05054 Mdot
.84281 .05028 Mdot
.84615 .05045 Mdot
.8495 .05107 Mdot
.85284 .05213 Mdot
.85619 .05353 Mdot
.85953 .05578 Mdot
.86288 .0583 Mdot
.86622 .06139 Mdot
.86957 .06508 Mdot
.87291 .06943 Mdot
.87625 .07452 Mdot
.8796 .08046 Mdot
.88294 .08739 Mdot
.88629 .09552 Mdot
.88963 .10513 Mdot
.89298 .11666 Mdot
.89632 .13079 Mdot
.89967 .14874 Mdot
.90301 .17289 Mdot
.90635 .20917 Mdot
.9097 .2819 Mdot
.91304 .32203 Mdot
.91639 .22186 Mdot
.91973 .17999 Mdot
.92308 .15327 Mdot
.92642 .13376 Mdot
.92977 .1185 Mdot
.93311 .10609 Mdot
.93645 .09574 Mdot
.9398 .08695 Mdot
.94314 .07942 Mdot
.94649 .07292 Mdot
.94983 .06728 Mdot
.95318 .06241 Mdot
.95652 .05819 Mdot
.95987 .05458 Mdot
.96321 .05148 Mdot
.96656 .04751 Mdot
.9699 .04706 Mdot
.97324 .0454 Mdot
.97659 .04422 Mdot
.97993 .04349 Mdot
.98328 .04318 Mdot
.98662 .0433 Mdot
.98997 .04385 Mdot
.99331 .04484 Mdot
.99666 .04608 Mdot
1 .04831 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{332.25, 205.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007b0001=2000`400?l00000o`00003oo`3ooooc
0?ooo`00o`3ooooc0?ooo`00o`3ooooc0?ooo`00o`3ooolH0?ooo`060?oo_`1d0000000000000000
B9`0gooo8@3oool0103OW4P000000000001d_on`0?ooo`00o`3ooolI0?ooo`030?oog`2LB00007Bo
02H0oooo00<0_gAd0;ooo`3oool0[P3oool00?l0oooo6@3oool00`3ooml0W4P0001d_`0V0?ooo`03
0?oOW01dW=l0oooo0:h0oooo003o0?oooaT0oooo00<0oooO09a80000M;l09P3oool00`3ooml0W4Qd
0;ooo`2^0?ooo`00o`3oool00`3ogi`0B000000000020000000607Boo`2oM00000000000000004P0
W=oo0`3oool01@2oM00000000000000007@0_ooo0080oooo00<0oooO09a8000000000`0000001@00
M;l0oooo0?ooo`3ookl0M0000080000000@0B9bo09a80000B9`0gooo0P3oool01`2oM00000000000
000007@0_ooo0?ooo`2oM0000P0000000`0007@0_ooO09a80002000000040018W03Oool0oooo0;md
0080000000<0001809cOo`3oool0103oool00`2oM000M;oo0?ooo`2]0?ooo`00o`3oool10?ooo`03
0?oog`2LB00007Bo00<0oooo00<0gia80000M02oool00`3oool03`2oM0000000001d_`3oool0omnL
04P0M02oool0oooO09a8000004P0W=oo0?ooo`3ooml0W4P0001d_`020?ooo`050=nLB00007@0_ooo
0?ooo`3OW4P00P0000004@0007@0_ooo0;md0000000007Bo0?ooo`3ogi`0B01d0;ooo`3oool0gia8
0018W03Oool0oooo0?oog`2LB00007Bo0080oooo00L0_g@000000000B9`0gooo0?oog`2LB7@0_ooo
00<0oooo00@0omnL04P00000B9`0gooo[@3oool00?l0oooo0@3oool00`3ooml0W4P0001d_`030?oo
o`030=nLB00007@0_ooo0080oooo00<0omnL04P00018W=l00`3oool01@3ogi`0M9cO0?oOW0180000
M;oo0080oooo00<0oooO09a80000M;l00P3oool02`2oM00004RL0=ooo`3oool0oooO09a80000M;l0
oooo0?oOW0180000B9cO00<0oooo00h0omnL07BLg`3oool0gia80018W03Oool0oooo0?oog`2LB000
07Bo0?ooo`3ogi`0B000001d_`<0oooo00<0omnL09boo`3oool00P3oool0102oM00004RL09ad001d
_on]0?ooo`00o`3oool10?ooo`030?oog`2LB00007Bo00<0oooo00<0gia80000M02oool00P3oool0
0`3o_g@0001809cOo`050?ooo`030?noM00004P0W=oo0080oooo00<0oooO09a80000M;l00P3oool0
2`2oM00004RL0=ooo`3oool0oooO09a80000M;l0oooo0?noM00004P0W=oo00H0oooo00/0gia80018
W03Oool0oooo0?oog`2LB00007Bo0?ooo`3o_g@0001809cOo`070?ooo`050?noM0000000M;oo0?oO
W018M;l0[@3oool00?l0oooo0@3oool00`3ooml0W4P0001d_`030?ooo`030=nLB00007@0_ooo0080
oooo00<0okmd0000M02oool01@3oool00`3o_g@0001809cOo`020?ooo`030?oog`2LB00007Bo0080
oooo00/0_g@00018W03Oool0oooo0?oog`2LB00007Bo0?ooo`3o_g@0001d0;ooo`060?ooo`0;0=nL
B000B9`0gooo0?ooo`3ooml0W4P0001d_`3oool0okmd0000M02oool01P3oool01`3ooml0W4P00018
W03Oool0oooo0;mdB02Lgol0[03oool00?l0oooo0@3oool00`3ooml0W4P0001d_`030?ooo`030=nL
B00004P0W=oo0080oooo00<0omnL04P000000000100000001018W=l0oono07@0001d_ol20?ooo`03
0?oog`2LB00007Bo0080oooo00X0_g@00018W03Oool0oooo0?oog`2LB00007Bo0?ooo`3ogi`0B000
1@0000003@18W=l0oooo0;md000007@0_ooo0?ooo`3ooml0W4P0001d_`3oool0omnL04P0B02Lgol0
0P3oool01`3o_g@0001809cOo`3oool0okmd0000B02Lgol00P3oool00`3o_g@0B9cO0?ooo`2[0?oo
o`00o`3oool10?ooo`0>0?oog`2LB00007Bo0?ooo`3ooml0W4P00000000004P0B7BL0=noM00007@0
_ooo0;md0018W=l20?ooo`0;0=nLB00004P0W=oo0?ooo`3OW4P0001d0;ooo`3oool0omnL04P00000
M;l00P3oool01`2oM00004RL0=ooo`3oool0oooO09a80000M;l00P3oool03`2oM000B9cO0?ooo`3o
ool0gia80000B02Lgml0W4P000000000B4P0B01809cOo`3ookl0M00004RLg`020?ooo`0;0;md0000
B9`0gooo0?oog`2LB000001d0;ooo`3ookl0M0000018W03Oool00P3oool00`3ookl0M01d0;ooo`2[
0?ooo`00o`3oool00`3o_g@00000000000020000000:0018W03Oool0_g@00000M02ogi`0B0000000
M02oool0oooo0=nLB080000000<0001809cOo`3oool00P3oool03`3o_g@000000000000007@0_mnL
04Qd_`3ookl0M00000000000B9`0gooo0?oOW01800000000001d_`030?ooo`050=nLB00000000000
0000B02Lgol00P3oool01`2oM00004RL0=oog`2LB00000000000M02oool00`3oool01`3OW4P00000
0000000004P0W=oo0?oog`2LB0000P0000001`00B9`0gooo0?ooo`2oM00000000018W03Oool0ZP3o
ool00?l0oooo0@3oool00`3ooml0W4P0001d_`3_0?ooo`00o`3oool20?ooo`030;md0000M;l0oooo
0>h0oooo003o0?ooo`80oooo00<0gia8001d_`3oool0kP3oool00?l0oooo0P3oool01`3ookl0M01d
0;ooo`3ooml0W4P00018W03Oool0jP3oool00?l0oooo0`3oool01@3ookl0M0000000000004P0W=oo
0>/0oooo003o0?oooo<0oooo003o0?oooo<0oooo003o0?oooo<0oooo003o0?oooo<0oooo003o0?oo
oo<0oooo003o0?oooo<0oooo003o0?oooo<0oooo003o0?oooo<0oooo003o0?oooo<0oooo003o0?oo
oo<0oooo003o0?oooo<0oooo002N0?ooo`030?oog`2LB00000000080000000<0M;oo0?ooo`3oool0
0`3oool01@3ogi`0B0000000000007@0_ooo02/0oooo00H0_g@000000000000000000018W03Oool3
0?ooo`050?oOW018000000000000M02oool0103oool01@3ogi`0B0000000000007@0_ooo02H0oooo
00T0_g@000000000000000000018W03Oool0oooo0?oog`2LB0000`0000000`1d_ol0oooo0?ooo`03
0?ooo`050?oOW018000000000000M02oool09@3oool00`2oM0000000000000040000000904RLg`3o
ool0oooo0?ooo`3ogi`0B0000000000007@0_ooo00@0oooo00D0omnL04P000000000001d0;ooo`0T
0?ooo`030;md00000000000000@0000000@0B9cO0?ooo`3ooml0W4P00`0000000`1d_ol0oooo0?oo
o`030?ooo`050?oOW018000000000000M02oool0903oool00`3ookl0M000000000020000000307Bo
o`3oool0oooo00<0oooo00D0omnL04P000000000001d0;ooo`040?ooo`050?oOW018000000000000
M02oool03@3oool009h0oooo00<0oooO09a8M02oool00P3oool00`2oM000M;oo0?ooo`020?ooo`07
0?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`0[0?ooo`030?oOW0180000M;oo00@0oooo00L0oono
07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo
02H0oooo00<0omnL04P0001d_ol00`3oool00`3ooml0W4Qd0;ooo`020?ooo`030;md001d_ol0oooo
0080oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo02D0oooo00<0gia80000000000000`00
00002P00B9`0gooo0?ooo`3ookl0M00007Boo`3oool0okmd0000M02oool20?ooo`070?oo_`1d0000
M;oo0?ooo`3o_g@0001d0;ooo`0T0?ooo`030=nLB0000000000000<0000000D004RL0=ooo`3ooml0
W4Qd0;ooo`020?ooo`030;md001d_ol0oooo0080oooo00L0oono07@0001d_ol0oooo0?noM00007@0
_ooo02<0oooo00<0omnL04P00018W=l00P3oool00`2oM000B9cO0?ooo`020?ooo`070?oo_`1d0000
M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`0<0?oo
o`00X`3oool00`3ooml0W4Qd0;ooo`020?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3o
ool0:P3oool00`3ogi`0B00007Boo`040?ooo`030;md0000B9`0gooo0080oooo00L0_g@0001d_`3o
ool0oooo0;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool09@3oool00`3ogi`0B00007Boo`08
0?ooo`030?oog`2LB7@0_ooo0080oooo00<0_g@00018W03Oool00P3oool00`2oM00007Bo0?ooo`0U
0?ooo`030=nLB018W=l0oooo0080oooo00H0giad09cOo`3oool0_g@00018W03Oool20?ooo`070;md
0000M;l0oooo0?ooo`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo02@0oooo00<0gia804RL
g`3oool00P3oool00`3OW7@0W=oo0?ooo`040?ooo`030?oog`2LB7@0_ooo0080oooo00<0_g@00018
W03Oool00P3oool00`2oM00007Bo0?ooo`0W0?ooo`030?oo_`1d04P0W=oo0080oooo00<0_g@00018
W03Oool00P3oool01`2oM00007Bo0?ooo`3oool0_g@00018W03Oool00P3oool00`2oM00007Bo0?oo
o`0;0?ooo`00Y03oool01P2oM000M;oo0?ooo`3ookl0M00004RLg`<0oooo00<0gia80000M02oool0
:P3oool00`3ogi`0B00007Boo`030?ooo`030?oo_`1d0000B9cO00<0oooo00H0gia80000M02oool0
oono07@00018W=l30?ooo`030=nLB00007@0_ooo02D0oooo00<0omnL04P0001d_ol02@3oool01P2o
M000M;oo0?ooo`3ookl0M00004RLg`<0oooo00<0gia80000M02oool09P3oool00`3OW4P0M;oo0?oo
o`030?ooo`030?oo_`1d0000B9cO00<0oooo00H0gia80000M02oool0oono07@00018W=l30?ooo`03
0=nLB00007@0_ooo02D0oooo00<0gia807Boo`3oool02@3oool01P2oM000M;oo0?ooo`3ookl0M000
04RLg`<0oooo00<0gia80000M02oool09`3oool01`3ookl0M00007Boo`3oool0oono07@00018W=l0
0`3oool01P3OW4P0001d0;ooo`3ookl0M00004RLg`<0oooo00<0gia80000M02oool02`3oool00:<0
oooo00L0oooO09a80018W=l0oooo0?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol0:P3oool0
0`3ogi`0B00007Boo`030?ooo`030?oOW0180000M;oo00<0oooo00H0okmd0000B02Lgol0omnL04P0
001d_ol30?ooo`030?noM00004P0W=oo02D0oooo00<0omnL04P0001d_ol0203oool01`3ooml0W4P0
04RLg`3oool0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0W0?ooo`030;mdB02Lgol0oooo
0080oooo00<0omnL04P0001d_ol00`3oool01P3o_g@0001809cOo`3ogi`0B00007Boo`<0oooo00<0
okmd0000B02Lgol09P3oool00`2oM4P0W=oo0?ooo`070?ooo`070?oog`2LB000B9cO0?ooo`3ogi`0
B00007Boo`030?ooo`030?noM00004P0W=oo02L0oooo00L0okmd0000001d_ol0oooo0?oOW0180000
M;oo00<0oooo00H0okmd0000B02Lgol0omnL04P0001d_ol30?ooo`030?noM00004P0W=oo00/0oooo
002S0?ooo`070=nLB0000000M;oo0?ooo`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo02X0
oooo00<0omnL04P0001d_ol00`3oool00`3ogi`0B00007Boo`030?ooo`060?noM00004P0W=oo0?oO
W0180000M;oo0`3oool00`3o_g@0001809cOo`0U0?ooo`030?oOW0180000M;oo00P0oooo00L0gia8
0000001d_ol0oooo0?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol09`3oool00`3ooml0W4Qd
0;ooo`020?ooo`030?oOW0180000M;oo00<0oooo00H0okmd0000B02Lgol0omnL04P0001d_ol30?oo
o`030?noM00004P0W=oo02H0oooo00<0oooO09a8M02oool01`3oool01`3OW4P0000007Boo`3oool0
omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`0V0?ooo`080?oOW0180000001809cOo`3oool0
omnL04P0001d_ol30?ooo`060?noM00004P0W=oo0?oOW0180000M;oo0`3oool00`3o_g@0001809cO
o`0;0?ooo`00W`3oool02`3Ogml0oooo0?oo_`1d000000000000M02oool0oooo0?oOW0180000M;oo
00<0oooo00<0okmd0000B02Lgol0:P3oool00`3ogi`0B00007Boo`030?ooo`030?oOW0180000M;oo
00<0oooo00H0okmd0000B02Lgol0omnL04P0001d_ol30?ooo`030?noM00004P0W=oo02D0oooo00<0
omnL04P0001d_ol0103oool02`3Ogml0oooo0?oo_`1d000000000000M02oool0oooo0?oOW0180000
M;oo00<0oooo00<0okmd0000B02Lgol0:03oool01`3o_g@007Bo0?ooo`3oool0omnL04P0001d_ol0
0`3oool01P3o_g@0001809cOo`3ogi`0B00007Boo`<0oooo00<0okmd0000B02Lgol09`3oool00`3o
_g@007Bo0?ooo`020?ooo`0;0=oOg`3oool0oono07@000000000001d0;ooo`3oool0omnL04P0001d
_ol00`3oool00`3o_g@0001809cOo`0T0?ooo`050?noM000000000000000B02Lgol00P3oool00`3o
gi`0B00007Boo`030?ooo`060?noM00004P0W=oo0?oOW0180000M;oo0`3oool00`3o_g@0001809cO
o`0;0?ooo`00W`3oool01P3OW4P00000000000000000001809cOo`80oooo00<0omnL04P0001d_ol0
0`3oool00`3o_g@0001809cOo`0Z0?ooo`030?oOW0180000M;oo00<0oooo00<0omnL04P0001d_ol0
0`3oool01P3o_g@0001809cOo`3ogi`0B00007Boo`<0oooo00<0okmd0000B02Lgol09@3oool00`3o
gi`0B00007Boo`040?ooo`060=nLB000000000000000000004P0W=oo0P3oool00`3ogi`0B00007Bo
o`030?ooo`030?noM00004P0W=oo02P0oooo00L0oono07@0B02Lgol0oooo0?oOW0180000M;oo00<0
oooo00H0okmd0000B02Lgol0omnL04P0001d_ol30?ooo`030?noM00004P0W=oo02L0oooo00<0oono
07@0B02Lgol00P3oool01P3OW4P00000000000000000001809cOo`80oooo00<0omnL04P0001d_ol0
0`3oool00`3o_g@0001809cOo`0V0?ooo`030;md0000M;l0oooo0080oooo00<0omnL04P0001d_ol0
0`3oool01P3o_g@0001809cOo`3ogi`0B00007Boo`<0oooo00<0okmd0000B02Lgol02`3oool009l0
oooo00@0oono07@000000000B9cO103oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo
02X0oooo00<0omnL04P0001d_ol00`3oool00`3ookl0M00004RLg`030?ooo`060=nLB00007@0_ooo
0?oo_`1d0000B9cO0`3oool00`3OW4P0001d0;ooo`0U0?ooo`030?oOW0180000M;oo00@0oooo00@0
oono07@000000000B9cO103oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo02P0oooo
00L0oono07@00018W=l0oooo0?oo_`1d0000B9cO00<0oooo00H0gia80000M02oool0oono07@00018
W=l30?ooo`030=nLB00007@0_ooo02L0oooo00<0oono07@00018W=l00P3oool0103ookl0M0000000
0018W=l40?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool09`3oool01`2oM000B9cO
0?ooo`3oool0oono07@00018W=l00`3oool01P3OW4P0001d0;ooo`3ookl0M00004RLg`<0oooo00<0
gia80000M02oool02`3oool00:00oooo00<0_g@007Boo`3oool01@3oool00`3OW4P004RL0=ooo`02
0?ooo`030;md0000M;l0oooo02X0oooo00<0omnL04P0001d_ol0103oool00`3OW4P004RL0=ooo`02
0?ooo`070;md0000M;l0oooo0?ooo`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo02D0oooo
00<0omnL04P0001d_ol01@3oool00`2oM000M;oo0?ooo`050?ooo`030=nLB000B9`0gooo0080oooo
00<0_g@0001d_`3oool08`3oool00`3o_i`0W=oo0?ooo`020?ooo`030?oOW0180000B9cO0080oooo
00<0gia80018W03Oool00P3oool01`2oM00007Bo0?ooo`3oool0gia80018W03Oool00P3oool00`2o
M00007Bo0?ooo`0R0?ooo`030?noW02Lgol0oooo0080oooo00<0omnL04P00018W=l00`3oool00`2o
M000M;oo0?ooo`050?ooo`030=nLB000B9`0gooo0080oooo00<0_g@0001d_`3oool08P3oool00`3o
oml0W9bo0?ooo`020?ooo`030=nLB00007@0_ooo0080oooo00<0gia80018W03Oool00P3oool01`2o
M00007Bo0?ooo`3oool0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`0;0?ooo`00X03oool0
1P3ogi`0B000000000000000001809cOo`80oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo
02T0oooo00D0oooO09a800000000000007Boo`040?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d
0;ooo`020?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`0T0?ooo`050?oog`2LB0000000
0000001d_ol01@3oool01P3ogi`0B000000000000000001809cOo`80oooo00L0oono07@0001d_ol0
oooo0?noM00007@0_ooo02@0oooo00P0oooO09a8B02Lgol0oooo0?oo_`1d0000001d0;ooo`80oooo
00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00L0oono07@0001d_ol0oooo0?noM000
07@0_ooo02<0oooo00P0oooO09a8B02Lgol0oooo0?oo_`1d0000001d0;ooo`<0oooo00H0omnL04P0
0000000000000000B02Lgol20?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`0T0?ooo`06
0?noM018W=l0oooo0?oo_`1d000007Bo0`3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool0
0P3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool0303oool00:40oooo00D0_g@000000000
0000000004RLg`030?ooo`050?oo_`1d000000000000M02oool0;03oool00`3o_g@0000007Boo`05
0?ooo`050?oo_`1d000000000000M02oool0103oool01@3ookl0M0000000000007@0_ooo02L0oooo
00<0okmd0000001d_ol01P3oool01@2oM0000000000000000000B9cO00<0oooo00D0oono07@00000
0000001d0;ooo`0V0?ooo`060?oog`2LB00000000000000007@0_ooo103oool01@3ookl0M0000000
000007@0_ooo00@0oooo00D0oono07@000000000001d0;ooo`0U0?ooo`060?oog`2LB00000000000
000007@0_ooo1@3oool01@2oM0000000000000000000B9cO00<0oooo00D0oono07@000000000001d
0;ooo`0V0?ooo`050=nLB000000000000000M02oool0103oool01@3ookl0M0000000000007@0_ooo
00@0oooo00D0oono07@000000000001d0;ooo`0=0?ooo`00o`3ooooc0?ooo`00o`3ooooc0?ooo`00
o`3ooooc0?ooo`00o`3ooooc0?ooo`009@3oool01P2oM000000000000000000004RL0=ooo`80oooo
00<0okmd0000001d_ol00`3oool00`3ookl0M00004RLg`050?ooo`030?oo_`1d0000B9cO00D0oooo
00H0_g@000000000000000000018W03Oool30?ooo`050?oOW018000000000000M02oool0o`3ooonR
0?ooo`009P3oool00`3ogi`0B00007Boo`040?ooo`030?noM0000000M;oo00@0oooo00<0oono07@0
0018W=l00`3oool00`3ookl0M00004RLg`070?ooo`030?oOW0180000M;oo00@0oooo00L0oono07@0
001d_ol0oooo0?noM00007@0_ooo0?l0ooooX@3oool002H0oooo00<0omnL04P0001d_ol0303oool0
1`3ookl0M00004RLg`3oool0oono07@00018W=l0203oool00`3ogi`0B00007Boo`040?ooo`030;md
0000B9`0gooo0080oooo00<0_g@0001d_`3oool0o`3ooonP0?ooo`009P3oool00`3ogi`0B00007Bo
o`0=0?ooo`050?oo_`1d0000B9bL07@00018W=l02@3oool00`3ogi`0B00007Boo`030?ooo`030?oo
_`1d0000B9cO00<0oooo00<0gia80000M02oool0o`3ooonP0?ooo`009P3oool00`3ogi`0B00007Bo
o`0>0?ooo`030?oo_`1d0000B9cO00X0oooo00<0omnL04P0001d_ol00`3oool00`3ogi`0B00007Bo
o`030?ooo`030?noM00004P0W=oo0?l0ooooX03oool002H0oooo00<0omnL04P0001d_ol03@3oool0
1@3ookl0M00004RLW01d0000B9cO00T0oooo00<0omnL04P0001d_ol00`3oool00`3ogi`0B00007Bo
o`030?ooo`030?noM00004P0W=oo01L0ooooo`00001b000001L0oooo000V0?ooo`030?oOW0180000
M;oo00`0oooo00L0oono07@00018W=l0oooo0?oo_`1d0000B9cO00P0oooo00<0omnL04P0001d_ol0
0`3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo01L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
5@3oool002H0oooo00<0omnL04P0001d_ol02`3oool00`3ooml0W4P004RLg`030?ooo`030?oo_`1d
0000B9cO00L0oooo00<0omnL04P0001d_ol00`3oool00`3ogi`0B00007Boo`030?ooo`030?noM000
04P0W=oo00T0oooo00@0okmd000000000000M;oo2P3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0E0?ooo`009P3o
ool00`3ogi`0B00007Boo`0:0?ooo`030?oog`2LB000B9cO00D0oooo00<0oono07@00018W=l01P3o
ool00`3ogi`0B00007Boo`030?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0203o
ool01P3ogi`0B01809cOo`3ookl0M01809cOo`T0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`03
0000003oool0oooo01D0oooo000V0?ooo`030?oOW0180000M;oo01/0oooo00<0omnL04P0001d_ol0
103oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo00P0oooo00H0gia8001d_`3oool0
oooo0;md0018W=l90?ooo`030000003oool0oooo0?l0ooooKP3oool00`000000oooo0?ooo`0E0?oo
o`00903oool01@3ooml0W4P0000000000000M;oo01T0oooo00D0oooO09a800000000000007Boo`04
0?ooo`0:0?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`3oool0omnL04P000D0000000<0B9cO0=nL
B018W=l00P3oool00`2oM000B9cO0?ooo`080?ooo`030000003oool0oooo0?l0ooooKP3oool00`00
0000oooo0?ooo`0E0?ooo`009P3oool00`3o_g@0000007Boo`0K0?ooo`030?noM0000000M;oo00D0
oooo00D0oono07@000000000001d0;ooo`0:0?ooo`060=nLB000M7@0_koo0?oOW0180000M;oo2@3o
ool00`000000oooo0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool05@3oool005/0oooo00D0omnL
04P0M01dM0000000001d_`0:0?ooo`030000003oool0oooo0?l0ooooKP3oool00`000000oooo0?oo
o`0E0?ooo`00F`3oool00`3ooml0W4P004RLg`0<0?ooo`030000003oool0oooo0?l0ooooKP3oool0
0`000000oooo0?ooo`0E0?ooo`00G03oool00`3ookl0M000001d_`0;0?ooo`030000003oool0oooo
0?l0ooooKP3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool0103ooml0W4P00000001d_ol90?oo
o`030000003oool0oooo0?l0ooooKP3oool00`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000
oooo0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool05@3oool006X0oooo00<000000?ooo`3oool0
o`3ooom^0?ooo`030000003oool0oooo01D0oooo001Z0?ooo`030000003oool0oooo0?l0ooooKP3o
ool00`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<00000
0?ooo`3oool05@3oool006X0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo
01D0oooo001Z0?ooo`030000003oool0oooo0?l0ooooI03oool00`000000oooo00000003000000@0
oooo00<000000?ooo`3oool05@3oool006X0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`<00000
00<0oooo0000000000000P0000001@3oool000000000003oool0000001L0oooo001Z0?ooo`030000
003oool0oooo0?l0ooooH@3oool3000000L0oooo1000000G0?ooo`00JP3oool00`000000oooo0?oo
o`3o0?oooc00oooo1@0000000`3oool000000000000X0?ooo`8000002`3oool2000001L0oooo001Z
0?ooo`030000003oool0oooo0?l0oooo;@3oool2000000030?ooo`000000000000<0000000@0oooo
00000000000000009@3oool00`000000oooo0000000=0?ooo`030000003oool0oooo01D0oooo001Z
0?ooo`030000003oool0oooo0?l0oooo;@3oool2000000T0oooo0P0000000`3oool000000?ooo`0P
0?ooo`8000003`3oool00`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`3o0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0000000Q0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool05@3oool006X0oooo00<000000?ooo`3o
ool0n`3oool3000000030?ooo`0000000000008000009`3oool2000000l0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01D0oooo001Z0?ooo`030000
003oool0oooo0</0oooo0P00000[0?ooo`030000003oool0000000<000000P3oool3000000030?oo
o`00000000000280oooo00<000000?ooo`000000403oool2000001h0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`370?ooo`80000000<0
oooo0000000000000P0000000`3oool000000000000V0?ooo`80000000<0oooo0000003oool0203o
ool300000240oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool05@3oool006X0oooo00<000000?ooo`3oool0UP3oool2
000000030?ooo`000000oooo02X0oooo100000001P3oool000000?ooo`3oool000000?ooo`<00000
9@3oool00`000000oooo0?ooo`0<0?ooo`8000007`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0E0?ooo`00JP3o
ool00`000000oooo0?ooo`2D0?ooo`@0000000<0oooo0000000000000P00000W0?ooo`<000002P3o
ool2000002<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0L0?ooo`8000005@3o
ool00`000000oooo0000000H0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05@3o
ool006X0oooo00<000000?ooo`3oool0T@3oool2000000030?ooo`000000000000@0oooo1000000V
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`000000803oool200000140oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`2@0?oo
o`<000002P3oool00`000000oooo0000000R0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool07@3oool200000180oooo00<000000?ooo`000000C03oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo01D0oooo001Z0?ooo`030000003oool0oooo02h0oooo1@0000000`3oool0
00000?ooo`0[0?ooo`80000000@0oooo0000000000000000:03oool2000000h0oooo0P00000P0?oo
o`8000004P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0000000@0000000<0oooo000000000000:@3oool4000000030?ooo`00000000000080
000000<0oooo0000003oool0903oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool04@3oool2000001/0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`0Z0?ooo`<00000203oool2000002H0oooo
00@000000?ooo`00000000001P3oool010000000oooo00000000000R0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01D0oooo001Z0?ooo`030000003oool0oooo02T0oooo0`00000:0?ooo`800000903oool2000000`0
oooo0P00000P0?ooo`8000004`3oool2000001`0oooo0P00000F0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01D0
oooo001Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0000000Q0?ooo`8000003P3oool2000001l0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool05@3oool006X0oooo0`00
000W0?ooo`030000003oool0oooo00l0oooo0P00000O0?ooo`800000403oool2000001d0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo04L0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01@0oooo0P00
000G0?ooo`00JP3oool5000002@0oooo0P00000B0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0000000K0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo001Z0?oo
o`030000003oool0oooo00<000008`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000
oooo0?ooo`020?ooo`030000003oool000000200oooo00<000000?ooo`3oool04`3oool2000001`0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo01D0
oooo001Z0?ooo`030000003oool0oooo00@0oooo0P00000O0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo0?oo
o`050?ooo`8000007@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo06H0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool05@3oool006X0oooo00<000000?ooo`3oool01P3oool2000001`0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo001Z0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool05@3oool006X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool05@3oool006X0oooo0`0000090?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
IP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01L0oooo0P00000G0?ooo`00JP3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01D0oooo001Z0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo05T0oooo00<000000?ooo`3oool05@3oool006X0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo01D0oooo001Z0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool05@3oool006X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`1V0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0E0?ooo`00JP3oool3000000`0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?oo
o`0H0?ooo`8000005`3oool006X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0E
0?ooo`00JP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?00oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo01D0oooo001Z0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo01D0oooo001Z0?ooo`<000003P3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool0RP3oool2000001L0oooo001Z0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`2I0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool05@3oool006X0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`1S0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0E0?ooo`00JP3oool300000>X0oooo00<000000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`0I0?ooo`8000005`3oool006X0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`2J0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05@3oool006X0oooo
0`00000?0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0F`3oool00`000000oooo
0?ooo`1E0?ooo`8000005`3oool003<0oooo00D0omnL04P000000000001d0;ooo`030?ooo`030?no
M0000000M;oo00<0oooo00D0omnL04P000000000001d0;ooo`040?ooo`050?oOW018000000000000
M02oool0103oool01@3ogi`0B0000000000007@0_ooo00@0oooo00H0_g@000000000000000000018
W03Oool80?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0U`3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`0E0?ooo`00<P3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool00`3o_g@0
000007Boo`020?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`070?oo_`1d0000
M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`040?oo
o`030?oOW0180000M;oo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1S0?oo
o`030000003oool0oooo05/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo01D0oooo000b0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3o
ool01P3oool00`2oM00004RL0=ooo`020?ooo`070;md0000M;l0oooo0?ooo`2oM00004RL0=ooo`02
0?ooo`070;md0000M;l0oooo0?ooo`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo00<0oooo
00<0omnL04P0001d_ol02P3oool300000100oooo00<000000?ooo`3oool0K`3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo0;d0oooo0P00000G0?ooo`00<@3oool00`3ookl0M00004RL
g`030?ooo`030=nLB00007@0_ooo00D0oooo00<0oono07@00018W=l00`3oool01P3OW4P0001d0;oo
o`3ookl0M00004RLg`<0oooo00H0gia80000M02oool0oono07@00018W=l30?ooo`030=nLB00007@0
_ooo00<0oooo00<0omnL04P0001d_ol02P3oool300000100oooo00<000000?ooo`3oool0V@3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0840oooo0P00000G0?ooo`00<@3oool00`3o
gi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00<0omnL04P0001d_ol00`3oool01P3o
_g@0001809cOo`3ogi`0B00007Boo`<0oooo00H0okmd0000B02Lgol0omnL04P0001d_ol30?ooo`03
0?noM00004P0W=oo00<0oooo00<0omnL04P0001d_ol02P3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1M0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool05@3oool00340oooo00<0omnL04P0001d_ol0
0`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000M;oo00<0oooo00H0okmd0000B02Lgol0
omnL04P0001d_ol30?ooo`060?noM00004P0W=oo0?oOW0180000M;oo0`3oool00`3o_g@0001809cO
o`030?ooo`030?oOW0180000M;oo00X0oooo100000140?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo0200oooo0`00
000G0?ooo`00<@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00D0oooo00<0omnL
04P0001d_ol00`3oool01P3o_g@0001809cOo`3ogi`0B00007Boo`<0oooo00H0okmd0000B02Lgol0
omnL04P0001d_ol30?ooo`030?noM00004P0W=oo00<0oooo00<0omnL04P0001d_ol02P3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool05@3oool00340
oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`050?ooo`030?oOW0180000M;oo00<0
oooo00H0okmd0000B02Lgol0omnL04P0001d_ol30?ooo`060?noM00004P0W=oo0?oOW0180000M;oo
0`3oool00`3o_g@0001809cOo`030?ooo`030?oOW0180000M;oo00X0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01D0oooo000a0?ooo`030?oo_`1d
0000B9cO00<0oooo00<0gia80000M02oool01@3oool00`3ookl0M00004RLg`030?ooo`060=nLB000
07@0_ooo0?oo_`1d0000B9cO0`3oool01P3OW4P0001d0;ooo`3ookl0M00004RLg`<0oooo00<0gia8
0000M02oool00`3oool00`3ogi`0B00007Boo`0:0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo08T0oooo00<00000
0?ooo`3oool05@3oool00380oooo00<0gia80018W03Oool00P3oool00`2oM00007Bo0?ooo`060?oo
o`030=nLB000B9`0gooo0080oooo00L0_g@0001d_`3oool0oooo0=nLB000B9`0gooo0080oooo00L0
_g@0001d_`3oool0oooo0=nLB000B9`0gooo0080oooo00<0_g@0001d_`3oool00`3oool00`3ogi`0
B00007Boo`0:0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0K@3oool00`000000
oooo0?ooo`1M0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool05@3oool00380oooo
00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00L0oooo00L0oono07@0001d_ol0oooo0?noM000
07@0_ooo0080oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo0080oooo00L0oono07@0001d
_ol0oooo0?noM00007@0_ooo0080oooo00D0oooO09a800000000000007Boo`0:0?ooo`030000003o
ool0oooo0840oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1[0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool05@3oool003<0oooo00D0oono07@000000000001d0;oo
o`090?ooo`050?oo_`1d000000000000M02oool0103oool01@3ookl0M0000000000007@0_ooo00@0
oooo00D0oono07@000000000001d0;ooo`050?ooo`030?noM0000000M;oo00X0oooo00<000000?oo
o`3oool0[@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool05@3oool006X0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo0?00oooo00<000000?ooo`3oool05@3oool006X0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
JP3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01D0oooo001Z0?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`230?ooo`030000003o
ool0oooo01D0oooo001Z0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0o`3ooomA
0?ooo`030000003oool0oooo01D0oooo001Z0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`3o0?oooe40oooo00<000000?ooo`3oool05@3oool006X0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo09<0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo
0?ooo`2d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`20
0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0E
0?ooo`00JP3oool00`000000oooo0?ooo`3R0?ooo`030000003oool0oooo08P0oooo00<000000?oo
o`3oool05@3oool006X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1P0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01D0oooo001Z0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0
H03oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
5@3oool006X0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`3_0?ooo`030000003o
ool0oooo01D0oooo001Z0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`3_0?ooo`030000003oool0oooo01D0oooo001Z0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo
0500oooo00<000000?ooo`3oool05@3oool006X0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0?h0oooo00<000000?ooo`3oool0D03oool00`000000
oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0oooo
E`3oool00`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<0
00000?ooo`3oool05@3oool006X0oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`24
0?ooo`030000003oool0oooo01D0oooo001Z0?ooo`030000003oool0oooo0>H0oooo00<000000?oo
o`3oool0Q03oool00`000000oooo0?ooo`0E0?ooo`00403oool00`3ooml0W9bo0?ooo`080?ooo`03
0;nLW03Oool0oooo04`0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo01D0
oooo000@0?ooo`030?oOW0180000000000P0000000<004RL0=ooo`3oool0C03oool00`000000oooo
0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool05@3oool00100oooo00<0gia80000000000002000
00000`00B9`0gooo0?ooo`1<0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool0^03o
ool00`000000oooo0?ooo`0E0?ooo`004@3oool00`2oM7@0_ooo0?ooo`020?ooo`030?oog`2LW;l0
oooo0080oooo00<0_ibL0=ooo`3oool0C03oool00`000000oooo0?ooo`2b0?ooo`030000003oool0
oooo0;P0oooo00<000000?ooo`3oool05@3oool00100oooo00<0gia8001d_`3oool0103oool00`3O
W9`0_ooo0?ooo`1@0?ooo`030000003oool0oooo0?l0ooooKP3oool00`000000oooo0?ooo`0E0?oo
o`00403oool00`2oM000000007Boo`030?ooo`030?oOW018B9`0gooo0540oooo00<000000?ooo`3o
ool0O`3oool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo01D0oooo000@0?ooo`030?no
M0000000000000@0000000<0M;oo0?ooo`3oool0D03oool00`000000oooo0?ooo`1o0?ooo`030000
003oool0oooo0>/0oooo00<000000?ooo`3oool05@3oool00140oooo00H0omnL04P0000000000000
0000B02LgomC0?ooo`030000003oool0oooo0?l0ooooKP3oool00`000000oooo0?ooo`0E0?ooo`00
JP3oool300000?l0ooooK@3oool2000001L0oooo001Z0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0o`3ooolP0?ooo`030000003oool0oooo01D0oooo000B0?ooo`050;md00000000
00000000B02Lgol0D`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0oooo803o
ool00`000000oooo0?ooo`0E0?ooo`00403oool00`3ookl0M000000000040000000307Boo`3oool0
oooo0500oooo00<000000?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo01D0oooo000@0?oo
o`030=nLB01d_ol0oooo00<0oooo00<0_g@00018W03Oool0D@3oool00`000000oooo0?ooo`3o0?oo
oaP0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
01D0oooo000@0?ooo`030;mdM02oool0oooo00@0oooo00<0gibL0;ooo`3oool0D03oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05@3oool00100oooo
00<0gia80018W03Oool00`3oool00`3ookl0M4RL0=ooo`1A0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01D0oooo
000@0?ooo`030?oo_`1d0000000000@0000000<0M;oo0?ooo`3oool0D03oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0?l0ooooEP3oool00`000000oooo0?ooo`0E0?ooo`004@3oool0
1P3ooml0W4P0000000000000001d0;oooe<0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`3o0?oooeH0oooo00<000000?ooo`3oool05@3oool006X0oooo0`00003o0?ooofd0oooo0P00
000G0?ooo`00403oool00`2oM4P0W=oo0?ooo`1G0?ooo`030000003oool0oooo0?l0ooooKP3oool0
0`000000oooo0?ooo`0E0?ooo`00403oool0102oM00000000000M02ooomF0?ooo`030000003oool0
oooo0?l0ooooKP3oool00`000000oooo0?ooo`0E0?ooo`00403oool00`2oM4P0M7A8000000020000
000307Boo`3oool0oooo0580oooo00<000000?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo
01D0oooo000C0?ooo`050?oo_`1d0000000000000000M;l0DP3oool00`000000oooo0?ooo`3o0?oo
ofh0oooo00<000000?ooo`3oool05@3oool001D0oooo00@0okmd0000000007@0_oooD@3oool00`00
0000oooo0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool05@3oool00100oooo00H0_gAd0;ooo`3o
okl0M00000000000M;mD0?ooo`<00000o`3ooom]0?ooo`8000005`3oool00100oooo00@0_g@00000
000007@0_oooEP3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool05@3oool0
0100oooo00H0_gAd09bLB000000000000000B02LgomD0?ooo`030000003oool0oooo0?l0ooooKP3o
ool00`000000oooo0?ooo`0E0?ooo`004`3oool01@3ookl0M00000000000000007Bo0580oooo00<0
00000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05@3o
ool001D0oooo00@0_g@00000000007@0_oooD@3oool300000?l0ooooC@3oool00`000000oooo0?oo
o`0M0?ooo`8000005`3oool00100oooo00<0_ibL0=oog`2LB0000P0000000`1d_ol0oooo0?ooo`1B
0?ooo`030000003oool0oooo0?l0ooooKP3oool00`000000oooo0?ooo`0E0?ooo`00403oool00`2o
M000001809cOo`1G0?ooo`030000003oool0oooo0?l0ooooKP3oool00`000000oooo0?ooo`0E0?oo
o`00403oool00`2oM7@0_ooo0?ooo`1G0?ooo`<00000o`3ooom]0?ooo`8000005`3oool006X0oooo
00<000000?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo01D0oooo000A0?ooo`030?oo_`1d
000000000080000000<0B9cO0?ooo`3oool0D@3oool300000?l0ooooK@3oool2000001L0oooo000@
0?ooo`030?oOW0180000000000@0000000<0B9cO0?ooo`3oool0:`3oool01@3ogi`0B00000000000
07@0_ooo00<0oooo00<0okmd0000001d_ol00`3oool01@3ogi`0B0000000000007@0_ooo00@0oooo
00H0_g@000000000000000000018W03Oool80?ooo`030000003oool0oooo0?l0ooooKP3oool00`00
0000oooo0?ooo`0E0?ooo`00403oool02@3OW7@0W=oo0?noM01d_ol0oooo0?noM0000000001d0;oo
o`0[0?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`030?noM0000000M;oo0080
oooo00L0oono07@0001d_ol0oooo0?noM00007@0_ooo00@0oooo00<0omnL04P0001d_ol02P3oool3
00000?l0oooo6@3oool00`000000oooo0?ooo`1A0?ooo`8000005`3oool00100oooo00@0_gA809cO
o`3o_g@0M;oo0P3oool00`3OW4P0001d0;ooo`0[0?ooo`030;md0000B9`0gooo0080oooo00<0_g@0
001d_`3oool01P3oool00`2oM00004RL0=ooo`020?ooo`030;md0000M;l0oooo00<0oooo00<0omnL
04P0001d_ol02P3oool00`000000oooo0?ooo`3o0?oooaT0oooo00<000000?ooo`3oool0DP3oool0
0`000000oooo0?ooo`0E0?ooo`00403oool0103o_g@000000000001d_ol20?ooo`030;md0000M;l0
oooo02X0oooo00<0oono07@00018W=l00`3oool00`3OW4P0001d0;ooo`050?ooo`030?oo_`1d0000
B9cO00<0oooo00<0gia80000M02oool00`3oool00`3ogi`0B00007Boo`0:0?ooo`<00000o`3ooom]
0?ooo`8000005`3oool00140oooo00H0gia80000001d_ol0okmd00000000M;l/0?ooo`030?oOW018
0000M;oo00<0oooo00<0okmd0000B02Lgol01@3oool00`3ogi`0B00007Boo`030?ooo`030?noM000
04P0W=oo00<0oooo00<0omnL04P0001d_ol02P3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<0
00000?ooo`3oool05@3oool004<0oooo00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`05
0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol00`3oool00`3ogi`0B00007Boo`0:
0?ooo`@00000o`3ooom[0?ooo`<000005`3oool00100oooo00<0oono07Ad_`3oool0103oool00`3O
W9`0_ooo0?ooo`0Y0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02Lgol01@3oool00`3o
gi`0B00007Boo`030?ooo`030?noM00004P0W=oo00<0oooo00<0omnL04P0001d_ol02P3oool00`00
0000oooo0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool05@3oool00100oooo00<0okmd00000000
0000100000000`0007@0_ooo0?ooo`0Y0?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol01@3oool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo00<0oooo00<0omnL04P0001d
_ol02P3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool05@3oool00100oooo
00<0_g@0000000000000100000000`0007@0_ooo0?ooo`0Y0?ooo`030?oo_`1d0000B9cO00<0oooo
00<0gia80000M02oool01@3oool00`3ookl0M00004RLg`030?ooo`030=nLB00007@0_ooo00<0oooo
00<0omnL04P0001d_ol02P3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool0
5@3oool00140oooo00<0_gAd0;ooo`3oool00`3oool00`3OW9`0_ooo0?ooo`0Z0?ooo`030=nLB000
B9`0gooo0080oooo00<0_g@0001d_`3oool01P3oool00`3OW4P004RL0=ooo`020?ooo`030;md0000
M;l0oooo00<0oooo00<0omnL04P0001d_ol02P3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<0
00000?ooo`3oool05@3oool00100oooo00<0gia8001d_`3oool0<@3oool01`3ookl0M00007Boo`3o
ool0okmd0000M02oool01`3oool01`3ookl0M00007Boo`3oool0okmd0000M02oool00P3oool01@3o
oml0W4P0000000000000M;oo00X0oooo00<000000?ooo`3oool0i@3oool00`000000oooo0?ooo`25
0?ooo`030000003oool0oooo01D0oooo000@0?ooo`030=nLB00004P0W=oo0380oooo00D0oono07@0
00000000001d0;ooo`090?ooo`050?oo_`1d000000000000M02oool01@3oool00`3o_g@0000007Bo
o`0:0?ooo`030000003oool0oooo0>D0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?oo
o`0E0?ooo`00JP3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool05@3oool0
06X0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo01D0oooo001Z0?ooo`03
0000003oool0oooo0?l0ooooKP3oool00`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo
0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool05@3oool006X0oooo00<000000?ooo`3oool0o`3o
oom^0?ooo`030000003oool0oooo01D0oooo001Z0?ooo`030000003oool0oooo0?l0ooooKP3oool0
0`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<000000?oo
o`3oool05@3oool006X0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`2i0?ooo`03
0000003oool0oooo01D0oooo001Z0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0
^@3oool00`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<0
00000?ooo`3oool05@3oool006X0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`030000003oool0
oooo01D0oooo001Z0?ooo`030000003oool0oooo0?l0ooooKP3oool00`000000oooo0?ooo`0E0?oo
o`00JP3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool05@3oool006X0oooo
00<000000?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo01D0oooo001Z0?ooo`030000003o
ool0oooo0?l0ooooKP3oool00`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`3o
0?ooofh0oooo00<000000?ooo`3oool05@3oool006X0oooo00<000000?ooo`3oool0o`3ooom^0?oo
o`030000003oool0oooo01D0oooo001Z0?ooo`030000003oool0oooo0?l0ooooKP3oool00`000000
oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool0
5@3oool006X0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`3]0?ooo`030000003o
ool0oooo01D0oooo001Z0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0k@3oool0
0`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<000000?oo
o`3oool05@3oool006X0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo01D0
oooo001Z0?ooo`030000003oool0oooo0?l0ooooKP3oool00`000000oooo0?ooo`0E0?ooo`00JP3o
ool00`000000oooo0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool05@3oool006X0oooo00<00000
0?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo01D0oooo001Z0?ooo`030000003oool0oooo
0?l0ooooKP3oool00`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`3o0?ooofh0
oooo00<000000?ooo`3oool05@3oool006X0oooo0`00003o0?ooofd0oooo0P00000G0?ooo`00JP3o
ool00`000000oooo0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool05@3oool006X0oooo00<00000
0?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo01D0oooo001Z0?ooo`030000003oool0oooo
0?l0ooooKP3oool00`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`3o0?ooofh0
oooo00<000000?ooo`3oool05@3oool006X0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`030000
003oool0oooo01D0oooo001Z0?ooo`030000003oool0oooo0?l0ooooKP3oool00`000000oooo0?oo
o`0E0?ooo`00JP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0?l0oooo8@3oool0
0`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo
0?l0oooo8@3oool00`000000oooo0?ooo`0E0?ooo`00JP3oool300000?l0ooooK@3oool2000001L0
oooo001Z0?ooo`030000003oool0oooo0?l0ooooKP3oool00`000000oooo0?ooo`0E0?ooo`00JP3o
ool00`000000oooo0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool05@3oool006X0oooo00<00000
0?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo01D0oooo001Z0?ooo`030000003oool0oooo
0?l0ooooKP3oool00`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`3o0?ooofh0
oooo00<000000?ooo`3oool05@3oool006X0oooo0`00003o0?ooofd0oooo0P00000G0?ooo`00JP3o
ool00`000000oooo0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool05@3oool006X0oooo00<00000
0?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo01D0oooo001Z0?ooo`030000003oool0oooo
0?l0ooooKP3oool00`000000oooo0?ooo`0E0?ooo`00JP3oool300000?l0ooooK@3oool2000001L0
oooo001Z0?ooo`030000003oool0oooo0?l0ooooKP3oool00`000000oooo0?ooo`0E0?ooo`00JP3o
ool00`000000oooo0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool05@3oool006X0oooo0`00003o
0?ooofd0oooo0P00000G0?ooo`00JP3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<000000?oo
o`3oool05@3oool006X0oooo0`00003o0?ooofd0oooo0P00000G0?ooo`00G03oool01P2oM0000000
00000000000004RL0=ooo`P0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo
01D0oooo001M0?ooo`030?oOW0180000M;oo00X0oooo0`00003o0?ooofd0oooo0P00000G0?ooo`00
G@3oool00`3ogi`0B00007Boo`0:0?ooo`030000003oool0oooo0?l0ooooKP3oool00`000000oooo
0?ooo`0E0?ooo`00G@3oool00`3ogi`0B00007Boo`0:0?ooo`<00000o`3ooom]0?ooo`8000005`3o
ool005d0oooo00<0omnL04P0001d_ol02P3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<00000
0?ooo`3oool05@3oool005d0oooo00<0omnL04P0001d_ol02P3oool400000?l0ooooJ`3oool30000
01L0oooo001M0?ooo`030?oOW0180000M;oo00X0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`03
0000003oool0oooo01D0oooo001M0?ooo`030?oOW0180000M;oo00X0oooo00<000000?ooo`3oool0
o`3ooom^0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030?oOW0180000M;oo00X0oooo00<0
00000?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030?oOW0180000
M;oo00X0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo01D0oooo001K0?oo
o`050?oog`2LB00000000000001d_ol02P3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<00000
0?ooo`3oool05@3oool005d0oooo00<0okmd0000001d_ol02P3oool00`000000oooo0?ooo`3o0?oo
ofh0oooo00<000000?ooo`3oool05@3oool006X0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`03
0000003oool0oooo01D0oooo001Z0?ooo`030000003oool0oooo0?l0ooooKP3oool00`000000oooo
0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool05@3o
ool006X0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo01D0oooo001Z0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`030000003oool0oooo
01D0oooo001Z0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`03
0000003oool0oooo01D0oooo001Z0?ooo`030000003oool0oooo0?l0ooooKP3oool00`000000oooo
0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool05@3o
ool006X0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo01D0oooo001Z0?oo
o`030000003oool0oooo0?l0ooooKP3oool00`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000
oooo0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool05@3oool006X0oooo00<000000?ooo`3oool0
o`3ooom^0?ooo`030000003oool0oooo01D0oooo001Z0?ooo`030000003oool0oooo0?l0ooooKP3o
ool00`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<00000
0?ooo`3oool05@3oool006X0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo
01D0oooo001Z0?ooo`030000003oool0oooo0?l0ooooKP3oool00`000000oooo0?ooo`0E0?ooo`00
JP3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool05@3oool006X0oooo00<0
00000?ooo`3oool0o`3ooom^0?ooo`030000003oool0oooo01D0oooo001Z0?ooo`030000003oool0
oooo0?l0ooooKP3oool00`000000oooo0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`3o0?oo
ofh0oooo00<000000?ooo`3oool05@3oool006X0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`03
0000003oool0oooo01D0oooo001Z0?ooo`030000003oool0oooo0?l0ooooKP3oool00`000000oooo
0?ooo`0E0?ooo`00JP3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<000000?ooo`3oool05@3o
ool006X0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool05@3oool006X0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05@3oool006X0
ooooo`00001b000001L0oooo003o0?oooo<0oooo003o0?oooo<0oooo003o0?oooo<0oooo003o0?oo
oo<0oooo003o0?oooo<0oooo003o0?oooo<0oooo003o0?oooo<0oooo003o0?oooo<0oooo003o0?oo
oeL0oooo00<0_g@00018W03Oool0V@3oool00?l0ooooF03oool00`3ogi`0W;oo0?ooo`2H0?ooo`00
o`3ooomI0?ooo`030;nLW03Oool0oooo09L0oooo002o0?ooo`030?oog`2LB7@0_ooo00<0oooo00T0
oooO09a80000000000000018W02LM0000000001d_`2oM0000P0000000`0007@0_ooO09a800020000
00030018W03Oool0oooo00<0oooo00P0oooO09a80000000000000000B018B00004RL0=ooo`80oooo
00L0_g@0000000000000001d0;ooo`3oool0_g@00080000000<0001809cOo`3oool0103oool00`2o
M00000000000000200000003001d_`3oool0oooo00D0oooo00D0gia8000000000000000007Boo`02
0?ooo`050=nLB000000000000000M02oool01P3oool01@3OW4P00000000000000000M;oo0080oooo
00<0oono0;no_`1d00000P0000001@1d_ol0oooo0?ooo`3oool0_g@00080000000@0001809cOo`3o
ool0gia80P0000001P0007@0W9a8000000000000001d09bLB080000000<0001d0;oog`2LB0000P00
00002@00B9`0W7@000000000M;l0oooo0?oOW0180000000004RLg`020?ooo`050=nLB00000000000
0000001d_ol00P3oool01@2oM00000000000000004P0W=oo00@0oooo00D0oooO09a80000000004RL
0=ooo`040?ooo`030?oOW018000000000080000000<007Bo0?ooo`3oool03P3oool01P2oM0000000
00000000000004RL0=ooo`<0oooo00D0omnL04P000000000001d0;ooo`030?ooo`030?noM0000000
M;oo06X0oooo002o0?ooo`030?noM0000000B9cO00<0oooo0100okmd0000001d_ol0oooo0?oOW018
000007Bo0?no_`2oool0gia80018W03Oool0oooo0?oog`2LB00007Bo1@3oool05@3ooml0W4P00000
001d_ol0oooo0?oo_`1d000000000000M02oool0_g@000000000M;l0oooo0?oOW01807@0_ooo0?oo
o`3OW4P0001d0;ooo`070?ooo`040?oog`2LB00004RL0=ooo`L0oooo00L0gia800000018W=l0oooo
0?oog`2LB000B9cO0080oooo00<0gia80000M02oool01P3oool0>03OW4P0000004RLg`3oool0oooO
09a80018W=l0oooo0?oo_`1d04P0W=oo0?ooo`3ookl0M01809cOo`3oool0_g@000000000B9`0gooo
0?oog`2LB7@0_ooo0?ooo`3OW4P0001d0;ooo`3oool0gia80000M02oool0oooo0=nLB00007@0_ooo
0?noM0000000M;oo0?ooo`3ogi`0B000001d_`3o_kl0_ooo0=nLB00007@0_ooo0=no_`3Oool0gia8
00000018W=l0oooo0?oog`2LB000B9cO0P3oool00`3OW4P0001d0;ooo`060?ooo`030;md00000000
M;oo00@0oooo00T0oono07@0000007@0_ooo0?ooo`3ooml0W4P00018W03Oool03`3oool00`3ogi`0
B00007Boo`040?ooo`070?oo_`1d0000M;oo0?ooo`3o_g@0001d0;ooo`020?ooo`030?noM0000000
M;oo06X0oooo002n0?ooo`050?oog`2LB00004RL09adM02oool00P3oool01`3o_g@0001809cOo`3o
ool0oooO09a80000M;l00P3oool01`3OW4P004RL0=ooo`3oool0oooO09a80000M;l01@3oool00`3o
gi`0B00004RLg`020?ooo`070?oog`2LB00007Bo0?ooo`3ogi`0B00004RLg`030?ooo`060?oOW01d
W=l0oooo0=nLB00007@0_ooo1`3oool00`3ooml0W4P0001d_`070?ooo`030?oOW018000007Bo00<0
oooo00L0okmd0000M02oool0oooo0=nLB00007@0_ooo00D0oooo00<0omnL04P00000M;l00`3oool0
1@3o_g@0001d0;ooo`3ookl0_koo0080oooo00H0okmd0000001d_ol0omnL04P00000M;l30?ooo`0E
0?oOW02L_ol0oooo0=nLB00007@0_ooo0?ooo`3OW4P0001d0;ooo`3oool0gia80000M02oool0okmd
0000B02Lgol0oooo0?oog`2LB00007Bo0080oooo00L0gia80018W03Oool0oooo0?oOW018000007Bo
00<0oooo00L0okmd0000M02oool0oooo0=nLB00007@0_ooo00d0oooo00@0oono07@00000B9`0gooo
0P3oool01@3ooml0W4P007Boo`3ooml0W4P000P0000000<0B9cO0?ooo`3oool00P3oool00`3ogi`0
B00007Boo`040?ooo`030;md0000B9`0gooo0080oooo00<0_g@0001d_`3oool0KP3oool00;h0oooo
00D0omnL04P0001d_ol0okmd04RLg`030?ooo`060?noM000000007Bo0?oog`2LB00007Bo0P3oool0
1`3OW4P004RL0=ooo`3oool0oooO09a80000M;l01@3oool00`3o_g@0000007Boo`020?ooo`070?oo
g`2LB00007Bo0?ooo`3o_g@0001809cOo`060?ooo`030=nLB00007@0_ooo00L0oooo00<0oooO09a8
0000M;l01`3oool00`3o_g@0000007Boo`030?ooo`070?noM0000000M;oo0?ooo`3OW4P0001d0;oo
o`050?ooo`030?noM0000000M;oo00<0oooo00<0okmd0000001d_ol00P3oool0203ookl0M0000000
000007@0_ooo0?noM00004P0W=oo1P3oool04P3OW4P0001d0;ooo`3oool0gia80000M02oool0oooo
0=nLB00007@0_ooo0?ooo`3o_g@00000001d_`3ooml0W4P0001d_`80oooo00L0gia80018W03Oool0
oooo0?noM0000000M;oo00<0oooo00L0okmd0000001d_ol0oooo0=nLB00007@0_ooo00h0oooo00<0
omnL04P00018W=l0503oool00`3ogi`0B00007Boo`030?ooo`030?oo_`1d0000B9cO00<0oooo00<0
gia80000M02oool0KP3oool00;h0oooo00H0_g@00018W03Oool0oooO09a8M02oool40?ooo`040?no
M00000000000001d_`80oooo00L0gia80018W03Oool0oooo0?oog`2LB00007Bo00D0oooo00<0okmd
0000001d_ol00P3oool01`3ooml0W4P0001d_`3oool0okmd0000M02oool01P3oool00`3OW4P0001d
0;ooo`070?ooo`030?oog`2LB00007Bo00L0oooo00<0okmd0000001d_ol00`3oool01`3o_g@00000
07Boo`3oool0gia80000M02oool01@3oool00`3o_g@0000007Boo`030?ooo`050?noM0000000M;oo
0?ooo`2oM0000P0000001P18W=l0oooo0?ooo`3o_g@0001d0;ooo`H0oooo00/0gia80000M02oool0
oooo0=nLB00007@0_ooo0?ooo`3OW4P0001d0;ooo`030?ooo`040?noM00000000000001d_`80oooo
00L0gia80018W03Oool0oooo0?noM0000000M;oo00<0oooo00L0okmd0000001d_ol0oooo0=nLB000
07@0_ooo0100oooo00D0gia8000000000000001d0;ooo`0@0?ooo`030?oOW0180000M;oo00<0oooo
00<0omnL04P0001d_ol00`3oool00`3o_g@0001809cOo`1^0?ooo`00_@3oool00`3ogi`0B00007Bo
o`020?ooo`0:0?noM018W=l0oooo0?oo_`1d0000M;oo0?ooo`3ooml0W4P0001d_`80oooo00L0_g@0
0000M02oool0oooo0?oog`2LB00007Bo00D0oooo00<0oono07@00018W=l00P3oool01P3ooml0W4P0
001d_`3oool0omnL04P000D0000000D0B9cO0?ooo`3OW4P0001809cOo`070?ooo`030?oog`2LB000
000000@0000000H0M;oo0?ooo`3oool0oono07@0001d_ol30?ooo`070;md000004P0W=oo0?ooo`3O
W4P0001d0;ooo`050?ooo`030?oo_`1d0000M;oo00<0oooo00H0_g@00000B02Lgol0omnL04P00018
W=l20?ooo`050;nLW03Oool0omnL04P0B02Lgol00P3oool05P3o_g@0001809cOo`3oool0gia80000
M02oool0oooo0=nLB00007@0_ooo0?ooo`3OW4P0001d0;ooo`3ookl0M00007Boo`3oool0oooO09a8
0000M;l20?ooo`070=nLB000B9`0gooo0?ooo`3ookl0M00007Boo`030?ooo`070;md000004P0W=oo
0?ooo`3OW4P0001809cOo`0?0?ooo`030=nLB00004P0W=oo01<0oooo00<0omnL04P0001d_ol00`3o
ool00`3ogi`0B00007Boo`030?ooo`030?noM00004P0W=oo06h0oooo002l0?ooo`040?oog`2LB000
001d0;ooo`80oooo01<0oooO09a8M02oool0oono07@00018W=l0oooo0?oo_`1d000007Bo0?oog`2L
B00000000018B01804P0W=oo0?oo_`1d0000B9cO00H0oooo00L0okmd0000B02Lgol0oooo0?noM000
000007Bo0080oooo00h0_g@004RLg`3oool0oooo0=nLB00004P0W=oO09a800000000001804QdW03O
_g@0001d0;ooo`@0oooo00<0oooO09a80000M;l00P3oool0103ooml0W4P000000018W=l20?ooo`07
0=nLB000B9`0gooo0?ooo`3o_g@00000001d_`020?ooo`030=nLB00007@0_ooo00H0oooo02X0gia8
0018W03Oool0oooo0?noM000000007Bo0?ooo`3ookl0M01d0;ooo`3oool0okmd0018W03Oool0oooo
0;md0000B9`0gooo0?oog`2LB000001d0;oog`2LB00000000000M02oool0oooo0=nLB00007@0_ooo
0?ooo`3OW4P0001d0;ooo`3ookl0M00004RLg`3oool0oono07@00000M;l20?ooo`030=nLB000B9`0
gooo0080oooo00l0gia80018W03Oool0oooo0?noM000000007Bo0?oog`2LB00000000000B018M9`0
gkmd0000M02oool0303oool00`3o_g@00000001d_`020?ooo`040=nLB00004P0W=oO09a800P00000
00<0B9cO0?ooo`3oool00P3oool00`3ogi`0B00007Boo`030?ooo`030?oOW0180000M;oo00<0oooo
00<0okmd0000B02Lgol0KP3oool00;/0oooo00d0oooO09a80000000000000000M02oool0oooO09a8
0000000004RL0=ooo`3ookl0M0000080000000/0001d0;ooo`3oool0oooo0;md0000B9`0gooO09a8
00000000001d0;ooo`070?ooo`030?noM000000000000080000000D007Bo0?ooo`3oool0oooo0=nL
B0020000000:0000B02Lgol0oooo0?ooo`2oM000001d0;oOW0180000001d0;ooo`@0oooo00<0oooO
09a80000M;l00`3oool0103ookl0M0000000M02oool20?ooo`050?noM0000000000000000018W=l0
0`3oool00`3OW4P0001d0;ooo`070?ooo`050?noM0000000000000000018W=l00`3oool01P3o_g@0
000000000000M;l0_ibL0=ooo`80oooo00D0gia8000000000000001809cOo`020?ooo`0>0;md0000
07@0_ooo0?ooo`3OW4P0001d0;ooo`3oool0gia80000M02oool0oooo0?oo_`1d0002000000040000
M02oool0oooo0;md00<0000000@004RL0=ooo`3oool0okmd0`0000002P18W=l0oooo0?ooo`3oool0
_g@00000M02ogi`0B0000000M02oool=0?ooo`030?oOW018000000000080000000<0B9cO0?ooo`3o
ool03@3oool00`3ogi`0B00007Boo`030?ooo`030?oOW0180000M;oo00<0oooo00<0okmd0000B02L
gol0KP3oool00=l0oooo00<0oooO09a80000M;l0503oool00`3ooml0W4P0001d_`030?ooo`040?oo
g`2LB000001809cOo`X0oooo00<0gia80000M02oool08P3oool01`3OW4P0001d0;ooo`3oool0gia8
0000M02oool02@3oool00`2oM00004RL0=ooo`0c0?ooo`030?oOW0180000M;oo00<0oooo00<0oono
07@00018W=l00`3oool00`3OW4P0001d0;ooo`1^0?ooo`00g`3oool00`3ooml0W4P0001d_`0D0?oo
o`030?oog`2LB00007Bo00<0oooo00@0omnL04P0000007@0_ooo2P3oool00`3OW4P0001d0;ooo`0R
0?ooo`070=nLB00007@0_ooo0?ooo`3OW4P0001d0;ooo`090?ooo`030?oo_`1dB9`0gooo03<0oooo
00<0omnL04P0001d_ol0103oool00`3OW4P004RL0=ooo`020?ooo`030;md0000M;l0oooo06h0oooo
003O0?ooo`030?oog`2LB00007Bo01@0oooo00<0oooO09a80000M;l00P3oool0103ookl0M0000000
0018W=l;0?ooo`030=nLB00007@0_ooo0280oooo00L0gia80000M02oool0oooo0=nLB00007@0_ooo
00T0oooo00<0oooO09adW03Oool0<@3oool01@3ooml0W4P0000000000000M;oo00@0oooo00L0oono
07@0001d_ol0oooo0?noM00007@0_ooo06l0oooo003N0?ooo`040?oo_`1d00000000001d_a<0oooo
00<0_g@0000000000000100000000`0004P0W=oo0?ooo`090?ooo`050?oog`2LB00000000000M02o
ool07P3oool02`3OW4P0001809cOg`2LB00000000000M02ooml0W4P00000000007@0_ooo03l0oooo
00<0okmd0000001d_ol01@3oool01@3ookl0M0000000000007@0_ooo0700oooo003O0?ooo`030?oo
g`2LB00007Bo02P0oooo00<0_g@00000M02oool07P3oool02`3OW4P0001809cOo`3oool0_g@00000
M02oool0oooo0;md000007@0_ooo0;`0oooo003o0?oooo<0oooo003o0?oooo<0oooo003o0?oooo<0
oooo003o0?oooo<0oooo0000\
\>"],
  ImageRangeCache->{{{0, 497.375}, {307.063, 0}} -> {-85.7967, -7.59112, \
1.21962, 0.0461996}}]
}, Closed]],

Cell["\<\
Notice that peaks occur at the odd harmonics.  Why?  [Hint: consider the \
Fourier transform of the differential equation.]  Observations of this kind \
can give insight into the dynamics responsible for observed motions.\
\>", "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Compare spectra for ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyEpsilon] \[Rule] 0.1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyEpsilon] \[Rule] 10\)]],
  ".  Interpret you results."
}], "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Spectral analysis of logistic map", "Section"],

Cell[TextData[{
  "Recall that the logistic map, ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(n + 1\) = \[Mu]\ \(\(x\_n\)(1 - x\_n)\)\)]],
  ", is a population model for species with nonoverlapping generations.  The \
behavior of this model is strongly affected by the growth parameter \[Mu].  \
For some ranges of \[Mu] the behavior is periodic in the sense that a \
sequence of points is visited in each cycle, while for other ranges the \
system is chaotic.  Fourier analysis of sequences ",
  Cell[BoxData[
      \(TraditionalForm\`{x\_n}\)]],
  " shows strikingly different characteristics for these types of behavior."
}], "Text"],

Cell["\<\
The following function is designed to display a power spectrum for the \
logistic map after the initial transients have been allowed to decay.  The \
zero-frequency mode is omitted also.\
\>", "Text"],

Cell[BoxData[
    \(logisticPower[\[Mu]_, n_, ndrop_, opts___Rule] := 
      Module[{sample}, 
        sample = 
          Drop[Fourier[\ 
              Drop[NestList[\[Mu]  #\ \((1 - #)\) &, 0.5, n + ndrop], 
                ndrop]\ ], 1]; 
        LogListPlot[\ sample\ Conjugate[sample]\ , opts, 
          PlotLabel \[Rule] "\<\[Mu]=\>" <> ToString[\[Mu]]]]\)], "Input"],

Cell[TextData[{
  "We studied the behavior of the logistic map in ",
  StyleBox[ButtonBox["logistic map.nb",
    ButtonData:>{"Applications/logistic map.nb", None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " and ",
  StyleBox[ButtonBox["cobweb.nb",
    ButtonData:>{"Applications/cobweb.nb", None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  ".  The next few examples illustrate the spectral properties of some of the \
characteristic behaviors.  Be sure to use enough points to sample the \
frequencies well and to drop enough starting points to suppress transients \
\[LongDash] some experimentation may be needed."
}], "Text"],

Cell[TextData[{
  "We found that for ",
  Cell[BoxData[
      \(TraditionalForm\`1 < \[Mu] < 3\)]],
  " there is a stable fixed point.  Frequency analysis of a fixed point is \
not very interesting!"
}], "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`3 < \[Mu] < 3.45\)]],
  " there is a 2-cycle \[LongDash] display a spectrum for \[Mu]~3.2.  Why is \
it peaked in the center?"
}], "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`3.45 < \[Mu] < 3.54\)]],
  " there is a 4-cycle \[LongDash] display a spectrum for \
\[Mu]\[TildeTilde]3.5."
}], "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Display a spectrum for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu] \[TildeTilde] 3.55\)]],
  " where there is an 8-cycle."
}], "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "As ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\)]],
  " continues to increase, period doublings become increasingly dense until \
chaos reigns.  Display a spectrum for \[Mu]=3.6."
}], "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "However, order miraculously reappears near ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu] \[TildeTilde] 3.83\)]],
  " when a 3-cycle becomes possible, but dissolves unto chaos again quite \
quickly.  Display spectra for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu] = 3.83\)]],
  ", 3.845, 3.85, and 3.86."
}], "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Within chaotic regions there are also some narrow slices of order.  \
Inspection of the logistic map figure suggest that \[Mu]=3.74 is one such \
value \[LongDash] verify with a frequency spectrum and determine the cycle \
length.  How far away is chaos from there?  Find another orderly slice and \
display its spectrum.\
\>", "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Some practical considerations", "Section"],

Cell[CellGroupData[{

Cell["Normalization and phase conventions", "Subsection"],

Cell[TextData[{
  "Many conventions for the normalization and phase of Fourier series and for \
the normalization of the power spectrum exist in the technical literature.  \
Some authors prefer to use positive imaginary arguments of the exponential in \
the series for ",
  Cell[BoxData[
      \(TraditionalForm\`x\_m\)]],
  " so that ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\&~\)\_k\)]],
  " is the complex conjugate of the present definition.  Others omit the ",
  Cell[BoxData[
      \(TraditionalForm\`n\^\(\(-1\)/2\)\)]],
  " factor in ",
  Cell[BoxData[
      \(TraditionalForm\`x\_m\)]],
  " so that ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\&~\)\_k\)]],
  " has a factor of ",
  Cell[BoxData[
      \(TraditionalForm\`n\^\(-1\)\)]],
  ", rather than the more symmetric choice of ",
  Cell[BoxData[
      \(TraditionalForm\`n\^\(\(-1\)/2\)\)]],
  " for both used by ",
  StyleBox["Mathematica.  ",
    FontSlant->"Italic"],
  "Still others put a factor of ",
  Cell[BoxData[
      \(TraditionalForm\`n\^\(-1\)\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`x\_m\)]],
  " while omitting ",
  Cell[BoxData[
      \(TraditionalForm\`n\^\(\(-1\)/2\)\)]],
  " from ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\&~\)\_k\)]],
  ".  Many employ frequencies ",
  Cell[BoxData[
      \(TraditionalForm
      \`{\[Nu]\_k, \(-n\)\/\(2\ T\), \ n\/\(2  T\), \ 1\/T}\)]],
  " instead of the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " choice ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Nu]\_k, 0, \(n - 1\)\/T, 1\/T}\)]],
  ".  All possible choices of normalization, phase, and grid conventions \
appear with similar frequency \[LongDash] you just have to cope with it!"
}], "Text"],

Cell[TextData[{
  "Similarly, there are several possible normalization of the power spectrum. \
 The most appropriate definition for applications to physical systems depends \
upon the physical meaning of the displacement and time variables and their \
relationship to the energy and power associated with a period oscillation.  \
For other applications the definition is more a matter of convenience.  The \
fundamental relationship between power in the time and frequency domains is \
",
  StyleBox["Parseval's theorem",
    FontSlant->"Italic"],
  ", which for Fourier series states"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[Sum]\+\(m = 1\)\%n\[LeftBracketingBar]x\_m\
\[RightBracketingBar]\^2 = \[Sum]\+\(k = 1\)\%n\[LeftBracketingBar]x\&~\_k\
\[RightBracketingBar]\^2\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "using the symmetric normalization convention.  Recognizing that for a \
sinusoidal oscillation with unit amplitude the average of ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]x\^2\[RightBracketingBar]\)]],
  " over a period is ",
  Cell[BoxData[
      \(TraditionalForm\`1/2\)]],
  ", the sum on the left-hand side reduces to ",
  Cell[BoxData[
      \(TraditionalForm\`n/2\)]],
  " for a unit sinusoid.  Thus, if we employ units of power for which a unit \
sinusoid has average power ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  ",  we should define ",
  Cell[BoxData[
      \(TraditionalForm\`P\_k = \(2\/n\) \[Rho]\ \[LeftBracketingBar]x\&~\_k\
\[RightBracketingBar]\^2\)]],
  ".  Of course, in the absence of a physical relationship or after \
nondimensionalization of expressions, we normally choose \[Rho]\[Rule]1."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Fast Fourier Transform", "Subsection"],

Cell[TextData[{
  "Direct computation of Fourier series using naive implementation of the \
definitions given in the introduction is quite inefficient, scaling with ",
  Cell[BoxData[
      \(TraditionalForm\`n\^2\)]],
  ".  You probably noticed that the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function was much faster than the inverse transformation you performed in \
one of the first exercises in this notebook.  All modern Fourier \
transformations use some variation of the fast Fourier transform (FFT) \
algorithm, pioneered by Cooley and Tukey in the mid-1960's, which reduces the \
computation time to ",
  Cell[BoxData[
      \(TraditionalForm\`n\ Log[2, n]\)]],
  " in the same units.  For large ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " the reduction factor"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(n\ Log[2, n]/n\^2\  /. n \[Rule] 10\^6\  // N\)], "Input"],

Cell[BoxData[
    \(0.000019931568569324173`\)], "Output"]
}, Closed]],

Cell[TextData[{
  "can be critically important.  FFT implementations are generally most \
efficient when ",
  Cell[BoxData[
      \(TraditionalForm\`n \[Rule] 2\^k\)]],
  " is an integral power of two and will usually subdivide a data set that \
does not satisfy this criterion so that the transforms of subsets can be \
computed and combined with maximum efficiency. "
}], "Text"],

Cell[TextData[{
  "Construct a data set containing 8192 points of a sinusoidal function and \
then evaluate ",
  StyleBox["Timing[Fourier[", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["data", "InlineInput"],
  StyleBox["];]", "InlineInput",
    FontWeight->"Bold"],
  ".  [We recommend a sinusoidal function to ensure reasonable function \
values and to avoid complications due to extremely small or extremely large \
numbers.]  Next, use ",
  StyleBox["Drop", "InlineInput",
    FontWeight->"Bold"],
  " to make a slightly shorter data set containing 8191 points and repeat the \
timing evaluation.  You will probably find that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " requires approximately 300 times as much time to compute the Fourier \
transform of 8191 points as it needs for 8192 points!  Not only is 8191 not \
an integral power of two, it is prime, which defeats the FFT algorithm and \
makes it hardly more efficient than naive summation.  Finally, you will find \
that transforming 8190 points is about 150 times faster than 8191 points but \
remains 2 times slower than 8192 points.  Therefore, although ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does not restrict the number of points, its Fourier transforms are most \
efficient for integral powers of two and it is often advantageous to pad \
shorter data lists with zeros.  Above all, avoid data sets with prime \
length."
}], "Text",
  CellDingbat->"\[FilledDownTriangle]",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Discretization", "Subsection"],

Cell[TextData[{
  "The discrete Fourier transform is often, if not usually, employed as an \
approximation to the continuous Fourier transform of nonperiodic functions.  \
In addition to problems associated with the implicit periodicity of Fourier \
series, the discretization of a continuous function distorts the Fourier \
transform and its power spectrum.  More sophisticated estimates of the power \
spectrum attempt to correct for discretization and edge effects using ",
  StyleBox["windowing",
    FontSlant->"Italic"],
  " functions and digital ",
  StyleBox["filters",
    FontSlant->"Italic"],
  ".  We will return to these issues after studying Fourier transforms and \
convolution techniques."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Aliasing", "Subsection"],

Cell[TextData[{
  "Parseval's theorem",
  StyleBox[" tells us that the total power in the frequency domain is equal \
to the total power in the time domain \[LongDash] in other words, that the \
Fourier transform conserves power.  If we know that our signal is ",
    FontSlant->"Plain"],
  "bandwidth limited",
  StyleBox[", meaning that all frequency components outside the sampling \
range vanish, then the total Fourier in the discrete Fourier series will be \
the same as that of the continuous Fourier transform.  For electronic signals \
bandwidth limitations can be imposed using electronic filters, but it is more \
difficult to impose such limitations on time series for dynamical systems.  \
However, if the input signal is not bandwidth limited, any power at \
frequencies greater than the Nyquist critical frequency, ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\_c = 1\/\(2  T\)\)]],
  ",",
  StyleBox[" will appear in the discrete power spectrum at lower frequencies. \
 This artificial difference between the continuous and discrete power spectra \
is an error in the discrete approximation known as the ",
    FontSlant->"Plain"],
  "aliasing problem",
  StyleBox[" because high frequencies are aliased to lower frequencies.  \
Often there is little one can do about the aliasing problem except to employ \
greater sampling rates for signals whose Fourier amplitudes remain \
appreciable near the Nyquist frequency.",
    FontSlant->"Plain"]
}], "Text",
  FontSlant->"Italic"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 952}},
WindowToolbars->"EditBar",
WindowSize->{1392, 912},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowCellLabel->False,
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->PaperWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}, {
        Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {0, 0}},
    CellGroupingRules->"TitleGrouping",
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    ShowCellBracket->True,
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{9, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->0.5,
    CellMargins->{{25, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.700008, 0.4]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{25, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{25, 0}, {6, 6}}],
  
  Cell[StyleData["Input", "Printout"],
    CellFrame->0.5,
    CellMargins->{{25, 0}, {6, 6}},
    Background->None]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->True,
    CellMargins->{{25, 10}, {8, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{25, Inherited}, {12, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{10, 4}, {2, 10}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{12, 10}, {2, 12}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {1, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->9],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{9, 0}, {4, 12}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    CellMargins->{{10, 10}, {40, 2}},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{12, 10}, {50, 2}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Example",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Definition",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Definition", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Theorem",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Theorem", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.4]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caution"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Caution",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.996109, 0, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Caution", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Caution", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Caution", "Printout"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Advice"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Advice",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0, 1, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Advice", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Advice", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Advice", "Printout"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->"NormalGrouping",
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseMain"],
    CellFrame->{{6, 0}, {0, 1}},
    CellMargins->{{12, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseMain", "Presentation"],
    CellMargins->{{18, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["ExerciseMain", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["ExerciseMain", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseTitle"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseTitle", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["ExerciseTitle", "Condensed"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["ExerciseTitle", "Printout"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{32, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExcersiceText",
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{32, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{32, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{32, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Problem"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Problem", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Problem", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Problem", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{12, 10}, {Inherited, 6}},
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{13, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{62, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{74, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    CellMargins->{{52, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"]],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"]],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 99, 2, 81, "Title"],
Cell[1878, 57, 455, 15, 85, "Author"],

Cell[CellGroupData[{
Cell[2358, 76, 31, 0, 83, "Section"],
Cell[2392, 78, 485, 12, 67, "Text"],
Cell[2880, 92, 282, 6, 77, "DisplayFormula",
  Evaluatable->False],
Cell[3165, 100, 25, 0, 41, "Text"],
Cell[3193, 102, 287, 6, 77, "DisplayFormula",
  Evaluatable->False],
Cell[3483, 110, 926, 24, 98, "Text"],
Cell[4412, 136, 1034, 15, 171, "Text"],
Cell[5449, 153, 189, 4, 41, "Text"],
Cell[5641, 159, 249, 6, 60, "DisplayFormula",
  Evaluatable->False],
Cell[5893, 167, 843, 19, 119, "Text"],
Cell[6739, 188, 1338, 44, 99, "Text"],
Cell[8080, 234, 1061, 17, 171, "Text"],
Cell[9144, 253, 443, 10, 79, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9624, 268, 33, 0, 51, "Section"],
Cell[9660, 270, 223, 4, 125, "Input"],
Cell[9886, 276, 125, 2, 99, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[10048, 283, 33, 0, 51, "Section"],
Cell[10084, 285, 955, 24, 100, "Text"],
Cell[11042, 311, 372, 7, 151, "Input"],
Cell[11417, 320, 1526, 28, 530, "Input"],
Cell[12946, 350, 845, 15, 307, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[13828, 370, 60, 0, 51, "Section"],
Cell[13891, 372, 324, 5, 67, "Text"],
Cell[14218, 379, 422, 10, 41, "Text"],
Cell[14643, 391, 579, 15, 67, "Text"],
Cell[15225, 408, 142, 2, 41, "Text"],
Cell[15370, 412, 287, 6, 77, "DisplayFormula",
  Evaluatable->False],
Cell[15660, 420, 605, 11, 93, "Text"],

Cell[CellGroupData[{
Cell[16290, 435, 40, 0, 68, "Subsection"],
Cell[16333, 437, 49, 0, 41, "Text"],
Cell[16385, 439, 130, 2, 74, "Input"],
Cell[16518, 443, 455, 8, 68, "Text"],
Cell[16976, 453, 305, 8, 42, "Text"],
Cell[17284, 463, 465, 11, 67, "Text"],
Cell[17752, 476, 275, 6, 41, "Text"],
Cell[18030, 484, 514, 14, 68, "Text"],
Cell[18547, 500, 309, 8, 42, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[18893, 513, 40, 0, 68, "Subsection"],
Cell[18936, 515, 141, 5, 41, "Text"],
Cell[19080, 522, 85, 1, 96, "Input"],
Cell[19168, 525, 464, 10, 67, "Text"],
Cell[19635, 537, 501, 13, 67, "Text"],
Cell[20139, 552, 159, 2, 41, "Text"],
Cell[20301, 556, 222, 6, 83, "DisplayFormula",
  Evaluatable->False],
Cell[20526, 564, 338, 8, 41, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[20901, 577, 34, 0, 68, "Subsection"],
Cell[20938, 579, 127, 3, 41, "Text"],
Cell[21068, 584, 132, 2, 73, "Input"],
Cell[21203, 588, 225, 5, 41, "Text"],
Cell[21431, 595, 174, 2, 41, "Text"],
Cell[21608, 599, 225, 5, 41, "Text"],
Cell[21836, 606, 333, 6, 67, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[22206, 617, 27, 0, 68, "Subsection"],
Cell[22236, 619, 799, 19, 119, "Text"],
Cell[23038, 640, 146, 2, 99, "Input"],
Cell[23187, 644, 220, 7, 41, "Text"],
Cell[23410, 653, 111, 2, 73, "Input"],
Cell[23524, 657, 239, 5, 41, "Text"],
Cell[23766, 664, 358, 8, 125, "Input"],

Cell[CellGroupData[{
Cell[24149, 676, 122, 2, 73, "Input"],
Cell[24274, 680, 88005, 1941, 279, 19955, 1096, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[112294, 2624, 234, 5, 41, "Text"],
Cell[112531, 2631, 299, 6, 41, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[112867, 2642, 37, 0, 68, "Subsection"],
Cell[112907, 2644, 201, 4, 41, "Text"],
Cell[113111, 2650, 236, 5, 41, "Text"],
Cell[113350, 2657, 241, 5, 41, "Text"],
Cell[113594, 2664, 196, 4, 41, "Text"],
Cell[113793, 2670, 224, 5, 41, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[114066, 2681, 62, 0, 51, "Section"],
Cell[114131, 2683, 290, 7, 42, "Text"],
Cell[114424, 2692, 1076, 23, 99, "Input"],
Cell[115503, 2717, 620, 12, 94, "Text"],
Cell[116126, 2731, 721, 12, 177, "Input"],
Cell[116850, 2745, 195, 4, 41, "Text"],

Cell[CellGroupData[{
Cell[117070, 2753, 126, 2, 74, "Input"],
Cell[117199, 2757, 86478, 2113, 321, 28941, 1398, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[203692, 4873, 343, 6, 67, "Text"],
Cell[204038, 4881, 339, 10, 41, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[204414, 4896, 52, 0, 51, "Section"],
Cell[204469, 4898, 640, 12, 93, "Text"],
Cell[205112, 4912, 210, 4, 41, "Text"],
Cell[205325, 4918, 374, 8, 125, "Input"],
Cell[205702, 4928, 711, 17, 68, "Text"],
Cell[206416, 4947, 309, 8, 41, "Text"],
Cell[206728, 4957, 303, 8, 41, "Text"],
Cell[207034, 4967, 285, 8, 41, "Text"],
Cell[207322, 4977, 257, 7, 41, "Text"],
Cell[207582, 4986, 314, 8, 41, "Text"],
Cell[207899, 4996, 442, 11, 67, "Text"],
Cell[208344, 5009, 443, 8, 67, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[208824, 5022, 48, 0, 51, "Section"],

Cell[CellGroupData[{
Cell[208897, 5026, 57, 0, 68, "Subsection"],
Cell[208957, 5028, 1716, 52, 151, "Text"],
Cell[210676, 5082, 598, 11, 93, "Text"],
Cell[211277, 5095, 276, 6, 77, "DisplayFormula",
  Evaluatable->False],
Cell[211556, 5103, 884, 21, 98, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[212477, 5129, 44, 0, 68, "Subsection"],
Cell[212524, 5131, 823, 19, 119, "Text"],

Cell[CellGroupData[{
Cell[213372, 5154, 78, 1, 74, "Input"],
Cell[213453, 5157, 58, 1, 59, "Output"]
}, Closed]],
Cell[213526, 5161, 381, 8, 67, "Text"],
Cell[213910, 5171, 1540, 31, 199, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[215487, 5207, 36, 0, 68, "Subsection"],
Cell[215526, 5209, 717, 14, 119, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[216280, 5228, 30, 0, 68, "Subsection"],
Cell[216313, 5230, 1522, 29, 203, "Text"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

