(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    310888,      12389]*)
(*NotebookOutlinePosition[    344812,      13612]*)
(*  CellTagsIndexPosition[    344768,      13608]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["H\[EAcute]non Map", "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "from ",
  StyleBox[ButtonBox["Essential Mathematica for Students of Science",
    Active->False,
    ButtonData:>{
      URL[ 
      "http://www.physics.umd.edu/courses/CourseWare/EssentialMathematica/"], 
      None},
    Active->False,
    ButtonStyle->"Hyperlink"],
    Active->False],
  "\n\[Copyright] James J. Kelly, 1998\nLast revised: January, 2006"
}], "Author",
  Active->True,
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell["\<\
In 1974 the French astronomer M. H\[EAcute]non map discovered a simple \
two-dimensional map\
\>", "Text"],

Cell[BoxData[{
    \(TraditionalForm\`x\_\(n + 1\) = 1 + y\_n - a\ x\_n\^2\), "\n", 
    \(TraditionalForm\`y\_\(n + 1\) = b\ x\_n\)}], "DisplayFormula",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "which, for appropriate choices of the parameters ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  ", possesses a ",
  StyleBox["strange attractor",
    FontSlant->"Italic"],
  ".  The sequence of points ",
  Cell[BoxData[
      \(TraditionalForm\`{x\_0, y\_0}\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`{x\_1, y\_1}\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`{x\_2, y\_2}\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`{x\_3, y\_3}\)]],
  ", \[CenterEllipsis] is called the ",
  StyleBox["orbit",
    FontSlant->"Italic"],
  " of the initial point.  When the map possesses a strange attractor, one \
finds that orbits either diverge to infinity or quickly approach a confined \
set that has the appearance of a complicated two-dimensional curve with many \
folds.  Nevertheless, the system exhibits ",
  StyleBox["deterministic chaos",
    FontSlant->"Italic"],
  ".  Although the attractor appears to follow a smooth curve, the system \
point hops around the attractor quite erratically as the map is iterated.  \
Furthermore, although two nearby initial points may both approach the \
attractor, their orbits rapidly diverge from each other \[LongDash] the \
Euclidean distance between points on two orbits increases rapidly as the \
iteration proceeds and then fluctuates erratically as each points hops around \
the attractor with very different sequences.  The attractor itself also \
exhibits the fractal property of self-similarity, with similar structure \
appearing at any level of magnification."
}], "Text"],

Cell[CellGroupData[{

Cell["References", "Subsubsection"],

Cell[TextData[{
  "R.L. Devaney, in ",
  StyleBox["The Science of Fractal Images",
    FontSlant->"Italic"],
  ", edited by H.O. Peitgen and D. Saupe, (Springer-Verlag, N.Y., 1988), p. \
135 ff."
}], "Text",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "M. H\[EAcute]non, Commun. Math. Phys. ",
  StyleBox["50",
    FontWeight->"Bold"],
  ", 69 (1976)."
}], "Text",
  CellMargins->{{30, Inherited}, {Inherited, Inherited}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[BoxData[{
    \(\(ClearAll["\<Global`*\>"];\)\), "\n", 
    \(Off[General::spell, \ General::spell1]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Implementation", "Section"],

Cell[BoxData[
    \(\(henon[{a_, b_}]\)[{x_, y_}] := {1 + y - a\ x\^2, b\ x}\)], "Input"],

Cell[BoxData[
    \(henonMap[{a_, b_}, {x0_, y0_}, n_] := 
      NestList[henon[{a, b}], {x0, y0}, n]\)], "Input"],

Cell[BoxData[{
    \(\(distance[{x1_, y1_}, {x2_, 
            y2_}] := \@\(\((x1 - x2)\)\^2 + \((y1 - y2)\)\^2\);\)\), "\n", 
    \(distance[list1 : {{_, _} .. }, list2 : {{_, _} .. }] := 
      MapThread[distance, {list1, list2}]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Characteristic behavior", "Section"],

Cell["\<\
Below we construct a set for the H\[EAcute]non map and then compare the first \
few iterations, shown as red points, with the attractor itself after allowing \
transients to decay.\
\>", "Text"],

Cell[BoxData[
    \(\(data = henonMap[{1.4, 0.3}, {0, 0}, 100000];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[{ListPlot[Take[data, 20], PlotRange \[Rule] All, 
            PlotStyle \[Rule] RGBColor[1, 0, 0], 
            DisplayFunction \[Rule] Identity], \n\t\tListPlot[
            Take[data, {100, 10000}], PlotRange \[Rule] All, 
            PlotStyle \[Rule] PointSize[0.001], 
            DisplayFunction \[Rule] Identity]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.502174 0.372376 0.31036 0.767137 [
[.1298 .29786 -6 -9 ]
[.1298 .29786 6 0 ]
[.31599 .29786 -12 -9 ]
[.31599 .29786 12 0 ]
[.68836 .29786 -9 -9 ]
[.68836 .29786 9 0 ]
[.87455 .29786 -3 -9 ]
[.87455 .29786 3 0 ]
[.48967 .00351 -24 -4.5 ]
[.48967 .00351 0 4.5 ]
[.48967 .15693 -24 -4.5 ]
[.48967 .15693 0 4.5 ]
[.48967 .46379 -18 -4.5 ]
[.48967 .46379 0 4.5 ]
[.48967 .61722 -18 -4.5 ]
[.48967 .61722 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1298 .31036 m
.1298 .31661 L
s
[(-1)] .1298 .29786 0 1 Mshowa
.31599 .31036 m
.31599 .31661 L
s
[(-0.5)] .31599 .29786 0 1 Mshowa
.68836 .31036 m
.68836 .31661 L
s
[(0.5)] .68836 .29786 0 1 Mshowa
.87455 .31036 m
.87455 .31661 L
s
[(1)] .87455 .29786 0 1 Mshowa
.125 Mabswid
.16704 .31036 m
.16704 .31411 L
s
.20427 .31036 m
.20427 .31411 L
s
.24151 .31036 m
.24151 .31411 L
s
.27875 .31036 m
.27875 .31411 L
s
.35322 .31036 m
.35322 .31411 L
s
.39046 .31036 m
.39046 .31411 L
s
.4277 .31036 m
.4277 .31411 L
s
.46494 .31036 m
.46494 .31411 L
s
.53941 .31036 m
.53941 .31411 L
s
.57665 .31036 m
.57665 .31411 L
s
.61389 .31036 m
.61389 .31411 L
s
.65112 .31036 m
.65112 .31411 L
s
.7256 .31036 m
.7256 .31411 L
s
.76284 .31036 m
.76284 .31411 L
s
.80007 .31036 m
.80007 .31411 L
s
.83731 .31036 m
.83731 .31411 L
s
.09256 .31036 m
.09256 .31411 L
s
.05532 .31036 m
.05532 .31411 L
s
.01808 .31036 m
.01808 .31411 L
s
.91179 .31036 m
.91179 .31411 L
s
.94903 .31036 m
.94903 .31411 L
s
.98626 .31036 m
.98626 .31411 L
s
.25 Mabswid
0 .31036 m
1 .31036 L
s
.50217 .00351 m
.50842 .00351 L
s
[(-0.4)] .48967 .00351 1 0 Mshowa
.50217 .15693 m
.50842 .15693 L
s
[(-0.2)] .48967 .15693 1 0 Mshowa
.50217 .46379 m
.50842 .46379 L
s
[(0.2)] .48967 .46379 1 0 Mshowa
.50217 .61722 m
.50842 .61722 L
s
[(0.4)] .48967 .61722 1 0 Mshowa
.125 Mabswid
.50217 .04186 m
.50592 .04186 L
s
.50217 .08022 m
.50592 .08022 L
s
.50217 .11858 m
.50592 .11858 L
s
.50217 .19529 m
.50592 .19529 L
s
.50217 .23365 m
.50592 .23365 L
s
.50217 .272 m
.50592 .272 L
s
.50217 .34872 m
.50592 .34872 L
s
.50217 .38707 m
.50592 .38707 L
s
.50217 .42543 m
.50592 .42543 L
s
.50217 .50214 m
.50592 .50214 L
s
.50217 .5405 m
.50592 .5405 L
s
.50217 .57886 m
.50592 .57886 L
s
.25 Mabswid
.50217 0 m
.50217 .61803 L
s
1 0 0 r
.008 w
.50217 .31036 Mdot
.87455 .31036 Mdot
.35322 .5405 Mdot
.90285 .2183 Mdot
.22629 .55799 Mdot
.70859 .13985 Mdot
.63159 .43793 Mdot
.8735 .39035 Mdot
.39498 .53985 Mdot
.94275 .24411 Mdot
.11263 .58265 Mdot
.43622 .06961 Mdot
.74133 .2696 Mdot
.63973 .45817 Mdot
.87516 .39537 Mdot
.39278 .54088 Mdot
.94145 .24275 Mdot
.11625 .58185 Mdot
.44639 .07185 Mdot
.74708 .27589 Mdot
0 g
.001 w
.97453 .31294 Mdot
.03696 .60229 Mdot
.20258 .02284 Mdot
.39753 .1252 Mdot
.7435 .24568 Mdot
.6242 .45951 Mdot
.89096 .38578 Mdot
.34287 .55064 Mdot
.89577 .2119 Mdot
.24431 .55362 Mdot
.74264 .15099 Mdot
.57979 .45898 Mdot
.92404 .35833 Mdot
.22871 .57109 Mdot
.71996 .14135 Mdot
.61418 .44496 Mdot
.89272 .37959 Mdot
.33472 .55173 Mdot
.88629 .20687 Mdot
.26961 .54775 Mdot
.78644 .16663 Mdot
.50098 .48604 Mdot
.95982 .30962 Mdot
.08676 .5932 Mdot
.36306 .05362 Mdot
.67716 .22438 Mdot
.71769 .41851 Mdot
.75243 .44356 Mdot
.70375 .46502 Mdot
.79685 .43494 Mdot
.60855 .49248 Mdot
.92041 .3761 Mdot
.24882 .56885 Mdot
.75869 .15378 Mdot
.55116 .46889 Mdot
.94248 .34064 Mdot
.16036 .58249 Mdot
.56737 .09911 Mdot
.75602 .35066 Mdot
.65184 .46725 Mdot
.86649 .40286 Mdot
.42045 .53552 Mdot
.95874 .25986 Mdot
.06634 .59253 Mdot
.29736 .041 Mdot
.58609 .18378 Mdot
.78663 .36223 Mdot
.59551 .48616 Mdot
.92713 .36805 Mdot
.2236 .573 Mdot
.71028 .13819 Mdot
.62815 .43898 Mdot
.87731 .38822 Mdot
.38325 .54221 Mdot
.93392 .23686 Mdot
.13805 .5772 Mdot
.50561 .08532 Mdot
.76527 .31248 Mdot
.61534 .47296 Mdot
.90533 .3803 Mdot
.29743 .55952 Mdot
.83789 .18382 Mdot
.3894 .51784 Mdot
.92745 .24066 Mdot
.16075 .5732 Mdot
.56386 .09935 Mdot
.75781 .34849 Mdot
.64736 .46835 Mdot
.872 .40009 Mdot
.4039 .53892 Mdot
.94919 .24963 Mdot
.09381 .58663 Mdot
.38168 .05798 Mdot
.69745 .23589 Mdot
.69503 .43105 Mdot
.7933 .42955 Mdot
.61376 .49029 Mdot
.91507 .37933 Mdot
.26706 .56555 Mdot
.79059 .16505 Mdot
.49127 .48861 Mdot
.96063 .30362 Mdot
.08108 .5937 Mdot
.34541 .05011 Mdot
.65583 .21348 Mdot
.73875 .40533 Mdot
.71022 .45658 Mdot
.7828 .43894 Mdot
.64089 .4838 Mdot
.8864 .39609 Mdot
.36114 .54782 Mdot
.91504 .2232 Mdot
.19138 .56552 Mdot
.63526 .11828 Mdot
.71472 .39261 Mdot
.74463 .44172 Mdot
.71731 .46021 Mdot
.77328 .44332 Mdot
.66276 .47791 Mdot
.85893 .40961 Mdot
.44422 .53085 Mdot
.96895 .27454 Mdot
.03802 .59884 Mdot
.20461 .0235 Mdot
.40241 .12645 Mdot
.74786 .2487 Mdot
.61768 .4622 Mdot
.89809 .38175 Mdot
.31988 .55505 Mdot
.86838 .19769 Mdot
.31566 .53669 Mdot
.85362 .19509 Mdot
.35422 .52757 Mdot
.89769 .21892 Mdot
.24204 .5548 Mdot
.73879 .14959 Mdot
.58602 .4566 Mdot
.9191 .36218 Mdot
.24616 .56804 Mdot
.75321 .15214 Mdot
.56081 .46551 Mdot
.93694 .3466 Mdot
.1815 .57906 Mdot
.61837 .11217 Mdot
.72759 .38217 Mdot
.71838 .44967 Mdot
.76644 .44398 Mdot
.67686 .47368 Mdot
.83911 .41832 Mdot
.50015 .5186 Mdot
.97561 .30911 Mdot
.03124 .60296 Mdot
.18276 .0193 Mdot
.34968 .11295 Mdot
.6913 .21612 Mdot
.69432 .42725 Mdot
.79248 .42912 Mdot
.61535 .48978 Mdot
.91349 .3803 Mdot
.27245 .56457 Mdot
.79953 .16838 Mdot
.4732 .49414 Mdot
.9606 .29245 Mdot
.07575 .59368 Mdot
.32843 .04682 Mdot
.63313 .20298 Mdot
.75795 .3913 Mdot
.66788 .46844 Mdot
.84805 .41277 Mdot
.47451 .52412 Mdot
.97543 .29326 Mdot
.02419 .60285 Mdot
.15755 .01495 Mdot
.28464 .09737 Mdot
.59326 .17592 Mdot
.7781 .36665 Mdot
.61563 .48089 Mdot
.90893 .38048 Mdot
.28655 .56175 Mdot
.82178 .1771 Mdot
.42583 .50789 Mdot
.94852 .26318 Mdot
.10264 .58622 Mdot
.40831 .06343 Mdot
.72157 .25235 Mdot
.66543 .44595 Mdot
.84017 .41126 Mdot
.49403 .51925 Mdot
.9757 .30533 Mdot
.0291 .60301 Mdot
.17521 .01799 Mdot
.33069 .10828 Mdot
.6659 .20438 Mdot
.72232 .41155 Mdot
.74146 .44642 Mdot
.72532 .45825 Mdot
.75912 .44827 Mdot
.69327 .46916 Mdot
.81433 .42847 Mdot
.56552 .50329 Mdot
.95311 .34951 Mdot
.12906 .58905 Mdot
.48643 .07976 Mdot
.76168 .30063 Mdot
.61663 .47075 Mdot
.90315 .3811 Mdot
.30442 .55818 Mdot
.84781 .18814 Mdot
.36608 .52397 Mdot
.90861 .22625 Mdot
.21267 .56155 Mdot
.68137 .13143 Mdot
.66697 .42111 Mdot
.8262 .41221 Mdot
.52926 .51062 Mdot
.969 .3271 Mdot
.06335 .59887 Mdot
.29062 .03915 Mdot
.57465 .17962 Mdot
.79134 .35515 Mdot
.58192 .48907 Mdot
.93739 .35965 Mdot
.18636 .57934 Mdot
.63013 .11518 Mdot
.71825 .38944 Mdot
.73741 .4439 Mdot
.73133 .45574 Mdot
.74769 .45199 Mdot
.71667 .4621 Mdot
.77522 .44293 Mdot
.65859 .47912 Mdot
.86448 .40703 Mdot
.42797 .53428 Mdot
.96254 .2645 Mdot
.05548 .59488 Mdot
.26249 .03429 Mdot
.52455 .16223 Mdot
.80076 .32419 Mdot
.54608 .4949 Mdot
.95688 .33749 Mdot
.11039 .59138 Mdot
.43387 .06822 Mdot
.73947 .26814 Mdot
.64235 .45702 Mdot
.87186 .397 Mdot
.40278 .53884 Mdot
.94831 .24893 Mdot
.09642 .58609 Mdot
.38941 .05959 Mdot
.70502 .24067 Mdot
.68603 .43573 Mdot
.80832 .42399 Mdot
.57733 .49957 Mdot
.94515 .35681 Mdot
.15934 .58414 Mdot
.56554 .09847 Mdot
.7566 .34952 Mdot
.65019 .46761 Mdot
.86851 .40184 Mdot
.4144 .53677 Mdot
.95548 .25611 Mdot
.07565 .59052 Mdot
.32657 .04675 Mdot
.63066 .20183 Mdot
.7598 .38977 Mdot
.66355 .46958 Mdot
.85392 .4101 Mdot
.45779 .52775 Mdot
.97267 .28293 Mdot
.02898 .60114 Mdot
.17387 .01791 Mdot
.32736 .10746 Mdot
.66117 .20232 Mdot
.72707 .40862 Mdot
.7321 .44935 Mdot
.74327 .45246 Mdot
.72499 .45936 Mdot
.76022 .44807 Mdot
.69105 .46984 Mdot
.81783 .42709 Mdot
.5566 .50545 Mdot
.95811 .344 Mdot
.10932 .59215 Mdot
.43109 .06756 Mdot
.7377 .26643 Mdot
.64467 .45592 Mdot
.86887 .39843 Mdot
.41176 .53699 Mdot
.95382 .25448 Mdot
.0805 .5895 Mdot
.34156 .04975 Mdot
.65106 .21109 Mdot
.74303 .40238 Mdot
.70112 .45922 Mdot
.798 .43331 Mdot
.60521 .49319 Mdot
.92339 .37404 Mdot
.23842 .57069 Mdot
.73936 .14735 Mdot
.58391 .45695 Mdot
.92059 .36087 Mdot
.24086 .56896 Mdot
.74335 .14886 Mdot
.57748 .45941 Mdot
.92558 .3569 Mdot
.22314 .57204 Mdot
.70885 .13791 Mdot
.63025 .43809 Mdot
.87488 .38952 Mdot
.39073 .5407 Mdot
.93966 .24148 Mdot
.12153 .58074 Mdot
.46106 .07511 Mdot
.754 .28495 Mdot
.62379 .466 Mdot
.89449 .38552 Mdot
.33238 .55283 Mdot
.88385 .20542 Mdot
.27591 .54625 Mdot
.79658 .17052 Mdot
.4808 .49231 Mdot
.96115 .29715 Mdot
.07612 .59403 Mdot
.32979 .04704 Mdot
.63501 .20382 Mdot
.7565 .39246 Mdot
.67123 .46754 Mdot
.8434 .41484 Mdot
.48751 .52125 Mdot
.97611 .3013 Mdot
.02568 .60327 Mdot
.16311 .01587 Mdot
.29938 .10081 Mdot
.61822 .18503 Mdot
.76308 .38208 Mdot
.65343 .47161 Mdot
.86681 .40384 Mdot
.42004 .53572 Mdot
.95858 .2596 Mdot
.06676 .59243 Mdot
.29869 .04126 Mdot
.58826 .1846 Mdot
.78564 .36356 Mdot
.59827 .48556 Mdot
.92488 .36975 Mdot
.23162 .5716 Mdot
.72615 .14315 Mdot
.60477 .44879 Mdot
.90217 .37377 Mdot
.30381 .55757 Mdot
.84661 .18776 Mdot
.36901 .52323 Mdot
.91121 .22806 Mdot
.20556 .56316 Mdot
.6665 .12705 Mdot
.68405 .41192 Mdot
.79949 .42276 Mdot
.59678 .49411 Mdot
.9301 .36883 Mdot
.21447 .57483 Mdot
.69174 .13255 Mdot
.65314 .42752 Mdot
.84573 .40366 Mdot
.47608 .52269 Mdot
.97506 .29423 Mdot
.02599 .60262 Mdot
.16393 .01607 Mdot
.30156 .10131 Mdot
.62176 .18637 Mdot
.7606 .38427 Mdot
.65935 .47007 Mdot
.8592 .4075 Mdot
.44247 .53101 Mdot
.96826 .27346 Mdot
.03992 .59842 Mdot
.21102 .02467 Mdot
.41716 .13042 Mdot
.76003 .25782 Mdot
.59907 .46973 Mdot
.91661 .37024 Mdot
.25787 .5665 Mdot
.77448 .15937 Mdot
.52248 .47866 Mdot
.95469 .32291 Mdot
.11077 .59003 Mdot
.43433 .06846 Mdot
.73982 .26843 Mdot
.64186 .45724 Mdot
.87248 .39669 Mdot
.4009 .53922 Mdot
.94708 .24777 Mdot
.09997 .58533 Mdot
.39984 .06179 Mdot
.71451 .24711 Mdot
.67433 .44159 Mdot
.82682 .41676 Mdot
.52995 .511 Mdot
.96904 .32752 Mdot
.0634 .5989 Mdot
.2908 .03918 Mdot
.57494 .17972 Mdot
.79123 .35533 Mdot
.58225 .48901 Mdot
.93716 .35985 Mdot
.18719 .5792 Mdot
.63204 .11569 Mdot
.71665 .39062 Mdot
.74057 .44291 Mdot
.72523 .45769 Mdot
.75901 .44822 Mdot
.69346 .46909 Mdot
.81403 .42858 Mdot
.5663 .5031 Mdot
.95265 .34999 Mdot
.13086 .58877 Mdot
.49134 .08088 Mdot
.76271 .30366 Mdot
.61609 .47138 Mdot
.90392 .38076 Mdot
.30191 .55866 Mdot
.84429 .18659 Mdot
.37444 .5218 Mdot
.91584 .23142 Mdot
.19288 .56602 Mdot
.63899 .11921 Mdot
.71139 .39492 Mdot
.75103 .43966 Mdot
.70448 .46416 Mdot
.79534 .43539 Mdot
.61211 .49155 Mdot
.91706 .37831 Mdot
.26039 .56677 Mdot
.77923 .16093 Mdot
.51343 .48159 Mdot
.95719 .31732 Mdot
.09953 .59158 Mdot
.40154 .06151 Mdot
.71569 .24817 Mdot
.67297 .44232 Mdot
.82893 .41592 Mdot
.52437 .51231 Mdot
.97073 .32408 Mdot
.05581 .59994 Mdot
.26605 .03449 Mdot
.53102 .16443 Mdot
.80058 .32819 Mdot
.54842 .49479 Mdot
.95603 .33894 Mdot
.11398 .59086 Mdot
.44415 .07044 Mdot
.74543 .2745 Mdot
.63467 .4607 Mdot
.88153 .39225 Mdot
.37324 .54482 Mdot
.92586 .23068 Mdot
.16098 .57221 Mdot
.56397 .09949 Mdot
.75783 .34855 Mdot
.64736 .46837 Mdot
.872 .40009 Mdot
.40388 .53893 Mdot
.94918 .24961 Mdot
.09384 .58662 Mdot
.38178 .058 Mdot
.69756 .23596 Mdot
.69491 .43111 Mdot
.79351 .42948 Mdot
.61327 .49042 Mdot
.91555 .37902 Mdot
.26543 .56584 Mdot
.78785 .16405 Mdot
.49671 .48692 Mdot
.96014 .30698 Mdot
.08439 .5934 Mdot
.35572 .05216 Mdot
.66858 .21985 Mdot
.72651 .4132 Mdot
.73527 .44901 Mdot
.73758 .45442 Mdot
.73613 .45585 Mdot
.73939 .45495 Mdot
.73318 .45697 Mdot
.74508 .45313 Mdot
.72201 .46049 Mdot
.76573 .44623 Mdot
.67936 .47324 Mdot
.83558 .41987 Mdot
.50978 .51642 Mdot
.97436 .31506 Mdot
.0386 .60218 Mdot
.20825 .02385 Mdot
.41068 .12871 Mdot
.7549 .25381 Mdot
.60698 .46655 Mdot
.90907 .37513 Mdot
.28352 .56184 Mdot
.81687 .17522 Mdot
.43662 .50485 Mdot
.9528 .26985 Mdot
.09143 .58886 Mdot
.37543 .0565 Mdot
.69093 .23203 Mdot
.70257 .42702 Mdot
.7802 .43421 Mdot
.64406 .48219 Mdot
.88227 .39805 Mdot
.37395 .54527 Mdot
.92676 .23111 Mdot
.15831 .57277 Mdot
.55737 .09784 Mdot
.75993 .34447 Mdot
.64132 .46967 Mdot
.87909 .39635 Mdot
.38218 .54331 Mdot
.93349 .2362 Mdot
.13914 .57693 Mdot
.50844 .08599 Mdot
.76549 .31423 Mdot
.61575 .4731 Mdot
.90505 .38055 Mdot
.29841 .55935 Mdot
.83931 .18443 Mdot
.3861 .51872 Mdot
.92504 .23862 Mdot
.16746 .5717 Mdot
.5802 .10349 Mdot
.75125 .35858 Mdot
.66472 .4643 Mdot
.84994 .41082 Mdot
.46862 .52529 Mdot
.97465 .28963 Mdot
.02522 .60237 Mdot
.16102 .01558 Mdot
.29388 .09951 Mdot
.60909 .18163 Mdot
.76908 .37644 Mdot
.63878 .47532 Mdot
.88446 .39479 Mdot
.36609 .54663 Mdot
.91961 .22625 Mdot
.1786 .56835 Mdot
.60614 .11038 Mdot
.73684 .37462 Mdot
.69871 .45539 Mdot
.79973 .43182 Mdot
.60063 .49426 Mdot
.92737 .37121 Mdot
.22436 .57315 Mdot
.71194 .13866 Mdot
.62578 .44 Mdot
.88004 .38675 Mdot
.37483 .54389 Mdot
.92694 .23166 Mdot
.158 .57288 Mdot
.55663 .09765 Mdot
.76015 .34402 Mdot
.64068 .4698 Mdot
.87982 .39596 Mdot
.37992 .54376 Mdot
.93165 .2348 Mdot
.1444 .57579 Mdot
.52216 .08925 Mdot
.76572 .32271 Mdot
.61942 .47324 Mdot
.90193 .38282 Mdot
.30891 .55742 Mdot
.85405 .19092 Mdot
.35106 .52783 Mdot
.89426 .21697 Mdot
.25123 .55269 Mdot
.75542 .15527 Mdot
.55814 .46688 Mdot
.93875 .34495 Mdot
.17476 .58018 Mdot
.60248 .10801 Mdot
.7385 .37236 Mdot
.69467 .45642 Mdot
.80613 .42933 Mdot
.58496 .49821 Mdot
.93997 .36152 Mdot
.17878 .58093 Mdot
.6127 .1105 Mdot
.7316 .37867 Mdot
.70981 .45215 Mdot
.78129 .43869 Mdot
.64395 .48286 Mdot
.88271 .39798 Mdot
.37266 .54554 Mdot
.92565 .23032 Mdot
.16149 .57208 Mdot
.56522 .0998 Mdot
.7574 .34932 Mdot
.64856 .4681 Mdot
.87056 .40083 Mdot
.40825 .53803 Mdot
.9519 .25232 Mdot
.08597 .58831 Mdot
.35819 .05313 Mdot
.67175 .22137 Mdot
.72325 .41516 Mdot
.74168 .44699 Mdot
.72521 .45838 Mdot
.75937 .44821 Mdot
.69277 .46932 Mdot
.81514 .42815 Mdot
.56348 .50378 Mdot
.95431 .34825 Mdot
.12438 .58979 Mdot
.47357 .07687 Mdot
.75814 .29268 Mdot
.61965 .46855 Mdot
.89945 .38297 Mdot
.31641 .55589 Mdot
.864 .19555 Mdot
.32662 .53398 Mdot
.86723 .20186 Mdot
.32084 .53598 Mdot
.86045 .19829 Mdot
.33756 .53179 Mdot
.88015 .20862 Mdot
.28803 .54396 Mdot
.81554 .17801 Mdot
.44112 .50403 Mdot
.95455 .27263 Mdot
.08686 .58994 Mdot
.36178 .05368 Mdot
.67585 .22359 Mdot
.71903 .4177 Mdot
.74985 .44438 Mdot
.70897 .46343 Mdot
.78807 .43817 Mdot
.62929 .48705 Mdot
.89957 .38892 Mdot
.31894 .55597 Mdot
.86754 .19712 Mdot
.31769 .53617 Mdot
.8562 .19634 Mdot
.34798 .52916 Mdot
.89137 .21506 Mdot
.2588 .5509 Mdot
.76863 .15995 Mdot
.53461 .47504 Mdot
.95053 .3304 Mdot
.1285 .58746 Mdot
.48408 .07941 Mdot
.76122 .29918 Mdot
.61684 .47046 Mdot
.90283 .38123 Mdot
.30543 .55798 Mdot
.84922 .18877 Mdot
.3627 .52485 Mdot
.90553 .22416 Mdot
.22102 .55965 Mdot
.69837 .1366 Mdot
.64548 .43162 Mdot
.8562 .39893 Mdot
.44634 .52916 Mdot
.96904 .27585 Mdot
.03835 .5989 Mdot
.20578 .0237 Mdot
.40513 .12718 Mdot
.75023 .25038 Mdot
.61411 .46367 Mdot
.90186 .37954 Mdot
.30752 .55738 Mdot
.85201 .19006 Mdot
.35604 .52657 Mdot
.89921 .22004 Mdot
.23805 .55574 Mdot
.73139 .14712 Mdot
.59779 .45202 Mdot
.90894 .36945 Mdot
.28116 .56176 Mdot
.81293 .17376 Mdot
.44518 .50242 Mdot
.95557 .27514 Mdot
.08461 .59057 Mdot
.35503 .05229 Mdot
.66787 .21942 Mdot
.72718 .41277 Mdot
.73392 .44942 Mdot
.74013 .45359 Mdot
.73118 .45743 Mdot
.74876 .4519 Mdot
.71464 .46276 Mdot
.7788 .44167 Mdot
.65059 .48133 Mdot
.87472 .40209 Mdot
.39727 .54061 Mdot
.94494 .24552 Mdot
.10604 .584 Mdot
.4174 .06553 Mdot
.72869 .25797 Mdot
.65621 .45035 Mdot
.85329 .40556 Mdot
.45725 .52736 Mdot
.9723 .2826 Mdot
.03013 .60091 Mdot
.17783 .01862 Mdot
.33742 .1099 Mdot
.67519 .20854 Mdot
.71257 .41729 Mdot
.76002 .4404 Mdot
.68771 .46972 Mdot
.82249 .42503 Mdot
.54447 .50833 Mdot
.96392 .3365 Mdot
.08565 .59573 Mdot
.36081 .05294 Mdot
.67446 .22299 Mdot
.72054 .41684 Mdot
.74696 .44532 Mdot
.71478 .46165 Mdot
.77805 .44176 Mdot
.6522 .48086 Mdot
.87269 .40308 Mdot
.40341 .53935 Mdot
.94904 .24932 Mdot
.09417 .58654 Mdot
.38276 .0582 Mdot
.69854 .23656 Mdot
.69375 .43172 Mdot
.79547 .42876 Mdot
.6086 .49163 Mdot
.91996 .37614 Mdot
.25026 .56856 Mdot
.7613 .15467 Mdot
.54653 .47051 Mdot
.94489 .33777 Mdot
.15097 .58398 Mdot
.54364 .0933 Mdot
.76273 .33599 Mdot
.63176 .47139 Mdot
.88958 .39045 Mdot
.34915 .54979 Mdot
.90274 .21579 Mdot
.2254 .55792 Mdot
.70672 .13931 Mdot
.63421 .43678 Mdot
.87037 .39197 Mdot
.40448 .53792 Mdot
.94913 .24998 Mdot
.09419 .58659 Mdot
.38283 .05821 Mdot
.69861 .2366 Mdot
.69368 .43176 Mdot
.7956 .42872 Mdot
.60829 .49171 Mdot
.92024 .37595 Mdot
.24928 .56874 Mdot
.75953 .15407 Mdot
.54968 .46941 Mdot
.94327 .33972 Mdot
.1573 .58297 Mdot
.55972 .09722 Mdot
.75864 .34593 Mdot
.64453 .46886 Mdot
.8753 .39834 Mdot
.39382 .54097 Mdot
.94235 .2434 Mdot
.11359 .5824 Mdot
.43892 .0702 Mdot
.74293 .27127 Mdot
.63765 .45916 Mdot
.87778 .39409 Mdot
.38479 .5425 Mdot
.93543 .23782 Mdot
.13361 .57813 Mdot
.49382 .08258 Mdot
.76372 .3052 Mdot
.61486 .472 Mdot
.90527 .38001 Mdot
.29747 .55949 Mdot
.83793 .18384 Mdot
.3893 .51787 Mdot
.92738 .2406 Mdot
.16095 .57315 Mdot
.56436 .09947 Mdot
.75764 .34879 Mdot
.64783 .46825 Mdot
.87142 .40038 Mdot
.40564 .53857 Mdot
.95029 .2507 Mdot
.09063 .58731 Mdot
.37221 .05601 Mdot
.68758 .23004 Mdot
.70632 .42495 Mdot
.77349 .43653 Mdot
.65904 .47804 Mdot
.86343 .40731 Mdot
.43096 .53363 Mdot
.96386 .26635 Mdot
.05181 .5957 Mdot
.25049 .03202 Mdot
.50129 .15481 Mdot
.79904 .30981 Mdot
.54294 .49384 Mdot
.95736 .33556 Mdot
.1078 .59168 Mdot
.42637 .06662 Mdot
.73463 .26351 Mdot
.64865 .45403 Mdot
.86363 .40089 Mdot
.4273 .53375 Mdot
.96191 .26409 Mdot
.05746 .59449 Mdot
.26893 .03551 Mdot
.5366 .16621 Mdot
.80012 .33164 Mdot
.55113 .4945 Mdot
.95492 .34061 Mdot
.11857 .59018 Mdot
.45714 .07328 Mdot
.75185 .28253 Mdot
.62668 .46467 Mdot
.89117 .38731 Mdot
.343 .55077 Mdot
.89599 .21198 Mdot
.24371 .55375 Mdot
.74154 .15062 Mdot
.58159 .4583 Mdot
.92265 .35944 Mdot
.23367 .57023 Mdot
.72965 .14442 Mdot
.59945 .45095 Mdot
.90721 .37048 Mdot
.28694 .56069 Mdot
.82189 .17734 Mdot
.42567 .50796 Mdot
.94846 .26308 Mdot
.10278 .58618 Mdot
.40872 .06352 Mdot
.7219 .2526 Mdot
.66501 .44616 Mdot
.84078 .411 Mdot
.49234 .51963 Mdot
.97577 .30428 Mdot
.02834 .60306 Mdot
.17253 .01752 Mdot
.32386 .10663 Mdot
.65611 .20015 Mdot
.73196 .4055 Mdot
.72221 .45238 Mdot
.76146 .44635 Mdot
.6878 .47061 Mdot
.8228 .42508 Mdot
.54375 .50852 Mdot
.96424 .33605 Mdot
.08432 .59593 Mdot
.35674 .05211 Mdot
.66968 .22048 Mdot
.72544 .41388 Mdot
.7374 .44834 Mdot
.73351 .45574 Mdot
.74391 .45333 Mdot
.72424 .45976 Mdot
.76167 .44761 Mdot
.688 .47074 Mdot
.82257 .42521 Mdot
.54437 .50837 Mdot
.96397 .33644 Mdot
.08543 .59577 Mdot
.36012 .0528 Mdot
.67366 .22257 Mdot
.72137 .41635 Mdot
.74536 .44583 Mdot
.71797 .46066 Mdot
.77242 .44373 Mdot
.6647 .47738 Mdot
.85631 .41081 Mdot
.4518 .52923 Mdot
.97125 .27923 Mdot
.03219 .60027 Mdot
.18482 .01989 Mdot
.35492 .11423 Mdot
.69782 .21935 Mdot
.68646 .43128 Mdot
.80556 .42426 Mdot
.58379 .49786 Mdot
.94052 .3608 Mdot
.17663 .58127 Mdot
.60762 .10916 Mdot
.73509 .37553 Mdot
.70223 .45431 Mdot
.79396 .434 Mdot
.61448 .49069 Mdot
.91466 .37977 Mdot
.26855 .56529 Mdot
.79309 .16597 Mdot
.48628 .49016 Mdot
.96087 .30054 Mdot
.07873 .59385 Mdot
.33804 .04866 Mdot
.64623 .20892 Mdot
.74729 .39939 Mdot
.69188 .46185 Mdot
.81279 .4276 Mdot
.56873 .50233 Mdot
.95108 .35149 Mdot
.13689 .5878 Mdot
.50755 .0846 Mdot
.76485 .31368 Mdot
.61674 .47271 Mdot
.904 .38117 Mdot
.30186 .55871 Mdot
.84424 .18656 Mdot
.37454 .52177 Mdot
.91592 .23148 Mdot
.19266 .56607 Mdot
.6385 .11907 Mdot
.71182 .39461 Mdot
.7502 .43993 Mdot
.70617 .46365 Mdot
.7925 .43644 Mdot
.61884 .48979 Mdot
.91048 .38246 Mdot
.28277 .56271 Mdot
.81607 .17476 Mdot
.4383 .50436 Mdot
.95338 .27088 Mdot
.08998 .58922 Mdot
.37113 .05561 Mdot
.68633 .22937 Mdot
.70773 .42418 Mdot
.77094 .4374 Mdot
.66464 .47647 Mdot
.85594 .41077 Mdot
.45277 .529 Mdot
.9715 .27982 Mdot
.03159 .60042 Mdot
.1828 .01953 Mdot
.34989 .11297 Mdot
.69154 .21624 Mdot
.69404 .4274 Mdot
.79296 .42894 Mdot
.6142 .49008 Mdot
.9146 .3796 Mdot
.26866 .56525 Mdot
.79328 .16604 Mdot
.4859 .49027 Mdot
.96089 .3003 Mdot
.07858 .59386 Mdot
.33756 .04856 Mdot
.64559 .20862 Mdot
.74783 .399 Mdot
.69069 .46219 Mdot
.81464 .42687 Mdot
.56404 .50347 Mdot
.9539 .3486 Mdot
.12594 .58954 Mdot
.47788 .07784 Mdot
.75946 .29535 Mdot
.61839 .46937 Mdot
.90096 .38218 Mdot
.31151 .55682 Mdot
.85751 .19252 Mdot
.34263 .52997 Mdot
.88546 .21176 Mdot
.27438 .54724 Mdot
.79444 .16958 Mdot
.48506 .49099 Mdot
.96113 .29978 Mdot
.07748 .59401 Mdot
.33414 .04789 Mdot
.64099 .20651 Mdot
.75169 .39615 Mdot
.68212 .46457 Mdot
.82767 .42157 Mdot
.53021 .51153 Mdot
.96924 .32769 Mdot
.06278 .59902 Mdot
.28882 .0388 Mdot
.57159 .1785 Mdot
.79243 .35326 Mdot
.57864 .48975 Mdot
.93964 .35762 Mdot
.17797 .58073 Mdot
.61063 .10999 Mdot
.73307 .37739 Mdot
.70665 .45306 Mdot
.78663 .43673 Mdot
.63169 .48616 Mdot
.89682 .3904 Mdot
.32785 .55427 Mdot
.8787 .20262 Mdot
.28925 .54306 Mdot
.81706 .17877 Mdot
.43788 .50497 Mdot
.95348 .27063 Mdot
.08952 .58928 Mdot
.36973 .05533 Mdot
.68481 .22851 Mdot
.70941 .42324 Mdot
.76787 .43844 Mdot
.67131 .47457 Mdot
.84671 .41489 Mdot
.47901 .52329 Mdot
.97589 .29605 Mdot
.0239 .60313 Mdot
.15667 .01477 Mdot
.28227 .09683 Mdot
.5891 .17445 Mdot
.78017 .36408 Mdot
.61007 .48217 Mdot
.91418 .37704 Mdot
.26871 .565 Mdot
.79323 .16607 Mdot
.48602 .49024 Mdot
.96089 .30038 Mdot
.07861 .59386 Mdot
.33767 .04859 Mdot
.64574 .20869 Mdot
.74771 .39909 Mdot
.69097 .46211 Mdot
.8142 .42704 Mdot
.56514 .50321 Mdot
.95325 .34927 Mdot
.12845 .58914 Mdot
.48477 .07939 Mdot
.76129 .2996 Mdot
.61689 .47051 Mdot
.90281 .38126 Mdot
.30552 .55796 Mdot
.84934 .18882 Mdot
.36241 .52492 Mdot
.90527 .22398 Mdot
.22175 .55948 Mdot
.69982 .13705 Mdot
.64356 .43251 Mdot
.85869 .39774 Mdot
.43909 .5307 Mdot
.96655 .27138 Mdot
.04489 .59736 Mdot
.2277 .02774 Mdot
.45412 .14072 Mdot
.78353 .28066 Mdot
.56253 .48425 Mdot
.94526 .34766 Mdot
.15454 .5842 Mdot
.55312 .09551 Mdot
.7605 .34185 Mdot
.63894 .47002 Mdot
.88172 .39489 Mdot
.37398 .54493 Mdot
.92663 .23113 Mdot
.15875 .57269 Mdot
.55847 .09811 Mdot
.75961 .34515 Mdot
.64228 .46946 Mdot
.87798 .39695 Mdot
.38562 .54262 Mdot
.93621 .23832 Mdot
.1313 .57861 Mdot
.48763 .08115 Mdot
.76249 .30137 Mdot
.61541 .47125 Mdot
.90444 .38035 Mdot
.30015 .55897 Mdot
.84179 .18551 Mdot
.38031 .52026 Mdot
.9206 .23504 Mdot
.17975 .56896 Mdot
.60924 .11109 Mdot
.73473 .37653 Mdot
.70335 .45409 Mdot
.79216 .43469 Mdot
.61875 .48958 Mdot
.91045 .38241 Mdot
.28282 .56269 Mdot
.81613 .17479 Mdot
.43816 .5044 Mdot
.95333 .2708 Mdot
.0901 .58919 Mdot
.3715 .05569 Mdot
.68673 .2296 Mdot
.70729 .42442 Mdot
.77173 .43713 Mdot
.66291 .47696 Mdot
.85828 .4097 Mdot
.44599 .53045 Mdot
.96952 .27564 Mdot
.03655 .59919 Mdot
.19966 .02259 Mdot
.39079 .12339 Mdot
.73716 .24152 Mdot
.63354 .45559 Mdot
.88016 .39155 Mdot
.3768 .54397 Mdot
.92885 .23288 Mdot
.15248 .57406 Mdot
.54279 .09424 Mdot
.76344 .33547 Mdot
.63011 .47183 Mdot
.89139 .38943 Mdot
.34337 .55091 Mdot
.89651 .21222 Mdot
.24229 .55407 Mdot
.73892 .14974 Mdot
.58585 .45668 Mdot
.91925 .36208 Mdot
.24566 .56813 Mdot
.75229 .15183 Mdot
.5624 .46494 Mdot
.93595 .34758 Mdot
.18519 .57845 Mdot
.62693 .11446 Mdot
.72094 .38746 Mdot
.73205 .44557 Mdot
.74152 .45243 Mdot
.72814 .45828 Mdot
.75438 .45002 Mdot
.7032 .46623 Mdot
.79828 .4346 Mdot
.60521 .49337 Mdot
.92347 .37404 Mdot
.23817 .57073 Mdot
.73889 .1472 Mdot
.58467 .45666 Mdot
.91998 .36135 Mdot
.24301 .56858 Mdot
.74737 .15019 Mdot
.57076 .4619 Mdot
.93043 .35275 Mdot
.20561 .57503 Mdot
.67236 .12707 Mdot
.67668 .41554 Mdot
.81111 .41821 Mdot
.56808 .50129 Mdot
.9509 .35109 Mdot
.13729 .58769 Mdot
.50862 .08485 Mdot
.76493 .31434 Mdot
.61691 .47275 Mdot
.90388 .38127 Mdot
.30229 .55863 Mdot
.84485 .18683 Mdot
.3731 .52215 Mdot
.91472 .23059 Mdot
.19597 .56533 Mdot
.6458 .12111 Mdot
.70513 .39913 Mdot
.76277 .43579 Mdot
.68011 .47142 Mdot
.83369 .42033 Mdot
.51473 .51525 Mdot
.97341 .31812 Mdot
.04343 .6016 Mdot
.22471 .02684 Mdot
.44748 .13888 Mdot
.78006 .27656 Mdot
.56782 .4821 Mdot
.94172 .35093 Mdot
.16789 .58201 Mdot
.58628 .10376 Mdot
.74767 .36234 Mdot
.6732 .46208 Mdot
.83823 .41606 Mdot
.50128 .51805 Mdot
.97536 .30981 Mdot
.03247 .60281 Mdot
.18704 .02007 Mdot
.36028 .1156 Mdot
.70431 .22266 Mdot
.67836 .43529 Mdot
.81849 .41925 Mdot
.55124 .50585 Mdot
.96039 .34069 Mdot
.09988 .59355 Mdot
.40356 .06173 Mdot
.7173 .24941 Mdot
.67098 .44331 Mdot
.83196 .41469 Mdot
.5163 .51418 Mdot
.97274 .31909 Mdot
.0463 .60118 Mdot
.23437 .02861 Mdot
.46816 .14485 Mdot
.78986 .28934 Mdot
.55319 .48816 Mdot
.95107 .34189 Mdot
.13225 .58779 Mdot
.49474 .08173 Mdot
.76336 .30576 Mdot
.61583 .47179 Mdot
.90434 .38061 Mdot
.30058 .55891 Mdot
.8424 .18577 Mdot
.37887 .52063 Mdot
.91946 .23415 Mdot
.18291 .56826 Mdot
.61652 .11304 Mdot
.72961 .38103 Mdot
.71437 .45093 Mdot
.7735 .4415 Mdot
.66144 .47805 Mdot
.86058 .40879 Mdot
.43938 .53187 Mdot
.96725 .27155 Mdot
.04253 .59779 Mdot
.21975 .02628 Mdot
.43677 .13581 Mdot
.77374 .26994 Mdot
.57766 .4782 Mdot
.9346 .35701 Mdot
.19418 .57761 Mdot
.64764 .12001 Mdot
.7026 .40026 Mdot
.76717 .43423 Mdot
.67067 .47414 Mdot
.84731 .4145 Mdot
.47725 .52367 Mdot
.97576 .29496 Mdot
.02386 .60305 Mdot
.15648 .01475 Mdot
.28177 .09671 Mdot
.58821 .17415 Mdot
.7806 .36354 Mdot
.60892 .48244 Mdot
.91524 .37633 Mdot
.26509 .56565 Mdot
.78714 .16383 Mdot
.49812 .48648 Mdot
.95998 .30786 Mdot
.08537 .5933 Mdot
.35876 .05276 Mdot
.67218 .22172 Mdot
.72286 .41543 Mdot
.74244 .44675 Mdot
.72372 .45885 Mdot
.7621 .44728 Mdot
.68701 .471 Mdot
.82408 .4246 Mdot
.54043 .50931 Mdot
.96562 .334 Mdot
.07852 .59679 Mdot
.33881 .04853 Mdot
.64711 .20939 Mdot
.74656 .39994 Mdot
.69349 .4614 Mdot
.81025 .4286 Mdot
.57511 .50076 Mdot
.94698 .35544 Mdot
.15259 .58526 Mdot
.54853 .09431 Mdot
.7616 .33901 Mdot
.63543 .47069 Mdot
.88561 .39272 Mdot
.36177 .54734 Mdot
.91547 .22359 Mdot
.19024 .56579 Mdot
.63271 .11757 Mdot
.7169 .39104 Mdot
.74036 .44307 Mdot
.72568 .45757 Mdot
.75819 .4485 Mdot
.69518 .46859 Mdot
.8113 .42965 Mdot
.57318 .50141 Mdot
.94833 .35425 Mdot
.14747 .5861 Mdot
.53537 .09114 Mdot
.76399 .33088 Mdot
.62679 .47217 Mdot
.89471 .38738 Mdot
.33262 .55296 Mdot
.88422 .20557 Mdot
.27492 .54648 Mdot
.79499 .16991 Mdot
.48401 .49133 Mdot
.96116 .29913 Mdot
.07708 .59403 Mdot
.33286 .04764 Mdot
.63924 .20572 Mdot
.75312 .39507 Mdot
.67891 .46545 Mdot
.8324 .41959 Mdot
.51759 .51445 Mdot
.97272 .31989 Mdot
.04672 .60118 Mdot
.23584 .02888 Mdot
.47123 .14576 Mdot
.79105 .29124 Mdot
.55153 .4889 Mdot
.95205 .34086 Mdot
.12843 .5884 Mdot
.48436 .07938 Mdot
.76123 .29935 Mdot
.61689 .47047 Mdot
.90279 .38126 Mdot
.30555 .55796 Mdot
.84939 .18884 Mdot
.3623 .52495 Mdot
.90516 .22391 Mdot
.22203 .55942 Mdot
.70039 .13722 Mdot
.64279 .43286 Mdot
.85967 .39727 Mdot
.43624 .53131 Mdot
.96545 .26961 Mdot
.04785 .59668 Mdot
.23749 .02957 Mdot
.47486 .14678 Mdot
.79234 .29348 Mdot
.54981 .48969 Mdot
.95307 .3398 Mdot
.12448 .58903 Mdot
.4735 .07693 Mdot
.75815 .29264 Mdot
.6196 .46856 Mdot
.8995 .38293 Mdot
.31624 .55592 Mdot
.86378 .19545 Mdot
.32717 .53384 Mdot
.86789 .2022 Mdot
.31921 .53638 Mdot
.8584 .19728 Mdot
.34256 .53052 Mdot
.88564 .21171 Mdot
.27383 .54735 Mdot
.79357 .16924 Mdot
.48682 .49045 Mdot
.96108 .30087 Mdot
.07818 .59398 Mdot
.33634 .04832 Mdot
.64396 .20787 Mdot
.74922 .39799 Mdot
.68764 .46304 Mdot
.81935 .42498 Mdot
.55198 .50638 Mdot
.96038 .34114 Mdot
.10016 .59354 Mdot
.40439 .0619 Mdot
.718 .24993 Mdot
.67009 .44375 Mdot
.83329 .41414 Mdot
.51274 .515 Mdot
.97346 .31689 Mdot
.04265 .60163 Mdot
.22203 .02636 Mdot
.44164 .13722 Mdot
.77673 .27295 Mdot
.57298 .48005 Mdot
.93807 .35412 Mdot
.18144 .57976 Mdot
.61857 .11214 Mdot
.72739 .3823 Mdot
.71876 .44955 Mdot
.76575 .44422 Mdot
.67834 .47326 Mdot
.83694 .41924 Mdot
.50605 .51726 Mdot
.97492 .31276 Mdot
.03546 .60254 Mdot
.19744 .02191 Mdot
.3854 .12202 Mdot
.73186 .23819 Mdot
.64118 .45231 Mdot
.87081 .39627 Mdot
.40534 .53819 Mdot
.94989 .25052 Mdot
.09188 .58706 Mdot
.37597 .05679 Mdot
.69158 .23236 Mdot
.70181 .42742 Mdot
.78154 .43374 Mdot
.64102 .48302 Mdot
.88588 .39617 Mdot
.36268 .5475 Mdot
.9165 .22415 Mdot
.18728 .56643 Mdot
.62606 .11575 Mdot
.72238 .38693 Mdot
.72941 .44646 Mdot
.74649 .4508 Mdot
.71831 .46135 Mdot
.77221 .44394 Mdot
.66525 .47725 Mdot
.85558 .41115 Mdot
.45391 .52878 Mdot
.97181 .28053 Mdot
.03084 .60061 Mdot
.1802 .01906 Mdot
.3434 .11137 Mdot
.68318 .21223 Mdot
.70374 .42223 Mdot
.77611 .43493 Mdot
.6529 .47966 Mdot
.87132 .40351 Mdot
.40745 .5385 Mdot
.95156 .25182 Mdot
.08688 .5881 Mdot
.36094 .05369 Mdot
.67496 .22307 Mdot
.71993 .41715 Mdot
.74811 .44494 Mdot
.71247 .46236 Mdot
.78206 .44033 Mdot
.64312 .48334 Mdot
.88382 .39747 Mdot
.36922 .54623 Mdot
.92259 .22819 Mdot
.17015 .57019 Mdot
.58622 .10516 Mdot
.74839 .3623 Mdot
.67185 .46253 Mdot
.84018 .41522 Mdot
.49593 .51926 Mdot
.9758 .3065 Mdot
.02929 .60308 Mdot
.17592 .0181 Mdot
.3325 .10872 Mdot
.66844 .2055 Mdot
.71971 .41312 Mdot
.74651 .44481 Mdot
.71535 .46137 Mdot
.77699 .44211 Mdot
.65456 .48021 Mdot
.86969 .40454 Mdot
.41245 .5375 Mdot
.95454 .25491 Mdot
.07828 .58994 Mdot
.3347 .04838 Mdot
.64193 .20686 Mdot
.75087 .39674 Mdot
.68394 .46406 Mdot
.82494 .4227 Mdot
.53741 .50984 Mdot
.96671 .33214 Mdot
.0738 .59746 Mdot
.32401 .04561 Mdot
.62669 .20025 Mdot
.76281 .38732 Mdot
.65652 .47144 Mdot
.86318 .40575 Mdot
.43088 .53347 Mdot
.96374 .2663 Mdot
.05219 .59562 Mdot
.25176 .03226 Mdot
.50381 .1556 Mdot
.79942 .31137 Mdot
.54286 .49407 Mdot
.9575 .33551 Mdot
.10731 .59177 Mdot
.42494 .06632 Mdot
.73367 .26263 Mdot
.64991 .45343 Mdot
.86194 .40167 Mdot
.43225 .53271 Mdot
.9641 .26714 Mdot
.05137 .59584 Mdot
.24906 .03175 Mdot
.49845 .15393 Mdot
.79856 .30806 Mdot
.54316 .49354 Mdot
.95715 .33569 Mdot
.10858 .59155 Mdot
.42861 .06711 Mdot
.73613 .2649 Mdot
.6467 .45495 Mdot
.8662 .39968 Mdot
.4197 .53534 Mdot
.95818 .25939 Mdot
.06801 .59219 Mdot
.30267 .04203 Mdot
.59466 .18706 Mdot
.78254 .36752 Mdot
.60677 .48364 Mdot
.91753 .37501 Mdot
.25732 .56706 Mdot
.77376 .15903 Mdot
.52379 .47821 Mdot
.95427 .32372 Mdot
.1126 .58977 Mdot
.4396 .06959 Mdot
.74296 .27169 Mdot
.63781 .45917 Mdot
.87762 .39419 Mdot
.38527 .5424 Mdot
.93581 .23811 Mdot
.13253 .57836 Mdot
.49094 .08191 Mdot
.76318 .30342 Mdot
.61505 .47167 Mdot
.90495 .38012 Mdot
.29849 .55929 Mdot
.83941 .18448 Mdot
.38586 .51879 Mdot
.92486 .23848 Mdot
.16795 .57159 Mdot
.58137 .1038 Mdot
.7507 .35931 Mdot
.6661 .46396 Mdot
.84808 .41167 Mdot
.47387 .52414 Mdot
.97531 .29287 Mdot
.02443 .60278 Mdot
.15839 .0151 Mdot
.28689 .09789 Mdot
.59717 .17731 Mdot
.77604 .36907 Mdot
.62107 .47962 Mdot
.90356 .38384 Mdot
.30449 .55843 Mdot
.84804 .18819 Mdot
.36549 .52412 Mdot
.90807 .22589 Mdot
.21413 .56122 Mdot
.68438 .13234 Mdot
.66332 .42297 Mdot
.83157 .40996 Mdot
.51496 .51394 Mdot
.97276 .31826 Mdot
.04582 .6012 Mdot
.23276 .02832 Mdot
.46475 .14385 Mdot
.78846 .28723 Mdot
.55518 .4873 Mdot
.94987 .34312 Mdot
.13689 .58705 Mdot
.50721 .08461 Mdot
.76487 .31348 Mdot
.61661 .47272 Mdot
.90412 .38109 Mdot
.30146 .55878 Mdot
.84367 .18631 Mdot
.37588 .52142 Mdot
.91703 .2323 Mdot
.18961 .56676 Mdot
.6317 .11718 Mdot
.71771 .39041 Mdot
.73875 .44357 Mdot
.72878 .45657 Mdot
.75246 .45041 Mdot
.70702 .46504 Mdot
.79187 .43697 Mdot
.62049 .4894 Mdot
.90883 .38348 Mdot
.28832 .56169 Mdot
.82461 .17819 Mdot
.41952 .50964 Mdot
.9456 .25928 Mdot
.11052 .58441 Mdot
.43087 .0683 Mdot
.73794 .2663 Mdot
.64418 .45607 Mdot
.86947 .39812 Mdot
.40995 .53736 Mdot
.95276 .25337 Mdot
.08356 .58884 Mdot
.35089 .05164 Mdot
.66292 .21686 Mdot
.73202 .40971 Mdot
.72416 .45241 Mdot
.75824 .44755 Mdot
.69462 .46862 Mdot
.81213 .4293 Mdot
.57108 .50192 Mdot
.94968 .35295 Mdot
.1423 .58694 Mdot
.5219 .08795 Mdot
.76513 .32255 Mdot
.62051 .47287 Mdot
.90079 .3835 Mdot
.31268 .55672 Mdot
.85913 .19324 Mdot
.33866 .53097 Mdot
.88112 .20931 Mdot
.28562 .54456 Mdot
.81191 .17652 Mdot
.44888 .50179 Mdot
.9568 .27743 Mdot
.08152 .59133 Mdot
.34566 .05038 Mdot
.65625 .21363 Mdot
.73834 .40559 Mdot
.71108 .45632 Mdot
.78131 .43947 Mdot
.64427 .48288 Mdot
.88238 .39818 Mdot
.37371 .54534 Mdot
.92657 .23097 Mdot
.15887 .57265 Mdot
.55876 .09819 Mdot
.75952 .34533 Mdot
.64254 .46941 Mdot
.87768 .39711 Mdot
.38652 .54244 Mdot
.93691 .23888 Mdot
.12928 .57905 Mdot
.4822 .0799 Mdot
.76118 .29802 Mdot
.61634 .47044 Mdot
.90325 .38092 Mdot
.30402 .55824 Mdot
.84724 .18789 Mdot
.36743 .52363 Mdot
.90981 .22708 Mdot
.2094 .56229 Mdot
.67457 .12941 Mdot
.67498 .41691 Mdot
.814 .41716 Mdot
.56081 .50308 Mdot
.95517 .3466 Mdot
.12064 .59033 Mdot
.46315 .07456 Mdot
.75436 .28624 Mdot
.62373 .46622 Mdot
.89465 .38549 Mdot
.33188 .55293 Mdot
.88327 .20511 Mdot
.27745 .54589 Mdot
.799 .17147 Mdot
.47587 .49381 Mdot
.961 .29411 Mdot
.07518 .59393 Mdot
.32672 .04646 Mdot
.63072 .20193 Mdot
.75979 .38981 Mdot
.6636 .46958 Mdot
.85387 .41013 Mdot
.45795 .52772 Mdot
.97271 .28303 Mdot
.0289 .60117 Mdot
.17358 .01786 Mdot
.32663 .10728 Mdot
.66011 .20187 Mdot
.7281 .40797 Mdot
.73002 .44999 Mdot
.74714 .45118 Mdot
.71729 .46176 Mdot
.77407 .44331 Mdot
.66115 .4784 Mdot
.8611 .40861 Mdot
.43788 .53219 Mdot
.96669 .27063 Mdot
.04403 .59745 Mdot
.22477 .02721 Mdot
.44778 .13891 Mdot
.78021 .27675 Mdot
.56761 .48219 Mdot
.94186 .3508 Mdot
.16734 .5821 Mdot
.58495 .10342 Mdot
.74834 .36152 Mdot
.67156 .4625 Mdot
.84053 .41505 Mdot
.49495 .51947 Mdot
.97586 .3059 Mdot
.0288 .60311 Mdot
.17419 .0178 Mdot
.3281 .10766 Mdot
.66224 .20278 Mdot
.72601 .40928 Mdot
.73421 .4487 Mdot
.73928 .45377 Mdot
.73279 .4569 Mdot
.74573 .45289 Mdot
.72072 .46088 Mdot
.76805 .44543 Mdot
.67435 .47468 Mdot
.84286 .41677 Mdot
.48983 .52092 Mdot
.97618 .30273 Mdot
.02611 .60331 Mdot
.1647 .01614 Mdot
.30354 .10179 Mdot
.62497 .1876 Mdot
.75827 .38625 Mdot
.66481 .46864 Mdot
.85193 .41088 Mdot
.46342 .52652 Mdot
.97383 .28641 Mdot
.02655 .60186 Mdot
.16556 .01641 Mdot
.30585 .10232 Mdot
.62866 .18903 Mdot
.7555 .38853 Mdot
.67122 .46693 Mdot
.84312 .41483 Mdot
.48823 .52107 Mdot
.9761 .30175 Mdot
.02592 .60326 Mdot
.16398 .01602 Mdot
.30168 .10135 Mdot
.62196 .18645 Mdot
.76045 .38439 Mdot
.65968 .46999 Mdot
.85876 .40771 Mdot
.44375 .53074 Mdot
.96869 .27425 Mdot
.03877 .59869 Mdot
.20715 .02396 Mdot
.4083 .12803 Mdot
.75292 .25235 Mdot
.61001 .46533 Mdot
.90605 .37701 Mdot
.29365 .55997 Mdot
.83223 .18148 Mdot
.40243 .51435 Mdot
.93616 .24872 Mdot
.13651 .57858 Mdot
.50206 .08437 Mdot
.76485 .31029 Mdot
.6151 .4727 Mdot
.90541 .38015 Mdot
.29712 .55957 Mdot
.83743 .18363 Mdot
.39046 .51756 Mdot
.9282 .24132 Mdot
.15865 .57366 Mdot
.55869 .09805 Mdot
.75948 .34529 Mdot
.64259 .46939 Mdot
.87762 .39714 Mdot
.38672 .5424 Mdot
.93707 .23901 Mdot
.12883 .57914 Mdot
.48098 .07962 Mdot
.76086 .29726 Mdot
.61661 .47024 Mdot
.90292 .38108 Mdot
.30508 .55804 Mdot
.84873 .18855 Mdot
.36388 .52454 Mdot
.90662 .22489 Mdot
.21808 .56032 Mdot
.69245 .13478 Mdot
.65321 .42795 Mdot
.84587 .40371 Mdot
.47576 .52277 Mdot
.97503 .29403 Mdot
.02598 .6026 Mdot
.16388 .01606 Mdot
.30142 .10128 Mdot
.62155 .18629 Mdot
.76075 .38414 Mdot
.65898 .47017 Mdot
.85967 .40727 Mdot
.44108 .53131 Mdot
.96777 .27261 Mdot
.04121 .59811 Mdot
.21535 .02547 Mdot
.42697 .13309 Mdot
.76724 .26388 Mdot
.58784 .47418 Mdot
.92648 .3633 Mdot
.22338 .5726 Mdot
.70963 .13806 Mdot
.62911 .43857 Mdot
.87621 .38881 Mdot
.38666 .54153 Mdot
.93659 .23897 Mdot
.13038 .57884 Mdot
.48519 .08058 Mdot
.76193 .29986 Mdot
.61578 .4709 Mdot
.90395 .38057 Mdot
.30173 .55867 Mdot
.84403 .18648 Mdot
.37503 .52164 Mdot
.91633 .23178 Mdot
.19152 .56633 Mdot
.63597 .11837 Mdot
.71405 .39305 Mdot
.74591 .44131 Mdot
.71476 .461 Mdot
.77776 .44175 Mdot
.65278 .48068 Mdot
.87195 .40344 Mdot
.40566 .53889 Mdot
.95046 .25071 Mdot
.09005 .58742 Mdot
.37049 .05566 Mdot
.68571 .22897 Mdot
.70839 .4238 Mdot
.76973 .43781 Mdot
.66727 .47572 Mdot
.85234 .4124 Mdot
.46309 .52677 Mdot
.97386 .28621 Mdot
.02636 .60188 Mdot
.16489 .01629 Mdot
.3041 .10191 Mdot
.62586 .18794 Mdot
.75761 .3868 Mdot
.66635 .46823 Mdot
.84985 .41183 Mdot
.46935 .52523 Mdot
.9748 .29007 Mdot
.02489 .60246 Mdot
.15988 .01538 Mdot
.29088 .09881 Mdot
.60401 .17977 Mdot
.77217 .3733 Mdot
.63103 .47723 Mdot
.89313 .39 Mdot
.33856 .55198 Mdot
.89119 .20924 Mdot
.2565 .55079 Mdot
.76434 .15853 Mdot
.54244 .47239 Mdot
.94711 .33524 Mdot
.14235 .58534 Mdot
.52127 .08798 Mdot
.76523 .32216 Mdot
.62011 .47294 Mdot
.90117 .38325 Mdot
.31139 .55696 Mdot
.8574 .19245 Mdot
.34289 .5299 Mdot
.88573 .21192 Mdot
.27365 .54741 Mdot
.79328 .16913 Mdot
.48738 .49028 Mdot
.96106 .30122 Mdot
.07842 .59397 Mdot
.33711 .04847 Mdot
.64498 .20834 Mdot
.74835 .39862 Mdot
.68954 .46251 Mdot
.81642 .42616 Mdot
.5595 .50457 Mdot
.95647 .34579 Mdot
.11583 .59113 Mdot
.44967 .07159 Mdot
.74828 .27791 Mdot
.63108 .46246 Mdot
.88591 .39003 Mdot
.3596 .54752 Mdot
.91324 .22224 Mdot
.19648 .56442 Mdot
.64653 .12143 Mdot
.70449 .39958 Mdot
.76396 .4354 Mdot
.67759 .47215 Mdot
.8374 .41877 Mdot
.50467 .51754 Mdot
.9751 .3119 Mdot
.03444 .60264 Mdot
.1939 .02128 Mdot
.37693 .11984 Mdot
.7231 .23296 Mdot
.65348 .4469 Mdot
.85475 .40387 Mdot
.45257 .52827 Mdot
.97107 .27971 Mdot
.03305 .60016 Mdot
.1878 .02042 Mdot
.36224 .11607 Mdot
.70662 .22388 Mdot
.67542 .43672 Mdot
.82304 .41743 Mdot
.53946 .50866 Mdot
.96558 .3334 Mdot
.07836 .59676 Mdot
.33829 .04843 Mdot
.64643 .20907 Mdot
.74715 .39951 Mdot
.6922 .46176 Mdot
.81229 .4278 Mdot
.57 .50202 Mdot
.95029 .35228 Mdot
.13993 .58731 Mdot
.51564 .08648 Mdot
.76519 .31868 Mdot
.6185 .47292 Mdot
.90258 .38225 Mdot
.30667 .55783 Mdot
.85098 .18954 Mdot
.35848 .52593 Mdot
.90156 .22155 Mdot
.23173 .5572 Mdot
.71939 .14322 Mdot
.61603 .44461 Mdot
.89098 .38073 Mdot
.34036 .55066 Mdot
.89275 .21035 Mdot
.25247 .55175 Mdot
.7573 .15603 Mdot
.55493 .46804 Mdot
.94063 .34296 Mdot
.16762 .58134 Mdot
.58529 .1036 Mdot
.74821 .36173 Mdot
.6719 .46242 Mdot
.84006 .41526 Mdot
.49624 .51918 Mdot
.97578 .3067 Mdot
.02946 .60307 Mdot
.17652 .01821 Mdot
.33402 .10909 Mdot
.67055 .20644 Mdot
.71752 .41442 Mdot
.75071 .44345 Mdot
.70691 .46397 Mdot
.79152 .4369 Mdot
.62122 .48918 Mdot
.90807 .38393 Mdot
.29085 .56122 Mdot
.82842 .17975 Mdot
.411 .51199 Mdot
.94117 .25401 Mdot
.12265 .58167 Mdot
.46472 .0758 Mdot
.75542 .28721 Mdot
.6222 .46687 Mdot
.89636 .38454 Mdot
.32636 .55398 Mdot
.8766 .2017 Mdot
.29473 .54177 Mdot
.82509 .18215 Mdot
.42029 .50993 Mdot
.94621 .25975 Mdot
.10869 .58479 Mdot
.42566 .06717 Mdot
.73449 .26307 Mdot
.64868 .45394 Mdot
.86355 .40091 Mdot
.42752 .5337 Mdot
.96201 .26422 Mdot
.05719 .59455 Mdot
.26804 .03534 Mdot
.53495 .16566 Mdot
.80027 .33062 Mdot
.5503 .49459 Mdot
.95527 .3401 Mdot
.11714 .59039 Mdot
.45311 .0724 Mdot
.74999 .28003 Mdot
.62894 .46352 Mdot
.88847 .38871 Mdot
.35154 .54911 Mdot
.90513 .21726 Mdot
.2189 .5594 Mdot
.69374 .13529 Mdot
.6516 .42876 Mdot
.84808 .40271 Mdot
.46954 .52414 Mdot
.97432 .29019 Mdot
.02666 .60216 Mdot
.16611 .01648 Mdot
.30728 .10266 Mdot
.63092 .18991 Mdot
.75376 .38993 Mdot
.6752 .46585 Mdot
.83747 .41729 Mdot
.50377 .51759 Mdot
.97513 .31135 Mdot
.03404 .60266 Mdot
.19253 .02104 Mdot
.37364 .11899 Mdot
.71954 .23092 Mdot
.65835 .4447 Mdot
.84805 .40689 Mdot
.47163 .52413 Mdot
.97481 .29148 Mdot
.02555 .60246 Mdot
.16227 .01579 Mdot
.29721 .10029 Mdot
.61463 .18368 Mdot
.76551 .37986 Mdot
.64757 .47311 Mdot
.87407 .40022 Mdot
.39818 .54021 Mdot
.94546 .24609 Mdot
.10458 .58433 Mdot
.4132 .06463 Mdot
.72551 .25537 Mdot
.66033 .44839 Mdot
.84751 .40811 Mdot
.47363 .52379 Mdot
.97509 .29272 Mdot
.02515 .60264 Mdot
.16092 .01554 Mdot
.29361 .09945 Mdot
.60863 .18146 Mdot
.76937 .37615 Mdot
.63807 .4755 Mdot
.88528 .39435 Mdot
.36352 .54713 Mdot
.9172 .22467 Mdot
.18536 .56686 Mdot
.6217 .11456 Mdot
.72579 .38423 Mdot
.72241 .44856 Mdot
.75928 .44647 Mdot
.6921 .46926 Mdot
.81606 .42774 Mdot
.5611 .50436 Mdot
.95566 .34678 Mdot
.11905 .59063 Mdot
.45874 .07358 Mdot
.75252 .28352 Mdot
.62589 .46508 Mdot
.89211 .38682 Mdot
.34002 .55135 Mdot
.89267 .21014 Mdot
.2526 .5517 Mdot
.75753 .15612 Mdot
.55453 .46818 Mdot
.94085 .34272 Mdot
.16677 .58148 Mdot
.58321 .10307 Mdot
.74924 .36044 Mdot
.66936 .46306 Mdot
.84358 .41369 Mdot
.48649 .52136 Mdot
.97605 .30067 Mdot
.0256 .60323 Mdot
.1628 .01582 Mdot
.29855 .10061 Mdot
.61686 .18452 Mdot
.76402 .38124 Mdot
.65119 .47219 Mdot
.86962 .40246 Mdot
.41165 .53745 Mdot
.95398 .25442 Mdot
.07996 .58959 Mdot
.33987 .04942 Mdot
.64885 .21005 Mdot
.74498 .40101 Mdot
.6969 .46042 Mdot
.80483 .43071 Mdot
.58859 .49741 Mdot
.93727 .36377 Mdot
.18875 .57926 Mdot
.63575 .11665 Mdot
.71344 .39292 Mdot
.74682 .44093 Mdot
.7129 .46156 Mdot
.78099 .4406 Mdot
.6455 .48268 Mdot
.88097 .39894 Mdot
.3781 .54447 Mdot
.93031 .23368 Mdot
.14818 .57496 Mdot
.53185 .09158 Mdot
.76504 .3287 Mdot
.62367 .47282 Mdot
.89791 .38545 Mdot
.32221 .55494 Mdot
.87151 .19914 Mdot
.30772 .53862 Mdot
.84319 .19018 Mdot
.379 .52112 Mdot
.91981 .23423 Mdot
.18184 .56847 Mdot
.61404 .11238 Mdot
.7314 .3795 Mdot
.71056 .45203 Mdot
.78005 .43915 Mdot
.64677 .4821 Mdot
.87931 .39972 Mdot
.38319 .54344 Mdot
.93446 .23682 Mdot
.13628 .57753 Mdot
.5009 .08422 Mdot
.76477 .30957 Mdot
.6149 .47266 Mdot
.90555 .38003 Mdot
.29662 .55966 Mdot
.83671 .18332 Mdot
.39212 .51712 Mdot
.92937 .24234 Mdot
.1554 .57438 Mdot
.55061 .09604 Mdot
.7617 .34029 Mdot
.63586 .47076 Mdot
.88522 .39298 Mdot
.36303 .5471 Mdot
.91667 .22436 Mdot
.18688 .56653 Mdot
.62514 .1155 Mdot
.72311 .38636 Mdot
.72792 .44691 Mdot
.74924 .44988 Mdot
.71279 .46305 Mdot
.7819 .44053 Mdot
.64355 .48324 Mdot
.88332 .39774 Mdot
.3708 .54592 Mdot
.924 .22916 Mdot
.16615 .57106 Mdot
.57659 .10269 Mdot
.75292 .35635 Mdot
.66049 .46533 Mdot
.85554 .40821 Mdot
.45258 .52875 Mdot
.97131 .27971 Mdot
.0322 .6003 Mdot
.18489 .0199 Mdot
.35509 .11427 Mdot
.69803 .21946 Mdot
.68621 .4314 Mdot
.80597 .4241 Mdot
.58277 .49812 Mdot
.94127 .36017 Mdot
.17386 .58173 Mdot
.60103 .10745 Mdot
.73932 .37146 Mdot
.69278 .45692 Mdot
.80911 .42816 Mdot
.57754 .50006 Mdot
.94528 .35694 Mdot
.15899 .58421 Mdot
.5647 .09826 Mdot
.7569 .349 Mdot
.64937 .46779 Mdot
.86951 .40133 Mdot
.41139 .53739 Mdot
.95377 .25425 Mdot
.08059 .58946 Mdot
.34182 .04981 Mdot
.6514 .21125 Mdot
.74272 .40259 Mdot
.70177 .45903 Mdot
.79694 .43372 Mdot
.60777 .49254 Mdot
.92106 .37562 Mdot
.24654 .56925 Mdot
.75452 .15237 Mdot
.55845 .46632 Mdot
.93835 .34514 Mdot
.17617 .57993 Mdot
.60584 .10888 Mdot
.73635 .37443 Mdot
.69948 .45509 Mdot
.79844 .4323 Mdot
.60375 .49346 Mdot
.92464 .37314 Mdot
.23402 .57146 Mdot
.73096 .14464 Mdot
.59732 .45176 Mdot
.90915 .36916 Mdot
.28039 .56188 Mdot
.81171 .17329 Mdot
.44779 .50167 Mdot
.95629 .27675 Mdot
.08291 .59102 Mdot
.34992 .05124 Mdot
.66162 .21626 Mdot
.7333 .4089 Mdot
.72155 .4532 Mdot
.76295 .44594 Mdot
.6847 .47153 Mdot
.82753 .42317 Mdot
.53132 .51144 Mdot
.96896 .32837 Mdot
.0641 .59885 Mdot
.29307 .03961 Mdot
.57874 .18113 Mdot
.78978 .35768 Mdot
.58654 .48811 Mdot
.93407 .3625 Mdot
.19855 .57729 Mdot
.65753 .12271 Mdot
.69272 .40638 Mdot
.78465 .42813 Mdot
.63172 .48494 Mdot
.8962 .39042 Mdot
.32971 .55388 Mdot
.88094 .20377 Mdot
.28345 .54445 Mdot
.80832 .17518 Mdot
.45657 .49957 Mdot
.95857 .28217 Mdot
.07773 .59243 Mdot
.33418 .04804 Mdot
.64111 .20653 Mdot
.75158 .39623 Mdot
.68237 .4645 Mdot
.82729 .42173 Mdot
.53121 .51129 Mdot
.96891 .32831 Mdot
.06424 .59882 Mdot
.29351 .0397 Mdot
.57948 .1814 Mdot
.78948 .35814 Mdot
.58739 .48793 Mdot
.93344 .36303 Mdot
.20086 .5769 Mdot
.66259 .12414 Mdot
.68741 .4095 Mdot
.79367 .42484 Mdot
.61067 .49051 Mdot
.91775 .37741 Mdot
.25781 .5672 Mdot
.77472 .15934 Mdot
.52197 .4788 Mdot
.95484 .3226 Mdot
.11011 .59012 Mdot
.43245 .06805 Mdot
.73866 .26727 Mdot
.64338 .45651 Mdot
.87053 .39763 Mdot
.40678 .53802 Mdot
.95084 .2514 Mdot
.08911 .58765 Mdot
.36766 .05507 Mdot
.6826 .22723 Mdot
.7118 .42187 Mdot
.76346 .43992 Mdot
.68076 .47185 Mdot
.83303 .42073 Mdot
.51657 .51484 Mdot
.97303 .31926 Mdot
.04535 .60136 Mdot
.23121 .02803 Mdot
.46145 .14289 Mdot
.78703 .28519 Mdot
.55727 .48641 Mdot
.94859 .34441 Mdot
.14183 .58626 Mdot
.52029 .08766 Mdot
.76521 .32156 Mdot
.61986 .47293 Mdot
.90139 .38309 Mdot
.31066 .55709 Mdot
.85643 .192 Mdot
.34528 .5293 Mdot
.88828 .21339 Mdot
.267 .54899 Mdot
.78245 .16502 Mdot
.50865 .48358 Mdot
.95848 .31436 Mdot
.09369 .59237 Mdot
.38412 .05791 Mdot
.69961 .2374 Mdot
.69258 .43238 Mdot
.79747 .42804 Mdot
.60383 .49286 Mdot
.92429 .37319 Mdot
.23516 .57124 Mdot
.73313 .14534 Mdot
.5939 .4531 Mdot
.9122 .36705 Mdot
.26998 .56377 Mdot
.79487 .16686 Mdot
.4828 .49126 Mdot
.96095 .29839 Mdot
.07743 .5939 Mdot
.33393 .04786 Mdot
.64071 .20638 Mdot
.75192 .39598 Mdot
.6816 .46471 Mdot
.82843 .42125 Mdot
.52818 .512 Mdot
.96988 .32643 Mdot
.05992 .59942 Mdot
.27952 .03703 Mdot
.55548 .17275 Mdot
.79707 .34331 Mdot
.56359 .49262 Mdot
.94883 .34832 Mdot
.1429 .58641 Mdot
.52328 .08832 Mdot
.7651 .3234 Mdot
.62099 .47285 Mdot
.90035 .38379 Mdot
.31411 .55645 Mdot
.86103 .19413 Mdot
.33396 .53215 Mdot
.87583 .2064 Mdot
.29917 .54129 Mdot
.83171 .1849 Mdot
.40536 .51403 Mdot
.93818 .25053 Mdot
.13081 .57982 Mdot
.48685 .08084 Mdot
.76226 .30089 Mdot
.61564 .4711 Mdot
.90417 .38048 Mdot
.30102 .55881 Mdot
.84302 .18604 Mdot
.37742 .52101 Mdot
.91829 .23326 Mdot
.18612 .56754 Mdot
.62384 .11503 Mdot
.72408 .38556 Mdot
.72592 .44751 Mdot
.75291 .44864 Mdot
.70531 .46532 Mdot
.79462 .43591 Mdot
.61394 .4911 Mdot
.91532 .37944 Mdot
.26635 .5657 Mdot
.78941 .16462 Mdot
.49361 .48789 Mdot
.96045 .30507 Mdot
.0824 .59359 Mdot
.34956 .05093 Mdot
.66105 .21604 Mdot
.73386 .40855 Mdot
.72039 .45355 Mdot
.76502 .44523 Mdot
.68027 .47281 Mdot
.83416 .42043 Mdot
.51361 .51554 Mdot
.97365 .31743 Mdot
.04223 .60175 Mdot
.22066 .0261 Mdot
.43861 .13637 Mdot
.7749 .27107 Mdot
.57583 .47892 Mdot
.93597 .35588 Mdot
.18916 .57846 Mdot
.63633 .11691 Mdot
.71298 .39327 Mdot
.74772 .44065 Mdot
.71112 .46212 Mdot
.78408 .43949 Mdot
.63845 .48459 Mdot
.8893 .39458 Mdot
.35199 .54962 Mdot
.90589 .21754 Mdot
.21673 .55987 Mdot
.68933 .13394 Mdot
.65723 .42603 Mdot
.84031 .40619 Mdot
.4912 .51934 Mdot
.97554 .30358 Mdot
.02882 .60292 Mdot
.17417 .01781 Mdot
.32805 .10764 Mdot
.66216 .20275 Mdot
.72608 .40924 Mdot
.73405 .44875 Mdot
.73958 .45367 Mdot
.73222 .45708 Mdot
.74681 .45253 Mdot
.71856 .46156 Mdot
.77191 .44409 Mdot
.66592 .47707 Mdot
.85467 .41156 Mdot
.45654 .52821 Mdot
.97247 .28215 Mdot
.02932 .60102 Mdot
.17501 .01812 Mdot
.33028 .10816 Mdot
.66531 .20412 Mdot
.72292 .41118 Mdot
.74028 .44679 Mdot
.72762 .45752 Mdot
.7549 .44969 Mdot
.70206 .46655 Mdot
.80015 .4339 Mdot
.6007 .49452 Mdot
.92745 .37125 Mdot
.22414 .57319 Mdot
.71151 .13853 Mdot
.62639 .43974 Mdot
.87934 .38713 Mdot
.37699 .54346 Mdot
.92878 .23299 Mdot
.15277 .57402 Mdot
.54354 .09442 Mdot
.76329 .33593 Mdot
.63061 .47174 Mdot
.89087 .38974 Mdot
.34507 .55059 Mdot
.89836 .21326 Mdot
.23728 .55522 Mdot
.72961 .14665 Mdot
.60061 .45092 Mdot
.90635 .3712 Mdot
.28992 .56015 Mdot
.82642 .17918 Mdot
.41559 .51076 Mdot
.94364 .25685 Mdot
.11585 .5832 Mdot
.44587 .0716 Mdot
.74674 .27557 Mdot
.63279 .46151 Mdot
.88377 .39109 Mdot
.36626 .5462 Mdot
.91958 .22636 Mdot
.17873 .56833 Mdot
.60645 .11046 Mdot
.73663 .37481 Mdot
.69916 .45526 Mdot
.799 .43211 Mdot
.60241 .49381 Mdot
.92582 .37231 Mdot
.22984 .57219 Mdot
.72281 .14205 Mdot
.60983 .44672 Mdot
.89717 .3769 Mdot
.32027 .55448 Mdot
.86865 .19794 Mdot
.31505 .53685 Mdot
.85284 .19471 Mdot
.35609 .52709 Mdot
.89952 .22008 Mdot
.23714 .55593 Mdot
.72967 .14656 Mdot
.60047 .45096 Mdot
.90647 .37111 Mdot
.28949 .56023 Mdot
.82578 .17892 Mdot
.41703 .51036 Mdot
.94438 .25774 Mdot
.11384 .58366 Mdot
.44023 .07035 Mdot
.74362 .27208 Mdot
.63679 .45959 Mdot
.87886 .39356 Mdot
.38147 .54316 Mdot
.93278 .23576 Mdot
.14121 .57649 Mdot
.51388 .08727 Mdot
.76575 .31759 Mdot
.61688 .47326 Mdot
.90416 .38125 Mdot
.30144 .5588 Mdot
.84365 .1863 Mdot
.37593 .5214 Mdot
.91707 .23234 Mdot
.18948 .56678 Mdot
.63142 .11711 Mdot
.71794 .39024 Mdot
.73829 .44371 Mdot
.72968 .45629 Mdot
.75079 .45097 Mdot
.71043 .46401 Mdot
.78608 .43907 Mdot
.63399 .48582 Mdot
.89439 .39183 Mdot
.33572 .55277 Mdot
.88805 .20749 Mdot
.2648 .54885 Mdot
.77846 .16365 Mdot
.51634 .48112 Mdot
.95668 .31911 Mdot
.10214 .59126 Mdot
.40925 .06312 Mdot
.72208 .25293 Mdot
.66487 .44627 Mdot
.84101 .41091 Mdot
.49172 .51977 Mdot
.97579 .3039 Mdot
.02808 .60307 Mdot
.17161 .01736 Mdot
.3215 .10606 Mdot
.65266 .1987 Mdot
.73521 .40336 Mdot
.71553 .45438 Mdot
.77333 .44222 Mdot
.66213 .47794 Mdot
.8597 .40922 Mdot
.44197 .53132 Mdot
.96818 .27315 Mdot
.04004 .59837 Mdot
.21142 .02475 Mdot
.41808 .13066 Mdot
.76074 .25839 Mdot
.59797 .47016 Mdot
.91761 .36957 Mdot
.25441 .56712 Mdot
.76839 .15723 Mdot
.53378 .47489 Mdot
.95066 .32989 Mdot
.12782 .58754 Mdot
.48222 .079 Mdot
.76075 .29803 Mdot
.61719 .47017 Mdot
.90238 .38145 Mdot
.30689 .5577 Mdot
.85123 .18967 Mdot
.35789 .52609 Mdot
.901 .22119 Mdot
.23325 .55685 Mdot
.72231 .14416 Mdot
.61168 .44641 Mdot
.8955 .37804 Mdot
.32575 .55345 Mdot
.87553 .20133 Mdot
.29754 .54111 Mdot
.82912 .18389 Mdot
.41128 .51242 Mdot
.94157 .25419 Mdot
.1214 .58192 Mdot
.46126 .07503 Mdot
.75403 .28508 Mdot
.62381 .46601 Mdot
.89448 .38553 Mdot
.3324 .55282 Mdot
.88388 .20544 Mdot
.27584 .54627 Mdot
.79646 .17048 Mdot
.48104 .49224 Mdot
.96116 .2973 Mdot
.07618 .59403 Mdot
.32999 .04708 Mdot
.63529 .20394 Mdot
.75628 .39263 Mdot
.67173 .46741 Mdot
.8427 .41515 Mdot
.48946 .52082 Mdot
.9761 .3025 Mdot
.0263 .60326 Mdot
.16534 .01625 Mdot
.30522 .10218 Mdot
.62767 .18864 Mdot
.75626 .38792 Mdot
.66948 .46739 Mdot
.84554 .41376 Mdot
.48149 .52257 Mdot
.97595 .29758 Mdot
.02444 .60317 Mdot
.15863 .01511 Mdot
.2875 .09804 Mdot
.59822 .17768 Mdot
.77547 .36972 Mdot
.62256 .47926 Mdot
.90205 .38476 Mdot
.3095 .5575 Mdot
.85495 .19128 Mdot
.34886 .52839 Mdot
.89201 .21561 Mdot
.25718 .5513 Mdot
.76584 .15895 Mdot
.53968 .47332 Mdot
.94836 .33354 Mdot
.13731 .58612 Mdot
.50791 .08486 Mdot
.76497 .31391 Mdot
.61663 .47278 Mdot
.90414 .3811 Mdot
.30142 .55879 Mdot
.84362 .18629 Mdot
.37601 .52138 Mdot
.91714 .23239 Mdot
.18931 .56682 Mdot
.63103 .117 Mdot
.71827 .39 Mdot
.73764 .44391 Mdot
.73093 .45589 Mdot
.74846 .45174 Mdot
.71513 .46257 Mdot
.77793 .44198 Mdot
.65255 .48079 Mdot
.87226 .4033 Mdot
.40473 .53909 Mdot
.94988 .25014 Mdot
.09175 .58706 Mdot
.37555 .0567 Mdot
.69114 .2321 Mdot
.70232 .42715 Mdot
.78064 .43405 Mdot
.64306 .48246 Mdot
.88347 .39743 Mdot
.37021 .54601 Mdot
.92347 .2288 Mdot
.16766 .57074 Mdot
.58024 .10362 Mdot
.75129 .35861 Mdot
.66466 .46432 Mdot
.85002 .41078 Mdot
.46838 .52534 Mdot
.97461 .28948 Mdot
.02527 .60234 Mdot
.1612 .01562 Mdot
.29437 .09963 Mdot
.60991 .18193 Mdot
.76857 .37694 Mdot
.64006 .475 Mdot
.88299 .39558 Mdot
.37069 .54572 Mdot
.9238 .2291 Mdot
.16677 .57094 Mdot
.5781 .10307 Mdot
.75226 .35728 Mdot
.66219 .46492 Mdot
.8533 .40926 Mdot
.45902 .52737 Mdot
.97289 .28369 Mdot
.02857 .60128 Mdot
.17249 .01766 Mdot
.32382 .1066 Mdot
.65605 .20013 Mdot
.73203 .40546 Mdot
.72208 .45242 Mdot
.76169 .44627 Mdot
.68731 .47075 Mdot
.82354 .42478 Mdot
.54182 .50897 Mdot
.96505 .33486 Mdot
.08092 .59643 Mdot
.34625 .05001 Mdot
.65677 .21399 Mdot
.73792 .4059 Mdot
.71198 .45606 Mdot
.77978 .44003 Mdot
.64776 .48193 Mdot
.87815 .40033 Mdot
.38677 .54273 Mdot
.93727 .23904 Mdot
.12819 .57927 Mdot
.47925 .07923 Mdot
.76038 .29619 Mdot
.61702 .46994 Mdot
.90243 .38134 Mdot
.3067 .55773 Mdot
.85097 .18955 Mdot
.35852 .52593 Mdot
.90161 .22158 Mdot
.23162 .55722 Mdot
.71917 .14315 Mdot
.61636 .44447 Mdot
.89063 .38093 Mdot
.34148 .55044 Mdot
.894 .21104 Mdot
.24913 .55252 Mdot
.75137 .15397 Mdot
.56518 .46437 Mdot
.93438 .3493 Mdot
.19113 .57748 Mdot
.64047 .11812 Mdot
.70933 .39583 Mdot
.75471 .43839 Mdot
.69693 .46643 Mdot
.8077 .43073 Mdot
.58203 .49919 Mdot
.94223 .35971 Mdot
.17045 .58233 Mdot
.59284 .10534 Mdot
.74412 .3664 Mdot
.68166 .45989 Mdot
.82601 .42129 Mdot
.53412 .5105 Mdot
.96787 .3301 Mdot
.06878 .59817 Mdot
.3081 .04251 Mdot
.60292 .19041 Mdot
.77817 .37263 Mdot
.6184 .48093 Mdot
.90656 .38219 Mdot
.2946 .56029 Mdot
.83388 .18208 Mdot
.39861 .51537 Mdot
.93374 .24635 Mdot
.14326 .57708 Mdot
.51972 .08854 Mdot
.76572 .3212 Mdot
.61868 .47324 Mdot
.90258 .38237 Mdot
.30674 .55783 Mdot
.85107 .18957 Mdot
.35827 .52599 Mdot
.90136 .22142 Mdot
.23228 .55707 Mdot
.72045 .14356 Mdot
.61446 .44526 Mdot
.89263 .37976 Mdot
.33506 .55167 Mdot
.8867 .20708 Mdot
.26853 .54801 Mdot
.78466 .16596 Mdot
.50443 .48495 Mdot
.95928 .31176 Mdot
.08967 .59287 Mdot
.37195 .05542 Mdot
.68704 .22988 Mdot
.70699 .42462 Mdot
.7723 .43694 Mdot
.66167 .47731 Mdot
.85995 .40893 Mdot
.44116 .53148 Mdot
.96789 .27265 Mdot
.04083 .59819 Mdot
.21406 .02523 Mdot
.42405 .13229 Mdot
.76517 .26208 Mdot
.59107 .4729 Mdot
.92373 .3653 Mdot
.23308 .5709 Mdot
.72878 .14405 Mdot
.60076 .45041 Mdot
.90599 .37129 Mdot
.29105 .55993 Mdot
.82811 .17988 Mdot
.4118 .5118 Mdot
.94163 .25451 Mdot
.12138 .58196 Mdot
.46123 .07502 Mdot
.75401 .28505 Mdot
.62383 .466 Mdot
.89446 .38555 Mdot
.33248 .55281 Mdot
.88397 .20548 Mdot
.2756 .54633 Mdot
.79608 .17033 Mdot
.48181 .492 Mdot
.96116 .29778 Mdot
.07639 .59403 Mdot
.33066 .04721 Mdot
.63622 .20436 Mdot
.75554 .39321 Mdot
.67342 .46695 Mdot
.84031 .41619 Mdot
.49606 .51934 Mdot
.97585 .30658 Mdot
.02917 .60311 Mdot
.17549 .01803 Mdot
.3314 .10846 Mdot
.6669 .20482 Mdot
.7213 .41217 Mdot
.74345 .44579 Mdot
.72142 .45948 Mdot
.76621 .44586 Mdot
.67822 .47354 Mdot
.83724 .41917 Mdot
.50528 .51744 Mdot
.97503 .31228 Mdot
.03485 .6026 Mdot
.19532 .02154 Mdot
.38035 .12071 Mdot
.72669 .23507 Mdot
.64848 .44912 Mdot
.86143 .40078 Mdot
.43321 .53239 Mdot
.96445 .26774 Mdot
.05044 .59606 Mdot
.24603 .03117 Mdot
.49237 .15206 Mdot
.79735 .3043 Mdot
.54404 .49279 Mdot
.95651 .33624 Mdot
.11104 .59116 Mdot
.43568 .06863 Mdot
.74058 .26926 Mdot
.6409 .45771 Mdot
.87371 .3961 Mdot
.39718 .53999 Mdot
.94457 .24547 Mdot
.10725 .58377 Mdot
.42089 .06628 Mdot
.73123 .26013 Mdot
.6529 .45193 Mdot
.85785 .40352 Mdot
.44415 .53018 Mdot
.9686 .2745 Mdot
.03924 .59863 Mdot
.20874 .02425 Mdot
.41195 .12901 Mdot
.75592 .2546 Mdot
.60542 .46718 Mdot
.9106 .37417 Mdot
.27837 .56278 Mdot
.80877 .17204 Mdot
.454 .49985 Mdot
.9578 .28059 Mdot
.0796 .59196 Mdot
.33989 .0492 Mdot
.64876 .21006 Mdot
.74508 .40096 Mdot
.6967 .46048 Mdot
.80516 .43058 Mdot
.58778 .49761 Mdot
.9379 .36327 Mdot
.18645 .57965 Mdot
.6305 .11523 Mdot
.71792 .38967 Mdot
.73804 .4437 Mdot
.73011 .45614 Mdot
.74998 .45123 Mdot
.71206 .46351 Mdot
.78328 .44007 Mdot
.64043 .48409 Mdot
.88702 .39581 Mdot
.35921 .54821 Mdot
.91316 .222 Mdot
.19663 .56436 Mdot
.64686 .12152 Mdot
.70419 .39978 Mdot
.76453 .43521 Mdot
.67638 .4725 Mdot
.83916 .41803 Mdot
.49988 .51863 Mdot
.97562 .30894 Mdot
.03112 .60297 Mdot
.18234 .01923 Mdot
.34865 .11269 Mdot
.68998 .21548 Mdot
.69588 .42643 Mdot
.78982 .43008 Mdot
.62158 .48814 Mdot
.90724 .38416 Mdot
.29348 .56071 Mdot
.83233 .18138 Mdot
.40212 .51441 Mdot
.93596 .24853 Mdot
.13707 .57846 Mdot
.50352 .08471 Mdot
.76501 .31119 Mdot
.61522 .4728 Mdot
.90535 .38023 Mdot
.29733 .55954 Mdot
.83774 .18376 Mdot
.38974 .51775 Mdot
.92769 .24087 Mdot
.16007 .57335 Mdot
.56219 .09893 Mdot
.75837 .34746 Mdot
.64578 .4687 Mdot
.87388 .39911 Mdot
.39818 .54009 Mdot
.9454 .24609 Mdot
.10476 .58429 Mdot
.41373 .06474 Mdot
.72591 .2557 Mdot
.65981 .44864 Mdot
.84825 .40778 Mdot
.47156 .52425 Mdot
.97485 .29144 Mdot
.02538 .60249 Mdot
.16167 .01569 Mdot
.29562 .09992 Mdot
.61199 .1827 Mdot
.76724 .37823 Mdot
.64334 .47418 Mdot
.87915 .39761 Mdot
.38263 .54334 Mdot
.93391 .23648 Mdot
.1379 .57719 Mdot
.5052 .08523 Mdot
.76523 .31223 Mdot
.61529 .47294 Mdot
.90537 .38027 Mdot
.2973 .55955 Mdot
.8377 .18374 Mdot
.38983 .51773 Mdot
.92776 .24093 Mdot
.1599 .57338 Mdot
.56178 .09882 Mdot
.75851 .3472 Mdot
.64539 .46879 Mdot
.87434 .39887 Mdot
.39679 .54037 Mdot
.94444 .24523 Mdot
.10754 .5837 Mdot
.42173 .06647 Mdot
.73183 .26064 Mdot
.65212 .4523 Mdot
.85891 .40303 Mdot
.44107 .53084 Mdot
.96753 .2726 Mdot
.04203 .59797 Mdot
.21811 .02597 Mdot
.43314 .1348 Mdot
.77141 .26769 Mdot
.5813 .47676 Mdot
.93178 .35927 Mdot
.20441 .57587 Mdot
.67008 .12633 Mdot
.67923 .41413 Mdot
.80707 .41978 Mdot
.57817 .49879 Mdot
.9443 .35733 Mdot
.16242 .58361 Mdot
.5732 .10038 Mdot
.75366 .35426 Mdot
.65808 .46579 Mdot
.85861 .40672 Mdot
.44368 .53065 Mdot
.96861 .27421 Mdot
.03903 .59864 Mdot
.20802 .02412 Mdot
.41029 .12856 Mdot
.75456 .25357 Mdot
.6075 .46634 Mdot
.90856 .37546 Mdot
.28525 .56152 Mdot
.81955 .1763 Mdot
.43076 .50651 Mdot
.95059 .26623 Mdot
.09714 .5875 Mdot
.39231 .06004 Mdot
.70766 .24246 Mdot
.68284 .43736 Mdot
.81348 .42202 Mdot
.5644 .50276 Mdot
.95339 .34882 Mdot
.12779 .58922 Mdot
.48294 .07898 Mdot
.76084 .29847 Mdot
.61722 .47023 Mdot
.90239 .38147 Mdot
.30689 .5577 Mdot
.85123 .18967 Mdot
.35789 .52609 Mdot
.901 .22119 Mdot
.23325 .55685 Mdot
.72231 .14416 Mdot
.61169 .44641 Mdot
.8955 .37804 Mdot
.32577 .55345 Mdot
.87555 .20133 Mdot
.2975 .54112 Mdot
.82906 .18386 Mdot
.4114 .51239 Mdot
.94164 .25426 Mdot
.12122 .58197 Mdot
.46076 .07492 Mdot
.75382 .28477 Mdot
.62405 .46588 Mdot
.8942 .38569 Mdot
.33333 .55264 Mdot
.88497 .20601 Mdot
.27297 .54694 Mdot
.79188 .16871 Mdot
.49024 .48941 Mdot
.96093 .30298 Mdot
.07974 .59389 Mdot
.34126 .04928 Mdot
.65046 .21091 Mdot
.7436 .40201 Mdot
.6999 .45957 Mdot
.79999 .43256 Mdot
.60041 .49442 Mdot
.92761 .37108 Mdot
.22354 .57329 Mdot
.71029 .13815 Mdot
.62812 .43899 Mdot
.87735 .3882 Mdot
.38313 .54223 Mdot
.93382 .23679 Mdot
.13833 .57713 Mdot
.50635 .08549 Mdot
.76533 .31294 Mdot
.61544 .473 Mdot
.90527 .38036 Mdot
.29765 .55949 Mdot
.83821 .18396 Mdot
.38866 .51804 Mdot
.92691 .2402 Mdot
.16224 .57286 Mdot
.56754 .10027 Mdot
.75651 .35076 Mdot
.65096 .46755 Mdot
.86762 .40232 Mdot
.41709 .53622 Mdot
.95697 .25778 Mdot
.07139 .59144 Mdot
.31331 .04412 Mdot
.61121 .19363 Mdot
.77319 .37775 Mdot
.63111 .47786 Mdot
.89336 .39005 Mdot
.33792 .55212 Mdot
.89047 .20885 Mdot
.25842 .55034 Mdot
.76765 .15971 Mdot
.53646 .47443 Mdot
.94977 .33155 Mdot
.13161 .58699 Mdot
.49256 .08134 Mdot
.76303 .30442 Mdot
.61583 .47158 Mdot
.90424 .38061 Mdot
.30088 .55885 Mdot
.84283 .18595 Mdot
.37788 .5209 Mdot
.91866 .23354 Mdot
.18511 .56776 Mdot
.62155 .11441 Mdot
.72586 .38414 Mdot
.72225 .4486 Mdot
.75956 .44638 Mdot
.6915 .46943 Mdot
.817 .42737 Mdot
.55872 .50493 Mdot
.95698 .34531 Mdot
.11385 .59144 Mdot
.44405 .07036 Mdot
.74535 .27444 Mdot
.63478 .46065 Mdot
.88139 .39232 Mdot
.37368 .54473 Mdot
.92624 .23095 Mdot
.15988 .57245 Mdot
.56128 .09881 Mdot
.75873 .34689 Mdot
.64483 .46892 Mdot
.87501 .39852 Mdot
.39473 .54079 Mdot
.943 .24396 Mdot
.11171 .58281 Mdot
.4336 .06904 Mdot
.73973 .26798 Mdot
.6418 .45718 Mdot
.87252 .39666 Mdot
.40079 .53925 Mdot
.94701 .2477 Mdot
.10019 .58528 Mdot
.40046 .06192 Mdot
.71506 .2475 Mdot
.67365 .44193 Mdot
.82787 .41634 Mdot
.52718 .51165 Mdot
.96991 .32582 Mdot
.05954 .59944 Mdot
.27827 .0368 Mdot
.55328 .17198 Mdot
.79756 .34195 Mdot
.56184 .49292 Mdot
.94978 .34724 Mdot
.1392 .587 Mdot
.5135 .08603 Mdot
.76518 .31736 Mdot
.61789 .4729 Mdot
.9031 .38188 Mdot
.30492 .55815 Mdot
.84855 .18845 Mdot
.36431 .52443 Mdot
.907 .22515 Mdot
.21704 .56056 Mdot
.69034 .13414 Mdot
.6559 .42665 Mdot
.84215 .40537 Mdot
.48611 .52048 Mdot
.97557 .30043 Mdot
.02717 .60294 Mdot
.16828 .01679 Mdot
.31292 .10401 Mdot
.63972 .19339 Mdot
.74665 .39537 Mdot
.69111 .46145 Mdot
.81368 .42713 Mdot
.56641 .50288 Mdot
.95249 .35006 Mdot
.13144 .58867 Mdot
.49289 .08123 Mdot
.763 .30463 Mdot
.61599 .47156 Mdot
.9041 .3807 Mdot
.30135 .55876 Mdot
.8435 .18624 Mdot
.3763 .52131 Mdot
.91738 .23257 Mdot
.18865 .56697 Mdot
.62955 .11659 Mdot
.7195 .38908 Mdot
.7352 .44467 Mdot
.7356 .45438 Mdot
.73961 .45462 Mdot
.73263 .4571 Mdot
.74611 .45279 Mdot
.71997 .46112 Mdot
.76939 .44496 Mdot
.67142 .47551 Mdot
.84702 .41496 Mdot
.47824 .52349 Mdot
.97585 .29557 Mdot
.02382 .60311 Mdot
.15638 .01472 Mdot
.28149 .09665 Mdot
.58772 .17397 Mdot
.78083 .36323 Mdot
.60827 .48258 Mdot
.91582 .37593 Mdot
.26308 .56601 Mdot
.78372 .16259 Mdot
.5048 .48437 Mdot
.95899 .31198 Mdot
.09078 .59269 Mdot
.37528 .0561 Mdot
.69059 .23194 Mdot
.70301 .42681 Mdot
.77944 .43448 Mdot
.64578 .48172 Mdot
.8802 .39911 Mdot
.38037 .54399 Mdot
.93218 .23508 Mdot
.14283 .57612 Mdot
.51807 .08827 Mdot
.7658 .32019 Mdot
.61804 .47329 Mdot
.90317 .38197 Mdot
.30478 .55819 Mdot
.84836 .18837 Mdot
.36476 .52431 Mdot
.90742 .22544 Mdot
.21591 .56082 Mdot
.68803 .13344 Mdot
.6588 .42523 Mdot
.83807 .40716 Mdot
.49735 .51796 Mdot
.97523 .30738 Mdot
.03176 .60273 Mdot
.18449 .01963 Mdot
.35399 .11402 Mdot
.69669 .21878 Mdot
.68784 .43058 Mdot
.8033 .42511 Mdot
.58934 .49647 Mdot
.93633 .36423 Mdot
.19205 .57868 Mdot
.64321 .1187 Mdot
.70673 .39753 Mdot
.75955 .43678 Mdot
.68686 .46943 Mdot
.82352 .42451 Mdot
.54172 .50896 Mdot
.96507 .3348 Mdot
.08081 .59645 Mdot
.34592 .04995 Mdot
.65635 .21379 Mdot
.73831 .40565 Mdot
.71117 .4563 Mdot
.78118 .43953 Mdot
.64459 .48279 Mdot
.882 .39838 Mdot
.37489 .5451 Mdot
.92758 .23169 Mdot
.15597 .57328 Mdot
.55156 .0964 Mdot
.76152 .34088 Mdot
.63649 .47065 Mdot
.88453 .39337 Mdot
.36521 .54667 Mdot
.91873 .22571 Mdot
.1811 .5678 Mdot
.61194 .11193 Mdot
.73293 .3782 Mdot
.70729 .45297 Mdot
.7856 .43713 Mdot
.63407 .48553 Mdot
.89418 .39187 Mdot
.33639 .55263 Mdot
.88882 .2079 Mdot
.26278 .54932 Mdot
.77507 .1624 Mdot
.52274 .47902 Mdot
.95483 .32307 Mdot
.11038 .59012 Mdot
.43323 .06822 Mdot
.73914 .26775 Mdot
.64275 .45681 Mdot
.87135 .39724 Mdot
.40433 .53852 Mdot
.94931 .24989 Mdot
.09353 .58671 Mdot
.38088 .05781 Mdot
.69664 .2354 Mdot
.69598 .43055 Mdot
.79168 .43014 Mdot
.61759 .48928 Mdot
.91132 .38169 Mdot
.2798 .56323 Mdot
.81139 .17293 Mdot
.44837 .50146 Mdot
.95643 .27711 Mdot
.08261 .59111 Mdot
.349 .05106 Mdot
.66048 .2157 Mdot
.73438 .4082 Mdot
.71931 .45387 Mdot
.76695 .44456 Mdot
.67612 .474 Mdot
.84022 .41787 Mdot
.4971 .51928 Mdot
.97587 .30723 Mdot
.02942 .60312 Mdot
.17639 .01818 Mdot
.3337 .10902 Mdot
.67011 .20624 Mdot
.71798 .41415 Mdot
.74983 .44374 Mdot
.70869 .46342 Mdot
.7885 .438 Mdot
.62828 .48732 Mdot
.90066 .3883 Mdot
.31537 .55664 Mdot
.86291 .19491 Mdot
.32927 .53331 Mdot
.87037 .2035 Mdot
.31298 .53792 Mdot
.85044 .19343 Mdot
.3618 .5256 Mdot
.90494 .2236 Mdot
.22254 .55928 Mdot
.70139 .13754 Mdot
.64145 .43348 Mdot
.86139 .39643 Mdot
.4312 .53237 Mdot
.96338 .26649 Mdot
.05356 .5954 Mdot
.25625 .0331 Mdot
.51259 .15837 Mdot
.80037 .3168 Mdot
.54337 .49465 Mdot
.95763 .33582 Mdot
.10702 .59184 Mdot
.42415 .06614 Mdot
.73311 .26214 Mdot
.65063 .45309 Mdot
.86098 .40211 Mdot
.43507 .53211 Mdot
.96526 .26889 Mdot
.04816 .59656 Mdot
.23852 .02977 Mdot
.477 .14741 Mdot
.79307 .2948 Mdot
.54885 .49015 Mdot
.95363 .33921 Mdot
.1223 .58937 Mdot
.46745 .07558 Mdot
.75605 .2889 Mdot
.6218 .46727 Mdot
.89691 .3843 Mdot
.32463 .55432 Mdot
.87446 .20063 Mdot
.30021 .54045 Mdot
.83288 .18554 Mdot
.40279 .51475 Mdot
.93662 .24894 Mdot
.13511 .57887 Mdot
.49833 .0835 Mdot
.76438 .30799 Mdot
.61492 .47241 Mdot
.90542 .38004 Mdot
.29704 .55958 Mdot
.83731 .18358 Mdot
.39073 .51749 Mdot
.9284 .24148 Mdot
.15811 .57378 Mdot
.55736 .09772 Mdot
.75988 .34447 Mdot
.64142 .46963 Mdot
.87897 .39642 Mdot
.38256 .54323 Mdot
.9338 .23643 Mdot
.13825 .57712 Mdot
.50612 .08545 Mdot
.76532 .3128 Mdot
.6154 .47299 Mdot
.90529 .38034 Mdot
.29756 .5595 Mdot
.83809 .1839 Mdot
.38894 .51797 Mdot
.92712 .24038 Mdot
.16168 .57299 Mdot
.56615 .09992 Mdot
.75701 .3499 Mdot
.64958 .46786 Mdot
.86931 .40146 Mdot
.41202 .53726 Mdot
.95413 .25464 Mdot
.07954 .58969 Mdot
.33858 .04916 Mdot
.64714 .20925 Mdot
.74646 .39995 Mdot
.69368 .46134 Mdot
.80996 .42871 Mdot
.57584 .50058 Mdot
.94648 .35589 Mdot
.15446 .58496 Mdot
.55328 .09546 Mdot
.76041 .34195 Mdot
.63916 .46996 Mdot
.88147 .39502 Mdot
.37475 .54478 Mdot
.9273 .23161 Mdot
.15684 .5731 Mdot
.55373 .09693 Mdot
.76096 .34223 Mdot
.63824 .4703 Mdot
.88258 .39446 Mdot
.37133 .54546 Mdot
.9243 .22949 Mdot
.16535 .57125 Mdot
.57466 .10219 Mdot
.75375 .35516 Mdot
.65835 .46584 Mdot
.85833 .40688 Mdot
.44451 .53047 Mdot
.9689 .27472 Mdot
.03829 .59881 Mdot
.20554 .02367 Mdot
.40457 .12703 Mdot
.74975 .25004 Mdot
.61483 .46337 Mdot
.9011 .37999 Mdot
.31002 .55691 Mdot
.85542 .19161 Mdot
.34778 .52868 Mdot
.8909 .21494 Mdot
.26012 .55061 Mdot
.7709 .16077 Mdot
.53044 .47644 Mdot
.95216 .32783 Mdot
.12174 .58847 Mdot
.46541 .07524 Mdot
.75534 .28764 Mdot
.62256 .46682 Mdot
.89601 .38476 Mdot
.32751 .55377 Mdot
.87801 .20241 Mdot
.29109 .54264 Mdot
.81979 .17991 Mdot
.43195 .50666 Mdot
.9513 .26696 Mdot
.09513 .58793 Mdot
.38636 .05879 Mdot
.70201 .23878 Mdot
.68967 .43386 Mdot
.80233 .42624 Mdot
.59208 .49587 Mdot
.93421 .36592 Mdot
.19977 .57737 Mdot
.66035 .12346 Mdot
.68977 .40812 Mdot
.7897 .4263 Mdot
.62002 .48806 Mdot
.90859 .3832 Mdot
.28891 .56154 Mdot
.82548 .17856 Mdot
.41759 .51017 Mdot
.94464 .25808 Mdot
.11312 .58382 Mdot
.43822 .06991 Mdot
.74245 .27083 Mdot
.6383 .45886 Mdot
.87697 .39449 Mdot
.38727 .542 Mdot
.93735 .23935 Mdot
.12808 .57931 Mdot
.47896 .07916 Mdot
.7603 .29601 Mdot
.61709 .46989 Mdot
.90234 .38138 Mdot
.307 .55767 Mdot
.85138 .18973 Mdot
.35754 .52618 Mdot
.90066 .22097 Mdot
.23416 .55664 Mdot
.72404 .14472 Mdot
.60908 .44748 Mdot
.89815 .37643 Mdot
.31713 .55508 Mdot
.86461 .196 Mdot
.32517 .53436 Mdot
.86549 .20096 Mdot
.32519 .5349 Mdot
.86578 .20098 Mdot
.32439 .53508 Mdot
.8648 .20048 Mdot
.32682 .53448 Mdot
.86774 .20199 Mdot
.31952 .53629 Mdot
.85879 .19747 Mdot
.34163 .53076 Mdot
.88463 .21114 Mdot
.27644 .54673 Mdot
.79771 .17085 Mdot
.47845 .49301 Mdot
.9611 .2957 Mdot
.07562 .59399 Mdot
.32816 .04673 Mdot
.63274 .20281 Mdot
.75826 .39105 Mdot
.66717 .46863 Mdot
.84903 .41233 Mdot
.47173 .52473 Mdot
.97512 .29155 Mdot
.02446 .60266 Mdot
.15845 .01512 Mdot
.28704 .09792 Mdot
.59742 .1774 Mdot
.7759 .36923 Mdot
.62143 .47953 Mdot
.9032 .38406 Mdot
.30569 .55821 Mdot
.84972 .18893 Mdot
.36149 .52516 Mdot
.9044 .22341 Mdot
.22409 .55895 Mdot
.70448 .1385 Mdot
.63725 .43539 Mdot
.86665 .39384 Mdot
.41563 .53562 Mdot
.95573 .25687 Mdot
.07517 .59068 Mdot
.32511 .04646 Mdot
.62857 .20093 Mdot
.76136 .38848 Mdot
.6599 .47055 Mdot
.85877 .40784 Mdot
.44378 .53075 Mdot
.96871 .27427 Mdot
.03873 .5987 Mdot
.207 .02393 Mdot
.40794 .12793 Mdot
.75261 .25212 Mdot
.61048 .46514 Mdot
.90558 .3773 Mdot
.2952 .55968 Mdot
.83452 .18244 Mdot
.3972 .51576 Mdot
.93282 .24548 Mdot
.1458 .57652 Mdot
.52626 .09011 Mdot
.76546 .32525 Mdot
.62117 .47308 Mdot
.9003 .3839 Mdot
.31432 .55642 Mdot
.86132 .19426 Mdot
.33326 .53232 Mdot
.87502 .20597 Mdot
.30122 .54079 Mdot
.83458 .18616 Mdot
.39884 .5158 Mdot
.93413 .2465 Mdot
.14206 .57732 Mdot
.51657 .0878 Mdot
.76574 .31926 Mdot
.61771 .47325 Mdot
.90344 .38176 Mdot
.30387 .55835 Mdot
.84708 .1878 Mdot
.36781 .52352 Mdot
.91015 .22732 Mdot
.20847 .5625 Mdot
.67263 .12884 Mdot
.6772 .41571 Mdot
.81051 .41854 Mdot
.56963 .50092 Mdot
.94994 .35205 Mdot
.141 .5871 Mdot
.51844 .08714 Mdot
.7652 .32041 Mdot
.61932 .47292 Mdot
.90186 .38276 Mdot
.30909 .55738 Mdot
.8543 .19103 Mdot
.35047 .52798 Mdot
.89366 .2166 Mdot
.25283 .55231 Mdot
.75825 .15626 Mdot
.55322 .46862 Mdot
.94158 .34191 Mdot
.16397 .58193 Mdot
.57634 .10134 Mdot
.75241 .3562 Mdot
.66138 .46502 Mdot
.85433 .40875 Mdot
.45606 .52801 Mdot
.9722 .28186 Mdot
.03011 .60085 Mdot
.17775 .01861 Mdot
.33723 .10986 Mdot
.67493 .20842 Mdot
.71286 .41713 Mdot
.7595 .44057 Mdot
.68881 .46939 Mdot
.82078 .42571 Mdot
.54889 .50727 Mdot
.96193 .33923 Mdot
.09388 .5945 Mdot
.38572 .05802 Mdot
.70107 .23839 Mdot
.69088 .43329 Mdot
.80034 .42699 Mdot
.59693 .49463 Mdot
.93024 .36892 Mdot
.21405 .57492 Mdot
.69086 .13229 Mdot
.65426 .42697 Mdot
.84419 .40436 Mdot
.48038 .52174 Mdot
.97537 .29689 Mdot
.02617 .60281 Mdot
.16466 .01618 Mdot
.30347 .10177 Mdot
.62485 .18755 Mdot
.75836 .38618 Mdot
.66461 .46869 Mdot
.85221 .41075 Mdot
.46263 .5267 Mdot
.97368 .28592 Mdot
.02685 .60177 Mdot
.16656 .01659 Mdot
.30849 .10294 Mdot
.63283 .19066 Mdot
.75226 .39111 Mdot
.6786 .46492 Mdot
.83255 .4194 Mdot
.51711 .51455 Mdot
.97282 .31959 Mdot
.04622 .60124 Mdot
.23415 .02857 Mdot
.46769 .14472 Mdot
.78967 .28905 Mdot
.55345 .48805 Mdot
.95092 .34205 Mdot
.13285 .5877 Mdot
.49637 .08211 Mdot
.76363 .30677 Mdot
.61581 .47195 Mdot
.90444 .38059 Mdot
.30026 .55897 Mdot
.84196 .18557 Mdot
.37991 .52036 Mdot
.92029 .2348 Mdot
.18061 .56877 Mdot
.61123 .11162 Mdot
.73337 .37776 Mdot
.70631 .45325 Mdot
.78723 .43653 Mdot
.63029 .48654 Mdot
.89835 .38954 Mdot
.32288 .55521 Mdot
.87254 .19955 Mdot
.30504 .53926 Mdot
.83955 .18852 Mdot
.38747 .51887 Mdot
.9263 .23947 Mdot
.16385 .57248 Mdot
.57144 .10126 Mdot
.75501 .35317 Mdot
.65499 .46662 Mdot
.86261 .4048 Mdot
.43197 .53312 Mdot
.96415 .26697 Mdot
.05109 .59588 Mdot
.24816 .03158 Mdot
.49663 .15337 Mdot
.79823 .30694 Mdot
.54336 .49333 Mdot
.95699 .33582 Mdot
.1092 .59145 Mdot
.4304 .06749 Mdot
.73729 .266 Mdot
.64519 .45567 Mdot
.86819 .39875 Mdot
.41379 .53657 Mdot
.95499 .25574 Mdot
.07716 .59021 Mdot
.33128 .04769 Mdot
.63724 .20474 Mdot
.75469 .39384 Mdot
.67533 .46643 Mdot
.83757 .41738 Mdot
.50357 .51765 Mdot
.97516 .31122 Mdot
.03387 .60268 Mdot
.19191 .02093 Mdot
.37215 .11861 Mdot
.71791 .23 Mdot
.66056 .44369 Mdot
.84496 .40825 Mdot
.4803 .52221 Mdot
.97559 .29684 Mdot
.02538 .60295 Mdot
.16188 .01568 Mdot
.29614 .10005 Mdot
.61286 .18302 Mdot
.76667 .37877 Mdot
.64473 .47383 Mdot
.8775 .39846 Mdot
.38771 .54232 Mdot
.93788 .23962 Mdot
.12646 .57964 Mdot
.47456 .07816 Mdot
.75897 .29329 Mdot
.61834 .46907 Mdot
.90086 .38215 Mdot
.31182 .55676 Mdot
.85792 .19271 Mdot
.34164 .53022 Mdot
.88438 .21114 Mdot
.27717 .54658 Mdot
.79887 .1713 Mdot
.47608 .49373 Mdot
.961 .29424 Mdot
.07524 .59393 Mdot
.3269 .0465 Mdot
.63097 .20204 Mdot
.7596 .38996 Mdot
.66405 .46946 Mdot
.85326 .4104 Mdot
.45969 .52734 Mdot
.97309 .2841 Mdot
.02806 .6014 Mdot
.17071 .01734 Mdot
.31926 .10551 Mdot
.64932 .19731 Mdot
.73827 .4013 Mdot
.70912 .45628 Mdot
.78436 .43826 Mdot
.63725 .48476 Mdot
.89061 .39384 Mdot
.34781 .55043 Mdot
.90149 .21496 Mdot
.22875 .55715 Mdot
.71327 .14137 Mdot
.62499 .44082 Mdot
.88116 .38627 Mdot
.37139 .54459 Mdot
.92394 .22953 Mdot
.16654 .57102 Mdot
.57755 .10293 Mdot
.7525 .35694 Mdot
.66157 .46507 Mdot
.85413 .40887 Mdot
.45666 .52788 Mdot
.97235 .28223 Mdot
.02978 .60094 Mdot
.17661 .0184 Mdot
.33433 .10915 Mdot
.67096 .20663 Mdot
.71708 .41468 Mdot
.75154 .44318 Mdot
.70523 .46448 Mdot
.79434 .43586 Mdot
.61454 .49093 Mdot
.91473 .37981 Mdot
.26836 .56533 Mdot
.79278 .16586 Mdot
.4869 .48997 Mdot
.96085 .30092 Mdot
.07898 .59384 Mdot
.33884 .04881 Mdot
.6473 .20942 Mdot
.74637 .40005 Mdot
.69389 .46128 Mdot
.80962 .42885 Mdot
.57669 .50037 Mdot
.94591 .35641 Mdot
.15663 .5846 Mdot
.55877 .0968 Mdot
.75884 .34534 Mdot
.64385 .46899 Mdot
.87609 .39792 Mdot
.39141 .54145 Mdot
.9406 .2419 Mdot
.11866 .58132 Mdot
.45309 .07334 Mdot
.75044 .28003 Mdot
.6281 .4638 Mdot
.88941 .38819 Mdot
.34855 .54969 Mdot
.902 .21542 Mdot
.22746 .55746 Mdot
.71076 .14058 Mdot
.62856 .43927 Mdot
.87707 .38847 Mdot
.38407 .54206 Mdot
.93458 .23737 Mdot
.13617 .5776 Mdot
.50064 .08416 Mdot
.76474 .30941 Mdot
.6149 .47264 Mdot
.90555 .38003 Mdot
.29663 .55966 Mdot
.83672 .18333 Mdot
.3921 .51712 Mdot
.92936 .24233 Mdot
.15544 .57438 Mdot
.55069 .09606 Mdot
.76168 .34035 Mdot
.63592 .47074 Mdot
.88514 .39302 Mdot
.36326 .54705 Mdot
.91689 .22451 Mdot
.18625 .56667 Mdot
.62371 .11511 Mdot
.72423 .38548 Mdot
.72562 .4476 Mdot
.75345 .44846 Mdot
.7042 .46566 Mdot
.79649 .43522 Mdot
.60949 .49226 Mdot
.91954 .37669 Mdot
.25183 .56831 Mdot
.76413 .15564 Mdot
.54146 .47226 Mdot
.94733 .33464 Mdot
.14129 .58549 Mdot
.51846 .08732 Mdot
.76529 .32043 Mdot
.61916 .47297 Mdot
.90203 .38266 Mdot
.30853 .55749 Mdot
.85353 .19068 Mdot
.35232 .52751 Mdot
.89554 .21775 Mdot
.24785 .55347 Mdot
.74939 .15318 Mdot
.56848 .46315 Mdot
.93219 .35134 Mdot
.19924 .57612 Mdot
.65854 .12314 Mdot
.69174 .407 Mdot
.78635 .42752 Mdot
.6278 .48599 Mdot
.90047 .388 Mdot
.3158 .55652 Mdot
.86345 .19518 Mdot
.32792 .53364 Mdot
.86877 .20267 Mdot
.31699 .53693 Mdot
.85561 .19591 Mdot
.34936 .52879 Mdot
.89279 .21592 Mdot
.25507 .55177 Mdot
.76216 .15764 Mdot
.54629 .47104 Mdot
.94523 .33763 Mdot
.14977 .58418 Mdot
.54057 .09256 Mdot
.76329 .33409 Mdot
.62974 .47174 Mdot
.89171 .3892 Mdot
.34235 .5511 Mdot
.89537 .21158 Mdot
.24534 .55337 Mdot
.7445 .15163 Mdot
.57672 .46013 Mdot
.92635 .35643 Mdot
.22044 .57252 Mdot
.70339 .13624 Mdot
.63781 .43472 Mdot
.86575 .39419 Mdot
.41825 .53506 Mdot
.95715 .25849 Mdot
.07113 .59155 Mdot
.31251 .04396 Mdot
.61 .19314 Mdot
.77394 .377 Mdot
.62921 .47832 Mdot
.8954 .38888 Mdot
.33131 .55339 Mdot
.88276 .20476 Mdot
.27872 .54558 Mdot
.801 .17226 Mdot
.47179 .49505 Mdot
.96073 .29158 Mdot
.07489 .59376 Mdot
.32572 .04629 Mdot
.62931 .20131 Mdot
.76085 .38893 Mdot
.66112 .47023 Mdot
.85717 .4086 Mdot
.44844 .52976 Mdot
.97019 .27715 Mdot
.03491 .59961 Mdot
.19409 .02157 Mdot
.37751 .11995 Mdot
.7237 .23332 Mdot
.65265 .44727 Mdot
.85587 .40336 Mdot
.44935 .52896 Mdot
.97017 .27771 Mdot
.03527 .5996 Mdot
.19535 .0218 Mdot
.38055 .12073 Mdot
.72689 .23519 Mdot
.64822 .44924 Mdot
.86178 .40062 Mdot
.43219 .53261 Mdot
.96402 .26711 Mdot
.05163 .5958 Mdot
.24992 .03191 Mdot
.50016 .15446 Mdot
.79886 .30911 Mdot
.54301 .49372 Mdot
.95728 .3356 Mdot
.10808 .59163 Mdot
.42718 .0668 Mdot
.73518 .26401 Mdot
.64794 .45436 Mdot
.86457 .40045 Mdot
.42453 .53433 Mdot
.9606 .26237 Mdot
.06115 .59368 Mdot
.28081 .03779 Mdot
.55802 .17355 Mdot
.79642 .34487 Mdot
.5658 .49221 Mdot
.9476 .34968 Mdot
.1477 .58565 Mdot
.53576 .09128 Mdot
.76396 .33112 Mdot
.62696 .47216 Mdot
.89454 .38748 Mdot
.33318 .55286 Mdot
.88489 .20591 Mdot
.27318 .54689 Mdot
.79222 .16884 Mdot
.48957 .48962 Mdot
.96097 .30257 Mdot
.0794 .59391 Mdot
.3402 .04907 Mdot
.64909 .21026 Mdot
.74481 .40116 Mdot
.69728 .46032 Mdot
.80422 .43094 Mdot
.59008 .49704 Mdot
.93611 .36469 Mdot
.19297 .57855 Mdot
.64528 .11926 Mdot
.70479 .3988 Mdot
.76313 .43559 Mdot
.67931 .47164 Mdot
.83486 .41984 Mdot
.51157 .51597 Mdot
.97402 .31617 Mdot
.04031 .60198 Mdot
.2141 .02491 Mdot
.42399 .13232 Mdot
.76515 .26204 Mdot
.59109 .47289 Mdot
.92372 .36532 Mdot
.23315 .57089 Mdot
.7289 .14409 Mdot
.60057 .45049 Mdot
.90617 .37117 Mdot
.29045 .56004 Mdot
.82722 .17951 Mdot
.41382 .51125 Mdot
.94271 .25575 Mdot
.1184 .58263 Mdot
.45297 .07317 Mdot
.75031 .27995 Mdot
.62829 .46372 Mdot
.88919 .38831 Mdot
.34926 .54955 Mdot
.90274 .21585 Mdot
.22541 .55793 Mdot
.70675 .13931 Mdot
.63418 .43679 Mdot
.87041 .39194 Mdot
.40435 .53794 Mdot
.94904 .2499 Mdot
.09443 .58654 Mdot
.38356 .05836 Mdot
.69934 .23706 Mdot
.69282 .43221 Mdot
.79705 .42818 Mdot
.60482 .49261 Mdot
.9234 .3738 Mdot
.23827 .57069 Mdot
.73908 .14726 Mdot
.58438 .45677 Mdot
.92022 .36116 Mdot
.24218 .56872 Mdot
.74582 .14968 Mdot
.57336 .46094 Mdot
.92859 .35436 Mdot
.21229 .5739 Mdot
.68654 .1312 Mdot
.6598 .4243 Mdot
.83645 .40778 Mdot
.50173 .51695 Mdot
.97483 .31009 Mdot
.03449 .60248 Mdot
.19402 .02132 Mdot
.37723 .11991 Mdot
.72341 .23314 Mdot
.65305 .44709 Mdot
.85534 .40361 Mdot
.4509 .52863 Mdot
.97061 .27867 Mdot
.03417 .59987 Mdot
.19161 .02112 Mdot
.37153 .11842 Mdot
.71721 .22962 Mdot
.66151 .44326 Mdot
.84362 .40883 Mdot
.48404 .52138 Mdot
.97575 .29915 Mdot
.02593 .60304 Mdot
.16391 .01603 Mdot
.30149 .1013 Mdot
.62165 .18633 Mdot
.76067 .3842 Mdot
.65917 .47012 Mdot
.85944 .40739 Mdot
.44178 .53116 Mdot
.96802 .27303 Mdot
.04056 .59827 Mdot
.21316 .02507 Mdot
.42203 .13174 Mdot
.7637 .26083 Mdot
.59337 .47199 Mdot
.92174 .36672 Mdot
.24007 .56967 Mdot
.74214 .14837 Mdot
.57943 .45867 Mdot
.9241 .35811 Mdot
.22843 .57113 Mdot
.71939 .14118 Mdot
.61503 .44461 Mdot
.89183 .38011 Mdot
.33758 .55118 Mdot
.8896 .20864 Mdot
.26086 .5498 Mdot
.77185 .16122 Mdot
.52873 .47703 Mdot
.9528 .32678 Mdot
.11907 .58886 Mdot
.45793 .07359 Mdot
.75226 .28302 Mdot
.62614 .46492 Mdot
.8918 .38698 Mdot
.341 .55116 Mdot
.89377 .21075 Mdot
.24966 .55238 Mdot
.7523 .1543 Mdot
.56358 .46495 Mdot
.93541 .34831 Mdot
.1873 .57812 Mdot
.63177 .11576 Mdot
.71694 .39046 Mdot
.74002 .44309 Mdot
.7263 .45735 Mdot
.75704 .44888 Mdot
.69757 .46788 Mdot
.80746 .43112 Mdot
.58276 .49904 Mdot
.94172 .36017 Mdot
.17237 .58201 Mdot
.59747 .10653 Mdot
.74147 .36926 Mdot
.68786 .45825 Mdot
.81671 .42512 Mdot
.5583 .50476 Mdot
.95707 .34505 Mdot
.11341 .5915 Mdot
.4428 .07009 Mdot
.74467 .27366 Mdot
.63566 .46023 Mdot
.88031 .39286 Mdot
.37703 .54406 Mdot
.92911 .23301 Mdot
.15173 .57422 Mdot
.54091 .09378 Mdot
.76378 .3343 Mdot
.62888 .47204 Mdot
.89267 .38867 Mdot
.33926 .5517 Mdot
.89191 .20967 Mdot
.25461 .55123 Mdot
.76104 .15735 Mdot
.54833 .47035 Mdot
.9442 .33889 Mdot
.15381 .58355 Mdot
.55091 .09506 Mdot
.76111 .34048 Mdot
.63709 .47039 Mdot
.8838 .39374 Mdot
.36748 .54622 Mdot
.92083 .22712 Mdot
.17517 .56911 Mdot
.59813 .10826 Mdot
.74183 .36966 Mdot
.68739 .45848 Mdot
.81747 .42483 Mdot
.55636 .50523 Mdot
.9581 .34385 Mdot
.10929 .59214 Mdot
.43101 .06755 Mdot
.73764 .26638 Mdot
.64474 .45589 Mdot
.86877 .39847 Mdot
.41204 .53693 Mdot
.95399 .25466 Mdot
.08003 .5896 Mdot
.34011 .04946 Mdot
.64916 .2102 Mdot
.7447 .4012 Mdot
.6975 .46025 Mdot
.80387 .43108 Mdot
.59095 .49682 Mdot
.93543 .36523 Mdot
.19546 .57813 Mdot
.65084 .1208 Mdot
.69944 .40224 Mdot
.77285 .43228 Mdot
.65827 .47765 Mdot
.86415 .40683 Mdot
.42876 .53407 Mdot
.96288 .26499 Mdot
.05454 .59509 Mdot
.25941 .0337 Mdot
.51868 .16032 Mdot
.8007 .32056 Mdot
.54446 .49486 Mdot
.95738 .3365 Mdot
.10818 .5917 Mdot
.4275 .06686 Mdot
.73539 .26421 Mdot
.64767 .45449 Mdot
.86493 .40028 Mdot
.42346 .53455 Mdot
.96008 .26172 Mdot
.06261 .59336 Mdot
.28549 .03869 Mdot
.56616 .17644 Mdot
.79415 .34991 Mdot
.57323 .49081 Mdot
.94316 .35428 Mdot
.16473 .5829 Mdot
.57875 .10181 Mdot
.75127 .35769 Mdot
.66424 .46431 Mdot
.85053 .41052 Mdot
.46694 .52565 Mdot
.97439 .28858 Mdot
.02563 .6022 Mdot
.16243 .01584 Mdot
.29762 .10038 Mdot
.61531 .18394 Mdot
.76506 .38028 Mdot
.64866 .47283 Mdot
.87274 .40089 Mdot
.40222 .53938 Mdot
.94816 .24859 Mdot
.09676 .586 Mdot
.3904 .0598 Mdot
.70595 .24128 Mdot
.6849 .4363 Mdot
.81016 .42329 Mdot
.57275 .5007 Mdot
.94822 .35398 Mdot
.14772 .58603 Mdot
.53601 .0913 Mdot
.76391 .33127 Mdot
.62715 .47212 Mdot
.89435 .3876 Mdot
.3338 .55274 Mdot
.88561 .2063 Mdot
.27127 .54734 Mdot
.78913 .16765 Mdot
.49569 .48771 Mdot
.96048 .30635 Mdot
.08292 .59361 Mdot
.35118 .05124 Mdot
.66306 .21704 Mdot
.73194 .40979 Mdot
.72434 .45236 Mdot
.75791 .44767 Mdot
.69531 .46842 Mdot
.81103 .42973 Mdot
.57385 .50124 Mdot
.94789 .35466 Mdot
.14914 .58583 Mdot
.53969 .09217 Mdot
.76335 .33355 Mdot
.62935 .47178 Mdot
.89209 .38896 Mdot
.3411 .55134 Mdot
.89398 .21081 Mdot
.24908 .55251 Mdot
.75126 .15394 Mdot
.56536 .4643 Mdot
.93426 .34941 Mdot
.19157 .57741 Mdot
.64147 .1184 Mdot
.70842 .39645 Mdot
.75641 .43783 Mdot
.69341 .46749 Mdot
.81332 .42855 Mdot
.56793 .50266 Mdot
.95164 .351 Mdot
.13476 .58814 Mdot
.50187 .08329 Mdot
.76433 .31017 Mdot
.61608 .47238 Mdot
.90441 .38076 Mdot
.30042 .55896 Mdot
.84219 .18567 Mdot
.37936 .5205 Mdot
.91985 .23446 Mdot
.18182 .5685 Mdot
.61402 .11237 Mdot
.73141 .37949 Mdot
.71054 .45204 Mdot
.7801 .43914 Mdot
.64666 .48213 Mdot
.87944 .39966 Mdot
.38278 .54353 Mdot
.93413 .23657 Mdot
.13722 .57733 Mdot
.50339 .08481 Mdot
.76506 .31111 Mdot
.61509 .47283 Mdot
.90548 .38015 Mdot
.2969 .55962 Mdot
.83713 .1835 Mdot
.39116 .51737 Mdot
.9287 .24175 Mdot
.15726 .57397 Mdot
.55525 .09719 Mdot
.76049 .34316 Mdot
.63961 .47001 Mdot
.88103 .3953 Mdot
.37615 .54451 Mdot
.92849 .23247 Mdot
.15344 .57384 Mdot
.54521 .09483 Mdot
.76297 .33696 Mdot
.63176 .47154 Mdot
.88966 .39045 Mdot
.34894 .54984 Mdot
.90251 .21565 Mdot
.22602 .55778 Mdot
.70793 .13969 Mdot
.63254 .43752 Mdot
.87238 .39093 Mdot
.39839 .53916 Mdot
.94511 .24622 Mdot
.10579 .58411 Mdot
.41671 .06538 Mdot
.72817 .25754 Mdot
.65689 .45003 Mdot
.85236 .40598 Mdot
.45992 .52679 Mdot
.97289 .28425 Mdot
.02882 .60128 Mdot
.17338 .01781 Mdot
.32611 .10716 Mdot
.65937 .20155 Mdot
.72882 .40752 Mdot
.72858 .45044 Mdot
.74983 .45028 Mdot
.71187 .46342 Mdot
.78353 .43996 Mdot
.63985 .48425 Mdot
.8877 .39545 Mdot
.35707 .54863 Mdot
.91104 .22068 Mdot
.2025 .56306 Mdot
.65958 .12515 Mdot
.69149 .40764 Mdot
.78702 .42737 Mdot
.6263 .4864 Mdot
.90208 .38707 Mdot
.31054 .55751 Mdot
.85645 .19192 Mdot
.34518 .52931 Mdot
.88817 .21334 Mdot
.26728 .54892 Mdot
.78292 .16519 Mdot
.50776 .48387 Mdot
.95866 .31381 Mdot
.0928 .59248 Mdot
.38144 .05736 Mdot
.69694 .23575 Mdot
.69571 .43073 Mdot
.79215 .42997 Mdot
.61647 .48958 Mdot
.91243 .381 Mdot
.27607 .56391 Mdot
.80542 .17062 Mdot
.46099 .49778 Mdot
.95915 .28491 Mdot
.07709 .59279 Mdot
.33229 .04764 Mdot
.63852 .20537 Mdot
.75369 .39463 Mdot
.67761 .46581 Mdot
.83429 .41879 Mdot
.51248 .51562 Mdot
.97379 .31673 Mdot
.04143 .60183 Mdot
.21791 .0256 Mdot
.43252 .13467 Mdot
.77103 .26731 Mdot
.58189 .47652 Mdot
.93131 .35963 Mdot
.20608 .57558 Mdot
.67369 .12737 Mdot
.67513 .41636 Mdot
.81354 .41725 Mdot
.56194 .5028 Mdot
.95453 .3473 Mdot
.12315 .58993 Mdot
.47016 .07611 Mdot
.75699 .29057 Mdot
.62083 .46785 Mdot
.89806 .38369 Mdot
.3209 .55503 Mdot
.86978 .19833 Mdot
.31212 .53755 Mdot
.84903 .1929 Mdot
.36522 .52473 Mdot
.90809 .22572 Mdot
.21399 .56123 Mdot
.68409 .13226 Mdot
.66367 .42279 Mdot
.83107 .41017 Mdot
.5163 .51363 Mdot
.97247 .31909 Mdot
.04724 .60102 Mdot
.23753 .0292 Mdot
.47477 .1468 Mdot
.79233 .29342 Mdot
.54979 .48969 Mdot
.95307 .33979 Mdot
.12446 .58903 Mdot
.47345 .07692 Mdot
.75814 .29261 Mdot
.61961 .46855 Mdot
.89948 .38294 Mdot
.3163 .55591 Mdot
.86385 .19549 Mdot
.32698 .53389 Mdot
.86766 .20208 Mdot
.31978 .53624 Mdot
.85913 .19764 Mdot
.3408 .53097 Mdot
.88373 .21063 Mdot
.27879 .54617 Mdot
.80141 .1723 Mdot
.47088 .4953 Mdot
.96064 .29102 Mdot
.07492 .59371 Mdot
.32578 .0463 Mdot
.62939 .20134 Mdot
.76079 .38898 Mdot
.66127 .47019 Mdot
.85697 .40869 Mdot
.449 .52964 Mdot
.97036 .2775 Mdot
.03449 .59972 Mdot
.19266 .02131 Mdot
.37408 .11907 Mdot
.72 .23119 Mdot
.65773 .44499 Mdot
.84893 .4065 Mdot
.46917 .52467 Mdot
.97448 .28996 Mdot
.02597 .60226 Mdot
.16368 .01605 Mdot
.30093 .10116 Mdot
.62074 .18598 Mdot
.76133 .38364 Mdot
.65762 .47053 Mdot
.86145 .40643 Mdot
.4359 .5324 Mdot
.96582 .2694 Mdot
.04647 .59691 Mdot
.23289 .02872 Mdot
.46521 .14393 Mdot
.78863 .28752 Mdot
.55496 .4874 Mdot
.95001 .34298 Mdot
.13636 .58714 Mdot
.50579 .08428 Mdot
.76476 .31259 Mdot
.61641 .47265 Mdot
.90426 .38096 Mdot
.30098 .55887 Mdot
.84298 .18601 Mdot
.3775 .52099 Mdot
.91836 .23331 Mdot
.18595 .56758 Mdot
.62344 .11492 Mdot
.72439 .38531 Mdot
.72527 .4477 Mdot
.75409 .44824 Mdot
.70289 .46605 Mdot
.79867 .43441 Mdot
.60426 .4936 Mdot
.92431 .37345 Mdot
.2352 .57126 Mdot
.73322 .14536 Mdot
.59376 .45316 Mdot
.91233 .36696 Mdot
.26954 .56385 Mdot
.79414 .16659 Mdot
.48428 .4908 Mdot
.96093 .2993 Mdot
.07792 .59389 Mdot
.33548 .04816 Mdot
.6428 .20734 Mdot
.75019 .39727 Mdot
.68547 .46364 Mdot
.82264 .42365 Mdot
.54344 .50842 Mdot
.96429 .33586 Mdot
.08406 .59596 Mdot
.35594 .05195 Mdot
.66871 .21998 Mdot
.7264 .41329 Mdot
.73548 .44894 Mdot
.73717 .45455 Mdot
.73693 .45559 Mdot
.73785 .45545 Mdot
.73616 .45602 Mdot
.73942 .45497 Mdot
.73313 .45699 Mdot
.74518 .4531 Mdot
.72182 .46055 Mdot
.76607 .44611 Mdot
.67862 .47346 Mdot
.83667 .41941 Mdot
.50682 .51709 Mdot
.97482 .31323 Mdot
.03607 .60247 Mdot
.19955 .02229 Mdot
.39041 .12333 Mdot
.7368 .24128 Mdot
.63406 .45537 Mdot
.87954 .39187 Mdot
.37872 .54359 Mdot
.93046 .23406 Mdot
.1479 .57505 Mdot
.53115 .09141 Mdot
.76511 .32827 Mdot
.62332 .47286 Mdot
.89825 .38523 Mdot
.32109 .55515 Mdot
.87009 .19845 Mdot
.31131 .53775 Mdot
.84796 .1924 Mdot
.36776 .52407 Mdot
.91036 .22729 Mdot
.20782 .56263 Mdot
.67125 .12844 Mdot
.67877 .41486 Mdot
.80803 .4195 Mdot
.57582 .49939 Mdot
.94592 .35588 Mdot
.15634 .58461 Mdot
.55803 .09663 Mdot
.75907 .34488 Mdot
.64318 .46913 Mdot
.87687 .39751 Mdot
.38902 .54193 Mdot
.93882 .24043 Mdot
.1238 .58022 Mdot
.46728 .07651 Mdot
.75646 .2888 Mdot
.62098 .46752 Mdot
.89777 .38379 Mdot
.32182 .55485 Mdot
.87094 .1989 Mdot
.30918 .53827 Mdot
.84515 .19108 Mdot
.3744 .52233 Mdot
.91606 .23139 Mdot
.19217 .56616 Mdot
.63741 .11877 Mdot
.71279 .39394 Mdot
.74835 .44053 Mdot
.70988 .46251 Mdot
.7862 .43873 Mdot
.63357 .4859 Mdot
.89485 .39157 Mdot
.33426 .55305 Mdot
.88635 .20659 Mdot
.26927 .5478 Mdot
.78587 .16642 Mdot
.50208 .4857 Mdot
.95966 .31031 Mdot
.08766 .5931 Mdot
.3658 .05417 Mdot
.68027 .22607 Mdot
.71439 .42043 Mdot
.75866 .44152 Mdot
.69088 .46888 Mdot
.81762 .42699 Mdot
.55706 .50531 Mdot
.95786 .34428 Mdot
.11034 .59199 Mdot
.43402 .06819 Mdot
.73954 .26824 Mdot
.64228 .45706 Mdot
.87196 .39695 Mdot
.40249 .5389 Mdot
.94813 .24876 Mdot
.09694 .58598 Mdot
.39096 .05991 Mdot
.70648 .24163 Mdot
.68425 .43663 Mdot
.8112 .42289 Mdot
.57014 .50135 Mdot
.94989 .35236 Mdot
.14131 .58707 Mdot
.51928 .08733 Mdot
.76519 .32093 Mdot
.6196 .47291 Mdot
.90162 .38293 Mdot
.30991 .55723 Mdot
.8554 .19153 Mdot
.34778 .52867 Mdot
.89089 .21494 Mdot
.26013 .5506 Mdot
.77091 .16077 Mdot
.53041 .47645 Mdot
.95217 .32781 Mdot
.12169 .58848 Mdot
.46528 .07521 Mdot
.75529 .28756 Mdot
.62261 .46679 Mdot
.89595 .3848 Mdot
.32772 .55373 Mdot
.87826 .20254 Mdot
.29043 .5428 Mdot
.81882 .1795 Mdot
.43407 .50606 Mdot
.95211 .26827 Mdot
.09302 .58843 Mdot
.38015 .05749 Mdot
.69582 .23494 Mdot
.69696 .43004 Mdot
.79 .43074 Mdot
.62153 .48825 Mdot
.90734 .38413 Mdot
.29318 .56077 Mdot
.83188 .18119 Mdot
.40316 .51413 Mdot
.9366 .24917 Mdot
.1353 .57885 Mdot
.49883 .08362 Mdot
.76444 .3083 Mdot
.61494 .47245 Mdot
.90542 .38005 Mdot
.29702 .55958 Mdot
.83729 .18357 Mdot
.39079 .51747 Mdot
.92844 .24152 Mdot
.15799 .57381 Mdot
.55704 .09764 Mdot
.75997 .34427 Mdot
.64114 .46969 Mdot
.87928 .39625 Mdot
.38158 .54343 Mdot
.933 .23583 Mdot
.14053 .57663 Mdot
.51209 .08685 Mdot
.76569 .31649 Mdot
.61646 .47322 Mdot
.9045 .38099 Mdot
.30028 .55901 Mdot
.84199 .18558 Mdot
.37983 .52038 Mdot
.92022 .23475 Mdot
.18081 .56873 Mdot
.61168 .11174 Mdot
.73306 .37804 Mdot
.70699 .45305 Mdot
.7861 .43694 Mdot
.6329 .48584 Mdot
.89547 .39116 Mdot
.33221 .55343 Mdot
.88393 .20531 Mdot
.27564 .5463 Mdot
.79615 .17036 Mdot
.48168 .49205 Mdot
.96116 .29769 Mdot
.07635 .59403 Mdot
.33054 .04719 Mdot
.63605 .20428 Mdot
.75568 .3931 Mdot
.67311 .46703 Mdot
.84075 .416 Mdot
.49484 .51961 Mdot
.97592 .30583 Mdot
.02855 .60315 Mdot
.17331 .01764 Mdot
.32585 .10711 Mdot
.65901 .20139 Mdot
.72918 .40729 Mdot
.72786 .45066 Mdot
.75116 .44984 Mdot
.70919 .46424 Mdot
.78813 .4383 Mdot
.62922 .48709 Mdot
.89965 .38888 Mdot
.31869 .55601 Mdot
.86722 .19696 Mdot
.31849 .53597 Mdot
.85722 .19684 Mdot
.34552 .52979 Mdot
.8888 .21354 Mdot
.26557 .54931 Mdot
.78007 .16413 Mdot
.51323 .48211 Mdot
.95746 .31719 Mdot
.09855 .59174 Mdot
.39865 .06091 Mdot
.71317 .24638 Mdot
.67612 .44076 Mdot
.8241 .41786 Mdot
.53711 .50932 Mdot
.96654 .33195 Mdot
.07432 .59735 Mdot
.32564 .04593 Mdot
.62903 .20126 Mdot
.76109 .38876 Mdot
.66057 .47038 Mdot
.8579 .40825 Mdot
.44631 .53021 Mdot
.96954 .27584 Mdot
.03658 .59921 Mdot
.19976 .02261 Mdot
.39104 .12346 Mdot
.73739 .24168 Mdot
.63319 .45573 Mdot
.88058 .39134 Mdot
.37552 .54423 Mdot
.92776 .23208 Mdot
.15559 .57339 Mdot
.55061 .09616 Mdot
.76175 .3403 Mdot
.63575 .47079 Mdot
.88534 .39292 Mdot
.36265 .54717 Mdot
.91631 .22413 Mdot
.18787 .56631 Mdot
.62739 .11611 Mdot
.72131 .38775 Mdot
.73156 .4458 Mdot
.74246 .45213 Mdot
.7263 .45886 Mdot
.75778 .44888 Mdot
.69614 .46834 Mdot
.80978 .43024 Mdot
.577 .50047 Mdot
.94578 .35661 Mdot
.15716 .58452 Mdot
.5601 .09713 Mdot
.75843 .34616 Mdot
.64504 .46874 Mdot
.87469 .39866 Mdot
.3957 .54059 Mdot
.94368 .24455 Mdot
.10975 .58323 Mdot
.42803 .06783 Mdot
.73616 .26454 Mdot
.64647 .45497 Mdot
.86646 .39954 Mdot
.41892 .5355 Mdot
.95778 .25891 Mdot
.06917 .59194 Mdot
.30633 .04275 Mdot
.60045 .18932 Mdot
.77948 .3711 Mdot
.61492 .48175 Mdot
.90995 .38004 Mdot
.2832 .56238 Mdot
.81661 .17503 Mdot
.43714 .50469 Mdot
.95298 .27017 Mdot
.09098 .58897 Mdot
.37412 .05623 Mdot
.68954 .23122 Mdot
.70414 .42616 Mdot
.7774 .43518 Mdot
.65034 .48046 Mdot
.87458 .40193 Mdot
.3976 .54052 Mdot
.94515 .24573 Mdot
.10542 .58414 Mdot
.41561 .06515 Mdot
.72735 .25686 Mdot
.65795 .44953 Mdot
.85088 .40663 Mdot
.46413 .52587 Mdot
.97372 .28685 Mdot
.02716 .60179 Mdot
.16769 .01679 Mdot
.31142 .10364 Mdot
.63741 .19247 Mdot
.74857 .39394 Mdot
.68688 .46264 Mdot
.82021 .42451 Mdot
.54969 .50692 Mdot
.96147 .33972 Mdot
.09569 .59422 Mdot
.39112 .05914 Mdot
.70624 .24173 Mdot
.68467 .43648 Mdot
.81055 .42315 Mdot
.57178 .50095 Mdot
.94885 .35338 Mdot
.14531 .58642 Mdot
.52976 .08981 Mdot
.76463 .32741 Mdot
.62385 .47257 Mdot
.89763 .38556 Mdot
.32311 .55476 Mdot
.87263 .19969 Mdot
.30486 .53932 Mdot
.83931 .18841 Mdot
.38803 .51872 Mdot
.92671 .23982 Mdot
.1627 .57274 Mdot
.56865 .10056 Mdot
.7561 .35144 Mdot
.65208 .46729 Mdot
.86624 .40301 Mdot
.42121 .53536 Mdot
.95912 .26032 Mdot
.06524 .59277 Mdot
.29386 .04032 Mdot
.58032 .18162 Mdot
.78909 .35866 Mdot
.58849 .48769 Mdot
.93262 .36371 Mdot
.20386 .57639 Mdot
.6691 .12599 Mdot
.68029 .41353 Mdot
.80535 .42044 Mdot
.58241 .49773 Mdot
.9413 .35995 Mdot
.17365 .58175 Mdot
.60051 .10732 Mdot
.73963 .37114 Mdot
.69205 .45712 Mdot
.81024 .42771 Mdot
.57471 .50075 Mdot
.94719 .35519 Mdot
.15177 .58539 Mdot
.54643 .0938 Mdot
.76206 .33772 Mdot
.63389 .47098 Mdot
.88729 .39177 Mdot
.35646 .54837 Mdot
.91026 .2203 Mdot
.20473 .56257 Mdot
.66435 .12653 Mdot
.68643 .41059 Mdot
.79556 .42424 Mdot
.60621 .49168 Mdot
.92187 .37466 Mdot
.24351 .56975 Mdot
.74891 .1505 Mdot
.56806 .46285 Mdot
.93225 .35108 Mdot
.19891 .57616 Mdot
.65781 .12293 Mdot
.69251 .40655 Mdot
.78504 .42799 Mdot
.63083 .48518 Mdot
.89718 .38987 Mdot
.32652 .55449 Mdot
.87706 .2018 Mdot
.29348 .54205 Mdot
.82328 .18138 Mdot
.42429 .50881 Mdot
.94808 .26223 Mdot
.10366 .58594 Mdot
.41123 .06406 Mdot
.7239 .25415 Mdot
.66244 .44739 Mdot
.8445 .40941 Mdot
.48204 .52193 Mdot
.97572 .29792 Mdot
.02541 .60303 Mdot
.16203 .0157 Mdot
.29655 .10014 Mdot
.61354 .18328 Mdot
.76623 .37919 Mdot
.64581 .47356 Mdot
.8762 .39914 Mdot
.3917 .54152 Mdot
.94087 .24208 Mdot
.11785 .58149 Mdot
.45085 .07284 Mdot
.74935 .27864 Mdot
.62945 .46312 Mdot
.8878 .38902 Mdot
.35366 .54869 Mdot
.90731 .21857 Mdot
.2129 .56075 Mdot
.68148 .13158 Mdot
.66689 .42118 Mdot
.82634 .41216 Mdot
.52888 .51071 Mdot
.96912 .32687 Mdot
.06282 .59895 Mdot
.28889 .03882 Mdot
.57172 .17855 Mdot
.79238 .35334 Mdot
.57878 .48972 Mdot
.93955 .3577 Mdot
.17832 .58067 Mdot
.61145 .11021 Mdot
.7325 .3779 Mdot
.70788 .45271 Mdot
.78455 .4375 Mdot
.63648 .48488 Mdot
.89145 .39337 Mdot
.34513 .55094 Mdot
.89861 .2133 Mdot
.23658 .55537 Mdot
.72827 .14621 Mdot
.60268 .4501 Mdot
.9044 .37248 Mdot
.29645 .55895 Mdot
.8361 .18321 Mdot
.39362 .51674 Mdot
.93042 .24327 Mdot
.15248 .57503 Mdot
.54327 .09424 Mdot
.76329 .33576 Mdot
.63054 .47174 Mdot
.89093 .3897 Mdot
.34485 .55063 Mdot
.89812 .21313 Mdot
.23793 .55507 Mdot
.73083 .14705 Mdot
.59872 .45167 Mdot
.9081 .37003 Mdot
.28401 .56124 Mdot
.81738 .17553 Mdot
.43556 .50517 Mdot
.95243 .26919 Mdot
.09237 .58863 Mdot
.37825 .05709 Mdot
.69387 .23377 Mdot
.69921 .42884 Mdot
.7861 .43214 Mdot
.63059 .48584 Mdot
.89773 .38972 Mdot
.32481 .55483 Mdot
.87495 .20075 Mdot
.29889 .54075 Mdot
.83101 .18472 Mdot
.40702 .51359 Mdot
.93916 .25155 Mdot
.12808 .58043 Mdot
.4795 .07916 Mdot
.76039 .29635 Mdot
.61707 .46995 Mdot
.90238 .38137 Mdot
.30686 .5577 Mdot
.85119 .18965 Mdot
.35799 .52606 Mdot
.9011 .22125 Mdot
.23298 .55691 Mdot
.72179 .14399 Mdot
.61246 .44609 Mdot
.8947 .37852 Mdot
.32836 .55296 Mdot
.87872 .20294 Mdot
.28933 .54308 Mdot
.8172 .17882 Mdot
.43759 .50506 Mdot
.95337 .27044 Mdot
.08978 .58922 Mdot
.37051 .05549 Mdot
.68565 .22899 Mdot
.70848 .42376 Mdot
.76957 .43787 Mdot
.66762 .47562 Mdot
.85186 .41261 Mdot
.46445 .52648 Mdot
.97411 .28705 Mdot
.02589 .60203 Mdot
.16326 .016 Mdot
.29981 .1009 Mdot
.61891 .18529 Mdot
.7626 .38251 Mdot
.65458 .47132 Mdot
.86535 .40455 Mdot
.42438 .53482 Mdot
.96075 .26228 Mdot
.06059 .59378 Mdot
.279 .03745 Mdot
.55483 .17243 Mdot
.79718 .3429 Mdot
.56316 .49268 Mdot
.94907 .34805 Mdot
.14199 .58656 Mdot
.52088 .08776 Mdot
.76518 .32192 Mdot
.6201 .47291 Mdot
.90117 .38324 Mdot
.3114 .55695 Mdot
.85742 .19246 Mdot
.34285 .52992 Mdot
.88569 .21189 Mdot
.27377 .54738 Mdot
.79348 .1692 Mdot
.48699 .4904 Mdot
.96107 .30098 Mdot
.07825 .59398 Mdot
.33658 .04836 Mdot
.64428 .20802 Mdot
.74895 .39819 Mdot
.68822 .46288 Mdot
.81845 .42534 Mdot
.55429 .50583 Mdot
.95922 .34257 Mdot
.10484 .59283 Mdot
.4181 .06479 Mdot
.72878 .2584 Mdot
.65628 .45041 Mdot
.85325 .4056 Mdot
.4574 .52734 Mdot
.97233 .28269 Mdot
.03005 .60094 Mdot
.17756 .01857 Mdot
.33674 .10974 Mdot
.67427 .20812 Mdot
.71357 .41672 Mdot
.75816 .44101 Mdot
.6916 .46857 Mdot
.81644 .42743 Mdot
.56005 .50459 Mdot
.95624 .34613 Mdot
.11678 .59099 Mdot
.45236 .07217 Mdot
.7496 .27957 Mdot
.62944 .46328 Mdot
.88789 .38901 Mdot
.35339 .54874 Mdot
.90704 .21841 Mdot
.21365 .56058 Mdot
.68304 .13204 Mdot
.66501 .42214 Mdot
.82912 .411 Mdot
.52151 .51243 Mdot
.97123 .32231 Mdot
.05319 .60025 Mdot
.25737 .03287 Mdot
.51454 .15906 Mdot
.80053 .318 Mdot
.54358 .49476 Mdot
.95761 .33595 Mdot
.10714 .59184 Mdot
.42447 .06621 Mdot
.73334 .26234 Mdot
.65034 .45323 Mdot
.86137 .40193 Mdot
.43393 .53235 Mdot
.9648 .26818 Mdot
.04944 .59628 Mdot
.24272 .03055 Mdot
.48563 .15001 Mdot
.79568 .30014 Mdot
.5457 .49176 Mdot
.95548 .33726 Mdot
.11505 .59052 Mdot
.44712 .07111 Mdot
.74702 .27633 Mdot
.63265 .46168 Mdot
.884 .391 Mdot
.36557 .54634 Mdot
.91894 .22593 Mdot
.18055 .56793 Mdot
.61067 .11159 Mdot
.7338 .37742 Mdot
.70539 .45351 Mdot
.78878 .43595 Mdot
.62669 .48749 Mdot
.90224 .38731 Mdot
.31015 .55762 Mdot
.85594 .19168 Mdot
.34642 .529 Mdot
.88948 .2141 Mdot
.26387 .54973 Mdot
.77723 .16308 Mdot
.51862 .48035 Mdot
.95605 .32052 Mdot
.10498 .59087 Mdot
.41759 .06488 Mdot
.72849 .25808 Mdot
.6566 .45023 Mdot
.85278 .4058 Mdot
.45872 .52705 Mdot
.97263 .2835 Mdot
.02938 .60112 Mdot
.1753 .01816 Mdot
.331 .10834 Mdot
.66633 .20457 Mdot
.72188 .41182 Mdot
.74231 .44615 Mdot
.72365 .45878 Mdot
.76217 .44724 Mdot
.68685 .47105 Mdot
.82432 .4245 Mdot
.53978 .50946 Mdot
.96588 .3336 Mdot
.07742 .59695 Mdot
.33537 .04785 Mdot
.64252 .20727 Mdot
.75045 .3971 Mdot
.6849 .46381 Mdot
.8235 .42329 Mdot
.54118 .50895 Mdot
.96523 .33447 Mdot
.08012 .59654 Mdot
.34375 .04951 Mdot
.65357 .21245 Mdot
.74085 .40393 Mdot
.7058 .45787 Mdot
.79026 .43621 Mdot
.6236 .48841 Mdot
.90554 .38541 Mdot
.29927 .55965 Mdot
.84078 .18496 Mdot
.38262 .51963 Mdot
.9224 .23647 Mdot
.17478 .57007 Mdot
.59762 .10802 Mdot
.74208 .36935 Mdot
.6868 .45863 Mdot
.81836 .42447 Mdot
.55407 .50578 Mdot
.95928 .34243 Mdot
.10456 .59287 Mdot
.41728 .06462 Mdot
.72817 .25789 Mdot
.65706 .45003 Mdot
.85215 .40609 Mdot
.46051 .52666 Mdot
.97302 .28461 Mdot
.02856 .60136 Mdot
.17248 .01765 Mdot
.32379 .1066 Mdot
.65601 .20011 Mdot
.73207 .40543 Mdot
.722 .45244 Mdot
.76184 .44622 Mdot
.68701 .47084 Mdot
.82401 .42459 Mdot
.54058 .50927 Mdot
.96555 .3341 Mdot
.0788 .59675 Mdot
.33966 .0487 Mdot
.64825 .20992 Mdot
.74558 .40064 Mdot
.69563 .46079 Mdot
.80686 .42992 Mdot
.58356 .49867 Mdot
.94105 .36066 Mdot
.1748 .5816 Mdot
.60328 .10803 Mdot
.73791 .37285 Mdot
.69596 .45605 Mdot
.80408 .43013 Mdot
.59 .49695 Mdot
.93612 .36464 Mdot
.19291 .57856 Mdot
.64516 .11923 Mdot
.70491 .39873 Mdot
.76292 .43566 Mdot
.67976 .47151 Mdot
.8342 .42012 Mdot
.51335 .51557 Mdot
.97369 .31727 Mdot
.04204 .60177 Mdot
.21999 .02598 Mdot
.43713 .13596 Mdot
.77399 .27016 Mdot
.57726 .47835 Mdot
.9349 .35677 Mdot
.19309 .5778 Mdot
.6452 .11934 Mdot
.70491 .39876 Mdot
.76293 .43566 Mdot
.67974 .47151 Mdot
.83423 .42011 Mdot
.51328 .51558 Mdot
.9737 .31722 Mdot
.04197 .60178 Mdot
.21975 .02594 Mdot
.4366 .13581 Mdot
.77366 .26983 Mdot
.57778 .47815 Mdot
.9345 .35709 Mdot
.19453 .57755 Mdot
.64841 .12022 Mdot
.70186 .40074 Mdot
.76851 .43377 Mdot
.66776 .47497 Mdot
.85137 .4127 Mdot
.46579 .52617 Mdot
.97433 .28788 Mdot
.02549 .60217 Mdot
.1619 .01575 Mdot
.29623 .10006 Mdot
.61301 .18308 Mdot
.76658 .37886 Mdot
.64495 .47377 Mdot
.87723 .3986 Mdot
.38853 .54216 Mdot
.93851 .24013 Mdot
.12465 .58003 Mdot
.46962 .07704 Mdot
.75731 .29024 Mdot
.62005 .46804 Mdot
.89885 .38321 Mdot
.31833 .55552 Mdot
.86648 .19674 Mdot
.32041 .53552 Mdot
.85963 .19803 Mdot
.33962 .53128 Mdot
.88245 .2099 Mdot
.28211 .54538 Mdot
.80656 .17435 Mdot
.46019 .49848 Mdot
.95924 .28441 Mdot
.07653 .59284 Mdot
.33053 .0473 Mdot
.63609 .20428 Mdot
.75563 .39312 Mdot
.6732 .46701 Mdot
.84062 .41606 Mdot
.49519 .51953 Mdot
.9759 .30605 Mdot
.02872 .60314 Mdot
.17393 .01775 Mdot
.32743 .10749 Mdot
.66127 .20236 Mdot
.72696 .40869 Mdot
.73231 .44929 Mdot
.74287 .45259 Mdot
.72578 .45912 Mdot
.75878 .44856 Mdot
.69408 .46895 Mdot
.81307 .42896 Mdot
.56873 .50251 Mdot
.95117 .35149 Mdot
.13659 .58785 Mdot
.50678 .08442 Mdot
.7648 .31321 Mdot
.61663 .47267 Mdot
.90409 .3811 Mdot
.30157 .55876 Mdot
.84383 .18638 Mdot
.3755 .52152 Mdot
.91672 .23207 Mdot
.19046 .56656 Mdot
.6336 .11771 Mdot
.7161 .39158 Mdot
.74192 .44257 Mdot
.72262 .45853 Mdot
.76376 .44661 Mdot
.68341 .47203 Mdot
.82953 .42237 Mdot
.52603 .51268 Mdot
.97062 .32511 Mdot
.0567 .59987 Mdot
.26899 .03504 Mdot
.53648 .16625 Mdot
.80017 .33156 Mdot
.55098 .49453 Mdot
.95499 .34052 Mdot
.1183 .59022 Mdot
.45637 .07311 Mdot
.7515 .28205 Mdot
.6271 .46445 Mdot
.89067 .38757 Mdot
.34458 .55047 Mdot
.89773 .21296 Mdot
.23903 .55483 Mdot
.73288 .14773 Mdot
.59551 .45294 Mdot
.91101 .36804 Mdot
.27413 .56304 Mdot
.80169 .16942 Mdot
.46886 .49547 Mdot
.96023 .28977 Mdot
.07572 .59346 Mdot
.32822 .0468 Mdot
.63285 .20285 Mdot
.75817 .39112 Mdot
.66737 .46857 Mdot
.84874 .41246 Mdot
.47254 .52455 Mdot
.97522 .29204 Mdot
.02436 .60272 Mdot
.15811 .01505 Mdot
.28614 .09772 Mdot
.59587 .17685 Mdot
.77673 .36827 Mdot
.61925 .48005 Mdot
.90539 .38272 Mdot
.29842 .55956 Mdot
.83944 .18444 Mdot
.38578 .5188 Mdot
.9248 .23843 Mdot
.16813 .57156 Mdot
.58181 .10391 Mdot
.75049 .35958 Mdot
.66661 .46383 Mdot
.84739 .41199 Mdot
.47582 .52372 Mdot
.9755 .29408 Mdot
.02433 .6029 Mdot
.15808 .01503 Mdot
.28606 .0977 Mdot
.59572 .17679 Mdot
.77681 .36818 Mdot
.61903 .4801 Mdot
.9056 .38258 Mdot
.29772 .55969 Mdot
.83842 .184 Mdot
.38815 .51817 Mdot
.92654 .23989 Mdot
.16328 .57263 Mdot
.57006 .10091 Mdot
.75555 .35232 Mdot
.65355 .46696 Mdot
.86442 .40391 Mdot
.42662 .53424 Mdot
.96176 .26367 Mdot
.05777 .5944 Mdot
.26991 .0357 Mdot
.53841 .16681 Mdot
.79993 .33275 Mdot
.55208 .49439 Mdot
.95451 .34121 Mdot
.12026 .58992 Mdot
.46188 .07432 Mdot
.75387 .28546 Mdot
.62428 .46592 Mdot
.894 .38583 Mdot
.33397 .55252 Mdot
.88573 .2064 Mdot
.27099 .54741 Mdot
.78868 .16748 Mdot
.49658 .48743 Mdot
.96038 .3069 Mdot
.08351 .59355 Mdot
.35302 .05161 Mdot
.66531 .21818 Mdot
.72975 .41118 Mdot
.72878 .45101 Mdot
.74976 .45041 Mdot
.71207 .46338 Mdot
.78319 .44008 Mdot
.64063 .48404 Mdot
.88678 .39593 Mdot
.35994 .54806 Mdot
.91388 .22246 Mdot
.19462 .56481 Mdot
.64244 .12028 Mdot
.70831 .39705 Mdot
.75687 .43776 Mdot
.69251 .46777 Mdot
.81475 .42799 Mdot
.56431 .50355 Mdot
.95381 .34876 Mdot
.12633 .58949 Mdot
.47895 .07807 Mdot
.75977 .29601 Mdot
.61811 .46956 Mdot
.90129 .38202 Mdot
.31044 .55703 Mdot
.85608 .19186 Mdot
.34615 .52908 Mdot
.88919 .21393 Mdot
.26461 .54955 Mdot
.77847 .16354 Mdot
.51628 .48112 Mdot
.95669 .31908 Mdot
.10209 .59127 Mdot
.40912 .0631 Mdot
.72197 .25285 Mdot
.665 .4462 Mdot
.84082 .41099 Mdot
.49225 .51965 Mdot
.97577 .30422 Mdot
.0283 .60306 Mdot
.17239 .01749 Mdot
.32349 .10654 Mdot
.65557 .19993 Mdot
.73247 .40517 Mdot
.72116 .45269 Mdot
.76334 .4457 Mdot
.68381 .47177 Mdot
.82887 .42262 Mdot
.52778 .51227 Mdot
.97009 .32619 Mdot
.05907 .59955 Mdot
.27676 .03651 Mdot
.55059 .17105 Mdot
.79811 .34028 Mdot
.5598 .49326 Mdot
.95085 .34598 Mdot
.135 .58766 Mdot
.50228 .08343 Mdot
.7644 .31043 Mdot
.61607 .47242 Mdot
.90445 .38075 Mdot
.30031 .55898 Mdot
.84204 .1856 Mdot
.37973 .52041 Mdot
.92014 .23469 Mdot
.18102 .56868 Mdot
.61216 .11187 Mdot
.73272 .37834 Mdot
.70771 .45285 Mdot
.78488 .43739 Mdot
.63573 .48508 Mdot
.89231 .3929 Mdot
.34239 .55147 Mdot
.8956 .21161 Mdot
.24468 .55351 Mdot
.7433 .15122 Mdot
.57871 .45939 Mdot
.92487 .35766 Mdot
.22578 .5716 Mdot
.71414 .13954 Mdot
.62271 .44137 Mdot
.88352 .38485 Mdot
.36396 .54605 Mdot
.91713 .22494 Mdot
.18571 .56682 Mdot
.62251 .11477 Mdot
.72517 .38473 Mdot
.7237 .44818 Mdot
.75695 .44727 Mdot
.69696 .46782 Mdot
.80834 .43074 Mdot
.58057 .49958 Mdot
.94329 .35881 Mdot
.1665 .58299 Mdot
.58326 .1029 Mdot
.74913 .36047 Mdot
.66958 .46299 Mdot
.84327 .41383 Mdot
.48736 .52117 Mdot
.97605 .3012 Mdot
.02584 .60323 Mdot
.16366 .01597 Mdot
.30083 .10115 Mdot
.62058 .18592 Mdot
.76144 .38354 Mdot
.65735 .4706 Mdot
.86179 .40627 Mdot
.43488 .53262 Mdot
.96541 .26877 Mdot
.04758 .59666 Mdot
.23659 .02941 Mdot
.47298 .14622 Mdot
.79167 .29232 Mdot
.5507 .48928 Mdot
.95254 .34035 Mdot
.12653 .5887 Mdot
.47914 .0782 Mdot
.75986 .29613 Mdot
.61799 .46962 Mdot
.90143 .38194 Mdot
.30999 .55711 Mdot
.85547 .19159 Mdot
.34763 .52871 Mdot
.89074 .21485 Mdot
.26053 .55051 Mdot
.77159 .16102 Mdot
.52916 .47687 Mdot
.95264 .32704 Mdot
.11975 .58876 Mdot
.45985 .07401 Mdot
.75309 .28421 Mdot
.62515 .46544 Mdot
.89297 .38636 Mdot
.33728 .55188 Mdot
.88956 .20845 Mdot
.26088 .54978 Mdot
.77188 .16123 Mdot
.52869 .47705 Mdot
.95282 .32675 Mdot
.119 .58887 Mdot
.45775 .07355 Mdot
.75218 .2829 Mdot
.62624 .46487 Mdot
.89168 .38704 Mdot
.34137 .55109 Mdot
.89418 .21098 Mdot
.24856 .55264 Mdot
.75033 .15362 Mdot
.56695 .46373 Mdot
.93322 .35039 Mdot
.19543 .57676 Mdot
.65011 .12078 Mdot
.70024 .40179 Mdot
.77144 .43277 Mdot
.66139 .47677 Mdot
.86003 .40876 Mdot
.44086 .53153 Mdot
.96777 .27247 Mdot
.04113 .59812 Mdot
.21509 .02542 Mdot
.42637 .13293 Mdot
.76682 .26351 Mdot
.58849 .47392 Mdot
.92593 .36371 Mdot
.22531 .57226 Mdot
.71349 .13925 Mdot
.6236 .44096 Mdot
.88251 .38541 Mdot
.36711 .54542 Mdot
.92007 .22689 Mdot
.17745 .56864 Mdot
.60349 .10967 Mdot
.73854 .37298 Mdot
.6949 .45644 Mdot
.80582 .42947 Mdot
.58573 .49802 Mdot
.93939 .362 Mdot
.18092 .58058 Mdot
.6177 .11181 Mdot
.728 .38176 Mdot
.71748 .44993 Mdot
.76801 .44343 Mdot
.67346 .47465 Mdot
.844 .41622 Mdot
.48665 .52162 Mdot
.97619 .30077 Mdot
.02513 .60332 Mdot
.16118 .01553 Mdot
.29428 .09961 Mdot
.60976 .18187 Mdot
.76867 .37685 Mdot
.63982 .47506 Mdot
.88326 .39543 Mdot
.36984 .54589 Mdot
.92304 .22858 Mdot
.16891 .57047 Mdot
.58326 .10439 Mdot
.74985 .36047 Mdot
.66824 .46344 Mdot
.84517 .41299 Mdot
.48205 .52235 Mdot
.97593 .29793 Mdot
.02469 .60316 Mdot
.15951 .01526 Mdot
.28986 .09858 Mdot
.60228 .17914 Mdot
.77318 .37223 Mdot
.62846 .47785 Mdot
.89589 .38841 Mdot
.32963 .55369 Mdot
.88074 .20372 Mdot
.28399 .54433 Mdot
.80914 .17552 Mdot
.45482 .50008 Mdot
.95821 .28109 Mdot
.07845 .59221 Mdot
.33636 .04849 Mdot
.64406 .20788 Mdot
.74911 .39805 Mdot
.68786 .46298 Mdot
.81901 .42512 Mdot
.55285 .50617 Mdot
.95995 .34168 Mdot
.1019 .59328 Mdot
.40951 .06298 Mdot
.72219 .25309 Mdot
.66476 .44634 Mdot
.84117 .41085 Mdot
.49129 .51987 Mdot
.9758 .30363 Mdot
.02791 .60308 Mdot
.17099 .01725 Mdot
.3199 .10568 Mdot
.65029 .19771 Mdot
.73739 .4019 Mdot
.71098 .45573 Mdot
.78119 .43941 Mdot
.6445 .4828 Mdot
.88209 .39832 Mdot
.37458 .54516 Mdot
.92732 .2315 Mdot
.15672 .57312 Mdot
.55342 .09686 Mdot
.76104 .34203 Mdot
.63798 .47035 Mdot
.88287 .39429 Mdot
.37041 .54564 Mdot
.92349 .22893 Mdot
.16767 .57075 Mdot
.58026 .10363 Mdot
.75127 .35862 Mdot
.66469 .46431 Mdot
.84998 .4108 Mdot
.46851 .52532 Mdot
.97463 .28955 Mdot
.02524 .60235 Mdot
.1611 .0156 Mdot
.29411 .09957 Mdot
.60948 .18177 Mdot
.76884 .37668 Mdot
.63938 .47517 Mdot
.88377 .39516 Mdot
.36825 .5462 Mdot
.9216 .22759 Mdot
.17298 .56958 Mdot
.59296 .10691 Mdot
.74481 .36647 Mdot
.68046 .46032 Mdot
.82784 .42054 Mdot
.52929 .51163 Mdot
.96949 .32712 Mdot
.06165 .59918 Mdot
.28514 .0381 Mdot
.56531 .17623 Mdot
.79446 .34938 Mdot
.57231 .491 Mdot
.94374 .35371 Mdot
.16253 .58326 Mdot
.57331 .10045 Mdot
.75363 .35432 Mdot
.65817 .46577 Mdot
.8585 .40677 Mdot
.44399 .53058 Mdot
.96872 .2744 Mdot
.03875 .5987 Mdot
.20709 .02395 Mdot
.40816 .12799 Mdot
.7528 .25226 Mdot
.61019 .46526 Mdot
.90587 .37712 Mdot
.29425 .55986 Mdot
.83311 .18185 Mdot
.40041 .51489 Mdot
.9349 .24747 Mdot
.14003 .5778 Mdot
.5113 .08654 Mdot
.76559 .316 Mdot
.61641 .47316 Mdot
.90452 .38096 Mdot
.30021 .55902 Mdot
.8419 .18554 Mdot
.38005 .52032 Mdot
.9204 .23488 Mdot
.18032 .56884 Mdot
.61055 .11144 Mdot
.73384 .37734 Mdot
.70529 .45354 Mdot
.78894 .43589 Mdot
.62632 .48759 Mdot
.90264 .38708 Mdot
.30885 .55786 Mdot
.85418 .19088 Mdot
.35071 .52791 Mdot
.8939 .21675 Mdot
.2522 .55246 Mdot
.75714 .15587 Mdot
.55515 .46794 Mdot
.94049 .3431 Mdot
.16815 .58125 Mdot
.58658 .10392 Mdot
.74756 .36252 Mdot
.67348 .46202 Mdot
.83783 .41624 Mdot
.50236 .51781 Mdot
.97525 .31048 Mdot
.03321 .60274 Mdot
.18961 .02052 Mdot
.36657 .11719 Mdot
.71164 .22655 Mdot
.6689 .43982 Mdot
.83288 .41341 Mdot
.5134 .51475 Mdot
.97329 .3173 Mdot
.04347 .60152 Mdot
.22483 .02687 Mdot
.44774 .13895 Mdot
.78021 .27672 Mdot
.56759 .48219 Mdot
.94187 .35079 Mdot
.16731 .58211 Mdot
.58488 .1034 Mdot
.74838 .36147 Mdot
.67147 .46252 Mdot
.84066 .41499 Mdot
.49459 .51955 Mdot
.97588 .30568 Mdot
.02863 .60313 Mdot
.17357 .01769 Mdot
.32653 .10727 Mdot
.65998 .20181 Mdot
.72823 .40789 Mdot
.72977 .45007 Mdot
.74762 .45102 Mdot
.71633 .46206 Mdot
.77576 .44271 Mdot
.65738 .47945 Mdot
.86606 .40628 Mdot
.42329 .53525 Mdot
.96032 .26161 Mdot
.06174 .59351 Mdot
.28269 .03816 Mdot
.5613 .17471 Mdot
.79556 .3469 Mdot
.56867 .49168 Mdot
.94594 .35146 Mdot
.15412 .58462 Mdot
.55224 .09525 Mdot
.76071 .3413 Mdot
.63827 .47015 Mdot
.88247 .39447 Mdot
.37163 .5454 Mdot
.92457 .22968 Mdot
.1646 .57141 Mdot
.57284 .10173 Mdot
.7545 .35404 Mdot
.65638 .46631 Mdot
.86085 .40566 Mdot
.43714 .53203 Mdot
.96625 .27017 Mdot
.04534 .59718 Mdot
.22913 .02802 Mdot
.45721 .14161 Mdot
.78504 .28257 Mdot
.56025 .48518 Mdot
.94673 .34625 Mdot
.14896 .58511 Mdot
.53886 .09206 Mdot
.76353 .33303 Mdot
.62875 .47188 Mdot
.89272 .38859 Mdot
.33909 .55173 Mdot
.89172 .20957 Mdot
.25511 .55111 Mdot
.76193 .15767 Mdot
.54676 .4709 Mdot
.945 .33792 Mdot
.15067 .58404 Mdot
.54288 .09312 Mdot
.76287 .33552 Mdot
.63125 .47148 Mdot
.89012 .39013 Mdot
.34743 .55013 Mdot
.90091 .21472 Mdot
.23038 .55679 Mdot
.71645 .14239 Mdot
.6204 .44279 Mdot
.88629 .38343 Mdot
.35531 .54775 Mdot
.90869 .2196 Mdot
.20918 .5616 Mdot
.67375 .12928 Mdot
.67597 .4164 Mdot
.81246 .41777 Mdot
.56472 .50213 Mdot
.95293 .34901 Mdot
.12942 .58894 Mdot
.4874 .07999 Mdot
.7619 .30123 Mdot
.61649 .47088 Mdot
.90333 .38101 Mdot
.30381 .55829 Mdot
.84696 .18776 Mdot
.3681 .52345 Mdot
.91041 .2275 Mdot
.20777 .56266 Mdot
.67116 .12841 Mdot
.67887 .4148 Mdot
.80786 .41957 Mdot
.57625 .49928 Mdot
.94563 .35614 Mdot
.15743 .58443 Mdot
.56077 .0973 Mdot
.75822 .34658 Mdot
.64565 .4686 Mdot
.87397 .39903 Mdot
.39789 .54014 Mdot
.9452 .24591 Mdot
.10534 .58417 Mdot
.4154 .0651 Mdot
.72719 .25673 Mdot
.65815 .44943 Mdot
.85058 .40676 Mdot
.46496 .52569 Mdot
.97387 .28736 Mdot
.02689 .60188 Mdot
.16677 .01662 Mdot
.30901 .10307 Mdot
.63365 .19098 Mdot
.75161 .39162 Mdot
.68007 .46452 Mdot
.8304 .42031 Mdot
.52289 .51321 Mdot
.9714 .32316 Mdot
.05298 .60036 Mdot
.25672 .03274 Mdot
.51328 .15866 Mdot
.80045 .31722 Mdot
.54339 .4947 Mdot
.95765 .33583 Mdot
.10696 .59186 Mdot
.42397 .06611 Mdot
.73299 .26203 Mdot
.65079 .45301 Mdot
.86076 .40221 Mdot
.43571 .53198 Mdot
.96552 .26928 Mdot
.04747 .59672 Mdot
.23622 .02934 Mdot
.47222 .14599 Mdot
.79139 .29185 Mdot
.55108 .48911 Mdot
.95232 .34059 Mdot
.12739 .58857 Mdot
.48152 .07873 Mdot
.76051 .29759 Mdot
.61744 .47002 Mdot
.9021 .3816 Mdot
.30781 .55753 Mdot
.8525 .19024 Mdot
.35483 .52687 Mdot
.89803 .2193 Mdot
.24121 .55501 Mdot
.73727 .14908 Mdot
.58846 .45566 Mdot
.91709 .36369 Mdot
.25319 .56679 Mdot
.76596 .15648 Mdot
.53826 .47339 Mdot
.94879 .33266 Mdot
.13546 .58638 Mdot
.50293 .08372 Mdot
.76453 .31083 Mdot
.61599 .47251 Mdot
.90455 .3807 Mdot
.29998 .55904 Mdot
.84156 .1854 Mdot
.38084 .52011 Mdot
.92102 .23537 Mdot
.17859 .56922 Mdot
.60654 .11037 Mdot
.73652 .37486 Mdot
.69938 .4552 Mdot
.79864 .43224 Mdot
.60326 .49359 Mdot
.92507 .37283 Mdot
.23248 .57173 Mdot
.72797 .14368 Mdot
.60196 .44991 Mdot
.90486 .37203 Mdot
.29485 .55923 Mdot
.83375 .18223 Mdot
.39901 .51529 Mdot
.93401 .2466 Mdot
.1425 .57725 Mdot
.51773 .08807 Mdot
.76574 .31998 Mdot
.61805 .47325 Mdot
.90314 .38198 Mdot
.30487 .55817 Mdot
.84848 .18842 Mdot
.36446 .52439 Mdot
.90715 .22525 Mdot
.21665 .56065 Mdot
.68954 .1339 Mdot
.65691 .42616 Mdot
.84074 .40599 Mdot
.49002 .5196 Mdot
.97556 .30285 Mdot
.02838 .60293 Mdot
.17258 .01754 Mdot
.324 .10666 Mdot
.65632 .20024 Mdot
.73176 .40563 Mdot
.72262 .45225 Mdot
.76072 .4466 Mdot
.68937 .47015 Mdot
.82037 .42605 Mdot
.55005 .50702 Mdot
.96139 .33995 Mdot
.09608 .59417 Mdot
.39231 .05938 Mdot
.70734 .24246 Mdot
.68333 .43716 Mdot
.81271 .42232 Mdot
.56634 .50228 Mdot
.95223 .35002 Mdot
.13228 .58851 Mdot
.49518 .08176 Mdot
.7634 .30604 Mdot
.6159 .47181 Mdot
.90429 .38065 Mdot
.30074 .55888 Mdot
.84263 .18586 Mdot
.37834 .52077 Mdot
.91903 .23383 Mdot
.18408 .56799 Mdot
.6192 .11377 Mdot
.72763 .38269 Mdot
.71855 .4497 Mdot
.76617 .44409 Mdot
.67744 .47352 Mdot
.83826 .41868 Mdot
.50247 .51807 Mdot
.97537 .31054 Mdot
.03278 .60281 Mdot
.18816 .02026 Mdot
.36301 .11629 Mdot
.70753 .22435 Mdot
.67425 .43728 Mdot
.82483 .41671 Mdot
.53476 .50978 Mdot
.96736 .3305 Mdot
.07075 .59786 Mdot
.31435 .04373 Mdot
.6125 .19428 Mdot
.77245 .37854 Mdot
.63302 .4774 Mdot
.89127 .39123 Mdot
.34462 .55083 Mdot
.89795 .21299 Mdot
.23837 .55497 Mdot
.73164 .14732 Mdot
.59744 .45218 Mdot
.90927 .36924 Mdot
.28006 .56196 Mdot
.8112 .17309 Mdot
.44888 .50135 Mdot
.95658 .27742 Mdot
.08226 .5912 Mdot
.34793 .05084 Mdot
.65913 .21503 Mdot
.73566 .40736 Mdot
.71668 .45466 Mdot
.77161 .44293 Mdot
.66597 .47688 Mdot
.85451 .41159 Mdot
.45695 .52812 Mdot
.97256 .28241 Mdot
.0291 .60108 Mdot
.17427 .01799 Mdot
.32839 .1077 Mdot
.66263 .20295 Mdot
.72562 .40953 Mdot
.73498 .44846 Mdot
.73781 .45424 Mdot
.73564 .45599 Mdot
.74032 .45465 Mdot
.73136 .45754 Mdot
.74851 .45201 Mdot
.71516 .46261 Mdot
.7779 .44199 Mdot
.65262 .48077 Mdot
.87217 .40334 Mdot
.40501 .53903 Mdot
.95005 .25031 Mdot
.09124 .58716 Mdot
.37402 .05639 Mdot
.68953 .23116 Mdot
.70414 .42615 Mdot
.7774 .43518 Mdot
.65034 .48046 Mdot
.87458 .40193 Mdot
.39759 .54052 Mdot
.94515 .24572 Mdot
.10543 .58413 Mdot
.41567 .06516 Mdot
.72739 .2569 Mdot
.65789 .44955 Mdot
.85095 .4066 Mdot
.46393 .52592 Mdot
.97368 .28672 Mdot
.02723 .60177 Mdot
.16794 .01683 Mdot
.31206 .10379 Mdot
.63839 .19286 Mdot
.74776 .39455 Mdot
.68867 .46214 Mdot
.81747 .42562 Mdot
.55675 .50522 Mdot
.95794 .34409 Mdot
.10997 .59204 Mdot
.43296 .06797 Mdot
.73888 .26758 Mdot
.64314 .45665 Mdot
.87085 .39748 Mdot
.40581 .53822 Mdot
.95024 .25081 Mdot
.09083 .58728 Mdot
.37282 .05613 Mdot
.68824 .23041 Mdot
.70559 .42535 Mdot
.77481 .43608 Mdot
.65613 .47886 Mdot
.86723 .40551 Mdot
.4197 .53598 Mdot
.95849 .25939 Mdot
.06695 .59238 Mdot
.29929 .04138 Mdot
.58922 .18497 Mdot
.7852 .36416 Mdot
.59951 .48528 Mdot
.92383 .37052 Mdot
.2353 .57096 Mdot
.73327 .14542 Mdot
.59369 .45319 Mdot
.91239 .36692 Mdot
.26934 .56389 Mdot
.79381 .16646 Mdot
.48494 .4906 Mdot
.96092 .29971 Mdot
.07816 .59388 Mdot
.33623 .0483 Mdot
.64382 .2078 Mdot
.74934 .3979 Mdot
.68737 .46311 Mdot
.81975 .42482 Mdot
.55093 .50663 Mdot
.96088 .3405 Mdot
.09809 .59386 Mdot
.39829 .06063 Mdot
.71275 .24615 Mdot
.67667 .4405 Mdot
.82324 .41821 Mdot
.53934 .50879 Mdot
.96568 .33333 Mdot
.078 .59682 Mdot
.33717 .04821 Mdot
.64493 .20838 Mdot
.74842 .39859 Mdot
.6894 .46255 Mdot
.81664 .42607 Mdot
.55893 .50471 Mdot
.95678 .34544 Mdot
.11458 .59132 Mdot
.44613 .07081 Mdot
.74646 .27572 Mdot
.63337 .46134 Mdot
.88312 .39145 Mdot
.36831 .5458 Mdot
.92146 .22763 Mdot
.17344 .56949 Mdot
.59405 .10719 Mdot
.74419 .36715 Mdot
.6819 .45994 Mdot
.82571 .42144 Mdot
.53492 .51032 Mdot
.96758 .3306 Mdot
.07003 .598 Mdot
.31206 .04328 Mdot
.60902 .19287 Mdot
.77459 .3764 Mdot
.6276 .47872 Mdot
.89713 .38788 Mdot
.3257 .55446 Mdot
.87595 .20129 Mdot
.29637 .54136 Mdot
.82743 .18316 Mdot
.41506 .51138 Mdot
.9436 .25652 Mdot
.11583 .58317 Mdot
.44582 .07159 Mdot
.74671 .27553 Mdot
.63283 .46149 Mdot
.88373 .39111 Mdot
.3664 .54618 Mdot
.91971 .22645 Mdot
.17838 .56841 Mdot
.60564 .11024 Mdot
.73716 .37431 Mdot
.69798 .45559 Mdot
.8009 .43138 Mdot
.59779 .49498 Mdot
.92979 .36946 Mdot
.21576 .57464 Mdot
.69442 .13335 Mdot
.64967 .42918 Mdot
.85043 .40152 Mdot
.46282 .52559 Mdot
.9732 .28604 Mdot
.02859 .60147 Mdot
.17265 .01767 Mdot
.32423 .1067 Mdot
.65665 .20038 Mdot
.73146 .40583 Mdot
.72325 .45206 Mdot
.75959 .44699 Mdot
.69175 .46945 Mdot
.81665 .42753 Mdot
.5596 .50472 Mdot
.95649 .34585 Mdot
.11577 .59115 Mdot
.44949 .07155 Mdot
.74819 .2778 Mdot
.63119 .46241 Mdot
.88578 .3901 Mdot
.36002 .54744 Mdot
.91366 .22251 Mdot
.19532 .56467 Mdot
.64398 .12071 Mdot
.70689 .398 Mdot
.75954 .43688 Mdot
.68694 .46942 Mdot
.82341 .42455 Mdot
.54201 .5089 Mdot
.96496 .33498 Mdot
.08131 .59637 Mdot
.34746 .05025 Mdot
.6583 .21474 Mdot
.7365 .40685 Mdot
.71496 .45518 Mdot
.77463 .44187 Mdot
.65931 .47874 Mdot
.86346 .40747 Mdot
.43096 .53365 Mdot
.96387 .26635 Mdot
.05177 .5957 Mdot
.25037 .032 Mdot
.50106 .15474 Mdot
.79901 .30967 Mdot
.54296 .49381 Mdot
.95735 .33557 Mdot
.10786 .59167 Mdot
.42653 .06666 Mdot
.73474 .26361 Mdot
.64851 .45409 Mdot
.86381 .4008 Mdot
.42675 .53387 Mdot
.96166 .26375 Mdot
.05817 .59434 Mdot
.27124 .03595 Mdot
.54084 .16763 Mdot
.79965 .33426 Mdot
.55346 .49421 Mdot
.9539 .34205 Mdot
.12274 .58955 Mdot
.46879 .07586 Mdot
.75653 .28973 Mdot
.6213 .46756 Mdot
.8975 .38398 Mdot
.3227 .55469 Mdot
.87205 .19944 Mdot
.30635 .53896 Mdot
.84134 .18933 Mdot
.38332 .51997 Mdot
.92319 .23691 Mdot
.17247 .57056 Mdot
.59217 .10659 Mdot
.74519 .36598 Mdot
.67952 .46055 Mdot
.82921 .41996 Mdot
.52565 .51248 Mdot
.97059 .32487 Mdot
.05668 .59986 Mdot
.2689 .03503 Mdot
.53632 .16619 Mdot
.80019 .33146 Mdot
.5509 .49454 Mdot
.95503 .34047 Mdot
.11815 .59024 Mdot
.45596 .07302 Mdot
.75131 .2818 Mdot
.62732 .46434 Mdot
.89041 .38771 Mdot
.34542 .5503 Mdot
.89864 .21348 Mdot
.23657 .55539 Mdot
.72827 .14621 Mdot
.60268 .45009 Mdot
.9044 .37248 Mdot
.29645 .55895 Mdot
.8361 .18322 Mdot
.3936 .51674 Mdot
.93041 .24326 Mdot
.15251 .57503 Mdot
.54334 .09425 Mdot
.76328 .3358 Mdot
.63059 .47173 Mdot
.89089 .38972 Mdot
.345 .5506 Mdot
.89829 .21322 Mdot
.23748 .55517 Mdot
.72997 .14677 Mdot
.60005 .45115 Mdot
.90687 .37085 Mdot
.28815 .56048 Mdot
.82374 .17809 Mdot
.42157 .5091 Mdot
.9466 .26055 Mdot
.1078 .58503 Mdot
.42314 .06662 Mdot
.73275 .26151 Mdot
.65095 .45286 Mdot
.8605 .40231 Mdot
.43645 .53182 Mdot
.96581 .26974 Mdot
.04667 .5969 Mdot
.23358 .02884 Mdot
.46666 .14436 Mdot
.78923 .28841 Mdot
.5541 .48777 Mdot
.95053 .34245 Mdot
.13435 .58746 Mdot
.5004 .08303 Mdot
.76419 .30927 Mdot
.61591 .4723 Mdot
.90452 .38065 Mdot
.30004 .55903 Mdot
.84164 .18544 Mdot
.38065 .52016 Mdot
.92087 .23525 Mdot
.17901 .56913 Mdot
.60752 .11063 Mdot
.73588 .37547 Mdot
.70082 .4548 Mdot
.79631 .43313 Mdot
.60887 .49215 Mdot
.91999 .37631 Mdot
.25025 .56858 Mdot
.76128 .15466 Mdot
.54656 .4705 Mdot
.94488 .33779 Mdot
.15102 .58397 Mdot
.54378 .09334 Mdot
.7627 .33607 Mdot
.63185 .47137 Mdot
.88948 .39051 Mdot
.34948 .54973 Mdot
.90308 .21599 Mdot
.22447 .55813 Mdot
.70487 .13873 Mdot
.63677 .43563 Mdot
.86725 .39354 Mdot
.41384 .53599 Mdot
.95474 .25577 Mdot
.07803 .59006 Mdot
.33396 .04822 Mdot
.64093 .2064 Mdot
.7517 .39612 Mdot
.68208 .46458 Mdot
.82772 .42155 Mdot
.53008 .51156 Mdot
.96929 .3276 Mdot
.06259 .59905 Mdot
.28819 .03868 Mdot
.57052 .17811 Mdot
.79279 .3526 Mdot
.57752 .48997 Mdot
.94039 .35693 Mdot
.17517 .58119 Mdot
.604 .10826 Mdot
.73747 .37329 Mdot
.69694 .45578 Mdot
.80251 .43074 Mdot
.59385 .49598 Mdot
.93306 .36702 Mdot
.20404 .57666 Mdot
.66963 .1261 Mdot
.67968 .41386 Mdot
.80633 .42006 Mdot
.57999 .49834 Mdot
.94303 .35846 Mdot
.1672 .58282 Mdot
.58494 .10333 Mdot
.7483 .36151 Mdot
.67162 .46248 Mdot
.84044 .41509 Mdot
.4952 .51942 Mdot
.97585 .30605 Mdot
.02892 .60311 Mdot
.17462 .01788 Mdot
.3292 .10792 Mdot
.6638 .20346 Mdot
.72445 .41025 Mdot
.73729 .44773 Mdot
.7334 .45567 Mdot
.74408 .45326 Mdot
.72391 .45987 Mdot
.76228 .4474 Mdot
.68671 .47111 Mdot
.82455 .42441 Mdot
.5392 .5096 Mdot
.96611 .33324 Mdot
.07645 .59709 Mdot
.33233 .04725 Mdot
.63838 .20539 Mdot
.75384 .39454 Mdot
.67728 .4659 Mdot
.83477 .41858 Mdot
.51119 .51592 Mdot
.97402 .31594 Mdot
.04021 .60198 Mdot
.21374 .02485 Mdot
.42319 .1321 Mdot
.76457 .26155 Mdot
.592 .47253 Mdot
.92293 .36588 Mdot
.23591 .5704 Mdot
.73423 .1458 Mdot
.59222 .45378 Mdot
.91368 .36601 Mdot
.26492 .56469 Mdot
.78637 .16373 Mdot
.49972 .486 Mdot
.95979 .30885 Mdot
.08651 .59318 Mdot
.36227 .05347 Mdot
.67627 .2239 Mdot
.71863 .41796 Mdot
.75062 .44414 Mdot
.70741 .46391 Mdot
.79072 .43721 Mdot
.62311 .48869 Mdot
.90613 .3851 Mdot
.29733 .56002 Mdot
.83798 .18376 Mdot
.38914 .5179 Mdot
.92726 .2405 Mdot
.16129 .57308 Mdot
.5652 .09968 Mdot
.75735 .34931 Mdot
.64865 .46807 Mdot
.87044 .40089 Mdot
.4086 .53796 Mdot
.95211 .25253 Mdot
.08536 .58844 Mdot
.35635 .05275 Mdot
.66956 .22024 Mdot
.72547 .41381 Mdot
.73731 .44836 Mdot
.73366 .45568 Mdot
.74362 .45343 Mdot
.72482 .45958 Mdot
.76061 .44797 Mdot
.69024 .47008 Mdot
.8191 .42659 Mdot
.55334 .50623 Mdot
.95978 .34198 Mdot
.1026 .59318 Mdot
.41158 .06341 Mdot
.72382 .25437 Mdot
.66267 .44735 Mdot
.8442 .40955 Mdot
.48288 .52175 Mdot
.97576 .29844 Mdot
.02554 .60305 Mdot
.16251 .01578 Mdot
.2978 .10043 Mdot
.61561 .18405 Mdot
.76486 .38047 Mdot
.64915 .47271 Mdot
.87214 .4012 Mdot
.40405 .53901 Mdot
.94934 .24971 Mdot
.09335 .58672 Mdot
.38033 .05769 Mdot
.69609 .23506 Mdot
.69663 .4302 Mdot
.79057 .43054 Mdot
.6202 .4886 Mdot
.9087 .3833 Mdot
.28863 .56161 Mdot
.82507 .17839 Mdot
.4185 .50992 Mdot
.9451 .25865 Mdot
.11188 .5841 Mdot
.43471 .06914 Mdot
.74035 .26867 Mdot
.64103 .45756 Mdot
.87351 .39618 Mdot
.39779 .53986 Mdot
.94499 .24585 Mdot
.10603 .58403 Mdot
.4174 .06553 Mdot
.72869 .25797 Mdot
.65621 .45035 Mdot
.85329 .40556 Mdot
.45726 .52736 Mdot
.9723 .2826 Mdot
.03012 .60091 Mdot
.17782 .01862 Mdot
.3374 .1099 Mdot
.67517 .20853 Mdot
.7126 .41728 Mdot
.75997 .44041 Mdot
.68781 .46969 Mdot
.82232 .42509 Mdot
.54489 .50822 Mdot
.96373 .33676 Mdot
.08642 .59562 Mdot
.36317 .05341 Mdot
.67718 .22445 Mdot
.71771 .41852 Mdot
.7524 .44357 Mdot
.70381 .46501 Mdot
.79676 .43498 Mdot
.60877 .49243 Mdot
.92021 .37624 Mdot
.24952 .56872 Mdot
.75997 .15421 Mdot
.54888 .46969 Mdot
.94369 .33923 Mdot
.15568 .58323 Mdot
.55563 .09622 Mdot
.75986 .3434 Mdot
.64094 .46962 Mdot
.87945 .39613 Mdot
.38103 .54353 Mdot
.93256 .23549 Mdot
.14181 .57635 Mdot
.51542 .08764 Mdot
.76578 .31855 Mdot
.61727 .47328 Mdot
.90382 .3815 Mdot
.30256 .55859 Mdot
.84524 .18699 Mdot
.37218 .52239 Mdot
.91393 .23002 Mdot
.19812 .56484 Mdot
.65049 .12244 Mdot
.70062 .40203 Mdot
.77098 .43301 Mdot
.66242 .47649 Mdot
.85865 .4094 Mdot
.44487 .53067 Mdot
.96915 .27495 Mdot
.03752 .59897 Mdot
.20291 .02319 Mdot
.39845 .12541 Mdot
.74433 .24626 Mdot
.62298 .46002 Mdot
.89233 .38502 Mdot
.33849 .55149 Mdot
.89087 .2092 Mdot
.25742 .55059 Mdot
.76594 .15909 Mdot
.53956 .47338 Mdot
.94843 .33346 Mdot
.13707 .58616 Mdot
.50726 .08471 Mdot
.76492 .3135 Mdot
.61652 .47275 Mdot
.90421 .38103 Mdot
.30116 .55883 Mdot
.84325 .18613 Mdot
.37687 .52116 Mdot
.91784 .23292 Mdot
.18736 .56726 Mdot
.62665 .1158 Mdot
.72186 .38729 Mdot
.73045 .44613 Mdot
.74454 .45144 Mdot
.72219 .46015 Mdot
.76526 .44634 Mdot
.68033 .47296 Mdot
.83415 .42046 Mdot
.51365 .51553 Mdot
.97365 .31745 Mdot
.04227 .60175 Mdot
.22078 .02612 Mdot
.43887 .13645 Mdot
.77506 .27124 Mdot
.57558 .47902 Mdot
.93616 .35573 Mdot
.18847 .57858 Mdot
.63477 .11648 Mdot
.71434 .39231 Mdot
.74509 .44149 Mdot
.71636 .46049 Mdot
.77495 .44273 Mdot
.65906 .47895 Mdot
.86385 .40732 Mdot
.42982 .53389 Mdot
.96337 .26564 Mdot
.05316 .59539 Mdot
.25493 .03286 Mdot
.51002 .15756 Mdot
.80015 .31521 Mdot
.5431 .49452 Mdot
.95764 .33565 Mdot
.10688 .59186 Mdot
.42371 .06605 Mdot
.73281 .26186 Mdot
.65102 .4529 Mdot
.86045 .40235 Mdot
.43662 .53178 Mdot
.96588 .26985 Mdot
.04649 .59694 Mdot
.23297 .02873 Mdot
.46539 .14399 Mdot
.7887 .28763 Mdot
.55485 .48744 Mdot
.95008 .34292 Mdot
.13611 .58718 Mdot
.50512 .08412 Mdot
.7647 .31218 Mdot
.61632 .47261 Mdot
.90432 .38091 Mdot
.30078 .5589 Mdot
.84271 .18589 Mdot
.37815 .52082 Mdot
.91888 .23371 Mdot
.1845 .5679 Mdot
.62016 .11403 Mdot
.72691 .38328 Mdot
.72005 .44926 Mdot
.76349 .44502 Mdot
.68318 .47186 Mdot
.82977 .42223 Mdot
.52536 .51283 Mdot
.97081 .32469 Mdot
.05582 .59999 Mdot
.2661 .0345 Mdot
.53112 .16446 Mdot
.80058 .32825 Mdot
.54846 .49478 Mdot
.95602 .33897 Mdot
.11405 .59085 Mdot
.44434 .07049 Mdot
.74554 .27462 Mdot
.63453 .46077 Mdot
.8817 .39216 Mdot
.37273 .54492 Mdot
.92541 .23036 Mdot
.16225 .57194 Mdot
.56711 .10028 Mdot
.75672 .35049 Mdot
.65043 .46768 Mdot
.86828 .40199 Mdot
.4151 .53663 Mdot
.95588 .25655 Mdot
.07452 .59076 Mdot
.32306 .04605 Mdot
.62563 .19966 Mdot
.76351 .38666 Mdot
.65482 .47187 Mdot
.86535 .4047 Mdot
.42446 .53481 Mdot
.9608 .26233 Mdot
.06045 .59381 Mdot
.27855 .03736 Mdot
.55403 .17215 Mdot
.79736 .34241 Mdot
.56252 .49279 Mdot
.94941 .34766 Mdot
.14064 .58677 Mdot
.51731 .08692 Mdot
.76523 .31972 Mdot
.61893 .47294 Mdot
.90221 .38252 Mdot
.30792 .5576 Mdot
.8527 .19031 Mdot
.35434 .52699 Mdot
.89755 .219 Mdot
.2425 .55471 Mdot
.73964 .14987 Mdot
.58463 .45713 Mdot
.92023 .36132 Mdot
.24222 .56873 Mdot
.7459 .1497 Mdot
.57323 .46099 Mdot
.92868 .35428 Mdot
.21194 .57396 Mdot
.68582 .13099 Mdot
.66069 .42386 Mdot
.83517 .40833 Mdot
.5052 .51617 Mdot
.97442 .31223 Mdot
.03701 .60222 Mdot
.20273 .02288 Mdot
.39789 .1253 Mdot
.74383 .24591 Mdot
.62371 .45971 Mdot
.89152 .38547 Mdot
.3411 .55099 Mdot
.8938 .21081 Mdot
.24959 .5524 Mdot
.75218 .15426 Mdot
.56378 .46487 Mdot
.93528 .34844 Mdot
.18778 .57804 Mdot
.63288 .11606 Mdot
.71601 .39114 Mdot
.74186 .44252 Mdot
.72272 .45849 Mdot
.76359 .44666 Mdot
.68379 .47192 Mdot
.82896 .42261 Mdot
.52755 .51232 Mdot
.97016 .32605 Mdot
.05875 .59959 Mdot
.27571 .03631 Mdot
.5487 .1704 Mdot
.79847 .33911 Mdot
.55844 .49348 Mdot
.95154 .34513 Mdot
.13226 .58808 Mdot
.49489 .08174 Mdot
.76338 .30586 Mdot
.61586 .47179 Mdot
.90432 .38062 Mdot
.30064 .5589 Mdot
.8425 .18581 Mdot
.37865 .52069 Mdot
.91928 .23402 Mdot
.1834 .56815 Mdot
.61764 .11335 Mdot
.72879 .38172 Mdot
.71611 .45042 Mdot
.77046 .44258 Mdot
.66811 .47617 Mdot
.85151 .41292 Mdot
.46551 .52626 Mdot
.9743 .2877 Mdot
.02552 .60215 Mdot
.162 .01577 Mdot
.29651 .10012 Mdot
.61347 .18325 Mdot
.76628 .37915 Mdot
.6457 .47359 Mdot
.87634 .39906 Mdot
.39126 .54161 Mdot
.94055 .24181 Mdot
.11877 .58129 Mdot
.45342 .07341 Mdot
.75059 .28023 Mdot
.62791 .46389 Mdot
.88964 .38807 Mdot
.34784 .54983 Mdot
.90124 .21498 Mdot
.22951 .557 Mdot
.71477 .14185 Mdot
.62283 .44175 Mdot
.88359 .38493 Mdot
.3638 .54609 Mdot
.91699 .22484 Mdot
.18612 .56673 Mdot
.62344 .11503 Mdot
.72445 .38531 Mdot
.72518 .44773 Mdot
.75425 .44819 Mdot
.70255 .46615 Mdot
.79922 .4342 Mdot
.60294 .49394 Mdot
.92549 .37264 Mdot
.23106 .57198 Mdot
.72521 .14281 Mdot
.6062 .4482 Mdot
.90078 .37465 Mdot
.3084 .55671 Mdot
.85297 .1906 Mdot
.35377 .52716 Mdot
.89699 .21864 Mdot
.24398 .55437 Mdot
.74236 .15079 Mdot
.58021 .4588 Mdot
.92371 .35859 Mdot
.22989 .57089 Mdot
.72228 .14208 Mdot
.61072 .44639 Mdot
.89629 .37745 Mdot
.32315 .55393 Mdot
.87229 .19972 Mdot
.30583 .5391 Mdot
.84064 .18901 Mdot
.38494 .51955 Mdot
.92442 .23791 Mdot
.16907 .57132 Mdot
.58407 .10449 Mdot
.74941 .36097 Mdot
.66932 .46316 Mdot
.84369 .41366 Mdot
.4862 .52143 Mdot
.97604 .30049 Mdot
.02552 .60323 Mdot
.16251 .01577 Mdot
.2978 .10044 Mdot
.61562 .18405 Mdot
.76485 .38047 Mdot
.64916 .47271 Mdot
.87212 .40121 Mdot
.4041 .539 Mdot
.94937 .24975 Mdot
.09326 .58674 Mdot
.38005 .05764 Mdot
.6958 .23488 Mdot
.69696 .43003 Mdot
.79 .43074 Mdot
.62153 .48824 Mdot
.90734 .38413 Mdot
.29318 .56077 Mdot
.83188 .18119 Mdot
.40315 .51413 Mdot
.9366 .24916 Mdot
.1353 .57885 Mdot
.49886 .08362 Mdot
.76445 .30831 Mdot
.61494 .47245 Mdot
.90543 .38005 Mdot
.29702 .55958 Mdot
.83728 .18357 Mdot
.3908 .51747 Mdot
.92845 .24153 Mdot
.15798 .57381 Mdot
.55703 .09764 Mdot
.75998 .34426 Mdot
.64113 .46969 Mdot
.8793 .39624 Mdot
.38153 .54344 Mdot
.93296 .2358 Mdot
.14065 .5766 Mdot
.51239 .08692 Mdot
.7657 .31667 Mdot
.61652 .47323 Mdot
.90445 .38103 Mdot
.30046 .55898 Mdot
.84226 .18569 Mdot
.37921 .52054 Mdot
.91972 .23436 Mdot
.18217 .56842 Mdot
.61482 .11259 Mdot
.73084 .37998 Mdot
.71175 .45169 Mdot
.77801 .43989 Mdot
.65136 .48084 Mdot
.87363 .40256 Mdot
.40056 .53993 Mdot
.94717 .24756 Mdot
.09959 .58538 Mdot
.3987 .06155 Mdot
.71352 .24641 Mdot
.67557 .44098 Mdot
.82492 .41753 Mdot
.53496 .50983 Mdot
.96733 .33062 Mdot
.0709 .59784 Mdot
.31483 .04382 Mdot
.61321 .19457 Mdot
.77199 .37898 Mdot
.63415 .47712 Mdot
.89001 .39192 Mdot
.34861 .55006 Mdot
.90225 .21546 Mdot
.22671 .55762 Mdot
.7093 .14012 Mdot
.63062 .43837 Mdot
.87466 .38974 Mdot
.39145 .54057 Mdot
.9402 .24193 Mdot
.11998 .58108 Mdot
.45678 .07415 Mdot
.75214 .2823 Mdot
.62601 .46485 Mdot
.89188 .3869 Mdot
.34071 .55121 Mdot
.89344 .21057 Mdot
.25053 .55218 Mdot
.75386 .15484 Mdot
.56089 .46591 Mdot
.93709 .34665 Mdot
.18101 .57916 Mdot
.61724 .11187 Mdot
.72842 .38148 Mdot
.71662 .45019 Mdot
.76953 .4429 Mdot
.67015 .47559 Mdot
.84867 .41418 Mdot
.47357 .52451 Mdot
.97542 .29268 Mdot
.02395 .60284 Mdot
.15669 .0148 Mdot
.28233 .09684 Mdot
.58919 .17449 Mdot
.78013 .36414 Mdot
.61019 .48215 Mdot
.91407 .37712 Mdot
.26909 .56493 Mdot
.79387 .16631 Mdot
.48473 .49064 Mdot
.96091 .29958 Mdot
.07813 .59388 Mdot
.33612 .04828 Mdot
.64367 .20774 Mdot
.74946 .39781 Mdot
.6871 .46319 Mdot
.82017 .42465 Mdot
.54985 .50689 Mdot
.9614 .33983 Mdot
.09598 .59418 Mdot
.392 .05932 Mdot
.70706 .24227 Mdot
.68368 .43698 Mdot
.81215 .42254 Mdot
.56775 .50194 Mdot
.95138 .35089 Mdot
.13558 .58798 Mdot
.50406 .08379 Mdot
.76456 .31152 Mdot
.61628 .47252 Mdot
.90432 .38088 Mdot
.30078 .5589 Mdot
.8427 .18589 Mdot
.37817 .52082 Mdot
.91889 .23372 Mdot
.18447 .56791 Mdot
.62008 .11401 Mdot
.72697 .38323 Mdot
.71994 .44929 Mdot
.76371 .44494 Mdot
.68272 .472 Mdot
.83045 .42195 Mdot
.52355 .51325 Mdot
.97132 .32357 Mdot
.05349 .60031 Mdot
.2584 .03306 Mdot
.51652 .1597 Mdot
.80064 .31922 Mdot
.54393 .49482 Mdot
.95754 .33617 Mdot
.1075 .59179 Mdot
.42552 .06644 Mdot
.73406 .26299 Mdot
.6494 .45367 Mdot
.86263 .40135 Mdot
.43024 .53313 Mdot
.96323 .2659 Mdot
.05377 .59531 Mdot
.25693 .03323 Mdot
.5139 .15879 Mdot
.80046 .31761 Mdot
.54356 .49471 Mdot
.9576 .33594 Mdot
.10718 .59183 Mdot
.42459 .06624 Mdot
.73342 .26241 Mdot
.65022 .45328 Mdot
.86152 .40186 Mdot
.43349 .53245 Mdot
.96462 .26791 Mdot
.04993 .59617 Mdot
.24436 .03086 Mdot
.48899 .15102 Mdot
.79655 .30221 Mdot
.54479 .4923 Mdot
.95604 .3367 Mdot
.11288 .59086 Mdot
.44094 .06977 Mdot
.74367 .27252 Mdot
.63692 .45961 Mdot
.87873 .39364 Mdot
.38187 .54309 Mdot
.9331 .23601 Mdot
.1403 .57669 Mdot
.51148 .08671 Mdot
.76566 .31611 Mdot
.61633 .4732 Mdot
.9046 .38091 Mdot
.29992 .55908 Mdot
.84149 .18536 Mdot
.38101 .52007 Mdot
.92115 .23547 Mdot
.17824 .5693 Mdot
.60573 .11016 Mdot
.73705 .37436 Mdot
.6982 .45552 Mdot
.80054 .43151 Mdot
.59866 .49476 Mdot
.92906 .36999 Mdot
.21836 .57419 Mdot
.69978 .13496 Mdot
.64259 .43249 Mdot
.8597 .39714 Mdot
.4361 .53132 Mdot
.96539 .26952 Mdot
.04801 .59665 Mdot
.23804 .02967 Mdot
.47601 .14712 Mdot
.79274 .29419 Mdot
.54929 .48994 Mdot
.95337 .33948 Mdot
.12329 .58922 Mdot
.4702 .0762 Mdot
.75704 .2906 Mdot
.62074 .46788 Mdot
.89816 .38364 Mdot
.3206 .55509 Mdot
.8694 .19814 Mdot
.31308 .53732 Mdot
.85029 .19349 Mdot
.36222 .52551 Mdot
.90534 .22386 Mdot
.22145 .55953 Mdot
.69922 .13686 Mdot
.64435 .43214 Mdot
.85766 .39823 Mdot
.44209 .53007 Mdot
.96762 .27322 Mdot
.04203 .59802 Mdot
.21813 .02597 Mdot
.43317 .13481 Mdot
.77144 .26772 Mdot
.58126 .47677 Mdot
.93181 .35924 Mdot
.20429 .57589 Mdot
.66983 .12626 Mdot
.6795 .41398 Mdot
.80663 .41995 Mdot
.57926 .49852 Mdot
.94354 .358 Mdot
.16527 .58314 Mdot
.58022 .10214 Mdot
.75058 .35859 Mdot
.66598 .46388 Mdot
.8482 .4116 Mdot
.47355 .52421 Mdot
.97527 .29267 Mdot
.02446 .60275 Mdot
.15849 .01512 Mdot
.28716 .09795 Mdot
.59764 .17748 Mdot
.77578 .36936 Mdot
.62174 .47946 Mdot
.90289 .38425 Mdot
.30673 .55802 Mdot
.85115 .18957 Mdot
.35806 .52604 Mdot
.90116 .22129 Mdot
.23283 .55695 Mdot
.72149 .14389 Mdot
.61291 .44591 Mdot
.89424 .3788 Mdot
.32984 .55267 Mdot
.88052 .20385 Mdot
.28468 .54419 Mdot
.81021 .17594 Mdot
.45256 .50074 Mdot
.95771 .2797 Mdot
.0795 .5919 Mdot
.33954 .04913 Mdot
.64831 .20985 Mdot
.74547 .40068 Mdot
.69585 .46072 Mdot
.80651 .43006 Mdot
.58442 .49845 Mdot
.94042 .36119 Mdot
.17716 .58121 Mdot
.60887 .10949 Mdot
.73424 .3763 Mdot
.70408 .45379 Mdot
.7909 .43515 Mdot
.6217 .48881 Mdot
.90746 .38423 Mdot
.29287 .56084 Mdot
.83143 .181 Mdot
.40418 .51385 Mdot
.93723 .2498 Mdot
.13357 .57924 Mdot
.49424 .08255 Mdot
.76373 .30545 Mdot
.61496 .47201 Mdot
.90519 .38007 Mdot
.29774 .55944 Mdot
.83833 .18402 Mdot
.38837 .51812 Mdot
.9267 .24002 Mdot
.16282 .57273 Mdot
.56896 .10063 Mdot
.75598 .35163 Mdot
.6524 .46722 Mdot
.86584 .40321 Mdot
.4224 .53512 Mdot
.95972 .26106 Mdot
.06354 .59314 Mdot
.28845 .03927 Mdot
.57122 .17827 Mdot
.79251 .35304 Mdot
.57835 .4898 Mdot
.93983 .35744 Mdot
.17727 .58085 Mdot
.60896 .10956 Mdot
.7342 .37636 Mdot
.70417 .45376 Mdot
.79075 .4352 Mdot
.62206 .48871 Mdot
.90709 .38445 Mdot
.29411 .56061 Mdot
.83327 .18177 Mdot
.39999 .51499 Mdot
.93462 .24721 Mdot
.1408 .57763 Mdot
.51331 .08702 Mdot
.76567 .31724 Mdot
.61685 .47321 Mdot
.90415 .38124 Mdot
.30144 .5588 Mdot
.84365 .1863 Mdot
.37593 .52141 Mdot
.91707 .23234 Mdot
.18949 .56678 Mdot
.63144 .11711 Mdot
.71792 .39025 Mdot
.73833 .4437 Mdot
.7296 .45631 Mdot
.75094 .45092 Mdot
.71012 .46411 Mdot
.78661 .43888 Mdot
.63276 .48615 Mdot
.89577 .39107 Mdot
.33128 .55362 Mdot
.88284 .20475 Mdot
.2785 .54562 Mdot
.80065 .17212 Mdot
.47251 .49483 Mdot
.96078 .29203 Mdot
.07491 .5938 Mdot
.32579 .0463 Mdot
.62941 .20135 Mdot
.76077 .389 Mdot
.6613 .47018 Mdot
.85693 .40871 Mdot
.44914 .52961 Mdot
.9704 .27758 Mdot
.03439 .59974 Mdot
.19232 .02125 Mdot
.37325 .11886 Mdot
.7191 .23068 Mdot
.65896 .44443 Mdot
.84721 .40726 Mdot
.474 .52361 Mdot
.97508 .29295 Mdot
.0253 .60263 Mdot
.16146 .01564 Mdot
.29505 .09979 Mdot
.61104 .18235 Mdot
.76785 .37764 Mdot
.64183 .47456 Mdot
.88092 .39667 Mdot
.37712 .54444 Mdot
.92938 .23307 Mdot
.15089 .57439 Mdot
.53876 .09325 Mdot
.76413 .33297 Mdot
.62753 .47226 Mdot
.89405 .38784 Mdot
.33479 .55256 Mdot
.88678 .20691 Mdot
.26821 .54806 Mdot
.78414 .16577 Mdot
.50546 .48462 Mdot
.9591 .31239 Mdot
.0906 .59276 Mdot
.37476 .05599 Mdot
.69004 .23161 Mdot
.70363 .42647 Mdot
.77832 .43487 Mdot
.64829 .48103 Mdot
.87712 .40067 Mdot
.38983 .54209 Mdot
.93958 .24093 Mdot
.12153 .58069 Mdot
.46105 .07511 Mdot
.754 .28494 Mdot
.62379 .466 Mdot
.89449 .38552 Mdot
.33239 .55282 Mdot
.88386 .20543 Mdot
.27588 .54626 Mdot
.79653 .1705 Mdot
.4809 .49228 Mdot
.96116 .29721 Mdot
.07614 .59403 Mdot
.32987 .04706 Mdot
.63512 .20387 Mdot
.75641 .39252 Mdot
.67143 .46749 Mdot
.84312 .41496 Mdot
.48829 .52108 Mdot
.97611 .30178 Mdot
.02591 .60327 Mdot
.16395 .01602 Mdot
.3016 .10133 Mdot
.62183 .1864 Mdot
.76055 .38431 Mdot
.65947 .47004 Mdot
.85904 .40757 Mdot
.44293 .53092 Mdot
.96841 .27374 Mdot
.03951 .59851 Mdot
.20963 .02442 Mdot
.41399 .12956 Mdot
.75755 .25586 Mdot
.6029 .46819 Mdot
.91302 .37261 Mdot
.27016 .56428 Mdot
.79542 .16697 Mdot
.48163 .4916 Mdot
.96094 .29767 Mdot
.07711 .59389 Mdot
.3329 .04766 Mdot
.63931 .20575 Mdot
.75306 .39512 Mdot
.67904 .46542 Mdot
.83221 .41967 Mdot
.51809 .51434 Mdot
.97261 .3202 Mdot
.04728 .60111 Mdot
.2377 .02922 Mdot
.47512 .14691 Mdot
.79246 .29364 Mdot
.54963 .48977 Mdot
.95317 .33969 Mdot
.12409 .58909 Mdot
.47242 .07669 Mdot
.7578 .29197 Mdot
.61996 .46834 Mdot
.89908 .38315 Mdot
.31761 .55566 Mdot
.86556 .19629 Mdot
.32273 .53494 Mdot
.86251 .19946 Mdot
.33257 .53306 Mdot
.8745 .20554 Mdot
.30249 .54047 Mdot
.83634 .18695 Mdot
.39482 .51689 Mdot
.93147 .24401 Mdot
.14945 .57568 Mdot
.5356 .09237 Mdot
.76453 .33102 Mdot
.62579 .47251 Mdot
.89581 .38676 Mdot
.32909 .55364 Mdot
.88001 .20339 Mdot
.28589 .54388 Mdot
.81204 .17669 Mdot
.44868 .50187 Mdot
.95675 .2773 Mdot
.08161 .5913 Mdot
.34593 .05044 Mdot
.6566 .2138 Mdot
.73802 .4058 Mdot
.71176 .45612 Mdot
.78015 .43989 Mdot
.64691 .48216 Mdot
.87919 .39981 Mdot
.38358 .54337 Mdot
.93478 .23707 Mdot
.13537 .57772 Mdot
.4985 .08367 Mdot
.76446 .30809 Mdot
.61481 .47246 Mdot
.90554 .37997 Mdot
.29664 .55965 Mdot
.83673 .18333 Mdot
.39208 .51713 Mdot
.92935 .24232 Mdot
.15547 .57437 Mdot
.55078 .09609 Mdot
.76166 .3404 Mdot
.63599 .47073 Mdot
.88507 .39306 Mdot
.36349 .547 Mdot
.91711 .22465 Mdot
.18563 .56681 Mdot
.62232 .11473 Mdot
.72532 .38461 Mdot
.72338 .44827 Mdot
.75752 .44708 Mdot
.69578 .46817 Mdot
.81023 .43001 Mdot
.57584 .50075 Mdot
.94657 .35589 Mdot
.15418 .58501 Mdot
.55256 .09529 Mdot
.7606 .3415 Mdot
.63857 .47008 Mdot
.88213 .39466 Mdot
.3727 .54519 Mdot
.92552 .23034 Mdot
.16191 .572 Mdot
.56627 .10007 Mdot
.75703 .34997 Mdot
.64959 .46787 Mdot
.8693 .40147 Mdot
.41203 .53726 Mdot
.95414 .25465 Mdot
.07951 .58969 Mdot
.33849 .04914 Mdot
.64703 .2092 Mdot
.74656 .39988 Mdot
.69346 .4614 Mdot
.8103 .42858 Mdot
.575 .50079 Mdot
.94705 .35537 Mdot
.15232 .58531 Mdot
.54784 .09414 Mdot
.76175 .33858 Mdot
.63492 .47079 Mdot
.88618 .3924 Mdot
.35998 .54769 Mdot
.91374 .22248 Mdot
.19506 .56472 Mdot
.64342 .12056 Mdot
.70741 .39766 Mdot
.75857 .4372 Mdot
.68897 .46882 Mdot
.82029 .42581 Mdot
.55013 .50696 Mdot
.96134 .34 Mdot
.09629 .59414 Mdot
.39294 .05951 Mdot
.70792 .24285 Mdot
.68262 .43752 Mdot
.81385 .42189 Mdot
.56346 .50299 Mdot
.95393 .34824 Mdot
.12565 .58956 Mdot
.47708 .07766 Mdot
.75923 .29485 Mdot
.6186 .46923 Mdot
.9007 .38232 Mdot
.31235 .55667 Mdot
.85863 .19304 Mdot
.33989 .53067 Mdot
.88247 .21006 Mdot
.28212 .5454 Mdot
.80659 .17436 Mdot
.46013 .4985 Mdot
.95923 .28438 Mdot
.07655 .59284 Mdot
.33059 .04731 Mdot
.63617 .20431 Mdot
.75557 .39317 Mdot
.67334 .46697 Mdot
.84041 .41615 Mdot
.49577 .5194 Mdot
.97587 .3064 Mdot
.02902 .60312 Mdot
.17496 .01793 Mdot
.33007 .10813 Mdot
.66503 .20399 Mdot
.72321 .41101 Mdot
.73972 .44697 Mdot
.7287 .45718 Mdot
.75289 .45036 Mdot
.70618 .46531 Mdot
.79329 .43645 Mdot
.61713 .49028 Mdot
.9122 .38141 Mdot
.27696 .56377 Mdot
.80686 .17117 Mdot
.45797 .49866 Mdot
.95861 .28304 Mdot
.07803 .59245 Mdot
.33514 .04823 Mdot
.64241 .20713 Mdot
.7505 .39703 Mdot
.68477 .46384 Mdot
.82369 .42321 Mdot
.54068 .50907 Mdot
.96543 .33416 Mdot
.07925 .59667 Mdot
.34107 .04898 Mdot
.65009 .21079 Mdot
.74396 .40178 Mdot
.69913 .45979 Mdot
.80124 .43209 Mdot
.59738 .49519 Mdot
.93019 .3692 Mdot
.21435 .57489 Mdot
.69149 .13247 Mdot
.65346 .42736 Mdot
.8453 .40386 Mdot
.4773 .52242 Mdot
.97516 .29499 Mdot
.02599 .60268 Mdot
.16396 .01607 Mdot
.30163 .10133 Mdot
.62188 .18642 Mdot
.76051 .38434 Mdot
.65955 .47002 Mdot
.85894 .40762 Mdot
.44323 .53085 Mdot
.96852 .27393 Mdot
.03923 .59858 Mdot
.2087 .02425 Mdot
.41187 .12898 Mdot
.75585 .25455 Mdot
.60553 .46714 Mdot
.91049 .37424 Mdot
.27873 .56272 Mdot
.80934 .17227 Mdot
.45279 .5002 Mdot
.95753 .27984 Mdot
.08017 .59179 Mdot
.34162 .04955 Mdot
.65104 .21113 Mdot
.74307 .40236 Mdot
.70103 .45924 Mdot
.79815 .43326 Mdot
.60486 .49328 Mdot
.9237 .37383 Mdot
.23734 .57088 Mdot
.73732 .14668 Mdot
.58722 .45569 Mdot
.9179 .36292 Mdot
.25029 .56729 Mdot
.76073 .15469 Mdot
.54764 .47016 Mdot
.94435 .33846 Mdot
.15312 .58364 Mdot
.54913 .09463 Mdot
.76154 .33938 Mdot
.63572 .47066 Mdot
.88531 .39289 Mdot
.36272 .54715 Mdot
.91637 .22417 Mdot
.1877 .56635 Mdot
.62702 .11601 Mdot
.72161 .38752 Mdot
.73096 .44598 Mdot
.74358 .45176 Mdot
.72408 .45956 Mdot
.76184 .44751 Mdot
.68762 .47084 Mdot
.82316 .42497 Mdot
.54283 .50874 Mdot
.96463 .33549 Mdot
.08268 .59617 Mdot
.3517 .0511 Mdot
.66357 .21736 Mdot
.73147 .41011 Mdot
.7253 .45207 Mdot
.75616 .44826 Mdot
.69895 .46733 Mdot
.80517 .43197 Mdot
.58842 .49762 Mdot
.93748 .36366 Mdot
.188 .5794 Mdot
.63404 .11619 Mdot
.71492 .39186 Mdot
.74395 .44184 Mdot
.71861 .45978 Mdot
.77097 .44412 Mdot
.66785 .47648 Mdot
.85199 .41275 Mdot
.46418 .52656 Mdot
.97407 .28688 Mdot
.02594 .60201 Mdot
.16345 .01603 Mdot
.30031 .10101 Mdot
.61973 .1856 Mdot
.76203 .38301 Mdot
.65594 .47096 Mdot
.86362 .40539 Mdot
.42952 .53374 Mdot
.96314 .26546 Mdot
.05388 .59525 Mdot
.25728 .0333 Mdot
.51458 .15901 Mdot
.8005 .31803 Mdot
.54366 .49474 Mdot
.95758 .336 Mdot
.10728 .59181 Mdot
.42489 .0663 Mdot
.73363 .2626 Mdot
.64996 .45341 Mdot
.86187 .4017 Mdot
.43246 .53267 Mdot
.96419 .26727 Mdot
.05112 .5959 Mdot
.24826 .0316 Mdot
.49685 .15344 Mdot
.79827 .30707 Mdot
.54333 .49336 Mdot
.95701 .3358 Mdot
.10912 .59146 Mdot
.43017 .06744 Mdot
.73714 .26586 Mdot
.64538 .45558 Mdot
.86793 .39887 Mdot
.41454 .53641 Mdot
.95541 .2562 Mdot
.07595 .59047 Mdot
.32752 .04694 Mdot
.632 .20242 Mdot
.75879 .3906 Mdot
.66593 .46896 Mdot
.85072 .41156 Mdot
.46694 .52577 Mdot
.97445 .28858 Mdot
.02543 .60224 Mdot
.16171 .01571 Mdot
.29572 .09994 Mdot
.61215 .18276 Mdot
.76714 .37833 Mdot
.6436 .47412 Mdot
.87884 .39777 Mdot
.38356 .54315 Mdot
.93466 .23705 Mdot
.13576 .57765 Mdot
.49953 .0839 Mdot
.7646 .30872 Mdot
.61484 .47255 Mdot
.90555 .37999 Mdot
.2966 .55966 Mdot
.83668 .18331 Mdot
.3922 .5171 Mdot
.92943 .24239 Mdot
.15524 .57442 Mdot
.5502 .09594 Mdot
.7618 .34005 Mdot
.63554 .47082 Mdot
.88556 .39279 Mdot
.36195 .54731 Mdot
.91564 .2237 Mdot
.18976 .5659 Mdot
.63163 .11728 Mdot
.71782 .39037 Mdot
.73856 .44363 Mdot
.72916 .45645 Mdot
.75175 .45065 Mdot
.70846 .46461 Mdot
.78943 .43785 Mdot
.6262 .4879 Mdot
.90289 .38701 Mdot
.30805 .55802 Mdot
.85309 .19039 Mdot
.35334 .52724 Mdot
.89654 .21837 Mdot
.24518 .55409 Mdot
.74455 .15153 Mdot
.57658 .46016 Mdot
.92645 .35635 Mdot
.22011 .57258 Mdot
.70271 .13603 Mdot
.63874 .4343 Mdot
.86459 .39476 Mdot
.42171 .53435 Mdot
.95893 .26063 Mdot
.06604 .59265 Mdot
.29645 .04082 Mdot
.58459 .18322 Mdot
.78729 .3613 Mdot
.59364 .48657 Mdot
.92863 .36689 Mdot
.21824 .57393 Mdot
.69939 .13488 Mdot
.64315 .43224 Mdot
.859 .39749 Mdot
.43816 .53089 Mdot
.96619 .2708 Mdot
.04586 .59714 Mdot
.2309 .02834 Mdot
.46098 .1427 Mdot
.78679 .2849 Mdot
.55764 .48626 Mdot
.94837 .34464 Mdot
.14269 .58612 Mdot
.52255 .08819 Mdot
.76514 .32295 Mdot
.62067 .47288 Mdot
.90065 .3836 Mdot
.31314 .55663 Mdot
.85975 .19353 Mdot
.33714 .53135 Mdot
.87942 .20836 Mdot
.28998 .54351 Mdot
.81844 .17922 Mdot
.43484 .50582 Mdot
.95238 .26874 Mdot
.09231 .5886 Mdot
.37805 .05705 Mdot
.69367 .23365 Mdot
.69945 .42871 Mdot
.78569 .43228 Mdot
.63153 .48558 Mdot
.89669 .39031 Mdot
.32819 .55419 Mdot
.8791 .20283 Mdot
.2882 .54332 Mdot
.8155 .17812 Mdot
.44127 .504 Mdot
.9546 .27272 Mdot
.08672 .58998 Mdot
.36134 .05359 Mdot
.67535 .22332 Mdot
.71955 .41739 Mdot
.74885 .44471 Mdot
.711 .46281 Mdot
.7846 .43942 Mdot
.63732 .48491 Mdot
.89061 .39388 Mdot
.34782 .55043 Mdot
.9015 .21496 Mdot
.22872 .55716 Mdot
.71321 .14135 Mdot
.62508 .44079 Mdot
.88107 .38632 Mdot
.37168 .54453 Mdot
.9242 .22971 Mdot
.16579 .57119 Mdot
.57575 .10247 Mdot
.75328 .35583 Mdot
.65955 .46555 Mdot
.85676 .40763 Mdot
.44906 .52951 Mdot
.97032 .27753 Mdot
.03465 .59969 Mdot
.19323 .02142 Mdot
.37545 .11942 Mdot
.72149 .23204 Mdot
.65569 .44591 Mdot
.85174 .40524 Mdot
.46119 .5264 Mdot
.9731 .28503 Mdot
.02846 .60141 Mdot
.17214 .01759 Mdot
.32293 .10639 Mdot
.65475 .19958 Mdot
.73326 .40466 Mdot
.71956 .45318 Mdot
.7662 .44471 Mdot
.67768 .47354 Mdot
.83795 .41883 Mdot
.50332 .51788 Mdot
.97528 .31107 Mdot
.03338 .60275 Mdot
.19024 .02063 Mdot
.3681 .11758 Mdot
.71339 .2275 Mdot
.66661 .4409 Mdot
.83626 .41199 Mdot
.50425 .51684 Mdot
.97476 .31165 Mdot
.03551 .60243 Mdot
.19756 .02194 Mdot
.38569 .1221 Mdot
.73216 .23837 Mdot
.64075 .4525 Mdot
.87135 .39601 Mdot
.40372 .53852 Mdot
.94886 .24952 Mdot
.09485 .58643 Mdot
.38479 .05862 Mdot
.70054 .23781 Mdot
.69139 .43296 Mdot
.79946 .4273 Mdot
.59904 .49409 Mdot
.92846 .37023 Mdot
.22042 .57382 Mdot
.70398 .13623 Mdot
.63692 .43508 Mdot
.86683 .39364 Mdot
.41503 .53573 Mdot
.9554 .2565 Mdot
.07613 .59047 Mdot
.32811 .04705 Mdot
.63282 .20278 Mdot
.75815 .39111 Mdot
.66739 .46857 Mdot
.84872 .41247 Mdot
.47261 .52454 Mdot
.97523 .29209 Mdot
.02435 .60272 Mdot
.15809 .01505 Mdot
.28608 .0977 Mdot
.59575 .1768 Mdot
.7768 .3682 Mdot
.61908 .48009 Mdot
.90555 .38261 Mdot
.29788 .55966 Mdot
.83865 .1841 Mdot
.38762 .51831 Mdot
.92615 .23956 Mdot
.16435 .57239 Mdot
.57269 .10158 Mdot
.75451 .35394 Mdot
.65631 .46631 Mdot
.86093 .40562 Mdot
.43691 .53208 Mdot
.96616 .27002 Mdot
.04558 .59712 Mdot
.22993 .02817 Mdot
.45892 .14211 Mdot
.78584 .28363 Mdot
.55904 .48568 Mdot
.94749 .34551 Mdot
.14604 .58558 Mdot
.5313 .09026 Mdot
.76452 .32836 Mdot
.62453 .4725 Mdot
.89697 .38598 Mdot
.32527 .55436 Mdot
.87534 .20103 Mdot
.29795 .54099 Mdot
.82969 .18414 Mdot
.40999 .51278 Mdot
.94086 .25339 Mdot
.12338 .58148 Mdot
.46669 .07625 Mdot
.75618 .28843 Mdot
.62134 .46734 Mdot
.89736 .38401 Mdot
.32314 .5546 Mdot
.8726 .19971 Mdot
.30495 .5393 Mdot
.83944 .18847 Mdot
.38774 .5188 Mdot
.9265 .23964 Mdot
.1633 .57261 Mdot
.57011 .10093 Mdot
.75554 .35235 Mdot
.65359 .46695 Mdot
.86436 .40394 Mdot
.42678 .5342 Mdot
.96184 .26377 Mdot
.05755 .59445 Mdot
.26922 .03557 Mdot
.53713 .16638 Mdot
.80007 .33196 Mdot
.5514 .49447 Mdot
.95481 .34078 Mdot
.11905 .5901 Mdot
.4585 .07358 Mdot
.75244 .28337 Mdot
.62597 .46503 Mdot
.89202 .38687 Mdot
.34031 .5513 Mdot
.893 .21032 Mdot
.25173 .5519 Mdot
.75598 .15558 Mdot
.55723 .46722 Mdot
.9393 .34439 Mdot
.17269 .58052 Mdot
.59754 .10673 Mdot
.74151 .3693 Mdot
.6878 .45828 Mdot
.8168 .42509 Mdot
.55807 .50481 Mdot
.95719 .34491 Mdot
.11293 .59158 Mdot
.44142 .06979 Mdot
.7439 .27281 Mdot
.63665 .45975 Mdot
.87908 .39347 Mdot
.3808 .5433 Mdot
.93224 .23535 Mdot
.14277 .57616 Mdot
.51793 .08824 Mdot
.76579 .3201 Mdot
.618 .47329 Mdot
.9032 .38194 Mdot
.30466 .55821 Mdot
.84819 .18829 Mdot
.36517 .52421 Mdot
.90778 .22569 Mdot
.21492 .56104 Mdot
.686 .13283 Mdot
.66133 .42397 Mdot
.83447 .40872 Mdot
.50716 .51573 Mdot
.97414 .31344 Mdot
.03857 .60205 Mdot
.20807 .02383 Mdot
.41027 .1286 Mdot
.75457 .25356 Mdot
.60748 .46635 Mdot
.90857 .37545 Mdot
.2852 .56153 Mdot
.81948 .17626 Mdot
.43093 .50646 Mdot
.95066 .26633 Mdot
.09696 .58754 Mdot
.39178 .05993 Mdot
.70717 .24213 Mdot
.68344 .43706 Mdot
.81252 .42239 Mdot
.56682 .50216 Mdot
.95194 .35032 Mdot
.13341 .58833 Mdot
.49821 .08245 Mdot
.76386 .30791 Mdot
.6159 .47209 Mdot
.90443 .38065 Mdot
.30032 .55897 Mdot
.84204 .18561 Mdot
.37972 .52041 Mdot
.92013 .23468 Mdot
.18104 .56867 Mdot
.61223 .11189 Mdot
.73267 .37838 Mdot
.70782 .45282 Mdot
.78471 .43745 Mdot
.63612 .48498 Mdot
.89185 .39315 Mdot
.34384 .55119 Mdot
.8972 .2125 Mdot
.24038 .5545 Mdot
.73538 .14856 Mdot
.59154 .45449 Mdot
.91449 .36559 Mdot
.26222 .56518 Mdot
.78177 .16206 Mdot
.50867 .48316 Mdot
.95827 .31437 Mdot
.09441 .59224 Mdot
.38625 .05835 Mdot
.7017 .23871 Mdot
.69011 .43367 Mdot
.80162 .42651 Mdot
.59381 .49543 Mdot
.93282 .36699 Mdot
.2048 .57651 Mdot
.67128 .12657 Mdot
.67783 .41487 Mdot
.80928 .41892 Mdot
.57266 .50016 Mdot
.948 .35392 Mdot
.14841 .5859 Mdot
.53779 .09172 Mdot
.76365 .33237 Mdot
.62818 .47196 Mdot
.8933 .38824 Mdot
.33722 .55209 Mdot
.88958 .20841 Mdot
.26079 .54979 Mdot
.77172 .16118 Mdot
.52898 .47695 Mdot
.95271 .32693 Mdot
.11945 .58881 Mdot
.45901 .07382 Mdot
.75273 .28368 Mdot
.62558 .46521 Mdot
.89246 .38663 Mdot
.3389 .55157 Mdot
.89141 .20945 Mdot
.25597 .55092 Mdot
.76343 .1582 Mdot
.54407 .47183 Mdot
.94633 .33625 Mdot
.14544 .58486 Mdot
.52936 .08989 Mdot
.76475 .32716 Mdot
.62349 .47264 Mdot
.89799 .38534 Mdot
.32191 .55499 Mdot
.87113 .19895 Mdot
.30868 .53839 Mdot
.84447 .19077 Mdot
.37599 .52191 Mdot
.91738 .23238 Mdot
.18855 .56697 Mdot
.62931 .11653 Mdot
.71969 .38894 Mdot
.73481 .44479 Mdot
.73634 .45414 Mdot
.73819 .45508 Mdot
.73537 .45623 Mdot
.74091 .45448 Mdot
.73023 .45791 Mdot
.75063 .45131 Mdot
.71088 .46391 Mdot
.78532 .43935 Mdot
.63575 .48535 Mdot
.89241 .39291 Mdot
.34208 .55154 Mdot
.89526 .21142 Mdot
.2456 .5533 Mdot
.74497 .15179 Mdot
.57594 .46042 Mdot
.92693 .35595 Mdot
.21838 .57287 Mdot
.69918 .13497 Mdot
.64349 .43212 Mdot
.85857 .3977 Mdot
.43941 .53062 Mdot
.96666 .27157 Mdot
.04459 .59743 Mdot
.2267 .02756 Mdot
.45198 .14011 Mdot
.78243 .27934 Mdot
.56418 .48357 Mdot
.94417 .34869 Mdot
.15866 .58353 Mdot
.56352 .09806 Mdot
.75735 .34827 Mdot
.64814 .46807 Mdot
.871 .40057 Mdot
.40692 .5383 Mdot
.95108 .25149 Mdot
.08833 .5878 Mdot
.36533 .05459 Mdot
.67999 .22579 Mdot
.71462 .42026 Mdot
.75821 .44166 Mdot
.69182 .4686 Mdot
.81615 .42757 Mdot
.56082 .50441 Mdot
.95581 .34661 Mdot
.11846 .59072 Mdot
.45709 .07321 Mdot
.7518 .2825 Mdot
.62676 .46464 Mdot
.89108 .38736 Mdot
.34328 .55072 Mdot
.8963 .21216 Mdot
.24286 .55395 Mdot
.73998 .1501 Mdot
.58414 .45733 Mdot
.92063 .36102 Mdot
.24079 .56898 Mdot
.74323 .14882 Mdot
.57767 .45934 Mdot
.92544 .35702 Mdot
.22366 .57195 Mdot
.70988 .13823 Mdot
.62879 .43873 Mdot
.87659 .38861 Mdot
.38548 .54176 Mdot
.93568 .23824 Mdot
.13301 .57828 Mdot
.49223 .0822 Mdot
.76343 .30421 Mdot
.61496 .47182 Mdot
.9051 .38006 Mdot
.29799 .55939 Mdot
.83869 .18417 Mdot
.38754 .51834 Mdot
.9261 .23951 Mdot
.16451 .57236 Mdot
.57306 .10167 Mdot
.75436 .35417 Mdot
.65671 .46622 Mdot
.86041 .40587 Mdot
.43841 .53177 Mdot
.96674 .27095 Mdot
.04402 .59748 Mdot
.22475 .02721 Mdot
.44774 .1389 Mdot
.78018 .27672 Mdot
.56764 .48218 Mdot
.94184 .35082 Mdot
.16743 .58209 Mdot
.58516 .10348 Mdot
.74823 .36165 Mdot
.67182 .46243 Mdot
.84017 .4152 Mdot
.49593 .51925 Mdot
.9758 .3065 Mdot
.0293 .60308 Mdot
.17594 .01811 Mdot
.33256 .10874 Mdot
.66851 .20553 Mdot
.71964 .41316 Mdot
.74666 .44476 Mdot
.71507 .46146 Mdot
.77749 .44194 Mdot
.65344 .48052 Mdot
.87112 .40385 Mdot
.40817 .53838 Mdot
.95201 .25226 Mdot
.08558 .58837 Mdot
.35701 .05289 Mdot
.67035 .22065 Mdot
.72467 .4143 Mdot
.73889 .44787 Mdot
.73063 .45666 Mdot
.74934 .45156 Mdot
.71342 .46311 Mdot
.78093 .44092 Mdot
.64578 .48264 Mdot
.88065 .39911 Mdot
.37909 .54427 Mdot
.93114 .23429 Mdot
.14582 .57547 Mdot
.5258 .09012 Mdot
.76554 .32496 Mdot
.62085 .47313 Mdot
.90061 .38371 Mdot
.31331 .55661 Mdot
.85998 .19364 Mdot
.33656 .5315 Mdot
.87878 .20801 Mdot
.29164 .54311 Mdot
.82089 .18024 Mdot
.42949 .50734 Mdot
.9503 .26544 Mdot
.09774 .58732 Mdot
.39404 .06041 Mdot
.70926 .24353 Mdot
.68088 .43834 Mdot
.8166 .42081 Mdot
.55647 .50469 Mdot
.95779 .34392 Mdot
.11037 .59195 Mdot
.4341 .06821 Mdot
.73959 .26829 Mdot
.64221 .45709 Mdot
.87204 .39691 Mdot
.40223 .53895 Mdot
.94796 .24859 Mdot
.09744 .58587 Mdot
.39242 .06022 Mdot
.70784 .24253 Mdot
.6826 .43747 Mdot
.81386 .42187 Mdot
.56343 .503 Mdot
.95395 .34822 Mdot
.12557 .58957 Mdot
.47686 .07761 Mdot
.75916 .29472 Mdot
.61866 .46919 Mdot
.90063 .38235 Mdot
.31259 .55662 Mdot
.85895 .19319 Mdot
.33911 .53086 Mdot
.88161 .20958 Mdot
.28435 .54487 Mdot
.80999 .17574 Mdot
.45297 .5006 Mdot
.95779 .27995 Mdot
.07933 .59195 Mdot
.33902 .04903 Mdot
.64762 .20953 Mdot
.74607 .40025 Mdot
.69453 .4611 Mdot
.8086 .42925 Mdot
.57923 .49975 Mdot
.94416 .35798 Mdot
.16323 .58352 Mdot
.57521 .10088 Mdot
.75281 .3555 Mdot
.66029 .46526 Mdot
.85575 .40808 Mdot
.45198 .52888 Mdot
.97115 .27934 Mdot
.0326 .6002 Mdot
.18625 .02015 Mdot
.35844 .11511 Mdot
.70211 .22153 Mdot
.68115 .43393 Mdot
.8141 .42097 Mdot
.56243 .50314 Mdot
.95448 .3476 Mdot
.12348 .5899 Mdot
.47109 .07632 Mdot
.75731 .29115 Mdot
.62049 .46804 Mdot
.89846 .38349 Mdot
.31963 .55528 Mdot
.86815 .19754 Mdot
.31622 .53655 Mdot
.85434 .19544 Mdot
.35248 .52801 Mdot
.89596 .21785 Mdot
.24665 .55373 Mdot
.74721 .15244 Mdot
.57215 .4618 Mdot
.92965 .35361 Mdot
.20853 .57455 Mdot
.67861 .12888 Mdot
.66943 .4194 Mdot
.82231 .41373 Mdot
.53941 .50822 Mdot
.96538 .33337 Mdot
.07906 .59664 Mdot
.34044 .04886 Mdot
.64927 .2104 Mdot
.74468 .40127 Mdot
.69757 .46024 Mdot
.80375 .43112 Mdot
.59123 .49675 Mdot
.93521 .3654 Mdot
.19627 .57799 Mdot
.65265 .1213 Mdot
.69765 .40336 Mdot
.77604 .43117 Mdot
.65122 .47962 Mdot
.87319 .40247 Mdot
.40173 .53966 Mdot
.94793 .24828 Mdot
.0974 .58585 Mdot
.39228 .06019 Mdot
.70771 .24244 Mdot
.68275 .43739 Mdot
.81362 .42196 Mdot
.56405 .50284 Mdot
.95359 .3486 Mdot
.12699 .58935 Mdot
.48075 .07848 Mdot
.76027 .29712 Mdot
.61768 .46987 Mdot
.90182 .38175 Mdot
.30873 .55735 Mdot
.85376 .19081 Mdot
.35178 .52765 Mdot
.89499 .21741 Mdot
.24931 .55313 Mdot
.752 .15408 Mdot
.56403 .46476 Mdot
.93511 .34859 Mdot
.18841 .57793 Mdot
.63431 .11645 Mdot
.71478 .39203 Mdot
.74426 .44176 Mdot
.718 .45998 Mdot
.77205 .44375 Mdot
.66547 .47715 Mdot
.85526 .41128 Mdot
.45483 .52858 Mdot
.97205 .2811 Mdot
.03029 .60076 Mdot
.17832 .01872 Mdot
.33867 .11021 Mdot
.67688 .20931 Mdot
.71074 .41834 Mdot
.76341 .43926 Mdot
.68054 .47182 Mdot
.83331 .4206 Mdot
.51581 .51501 Mdot
.97319 .31879 Mdot
.04453 .60147 Mdot
.22845 .02752 Mdot
.45557 .14119 Mdot
.78427 .28156 Mdot
.56139 .4847 Mdot
.94599 .34696 Mdot
.15175 .58466 Mdot
.54603 .09379 Mdot
.76219 .33747 Mdot
.63352 .47106 Mdot
.88769 .39154 Mdot
.35518 .54862 Mdot
.90897 .21951 Mdot
.2083 .56177 Mdot
.67189 .12873 Mdot
.6781 .41525 Mdot
.80911 .41909 Mdot
.57313 .50006 Mdot
.9477 .35422 Mdot
.14958 .58571 Mdot
.54079 .09244 Mdot
.76316 .33423 Mdot
.63004 .47166 Mdot
.89137 .38939 Mdot
.34342 .5509 Mdot
.89655 .21224 Mdot
.24217 .5541 Mdot
.73871 .14967 Mdot
.58621 .45655 Mdot
.91896 .36229 Mdot
.24666 .56795 Mdot
.75414 .15245 Mdot
.55921 .46608 Mdot
.93791 .34561 Mdot
.17784 .57966 Mdot
.6098 .10991 Mdot
.7337 .37687 Mdot
.7053 .45345 Mdot
.78889 .4359 Mdot
.62641 .48756 Mdot
.90253 .38715 Mdot
.3092 .5578 Mdot
.85465 .1911 Mdot
.34955 .5282 Mdot
.89272 .21604 Mdot
.25532 .55173 Mdot
.76261 .1578 Mdot
.54548 .47132 Mdot
.94563 .33713 Mdot
.14819 .58443 Mdot
.53649 .09159 Mdot
.76393 .33157 Mdot
.62725 .47213 Mdot
.89426 .38766 Mdot
.33411 .55268 Mdot
.88598 .20649 Mdot
.2703 .54757 Mdot
.78756 .16706 Mdot
.49878 .48674 Mdot
.96012 .30826 Mdot
.08507 .59339 Mdot
.35785 .05258 Mdot
.67111 .22116 Mdot
.72396 .41477 Mdot
.7403 .44743 Mdot
.7279 .45753 Mdot
.75443 .44987 Mdot
.70303 .46626 Mdot
.79855 .4345 Mdot
.60457 .49353 Mdot
.92405 .37364 Mdot
.23614 .57109 Mdot
.73503 .14594 Mdot
.59089 .45427 Mdot
.91482 .36519 Mdot
.261 .56539 Mdot
.77966 .16131 Mdot
.5127 .48186 Mdot
.95738 .31687 Mdot
.09866 .59169 Mdot
.39897 .06098 Mdot
.71345 .24658 Mdot
.67577 .44094 Mdot
.82464 .41765 Mdot
.53568 .50966 Mdot
.96707 .33107 Mdot
.07205 .59768 Mdot
.31845 .04453 Mdot
.6186 .19681 Mdot
.76847 .38232 Mdot
.64287 .47494 Mdot
.88001 .39732 Mdot
.38002 .54388 Mdot
.9318 .23487 Mdot
.14394 .57589 Mdot
.52096 .08896 Mdot
.76575 .32197 Mdot
.61899 .47326 Mdot
.90232 .38256 Mdot
.30761 .55766 Mdot
.85227 .19011 Mdot
.35536 .52673 Mdot
.89854 .21962 Mdot
.23983 .55533 Mdot
.73472 .14823 Mdot
.59254 .45408 Mdot
.91361 .36621 Mdot
.26524 .56464 Mdot
.78691 .16392 Mdot
.49865 .48634 Mdot
.95993 .30818 Mdot
.08571 .59327 Mdot
.3598 .05297 Mdot
.6734 .22237 Mdot
.72161 .41618 Mdot
.74488 .44598 Mdot
.71892 .46036 Mdot
.77074 .44432 Mdot
.6684 .47634 Mdot
.85123 .4131 Mdot
.46633 .52609 Mdot
.97444 .28821 Mdot
.02527 .60224 Mdot
.16115 .01562 Mdot
.29424 .0996 Mdot
.60969 .18185 Mdot
.76871 .37681 Mdot
.63971 .47509 Mdot
.88339 .39536 Mdot
.36944 .54596 Mdot
.92268 .22833 Mdot
.16994 .57025 Mdot
.5857 .10503 Mdot
.74865 .36198 Mdot
.67122 .46269 Mdot
.84106 .41483 Mdot
.49349 .5198 Mdot
.97593 .30499 Mdot
.02811 .60316 Mdot
.17173 .01737 Mdot
.32181 .10614 Mdot
.65311 .19889 Mdot
.73479 .40364 Mdot
.71639 .45413 Mdot
.77181 .44276 Mdot
.66548 .477 Mdot
.85517 .41129 Mdot
.45507 .52852 Mdot
.97211 .28125 Mdot
.03015 .6008 Mdot
.17786 .01863 Mdot
.33749 .10992 Mdot
.67529 .20858 Mdot
.71247 .41735 Mdot
.76022 .44033 Mdot
.68728 .46984 Mdot
.82314 .42477 Mdot
.54277 .50873 Mdot
.96464 .33545 Mdot
.08263 .59618 Mdot
.35153 .05107 Mdot
.66337 .21726 Mdot
.73166 .40999 Mdot
.7249 .45219 Mdot
.75689 .44802 Mdot
.69745 .46778 Mdot
.8076 .43105 Mdot
.58242 .49912 Mdot
.94196 .35996 Mdot
.17145 .58217 Mdot
.59527 .10596 Mdot
.74275 .3679 Mdot
.68489 .45904 Mdot
.82121 .42328 Mdot
.54669 .50754 Mdot
.96281 .33787 Mdot
.09017 .59505 Mdot
.37454 .05573 Mdot
.6897 .23148 Mdot
.70405 .42626 Mdot
.77759 .43512 Mdot
.64992 .48058 Mdot
.87511 .40167 Mdot
.39598 .54085 Mdot
.94403 .24473 Mdot
.10867 .58344 Mdot
.42494 .06716 Mdot
.73407 .26263 Mdot
.6492 .45368 Mdot
.86285 .40122 Mdot
.42956 .53327 Mdot
.96293 .26549 Mdot
.0546 .59512 Mdot
.25964 .03375 Mdot
.51913 .16047 Mdot
.80071 .32084 Mdot
.54456 .49487 Mdot
.95735 .33656 Mdot
.10831 .59168 Mdot
.42787 .06694 Mdot
.73563 .26444 Mdot
.64735 .45465 Mdot
.86535 .40008 Mdot
.42221 .53482 Mdot
.95946 .26094 Mdot
.06437 .59298 Mdot
.29113 .03978 Mdot
.57575 .17993 Mdot
.79088 .35584 Mdot
.58325 .48879 Mdot
.93645 .36047 Mdot
.18982 .57876 Mdot
.63803 .11732 Mdot
.71145 .39433 Mdot
.75065 .4397 Mdot
.70522 .46393 Mdot
.7941 .43585 Mdot
.61507 .49078 Mdot
.91421 .38014 Mdot
.27014 .56501 Mdot
.79575 .16696 Mdot
.48092 .4918 Mdot
.96092 .29722 Mdot
.07695 .59388 Mdot
.33239 .04756 Mdot
.63861 .20543 Mdot
.75363 .39468 Mdot
.67775 .46577 Mdot
.83409 .41887 Mdot
.51303 .5155 Mdot
.97368 .31707 Mdot
.04196 .60177 Mdot
.21974 .02594 Mdot
.43658 .1358 Mdot
.77364 .26982 Mdot
.57781 .47814 Mdot
.93448 .3571 Mdot
.19459 .57754 Mdot
.64855 .12026 Mdot
.70172 .40083 Mdot
.76876 .43369 Mdot
.66721 .47512 Mdot
.85212 .41236 Mdot
.46365 .52664 Mdot
.97395 .28655 Mdot
.02619 .60194 Mdot
.16429 .01618 Mdot
.30252 .10153 Mdot
.62332 .18697 Mdot
.75948 .38523 Mdot
.66199 .46938 Mdot
.85572 .40913 Mdot
.45256 .52886 Mdot
.97136 .2797 Mdot
.03204 .60033 Mdot
.18433 .0198 Mdot
.35369 .11392 Mdot
.69631 .21859 Mdot
.68831 .43034 Mdot
.80253 .4254 Mdot
.59122 .49599 Mdot
.93485 .36539 Mdot
.19743 .57777 Mdot
.6552 .12202 Mdot
.69508 .40494 Mdot
.78055 .42959 Mdot
.64108 .4824 Mdot
.88552 .39621 Mdot
.36373 .54728 Mdot
.9175 .2248 Mdot
.18451 .56704 Mdot
.61975 .11403 Mdot
.72727 .38303 Mdot
.71933 .44948 Mdot
.76479 .44457 Mdot
.68039 .47267 Mdot
.83392 .42051 Mdot
.51424 .51539 Mdot
.97353 .31782 Mdot
.04288 .60167 Mdot
.22286 .0265 Mdot
.44345 .13773 Mdot
.77779 .27407 Mdot
.57134 .4807 Mdot
.93925 .3531 Mdot
.17707 .58049 Mdot
.60831 .10944 Mdot
.73467 .37596 Mdot
.70317 .45405 Mdot
.79241 .43458 Mdot
.61814 .48974 Mdot
.91106 .38203 Mdot
.28077 .56307 Mdot
.81292 .17352 Mdot
.44509 .50241 Mdot
.95552 .27508 Mdot
.08473 .59055 Mdot
.35539 .05236 Mdot
.66831 .21964 Mdot
.72674 .41304 Mdot
.73478 .44915 Mdot
.7385 .45412 Mdot
.73436 .45642 Mdot
.74276 .45386 Mdot
.7266 .45905 Mdot
.75736 .44906 Mdot
.69705 .46807 Mdot
.80833 .4308 Mdot
.58062 .49958 Mdot
.94326 .35884 Mdot
.16661 .58297 Mdot
.58353 .10297 Mdot
.749 .36064 Mdot
.66991 .46291 Mdot
.84282 .41403 Mdot
.48861 .52089 Mdot
.97605 .30198 Mdot
.02622 .60323 Mdot
.16502 .0162 Mdot
.30439 .10199 Mdot
.62633 .18812 Mdot
.75726 .38709 Mdot
.66717 .46801 Mdot
.84873 .41233 Mdot
.47251 .52454 Mdot
.97521 .29203 Mdot
.02439 .60271 Mdot
.15821 .01507 Mdot
.2864 .09778 Mdot
.59632 .17701 Mdot
.77649 .36855 Mdot
.61988 .4799 Mdot
.90476 .3831 Mdot
.30051 .55917 Mdot
.84243 .18573 Mdot
.37878 .52065 Mdot
.91939 .2341 Mdot
.18311 .56821 Mdot
.61697 .11317 Mdot
.72928 .38131 Mdot
.71507 .45072 Mdot
.77227 .44194 Mdot
.66415 .47729 Mdot
.85694 .41047 Mdot
.44995 .52962 Mdot
.97073 .27808 Mdot
.03349 .59994 Mdot
.18924 .0207 Mdot
.36578 .11696 Mdot
.71073 .22607 Mdot
.6701 .43926 Mdot
.8311 .41415 Mdot
.51817 .51365 Mdot
.97226 .32025 Mdot
.04852 .60089 Mdot
.24184 .02999 Mdot
.48366 .14947 Mdot
.79516 .29892 Mdot
.54626 .49144 Mdot
.95514 .33761 Mdot
.11638 .59031 Mdot
.45087 .07193 Mdot
.74892 .27865 Mdot
.63027 .46286 Mdot
.88689 .38953 Mdot
.35654 .54813 Mdot
.91022 .22035 Mdot
.20487 .56255 Mdot
.66464 .12661 Mdot
.68612 .41077 Mdot
.79608 .42404 Mdot
.60497 .49201 Mdot
.923 .37389 Mdot
.23959 .57044 Mdot
.74157 .14807 Mdot
.58031 .45831 Mdot
.92341 .35865 Mdot
.23087 .5707 Mdot
.72419 .14269 Mdot
.60784 .44758 Mdot
.89918 .37566 Mdot
.31368 .55572 Mdot
.86007 .19386 Mdot
.33644 .53155 Mdot
.87865 .20793 Mdot
.29197 .54303 Mdot
.82137 .18045 Mdot
.42843 .50763 Mdot
.94987 .26479 Mdot
.09889 .58705 Mdot
.3974 .06112 Mdot
.7123 .24561 Mdot
.67713 .44022 Mdot
.82251 .41849 Mdot
.54124 .50834 Mdot
.96491 .3345 Mdot
.08123 .59635 Mdot
.34718 .0502 Mdot
.65795 .21457 Mdot
.73682 .40664 Mdot
.71428 .45538 Mdot
.77579 .44145 Mdot
.65671 .47947 Mdot
.86685 .40587 Mdot
.42091 .53575 Mdot
.95913 .26014 Mdot
.06514 .59277 Mdot
.29355 .04026 Mdot
.5798 .18142 Mdot
.78931 .35834 Mdot
.58787 .48782 Mdot
.93308 .36332 Mdot
.20217 .57667 Mdot
.66545 .12495 Mdot
.68432 .41127 Mdot
.79881 .42293 Mdot
.59838 .49369 Mdot
.92874 .36982 Mdot
.21931 .57399 Mdot
.70169 .13554 Mdot
.64002 .43367 Mdot
.86296 .39556 Mdot
.42652 .53334 Mdot
.96127 .2636 Mdot
.05945 .5941 Mdot
.27536 .03674 Mdot
.54833 .17018 Mdot
.7985 .33888 Mdot
.55827 .4935 Mdot
.95162 .34503 Mdot
.13193 .58813 Mdot
.49401 .08154 Mdot
.76323 .30531 Mdot
.61589 .4717 Mdot
.90425 .38064 Mdot
.30086 .55886 Mdot
.8428 .18594 Mdot
.37793 .52088 Mdot
.9187 .23357 Mdot
.185 .56779 Mdot
.62129 .11434 Mdot
.72606 .38398 Mdot
.72184 .44873 Mdot
.7603 .44612 Mdot
.68995 .46989 Mdot
.81942 .42641 Mdot
.55248 .50643 Mdot
.96021 .34145 Mdot
.10088 .59344 Mdot
.40653 .06235 Mdot
.71977 .25125 Mdot
.66784 .44484 Mdot
.83664 .41275 Mdot
.50367 .51707 Mdot
.97488 .31129 Mdot
.0349 .60251 Mdot
.19546 .02157 Mdot
.38069 .1208 Mdot
.72705 .23528 Mdot
.64799 .44934 Mdot
.86208 .40048 Mdot
.4313 .53279 Mdot
.96364 .26656 Mdot
.05268 .59556 Mdot
.25336 .03256 Mdot
.50696 .15659 Mdot
.79982 .31332 Mdot
.5429 .49432 Mdot
.95761 .33553 Mdot
.10695 .59183 Mdot
.4239 .0661 Mdot
.73295 .26199 Mdot
.65084 .45299 Mdot
.86069 .40224 Mdot
.43591 .53193 Mdot
.9656 .26941 Mdot
.04725 .59677 Mdot
.23548 .0292 Mdot
.47067 .14554 Mdot
.79081 .29089 Mdot
.55188 .48875 Mdot
.95185 .34108 Mdot
.12922 .58828 Mdot
.4865 .07986 Mdot
.76174 .30067 Mdot
.61655 .47078 Mdot
.90324 .38105 Mdot
.30411 .55823 Mdot
.84738 .18795 Mdot
.3671 .52371 Mdot
.90952 .22688 Mdot
.21018 .56211 Mdot
.67622 .1299 Mdot
.67307 .41792 Mdot
.81696 .41598 Mdot
.55327 .50491 Mdot
.95917 .34194 Mdot
.1047 .5928 Mdot
.41769 .06471 Mdot
.72847 .25815 Mdot
.65667 .45022 Mdot
.8527 .40584 Mdot
.45895 .527 Mdot
.97268 .28365 Mdot
.02927 .60115 Mdot
.17491 .01809 Mdot
.33002 .1081 Mdot
.66495 .20396 Mdot
.72329 .41096 Mdot
.73956 .44702 Mdot
.72902 .45708 Mdot
.75231 .45056 Mdot
.70738 .46495 Mdot
.79128 .43718 Mdot
.62187 .48904 Mdot
.90742 .38434 Mdot
.29305 .56081 Mdot
.8317 .18111 Mdot
.40357 .51402 Mdot
.93685 .24942 Mdot
.1346 .57901 Mdot
.49699 .08319 Mdot
.76418 .30716 Mdot
.61491 .47229 Mdot
.90537 .38004 Mdot
.29719 .55955 Mdot
.83753 .18367 Mdot
.39023 .51762 Mdot
.92804 .24118 Mdot
.1591 .57356 Mdot
.5598 .09833 Mdot
.75914 .34597 Mdot
.64358 .46918 Mdot
.87647 .39775 Mdot
.39026 .54169 Mdot
.93975 .2412 Mdot
.1211 .5808 Mdot
.45987 .07485 Mdot
.7535 .28421 Mdot
.62438 .46569 Mdot
.8938 .38589 Mdot
.3346 .5524 Mdot
.88646 .20679 Mdot
.26907 .54786 Mdot
.78554 .16629 Mdot
.50273 .48549 Mdot
.95956 .31071 Mdot
.0882 .59304 Mdot
.36746 .05451 Mdot
.68212 .2271 Mdot
.71239 .42158 Mdot
.76239 .44028 Mdot
.68303 .47119 Mdot
.82964 .42214 Mdot
.52565 .51274 Mdot
.97072 .32487 Mdot
.05623 .59994 Mdot
.26744 .03475 Mdot
.5336 .16528 Mdot
.80041 .32978 Mdot
.54957 .49468 Mdot
.95558 .33965 Mdot
.11588 .59058 Mdot
.44954 .07162 Mdot
.74825 .27783 Mdot
.63111 .46244 Mdot
.88587 .39004 Mdot
.35971 .5475 Mdot
.91336 .22232 Mdot
.19616 .56449 Mdot
.64583 .12123 Mdot
.70516 .39915 Mdot
.76274 .43581 Mdot
.68018 .4714 Mdot
.8336 .42037 Mdot
.51498 .51519 Mdot
.97336 .31828 Mdot
.04369 .60157 Mdot
.22559 .027 Mdot
.4494 .13942 Mdot
.78111 .27775 Mdot
.56621 .48275 Mdot
.94281 .34993 Mdot
.16377 .58269 Mdot
.5762 .10122 Mdot
.75243 .35611 Mdot
.6613 .46503 Mdot
.85442 .40871 Mdot
.4558 .52806 Mdot
.97214 .2817 Mdot
.03026 .60081 Mdot
.17825 .0187 Mdot
.33849 .11016 Mdot
.67664 .2092 Mdot
.71101 .41818 Mdot
.76292 .43943 Mdot
.68158 .47151 Mdot
.83176 .42124 Mdot
.51997 .51406 Mdot
.97223 .32136 Mdot
.04917 .60087 Mdot
.24405 .03039 Mdot
.48815 .15083 Mdot
.79637 .30169 Mdot
.54493 .49219 Mdot
.95593 .33679 Mdot
.11327 .5908 Mdot
.44205 .07001 Mdot
.74429 .2732 Mdot
.63612 .46 Mdot
.87973 .39315 Mdot
.37881 .5437 Mdot
.9306 .23412 Mdot
.14746 .57514 Mdot
.53004 .09114 Mdot
.76522 .32758 Mdot
.62277 .47293 Mdot
.89878 .3849 Mdot
.31935 .55548 Mdot
.86787 .19737 Mdot
.31692 .53637 Mdot
.85523 .19587 Mdot
.35034 .52856 Mdot
.89379 .21652 Mdot
.2524 .55239 Mdot
.75749 .15599 Mdot
.55454 .46816 Mdot
.94084 .34272 Mdot
.16681 .58147 Mdot
.58331 .1031 Mdot
.74919 .36051 Mdot
.66949 .46303 Mdot
.84341 .41377 Mdot
.48697 .52125 Mdot
.97605 .30096 Mdot
.02573 .60323 Mdot
.16326 .0159 Mdot
.29979 .1009 Mdot
.61888 .18528 Mdot
.76263 .38249 Mdot
.65452 .47133 Mdot
.86542 .40452 Mdot
.42417 .53486 Mdot
.96065 .26215 Mdot
.06088 .59371 Mdot
.27993 .03762 Mdot
.55647 .17301 Mdot
.79679 .34392 Mdot
.5645 .49245 Mdot
.94833 .34888 Mdot
.14486 .5861 Mdot
.52839 .08953 Mdot
.76477 .32657 Mdot
.62316 .47265 Mdot
.8983 .38513 Mdot
.32091 .55518 Mdot
.86986 .19833 Mdot
.31189 .5376 Mdot
.84873 .19276 Mdot
.36593 .52454 Mdot
.90873 .22616 Mdot
.21226 .56163 Mdot
.68051 .13118 Mdot
.668 .42058 Mdot
.82467 .41285 Mdot
.53328 .50967 Mdot
.96766 .32959 Mdot
.06925 .59805 Mdot
.30956 .0428 Mdot
.60518 .19132 Mdot
.77687 .37402 Mdot
.62176 .48013 Mdot
.9032 .38427 Mdot
.3058 .55821 Mdot
.84988 .189 Mdot
.3611 .52526 Mdot
.90403 .22317 Mdot
.22508 .55872 Mdot
.70643 .1391 Mdot
.63457 .4366 Mdot
.86993 .39218 Mdot
.4058 .53765 Mdot
.94996 .2508 Mdot
.09179 .58711 Mdot
.37571 .05673 Mdot
.6913 .2322 Mdot
.70213 .42725 Mdot
.78097 .43394 Mdot
.6423 .48267 Mdot
.88436 .39696 Mdot
.36742 .54657 Mdot
.92094 .22708 Mdot
.17483 .56917 Mdot
.59731 .10805 Mdot
.74232 .36916 Mdot
.68628 .45878 Mdot
.81917 .42414 Mdot
.552 .50627 Mdot
.96031 .34115 Mdot
.10038 .59351 Mdot
.40503 .06204 Mdot
.71853 .25032 Mdot
.66942 .44408 Mdot
.8343 .41372 Mdot
.51 .51563 Mdot
.97396 .3152 Mdot
.04008 .60194 Mdot
.21328 .02477 Mdot
.42213 .13181 Mdot
.76379 .26089 Mdot
.59321 .47205 Mdot
.92188 .36662 Mdot
.23959 .56975 Mdot
.74124 .14808 Mdot
.5809 .45811 Mdot
.92297 .35902 Mdot
.23245 .57043 Mdot
.72727 .14366 Mdot
.60313 .44948 Mdot
.90376 .37276 Mdot
.29852 .55855 Mdot
.83909 .18449 Mdot
.38669 .51859 Mdot
.92548 .23899 Mdot
.16622 .57198 Mdot
.5772 .10273 Mdot
.7526 .35673 Mdot
.66128 .46513 Mdot
.8545 .40869 Mdot
.45558 .52811 Mdot
.97209 .28156 Mdot
.03038 .60078 Mdot
.17866 .01877 Mdot
.33953 .11042 Mdot
.67804 .20984 Mdot
.70948 .41905 Mdot
.76574 .43848 Mdot
.67557 .47325 Mdot
.84059 .41752 Mdot
.496 .51951 Mdot
.97593 .30655 Mdot
.02886 .60316 Mdot
.17444 .01784 Mdot
.32873 .10781 Mdot
.66312 .20316 Mdot
.72512 .40983 Mdot
.73595 .44815 Mdot
.73596 .45485 Mdot
.7392 .45485 Mdot
.73346 .45685 Mdot
.74455 .4533 Mdot
.72308 .46015 Mdot
.7638 .44689 Mdot
.68349 .47205 Mdot
.82944 .42242 Mdot
.52627 .51262 Mdot
.97055 .32525 Mdot
.05701 .59983 Mdot
.27002 .03524 Mdot
.53837 .16688 Mdot
.79998 .33273 Mdot
.55198 .49441 Mdot
.95456 .34114 Mdot
.12005 .58995 Mdot
.4613 .0742 Mdot
.75363 .2851 Mdot
.62456 .46577 Mdot
.89367 .386 Mdot
.33502 .55232 Mdot
.88696 .20705 Mdot
.26776 .54817 Mdot
.7834 .16549 Mdot
.50689 .48417 Mdot
.95883 .31327 Mdot
.09194 .59259 Mdot
.37882 .05682 Mdot
.69427 .23412 Mdot
.69881 .42908 Mdot
.78681 .43189 Mdot
.62894 .48628 Mdot
.89952 .38871 Mdot
.31898 .55594 Mdot
.86758 .19714 Mdot
.31759 .53619 Mdot
.85608 .19628 Mdot
.34828 .52909 Mdot
.89168 .21525 Mdot
.25799 .55109 Mdot
.76723 .15945 Mdot
.53717 .47417 Mdot
.94946 .33199 Mdot
.13287 .5868 Mdot
.49597 .08212 Mdot
.76361 .30652 Mdot
.61571 .47194 Mdot
.90451 .38053 Mdot
.30001 .55902 Mdot
.8416 .18542 Mdot
.38076 .52014 Mdot
.92096 .23532 Mdot
.17877 .56918 Mdot
.60696 .11048 Mdot
.73625 .37512 Mdot
.69999 .45503 Mdot
.79766 .43262 Mdot
.60564 .49298 Mdot
.92295 .37431 Mdot
.23994 .57041 Mdot
.74225 .14829 Mdot
.57919 .45873 Mdot
.92427 .35796 Mdot
.22781 .57123 Mdot
.71817 .1408 Mdot
.61683 .44386 Mdot
.88993 .38122 Mdot
.34368 .55 Mdot
.89643 .21241 Mdot
.2426 .55403 Mdot
.73951 .14994 Mdot
.5849 .45705 Mdot
.92003 .36149 Mdot
.24293 .56861 Mdot
.74724 .15014 Mdot
.57099 .46182 Mdot
.93027 .35289 Mdot
.20619 .57494 Mdot
.67361 .12743 Mdot
.67526 .41631 Mdot
.81335 .41733 Mdot
.56244 .50267 Mdot
.95425 .34761 Mdot
.12427 .58976 Mdot
.47326 .0768 Mdot
.75804 .29249 Mdot
.61975 .46849 Mdot
.89934 .38303 Mdot
.31679 .55582 Mdot
.86449 .19579 Mdot
.3254 .53428 Mdot
.86576 .20111 Mdot
.32451 .53507 Mdot
.86495 .20056 Mdot
.32645 .53457 Mdot
.86729 .20176 Mdot
.32063 .53602 Mdot
.86017 .19816 Mdot
.33825 .53161 Mdot
.88092 .20905 Mdot
.28606 .54444 Mdot
.81258 .17679 Mdot
.44748 .5022 Mdot
.95642 .27655 Mdot
.08237 .5911 Mdot
.34825 .05091 Mdot
.65953 .21523 Mdot
.73528 .40761 Mdot
.71746 .45443 Mdot
.77023 .44342 Mdot
.669 .47603 Mdot
.85033 .41347 Mdot
.46888 .52553 Mdot
.97483 .28978 Mdot
.02465 .60248 Mdot
.15902 .01523 Mdot
.28858 .09828 Mdot
.60009 .17835 Mdot
.77443 .37087 Mdot
.62525 .47862 Mdot
.89928 .38642 Mdot
.3186 .55579 Mdot
.86698 .1969 Mdot
.31912 .53582 Mdot
.85802 .19723 Mdot
.34358 .53028 Mdot
.88673 .21234 Mdot
.27097 .54803 Mdot
.78894 .16747 Mdot
.49601 .48759 Mdot
.96044 .30655 Mdot
.08315 .59358 Mdot
.35192 .05139 Mdot
.66396 .2175 Mdot
.73106 .41035 Mdot
.72612 .45182 Mdot
.75466 .44877 Mdot
.70205 .46641 Mdot
.80009 .43389 Mdot
.60082 .49448 Mdot
.92734 .37133 Mdot
.22453 .57313 Mdot
.71229 .13877 Mdot
.62527 .44022 Mdot
.88061 .38644 Mdot
.37304 .54425 Mdot
.92539 .23055 Mdot
.16243 .57192 Mdot
.56755 .10039 Mdot
.75656 .35076 Mdot
.65087 .46758 Mdot
.86774 .40226 Mdot
.41673 .53629 Mdot
.95677 .25756 Mdot
.07195 .59132 Mdot
.31504 .04447 Mdot
.61383 .19471 Mdot
.77154 .37937 Mdot
.63526 .47684 Mdot
.88877 .39261 Mdot
.35256 .54929 Mdot
.90637 .21789 Mdot
.21543 .56017 Mdot
.68668 .13314 Mdot
.66054 .42439 Mdot
.83561 .40824 Mdot
.50406 .51644 Mdot
.97457 .31153 Mdot
.03613 .60232 Mdot
.19968 .02233 Mdot
.39072 .12341 Mdot
.7371 .24148 Mdot
.63362 .45555 Mdot
.88007 .3916 Mdot
.37708 .54392 Mdot
.92908 .23305 Mdot
.15182 .5742 Mdot
.54114 .09383 Mdot
.76374 .33444 Mdot
.62902 .47201 Mdot
.89252 .38876 Mdot
.33974 .55161 Mdot
.89246 .20997 Mdot
.25314 .55157 Mdot
.75848 .15645 Mdot
.55286 .46876 Mdot
.94178 .34169 Mdot
.16319 .58205 Mdot
.57442 .10086 Mdot
.75323 .35501 Mdot
.65925 .46552 Mdot
.85711 .40744 Mdot
.44804 .52972 Mdot
.97001 .2769 Mdot
.03543 .5995 Mdot
.19586 .0219 Mdot
.38177 .12105 Mdot
.72815 .23595 Mdot
.64644 .45002 Mdot
.8641 .39952 Mdot
.42535 .53404 Mdot
.96094 .26288 Mdot
.06022 .59389 Mdot
.27784 .03722 Mdot
.55276 .17172 Mdot
.79763 .34163 Mdot
.56153 .49296 Mdot
.94994 .34705 Mdot
.13858 .58709 Mdot
.51184 .08564 Mdot
.76512 .31634 Mdot
.61751 .47287 Mdot
.90342 .38164 Mdot
.30384 .55835 Mdot
.84704 .18779 Mdot
.3679 .5235 Mdot
.91023 .22738 Mdot
.20825 .56255 Mdot
.67217 .12871 Mdot
.67772 .41543 Mdot
.80969 .41885 Mdot
.57168 .50042 Mdot
.94864 .35332 Mdot
.14597 .58629 Mdot
.53147 .09022 Mdot
.76446 .32847 Mdot
.62469 .47246 Mdot
.8968 .38608 Mdot
.32582 .55425 Mdot
.87601 .20137 Mdot
.29622 .54141 Mdot
.82722 .18307 Mdot
.41553 .51125 Mdot
.94384 .25681 Mdot
.11516 .58333 Mdot
.44394 .07118 Mdot
.7457 .27437 Mdot
.63412 .46087 Mdot
.88216 .39191 Mdot
.37129 .5452 Mdot
.92414 .22947 Mdot
.16586 .57115 Mdot
.5759 .10251 Mdot
.75322 .35592 Mdot
.65972 .46552 Mdot
.85655 .40773 Mdot
.44966 .52938 Mdot
.9705 .27791 Mdot
.03421 .5998 Mdot
.19173 .02114 Mdot
.37182 .11849 Mdot
.71753 .2298 Mdot
.66108 .44346 Mdot
.84423 .40857 Mdot
.48235 .52176 Mdot
.97569 .29811 Mdot
.02563 .60301 Mdot
.16283 .01584 Mdot
.29864 .10063 Mdot
.617 .18457 Mdot
.76392 .38133 Mdot
.65142 .47213 Mdot
.86933 .4026 Mdot
.41251 .53728 Mdot
.95447 .25494 Mdot
.07853 .5899 Mdot
.33549 .04854 Mdot
.643 .20734 Mdot
.74998 .39739 Mdot
.68592 .46352 Mdot
.82196 .42392 Mdot
.54519 .508 Mdot
.96353 .33695 Mdot
.08722 .59549 Mdot
.36561 .05391 Mdot
.67995 .22596 Mdot
.71476 .42023 Mdot
.75797 .44175 Mdot
.69233 .46845 Mdot
.81534 .42789 Mdot
.56289 .50391 Mdot
.95464 .34788 Mdot
.12307 .59 Mdot
.46995 .07606 Mdot
.75691 .29045 Mdot
.62091 .4678 Mdot
.89797 .38374 Mdot
.32121 .55498 Mdot
.87017 .19852 Mdot
.31113 .53779 Mdot
.84773 .19229 Mdot
.36829 .52393 Mdot
.91083 .22762 Mdot
.20652 .56292 Mdot
.66852 .12764 Mdot
.68182 .41317 Mdot
.80311 .42139 Mdot
.58795 .49635 Mdot
.93717 .36338 Mdot
.18889 .5792 Mdot
.63605 .11674 Mdot
.71318 .3931 Mdot
.74732 .44077 Mdot
.71191 .46187 Mdot
.7827 .43999 Mdot
.6416 .48374 Mdot
.88562 .39653 Mdot
.36359 .54734 Mdot
.91738 .22471 Mdot
.18484 .56697 Mdot
.6205 .11423 Mdot
.72671 .38349 Mdot
.72051 .44913 Mdot
.76269 .4453 Mdot
.68488 .47137 Mdot
.8272 .42328 Mdot
.53219 .51124 Mdot
.96867 .32891 Mdot
.06539 .59867 Mdot
.29724 .04041 Mdot
.58562 .1837 Mdot
.78689 .36193 Mdot
.59481 .48633 Mdot
.9277 .36761 Mdot
.22156 .57335 Mdot
.70617 .13693 Mdot
.63391 .43644 Mdot
.8705 .39178 Mdot
.40403 .538 Mdot
.94883 .2497 Mdot
.09504 .58641 Mdot
.38537 .05874 Mdot
.70111 .23817 Mdot
.69071 .43331 Mdot
.80059 .42688 Mdot
.59631 .49479 Mdot
.93076 .36854 Mdot
.2122 .57524 Mdot
.68699 .13115 Mdot
.65914 .42458 Mdot
.83737 .40737 Mdot
.49923 .51752 Mdot
.97508 .30854 Mdot
.03288 .60263 Mdot
.18839 .02032 Mdot
.3636 .11643 Mdot
.70822 .22471 Mdot
.67337 .4377 Mdot
.82618 .41616 Mdot
.53122 .51061 Mdot
.96858 .32831 Mdot
.06541 .59862 Mdot
.29728 .04043 Mdot
.58568 .18373 Mdot
.78686 .36197 Mdot
.59489 .48631 Mdot
.92764 .36766 Mdot
.2218 .57331 Mdot
.70666 .13708 Mdot
.63324 .43674 Mdot
.87131 .39136 Mdot
.40157 .5385 Mdot
.94724 .24818 Mdot
.09964 .58543 Mdot
.39889 .06158 Mdot
.71369 .24653 Mdot
.67537 .44108 Mdot
.82523 .4174 Mdot
.53414 .51002 Mdot
.96762 .33012 Mdot
.06963 .59802 Mdot
.31079 .04304 Mdot
.60709 .19208 Mdot
.77575 .3752 Mdot
.62463 .47944 Mdot
.90025 .38604 Mdot
.31552 .55638 Mdot
.86299 .195 Mdot
.32909 .53336 Mdot
.87017 .20339 Mdot
.3135 .53779 Mdot
.85112 .19376 Mdot
.36017 .52602 Mdot
.90342 .2226 Mdot
.22665 .55834 Mdot
.70953 .14008 Mdot
.63025 .43851 Mdot
.87508 .38952 Mdot
.39015 .54083 Mdot
.93924 .24112 Mdot
.12275 .58048 Mdot
.46442 .07586 Mdot
.75536 .28703 Mdot
.62221 .46684 Mdot
.89633 .38455 Mdot
.32645 .55396 Mdot
.87671 .20176 Mdot
.29444 .54184 Mdot
.82467 .18197 Mdot
.42121 .50967 Mdot
.94665 .26032 Mdot
.1075 .58506 Mdot
.42225 .06644 Mdot
.73213 .26097 Mdot
.65176 .45248 Mdot
.85941 .40281 Mdot
.43963 .53114 Mdot
.96702 .27171 Mdot
.04341 .59765 Mdot
.22274 .02683 Mdot
.44336 .13766 Mdot
.77772 .27401 Mdot
.57146 .48066 Mdot
.93916 .35318 Mdot
.17739 .58044 Mdot
.60906 .10963 Mdot
.73416 .37642 Mdot
.70429 .45373 Mdot
.79057 .43527 Mdot
.62249 .4886 Mdot
.90664 .38472 Mdot
.29559 .56034 Mdot
.83543 .18268 Mdot
.39502 .51633 Mdot
.93136 .24414 Mdot
.14988 .57561 Mdot
.53668 .09263 Mdot
.76438 .33169 Mdot
.62641 .47241 Mdot
.89518 .38714 Mdot
.33112 .55325 Mdot
.88245 .20465 Mdot
.27954 .54539 Mdot
.80229 .17277 Mdot
.46913 .49584 Mdot
.96048 .28994 Mdot
.07495 .59361 Mdot
.32582 .04632 Mdot
.62945 .20137 Mdot
.76074 .38902 Mdot
.66138 .47016 Mdot
.85683 .40875 Mdot
.44942 .52955 Mdot
.97048 .27776 Mdot
.03418 .59979 Mdot
.19161 .02112 Mdot
.37154 .11842 Mdot
.71722 .22962 Mdot
.6615 .44327 Mdot
.84363 .40883 Mdot
.484 .52139 Mdot
.97575 .29913 Mdot
.02592 .60304 Mdot
.16388 .01602 Mdot
.30142 .10129 Mdot
.62154 .18629 Mdot
.76075 .38414 Mdot
.65898 .47017 Mdot
.85968 .40727 Mdot
.44107 .53131 Mdot
.96777 .2726 Mdot
.04122 .59811 Mdot
.21538 .02548 Mdot
.42704 .13311 Mdot
.76729 .26393 Mdot
.58776 .47421 Mdot
.92655 .36325 Mdot
.22314 .57264 Mdot
.70914 .13791 Mdot
.6298 .43827 Mdot
.87541 .38924 Mdot
.38911 .54103 Mdot
.93846 .24048 Mdot
.125 .58 Mdot
.47059 .07725 Mdot
.75765 .29084 Mdot
.6197 .46825 Mdot
.89927 .38299 Mdot
.31698 .55578 Mdot
.86473 .1959 Mdot
.32478 .53444 Mdot
.86501 .20073 Mdot
.32636 .53461 Mdot
.8672 .2017 Mdot
.32087 .53596 Mdot
.86047 .19831 Mdot
.33751 .5318 Mdot
.88009 .20859 Mdot
.28818 .54393 Mdot
.81576 .17811 Mdot
.44063 .50417 Mdot
.95439 .27233 Mdot
.08725 .58984 Mdot
.36294 .05392 Mdot
.67719 .22431 Mdot
.71762 .41853 Mdot
.75254 .44351 Mdot
.70351 .4651 Mdot
.79725 .4348 Mdot
.6076 .49273 Mdot
.92129 .37552 Mdot
.24577 .56939 Mdot
.75312 .1519 Mdot
.56087 .46545 Mdot
.93688 .34664 Mdot
.1817 .57902 Mdot
.61884 .1123 Mdot
.72724 .38246 Mdot
.71911 .44946 Mdot
.76514 .44443 Mdot
.67965 .47288 Mdot
.83502 .42005 Mdot
.51127 .51607 Mdot
.97409 .31598 Mdot
.03998 .60202 Mdot
.21297 .02471 Mdot
.42144 .13162 Mdot
.76328 .26046 Mdot
.59401 .47173 Mdot
.92118 .36712 Mdot
.24205 .56932 Mdot
.74585 .14959 Mdot
.57327 .46096 Mdot
.92865 .3543 Mdot
.21207 .57394 Mdot
.68607 .13106 Mdot
.66037 .42402 Mdot
.83563 .40813 Mdot
.50397 .51645 Mdot
.97457 .31147 Mdot
.03608 .60232 Mdot
.1995 .0223 Mdot
.3903 .1233 Mdot
.7367 .24122 Mdot
.6342 .4553 Mdot
.87937 .39196 Mdot
.37925 .54348 Mdot
.9309 .23439 Mdot
.14662 .57533 Mdot
.52789 .09062 Mdot
.7654 .32625 Mdot
.62177 .47304 Mdot
.89974 .38427 Mdot
.31617 .55607 Mdot
.86375 .1954 Mdot
.32723 .53383 Mdot
.86796 .20224 Mdot
.31904 .53643 Mdot
.85819 .19718 Mdot
.34307 .53039 Mdot
.88619 .21203 Mdot
.2724 .54769 Mdot
.79126 .16835 Mdot
.49143 .48902 Mdot
.96084 .30372 Mdot
.08039 .59383 Mdot
.3433 .04968 Mdot
.65312 .21217 Mdot
.74122 .40365 Mdot
.70499 .4581 Mdot
.79162 .43571 Mdot
.62043 .48925 Mdot
.90881 .38344 Mdot
.28836 .56168 Mdot
.82466 .17822 Mdot
.41941 .50967 Mdot
.94554 .25921 Mdot
.11067 .58438 Mdot
.4313 .0684 Mdot
.73821 .26656 Mdot
.64382 .45624 Mdot
.86993 .3979 Mdot
.40857 .53765 Mdot
.95194 .25251 Mdot
.08594 .58833 Mdot
.35813 .05312 Mdot
.67167 .22134 Mdot
.72332 .41512 Mdot
.74153 .44704 Mdot
.7255 .45829 Mdot
.75885 .44838 Mdot
.69386 .46899 Mdot
.81341 .42883 Mdot
.56787 .50271 Mdot
.95169 .35097 Mdot
.13456 .58818 Mdot
.50134 .08317 Mdot
.76426 .30985 Mdot
.61604 .47234 Mdot
.90443 .38074 Mdot
.30037 .55897 Mdot
.84212 .18564 Mdot
.37954 .52046 Mdot
.91999 .23457 Mdot
.18143 .56859 Mdot
.61312 .11213 Mdot
.73205 .37893 Mdot
.70916 .45243 Mdot
.78244 .43829 Mdot
.64134 .48357 Mdot
.88581 .39637 Mdot
.36295 .54746 Mdot
.91677 .22432 Mdot
.18653 .5666 Mdot
.62436 .11528 Mdot
.72373 .38587 Mdot
.72665 .44729 Mdot
.75157 .4491 Mdot
.70806 .46449 Mdot
.79001 .4376 Mdot
.62484 .48825 Mdot
.90433 .38617 Mdot
.3033 .55891 Mdot
.84651 .18745 Mdot
.36913 .52317 Mdot
.9113 .22813 Mdot
.20533 .56322 Mdot
.666 .1269 Mdot
.68459 .41161 Mdot
.79859 .4231 Mdot
.59895 .49355 Mdot
.92826 .37017 Mdot
.22101 .5737 Mdot
.70517 .13659 Mdot
.63528 .43582 Mdot
.86884 .39262 Mdot
.40901 .53697 Mdot
.95192 .25278 Mdot
.08613 .58832 Mdot
.35872 .05323 Mdot
.67237 .2217 Mdot
.72261 .41555 Mdot
.74292 .4466 Mdot
.72278 .45915 Mdot
.7638 .4467 Mdot
.68339 .47205 Mdot
.82957 .42236 Mdot
.52593 .5127 Mdot
.97065 .32504 Mdot
.05656 .59989 Mdot
.26853 .03495 Mdot
.53562 .16596 Mdot
.80025 .33103 Mdot
.55055 .49458 Mdot
.95518 .34026 Mdot
.11754 .59033 Mdot
.45425 .07265 Mdot
.75052 .28074 Mdot
.62828 .46385 Mdot
.88926 .3883 Mdot
.34905 .54959 Mdot
.90252 .21572 Mdot
.22602 .55779 Mdot
.70793 .13969 Mdot
.63253 .43753 Mdot
.87239 .39092 Mdot
.39835 .53917 Mdot
.94509 .24619 Mdot
.10586 .5841 Mdot
.41691 .06542 Mdot
.72832 .25767 Mdot
.65669 .45013 Mdot
.85263 .40586 Mdot
.45914 .52696 Mdot
.97272 .28376 Mdot
.02919 .60118 Mdot
.17462 .01804 Mdot
.32928 .10792 Mdot
.66389 .2035 Mdot
.72435 .41031 Mdot
.73748 .44767 Mdot
.73304 .45579 Mdot
.74475 .45304 Mdot
.72258 .46028 Mdot
.76469 .44658 Mdot
.68157 .47261 Mdot
.8323 .42124 Mdot
.51862 .51439 Mdot
.97257 .32053 Mdot
.04757 .60108 Mdot
.23869 .0294 Mdot
.47717 .14752 Mdot
.79316 .29491 Mdot
.54872 .4902 Mdot
.9537 .33913 Mdot
.12202 .58942 Mdot
.46667 .07541 Mdot
.75576 .28841 Mdot
.62213 .46709 Mdot
.89653 .38449 Mdot
.32585 .55409 Mdot
.87596 .20138 Mdot
.29636 .54138 Mdot
.82743 .18316 Mdot
.41507 .51138 Mdot
.9436 .25653 Mdot
.11582 .58318 Mdot
.44578 .07158 Mdot
.74669 .27551 Mdot
.63285 .46148 Mdot
.8837 .39112 Mdot
.36649 .54616 Mdot
.91979 .2265 Mdot
.17814 .56846 Mdot
.60509 .1101 Mdot
.73752 .37397 Mdot
.69719 .45581 Mdot
.80218 .43088 Mdot
.59468 .49577 Mdot
.93238 .36753 Mdot
.20649 .57624 Mdot
.67491 .12762 Mdot
.67366 .41712 Mdot
.81581 .41634 Mdot
.55617 .5042 Mdot
.95768 .34373 Mdot
.11068 .59188 Mdot
.43496 .0684 Mdot
.74012 .26882 Mdot
.64153 .45742 Mdot
.87292 .39648 Mdot
.39957 .5395 Mdot
.94619 .24695 Mdot
.10254 .58478 Mdot
.40731 .06337 Mdot
.72082 .25173 Mdot
.66635 .44549 Mdot
.83881 .41183 Mdot
.49775 .51841 Mdot
.97547 .30762 Mdot
.03104 .60287 Mdot
.18202 .01918 Mdot
.34785 .11249 Mdot
.68896 .21498 Mdot
.69708 .4258 Mdot
.78776 .43082 Mdot
.62639 .48686 Mdot
.90222 .38713 Mdot
.31014 .5576 Mdot
.85592 .19168 Mdot
.34646 .52899 Mdot
.88952 .21413 Mdot
.26376 .54975 Mdot
.77704 .16301 Mdot
.51897 .48024 Mdot
.95595 .32074 Mdot
.10543 .59081 Mdot
.4189 .06516 Mdot
.72946 .2589 Mdot
.65535 .45083 Mdot
.85452 .40503 Mdot
.45376 .52812 Mdot
.97144 .28044 Mdot
.03211 .60038 Mdot
.1846 .01985 Mdot
.35436 .11409 Mdot
.69714 .21901 Mdot
.6873 .43085 Mdot
.80419 .42477 Mdot
.58716 .49702 Mdot
.938 .36288 Mdot
.18592 .57972 Mdot
.62927 .1149 Mdot
.71894 .38891 Mdot
.73601 .44433 Mdot
.734 .45488 Mdot
.74265 .45364 Mdot
.72668 .45898 Mdot
.75719 .44912 Mdot
.6974 .46797 Mdot
.80776 .43102 Mdot
.58204 .49922 Mdot
.94224 .35972 Mdot
.17041 .58234 Mdot
.59275 .10532 Mdot
.74417 .36634 Mdot
.68155 .45992 Mdot
.82619 .42122 Mdot
.53366 .51061 Mdot
.96803 .32982 Mdot
.06809 .59827 Mdot
.30587 .04208 Mdot
.59945 .18904 Mdot
.78008 .37048 Mdot
.61336 .48212 Mdot
.91145 .37908 Mdot
.27815 .5633 Mdot
.80865 .17191 Mdot
.4542 .49977 Mdot
.95784 .28071 Mdot
.07953 .59198 Mdot
.33968 .04915 Mdot
.64849 .20993 Mdot
.74532 .40079 Mdot
.69618 .46063 Mdot
.80599 .43026 Mdot
.58572 .49813 Mdot
.93945 .362 Mdot
.18073 .58061 Mdot
.61726 .1117 Mdot
.72832 .38149 Mdot
.7168 .45013 Mdot
.76921 .44301 Mdot
.67085 .4754 Mdot
.84769 .41461 Mdot
.47631 .5239 Mdot
.97569 .29437 Mdot
.02381 .60301 Mdot
.15628 .01472 Mdot
.28122 .09659 Mdot
.58724 .1738 Mdot
.78106 .36293 Mdot
.60765 .48272 Mdot
.91639 .37555 Mdot
.26114 .56636 Mdot
.78039 .16139 Mdot
.51122 .48231 Mdot
.95771 .31595 Mdot
.0971 .5919 Mdot
.3943 .06001 Mdot
.70928 .24369 Mdot
.68093 .43836 Mdot
.81655 .42084 Mdot
.55661 .50465 Mdot
.95772 .344 Mdot
.11066 .5919 Mdot
.43494 .06839 Mdot
.7401 .26881 Mdot
.64155 .45741 Mdot
.8729 .3965 Mdot
.39965 .53948 Mdot
.94625 .247 Mdot
.10237 .58482 Mdot
.40683 .06327 Mdot
.72043 .25143 Mdot
.66685 .44525 Mdot
.83807 .41214 Mdot
.49976 .51796 Mdot
.9753 .30887 Mdot
.03224 .60277 Mdot
.18623 .01993 Mdot
.35828 .11509 Mdot
.70192 .22143 Mdot
.68138 .43381 Mdot
.81373 .42112 Mdot
.56337 .50291 Mdot
.95393 .34818 Mdot
.12561 .58956 Mdot
.47697 .07763 Mdot
.75919 .29478 Mdot
.61863 .46921 Mdot
.90067 .38233 Mdot
.31247 .55664 Mdot
.8588 .19312 Mdot
.33949 .53077 Mdot
.88203 .20982 Mdot
.28325 .54513 Mdot
.80832 .17506 Mdot
.45649 .49957 Mdot
.95855 .28213 Mdot
.0778 .59242 Mdot
.33436 .04808 Mdot
.64136 .20665 Mdot
.75137 .39638 Mdot
.68284 .46437 Mdot
.8266 .42202 Mdot
.53304 .51087 Mdot
.96829 .32944 Mdot
.06696 .59844 Mdot
.30226 .04138 Mdot
.59373 .18681 Mdot
.78306 .36694 Mdot
.60539 .48396 Mdot
.91877 .37415 Mdot
.25303 .56783 Mdot
.76616 .15638 Mdot
.5378 .47351 Mdot
.94897 .33238 Mdot
.1347 .5865 Mdot
.50091 .08325 Mdot
.7643 .30958 Mdot
.61584 .47237 Mdot
.90461 .38061 Mdot
.29974 .55908 Mdot
.84122 .18525 Mdot
.38164 .5199 Mdot
.92164 .23587 Mdot
.17687 .56961 Mdot
.60252 .10931 Mdot
.7391 .37238 Mdot
.69362 .45679 Mdot
.80783 .42868 Mdot
.58073 .49927 Mdot
.94305 .35891 Mdot
.16735 .58284 Mdot
.58534 .10343 Mdot
.7481 .36176 Mdot
.67211 .46235 Mdot
.83975 .41539 Mdot
.49709 .51899 Mdot
.97573 .30722 Mdot
.02992 .60303 Mdot
.17813 .01849 Mdot
.33809 .11009 Mdot
.67612 .20895 Mdot
.71157 .41786 Mdot
.76188 .43978 Mdot
.68379 .47087 Mdot
.82845 .42261 Mdot
.5288 .51201 Mdot
.96977 .32682 Mdot
.06052 .59935 Mdot
.28147 .0374 Mdot
.55893 .17396 Mdot
.79623 .34544 Mdot
.56648 .4921 Mdot
.94722 .35011 Mdot
.14919 .58541 Mdot
.53962 .09221 Mdot
.76338 .33351 Mdot
.62927 .4718 Mdot
.89219 .38891 Mdot
.3408 .5514 Mdot
.89365 .21063 Mdot
.24996 .55231 Mdot
.75284 .15448 Mdot
.56266 .46528 Mdot
.93599 .34774 Mdot
.18513 .57848 Mdot
.62679 .11442 Mdot
.72105 .38738 Mdot
.73181 .44564 Mdot
.74195 .45229 Mdot
.72729 .45855 Mdot
.75595 .44949 Mdot
.69996 .4672 Mdot
.80361 .4326 Mdot
.59226 .49666 Mdot
.93447 .36604 Mdot
.19898 .57753 Mdot
.65863 .12298 Mdot
.69156 .40706 Mdot
.78664 .42741 Mdot
.62714 .48617 Mdot
.90118 .38759 Mdot
.31348 .55696 Mdot
.86039 .19374 Mdot
.33551 .53175 Mdot
.87758 .20736 Mdot
.2947 .54237 Mdot
.82534 .18214 Mdot
.41967 .51009 Mdot
.94591 .25937 Mdot
.10953 .5846 Mdot
.42805 .06769 Mdot
.7361 .26455 Mdot
.64658 .45494 Mdot
.86633 .39961 Mdot
.41931 .53542 Mdot
.95798 .25915 Mdot
.06859 .59206 Mdot
.30449 .04239 Mdot
.59756 .18819 Mdot
.78104 .36931 Mdot
.61079 .48271 Mdot
.91385 .37749 Mdot
.26995 .56479 Mdot
.79531 .16684 Mdot
.48183 .49153 Mdot
.96093 .29779 Mdot
.07719 .59389 Mdot
.33315 .04771 Mdot
.63964 .2059 Mdot
.75279 .39532 Mdot
.67965 .46525 Mdot
.83131 .42005 Mdot
.5205 .51378 Mdot
.97203 .32168 Mdot
.05005 .60075 Mdot
.24698 .03093 Mdot
.49406 .15264 Mdot
.79774 .30535 Mdot
.54367 .49303 Mdot
.95675 .33601 Mdot
.11012 .5913 Mdot
.43304 .06806 Mdot
.73896 .26763 Mdot
.64301 .4567 Mdot
.87102 .3974 Mdot
.40532 .53832 Mdot
.94993 .2505 Mdot
.09172 .58709 Mdot
.37549 .05669 Mdot
.69108 .23207 Mdot
.70238 .42711 Mdot
.78052 .4341 Mdot
.64332 .48239 Mdot
.88316 .39759 Mdot
.37119 .54582 Mdot
.92434 .22941 Mdot
.16519 .57127 Mdot
.57427 .10209 Mdot
.75391 .35492 Mdot
.65792 .46594 Mdot
.85888 .40661 Mdot
.4429 .53082 Mdot
.96835 .27373 Mdot
.03971 .59847 Mdot
.21033 .02454 Mdot
.41559 .12999 Mdot
.75881 .25685 Mdot
.60095 .46897 Mdot
.91486 .37141 Mdot
.26387 .56542 Mdot
.78486 .16308 Mdot
.50262 .48507 Mdot
.95935 .31064 Mdot
.08887 .59291 Mdot
.36947 .05492 Mdot
.68435 .22834 Mdot
.70997 .42295 Mdot
.76687 .43878 Mdot
.67347 .47395 Mdot
.84364 .41623 Mdot
.48757 .5214 Mdot
.97619 .30134 Mdot
.02542 .60332 Mdot
.1622 .01571 Mdot
.29699 .10025 Mdot
.61427 .18355 Mdot
.76575 .37964 Mdot
.64699 .47326 Mdot
.87478 .39986 Mdot
.39602 .54064 Mdot
.94397 .24475 Mdot
.1089 .5834 Mdot
.4256 .0673 Mdot
.73452 .26303 Mdot
.64861 .45396 Mdot
.86363 .40087 Mdot
.42728 .53375 Mdot
.9619 .26408 Mdot
.05749 .59449 Mdot
.26902 .03553 Mdot
.53677 .16626 Mdot
.8001 .33174 Mdot
.55121 .49449 Mdot
.95489 .34067 Mdot
.11872 .59015 Mdot
.45756 .07337 Mdot
.75203 .28279 Mdot
.62645 .46478 Mdot
.89144 .38717 Mdot
.34215 .55094 Mdot
.89505 .21146 Mdot
.24622 .55317 Mdot
.74612 .15217 Mdot
.57403 .46113 Mdot
.92832 .35477 Mdot
.21335 .57373 Mdot
.68878 .13186 Mdot
.65699 .42569 Mdot
.84042 .40604 Mdot
.49085 .51941 Mdot
.97554 .30336 Mdot
.0287 .60292 Mdot
.17375 .01774 Mdot
.32698 .10738 Mdot
.66063 .20208 Mdot
.7276 .40829 Mdot
.73104 .44968 Mdot
.74525 .45181 Mdot
.72107 .46059 Mdot
.76733 .44564 Mdot
.67588 .47424 Mdot
.84066 .41771 Mdot
.49591 .51956 Mdot
.97595 .30649 Mdot
.02877 .60317 Mdot
.17411 .01778 Mdot
.3279 .10761 Mdot
.66195 .20265 Mdot
.72629 .40911 Mdot
.73364 .44887 Mdot
.74036 .45341 Mdot
.73069 .45757 Mdot
.74969 .45159 Mdot
.71277 .46333 Mdot
.78205 .44052 Mdot
.64323 .48334 Mdot
.88371 .39754 Mdot
.36957 .54616 Mdot
.92291 .22841 Mdot
.16926 .57039 Mdot
.58407 .10461 Mdot
.74946 .36098 Mdot
.66922 .46319 Mdot
.84382 .4136 Mdot
.48582 .52151 Mdot
.97604 .30025 Mdot
.02542 .60323 Mdot
.16217 .01571 Mdot
.2969 .10023 Mdot
.61412 .18349 Mdot
.76585 .37955 Mdot
.64675 .47332 Mdot
.87507 .39971 Mdot
.39514 .54082 Mdot
.94335 .24421 Mdot
.11068 .58302 Mdot
.43068 .06841 Mdot
.73789 .26618 Mdot
.64421 .45604 Mdot
.86941 .39815 Mdot
.41012 .53733 Mdot
.95286 .25347 Mdot
.08327 .5889 Mdot
.35002 .05146 Mdot
.66184 .21632 Mdot
.73306 .40904 Mdot
.72203 .45306 Mdot
.76209 .44624 Mdot
.68651 .471 Mdot
.82477 .42429 Mdot
.5386 .50973 Mdot
.96634 .33287 Mdot
.07547 .59723 Mdot
.32925 .04664 Mdot
.63411 .20349 Mdot
.75723 .3919 Mdot
.66956 .46799 Mdot
.84573 .41381 Mdot
.48102 .52269 Mdot
.97593 .29729 Mdot
.02436 .60316 Mdot
.15833 .01505 Mdot
.2867 .09785 Mdot
.59683 .17719 Mdot
.77622 .36886 Mdot
.6206 .47973 Mdot
.90404 .38355 Mdot
.30292 .55872 Mdot
.84584 .18722 Mdot
.37072 .52276 Mdot
.91269 .22912 Mdot
.20153 .56407 Mdot
.65788 .12455 Mdot
.6932 .40659 Mdot
.78407 .42842 Mdot
.6331 .48458 Mdot
.89467 .39128 Mdot
.33464 .55294 Mdot
.88678 .20682 Mdot
.26816 .54806 Mdot
.78405 .16573 Mdot
.50562 .48457 Mdot
.95907 .31249 Mdot
.09075 .59274 Mdot
.37522 .05609 Mdot
.69053 .2319 Mdot
.70308 .42677 Mdot
.7793 .43453 Mdot
.64608 .48164 Mdot
.87983 .3993 Mdot
.3815 .54377 Mdot
.9331 .23578 Mdot
.14018 .57669 Mdot
.51118 .08664 Mdot
.76565 .31593 Mdot
.61626 .4732 Mdot
.90466 .38087 Mdot
.29974 .55911 Mdot
.84123 .18525 Mdot
.38161 .51991 Mdot
.92162 .23585 Mdot
.17694 .56959 Mdot
.60269 .10935 Mdot
.73899 .37248 Mdot
.69385 .45672 Mdot
.80746 .42882 Mdot
.58165 .49904 Mdot
.94239 .35948 Mdot
.16981 .58243 Mdot
.59131 .10495 Mdot
.74497 .36545 Mdot
.67965 .46042 Mdot
.82896 .42005 Mdot
.5263 .51233 Mdot
.9704 .32527 Mdot
.05754 .59974 Mdot
.27174 .03556 Mdot
.54153 .16795 Mdot
.7996 .33468 Mdot
.55378 .49418 Mdot
.95377 .34225 Mdot
.12331 .58946 Mdot
.47036 .07621 Mdot
.75709 .2907 Mdot
.62071 .4679 Mdot
.8982 .38362 Mdot
.32046 .55512 Mdot
.86921 .19805 Mdot
.31355 .5372 Mdot
.85089 .19378 Mdot
.36077 .52588 Mdot
.904 .22297 Mdot
.2251 .5587 Mdot
.70646 .13912 Mdot
.63452 .43662 Mdot
.86998 .39216 Mdot
.40564 .53768 Mdot
.94986 .2507 Mdot
.09208 .58704 Mdot
.37658 .05691 Mdot
.69222 .23274 Mdot
.70109 .42781 Mdot
.78281 .4333 Mdot
.63813 .4838 Mdot
.88924 .39439 Mdot
.35206 .54958 Mdot
.90595 .21759 Mdot
.21655 .55991 Mdot
.68897 .13383 Mdot
.65768 .4258 Mdot
.83967 .40647 Mdot
.49297 .51894 Mdot
.97548 .30467 Mdot
.02956 .60288 Mdot
.17677 .01827 Mdot
.33467 .10925 Mdot
.67145 .20684 Mdot
.71657 .41498 Mdot
.75251 .44287 Mdot
.70326 .46508 Mdot
.79763 .43464 Mdot
.60668 .49296 Mdot
.92212 .37495 Mdot
.24286 .5699 Mdot
.74772 .15009 Mdot
.57008 .46212 Mdot
.93088 .35233 Mdot
.20394 .57532 Mdot
.66877 .12604 Mdot
.68074 .41332 Mdot
.80466 .42072 Mdot
.58413 .4973 Mdot
.94004 .36101 Mdot
.17831 .58098 Mdot
.61156 .1102 Mdot
.7324 .37797 Mdot
.70809 .45265 Mdot
.78421 .43762 Mdot
.63727 .48467 Mdot
.89054 .39386 Mdot
.34802 .55038 Mdot
.90171 .21509 Mdot
.22814 .55729 Mdot
.71209 .141 Mdot
.62668 .44009 Mdot
.87925 .38731 Mdot
.37734 .5434 Mdot
.92908 .23321 Mdot
.1519 .57421 Mdot
.54134 .09388 Mdot
.7637 .33457 Mdot
.62916 .47199 Mdot
.89238 .38884 Mdot
.34019 .55152 Mdot
.89296 .21025 Mdot
.2518 .55188 Mdot
.75611 .15562 Mdot
.55701 .4673 Mdot
.93942 .34425 Mdot
.1722 .5806 Mdot
.59637 .10643 Mdot
.7422 .36858 Mdot
.68621 .4587 Mdot
.81922 .4241 Mdot
.55186 .5063 Mdot
.96038 .34107 Mdot
.1001 .59355 Mdot
.40422 .06187 Mdot
.71785 .24982 Mdot
.67028 .44366 Mdot
.83301 .41425 Mdot
.51347 .51483 Mdot
.97332 .31734 Mdot
.04337 .60155 Mdot
.2245 .02681 Mdot
.44703 .13875 Mdot
.77981 .27628 Mdot
.5682 .48195 Mdot
.94145 .35117 Mdot
.16888 .58185 Mdot
.58869 .10437 Mdot
.74642 .36383 Mdot
.67621 .46131 Mdot
.83394 .41792 Mdot
.51293 .51541 Mdot
.97365 .31701 Mdot
.04206 .60175 Mdot
.22007 .026 Mdot
.43732 .13601 Mdot
.77411 .27028 Mdot
.57708 .47843 Mdot
.93504 .35665 Mdot
.19257 .57789 Mdot
.64403 .11902 Mdot
.70601 .39803 Mdot
.7609 .43634 Mdot
.68403 .47026 Mdot
.82782 .42276 Mdot
.5304 .51162 Mdot
.96925 .32781 Mdot
.06282 .59903 Mdot
.28894 .03882 Mdot
.57179 .17857 Mdot
.79236 .35339 Mdot
.57885 .4897 Mdot
.9395 .35775 Mdot
.17851 .58064 Mdot
.61189 .11032 Mdot
.7322 .37817 Mdot
.70854 .45252 Mdot
.78345 .4379 Mdot
.63902 .4842 Mdot
.88852 .39494 Mdot
.35442 .54914 Mdot
.90837 .21904 Mdot
.20989 .56141 Mdot
.67523 .12972 Mdot
.67428 .41731 Mdot
.81511 .41673 Mdot
.55801 .50376 Mdot
.95671 .34487 Mdot
.11454 .59128 Mdot
.446 .07079 Mdot
.7464 .27564 Mdot
.63345 .4613 Mdot
.88302 .39149 Mdot
.36861 .54574 Mdot
.92174 .22781 Mdot
.17266 .56966 Mdot
.5922 .10671 Mdot
.74522 .366 Mdot
.67947 .46057 Mdot
.82929 .41993 Mdot
.52544 .51253 Mdot
.97065 .32474 Mdot
.05641 .59989 Mdot
.26803 .03486 Mdot
.53471 .16565 Mdot
.80033 .33047 Mdot
.5501 .49463 Mdot
.95536 .33998 Mdot
.11677 .59045 Mdot
.45207 .07217 Mdot
.74949 .2794 Mdot
.62955 .46321 Mdot
.88774 .38909 Mdot
.35384 .54865 Mdot
.9075 .21869 Mdot
.21237 .56087 Mdot
.6804 .13125 Mdot
.66819 .42051 Mdot
.8244 .41296 Mdot
.534 .50951 Mdot
.96741 .33003 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{411.938, 254.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009Y0001OB000`400?l00000o`00003oo`3ooooo
0?ooof/0oooo003o0?ooool0ooooJ`3oool00?l0ooooo`3ooom[0?ooo`00o`3ooolF0?ooo`050?no
M000000000000000001d_ol01@3oool00`2oM0000000001d_`060?ooo`050?oOW018000000000000
001d_ol0o`3ooolm0?ooo`00o`3ooolF0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool0
0`2oM0000000001d_`080?ooo`030;md001d_ol0oooo00P0oooo00<000000?ooo`3oool0o`3ooolb
0?ooo`00o`3ooolE0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool03P3oool00`2o
M000M;oo0?ooo`080?ooo`030000003oool0oooo0?l0oooo<P3oool00?l0oooo5@3oool00`3OW4P0
B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0gia80000000000000`0000000`1d_ol0
oooo0?ooo`060?ooo`D00000o`3oool`0?ooo`00o`3oool<0?ooo`0309a800000000000000<00000
00D004RL0?ooo`3oool0gia804RLg`030?ooo`030?noM000M;l0oooo00X0oooo00H0okmd0000M02o
ool0oooo0;md001d_ol90?ooo`030000003oool0oooo0?l0oooo<P3oool00?l0oooo5@3oool00`3O
W4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00/0oooo00D0gia8001d_`3oool0_g@007Boo`09
0?ooo`030000003oool0oooo0?l0oooo<P3oool00?l0oooo5@3oool00`3o_g@0B9cO0?ooo`020?oo
o`030=nLB018W=l0oooo00`0oooo00@0W4P004RLg`2oM000M;oo2@3oool00`000000oooo0?ooo`3o
0?oooc80oooo003o0?oooaH0oooo00H0W4P007Boo`3oool0omnL04P0M02oool=0?ooo`040?oOW018
04P0B4P007Boo`T0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00o`3ooolF0?ooo`050?oo_`1d
000000000000B02Lgol03`3oool00`3o_g@0000007Boo`090?ooo`030000003oool0oooo0?l0oooo
<P3oool00?l0oooo=P3oool00`000000oooo0?ooo`3o0?oooc80oooo001V0?ooo`H00000b@3oool0
0`000000oooo0?ooo`3o0?oooc80oooo001[0?ooo`H00000a03oool00`000000oooo0?ooo`3o0?oo
oc80oooo001`0?ooo`L00000_P3oool00`000000oooo0?ooo`3o0?oooc80oooo001f0?ooo`L00000
^03oool00`000000oooo0?ooo`3o0?oooc80oooo001l0?ooo`D00000]03oool00`000000oooo0?oo
o`3o0?oooc80oooo00220?ooo`D00000[P3oool00`000000oooo0?ooo`3o0?oooc80oooo00260?oo
o`L00000Z03oool00`000000oooo0?ooo`3o0?oooc80oooo002;0?ooo`P00000XP3oool00`000000
oooo0?ooo`3o0?oooc80oooo002A0?ooo`L00000W@3oool00`000000oooo0?ooo`3o0?oooc80oooo
002F0?ooo`<0000000D0oooo000000000000oooo0000002G0?ooo`030000003oool0oooo0?l0oooo
<P3oool009`0oooo1P00002C0?ooo`030000003oool0oooo0?l0oooo<P3oool00:40oooo10000000
0`3oool000000?ooo`2=0?ooo`030000003oool0oooo0?l0oooo<P3oool00:P0oooo1@0000280?oo
o`030000003oool0oooo0?l0oooo<P3oool00:h0oooo100000230?ooo`030000003oool0oooo0?l0
oooo<P3oool00;40oooo0P0000000`3oool0000000000002000007d0oooo00<000000?ooo`3oool0
o`3ooolb0?ooo`00]`3oool5000007T0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00^`3oool2
000000030?ooo`000000000000800000L`3oool300000?l0oooo<P3oool00<00oooo00<000000?oo
o`0000000`00001_0?ooo`030000003oool0oooo0?l0oooo<P3oool00<D0oooo00<000000?ooo`00
00000`3oool2000006P0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00bP3oool7000006@0oooo
00<000000?ooo`3oool0o`3ooolb0?ooo`00c`3oool7000005l0oooo00<000000?ooo`3oool0o`3o
oolb0?ooo`00e03oool7000005X0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00fP3oool60000
05D0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00gP3oool5000000030?ooo`000000oooo04l0
oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00i03oool6000004/0oooo00<000000?ooo`3oool0
o`3ooolb0?ooo`00j03oool6000004L0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00k@3oool4
00000080oooo0P0000100?ooo`030000003oool0oooo0?l0oooo<P3oool00?80oooo100000000`3o
ool000000000000l0?ooo`030000003oool0oooo0?l0oooo<P3oool00?L0oooo1P00000h0?ooo`03
0000003oool0oooo0?l0oooo<P3oool00?`0oooo1000000e0?ooo`030000003oool0oooo0?l0oooo
<P3oool00?l0oooo0@3oool500000300oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00o`3oool6
0?ooo`L00000:@3oool00`000000oooo0?ooo`3o0?oooc80oooo003o0?ooo`X0oooo00<000000?oo
o`0000000`00000V0?ooo`030000003oool0oooo0?l0oooo<P3oool00?l0oooo3@3oool30?l000H0
0000803oool00`000000oooo0?ooo`3o0?oooc80oooo003o0?ooo`d0oooo103o00020?ooo`030?l0
00000000000000D000006`3oool00`000000oooo0?ooo`3o0?oooc80oooo003o0?ooo`h0oooo0P3o
00030?ooo`@0o`0000@0oooo000000000000oooo1000000G0?ooo`030000003oool0oooo0?l0oooo
<P3oool00?l0oooo503oool20?l000L0oooo1`00000B0?ooo`030000003oool0oooo0?l0oooo<P3o
ool00?l0oooo8@3oool5000000030?ooo`000000oooo00d0oooo00<000000?ooo`3oool0o`3ooolb
0?ooo`00o`3ooolV0?ooo`030000003oool0000000@000002@3oool00`000000oooo0?ooo`3o0?oo
oc80oooo003o0?ooobX0oooo1@0000000`3oool000000?ooo`040?ooo`<00000o`3ooolb0?ooo`00
o`3oool^0?ooo`030000003oool0000000@0000000<0oooo0000003oool0o`3ooolc0?ooo`00o`3o
oolc0?ooo`L00000o`3ooola0?ooo`00o`3ooolf0?ooo`D0000000<0oooo000000000000o`3oool]
0?ooo`00o`3ooolf0?ooo`030000003oool0oooo00<0oooo1P00003o0?ooobT0oooo003o0?ooocH0
oooo00<000000?ooo`3oool01P3oool500000?l0oooo9`3oool00?l0oooo=P3oool00`000000oooo
0?ooo`0<0?ooo`@00000o`3ooolR0?ooo`00o`3ooolf0?ooo`030000003oool0oooo00h0oooo0P00
00000`3oool000000000000300000?l0oooo703oool00?l0oooo=P3oool00`000000oooo0?ooo`0C
0?ooo`050000003oool000000000003oool00P00003o0?oooaP0oooo003o0?ooocH0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0300000?l0oooo5@3oool00;40oooo100000200?oo
o`030000003oool0oooo01X0oooo2000003o0?oooa00oooo002d0?ooo`@00000O@3oool00`000000
oooo0?ooo`0O0?ooo`D0000000<0oooo0000003oool0o`3oool;0?ooo`00^@3oool5000007L0oooo
00<000000?ooo`3oool08P3oool5000000030?ooo`00000000000?l0oooo203oool00;d0oooo1@00
001c0?ooo`030000003oool0oooo02L0oooo1P00003o0?ooo`D0oooo00320?ooo`<00000L03oool0
0`000000oooo0?ooo`0[0?ooo`L00000o`3oool00<P0oooo0P00001[0?ooo`030000003oool0oooo
02l0oooo0P0000020?ooo`<00000n`3oool00<X0oooo1000001W0?ooo`030000003oool0oooo03<0
oooo0P0000000`3oool000000000000200000?L0oooo003>0?ooo`@00000H`3oool00`000000oooo
0?ooo`0f0?ooo`8000000P3oool010000000oooo00000000003c0?ooo`00dP3oool300000600oooo
00<000000?ooo`3oool0>P3oool700000?00oooo003F0?ooo`030000003oool0oooo00800000FP3o
ool00`000000oooo0?ooo`0n0?ooo`H00000k@3oool00=X0oooo00@000000?ooo`3oool00000E`3o
ool00`000000oooo0?ooo`120?ooo`@000000P3oool00`000000oooo0?ooo`3V0?ooo`00g`3oool0
10000000oooo00000000001B0?ooo`030000003oool0oooo04D0oooo10000000103oool000000000
0000003T0?ooo`00hP3oool4000004l0oooo00<000000?ooo`3oool0BP3oool600000>40oooo003W
0?ooo`@00000BP3oool3000004d0oooo1`00003M0?ooo`00j`3oool00`000000oooo000000170?oo
o`030000003oool0oooo0540oooo0`0000000`3oool000000000003J0?ooo`00l03oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo05<0oooo0P0000000`3oool000000?ooo`0200000003
0?ooo`000000oooo0=@0oooo003c0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
F`3oool2000000030?ooo`000000oooo0=40oooo003g0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0F`3oool200000080oooo00@000000?ooo`0000000000cP3oool00?X0oooo0P00
000i0?ooo`030000003oool0oooo05l0oooo1`00003;0?ooo`00o@3oool3000003D0oooo00<00000
0?ooo`3oool0H`3oool3000000030?ooo`000000oooo0<P0oooo003o0?ooo`80oooo0`00000a0?oo
o`030000003oool0oooo06D0oooo0P000000103oool000000?ooo`3oool200000<@0oooo003o0?oo
o`H0oooo0`00000]0?ooo`030000003oool0oooo06P0oooo200000310?ooo`00o`3oool90?ooo`80
0000:`3oool00`000000oooo0?ooo`1/0?ooo`<000000P3oool00`000000oooo0?ooo`2m0?ooo`00
o`3oool=0?ooo`040000003oool00000000002D0oooo00<000000?ooo`3oool0K`3oool200000080
oooo1000002j0?ooo`00o`3oool@0?ooo`@000008P3oool00`000000oooo0?ooo`1c0?ooo`H00000
^03oool00?l0oooo5@3oool3000001h0oooo00<000000?ooo`3oool0M`3oool600000;@0oooo003o
0?oooaP0oooo00@000000?ooo`00000000006P3oool00`000000oooo0?ooo`1g0?ooo`80o`001000
00020?ooo`800000/03oool00?l0oooo703oool3000001L0oooo00<000000?ooo`3oool0M`3oool4
0?l000050?ooo`00000000000000003oool01000002]0?ooo`00o`3ooolN0?ooo`040000003oool0
0000000001@0oooo00<000000?ooo`3oool0N03oool20?l000D0oooo0`0000020?ooo`<00000ZP3o
ool00?l0oooo8P3oool010000000oooo00000000000@0?ooo`030000003oool0oooo0880oooo00<0
00000?ooo`3oool00P0000000`3oool000000000002W0?ooo`00o`3ooolU0?ooo`@000003@3oool0
0`000000oooo0?ooo`260?ooo`<0000000<0oooo000000000000Y@3oool00?l0oooo:`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo08T0oooo0P0000020?ooo`800000XP3oool00?l0
oooo;@3oool3000000H0oooo00<000000?ooo`3oool0R`3oool7000009l0oooo003o0?oooaH0oooo
00D0okmd000000000000000007Boo`050?ooo`030;md0000000007Bo00<0oooo00<0oono07@00000
000010000000101d_ol0oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool0S`3oool20000
0080oooo0`00002K0?ooo`00o`3ooolF0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool0
0`2oM0000000001d_`040?ooo`030;md000007@0_ooo0080oooo00<0giad09cOo`3oool0103oool4
000009@0oooo0`0000020?ooo`800000V03oool00?l0oooo5@3oool00`3o_g@007Bo0?ooo`020?oo
o`030=nLB018W=l0oooo00/0oooo00<0okmd0000B02Lgol02`3oool2000009D0oooo0`000000103o
ool0000000000000002F0?ooo`00o`3ooolE0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d
_`3oool0303oool00`3ogi`0B00004RLg`0:0?ooo`H00000U03oool3000000040?ooo`0000000000
000009<0oooo003o0?ooo``0oooo00<0W4P00000000000000`0000001@00B9`0oooo0?ooo`3OW4P0
B9cO00<0oooo00<0okmd001d_`3oool03P3oool00`2LB000B9cO0?ooo`080?ooo`030000003oool0
oooo00@0oooo0P00002D0?ooo`<000000`3oool2000008l0oooo003o0?oooaD0oooo00<0gia804RL
g`3oool00P3oool00`3o_g@007Bo0?ooo`0?0?ooo`0309a8M02oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool3000009<0oooo100000030?ooo`030000003oool0oooo08/0oooo003o0?oooaD0
oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030=nLB01d_ol0oooo0080
oooo00<0_g@007Boo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo09<0
oooo00<000000?ooo`3oool00`00002:0?ooo`00o`3ooolF0?ooo`0609a8001d_ol0oooo0?oOW018
07@0_ooo2`3oool01`3o_g@0001d0;ooo`3oool0okmd0000B02Lgol0203oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0900oooo0`0000020?ooo`<00000Q`3oool00?l0oooo5P3oool0
1@3ookl0M0000000000004P0W=oo00d0oooo00D0okmd000000000000001809cOo`090?ooo`030000
003oool0oooo0100oooo0`00002B0?ooo`<0000000<0oooo0000000000000P0000240?ooo`00o`3o
oolf0?ooo`030000003oool0oooo0180oooo0P0000000`3oool000000?ooo`2@0?ooo`<000000P3o
ool2000008<0oooo003o0?ooocH0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`2C
0?ooo`8000000`3oool2000007l0oooo003o0?ooocH0oooo00<000000?ooo`3oool06@3oool20000
0980oooo0P0000040?ooo`800000O03oool00?l0oooo=P3oool00`000000oooo0?ooo`0L0?ooo`80
0000T@3oool3000000<0oooo00<000000?ooo`000000N@3oool00?l0oooo=P3oool00`000000oooo
0?ooo`0N0?ooo`800000403oool300000840oooo00<000000?ooo`3oool00P00001h0?ooo`00o`3o
oolf0?ooo`030000003oool0oooo0240oooo00<000000?ooo`000000403oool00`000000oooo0?oo
o`1n0?ooo`8000000P3oool3000007D0oooo003o0?ooocH0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0>0?ooo`<00000O`3oool00`000000oooo0?ooo`020?ooo`800000L`3oool0
0?l0oooo=P3oool00`000000oooo0?ooo`0V0?ooo`800000403oool2000007l0oooo0`0000020?oo
o`<00000L03oool00?l0oooo=P3oool00`000000oooo0?ooo`0Y0?ooo`<000003P3oool00`000000
oooo0?ooo`1o0?ooo`8000000`3oool00`000000oooo0000001]0?ooo`00o`3ooolf0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool03P3oool3000007h0oooo0P0000030?ooo`<00000
J`3oool00?l0oooo=P3oool00`000000oooo0?ooo`0_0?ooo`<000003P3oool3000007d0oooo0`00
00020?ooo`<00000J@3oool00?l0oooo=P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo00h0oooo0`00001l0?ooo`80000000@0oooo0000003oool0oooo0`00001V0?ooo`00o`3ooolf
0?ooo`030000003oool0oooo03@0oooo0P00000?0?ooo`@00000O@3oool010000000oooo0?ooo`3o
ool3000006@0oooo003o0?ooocH0oooo00<000000?ooo`3oool0=`3oool2000000l0oooo0P00001m
0?ooo`<000000P3oool300000680oooo003o0?ooocH0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0>0?ooo`800000O@3oool200000080oooo1000001O0?ooo`00o`3ooolf0?ooo`03
0000003oool0oooo03/0oooo0`00000@0?ooo`800000O03oool2000000<0oooo0P00001N0?ooo`00
o`3ooolf0?ooo`030000003oool0oooo03h0oooo0`00000?0?ooo`030000003oool0oooo07/0oooo
00<000000?ooo`3oool00P3oool3000005/0oooo003o0?ooocH0oooo0`0000100?ooo`030000003o
ool0oooo08`0oooo0`0000030?ooo`<00000F@3oool00?l0oooo=P3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0N03oool3000000@0oooo0P00001G
0?ooo`00o`3ooolf0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03P3oool20000
07X0oooo0P0000030?ooo`<00000E@3oool00?l0oooo=P3oool00`000000oooo0?ooo`180?ooo`<0
00003P3oool2000007`0oooo00@000000?ooo`3oool0oooo0`00001C0?ooo`00o`3ooolf0?ooo`03
0000003oool0oooo04X0oooo0`00000>0?ooo`@00000N@3oool2000000<0oooo0`00001A0?ooo`00
o`3ooolf0?ooo`030000003oool0oooo04`0oooo0`00000?0?ooo`<00000N@3oool00`000000oooo
0?ooo`030?ooo`800000C`3oool00?l0oooo=P3oool00`000000oooo0?ooo`1>0?ooo`<000003`3o
ool3000007T0oooo0P0000030?ooo`<00000C@3oool00?l0oooo=P3oool00`000000oooo0?ooo`1@
0?ooo`<000003`3oool2000007T0oooo0`0000030?ooo`<00000B`3oool00?l0oooo=P3oool00`00
0000oooo0?ooo`1C0?ooo`<000003`3oool2000007P0oooo0`0000030?ooo`<00000B@3oool00?l0
oooo=P3oool00`000000oooo0?ooo`1E0?ooo`<000003`3oool00`000000oooo0?ooo`1g0?ooo`80
0000103oool2000004P0oooo003o0?ooocH0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo07H0oooo0P0000040?ooo`800000AP3oool00?l0oooo=P3o
ool00`000000oooo0?ooo`1I0?ooo`<00000R@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo04<0oooo003o0?ooocH0oooo00<000000?ooo`3oool0F`3oool3000000l0oooo0`00001f
0?ooo`800000103oool300000480oooo003o0?ooocH0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`270?ooo`8000000P3oool20?l000030?ooo`000000oooo0400oooo003o0?ooocH0
oooo00<000000?ooo`3oool0G`3oool00`000000oooo0000000@0?ooo`800000MP3oool2000000<0
o`0000<0oooo000000000000?`3oool00?l0oooo=P3oool00`000000oooo0?ooo`1Q0?ooo`<00000
Q`3oool200000080o`000`3oool00`000000oooo0?ooo`0l0?ooo`00o`3ooolf0?ooo`030000003o
ool0oooo06<0oooo0`00000?0?ooo`030000003oool0000007@0oooo0`0000050?ooo`030000003o
ool0oooo03X0oooo003o0?ooocH0oooo00<000000?ooo`3oool0I@3oool200000140oooo0P00001d
0?ooo`8000001@3oool2000003X0oooo003o0?ooocH0oooo00<000000?ooo`3oool0J03oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo07<0oooo0P0000040?ooo`800000>@3oool00?l0
oooo=P3oool00`000000oooo0?ooo`1Y0?ooo`800000403oool2000007@0oooo0P0000040?ooo`<0
0000=`3oool00?l0oooo=P3oool00`000000oooo0?ooo`1[0?ooo`8000004@3oool00`000000oooo
0?ooo`1a0?ooo`8000001@3oool2000003H0oooo003o0?ooocH0oooo00<000000?ooo`3oool0K03o
ool3000000l0oooo0`00001c0?ooo`8000001@3oool2000003@0oooo003o0?ooocH0oooo00<00000
0?ooo`3oool0KP3oool200000140oooo0P00001b0?ooo`8000001@3oool2000003<0oooo003o0?oo
ocH0oooo0`00001`0?ooo`800000403oool00`000000oooo0?ooo`1b0?ooo`800000103oool20000
0380oooo003o0?ooocH0oooo00<000000?ooo`3oool0L@3oool200000140oooo0P00001b0?ooo`80
00001@3oool200000300oooo003o0?ooocH0oooo00<000000?ooo`3oool0L`3oool2000008@0oooo
0P0000050?ooo`800000;`3oool00?l0oooo=P3oool00`000000oooo0?ooo`1e0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0L@3oool2000000@0oooo0P00000^0?ooo`00o`3ooolf
0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1_
0?ooo`8000001@3oool00`000000o`000?ooo`0[0?ooo`00o`3ooolf0?ooo`030000003oool0oooo
07P0oooo0P00000@0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool00P3oool0103o
000000000000003o000[0?ooo`00o`3ooolf0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool0PP3oool200000080oooo0`3o0002000002X0oooo003o0?ooocH0oooo00<000000?ooo`3o
ool0N`3oool200000140oooo00<000000?ooo`3oool0KP3oool200000080oooo0`3o0002000002T0
oooo003o0?ooocH0oooo00<000000?ooo`3oool0O03oool200000880oooo0P0000020?ooo`80o`00
00<0oooo000000000000:03oool00?l0oooo=P3oool00`000000oooo0?ooo`1m0?ooo`8000004P3o
ool00`000000oooo0?ooo`1]0?ooo`8000001@3oool2000002L0oooo003o0?ooocH0oooo00<00000
0?ooo`3oool0O`3oool200000140oooo00<000000?ooo`3oool0K@3oool2000000D0oooo0P00000V
0?ooo`00o`3ooolf0?ooo`030000003oool0oooo0800oooo0P00000A0?ooo`800000KP3oool00`00
0000oooo0?ooo`040?ooo`8000009@3oool00?l0oooo=P3oool00`000000oooo0?ooo`220?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0K03oool2000000D0oooo0P00000T0?ooo`00
o`3ooolf0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`1/0?ooo`030000003oool0oooo00@0oooo0P00000S0?ooo`00o`3ooolf0?ooo`030000003o
ool0oooo08@0oooo0P00000A0?ooo`800000K@3oool00`000000oooo0?ooo`040?ooo`8000008P3o
ool00?l0oooo=P3oool00`000000oooo0?ooo`250?ooo`8000004@3oool00`000000oooo0?ooo`1/
0?ooo`030000003oool0oooo00@0oooo0P00000Q0?ooo`00o`3ooolf0?ooo`030000003oool0oooo
08L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool07`3oool00?l0oooo=P3oool00`000000oooo0?ooo`280?ooo`80
00004@3oool00`000000oooo0?ooo`1Z0?ooo`8000001P3oool00`000000oooo0?ooo`0N0?ooo`00
o`3ooolf0?ooo`030000003oool0oooo08T0oooo0P00000A0?ooo`030000003oool0oooo06X0oooo
0P0000050?ooo`8000007`3oool00?l0oooo=P3oool00`000000oooo0?ooo`2:0?ooo`800000OP3o
ool00`000000oooo0?ooo`040?ooo`8000007P3oool00?l0oooo=P3oool00`000000oooo0?ooo`2;
0?ooo`80000000<0o`000?ooo`3oool03P3oool2000006X0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0L0?ooo`00o`3ooolf0?ooo`030000003oool0oooo08/0oooo00@0o`000000
003o0000o`00O03oool00`000000oooo0?ooo`040?ooo`8000007@3oool00?l0oooo=P3oool00`00
0000oooo0?ooo`2;0?ooo`80o`000P00000A0?ooo`800000J@3oool2000000H0oooo0P00000L0?oo
o`00o`3ooolf0?ooo`<00000S03oool20?l000030000003oool0oooo0140oooo00<000000?ooo`3o
ool0I`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01X0oooo003o0?ooocH0oooo
00<000000?ooo`3oool0SP3oool2000000030?l0003oool0oooo00l0oooo0P00001`0?ooo`800000
6`3oool00?l0oooo=P3oool00`000000oooo0?ooo`2>0?ooo`80o`0000<000000?l0003oool04@3o
ool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06@3o
ool00?l0oooo=P3oool00`000000oooo0?ooo`2>0?ooo`<0o`0000<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`1V0?ooo`8000001`3oool00`000000oooo0?ooo`0H0?ooo`00E`3oool00`3o
_g@000000000000300000003001d_`3oool0oooo05l0oooo00D0okmd000000000000000007Boo`05
0?ooo`030;md0000000007Bo00D0oooo00D0_g@0000000000000000007Boo`1O0?ooo`030000003o
ool0oooo0640oooo00D0okmd000000000000000007Boo`050?ooo`030;md0000000007Bo00D0oooo
00D0_g@0000000000000000007Boo`0G0?ooo`80o`000P00000B0?ooo`030000003oool0oooo0340
oooo00<0okmd0000000000000`0000000`00M;l0oooo0?ooo`0/0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0603oool005X0oooo00<0W4Q809cOo`3oool0HP3oool01P2LB7@0_ooo
0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l0103oool01`2oM00007Bo0?ooo`3oool0
omnL04P0001d_ol0GP3oool00`000000oooo0?ooo`1Q0?ooo`0609a8M02oool0oooo0?oo_`1d07@0
_ooo103oool00`2oM0000000001d_`040?ooo`070;md0000M;l0oooo0?ooo`3ogi`0B00007Boo`0I
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0<`3oool00`2LB4P0W=oo0?ooo`0_
0?ooo`8000001P3oool2000001T0oooo001J0?ooo`0309a8B02Lgol0oooo0640oooo00<0okmd001d
_`3oool00P3oool00`3OW4P0B9cO0?ooo`0?0?ooo`030?noM000M;l0oooo05d0oooo00<000000?oo
o`3oool0H03oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo00l0oooo00<0okmd001d
_`3oool06@3oool00`000000oooo0?ooo`0@0?ooo`800000=03oool00`2LB4P0W=oo0?ooo`0`0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool05`3oool005X0oooo00<0W4Q809cOo`3o
ool0H@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00l0oooo00<0okmd001d_`3o
ool0G@3oool00`000000oooo0?ooo`1P0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3o
ool03`3oool00`3o_g@007Bo0?ooo`0I0?ooo`8000004P3oool00`000000oooo0?ooo`0b0?ooo`03
09a8B02Lgol0oooo0300oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`00
CP3oool00`2LB000000000000003000000030018W03oool0oooo00<0oooo00<0W4Q809cOo`3oool0
F03oool00`2LB000000000000003000000050018W03oool0oooo0=nLB018W=l00`3oool00`3o_g@0
07Bo0?ooo`0?0?ooo`0309a8001d_ol0oooo05d0oooo00<000000?ooo`3oool0H03oool00`3OW4P0
B9cO0?ooo`020?ooo`030?noM000M;l0oooo00l0oooo00<0W4P007Boo`3oool06P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0340oooo00<0W4Q809cOo`3oool0<03oool00`000000
oooo0?ooo`050?ooo`800000603oool005X0oooo00<0W4Q809cOo`3oool0H@3oool00`3OW4P0B9cO
0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0oono07@0000000000P0000000`18W=l0oooo
0?ooo`1M0?ooo`030000003oool0oooo0600oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo
0?ooo`0:0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool06`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0300oooo00<0W4Q809cOo`3oool0>@3oool00`000000oooo
0?ooo`0F0?ooo`00FP3oool00`2LB4P0W=oo0?ooo`1Q0?ooo`030?noM018W=l0oooo0080oooo00<0
gia804RLg`3oool02P3oool00`3ookl0M01d0;ooo`1R0?ooo`030000003oool0oooo0600oooo00<0
okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030?oo_`1d07@0_ooo0200oooo0P00
000B0?ooo`800000<@3oool00`2LB4P0W=oo0?ooo`0a0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool05P3oool005L0oooo00D0gia800000000B9`0W4Q809cOo`1S0?ooo`0609a8001d
_ol0oooo0?oOW01807@0_ooo2`3oool00`3ookl0M01d0;ooo`1R0?ooo`030000003oool0oooo0640
oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`030?oo_`1d07@0_ooo0240oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0/0?ooo`050=nLB000000004RL09a8B02Lgol0<P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01H0oooo001I0?ooo`030=nLB00004P0
W=oo06<0oooo00D0oono07@000000000001809cOo`0<0?ooo`030?oo_`1d000000000080000000<0
001d0;ooo`3oool0G@3oool00`000000oooo0?ooo`1Q0?ooo`050?oo_`1d000000000000B02Lgol0
303oool00`3ookl0M00000000002000000030000M02oool0oooo01d0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0]0?ooo`030=nLB00004P0W=oo0380oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0E0?ooo`00o`3ooolf0?ooo`030000003oool0oooo09L0oooo00<0
00000?ooo`3oool04@3oool2000006<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0E0?ooo`00o`3ooolf0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool0
0?l0oooo=P3oool00`000000oooo0?ooo`2H0?ooo`800000MP3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo01D0oooo003o0?ooocH0oooo00<000000?ooo`3oool0V03oool2000001<0
oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0
oooo003o0?ooocH0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0600oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`00o`3o
oolf0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01D0oooo003o0?ooocH0oooo00<000000?ooo`3oool0V@3oool2
000001<0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo01D0oooo003o0?ooocH0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo05l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?oo
o`00o`3ooolf0?ooo`030000003oool0oooo09X0oooo0P00000C0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`00o`3ooole0?ooo`80o`00
W03oool2000001<0oooo00<000000?ooo`3oool0:@3oool20?l00380oooo0P0000080?ooo`030000
003oool0oooo01D0oooo00090?ooool00000:`0000040?l00=/00000103o001:000000T0oooo000C
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0140oooo103o000E0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0000001@0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0A0?ooo`@0o`00503oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool2000000D0oooo00<00000
0?ooo`3oool03`3oool001<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool20?l001H0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`000000503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo0P3o000E0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool005H0oooo00<000000?ooo`3o
ool0K@3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01H0oooo001F0?ooo`030000
003oool0oooo06d0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1]0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`00o`3o
oolf0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`1K0?ooo`030000003oool0oooo00H0oooo0P00000H0?ooo`00o`3ooolf0?ooo`030000003oool0
oooo09/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool05`3oool00?l0oooo=P3oool00`000000oooo0?ooo`2K0?oo
o`030000003oool0oooo06h0oooo0P0000080?ooo`8000006@3oool00?l0oooo=P3oool00`000000
oooo0?ooo`2K0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0F@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo01P0oooo003o0?ooocH0oooo00<000000?ooo`3oool0
V`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo01P0oooo003o0?ooocH0oooo00<0
00000?ooo`3oool0V`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0I0?ooo`00o`3ooolf0?ooo`030000003oool0
oooo09/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo00L0oooo0P00000K0?ooo`00o`3ooolf0?ooo`030000003oool0oooo09X0oooo0P00000D0?oo
o`030000003oool0oooo05H0oooo0P0000090?ooo`030000003oool0oooo01X0oooo003o0?ooocH0
oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool01`3oool2000001`0oooo003o0?ooocH0oooo00<000000?ooo`3oool0
VP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05D0oooo0P0000090?ooo`030000
003oool0oooo01/0oooo003o0?ooocH0oooo00<000000?ooo`3oool0V@3oool2000006`0oooo0P00
00050?ooo`040000003oool0oooo0?ooo`8000007@3oool00?l0oooo=P3oool00`000000oooo0?oo
o`2I0?ooo`800000K03oool00`000000oooo0?ooo`030?ooo`8000000P3oool2000001h0oooo003o
0?ooocH0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool00P3oool300000080oooo0P00000O0?ooo`00o`3ooolf0?oo
o`030000003oool0oooo09P0oooo0P00000D0?ooo`800000E@3oool00`000000oooo0?ooo`030?oo
o`<000000P3oool00`000000oooo0?ooo`0N0?ooo`00o`3ooolf0?ooo`030000003oool0oooo09P0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1C0?ooo`800000103oool00`000000
oooo000000020?ooo`800000803oool00?l0oooo=P3oool00`000000oooo0?ooo`2G0?ooo`800000
5@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0P0?ooo`00o`3ooolf0?ooo`030000003oool0oooo09L0oooo0P00
000E0?ooo`030000003oool0oooo0540oooo0P0000040?ooo`050000003oool000000000003oool0
0P00000R0?ooo`00o`3ooolf0?ooo`030000003oool0oooo09H0oooo0P00000E0?ooo`030000003o
ool0oooo0540oooo0P0000040?ooo`050000003oool000000000003oool00P00000S0?ooo`00o`3o
oolf0?ooo`<00000UP3oool2000001@0oooo00<000000?ooo`3oool0D@3oool2000000<0oooo0P00
0000103oool000000000003oool2000002@0oooo003o0?ooocH0oooo00<000000?ooo`3oool0U@3o
ool2000006P0oooo0P0000030?ooo`80000000@0oooo000000000000oooo0P00000U0?ooo`00o`3o
oolf0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`1@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000002H0oooo003o
0?ooocH0oooo00<000000?ooo`3oool0U03oool2000001D0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`020?ooo`060000003oool0oooo0?ooo`000000oooo0P00000W0?ooo`00o`3o
oolf0?ooo`030000003oool0oooo09<0oooo0P00000E0?ooo`800000C`3oool2000000@0oooo00<0
00000?ooo`3oool00`3oool2000002P0oooo003o0?ooocH0oooo00<000000?ooo`3oool0T`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04d0oooo0P0000040?ooo`80000000@0oooo
000000000000oooo0P00000Y0?ooo`00o`3ooolf0?ooo`030000003oool0oooo0980oooo0P00000E
0?ooo`030000003oool0oooo04d0oooo0P0000030?ooo`8000000P3oool00`000000oooo00000002
000002X0oooo003o0?ooocH0oooo00<000000?ooo`3oool0T@3oool2000001D0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00800000:`3oool00?l0
oooo=P3oool00`000000oooo0?ooo`2@0?ooo`8000004P3oool01@000000oooo0?ooo`3oool00000
04d0oooo0P0000040?ooo`030000003oool0oooo0080000000<0oooo000000000000;@3oool00?l0
oooo=P3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3o
ool00000CP3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0?ooo`000000oooo0P00
000^0?ooo`00o`3ooolf0?ooo`030000003oool0oooo08h0oooo0P00000C0?ooo`030000003oool0
oooo04h0oooo0P0000030?ooo`8000001@3oool2000002l0oooo003o0?ooocH0oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00800000B`3oool20000
00@0oooo0P0000020?ooo`80000000<0oooo0000003oool0<03oool00?l0oooo=P3oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo0140oooo0P0000000`3oool000000?ooo`1;0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo00000000000b0?oo
o`00o`3ooolf0?ooo`030000003oool0oooo08/0oooo0P00000C0?ooo`050000003oool0oooo0?oo
o`000000BP3oool3000000<0oooo0P0000030?ooo`040000003oool00000000003<0oooo003o0?oo
ocH0oooo00<000000?ooo`3oool0RP3oool2000001<0oooo0P0000020?ooo`030000003oool0oooo
04P0oooo0P0000030?ooo`030000003oool0oooo00@0oooo0P00000e0?ooo`00o`3ooolf0?ooo`03
0000003oool0oooo08X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`170?ooo`80
0000103oool010000000oooo0?ooo`3oool2000000030?ooo`000000000003H0oooo003o0?ooocH0
oooo00<000000?ooo`3oool0R03oool300000180oooo00D000000?ooo`3oool0oooo000000190?oo
o`030000003oool0oooo00<0oooo00H000000?ooo`3oool0oooo0000003oool2000003P0oooo003o
0?ooocH0oooo00<000000?ooo`3oool0Q`3oool2000001<0oooo0P0000020?ooo`030000003oool0
oooo04H0oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000>P3oool0
0?l0oooo=P3oool00`000000oooo0?ooo`260?ooo`8000004`3oool200000080oooo00<000000?oo
o`3oool0A@3oool2000000<0oooo0P000000103oool000000?ooo`3oool4000003/0oooo003o0?oo
ocH0oooo00<000000?ooo`3oool0Q@3oool2000001<0oooo0P00001:0?ooo`8000001@3oool30000
00030?ooo`000000000000800000?03oool00?l0oooo=P3oool00`000000oooo0?ooo`240?ooo`80
00004`3oool200000080oooo00<000000?ooo`3oool0B`3oool8000003h0oooo003o0?ooocH0oooo
00<000000?ooo`3oool0P`3oool2000001<0oooo0P0000180?ooo`8000000`3oool00`000000oooo
00000005000000030?ooo`000000000003l0oooo003o0?ooocH0oooo00<000000?ooo`3oool0PP3o
ool2000001<0oooo0P0000000`3oool000000?ooo`140?ooo`800000103oool3000000050?ooo`00
000000000000003oool00P0000110?ooo`00o`3ooolf0?ooo`<00000P03oool2000001@0oooo00D0
00000?ooo`3oool0oooo000000130?ooo`<00000103oool6000000030?ooo`000000000004<0oooo
003o0?ooocH0oooo00<000000?ooo`3oool0O`3oool2000001<0oooo0P0000020?ooo`800000@@3o
ool20?l000800000103oool9000004D0oooo003o0?ooocH0oooo00<000000?ooo`3oool0OP3oool2
000001<0oooo00D000000?ooo`3oool0oooo000000120?ooo`8000000P3o00020?ooo`030000003o
ool0000000@0000000@0oooo0000000000000000AP3oool00?l0oooo=P3oool00`000000oooo0?oo
o`1l0?ooo`8000005`3oool200000480oooo0P0000030?l000030?ooo`000000000000P00000B03o
ool00?l0oooo=P3oool00`000000oooo0?ooo`1k0?ooo`800000503oool00`000000oooo0?ooo`02
00000400oooo0`0000020?ooo`<0o`000P0000001@3oool00000000000000000oooo00800000BP3o
ool00?l0oooo=P3oool00`000000oooo0?ooo`1i0?ooo`8000005@3oool00`000000oooo00000002
00000400oooo00<000000?ooo`3oool00P3oool300000080o`001P00001<0?ooo`00o`3ooolf0?oo
o`030000003oool0oooo07P0oooo0P00000G0?ooo`800000?`3oool3000000@0oooo0`0000000`3o
0000000000000004000004h0oooo003o0?ooocH0oooo00<000000?ooo`3oool0MP3oool2000001P0
oooo0P00000o0?ooo`030000003oool0oooo0080oooo100000000`3oool000000000000400000500
oooo003o0?ooocH0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0C0?ooo`040000
003oool0oooo0?ooo`800000?@3oool00`000000oooo0?ooo`040?ooo`<0000000<0oooo00000000
00001@00001A0?ooo`00o`3ooolf0?ooo`030000003oool0oooo07<0oooo0P00000D0?ooo`800000
0`3oool00`000000oooo0?ooo`0l0?ooo`060000003oool0oooo0?ooo`000000oooo0`0000001@3o
ool00000000000000000oooo00<00000D`3oool00?l0oooo=P3oool00`000000oooo0?ooo`1a0?oo
o`030000003oool0oooo01@0oooo0P0000020?ooo`800000?03oool2000000@0oooo0`0000020?oo
o`@0000000<0oooo000000000000E@3oool00?l0oooo=P3oool00`000000oooo0?ooo`1_0?ooo`80
00005P3oool00`000000oooo0?ooo`02000003`0oooo0P0000030?ooo`@000000P3oool6000005P0
oooo003o0?ooocH0oooo00<000000?ooo`3oool0KP3oool2000001@0oooo0P0000030?ooo`800000
>P3oool3000000<0oooo0`0000030?ooo`@0000000<0oooo0000003oool0F@3oool00?l0oooo=P3o
ool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo01@0oooo0P0000020?ooo`800000>P3o
ool2000000D0oooo00<000000?ooo`3oool00`3oool5000005`0oooo003o0?ooocH0oooo00<00000
0?ooo`3oool0J`3oool2000001@0oooo0`0000020?ooo`800000>@3oool2000000D0oooo00<00000
0?ooo`3oool00P3oool6000005h0oooo003o0?ooocH0oooo00<000000?ooo`3oool0J03oool30000
01D0oooo0P0000020?ooo`030000003oool0oooo03L0oooo0`0000020?ooo`030000003oool0oooo
008000000`3oool500000640oooo003o0?ooocH0oooo00<000000?ooo`3oool0I`3oool2000001D0
oooo0P0000020?ooo`800000>@3oool00`000000oooo0?ooo`020?ooo`<000000`3oool700000680
oooo003o0?ooocH0oooo00<000000?ooo`3oool0I@3oool3000001@0oooo00<000000?ooo`3oool0
0P3oool2000003H0oooo0P0000040?ooo`<00000103oool5000006H0oooo003o0?ooocH0oooo00<0
00000?ooo`3oool0I03oool2000001@0oooo0`0000020?ooo`800000=@3oool3000000D0oooo0P00
00040?ooo`030000003oool0000000800000J03oool00?l0oooo=P3oool00`000000oooo0?ooo`1R
0?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool0oooo0P00000d0?ooo`<00000103o
ool00`000000oooo000000030?ooo`030000003oool0000000@00000J@3oool00?l0oooo=P3oool0
0`000000oooo0?ooo`1P0?ooo`8000006@3oool00`000000oooo0000000d0?ooo`800000103oool0
0`000000oooo000000040?ooo`H00000K03oool00?l0oooo=P3oool00`000000oooo0?ooo`1N0?oo
o`8000005P3oool010000000oooo0?ooo`3oool2000003<0oooo00<000000?ooo`3oool0103oool3
000000@0oooo1P00001^0?ooo`00o`3ooolf0?ooo`030000003oool0oooo05/0oooo0`00000J0?oo
o`800000<P3oool2000000@0oooo0P0000000`3oool000000?ooo`030?ooo`H00000L@3oool00?l0
oooo=P3oool3000005X0oooo0P00000E0?ooo`8000000`3oool200000380oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`060?ooo`@00000L`3oool00?l0oooo=P3oool00`000000oooo
0?ooo`1H0?ooo`8000005P3oool2000000<0oooo00<000000?ooo`3oool0;P3oool3000000D0oooo
0`0000040?ooo`H00000MP3oool00?l0oooo=P3oool00`000000oooo0?ooo`1F0?ooo`8000006P3o
ool3000002l0oooo00<000000?ooo`3oool00`3oool4000000@0oooo1`00001h0?ooo`00o`3ooolf
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool05P3oool200000080oooo0`00000^
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000001@3oool7000007X0oooo003o0?oo
ocH0oooo00<000000?ooo`3oool0D@3oool3000001X0oooo0`00000]0?ooo`<000001@3oool30000
00D0oooo1P00001m0?ooo`00o`3ooolf0?ooo`030000003oool0oooo04h0oooo0`00000H0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0:`3oool2000000<0oooo1@0000040?ooo`<0
000000@0oooo0000000000000000P03oool00?l0oooo=P3oool00`000000oooo0?ooo`1:0?ooo`80
o`000`00000F0?ooo`030000003oool0000000<0oooo0P00000[0?ooo`@00000103oool3000000D0
oooo1`0000220?ooo`00o`3ooolf0?ooo`030000003oool0oooo04T0oooo00@0o`000000003o0000
00005`3oool200000080oooo0`00000Z0?ooo`@000000P3oool00`000000oooo00000002000000D0
oooo0`000000103oool000000000000000250?ooo`00o`3ooolf0?ooo`030000003oool0oooo04L0
oooo100000020?l001@0oooo0P00000_0?ooo`030000003oool0oooo00@0oooo0P0000000`3oool0
00000?ooo`050?ooo`H00000R03oool00?l0oooo=P3oool00`000000oooo0?ooo`160?ooo`800000
0P3oool20?l001@0oooo00<000000?ooo`3oool00P3oool2000002L0oooo100000050?ooo`<00000
1P3oool6000008/0oooo003o0?ooocH0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo00<0oooo0P00000W0?ooo`800000103oool2000000T0oooo1`00
002=0?ooo`00o`3ooolf0?ooo`030000003oool0oooo0440oooo0P00000H0?ooo`800000103oool2
000002H0oooo0`0000040?ooo`@000001P3oool600000940oooo003o0?ooocH0oooo00<000000?oo
o`3oool0?P3oool4000001L0oooo00<000000?ooo`3oool00`3oool2000002D0oooo0P0000040?oo
o`D000001P3oool7000009<0oooo003o0?ooocH0oooo00<000000?ooo`3oool0?03oool2000001X0
oooo00@000000?ooo`3oool0oooo0`00000S0?ooo`@000000`3oool5000000H0oooo00<000000?oo
o`0000001000002F0?ooo`00o`3ooolf0?ooo`030000003oool0oooo03T0oooo0`00000H0?ooo`80
0000103oool300000240oooo100000040?ooo`@000001`3oool00`000000oooo00000004000009T0
oooo003o0?ooocH0oooo00<000000?ooo`3oool0=P3oool4000001l0oooo0P00000P0?ooo`040000
003oool00000000000D0oooo0P0000080?ooo`L00000W03oool00?l0oooo=P3oool00`000000oooo
0?ooo`0d0?ooo`80000000<0oooo0000003oool05`3oool2000000@0oooo0`00000N0?ooo`@00000
1@3oool4000000P0oooo1P00002O0?ooo`00o`3ooolf0?ooo`030000003oool0oooo03<0oooo0P00
000O0?ooo`<000007@3oool3000000H0oooo100000070?ooo`L00000XP3oool00?l0oooo=P3oool0
0`000000oooo0?ooo`0_0?ooo`<000006P3oool2000000040?ooo`3o0000o`000?ooo`800000703o
ool4000000D0oooo100000080?ooo`L00000Y@3oool00?l0oooo5P3oool01@3o_g@0000000000000
0000M;oo00D0oooo00<0_g@000000000M;l00`3oool00`3ookl0M000000000040000000307Boo`3o
ool0oooo00H0oooo00<000000?ooo`3oool0;03oool4000001h0oooo0`3o00000`000000oooo0?oo
o`0H0?ooo`80000000<0oooo0000000000001P3oool00`000000oooo0?ooo`070?ooo`P00000Z03o
ool00?l0oooo5P3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l0
103oool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo00L0oooo00<000000?ooo`3oool0
:P3oool3000001T0oooo0P0000060?ooo`8000000P3o000G0?ooo`040000003oool00000000000H0
oooo0`0000080?ooo`80000000<0oooo0000000000000P00002/0?ooo`00o`3ooolE0?ooo`030?no
M000M;l0oooo0080oooo00<0gia804RLg`3oool02`3oool00`3o_g@0001809cOo`0;0?ooo`030000
003oool0oooo02L0oooo1000000Q0?ooo`80000000<0oooo0?l0003o00005@3oool00`000000oooo
000000060?ooo`@00000203oool700000:l0oooo003o0?oooaD0oooo00<0gia804RLg`3oool00P3o
ool00`3o_g@007Bo0?ooo`0<0?ooo`030?oOW0180000B9cO00X0oooo00<000000?ooo`3oool09@3o
ool3000001T0oooo00<000000?ooo`0000001@3oool3000001D0oooo100000070?ooo`@000002@3o
ool600000;80oooo003o0?oooaD0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0>
0?ooo`0309a80018W=l0oooo00P0oooo1@00000P0?ooo`<000006@3oool010000000oooo0?ooo`00
00050?ooo`<000004`3oool010000000oooo0000000000060?ooo`D000002P3oool500000;H0oooo
003o0?oooaD0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0?0?ooo`0309a8M02o
ool0oooo00L0oooo00<000000?ooo`3oool07`3oool4000001T0oooo0`0000060?ooo`<000004@3o
ool4000000P0oooo100000090?ooo`030000003oool0oooo00@00000^03oool00?l0oooo5@3oool0
0`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0gia807Boo`3oool00P3oool0
0`2oM000M;oo0?ooo`070?ooo`030000003oool0oooo01d0oooo0P00000K0?ooo`800000203oool2
000000h0oooo1@0000070?ooo`D000002P3oool600000;`0oooo003o0?oooaH0oooo00H0W4P007Bo
o`3oool0omnL04P0M02oool;0?ooo`070?noM00007@0_ooo0?ooo`3o_g@0001809cOo`080?ooo`03
0000003oool0oooo01T0oooo1000000J0?ooo`<00000203oool2000000/0oooo1@0000070?ooo`H0
00002`3oool600000;l0oooo003o0?oooaH0oooo00D0oono07@000000000001809cOo`0=0?ooo`05
0?noM000000000000000B02Lgol02@3oool00`000000oooo0?ooo`0G0?ooo`<000006P3oool00`00
0000oooo0?ooo`0:0?ooo`8000001P3oool7000000P0oooo1@00000;0?ooo`H00000``3oool00?l0
oooo=P3oool00`000000oooo0?ooo`0C0?ooo`@00000703oool2000000`0oooo2P0000080?ooo`<0
000000<0oooo0000003oool0303oool600000<H0oooo003o0?ooocH0oooo00<000000?ooo`3oool0
403oool3000001h0oooo00<000000?ooo`3oool0703oool4000000`0oooo1`00003:0?ooo`00o`3o
oolf0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0000000d0oooo00<000000?ooo`0000001000003=0?ooo`00o`3ooolf
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P00000K0?ooo`8000007@3oool5
000000d0oooo00<000000?ooo`0000000`00003@0?ooo`00o`3ooolf0?ooo`030000003oool0oooo
00P0oooo0`00000M0?ooo`<00000603oool5000000030?ooo`000000oooo00`0oooo1P00003D0?oo
o`00o`3ooolf0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`00000000007`3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0000000l0oooo1P00003H0?ooo`00o`3ooolf0?ooo`06
0000003oool0oooo0?ooo`000000oooo0P00000N0?ooo`<000005`3oool400000100oooo1000003L
0?ooo`00o`3ooolf0?ooo`D000007P3oool3000001P0oooo0P00000>0?ooo`L00000g`3oool00?l0
oooo<`3oool5000001l0oooo0`00000C0?ooo`80000000<0oooo0000000000003`3oool600000><0
oooo003o0?oooc00oooo0P0000001@3oool000000?ooo`3oool0000001h0oooo0P00000B0?ooo`80
00004P3oool700000>H0oooo003o0?ooobd0oooo100000050?ooo`030000003oool0oooo01T0oooo
0`00000?0?ooo`040000003oool0000000000180oooo1P00003Z0?ooo`00o`3ooolZ0?ooo`@00000
203oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`000000
00004`3oool600000>l0oooo003o0?ooobP0oooo00<000000?ooo`0000002`3oool00`000000oooo
0?ooo`0F0?ooo`8000001`3oool600000180oooo00<000000?ooo`3oool01@00003b0?ooo`00o`3o
oolT0?ooo`80000000<0oooo0000003oool03@3oool00`000000oooo0?ooo`0F0?ooo`L000006@3o
ool500000?H0oooo003o0?ooob<0oooo0P00000A0?ooo`030000003oool0oooo0340oooo1@00003k
0?ooo`00o`3ooolM0?ooo`8000005`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool00000
00@00000oP3oool00?l0oooo6@3oool4000001T0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0000000400000?l0oooo0`3oool00?l0oooo5P3oool2000000030?ooo`000000oooo01/0oooo
00<000000?ooo`3oool09@3oool600000?l0oooo1`3oool00?l0oooo503oool00`000000oooo0000
000O0?ooo`<000008@3oool600000?l0oooo2`3oool00?l0oooo3`3oool2000000030?ooo`000000
oooo0280oooo00<000000?ooo`3oool0703oool00`000000oooo0000000400000?l0oooo3`3oool0
0?l0oooo303oool00`000000oooo0000000W0?ooo`030000003oool0oooo01X0oooo1@00003o0?oo
oa<0oooo003o0?ooo`T0oooo0`00000Z0?ooo`030000003oool0oooo01@0oooo1`00003o0?oooaL0
oooo003o0?ooo`@0oooo0`0000000`3oool000000?ooo`0/0?ooo`030000003oool0oooo0100oooo
1`00003o0?oooa/0oooo003o0?ooo`030000003oool0000000800000<@3oool00`000000oooo0?oo
o`0<0?ooo`H00000o`3ooolP0?ooo`00o@3oool3000003D0oooo00<000000?ooo`3oool01P3oool2
000000030?ooo`000000000000<00000o`3ooolT0?ooo`00n03oool5000003P0oooo00<000000?oo
o`3oool0103oool500000?l0oooo:@3oool00?@0oooo0P0000000`3oool000000000000l0?ooo`05
0000003oool000000000003oool01000003o0?ooob`0oooo003`0?ooo`D00000?P3oool600000?l0
oooo<@3oool00>`0oooo1P00000l0?ooo`D000000P3oool00`000000oooo0?ooo`3o0?oooc80oooo
003Y0?ooo`@00000>`3oool7000000H0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00i@3oool5
000003/0oooo1@00000;0?ooo`030000003oool0oooo0?l0oooo<P3oool00>40oooo1@00000k0?oo
o`H000003P3oool00`000000oooo0?ooo`3o0?oooc80oooo003M0?ooo`H00000>@3oool500000003
0?ooo`000000oooo0140oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00f@3oool6000003P0oooo
1P00000H0?ooo`030000003oool0oooo0?l0oooo<P3oool00=D0oooo1P00000g0?ooo`P000006`3o
ool00`000000oooo0?ooo`3o0?oooc80oooo003B0?ooo`D00000=`3oool700000200oooo00<00000
0?ooo`3oool0o`3ooolb0?ooo`00c@3oool2000000030?ooo`000000000003H0oooo2000000U0?oo
o`030000003oool0oooo0?l0oooo<P3oool00<X0oooo1000000e0?ooo`P00000:P3oool00`000000
oooo0?ooo`3o0?oooc80oooo00350?ooo`D00000=03oool8000002l0oooo00<000000?ooo`3oool0
o`3ooolb0?ooo`00`@3oool5000002h0oooo0P3o00030?ooo`030000003oool0000000D00000=03o
ool00`000000oooo0?ooo`3o0?oooc80oooo002o0?ooo`8000006P3oool20?l001H0oooo0`3o0007
000003P0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00^@3oool6000001/0oooo103o000A0?oo
o`D0000000@0o`000000000000000000?@3oool300000?l0oooo<P3oool00;D0oooo1@00000P0?oo
o`@0o`003@3oool8000000<0o`00?`3oool00`000000oooo0?ooo`3o0?oooc80oooo002`0?ooo`03
0000003oool0000000<000009@3oool20?l000X0oooo1`0000050?ooo`80o`00@03oool00`000000
oooo0?ooo`3o0?oooc80oooo002/0?ooo`D00000<@3oool7000004`0oooo00<000000?ooo`3oool0
o`3ooolb0?ooo`00Z@3oool5000002h0oooo2000001A0?ooo`030000003oool0oooo0?l0oooo<P3o
ool00:@0oooo1P00000]0?ooo`L00000E`3oool00`000000oooo0?ooo`3o0?oooc80oooo002P0?oo
o`H00000:`3oool00`000000oooo00000004000000030?ooo`000000oooo05X0oooo00<000000?oo
o`3oool0o`3ooolb0?ooo`00V`3oool6000002/0oooo2000001Q0?ooo`030000003oool0oooo0?l0
oooo<P3oool009H0oooo1`00000Z0?ooo`P00000IP3oool00`000000oooo0?ooo`3o0?oooc80oooo
002?0?ooo`80o`0000<0oooo0000000000000P0000000`3oool000000?ooo`0X0?ooo`P00000K03o
ool00`000000oooo0?ooo`3o0?oooc80oooo002>0?ooo`030?l00000000000000080000000<0oooo
0000003oool09P3oool800000740oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00RP3oool60000
0080o`00903oool2000000030?ooo`000000000000@00000MP3oool00`000000oooo0?ooo`3o0?oo
oc80oooo00260?ooo`030000003oool0000000<000000`3oool20?l00200oooo00<000000?ooo`00
00001P00001k0?ooo`030000003oool0oooo0?l0oooo<P3oool00880oooo1P00000R0?ooo`050000
003oool0oooo0000003oool0100000220?ooo`030000003oool0oooo0?l0oooo<P3oool007d0oooo
0`0000000`3oool000000?ooo`0R0?ooo`@0000000H0oooo00000000000000000?ooo`0000260?oo
o`030000003oool0oooo0?l0oooo<P3oool007L0oooo1P00000S0?ooo`050000003oool0oooo0000
003oool00P0000000`3oool000000000002;0?ooo`030000003oool0oooo0?l0oooo<P3oool007<0
oooo1`00000P0?ooo`030000003oool0000000D0000000<0oooo0000003oool0T03oool00`000000
oooo0?ooo`3o0?oooc80oooo001^0?ooo`P000007P3oool3000000030?ooo`000000000000<00000
00<0oooo0000003oool0U@3oool00`000000oooo0?ooo`3o0?oooc80oooo001Z0?ooo`D0000000<0
oooo0000003oool0703oool;000009`0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00IP3oool6
000001d0oooo00<000000?ooo`3oool01@0000000`3oool000000?ooo`2Q0?ooo`030000003oool0
oooo0?l0oooo<P3oool00640oooo1`00000K0?ooo`80000000<0oooo0000003oool01P00002W0?oo
o`030000003oool0oooo0?l0oooo<P3oool005`0oooo1@0000000`3oool000000000000J0?ooo`03
0000003oool0000000@00000/03oool00`000000oooo0?ooo`3o0?oooc80oooo001G0?ooo`D00000
00<0oooo0000000000006@3oool900000;@0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00C@3o
ool20?l000<0oooo1P0000000`3oool000000000000F0?ooo`<0000000@0oooo000000000000oooo
0`00002j0?ooo`<00000o`3ooolb0?ooo`00B`3oool40?l000D000005`3oool01@000000oooo0000
00000000oooo00H00000_`3oool00`000000oooo0?ooo`3o0?oooc80oooo00190?ooo`H0000000<0
o`000000003oool04`3oool9000000030?ooo`000000oooo0<@0oooo00<000000?ooo`3oool0o`3o
oolb0?ooo`00A03oool900000080o`003P3oool2000000030?ooo`000000oooo00L00000c03oool0
0`000000oooo0?ooo`3o0?oooc80oooo000o0?ooo`H0000000<0oooo0000000000000`3oool20?l0
00/0oooo1`000000103oool0000000000000003B0?ooo`030000003oool0oooo0?l0oooo<P3oool0
03`0oooo2000000<0?ooo`<000000P3oool7000000030?ooo`000000oooo0=H0oooo00<000000?oo
o`3oool0o`3ooolb0?ooo`00=P3oool4000000030?ooo`000000oooo00@000002P3oool200000080
oooo2000003N0?ooo`030000003oool0oooo0?l0oooo<P3oool00380oooo1@0000000`3oool00000
00000003000000H0oooo0P0000000`3oool000000?ooo`0900000>@0oooo00<000000?ooo`3oool0
o`3ooolb0?ooo`00;@3oool6000000<0oooo300000030?ooo`@00000k03oool00`000000oooo0?oo
o`3o0?oooc80oooo000Y0?ooo`D00000203oool4000000<0oooo00@000000?ooo`000000oooo0P00
00000`3oool000000?ooo`3_0?ooo`030000003oool0oooo0?l0oooo<P3oool002@0oooo1@00000>
0?ooo`L00000m`3oool00`000000oooo0?ooo`3o0?oooc80oooo000P0?ooo`D000002P3oool80000
0?h0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00703oool5000000P0oooo1`00003o0?ooo`H0
oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00603oool4000000@0oooo2000003o0?ooo`h0oooo
00<000000?ooo`3oool0o`3ooolb0?ooo`005`3oool900000?l0oooo5P3oool00`000000oooo0?oo
o`3o0?oooc80oooo003o0?ooocH0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00o`3ooolf0?oo
o`030000003oool0oooo0?l0oooo<P3oool00?l0oooo=P3oool00`000000oooo0?ooo`3o0?oooc80
oooo003o0?ooocH0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00o`3ooolF0?ooo`050?noM000
000000000000001d_ol01@3oool00`2oM0000000001d_`060?ooo`050?oOW018000000000000001d
_ol0203oool00`000000oooo0?ooo`3o0?oooc80oooo003o0?oooaH0oooo00H0W4Qd0;ooo`3oool0
oono07@0M02oool40?ooo`030;md0000000007Bo00P0oooo00<0_g@007Boo`3oool0203oool00`00
0000oooo0?ooo`3o0?oooc80oooo003o0?oooaD0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0
B9cO0?ooo`0>0?ooo`030;md001d_ol0oooo00P0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00
o`3ooolE0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool00`3OW4P00000
000000030000000307Boo`3oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00o`3o
oolE0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool01P3o_g@0001d0;oo
o`3oool0_g@007Boo`T0oooo1@00003o0?oooc00oooo003o0?oooaD0oooo00<0gia804RLg`3oool0
0P3oool00`3o_g@007Bo0?ooo`0;0?ooo`050=nLB000M;l0oooo0;md001d_ol0o`3oooln0?ooo`00
o`3ooolE0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool0303oool0102LB000B9cO
0;md001d_ooo0?oooch0oooo003o0?oooaH0oooo00H0W4P007Boo`3oool0omnL04P0M02oool=0?oo
o`040?oOW01804P0B4P007Boool0oooo?P3oool00?l0oooo5P3oool01@3ookl0M0000000000004P0
W=oo00l0oooo00<0okmd0000001d_ol0o`3oooln0?ooo`00o`3ooooo0?ooof/0oooo003o0?ooool0
ooooJ`3oool00001\
\>"],
  ImageRangeCache->{{{0, 616.875}, {380.938, 0}} -> {-1.38931, -0.414694, \
0.00672812, 0.0032659}}]
}, Closed]],

Cell[TextData[
"Upon magnification lines which appear to be thin are seen to consist of \
closely spaced lines themselves.  Of course, the larger the number of \
iterations the more clearly this structure is seen \[LongDash] some regions \
fill in relatively slowly."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[data, 
        PlotRange \[Rule] {{0.72, 0.73}, {0.17, 0.176}}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-72 100 -17.511 103.006 [
[.2 -0.0125 -15 -9 ]
[.2 -0.0125 15 0 ]
[.4 -0.0125 -15 -9 ]
[.4 -0.0125 15 0 ]
[.6 -0.0125 -15 -9 ]
[.6 -0.0125 15 0 ]
[.8 -0.0125 -15 -9 ]
[.8 -0.0125 15 0 ]
[1 -0.0125 -12 -9 ]
[1 -0.0125 12 0 ]
[-0.0125 .10301 -30 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -30 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -30 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -30 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -30 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -30 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.722)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.724)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.726)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.728)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(0.73)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10301 m
.00625 .10301 L
s
[(0.171)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(0.172)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.173)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.174)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.175)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.176)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.51273 .16043 Mdot
.8048 .34191 Mdot
.57444 .39704 Mdot
.86256 .09815 Mdot
.51601 .42546 Mdot
.43689 .4455 Mdot
.81684 .19404 Mdot
.35572 .28959 Mdot
.04822 .24245 Mdot
.18299 .44987 Mdot
.47402 .3993 Mdot
.12188 .4757 Mdot
.40848 .26606 Mdot
.53323 .15664 Mdot
.88329 .36773 Mdot
.51225 .42611 Mdot
.04343 .3302 Mdot
.48719 .2522 Mdot
.51831 .26104 Mdot
.79574 .37875 Mdot
.39423 .18128 Mdot
.04883 .51198 Mdot
.96757 .35295 Mdot
.90411 .17862 Mdot
.382 .42829 Mdot
.14513 .4899 Mdot
.65956 .22182 Mdot
.23293 .20788 Mdot
.197 .21617 Mdot
.91018 .32349 Mdot
.2425 .20828 Mdot
.01153 .24687 Mdot
.18633 .44961 Mdot
.62439 .38831 Mdot
.07922 .23698 Mdot
.32444 .1918 Mdot
.4289 .40744 Mdot
.06324 .23774 Mdot
.8506 .20244 Mdot
.94464 .33244 Mdot
.05114 .47278 Mdot
.48796 .43575 Mdot
.19764 .30314 Mdot
.73172 .35436 Mdot
.27646 .20005 Mdot
.93356 .1734 Mdot
.92442 .321 Mdot
.42557 .27736 Mdot
.84023 .10212 Mdot
.83815 .3757 Mdot
.64467 .40935 Mdot
.52783 .42969 Mdot
.7864 .36005 Mdot
.86625 .09749 Mdot
.20263 .30226 Mdot
.98841 .34305 Mdot
.74406 .11714 Mdot
.26483 .47453 Mdot
.94523 .35691 Mdot
.42109 .17469 Mdot
.1811 .48906 Mdot
.546 .15231 Mdot
.4209 .26388 Mdot
.42203 .1765 Mdot
.64292 .22475 Mdot
.47066 .39988 Mdot
.7482 .11863 Mdot
.67862 .23273 Mdot
.00317 .35148 Mdot
.4801 .43809 Mdot
.10132 .47925 Mdot
.36792 .43296 Mdot
.62516 .22788 Mdot
.52548 .4262 Mdot
.64242 .23912 Mdot
.17437 .3214 Mdot
.73646 .387 Mdot
.31531 .28245 Mdot
.07427 .50219 Mdot
.3341 .45949 Mdot
.65705 .13259 Mdot
.96281 .07821 Mdot
.07721 .33856 Mdot
.54509 .15271 Mdot
.68729 .3624 Mdot
.28219 .47247 Mdot
.23746 .20917 Mdot
.47925 .43425 Mdot
.4011 .4454 Mdot
.20079 .21551 Mdot
.59346 .14401 Mdot
.37817 .45484 Mdot
.49603 .25065 Mdot
.83955 .19003 Mdot
.33758 .27853 Mdot
.82839 .3505 Mdot
.1857 .46463 Mdot
.02525 .49244 Mdot
.77584 .20129 Mdot
.93619 .35843 Mdot
.75932 .11455 Mdot
.9823 .16478 Mdot
.58807 .23442 Mdot
.402 .44529 Mdot
.41184 .27967 Mdot
.29829 .44507 Mdot
.77463 .34685 Mdot
.9002 .17931 Mdot
.85291 .33348 Mdot
.28052 .43325 Mdot
.61545 .14206 Mdot
.74483 .391 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00I@3oool01@3o_g@000000000
00000000M;oo00D0oooo00<0_g@000000000M;l01P3oool00`3ogi`0B4RL0?ooo`030?ooo`030?oo
_`1d0000000000@0000000@0M;oo0?ooo`3ookl0M0001@0000000`1d_ol0oooo0?ooo`0M0?ooo`05
0?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`060?ooo`030?oOW018B9`0oooo
00<0oooo00<0oono07@000000000100000000`1d_ol0oooo0?ooo`020?ooo`050?oOW01800000000
0000001d_ol07`3oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l01P3o
ool00`3ogi`0B4RL0?ooo`030?ooo`030?oo_`1d0000000000@0000000<0M;oo0?ooo`3oool00P3o
ool01@2oM00000000000000007@0_ooo01h0oooo00D0okmd000000000000000007Boo`050?ooo`03
0;md0000000007Bo00H0oooo00<0omnL04Q8W03oool00`3oool00`3ookl0M0000000000400000005
07Boo`3oool0oooo0?ooo`2oM0000`0000000`00M;l0oooo0?ooo`0S0?ooo`050?noM00000000000
0000001d_ol01@3oool00`2oM0000000001d_`060?ooo`030?oOW018B9`0oooo00D0oooo00D0_g@0
000000000000000004RLg`030?ooo`00I@3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo
00<0_g@000000000M;l01`3oool00`2LB4P0W=oo0?ooo`030?ooo`030;md000007@0_ooo0080oooo
00L0giad09cOo`3oool0oooo0;md000007@0_ooo0080oooo00<0giad09cOo`3oool07P3oool01P2L
B7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l01`3oool00`2LB4P0W=oo0?oo
o`030?ooo`030;md000007@0_ooo0080oooo00<0giad09cOo`3oool01@3oool00`2oM000M;oo0?oo
o`0O0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`070?ooo`03
09a8B02Lgol0oooo00<0oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?ooo`020?ooo`06
0=nLB000M;l0oooo0?ooo`3o_g@007Bo7P3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo
00<0_g@000000000M;l01`3oool00`2LB4P0W=oo0?ooo`030?ooo`030;md000007@0_ooo0080oooo
00H0giad09cOo`3oool0oooo0?noM000M;l30?ooo`030;mdB02Lgol0oooo02<0oooo00H0W4Qd0;oo
o`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00L0oooo00<0W4Q809cOo`3oool00`3o
ool01`2oM00007Bo0?ooo`3oool0oono07@00018W=l00P3oool006@0oooo00<0okmd001d_`3oool0
0P3oool00`3OW4P0B9cO0?ooo`0=0?ooo`030=nLB018W=l0oooo00@0oooo00<0okmd0000B02Lgol0
1P3oool00`3o_g@0001809cOo`0Q0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool0
3@3oool00`3OW4P0B9cO0?ooo`040?ooo`030?noM00004P0W=oo00T0oooo00<0_g@007Boo`3oool0
7P3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo00d0oooo00<0gia804RLg`3oool0
103oool00`3o_g@0001809cOo`050?ooo`030?oo_`1d0000M;oo0080oooo00<0oono07A8W03oool0
703oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo00d0oooo00<0gia804RLg`3oool0
103oool00`3o_g@0001809cOo`050?ooo`030=nLB018W=l0oooo0080oooo00<0_g@007Boo`3oool0
8P3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo00d0oooo00<0gia804RLg`3oool0
203oool00`3o_g@007Bo0?ooo`010?ooo`00I03oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000
M;l0oooo00d0oooo00<0omnL04Q8W03oool01@3oool00`3ogi`0B00004RLg`060?ooo`030?oOW018
0000B9cO0200oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0=0?ooo`030?oOW018
B9`0oooo00D0oooo00<0omnL04P00018W=l0103oool00`3OW4P00000000000030000000307Boo`3o
ool0oooo01`0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0=0?ooo`030?oOW018
B9`0oooo00D0oooo00<0omnL04P00018W=l0103oool01`3o_g@004Q807@0M02oool0oooo0=nLB000
M;l07@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0omnL04Q8W03o
ool01@3oool00`3ogi`0B00004RLg`040?ooo`030?noM000B9`0oooo0080oooo00<0W4Q809cOo`3o
ool08P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0omnL04Q8W03o
ool01`3oool00`3ogi`0B01809cOo`020?ooo`00I03oool00`3OW4P0B9cO0?ooo`020?ooo`030?no
M000M;l0oooo00h0oooo00<0W4Q809cOo`3oool01P3oool00`2LB000B9cO0?ooo`060?ooo`0309a8
0018W=l0oooo01h0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0>0?ooo`0309a8
B02Lgol0oooo00H0oooo00<0W4P004RLg`3oool00P3oool01P3o_g@0001d0;ooo`3oool0_g@007Bo
oal0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0>0?ooo`0309a8B02Lgol0oooo
00H0oooo00<0W4P004RLg`3oool00P3oool00`3ogi`0B4RL0?noM002000000030018W03oool0oooo
01`0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0>0?ooo`0309a8B02Lgol0oooo
00H0oooo00<0W4P004RLg`3oool00`3oool01@3OW4P00000000000000000B9cO02@0oooo00<0gia8
04RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0>0?ooo`0309a8B02Lgol0oooo00@0oooo00@0gia8
0000000004P0W=oo0`3oool006@0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0>
0?ooo`030=nLB018W=l0oooo00L0oooo00<0W4Qd0;ooo`3oool01P3oool00`2LB7@0_ooo0?ooo`0M
0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03P3oool00`3OW4P0B9cO0?ooo`07
0?ooo`0309a8M02oool0oooo0080oooo00D0gia8001d_`3oool0_g@007Boo`0O0?ooo`030=nLB018
W=l0oooo0080oooo00<0okmd001d_`3oool03P3oool00`3OW4P0B9cO0?ooo`070?ooo`0709a8M02o
ool0oooo0?ooo`3ookl0M01d0;ooo`0Q0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3o
ool03P3oool00`3OW4P0B9cO0?ooo`070?ooo`0609a8M02oool0oooo0?ooo`3ookl0M4RL0`3oool0
0`2LB7@0_ooo0?ooo`0R0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03P3oool0
0`3OW4P0B9cO0?ooo`060?ooo`030?oOW01804P0W=oo0080oooo001T0?ooo`030?noM018W=l0oooo
0080oooo00<0gia804RLg`3oool03P3oool00`3ogi`0B4RL0?ooo`020?ooo`030=nLB01d_ol0oooo
0080oooo00H0_g@007Boo`3oool0oooo0=nLB01d_ol30?ooo`030;md001d_ol0oooo01d0oooo00<0
okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0>0?ooo`030?oOW018B9`0oooo0080oooo00<0
gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`030?ooo`0409a80018W=l0_g@007Booal0oooo
00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0>0?ooo`030?oOW018B9`0oooo0080oooo
00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`020?ooo`030;md0018W=l0oooo0200oooo
00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0>0?ooo`030?oOW018B9`0oooo0080oooo
00<0gia807Boo`3oool00P3oool01P2oM000M;oo0?ooo`3oool0okmd04RLg`<0oooo00<0_g@007Bo
o`3oool08P3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00h0oooo00<0omnL04Q8
W03oool01`3oool00`2oM000M;oo0?ooo`010?ooo`00I@3oool01P2LB000M;oo0?ooo`3ogi`0B01d
0;ooo`/0oooo00<0_gA809cOo`3oool00P3oool02`2oM4P0W=oo0?ooo`3oool0okmd0000M02oool0
oooo0?noM00004P0W=oo0080oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo01l0oooo00H0
W4P007Boo`3oool0omnL04P0M02oool;0?ooo`030;mdB02Lgol0oooo0080oooo00/0_gA809cOo`3o
ool0oooo0?noM00007@0_ooo0?ooo`3o_g@0001809cOo`040?ooo`040?oOW01804P0B4P007Boob00
oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`030;mdB02Lgol0oooo0080oooo00/0_gA8
09cOo`3oool0oooo0?noM00007@0_ooo0?ooo`3o_g@0001809cOo`030?ooo`030?oo_`1d000007Bo
0240oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`030;mdB02Lgol0oooo0080oooo00/0
_gA809cOo`3oool0oooo0?noM00007@0_ooo0?ooo`3o_g@0001809cOo`020?ooo`070?oOW01807@0
_ooo0?ooo`3ogi`0B01d0;ooo`0T0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2`3oool00`2o
M4P0W=oo0?ooo`020?ooo`0;0;mdB02Lgol0oooo0?ooo`3o_g@0001809cOo`3oool0omnL04P0B02L
gol00P3oool006D0oooo00D0oono07@000000000001809cOo`0<0?ooo`030;md00000000000000<0
000000D0M;oo0?ooo`3oool0oooo0?noM002000000030000B02Lgol0oooo00<0oooo00D0okmd0000
00000000001809cOo`0P0?ooo`050?oo_`1d000000000000B02Lgol0303oool00`2oM00000000000
00030000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`0004P0W=oo0?ooo`050?ooo`030?no
M0000000M;oo0200oooo00D0oono07@000000000001809cOo`0<0?ooo`030;md00000000000000<0
000000D0M;oo0?ooo`3oool0oooo0?noM002000000030000B02Lgol0oooo00D0oooo00@0_g@00000
0000000004RL7P3oool01@3ookl0M0000000000004P0W=oo00`0oooo00<0_g@00000000000000`00
00001@1d_ol0oooo0?ooo`3oool0okmd0080000000<0001809cOo`3oool00`3oool01@3o_g@00000
0000000004P0W=oo02D0oooo00D0oono07@000000000001809cOo`0<0?ooo`030;md000000000000
00<0000000H0M;oo0?ooo`3oool0oooo0?oOW01800020000000307Boo`3oool0oooo0040oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo000a0?ooool00000KP00000B0?ooo`00<@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403o
ool00340oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo0100oooo000a0?ooo`030000003oool0oooo0?l0ooooO@3oool00340oooo00<000000?ooo`3o
ool0o`3ooomm0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo000a0?ooo`030000003o
ool0oooo0?l0ooooO@3oool00340oooo0P00003o0?ooogh0oooo000a0?ooo`030000003oool0oooo
0?l0ooooO@3oool00340oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`000000oooo
0?ooo`3o0?ooogd0oooo000a0?ooo`030000003oool0oooo0?l0ooooO@3oool00340oooo00<00000
0?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo000a0?ooo`03
0000003oool0oooo0?l0ooooO@3oool00340oooo0P00003o0?ooogh0oooo000a0?ooo`030000003o
ool0oooo0?l0ooooO@3oool00340oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`00
0000oooo0?ooo`3o0?ooogd0oooo000a0?ooo`030000003oool0oooo0?l0ooooO@3oool00340oooo
00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo000a
0?ooo`800000o`3ooomn0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo000a0?ooo`03
0000003oool0oooo0?l0ooooO@3oool00340oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3o
ool00`000000oooo0?ooo`3o0?ooogd0oooo000a0?ooo`030000003oool0oooo0?l0ooooO@3oool0
0340oooo00<000000?ooo`3oool0o`3ooomK0?ooo`030000003oool0oooo01l0oooo000a0?ooo`03
0000003oool0oooo0?l0ooooF`3oool00`000000oooo0?ooo`0O0?ooo`00<@3oool200000?l0oooo
OP3oool00340oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`000000oooo0?ooo`3o
0?ooogd0oooo000a0?ooo`030000003oool0oooo0?l0ooooO@3oool00080oooo00D0okmd00000000
0000000007Boo`050?ooo`030;md0000000007Bo00@0oooo00<0okmd0000000000000`0000000`00
M;l0oooo0?ooo`020?ooo`030?oOW018B9`0oooo00@0oooo00<0okmd0000000000000`0000000`00
M;l0oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooO@3oool00080oooo00H0W4Qd0;ooo`3o
ool0oono07@0M02oool40?ooo`030;md0000000007Bo00L0oooo00<0W4Q809cOo`3oool01P3oool0
0`2LB4P0W=oo0?ooo`060?ooo`0309a8B02Lgol0oooo00H0oooo00<000000?ooo`3oool0o`3ooolh
0?ooo`030000003oool0oooo0480oooo00000`3oool0okmd001d_`030?ooo`030=nLB018W=l0oooo
00d0oooo00<0W4Q809cOo`3oool01P3oool00`3OW4P0B9cO0?ooo`060?ooo`0309a8B02Lgol0oooo
00H0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`800000A03oool000030?ooo`3OW4P0B9cO00<0
oooo00<0okmd001d_`3oool03@3oool00`2LB4P0W=oo0?ooo`060?ooo`030?oOW018B9`0oooo00H0
oooo00<0W4Q809cOo`3oool01P3oool300000?l0oooo;P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo04<0oooo00000`3oool0gia804RLg`030?ooo`030?noM000M;l0oooo00d0oooo
00<0W4Q809cOo`3oool01`3oool00`2LB4P0W=oo0?ooo`050?ooo`0309a8B02Lgol0oooo00H0oooo
00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo04`0oooo00000`3oool0gia804RL
g`030?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool01`3oool00`3OW4P0B9cO0?oo
o`050?ooo`0309a8B02Lgol0oooo00H0oooo00<000000?ooo`3oool0o`3ooomm0?ooo`0000<0oooo
0?noM018W=l00`3oool00`3OW4P0B9cO0?ooo`0=0?ooo`0309a8B02Lgol0oooo00L0oooo00<0omnL
04Q8W03oool01@3oool00`2LB4P0W=oo0?ooo`060?ooo`030000003oool0oooo0?l0ooooO@3oool0
0080oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`050=nLB000000004RL09a8B02Lgol0
103oool00`2oM4P0W=oo0?ooo`020?ooo`090;mdB02Lgol0oooo0?ooo`3OW4P000000018W02LB4P0
W=oo00L0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`030000003oool0oooo06T0oooo00020?oo
o`050?oo_`1d000000000000B02Lgol03P3oool00`3OW4P0001809cOo`040?ooo`030;md00000000
000000<0000000<0M;oo0?ooo`3oool00P3oool00`3OW4P0001809cOo`070?ooo`030000003oool0
oooo0?l0oooo303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06T0oooo000a0?oo
o`030000003oool0oooo0?l0oooo303oool2000006l0oooo000a0?ooo`030000003oool0oooo0?l0
oooo3@3oool00`000000oooo0?ooo`1]0?ooo`00<@3oool200000?l0ooooOP3oool00340oooo00<0
00000?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo000a0?oo
o`030000003oool0oooo0>/0oooo00<000000?ooo`3oool0SP3oool00340oooo00<000000?ooo`3o
ool0j`3oool00`000000oooo0?ooo`2>0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo
000a0?ooo`030000003oool0oooo0=`0oooo00<000000?ooo`3oool0W@3oool00340oooo0P00003E
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0W@3oool00340oooo00<000000?oo
o`3oool0e03oool00`000000oooo0?ooo`2U0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooogd0
oooo000a0?ooo`030000003oool0oooo0<80oooo0P00002h0?ooo`00<@3oool00`000000oooo0?oo
o`320?ooo`800000^03oool00340oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`2k
0?ooo`00<@3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0^`3oool00340oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`330?ooo`00
<@3oool200000?l0ooooH`3oool00`000000oooo0?ooo`0H0?ooo`00<@3oool00`000000oooo0?oo
o`3o0?ooof80oooo00<000000?ooo`3oool0603oool00340oooo00<000000?ooo`3oool0o`3ooomm
0?ooo`00<@3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0;L0oooo00<000000?oo
o`3oool0:P3oool00340oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`2g0?ooo`03
0000003oool0oooo02X0oooo000a0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0
Z`3oool00`000000oooo0000000f0?ooo`00<@3oool00`000000oooo0?ooo`2;0?ooo`030000003o
ool0oooo0;D0oooo00<000000?ooo`000000=P3oool00340oooo0P00002<0?ooo`030000003oool0
oooo0>h0oooo000a0?ooo`030000003oool0oooo0?l0ooooO@3oool00340oooo00<000000?ooo`3o
ool0o`3oool^0?ooo`030000003oool0oooo04`0oooo000a0?ooo`030000003oool0oooo0780oooo
00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04`0oooo
00020?ooo`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`040?ooo`030?no
M0000000000000<0000000<007Bo0?ooo`3oool00P3oool00`3ogi`0B4RL0?ooo`030?ooo`030?oo
_`1d0000000000@0000000<0M;oo0?ooo`3oool00`3oool00`000000oooo0?ooo`1b0?ooo`030000
003oool0oooo0;00oooo00<000000?ooo`3oool0E03oool00080oooo00H0W4Qd0;ooo`3oool0oono
07@0M02oool40?ooo`030;md0000000007Bo00L0oooo00<0W4Q809cOo`3oool01P3oool00`2LB4P0
W=oo0?ooo`030?ooo`030;md000007@0_ooo0080oooo00<0giad09cOo`3oool0103oool00`000000
oooo0?ooo`3o0?ooogd0oooo00000`3oool0okmd001d_`030?ooo`030=nLB018W=l0oooo00d0oooo
00<0W4Q809cOo`3oool01P3oool00`3OW4P0B9cO0?ooo`040?ooo`030?noM00004P0W=oo00P0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0B03oool000030?ooo`3OW4P0B9cO00<0oooo00<0okmd001d_`3oool03@3o
ool00`2LB4P0W=oo0?ooo`060?ooo`030?oOW018B9`0oooo00D0oooo00<0omnL04P00018W=l01`3o
ool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`180?ooo`0000<0oooo0=nLB018W=l00`3oool00`3o_g@007Bo0?ooo`0=
0?ooo`0309a8B02Lgol0oooo00L0oooo00<0W4Q809cOo`3oool01P3oool00`2LB000B9cO0?ooo`05
0?ooo`<00000D@3oool00`000000oooo0?ooo`3o0?ooobT0oooo00000`3oool0gia804RLg`030?oo
o`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool01`3oool00`3OW4P0B9cO0?ooo`070?oo
o`0309a8M02oool0oooo00@0oooo00<000000?ooo`3oool0D@3oool2000000030?ooo`000000oooo
0?l0oooo9`3oool000030?ooo`3o_g@0B9cO00<0oooo00<0gia804RLg`3oool03@3oool00`2LB4P0
W=oo0?ooo`070?ooo`030?oOW018B9`0oooo0080oooo00<0gia807Boo`3oool00P3oool00`2oM000
M;oo0?ooo`040?ooo`030000003oool0oooo0580oooo00<000000?ooo`000000o`3ooolX0?ooo`00
0P3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00D0gia800000000B9`0W4Q809cOo`04
0?ooo`030;mdB02Lgol0oooo0080oooo00/0_gA809cOo`3oool0oooo0?noM00007@0_ooo0?ooo`3o
_g@0001809cOo`050?ooo`030000003oool0oooo04@0oooo0P00003o0?ooocL0oooo00020?ooo`05
0?oo_`1d000000000000B02Lgol03P3oool00`3OW4P0001809cOo`040?ooo`030;md000000000000
00<0000000D0M;oo0?ooo`3oool0oooo0?noM002000000030000B02Lgol0oooo00D0oooo00<00000
0?ooo`3oool0A03oool200000?l0oooo=`3oool00340oooo00<000000?ooo`3oool0k03oool00`00
0000oooo0?ooo`2=0?ooo`00<@3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo08d0
oooo000a0?ooo`800000i`3oool00`000000oooo0?ooo`2C0?ooo`00<@3oool00`000000oooo0?oo
o`3O0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0T`3oool00340oooo00<00000
0?ooo`3oool0g`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo08H0oooo000a0?oo
o`030000003oool0oooo0=80oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`260?oo
o`00<@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0]P3oool00`000000oooo0?ooo`2W0?ooo`00<@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`2C0?ooo`00<@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0T`3o
ool00340oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooof`0oooo000a0?oo
o`80000000<0oooo0000003oool0o`3ooomk0?ooo`00<@3oool010000000oooo0?ooo`00002/0?oo
o`040000003oool0oooo00000</0oooo000a0?ooo`030000003oool0oooo0:d0oooo00@000000?oo
o`3oool00000b`3oool00340oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`000000
oooo0?ooo`3o0?ooogd0oooo000a0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0
`@3oool00340oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo0<40oooo000a0?ooo`800000TP3oool01@000000oooo0?ooo`3oool000000>H0oooo000a
0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0j03oool00340oooo00<000000?oo
o`3oool0o`3ooomm0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo000a0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0>80oooo000a0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0hP3o
ool00340oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`3o0?ooo`/0oooo000a0?oo
o`030000003oool0oooo0?l0ooooO@3oool00340oooo0P00001n0?ooo`030000003oool0oooo0?`0
oooo000a0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0o03oool00340oooo00<0
00000?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo00020?oo
o`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`040?ooo`030?noM0000000
000000<0000000<007Bo0?ooo`3oool00P3oool00`3ogi`0B4RL0?ooo`050?ooo`050;md00000000
000000000018W=l01P3oool00`000000oooo0?ooo`3o0?ooogd0oooo00020?ooo`0609a8M02oool0
oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`070?ooo`0309a8B02Lgol0oooo00H0oooo
00<0W4Q809cOo`3oool00`3oool01`2oM00007Bo0?ooo`3oool0oono07@00018W=l01@3oool00`00
0000oooo0?ooo`140?ooo`030000003oool000000?l0oooo=P3oool000030?ooo`3o_g@007Bo00<0
oooo00<0gia804RLg`3oool03@3oool00`2LB4P0W=oo0?ooo`060?ooo`030=nLB018W=l0oooo00P0
oooo00<0okmd001d_`3oool0103oool00`000000oooo0?ooo`140?ooo`030000003oool000000?l0
oooo=P3oool000030?ooo`3OW4P0B9cO00<0oooo00<0okmd001d_`3oool03@3oool00`2LB4P0W=oo
0?ooo`060?ooo`030?oOW018B9`0oooo00L0oooo00<0omnL04P0B02Lgol01@3oool300000?l0oooo
O@3oool000030?ooo`3OW4P0B9cO00<0oooo00<0okmd001d_`3oool03@3oool00`2LB4P0W=oo0?oo
o`070?ooo`0309a8B02Lgol0oooo00@0oooo00@0gia80000000004P0W=oo1P3oool00`000000oooo
0?ooo`3o0?ooogd0oooo00000`3oool0gia804RLg`030?ooo`030?noM000M;l0oooo00d0oooo00<0
W4Q809cOo`3oool01`3oool00`3OW4P0B9cO0?ooo`060?ooo`030?oOW01804P0W=oo00D0oooo00<0
00000?ooo`3oool0o`3ooomm0?ooo`0000<0oooo0?noM018W=l00`3oool00`3OW4P0B9cO0?ooo`0=
0?ooo`0309a8B02Lgol0oooo00L0oooo00<0omnL04Q8W03oool01`3oool00`2oM000M;oo0?ooo`04
0?ooo`030000003oool0oooo0?l0ooooO@3oool00080oooo00H0W4P007Boo`3oool0omnL04P0M02o
ool;0?ooo`050=nLB000000004RL09a8B02Lgol0103oool00`2oM4P0W=oo0?ooo`020?ooo`0;0;md
B02Lgol0oooo0?ooo`3o_g@0001809cOo`3oool0omnL04P0B02Lgol01@3oool00`000000oooo0?oo
o`3o0?ooogd0oooo00020?ooo`050?oo_`1d000000000000B02Lgol03P3oool00`3OW4P0001809cO
o`040?ooo`030;md00000000000000<0000000H0M;oo0?ooo`3oool0oooo0?oOW018000200000003
07Boo`3oool0oooo00@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o0?ooo`X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0]0?ooo`00<@3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo02d0oooo000a0?ooo`030000003oool0oooo0?l0ooooO@3oool00340oooo0P00000=
0?ooo`030000003oool0oooo0?l0ooooKP3oool00340oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`3o0?ooob@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0V0?oo
o`00<@3oool00`000000oooo0?ooo`3o0?oooc<0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0V0?ooo`00<@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0?l0oooo
HP3oool00340oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3o0?ooo`L0oooo00<0
00000?ooo`3oool0F03oool00340oooo00<000000?ooo`3oool0o`3ooolR0?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool05P3oool00340oooo00<000000?ooo`3oool0o`3ooolG0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool05P3oool00340oooo0P00003o0?oooaP0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1@0?ooo`00<@3oool00`000000oooo
0?ooo`3o0?ooobX0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0M0?ooo`00<@3o
ool00`000000oooo0?ooo`3o0?ooo`L0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`0M0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo00<000000?ooo`3oool0A`3oool0
1@000000oooo0?ooo`3oool0000002L0oooo000a0?ooo`030000003oool0oooo0?l0oooo6`3oool0
0`000000oooo0?ooo`0c0?ooo`050000003oool0oooo0?ooo`0000009`3oool00340oooo00<00000
0?ooo`3oool0mP3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo05l0oooo000a0?oo
o`030000003oool0oooo0?H0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0l0?oo
o`00<@3oool00`000000oooo0?ooo`3o0?oooch0oooo00<000000?ooo`3oool0?03oool00340oooo
0P00003o0?ooogh0oooo000a0?ooo`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?oo
o`1<0?ooo`00<@3oool00`000000oooo0?ooo`3o0?oooah0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`1<0?ooo`00<@3oool00`000000oooo0?ooo`3o0?oooah0oooo00<000000?oo
o`3oool0G03oool00340oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo00<000000?ooo`3oool0L@3oool00340oooo00<000000?ooo`3oool0g`3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0740oooo000a0?ooo`800000h03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo06h0oooo000a0?ooo`030000003oool0oooo
0?l0oooo303oool00`000000oooo0?ooo`1^0?ooo`00<@3oool00`000000oooo0?ooo`3=0?ooo`03
0000003oool0oooo0:`0oooo000a0?ooo`030000003oool0oooo0:L0oooo0P00000T0?ooo`030000
003oool0oooo0:`0oooo00020?ooo`050?noM000000000000000001d_ol01@3oool00`2oM0000000
001d_`040?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool00P3oool00`3ogi`0B4RL
0?ooo`060?ooo`050?oOW018000000000000001d_ol01@3oool00`000000oooo0?ooo`2W0?ooo`80
0000d`3oool00080oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo
00L0oooo00<0W4Q809cOo`3oool01P3oool00`2LB4P0W=oo0?ooo`070?ooo`030;md001d_ol0oooo
00D0oooo00<000000?ooo`3oool0o`3ooomm0?ooo`0000<0oooo0?noM000M;l00`3oool00`3OW4P0
B9cO0?ooo`0=0?ooo`0309a8B02Lgol0oooo00H0oooo00<0gia804RLg`3oool01`3oool00`2oM000
M;oo0?ooo`050?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0h@3oool000030?oo
o`3OW4P0B9cO00<0oooo00<0okmd001d_`3oool03@3oool00`2LB4P0W=oo0?ooo`060?ooo`030?oO
W018B9`0oooo00<0oooo00<0gia80000000000000`0000000`1d_ol0oooo0?ooo`030?ooo`030000
003oool0oooo09P0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`2C0?ooo`0000<0
oooo0=nLB018W=l00`3oool00`3o_g@007Bo0?ooo`0=0?ooo`0309a8B02Lgol0oooo00L0oooo00<0
W4Q809cOo`3oool00P3oool01P3o_g@0001d0;ooo`3oool0_g@007Boo`H0oooo0`00003V0?ooo`03
0000003oool0oooo09<0oooo00000`3oool0gia804RLg`030?ooo`030?noM000M;l0oooo00d0oooo
00<0W4Q809cOo`3oool01`3oool00`3OW4P0B9cO0?ooo`030?ooo`050=nLB000M;l0oooo0;md001d
_ol01P3oool00`000000oooo0?ooo`3o0?ooogd0oooo00000`3oool0okmd04RLg`030?ooo`030=nL
B018W=l0oooo00d0oooo00<0W4Q809cOo`3oool01`3oool00`3ogi`0B4RL0?ooo`040?ooo`0409a8
0018W=l0_g@007Boo`H0oooo00<000000?ooo`3oool0o`3ooomm0?ooo`000P3oool01P2LB000M;oo
0?ooo`3ogi`0B01d0;ooo`/0oooo00D0gia800000000B9`0W4Q809cOo`040?ooo`030;mdB02Lgol0
oooo0080oooo00<0_gA809cOo`3oool00`3oool0103ogi`0B01804Q8001d_ol60?ooo`030000003o
ool0oooo0?l0ooooO@3oool00080oooo00D0oono07@000000000001809cOo`0>0?ooo`030=nLB000
04P0W=oo00@0oooo00<0_g@00000000000000`0000000`1d_ol0oooo0?ooo`030?ooo`030?noM000
0000M;oo00H0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`310?ooo`00<@3oool0
0`000000oooo0?ooo`270?ooo`030000003oool0oooo02`0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`2n0?ooo`00<@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool00P3oool200000;l0oooo000a0?ooo`800000H`3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0_@3oool00340oooo
00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02D0oooo
00@000000?ooo`3oool00000cP3oool00340oooo00<000000?ooo`3oool0ZP3oool2000000030?oo
o`000000oooo0<d0oooo000a0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0cP3o
ool00340oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`000000oooo0?ooo`1Y0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3N0?oo
o`00<@3oool00`000000oooo0?ooo`0o0?ooo`800000:03oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0gP3oool00340oooo00<000000?ooo`3oool0
?`3oool200000?l0oooo?03oool00340oooo0P0000270?ooo`030000003oool0oooo0?<0oooo000a
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0l`3oool00340oooo00<000000?oo
o`3oool0MP3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000a0?ooo`030000003oool0oooo07H0
oooo00<000000?ooo`3oool0o`3oool40?ooo`00<@3oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo0?l0oooo>P3oool00340oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`3o0?ooocX0oooo000a0?ooo`030000003oool0oooo0?l0ooooO@3oool00340oooo0P00000@0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oo
oaL0oooo000a0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`00
<@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
o`3ooomB0?ooo`00<@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0ooooF@3o
ool00340oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`000000oooo0?ooo`3o0?oo
ogd0oooo000a0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`3o0?oooc`0oooo000a0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo?03oool00340oooo0P00
00060?ooo`030000003oool0oooo0?l0ooooM@3oool00340oooo00<000000?ooo`3oool0o`3ooomm
0?ooo`00<@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0ooooH`3oool00340
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?ooof<0oooo00020?ooo`050?no
M000000000000000001d_ol01@3oool00`2oM0000000001d_`040?ooo`030?noM0000000000000<0
000000<007Bo0?ooo`3oool00P3oool00`3ogi`0B4RL0?ooo`050?ooo`050;md0000000000000000
001d_ol01P3oool00`000000oooo0?ooo`3o0?ooogd0oooo00020?ooo`0609a8M02oool0oooo0?oo
_`1d07@0_ooo103oool00`2oM0000000001d_`070?ooo`0309a8B02Lgol0oooo00H0oooo00<0W4Q8
09cOo`3oool00`3oool01`2oM00007Bo0?ooo`3oool0omnL04P0001d_ol01@3oool00`000000oooo
0?ooo`3o0?ooogd0oooo00000`3oool0okmd001d_`030?ooo`030=nLB018W=l0oooo00d0oooo00<0
W4Q809cOo`3oool01P3oool00`3OW4P0B9cO0?ooo`080?ooo`030?noM000M;l0oooo00@0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooof`0oooo00000`3oool0gia804RLg`03
0?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool01P3oool00`3ogi`0B4RL0?ooo`08
0?ooo`030?noM000M;l0oooo00@0oooo0`00000>0?ooo`030000003oool0oooo0?l0ooooK03oool0
00030?ooo`3OW4P0B9cO00<0oooo00<0okmd001d_`3oool03@3oool00`2LB4P0W=oo0?ooo`070?oo
o`0309a8B02Lgol0oooo00L0oooo00<0W4P007Boo`3oool0103oool00`000000oooo0?ooo`3o0?oo
ogd0oooo00000`3oool0gia804RLg`030?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3o
ool01`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3o
ool0103oool00`000000oooo0?ooo`3o0?ooogd0oooo00000`3oool0okmd04RLg`030?ooo`030=nL
B018W=l0oooo00d0oooo00<0W4Q809cOo`3oool01`3oool00`3ogi`0B4RL0?ooo`020?ooo`030?oo
_`1d07@0_ooo00T0oooo00<000000?ooo`3oool0o`3ooomm0?ooo`000P3oool01P2LB000M;oo0?oo
o`3ogi`0B01d0;ooo`/0oooo00D0gia800000000B9`0W4Q809cOo`040?ooo`030;mdB02Lgol0oooo
0080oooo00L0_gA809cOo`3oool0oooo0?oo_`1d07@0_ooo00T0oooo00<000000?ooo`3oool0o`3o
oomm0?ooo`000P3oool01@3ookl0M0000000000004P0W=oo00h0oooo00<0gia80000B02Lgol0103o
ool00`2oM0000000000000030000000507Boo`3oool0oooo0?oo_`1d00000`0000000`0007@0_ooo
0?ooo`040?ooo`030000003oool0oooo0?l0ooooO@3oool00340oooo00<000000?ooo`3oool0o`3o
oomm0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo000a0?ooo`800000o`3ooomn0?oo
o`00<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo000a0?ooo`030000003oool0oooo0?l0oooo
O@3oool00340oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`000000oooo0?ooo`3o
0?ooogd0oooo000a0?ooo`030000003oool0oooo0?l0ooooO@3oool00340oooo00<000000?ooo`3o
ool0o`3ooomm0?ooo`00<@3oool200000?l0ooooOP3oool00340oooo00<000000?ooo`3oool0o`3o
oomm0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo000a0?ooo`030000003oool0oooo
0?l0ooooO@3oool00340oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`000000oooo
0?ooo`3o0?ooogd0oooo000a0?ooo`030000003oool0oooo0?l0ooooO@3oool00340oooo00<00000
0?ooo`3oool0o`3ooomm0?ooo`00<@3oool200000?l0ooooOP3oool00340oooo00<000000?ooo`3o
ool0o`3ooomm0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo000a0?ooo`030000003o
ool0oooo0?l0ooooO@3oool00340oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`00
0000oooo0?ooo`3o0?ooogd0oooo000a0?ooo`030000003oool0oooo0?l0ooooO@3oool00340oooo
0P00003o0?ooogh0oooo000a0?ooo`030000003oool0oooo0?l0ooooO@3oool00340oooo00<00000
0?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo00020?ooo`05
0?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`040?ooo`030?noM00000000000
00<0000000<007Bo0?ooo`3oool00P3oool00`3ogi`0B4RL0?ooo`060?ooo`050;md000000000000
0000M02oool01@3oool00`000000oooo0?ooo`3o0?ooogd0oooo00020?ooo`0609a8M02oool0oooo
0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`070?ooo`0309a8B02Lgol0oooo00H0oooo00<0
W4Q809cOo`3oool0103oool01P3OW4P007Bo0?ooo`3oool0okmd001d_`D0oooo00<000000?ooo`3o
ool0o`3ooomm0?ooo`0000<0oooo0?noM000M;l00`3oool00`3OW4P0B9cO0?ooo`0=0?ooo`0309a8
B02Lgol0oooo00H0oooo00<0gia804RLg`3oool00`3oool00`3ookl0M00007Boo`020?ooo`030?oo
_`1dB9`0oooo00@0oooo00<000000?ooo`3oool0o`3ooomm0?ooo`0000<0oooo0=nLB018W=l00`3o
ool00`3o_g@007Bo0?ooo`0=0?ooo`0309a8B02Lgol0oooo00H0oooo00<0omnL04Q8W03oool00`3o
ool01`3o_g@004Q807@0M02oool0oooo0=nLB000M;l01@3oool00`000000oooo0?ooo`3o0?ooogd0
oooo00000`3oool0gia804RLg`030?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool0
1`3oool00`2LB4P0W=oo0?ooo`020?ooo`030?oOW018B9`0okmd0080000000<004RL0?ooo`3oool0
103oool300000?l0ooooO@3oool000030?ooo`3OW4P0B9cO00<0oooo00<0okmd001d_`3oool03@3o
ool00`2LB4P0W=oo0?ooo`070?ooo`030=nLB018W=l0oooo0080oooo00<0oono07@0M02oool0o`3o
oon90?ooo`0000<0oooo0?noM018W=l00`3oool00`3OW4P0B9cO0?ooo`0=0?ooo`0309a8B02Lgol0
oooo00L0oooo00<0omnL04Q8W03oool00`3oool00`2oM000B9cO0?ooo`3o0?ooohP0oooo00020?oo
o`0609a8001d_ol0oooo0?oOW01807@0_ooo2`3oool01@3OW4P000000018W02LB4P0W=oo00@0oooo
00<0_gA809cOo`3oool00P3oool00`2oM4P0W=oo0?ooo`020?ooo`030?oo_`1d000007Bo0?l0oooo
R03oool00080oooo00D0oono07@000000000001809cOo`0>0?ooo`030=nLB00004P0W=oo00@0oooo
00<0_g@00000000000000`0000000`1d_ol0oooo0?ooo`030?ooo`040;md0000000000000018W?l0
ooooQ@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0.718637, 0.169298, \
4.12708*^-05, 4.00664*^-05}}]
}, Closed]],

Cell["\<\
Below we show that the orbits of two neighboring points diverge, after which \
the distance between is comparable to the size of the attractor itself.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(data1 = henonMap[{1.4, 0.3}, {0, 0}, 100];\)\), "\n", 
    \(\(data2 = henonMap[{1.4, 0.3}, {0, 0.0001}, 100];\)\), "\n", 
    \(\(ListPlot[distance[data1, data2]];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00942951 0.0147151 0.234395 [
[.2124 .00222 -6 -9 ]
[.2124 .00222 6 0 ]
[.40099 .00222 -6 -9 ]
[.40099 .00222 6 0 ]
[.58958 .00222 -6 -9 ]
[.58958 .00222 6 0 ]
[.77817 .00222 -6 -9 ]
[.77817 .00222 6 0 ]
[.96676 .00222 -9 -9 ]
[.96676 .00222 9 0 ]
[.01131 .13191 -18 -4.5 ]
[.01131 .13191 0 4.5 ]
[.01131 .24911 -6 -4.5 ]
[.01131 .24911 0 4.5 ]
[.01131 .36631 -18 -4.5 ]
[.01131 .36631 0 4.5 ]
[.01131 .4835 -6 -4.5 ]
[.01131 .4835 0 4.5 ]
[.01131 .6007 -18 -4.5 ]
[.01131 .6007 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2124 .01472 m
.2124 .02097 L
s
[(20)] .2124 .00222 0 1 Mshowa
.40099 .01472 m
.40099 .02097 L
s
[(40)] .40099 .00222 0 1 Mshowa
.58958 .01472 m
.58958 .02097 L
s
[(60)] .58958 .00222 0 1 Mshowa
.77817 .01472 m
.77817 .02097 L
s
[(80)] .77817 .00222 0 1 Mshowa
.96676 .01472 m
.96676 .02097 L
s
[(100)] .96676 .00222 0 1 Mshowa
.125 Mabswid
.07096 .01472 m
.07096 .01847 L
s
.1181 .01472 m
.1181 .01847 L
s
.16525 .01472 m
.16525 .01847 L
s
.25955 .01472 m
.25955 .01847 L
s
.30669 .01472 m
.30669 .01847 L
s
.35384 .01472 m
.35384 .01847 L
s
.44814 .01472 m
.44814 .01847 L
s
.49529 .01472 m
.49529 .01847 L
s
.54243 .01472 m
.54243 .01847 L
s
.63673 .01472 m
.63673 .01847 L
s
.68388 .01472 m
.68388 .01847 L
s
.73102 .01472 m
.73102 .01847 L
s
.82532 .01472 m
.82532 .01847 L
s
.87247 .01472 m
.87247 .01847 L
s
.91961 .01472 m
.91961 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13191 m
.03006 .13191 L
s
[(0.5)] .01131 .13191 1 0 Mshowa
.02381 .24911 m
.03006 .24911 L
s
[(1)] .01131 .24911 1 0 Mshowa
.02381 .36631 m
.03006 .36631 L
s
[(1.5)] .01131 .36631 1 0 Mshowa
.02381 .4835 m
.03006 .4835 L
s
[(2)] .01131 .4835 1 0 Mshowa
.02381 .6007 m
.03006 .6007 L
s
[(2.5)] .01131 .6007 1 0 Mshowa
.125 Mabswid
.02381 .03815 m
.02756 .03815 L
s
.02381 .06159 m
.02756 .06159 L
s
.02381 .08503 m
.02756 .08503 L
s
.02381 .10847 m
.02756 .10847 L
s
.02381 .15535 m
.02756 .15535 L
s
.02381 .17879 m
.02756 .17879 L
s
.02381 .20223 m
.02756 .20223 L
s
.02381 .22567 m
.02756 .22567 L
s
.02381 .27255 m
.02756 .27255 L
s
.02381 .29599 m
.02756 .29599 L
s
.02381 .31943 m
.02756 .31943 L
s
.02381 .34287 m
.02756 .34287 L
s
.02381 .38975 m
.02756 .38975 L
s
.02381 .41319 m
.02756 .41319 L
s
.02381 .43663 m
.02756 .43663 L
s
.02381 .46006 m
.02756 .46006 L
s
.02381 .50694 m
.02756 .50694 L
s
.02381 .53038 m
.02756 .53038 L
s
.02381 .55382 m
.02756 .55382 L
s
.02381 .57726 m
.02756 .57726 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.03324 .01474 Mdot
.04267 .01474 Mdot
.0521 .01478 Mdot
.06153 .01478 Mdot
.07096 .0149 Mdot
.08039 .01507 Mdot
.08982 .01522 Mdot
.09925 .01532 Mdot
.10868 .01652 Mdot
.1181 .01611 Mdot
.12753 .01846 Mdot
.13696 .02521 Mdot
.14639 .02117 Mdot
.15582 .02211 Mdot
.16525 .02381 Mdot
.17468 .04224 Mdot
.18411 .04044 Mdot
.19354 .08384 Mdot
.20297 .17994 Mdot
.2124 .10119 Mdot
.22183 .16617 Mdot
.23126 .32041 Mdot
.24069 .39352 Mdot
.25012 .54426 Mdot
.25955 .21561 Mdot
.26898 .08011 Mdot
.27841 .04391 Mdot
.28784 .06934 Mdot
.29727 .12742 Mdot
.30669 .18639 Mdot
.31612 .42594 Mdot
.32555 .2035 Mdot
.33498 .2096 Mdot
.34441 .51521 Mdot
.35384 .28081 Mdot
.36327 .40071 Mdot
.3727 .42733 Mdot
.38213 .26194 Mdot
.39156 .14794 Mdot
.40099 .15322 Mdot
.41042 .20107 Mdot
.41985 .49314 Mdot
.42928 .18746 Mdot
.43871 .21441 Mdot
.44814 .45871 Mdot
.45757 .37103 Mdot
.467 .27688 Mdot
.47643 .09267 Mdot
.48586 .13002 Mdot
.49529 .23284 Mdot
.50471 .3564 Mdot
.51414 .60332 Mdot
.52357 .22555 Mdot
.533 .17106 Mdot
.54243 .23695 Mdot
.55186 .16886 Mdot
.56129 .2561 Mdot
.57072 .52403 Mdot
.58015 .27177 Mdot
.58958 .12911 Mdot
.59901 .09248 Mdot
.60844 .13891 Mdot
.61787 .31868 Mdot
.6273 .17058 Mdot
.63673 .3382 Mdot
.64616 .37102 Mdot
.65559 .48413 Mdot
.66502 .34464 Mdot
.67445 .13375 Mdot
.68388 .03908 Mdot
.69331 .02516 Mdot
.70273 .02637 Mdot
.71216 .04636 Mdot
.72159 .02471 Mdot
.73102 .03584 Mdot
.74045 .08716 Mdot
.74988 .17811 Mdot
.75931 .15185 Mdot
.76874 .15966 Mdot
.77817 .22932 Mdot
.7876 .51 Mdot
.79703 .20008 Mdot
.80646 .07475 Mdot
.81589 .15981 Mdot
.82532 .06128 Mdot
.83475 .11123 Mdot
.84418 .20401 Mdot
.85361 .28617 Mdot
.86304 .181 Mdot
.87247 .38262 Mdot
.8819 .30192 Mdot
.89132 .35225 Mdot
.90075 .55811 Mdot
.91018 .26137 Mdot
.91961 .21705 Mdot
.92904 .07937 Mdot
.93847 .11429 Mdot
.9479 .20829 Mdot
.95733 .31119 Mdot
.96676 .59317 Mdot
.97619 .25286 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00I03oool00`3ookl0M000000000040000000507Boo`3oool0oooo0?ooo`3o_g@00`000000
0`1d_ol0oooo0?ooo`0n0?ooo`050?oOW018000000000000001d_ol00`3oool01@3o_g@000000000
00000000M;oo0400oooo00D0_g@0000000000000001d0;ooo`030?ooo`050?noM000000000000000
001d_ol0?`3oool01@2oM000000000000000000007Bo00@0oooo00D0okmd000000000000000007Bo
o`0i0?ooo`030?noM0000000000000<0000000D007Bo0?ooo`3oool0oooo0?noM0030000000307Bo
o`3oool0oooo0080oooo00D0okmd000000000000000007Boo`040?ooo`00I@3oool00`2oM000001d
0;ooo`020?ooo`030=nLM02Lgol0oooo0080oooo00H0W4Qd0;ooo`3oool0oono07@0M02ooom10?oo
o`030;md001d_ol0oooo00<0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oooln0?ooo`060=nLB000
M;l0oooo0?ooo`3o_g@007Bo0`3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooocd0oooo00<0okmd
001d_`3oool00P3oool00`2oM4P0W=oo0?ooo`020?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo
>`3oool00`2LB4P0W=oo0?ooo`040?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo0`3oool01P2L
B7@0_ooo0?ooo`3ookl0M01d0;ooo`<0oooo001V0?ooo`030?noM00004P0W=oo00D0oooo00<0okmd
001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`100?ooo`030;md001d_ol0oooo0080oooo00<0okmd
001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0l0?ooo`030?oo_`1d0000M;oo0080oooo00H0oono
07A8W03oool0oooo0?noM000M;l30?ooo`030=nLB018W=l0oooo03`0oooo00<0gia804RLg`3oool0
0P3oool01P2oM000M;oo0?ooo`3oool0okmd001d_`<0oooo00<0gia804RLg`3oool0>P3oool00`2L
B4P0W=oo0?ooo`030?ooo`030?noM000M;l0oooo0080oooo00H0gia804RLg`3oool0oooo0?noM000
M;l30?ooo`030=nLB018W=l0oooo0080oooo001W0?ooo`030?oOW0180000B9cO00@0oooo00<0gia8
04RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0l0?ooo`030=nLB0000000000000<0000000D0M;oo
0?ooo`3oool0gia804RLg`030?ooo`030?noM000M;l0oooo03`0oooo00L0okmd0018B01d07@0_ooo
0?ooo`3OW4P007Bo0080oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0l0?ooo`03
0?noM000B9`0oooo0080oooo00H0W4Q809cOo`3oool0oooo0=nLB018W=l30?ooo`030?noM000M;l0
oooo03X0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`060?noM000M;l0
oooo0?ooo`3OW4P0B9cO0`3oool00`3o_g@007Bo0?ooo`020?ooo`00J@3oool00`2LB000B9cO0?oo
o`020?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0?03oool01P3o_g@0001d0;oo
o`3oool0_g@007Boo`<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0l0?ooo`03
0?oOW018B9`0okmd0080000000H004RL0?ooo`3oool0oooo0=nLB018W=l30?ooo`030?noM000M;l0
oooo03d0oooo00D0gia8000000000000000004RLg`030?ooo`030=nLB018W=l0oooo0080oooo00<0
okmd001d_`3oool0>P3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00H0
okmd001d_`3oool0oooo0=nLB018W=l30?ooo`030?noM000M;l0oooo0080oooo001Z0?ooo`0609a8
M02oool0oooo0?ooo`3OW4P0B9cO0`3oool00`3o_g@007Bo0?ooo`0m0?ooo`050=nLB000M;l0oooo
0;md001d_ol00`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo03`0oooo00<0oono
07@0M02oool01P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo03`0oooo00<0oono
07A8W03oool00P3oool01P2LB7@0_ooo0?ooo`3oool0gia804RLg`<0oooo00<0okmd001d_`3oool0
>P3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00H0okmd001d_`3oool0
oooo0=nLB018W=l30?ooo`030?noM000M;l0oooo0080oooo001U0?ooo`030=nLB01d_ol0oooo0080
oooo00H0_g@007Boo`3oool0oooo0?noM018W=l30?ooo`030=nLB018W=l0oooo03h0oooo00@0W4P0
04RLg`2oM000M;oo0`3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo03d0oooo00<0
_g@004RLg`3oool01@3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo03`0oooo00<0
okmd04RLg`3oool00P3oool01P2oM000M;oo0?ooo`3oool0okmd04RLg`<0oooo00<0gia804RLg`3o
ool0>P3oool00`2LB4P0W=oo0?ooo`030?ooo`030?noM018W=l0oooo0080oooo00H0gia804RLg`3o
ool0oooo0?noM018W=l30?ooo`030=nLB018W=l0oooo0080oooo001U0?ooo`070?noM00007@0_ooo
0?ooo`3o_g@0001809cOo`030?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo?`3oool0103ogi`0
B01804Q8001d_ol40?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo?P3oool00`3ookl0M000001d
_`060?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo?@3oool01`3ogi`0B01d0;ooo`3oool0omnL
04P0M02oool00`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooocP0oooo00D0gia800000000B9`0
W4Q809cOo`050?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo0`3oool01P2LB000M;oo0?ooo`3o
gi`0B01d0;ooo`<0oooo001V0?ooo`050?noM000000000000000B02Lgol0103oool01@3ookl0M000
0000000004P0W=oo0440oooo00<0okmd0000001d_ol0103oool01@3ookl0M0000000000004P0W=oo
0440oooo00@0_g@000000000000004RL0`3oool01@3ookl0M0000000000004P0W=oo03l0oooo00D0
okmd000000000000001809cOo`040?ooo`050?oo_`1d000000000000B02Lgol0>`3oool00`3OW4P0
001809cOo`050?ooo`050?oo_`1d000000000000B02Lgol0103oool01@3ookl0M0000000000004P0
W=oo00@0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo000P0?ooo`030000003o
ool0oooo0?l0ooooSP3oool00200oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool00`00
0000oooo0?ooo`3o0?ooohh0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00200oooo
00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool010000000oooo0?ooo`0000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?oo
o`3oool000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0o`3o
oomX0?ooo`005P3ooooo000009X000000@3oool00200oooo00@000000?ooo`3oool000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000
003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00<000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0<0?ooo`00803oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo00@0oooo0`0000000`3oool000000?ooo`020?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04X0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0<0?ooo`00803oool00`000000oooo
0?ooo`0[0?ooo`060000003oool0oooo0?ooo`000000oooo0`000000103oool0000000000000003F
0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`1`0?ooo`00803oool0
0`000000oooo0?ooo`0Z0?ooo`<000001@3oool01@000000oooo0?ooo`3oool000000=H0oooo0`00
0000103oool000000000000000050?ooo`<00000L@3oool00200oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`3P0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo
0?ooo`1`0?ooo`00803oool00`000000oooo0?ooo`3o0?ooohh0oooo000P0?ooo`030000003oool0
oooo0?l0oooo7P3oool00`000000oooo0?ooo`1]0?ooo`00803oool00`000000oooo0?ooo`3o0?oo
oad0oooo0`00001^0?ooo`00803oool2000003l0oooo00<000000?ooo`3oool0b@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo06d0oooo000P0?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool00`0000390?ooo`<00000P@3oool00200oooo00<000000?ooo`3oool0>@3o
ool300000080oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`2R0?ooo`030000003o
ool0oooo0800oooo000P0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool09`3oool3
00000:l0oooo00<000000?ooo`3oool0M03oool00200oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`2]0?ooo`<00000M@3oool00200oooo00<000000?ooo`3oool0o`3ooolG0?ooo`03
0000003oool0oooo07@0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00200oooo00<0
00000?ooo`3oool0o`3ooon>0?ooo`00803oool00`000000oooo0?ooo`3o0?ooohh0oooo000P0?oo
o`030000003oool0oooo0?l0ooooA@3oool00`000000oooo0?ooo`160?ooo`00803oool200000?l0
ooooA@3oool3000004L0oooo000P0?ooo`030000003oool0oooo0?l0ooooA@3oool00`000000oooo
0?ooo`160?ooo`00803oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo0?l0oooo8`3o
ool00200oooo00<000000?ooo`3oool0I`3oool300000?l0oooo903oool00200oooo00<000000?oo
o`3oool0J03oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo04h0oooo000P0?ooo`03
0000003oool0oooo0?l0oooo?03oool3000004l0oooo000P0?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01`0oooo
000P0?ooo`030000003oool0oooo0600oooo0`00003o0?ooo`/0oooo0`00000M0?ooo`00803oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0o`3oool;
0?ooo`030000003oool0oooo01`0oooo000P0?ooo`800000@P3oool300000=d0oooo00<000000?oo
o`3oool0J@3oool00200oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`3K0?ooo`<0
0000JP3oool00200oooo00<000000?ooo`3oool0o`3ooolR0?ooo`030000003oool0oooo06T0oooo
000P0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`2R0?ooo`00803oool00`000000oooo0?ooo`2d0?ooo`<00000<03oool300000:<0oooo000P0?oo
o`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`2R0?oo
o`00803oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0?l0oooo@@3oool00200oooo
00<000000?ooo`3oool0B@3oool300000?l0oooo@P3oool00200oooo00<000000?ooo`3oool0BP3o
ool00`000000oooo0?ooo`3o0?oood40oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool0
0200oooo0P00003o0?ooodX0oooo00<000000?ooo`3oool0@P3oool00200oooo00<000000?ooo`3o
ool0o`3ooom80?ooo`<00000:03oool00`000000oooo0?ooo`0H0?ooo`00803oool00`000000oooo
0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool09P3oool3000001T0oooo000P0?ooo`030000003o
ool0oooo0?l0ooooL`3oool00`000000oooo0?ooo`0H0?ooo`00803oool00`000000oooo0?ooo`3o
0?ooohh0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00080oooo00D0okmd00000000
0000000007Boo`050?ooo`030;md0000000007Bo00D0oooo00D0_g@0000000000000000007Boo`07
0?ooo`030000003oool0oooo0?l0ooooSP3oool00080oooo00H0W4Qd0;ooo`3oool0oono07@0M02o
ool40?ooo`030;md0000000007Bo00@0oooo00L0_g@0001d_`3oool0oooo0?oOW0180000M;oo00H0
oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0:H0
oooo00000`3oool0okmd001d_`030?ooo`030=nLB018W=l0oooo00l0oooo00<0okmd001d_`3oool0
1@3oool00`000000oooo0?ooo`1[0?ooo`<00000B`3oool00`000000oooo0?ooo`0W0?ooo`<00000
Y`3oool000030?ooo`3OW4P0B9cO00<0oooo00<0okmd001d_`3oool03`3oool00`3o_g@007Bo0?oo
o`050?ooo`<00000K03oool00`000000oooo0?ooo`190?ooo`<00000:@3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo08@0oooo00000`3oool0gia804RLg`030?ooo`030?noM000M;l0
oooo00l0oooo00<0W4P007Boo`3oool01@3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0
oooo04T0oooo0`0000250?ooo`0000<0oooo0=nLB018W=l00`3oool00`3o_g@007Bo0?ooo`0:0?oo
o`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`3[0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0Q03oool000030?ooo`3o_g@0B9cO00<0
oooo00<0gia804RLg`3oool02P3oool00`3ookl0M01d0;ooo`0:0?ooo`030000003oool0oooo0>X0
oooo0`00002P0?ooo`000P3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00<0oono07@0
M02oool02P3oool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo09l0oooo00020?ooo`05
0?oo_`1d000000000000B02Lgol0303oool00`3ookl0M00000000002000000030000M02oool0oooo
00D0oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool00`000000oooo0?ooo`2C0?ooo`03
0000003oool0oooo0?L0oooo000P0?ooo`030000003oool0oooo0980oooo0`00003h0?ooo`00803o
ool00`000000oooo0?ooo`2C0?ooo`050000003oool0oooo0?ooo`000000T@3oool00`000000oooo
0?ooo`1Q0?ooo`00803oool00`000000oooo0?ooo`2F0?ooo`<00000S`3oool300000680oooo000P
0?ooo`800000V03oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0640oooo000P0?oo
o`030000003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
04X0oooo000P0?ooo`030000003oool0oooo0?l0oooo;@3oool300000100oooo0`00001;0?ooo`00
803oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`1:0?ooo`00803oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0?l0oooo?P3o
ool00200oooo00<000000?ooo`3oool0C03oool3000008D0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`2G0?ooo`00803oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
07d0oooo00<000000?ooo`3oool00`3oool3000001`0oooo0`00002H0?ooo`00803oool00`000000
oooo0?ooo`3<0?ooo`<000001@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo09L0
oooo000P0?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`1U0?ooo`00803oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0=/0oooo0`00
001V0?ooo`00803oool2000004H0oooo0`00003M0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0=`3oool00200oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`3o0?oo
o`X0oooo0`00000h0?ooo`00803oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0g0?ooo`00803oool00`000000oooo
0?ooo`1_0?ooo`<00000;`3oool300000>T0oooo000P0?ooo`030000003oool0oooo0700oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`3X0?ooo`00803oool00`000000oooo0?ooo`3o
0?ooohh0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00200oooo00<000000?ooo`3o
ool0o`3oooli0?ooo`030000003oool0oooo0580oooo000P0?ooo`030000003oool0oooo09X0oooo
00<000000?ooo`3oool0VP3oool3000005<0oooo000P0?ooo`800000N@3oool00`000000oooo0?oo
o`0N0?ooo`<00000W03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03h0oooo000P
0?ooo`030000003oool0oooo07L0oooo0`00000P0?ooo`030000003oool0oooo0:h0oooo0`00000o
0?ooo`00803oool00`000000oooo0?ooo`1h0?ooo`050000003oool0oooo0?ooo`000000c`3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01@0oooo000P0?ooo`030000003oool0oooo
07/0oooo0`00003g0?ooo`<000005@3oool00200oooo00<000000?ooo`3oool0O03oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool0503oool00200oooo
00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`150?ooo`<00000``3oool00`000000oooo
0?ooo`0O0?ooo`00803oool00`000000oooo0?ooo`1L0?ooo`<00000A`3oool00`000000oooo0?oo
o`310?ooo`<00000803oool00200oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3o
0?ooo``0oooo00<000000?ooo`3oool07`3oool00200oooo00<000000?ooo`3oool0o`3ooon>0?oo
o`00803oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo0<40oooo000P0?ooo`800000
b@3oool3000006H0oooo00<000000?ooo`3oool0F@3oool00200oooo00<000000?ooo`3oool0b@3o
ool00`000000oooo0?ooo`1T0?ooo`<00000FP3oool00200oooo00<000000?ooo`3oool0_@3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo05T0oooo000P0?ooo`030000003oool0oooo
0;`0oooo0`00003>0?ooo`00803oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0^P3oool00200oooo00<000000?ooo`3oool0c`3oool300000;/0oooo
000C0?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool0103oool00`000000oooo0?oo
o`3@0?ooo`030000003oool0oooo0;X0oooo000F0?ooo`0309a8B02Lgol0oooo00L0oooo00<00000
0?ooo`3oool0o`3ooon>0?ooo`005P3oool00`2LB4P0W=oo0?ooo`070?ooo`030000003oool0oooo
0?l0ooooSP3oool001H0oooo00<0W4Q809cOo`3oool01`3oool300000?l0ooooSP3oool001H0oooo
00<0W4Q809cOo`3oool01`3oool00`000000oooo0?ooo`3o0?oooh<0oooo00<000000?ooo`3oool0
203oool001H0oooo00<0W4Q809cOo`3oool01`3oool00`000000oooo0?ooo`3H0?ooo`030000003o
ool0oooo0:H0oooo0`0000090?ooo`005P3oool00`2LB4P0W=oo0?ooo`070?ooo`030000003oool0
oooo0=L0oooo0`00002X0?ooo`030000003oool0oooo00P0oooo000C0?ooo`050=nLB000000004RL
09a8B02Lgol0203oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo0;80oooo000E0?oo
o`030=nLB00004P0W=oo00P0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`3E0?oo
o`030000003oool0oooo02<0oooo000P0?ooo`030000003oool0oooo08h0oooo0`00003E0?ooo`<0
0000903oool00200oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`3E0?ooo`030000
003oool0oooo02<0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00200oooo00<00000
0?ooo`3oool0h03oool00`000000oooo0?ooo`2Z0?ooo`00803oool200000>00oooo0`00002[0?oo
o`00803oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0ZP3oool00200oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0[0?ooo`<00000
f@3oool00200oooo00<000000?ooo`3oool0PP3oool3000002d0oooo00<000000?ooo`3oool0f03o
ool00200oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`3o0?ooo`P0oooo000P0?oo
o`030000003oool0oooo0?l0ooooD@3oool00`000000oooo0?ooo`0j0?ooo`00803oool00`000000
oooo0?ooo`3o0?oooe00oooo0`00000k0?ooo`00803oool00`000000oooo0?ooo`3o0?oooe40oooo
00<000000?ooo`3oool0>P3oool00200oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool0
0`000000oooo0?ooo`3o0?ooohh0oooo000P0?ooo`800000o`3ooon?0?ooo`00803oool00`000000
oooo0?ooo`3o0?oooe`0oooo00<000000?ooo`3oool0;`3oool00200oooo00<000000?ooo`3oool0
o`3ooomK0?ooo`<00000<03oool00200oooo00<000000?ooo`3oool0o`3ooomL0?ooo`030000003o
ool0oooo02l0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00200oooo00<000000?oo
o`3oool0o`3ooomk0?ooo`030000003oool0oooo0100oooo000P0?ooo`030000003oool0oooo0?l0
ooooNP3oool300000140oooo000P0?ooo`030000003oool0oooo0?l0ooooN`3oool00`000000oooo
0?ooo`0@0?ooo`00803oool00`000000oooo0?ooo`3_0?ooo`030000003oool0oooo09/0oooo000P
0?ooo`800000DP3oool00`000000oooo0?ooo`2J0?ooo`<00000W03oool00200oooo00<000000?oo
o`3oool0D03oool3000009`0oooo00<000000?ooo`3oool0V`3oool00200oooo00<000000?ooo`3o
ool0D@3oool00`000000oooo0?ooo`3o0?ooocX0oooo000P0?ooo`030000003oool0oooo0?l0oooo
SP3oool00200oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool00`000000oooo0?ooo`3o
0?ooohh0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00200oooo00<000000?ooo`3o
ool0m`3oool00`000000oooo0?ooo`2C0?ooo`00803oool00`000000oooo0?ooo`3f0?ooo`<00000
U03oool00200oooo00<000000?ooo`3oool0m`3oool00`000000oooo0?ooo`2C0?ooo`00803oool2
00000?l0oooo103oool00`000000oooo0?ooo`280?ooo`00803oool00`000000oooo0?ooo`3o0?oo
o`80oooo0`0000290?ooo`00803oool00`000000oooo0?ooo`3o0?ooo`<0oooo00<000000?ooo`3o
ool0R03oool00200oooo00<000000?ooo`3oool0o`3ooomP0?ooo`030000003oool0oooo02/0oooo
000P0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool0VP3oool3000002`0oooo000P
0?ooo`030000003oool0oooo0<00oooo0`00002L0?ooo`030000003oool0oooo02/0oooo00000`3o
ool0okmd0000000400000003001d_`3oool0oooo0080oooo00<0_g@000000000M;l01@3oool01@2o
M0000000000000000000M;oo00L0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`39
0?ooo`00103oool00`2LB4P0W=oo0?ooo`050?ooo`030;md0000000007Bo00@0oooo00L0_g@0001d
_`3oool0oooo0?oOW0180000M;oo00H0oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00103oool0
0`2LB4P0W=oo0?ooo`0A0?ooo`030?noM000M;l0oooo00D0oooo00<000000?ooo`3oool0o`3ooon>
0?ooo`00103oool00`2LB4P0W=oo0?ooo`0A0?ooo`030?noM000M;l0oooo00D0oooo0`00003o0?oo
ohh0oooo00040?ooo`0309a8B02Lgol0oooo0140oooo00<0W4P007Boo`3oool01@3oool00`000000
oooo0?ooo`2^0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0S`3oool000@0oooo
00<0W4Q809cOo`3oool0303oool00`3ookl0M000000000020000000304RLg`3oool0oooo00D0oooo
00<000000?ooo`3oool0[@3oool3000004X0oooo0`00002@0?ooo`00103oool00`2LB4P0W=oo0?oo
o`0<0?ooo`030?oo_`1d07@0_ooo00X0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo08l0oooo00001P3oool0gia800000000B9`0W4Q809cOo`d0oooo
00<0oono07@0M02oool02P3oool00`000000oooo0?ooo`3o0?ooohh0oooo00030?ooo`030=nLB000
04P0W=oo00d0oooo00<0oono07@0000000000P0000000`0007@0_ooo0?ooo`050?ooo`030000003o
ool0oooo0?l0ooooSP3oool00200oooo00<000000?ooo`3oool0o`3ooomH0?ooo`030000003oool0
oooo03<0oooo000P0?ooo`030000003oool0oooo0?l0ooooE`3oool3000003@0oooo000P0?ooo`03
0000003oool0oooo0?l0ooooF03oool00`000000oooo0?ooo`0c0?ooo`00803oool00`000000oooo
0?ooo`3o0?ooohh0oooo000P0?ooo`800000o`3ooon?0?ooo`00803oool00`000000oooo0?ooo`1E
0?ooo`030000003oool0oooo0?l0oooo=P3oool00200oooo00<000000?ooo`3oool0E03oool30000
0?l0oooo=`3oool00200oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo0?l0oooo103oool00200oooo00<000000?ooo`3oool0QP3oool300000?l0oooo
1@3oool00200oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000P
0?ooo`030000003oool0oooo0?l0ooooSP3oool00200oooo00<000000?ooo`3oool0o`3ooon>0?oo
o`00803oool00`000000oooo0?ooo`3o0?ooohh0oooo000P0?ooo`800000o`3ooon?0?ooo`00803o
ool00`000000oooo0?ooo`3o0?ooohh0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool0
0200oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool00`000000oooo0?ooo`3o0?ooohh0
oooo000P0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`3o0?ooo`00803oool00`000000oooo0?ooo`1c0?ooo`<00000503oool300000?l0oooo0@3o
ool00200oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0?l0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00200oooo00<000000?ooo`3o
ool0o`3ooon>0?ooo`00803oool200000?l0ooooS`3oool00200oooo00<000000?ooo`3oool0o`3o
oon>0?ooo`00803oool00`000000oooo0?ooo`3o0?ooohh0oooo000P0?ooo`030000003oool0oooo
0?l0ooooSP3oool00200oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool00`000000oooo
0?ooo`3o0?ooohh0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00200oooo00<00000
0?ooo`3oool0o`3ooon>0?ooo`00803oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo
0>00oooo000P0?ooo`030000003oool0oooo0:T0oooo0`00003Q0?ooo`00803oool200000:/0oooo
00<000000?ooo`3oool0h03oool00200oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool0
0`000000oooo0?ooo`3o0?ooohh0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00200
oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool00`000000oooo0?ooo`3o0?ooohh0oooo
000B0?ooo`030?oo_`1d0000000000@0000000<0M;oo0?ooo`3oool0103oool00`000000oooo0?oo
o`3o0?ooohh0oooo000C0?ooo`030;md000007@0_ooo0080oooo00<0giad09cOo`3oool01@3oool0
0`000000oooo0?ooo`3o0?ooohh0oooo000D0?ooo`030?noM00004P0W=oo00T0oooo00<000000?oo
o`3oool0o`3ooon>0?ooo`005@3oool00`3ogi`0B00004RLg`080?ooo`<00000o`3oool00`000000
oooo0?ooo`2;0?ooo`005`3oool00`2LB000B9cO0?ooo`060?ooo`030000003oool0oooo0?h0oooo
0`00002<0?ooo`00603oool00`2LB7@0_ooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo00<0
00000?ooo`3oool0R`3oool001<0oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`05
0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0k03oool001<0oooo00L0okmd0000
M02oool0oooo0?noM00004P0W=oo00H0oooo00<000000?ooo`3oool0W@3oool300000>d0oooo000D
0?ooo`050?noM000000000000000B02Lgol01`3oool00`000000oooo0?ooo`2N0?ooo`030000003o
ool0oooo0>`0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00200oooo00<000000?oo
o`3oool0o`3ooon>0?ooo`00803oool00`000000oooo0?ooo`3o0?ooohh0oooo000P0?ooo`030000
003oool0oooo0?l0ooooSP3oool00200oooo0P00003o0?ooocL0oooo00<000000?ooo`3oool0E@3o
ool00200oooo00<000000?ooo`3oool0o`3ooole0?ooo`<00000EP3oool00200oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo05D0oooo000P0?ooo`03
0000003oool0oooo07h0oooo0`00003o0?ooo`d0oooo000P0?ooo`030000003oool0oooo07l0oooo
00<000000?ooo`3oool0o`3oool<0?ooo`00803oool00`000000oooo0?ooo`3o0?ooohh0oooo000P
0?ooo`030000003oool0oooo0=`0oooo00<000000?ooo`3oool0[P3oool00200oooo00<000000?oo
o`3oool0f`3oool300000:l0oooo000P0?ooo`030000003oool0oooo0=`0oooo00<000000?ooo`3o
ool0[P3oool00200oooo0P00003o0?ooohl0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3o
ool00200oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool00`000000oooo0?ooo`3o0?oo
ohh0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00200oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`3o0?oooc80oooo000P0?ooo`030000003oool0oooo05P0oooo0`00
003o0?oooc<0oooo000P0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0o`3ooolb
0?ooo`00803oool00`000000oooo0?ooo`3o0?ooohh0oooo000P0?ooo`030000003oool0oooo0?l0
ooooSP3oool00200oooo0P00003o0?ooohl0oooo000P0?ooo`030000003oool0oooo0?l0ooooI03o
ool00`000000oooo0?ooo`0W0?ooo`00803oool00`000000oooo0?ooo`3o0?ooof<0oooo0`00000X
0?ooo`00803oool00`000000oooo0?ooo`3o0?ooof@0oooo00<000000?ooo`3oool09`3oool00200
oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool00`000000oooo0?ooo`3o0?ooohh0oooo
000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00200oooo00<000000?ooo`3oool0o`3ooon>
0?ooo`00803oool00`000000oooo0?ooo`3o0?ooohh0oooo000P0?ooo`800000o`3ooon?0?ooo`00
803oool00`000000oooo0?ooo`3o0?ooohh0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3o
ool00200oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool00`000000oooo0?ooo`3o0?oo
ohh0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00200oooo00<000000?ooo`3oool0
o`3ooomo0?ooo`030000003oool0oooo00`0oooo00000`3ookl0M000000000040000000307Boo`3o
ool0oooo0080oooo00<0_g@000000000M;l01@3oool01@2oM0000000000000000000M;oo00L0oooo
00<000000?ooo`3oool0o`3ooomn0?ooo`<000003@3oool000040?ooo`2oM000001d0;ooo`80oooo
00<0giad09cOo`3oool00`3oool00`2oM0000000001d_`040?ooo`070;md0000M;l0oooo0?ooo`3o
gi`0B00007Boo`060?ooo`030000003oool0oooo0?l0ooooO`3oool00`000000oooo0?ooo`0<0?oo
o`000P3oool00`3o_g@0001809cOo`0C0?ooo`030?noM000M;l0oooo00D0oooo00<000000?ooo`3o
ool0o`3ooon>0?ooo`000`3oool00`3ogi`0B00004RLg`0B0?ooo`030?noM000M;l0oooo00D0oooo
0`0000350?ooo`030000003oool0oooo0<D0oooo00050?ooo`0309a80018W=l0oooo0100oooo00<0
W4P007Boo`3oool01@3oool00`000000oooo0?ooo`340?ooo`<00000aP3oool000H0oooo00<0W4Qd
0;ooo`3oool02P3oool00`3ookl0M000000000020000000304RLg`3oool0oooo00D0oooo00<00000
0?ooo`3oool0a@3oool00`000000oooo0?ooo`350?ooo`0000<0oooo0=nLB01d_ol00`3oool00`2o
M000M;oo0?ooo`0:0?ooo`030?oo_`1d07@0_ooo00X0oooo00<000000?ooo`3oool0o`3ooon>0?oo
o`0000P0oooo0?noM00007@0_ooo0?ooo`3o_g@0001809cOo`/0oooo00<0oono07@0M02oool02P3o
ool00`000000oooo0?ooo`3o0?ooohh0oooo00020?ooo`050?noM000000000000000B02Lgol0303o
ool00`3ookl0M00000000002000000030000M02oool0oooo00D0oooo00<000000?ooo`3oool0o`3o
oon>0?ooo`00803oool00`000000oooo0?ooo`3o0?ooohh0oooo000P0?ooo`030000003oool0oooo
0?l0ooooSP3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-8.33351, -0.198145, \
0.389301, 0.0156612}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises", "ExerciseMain"],

Cell[CellGroupData[{

Cell["H\[EAcute]non maps for various parameters", "ExerciseTitle"],

Cell[TextData[{
  "Display and characterize the attractors for the H\[EAcute]non map with \
various choices of its parameters.  The following choices of ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  " provide some variety, but you might be able to find more interesting \
behaviors also.  Be sure to disregard transients.\na) {0.5,0.3}\tb) {1.0,0.3}\
\tc) {1.1,0.3}\td) ",
  Cell[BoxData[
      \({\[Pi]\/3, \[Pi]\/10}\)]]
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Ikeda map", "ExerciseTitle"],

Cell[TextData[{
  "Display the strange attractor for the Ikeda map defined by ",
  Cell[BoxData[
      \(TraditionalForm\`{x, 
          y} \[Rule] {0.97\  + \ 0.9 \((x\ Cos[\[Tau]] - y\ Sin[\[Tau]])\), 
          0.9 \((x\ Sin[\[Tau]] + y\ Cos[\[Tau]])\)}\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] = 0.4\  - \ 6\/\(1 + x\^2 + y\^2\)\)]],
  "."
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Gingerbread man", "ExerciseTitle"],

Cell["Devaney proposed a two-dimensional map", "ExerciseText"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\t\t\)\(x\_\(n + 1\) = \(1 - y\_n + \  | 
          x\_n | \n\t\ty\_\(n + 1\) = x\_n\)\)\)\)], "ExerciseText",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "whose set of iterates bears a remarkable resemblance to a gingerbread man. \
 [Ref.:  R.L. Devaney, in ",
  StyleBox["The Science of Fractal Images",
    FontSlant->"Italic"],
  ", edited by H.O. Peitgen and D. Saupe, (Springer-Verlag, N.Y., 1988), p. \
135 ff.]"
}], "ExerciseText"],

Cell[TextData[{
  "a) Display ",
  Cell[BoxData[
      \(TraditionalForm\`10\^4\)]],
  " iterates of {-0.1,0.1} as a list plot.  You should see figure with a \
vaguely humanoid outline that has hexagonal voids in the middle of the torso, \
head, and four limbs."
}], "ExerciseText"],

Cell["\<\
b) Show that the vertices of the hexagonal void in the torso form a period-6 \
orbit.\
\>", "ExerciseText"],

Cell["\<\
c) Show that the centers of the hexagonal voids in the head and limbs belong \
to a period-5 orbit.\
\>", "ExerciseText"],

Cell["\<\
d) Show that other points within the voids belong to bi-periodic orbits with \
6\[Times]5 structure.\
\>", "ExerciseText"],

Cell[TextData[{
  "e) Display ",
  Cell[BoxData[
      \(TraditionalForm\`10\^3\)]],
  " iterates of {4.01,7.99}, a point just inside the border.  The chaotic \
orbit of this point should produce a \"chalk outline\"."
}], "ExerciseText"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 952}},
WindowToolbars->"EditBar",
WindowSize->{1392, 912},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowCellLabel->False,
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->PaperWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}, {
        Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {0, 0}},
    CellGroupingRules->"TitleGrouping",
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    ShowCellBracket->True,
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{9, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->0.5,
    CellMargins->{{25, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.700008, 0.4]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{25, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{25, 0}, {6, 6}}],
  
  Cell[StyleData["Input", "Printout"],
    CellFrame->0.5,
    CellMargins->{{25, 0}, {6, 6}},
    Background->None]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->True,
    CellMargins->{{25, 10}, {8, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{25, Inherited}, {12, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{10, 4}, {2, 10}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{12, 10}, {2, 12}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {1, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->9],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{9, 0}, {4, 12}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    CellMargins->{{10, 10}, {40, 2}},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{12, 10}, {50, 2}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Example",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Definition",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Definition", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Theorem",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Theorem", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.4]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caution"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Caution",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.996109, 0, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Caution", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Caution", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Caution", "Printout"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Advice"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Advice",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0, 1, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Advice", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Advice", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Advice", "Printout"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->"NormalGrouping",
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseMain"],
    CellFrame->{{6, 0}, {0, 1}},
    CellMargins->{{12, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseMain", "Presentation"],
    CellMargins->{{18, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["ExerciseMain", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["ExerciseMain", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseTitle"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseTitle", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["ExerciseTitle", "Condensed"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["ExerciseTitle", "Printout"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{32, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExcersiceText",
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{32, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{32, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{32, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Problem"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Problem", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Problem", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Problem", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{12, 10}, {Inherited, 6}},
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{13, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{62, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{74, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    CellMargins->{{52, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"]],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"]],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 83, 2, 81, "Title"],
Cell[1862, 57, 455, 15, 85, "Author"],

Cell[CellGroupData[{
Cell[2342, 76, 31, 0, 83, "Section"],
Cell[2376, 78, 116, 3, 41, "Text"],
Cell[2495, 83, 200, 4, 68, "DisplayFormula"],
Cell[2698, 89, 1578, 37, 171, "Text"],

Cell[CellGroupData[{
Cell[4301, 130, 35, 0, 55, "Subsubsection"],
Cell[4339, 132, 265, 7, 41, "Text"],
Cell[4607, 141, 188, 6, 41, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4844, 153, 33, 0, 51, "Section"],
Cell[4880, 155, 119, 2, 99, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5036, 162, 33, 0, 51, "Section"],
Cell[5072, 164, 89, 1, 74, "Input"],
Cell[5164, 167, 114, 2, 73, "Input"],
Cell[5281, 171, 245, 4, 113, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5563, 180, 42, 0, 51, "Section"],
Cell[5608, 182, 204, 4, 41, "Text"],
Cell[5815, 188, 81, 1, 73, "Input"],

Cell[CellGroupData[{
Cell[5921, 193, 415, 7, 125, "Input"],
Cell[6339, 202, 236147, 10710, 394, 189062, 10124, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[242501, 10915, 277, 4, 67, "Text"],

Cell[CellGroupData[{
Cell[242803, 10923, 110, 2, 73, "Input"],
Cell[242916, 10927, 35606, 728, 279, 4967, 345, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[278537, 11658, 174, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[278736, 11665, 203, 3, 125, "Input"],
Cell[278942, 11670, 29252, 621, 279, 4934, 316, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[308243, 12297, 33, 0, 54, "ExerciseMain"],

Cell[CellGroupData[{
Cell[308301, 12301, 66, 0, 58, "ExerciseTitle"],
Cell[308370, 12303, 454, 10, 105, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[308861, 12318, 34, 0, 58, "ExerciseTitle"],
Cell[308898, 12320, 388, 10, 49, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[309323, 12335, 40, 0, 58, "ExerciseTitle"],
Cell[309366, 12337, 62, 0, 41, "ExerciseText"],
Cell[309431, 12339, 198, 4, 63, "ExerciseText"],
Cell[309632, 12345, 302, 7, 67, "ExerciseText"],
Cell[309937, 12354, 282, 7, 67, "ExerciseText"],
Cell[310222, 12363, 117, 3, 41, "ExerciseText"],
Cell[310342, 12368, 131, 3, 41, "ExerciseText"],
Cell[310476, 12373, 132, 3, 41, "ExerciseText"],
Cell[310611, 12378, 237, 6, 41, "ExerciseText"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

