(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1312143,      24964]*)
(*NotebookOutlinePosition[   1349416,      26282]*)
(*  CellTagsIndexPosition[   1349307,      26275]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Calculus", "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "from ",
  StyleBox[ButtonBox["Essential Mathematica for Students of Science",
    Active->False,
    ButtonData:>{
      URL[ 
      "http://www.physics.umd.edu/courses/CourseWare/EssentialMathematica/"], 
      None},
    Active->False,
    ButtonStyle->"Hyperlink"],
    Active->False],
  "\n\[Copyright] James J. Kelly, 1998\nLast revised: January, 2006"
}], "Author",
  Active->True,
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell["\<\
In this notebook we present some of the basic techniques for performing \
standard operations in calculus, including differentiation, Taylor expansion, \
and integration.  Both symbolic and numerical integration are covered and \
brief discussions of line and contour integration are given also.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[BoxData[{
    \(\(ClearAll["\<Global`*\>"];\)\), "\n", 
    \(Off[General::spell, \ General::spell1]\)}], "Input"],

Cell[BoxData[
    \(Needs["\<Utilities`Notation`\>"]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Differentiation", "Section"],

Cell[CellGroupData[{

Cell["Partial derivatives", "Subsection"],

Cell[TextData[{
  "Partial derivatives are produced by the function ",
  ButtonBox["D",
    ButtonStyle->"RefGuideLink"],
  StyleBox["[", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["f,x", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["]", "InlineInput",
    FontWeight->"Bold"],
  ", where the expression ",
  StyleBox["f", "InlineInput"],
  " should be either an implicit or explicit function of the variable ",
  StyleBox["x", "InlineInput"],
  " for which the derivative is sought.  Partial derivatives with respect to \
several variables simultaneously are obtained by using a sequence of \
variables in the argument list.  Multiple derivatives with respect to the \
same variable are specified by arguments of the form ",
  StyleBox["{x,n}", "InlineInput"],
  " where ",
  StyleBox["n", "InlineInput"],
  " is the degree of differentiation or by including ",
  StyleBox["n",
    FontSlant->"Italic"],
  " instances of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " in the sequence of differentiation variables.  "
}], "Text"],

Cell[TextData[{
  "There are many equivalent input forms for this function to reflect common \
usages.  The prime notation is convenient for writing ordinary differential \
equations and can be entered directly from the keyboard; a slightly more \
appealing form is obtained by entering \[EscapeKey]'\[EscapeKey] in a \
superscript box.  The ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_\({x, n}, {y, m}\)f[x, y]\)]],
  " notation is more flexible and more rigorous, superseding the traditional \
",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^\(n + m\)f[x, y]\/\(\[PartialD]\^n x \
\[PartialD]\^m y\)\)]],
  " notation with its cumbersome fractions which do not divide out.  That \
traditional notation cannot be used without constructing special notation \
palettes first.  The partial derivative symbol is entered as \[EscapeKey]pd\
\[EscapeKey]."
}], "Text"],

Cell[BoxData[
    \(D[f[x], 
        x] = \(\[PartialD]f[x]\/\[PartialD]x = \(\(f'\)[
            x] = \(\(f\^\[Prime]\)[
              x] = \[PartialD]\_x f[x]\)\)\)\)], "InlineInput",
  Evaluatable->False],

Cell[BoxData[
    \(D[f[x], {x, n}] = 
      \(\[PartialD]\^n f[x]\/\[PartialD]x\^n = \[PartialD]\_{x, n}f[x]\)\)], 
  "InlineInput",
  Evaluatable->False],

Cell[BoxData[
    \(D[f[x, y], x, y] = 
      \(\[PartialD]\^2 f[x, y]\/\(\[PartialD]x \[PartialD]y\) = 
        \[PartialD]\_\(x, y\)f[x, y]\)\)], "InlineInput",
  Evaluatable->False],

Cell[BoxData[
    \(D[f[x, y], {x, n}, {y, m}] = 
      \(\[PartialD]\^\(n + m\)f[x, y]\/\(\[PartialD]\^n x 
            \[PartialD]\^m y\) = \[PartialD]\_\({x, n}, {y, m}\)f[x, y]\)\)], 
  "InlineInput",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[f[x], x]\)], "Input"],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "x", "]"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[f[x, y], {x, n}, {y, m}]\)], "Input"],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["f", 
        TagBox[\((n, m)\),
          Derivative],
        MultilineFunction->None], "[", \(x, y\), "]"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[PartialD]\_\({x, n}, {y, m}\)f[x, y]\)], "Input"],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["f", 
        TagBox[\((n, m)\),
          Derivative],
        MultilineFunction->None], "[", \(x, y\), "]"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[PartialD]\_\(x, x\)f[x]\)], "Input"],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["f", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "x", "]"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[PartialD]\_{x, 4}f[x]\)], "Input"],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["f", 
        TagBox[\((4)\),
          Derivative],
        MultilineFunction->None], "[", "x", "]"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\(\(f'\)'\)'\)'\)[x]\)], "Input"],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["f", 
        TagBox[\((4)\),
          Derivative],
        MultilineFunction->None], "[", "x", "]"}]], "Output"]
}, Closed]],

Cell["Note that entering ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(f\^\((4)\)\)[X]\)], "Input"],

Cell[BoxData[
    \(\(f\^4\)[X]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "with an exponent box returns a power instead of a derivative, parentheses \
notwithstanding.  You would need to develop special notation palettes to use \
traditional notations like ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\((4)\)\)[x]\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^4 f/\[PartialD]x\^4\)]],
  "."
}], "Text"],

Cell[TextData[{
  "D",
  StyleBox[
  " employs all the basic rules for differentiating products and quotients \
and uses the chain rule.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    \(Clear[f, g]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[f[x]\ g[x], x]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(g[x]\), " ", 
        RowBox[{
          SuperscriptBox["f", "\[Prime]",
            MultilineFunction->None], "[", "x", "]"}]}], "+", 
      RowBox[{\(f[x]\), " ", 
        RowBox[{
          SuperscriptBox["g", "\[Prime]",
            MultilineFunction->None], "[", "x", "]"}]}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[f[x\ y], x]\)], "Input"],

Cell[BoxData[
    RowBox[{"y", " ", 
      RowBox[{
        SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", \(x\ y\), "]"}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[f[g[x]], x]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", \(g[x]\), "]"}], " ", 
      RowBox[{
        SuperscriptBox["g", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[\[Integral]\_a\%x f[t] \[DifferentialD]t, x]\)], "Input"],

Cell[BoxData[
    \(f[x]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[\[Integral]\_a\%\(Cos[x]\)f[t] \[DifferentialD]t, x]\)], "Input"],

Cell[BoxData[
    \(\(-f[Cos[x]]\)\ Sin[x]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "It is always important to remember that because ",
  StyleBox["D", "InlineInput",
    FontWeight->"Bold"],
  " evaluates partial derivatives it treats all symbols that are not declared \
variable as constants.  Symbols are declared as variable either by inclusion \
in the argument list or by means of the option ",
  StyleBox["NonConstants\[Rule]", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["list", "InlineInput",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["  ",
    FontWeight->"Bold"],
  "Suppose that ",
  StyleBox["x",
    FontSlant->"Italic"],
  " is an implicit function of ",
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox[",",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "where ",
  StyleBox["x",
    FontSlant->"Italic"],
  " is the position of a parcel of fluid and ",
  StyleBox["t",
    FontSlant->"Italic"],
  " is time.  The expression"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[f[x, t], t]\)], "Input"],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["f", 
        TagBox[\((0, 1)\),
          Derivative],
        MultilineFunction->None], "[", \(x, t\), "]"}]], "Output"]
}, Closed]],

Cell[TextData[{
  "then evaluates the derivative of ",
  StyleBox["f",
    FontSlant->"Italic"],
  " with respect to ",
  StyleBox["t",
    FontSlant->"Italic"],
  " at a fixed position, whereas"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[f[x, t], t, NonConstants \[Rule] x]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["f", 
          TagBox[\((0, 1)\),
            Derivative],
          MultilineFunction->None], "[", \(x, t\), "]"}], "+", 
      RowBox[{\(D[x, t, NonConstants \[Rule] {x}]\), " ", 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x, t\), "]"}]}]}]], "Output"]
}, Closed]],

Cell[TextData[{
  "evaluates the convective derivative for a particular moving parcel of \
fluid.  Of course, the same effect is achieved by declaring ",
  StyleBox["x",
    FontSlant->"Italic"],
  " to be an explicit function of ",
  StyleBox["t",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[f[x[t], t], t]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["f", 
          TagBox[\((0, 1)\),
            Derivative],
          MultilineFunction->None], "[", \(x[t], t\), "]"}], "+", 
      RowBox[{
        RowBox[{
          SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x[t], t\), "]"}]}]}]], "Output"]
}, Closed]],

Cell[TextData[{
  "Locate the extrema of ",
  Cell[BoxData[
      \(TraditionalForm\`x\^3 - 2  x\^2 - 10  x + 5\)]],
  "."
}], "Exercise"],

Cell[TextData[{
  "Find the maximum of ",
  Cell[BoxData[
      \(TraditionalForm\`x\^4\/\(\[ExponentialE]\^x + 1\)\)]],
  " for positive ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " (both position and value).  [Hint: simplify the equation first to \
eliminate the trivial but spurious solution.  Then use Solve, NSolve, or \
FindRoot; all should agree!]"
}], "Exercise"],

Cell["Jacobian for coordinate transformations", "Exercise"],

Cell[TextData[{
  "Suppose that the Cartesian coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`{x, y, z}\)]],
  " are represented in terms of a new set of variables ",
  Cell[BoxData[
      \(TraditionalForm\`{u, v, w}\)]],
  " such that ",
  Cell[BoxData[
      \(TraditionalForm\`x = f[u, v, w]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`y = g[u, v, w]\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`z = h[u, v, w]\)]],
  ".  Multivariate calculus tell us that the volume element is transformed \
according to ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x\ \[DifferentialD]y\ \
\[DifferentialD]z\  \[Rule] \ \[LeftDoubleBracketingBar]J[u, v, 
              w]\ \[RightDoubleBracketingBar] \[DifferentialD]u\ \
\[DifferentialD]v\ \[DifferentialD]w\)]],
  " where "
}], "ExerciseText"],

Cell[BoxData[
    FormBox[
      RowBox[{\(J[u, v, w]\), "=", 
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(\[PartialD]f\/\[PartialD]u\), \
\(\[PartialD]f\/\[PartialD]v\), \(\[PartialD]f\/\[PartialD]w\)},
              {\(\[PartialD]g\/\[PartialD]u\), \
\(\[PartialD]g\/\[PartialD]v\), \(\[PartialD]g\/\[PartialD]w\)},
              {\(\[PartialD]h\/\[PartialD]u\), \
\(\[PartialD]h\/\[PartialD]v\), \(\[PartialD]h\/\[PartialD]w\)}
              }], "\[NegativeThinSpace]", ")"}]}], TraditionalForm]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "is the ",
  StyleBox["Jacobian",
    FontSlant->"Italic"],
  " matrix and ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftDoubleBracketingBar]J\
\[RightDoubleBracketingBar]\)]],
  " indicates its determinant.  Write a simple function, using ",
  StyleBox["Outer", "InlineInput",
    FontWeight->"Bold"],
  " and ",
  StyleBox["D", "InlineInput",
    FontWeight->"Bold"],
  ", that constructs Jacobian matrices.  Test your function by evaluating the \
determinant of the Jacobian for spherical coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`{x, y, z} \[Rule] {r\ Sin[\[Theta]] Cos[\[Phi]], 
          r\ Sin[\[Theta]]\ Sin[\[Phi]], \ r\ Cos[\[Theta]]}\)]],
  "."
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Total derivatives", "Subsection"],

Cell[TextData[{
  "The total derivative ",
  ButtonBox["Dt",
    ButtonStyle->"RefGuideLink"],
  StyleBox["[", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["f,x", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["]", "InlineInput",
    FontWeight->"Bold"],
  " evaluates the derivative ",
  Cell[BoxData[
      \(TraditionalForm\`\(d\[InvisibleComma]f\)\/\(d\[InvisibleComma]x\)\)]],\

  " by interpreting any variable that appears in the expression ",
  StyleBox["f",
    FontSlant->"Italic"],
  " as a function of ",
  StyleBox["x",
    FontSlant->"Italic"],
  ".  Consider, for example, a function of position ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and time ",
  StyleBox["t",
    FontSlant->"Italic"],
  " where ",
  StyleBox["x",
    FontSlant->"Italic"],
  " is an implicit function of time.  The total derivative with respect to \
time "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dt[f[x, t], t]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["f", 
          TagBox[\((0, 1)\),
            Derivative],
          MultilineFunction->None], "[", \(x, t\), "]"}], "+", 
      RowBox[{\(Dt[x, t]\), " ", 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x, t\), "]"}]}]}]], "Output"]
}, Closed]],

Cell[TextData[{
  "contains two contributions, one arising from the explicit dependence upon \
",
  StyleBox["t",
    FontSlant->"Italic"],
  " and a second arising from the implicit dependence of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " upon ",
  StyleBox["t",
    FontSlant->"Italic"],
  ".  Similarly, multiple or mixed derivatives can be defined also."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dt[f[x, t], x, x, t]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(Dt[t, {x, 2}]\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox["f", 
                TagBox[\((0, 2)\),
                  Derivative],
                MultilineFunction->None], "[", \(x, t\), "]"}], "+", 
            RowBox[{\(Dt[x, t]\), " ", 
              RowBox[{
                SuperscriptBox["f", 
                  TagBox[\((1, 1)\),
                    Derivative],
                  MultilineFunction->None], "[", \(x, t\), "]"}]}]}], ")"}]}],
       "+", 
      RowBox[{
        SuperscriptBox["f", 
          TagBox[\((2, 1)\),
            Derivative],
          MultilineFunction->None], "[", \(x, t\), "]"}], "+", 
      RowBox[{\(Dt[t, x]\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox["f", 
                TagBox[\((1, 2)\),
                  Derivative],
                MultilineFunction->None], "[", \(x, t\), "]"}], "+", 
            RowBox[{\(Dt[x, t]\), " ", 
              RowBox[{
                SuperscriptBox["f", 
                  TagBox[\((2, 1)\),
                    Derivative],
                  MultilineFunction->None], "[", \(x, t\), "]"}]}]}], ")"}]}],
       "+", 
      RowBox[{\(Dt[t, x]\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox["f", 
                TagBox[\((1, 2)\),
                  Derivative],
                MultilineFunction->None], "[", \(x, t\), "]"}], "+", 
            RowBox[{\(Dt[t, x]\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["f", 
                      TagBox[\((0, 3)\),
                        Derivative],
                      MultilineFunction->None], "[", \(x, t\), "]"}], "+", 
                  RowBox[{\(Dt[x, t]\), " ", 
                    RowBox[{
                      SuperscriptBox["f", 
                        TagBox[\((1, 2)\),
                          Derivative],
                        MultilineFunction->None], "[", \(x, t\), "]"}]}]}], 
                ")"}]}], "+", 
            RowBox[{\(Dt[x, t]\), " ", 
              RowBox[{
                SuperscriptBox["f", 
                  TagBox[\((2, 1)\),
                    Derivative],
                  MultilineFunction->None], "[", \(x, t\), "]"}]}]}], ")"}]}],
       "+", 
      RowBox[{\(Dt[x, t]\), " ", 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((3, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x, t\), "]"}]}]}]], "Output"]
}, Closed]],

Cell["A closely related quantity is the total differential ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dt[f[x, y, z, t]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(Dt[t]\), " ", 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((0, 0, 0, 1)\),
              Derivative],
            MultilineFunction->None], "[", \(x, y, z, t\), "]"}]}], "+", 
      RowBox[{\(Dt[z]\), " ", 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((0, 0, 1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x, y, z, t\), "]"}]}], "+", 
      RowBox[{\(Dt[y]\), " ", 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((0, 1, 0, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x, y, z, t\), "]"}]}], "+", 
      RowBox[{\(Dt[x]\), " ", 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((1, 0, 0, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x, y, z, t\), 
          "]"}]}]}]], "Output"]
}, Closed]],

Cell[TextData[{
  "which represents the differential change in a function arising from \
differential changes in each variable that is not explicitly constant.  One \
or more variables can be held constant by using the option ",
  StyleBox["Constants", "InlineInput",
    FontWeight->"Bold"],
  " to specify a list of constants."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dt[f[x, y, z, t], Constants \[Rule] {x, y}]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(Dt[t, Constants \[Rule] {x, y}]\), " ", 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((0, 0, 0, 1)\),
              Derivative],
            MultilineFunction->None], "[", \(x, y, z, t\), "]"}]}], "+", 
      RowBox[{\(Dt[z, Constants \[Rule] {x, y}]\), " ", 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((0, 0, 1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x, y, z, t\), 
          "]"}]}]}]], "Output"]
}, Closed]],

Cell["Alternatively, we can eliminate selected differentials", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dt[f[x, y, z, t]] /. {Dt[x] \[Rule] 0, Dt[y] \[Rule] 0}\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(Dt[t]\), " ", 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((0, 0, 0, 1)\),
              Derivative],
            MultilineFunction->None], "[", \(x, y, z, t\), "]"}]}], "+", 
      RowBox[{\(Dt[z]\), " ", 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((0, 0, 1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x, y, z, t\), 
          "]"}]}]}]], "Output"]
}, Closed]],

Cell["\<\
and obtain a slightly simpler result that does not propagate the option in \
the result.  The best choice depends upon the application.\
\>", "Text"],

Cell["\<\
However, if expressions involve symbols which should always be constant, such \
as constants of nature, it is best to declare them constants by setting the \
appropriate attribute.\
\>", "Text"],

Cell[BoxData[
    \(SetAttributes[{\[HBar], m}, Constant]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dt[\(-\(\[HBar]\^2\/\(2  m\)\)\) \[PartialD]\_{x, 2}\[Psi][x, t], 
      t]\)], "Input"],

Cell[BoxData[
    RowBox[{"-", 
      FractionBox[
        RowBox[{\(\[HBar]\^2\), " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Psi]", 
                  TagBox[\((2, 1)\),
                    Derivative],
                  MultilineFunction->None], "[", \(x, t\), "]"}], "+", 
              RowBox[{\(Dt[x, t]\), " ", 
                RowBox[{
                  SuperscriptBox["\[Psi]", 
                    TagBox[\((3, 0)\),
                      Derivative],
                    MultilineFunction->None], "[", \(x, t\), "]"}]}]}], 
            ")"}]}], \(2\ m\)]}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: particle in uniform gravity", "Subsubsection"],

Cell["The energy of a particle in uniform gravity has the form ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ClearAll[m, g, x, y, z, t];\)\), "\[IndentingNewLine]", 
    \(energy\  = \ 
      m\ g\ z[t]\  + \ \(1\/2\) 
          m\ \((\(x\^\[Prime]\)[t]\^2 + \(y\^\[Prime]\)[t]\^2 + \(z\^\[Prime]\
\)[t]\^2)\)\)}], "Input"],

Cell[BoxData[
    RowBox[{\(g\ m\ z[t]\), "+", 
      RowBox[{\(1\/2\), " ", "m", " ", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["z", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"]}], 
          ")"}]}]}]], "Output"]
}, Closed]],

Cell["\<\
The time dependence of the energy is given by the total derivative\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dt[energy, t]\)], "Input"],

Cell[BoxData[
    RowBox[{\(m\ Dt[g, t]\ z[t]\), "+", \(g\ Dt[m, t]\ z[t]\), "+", 
      RowBox[{"g", " ", "m", " ", 
        RowBox[{
          SuperscriptBox["z", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(Dt[m, t]\), " ", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["z", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"]}], ")"}]}], 
      "+", 
      RowBox[{\(1\/2\), " ", "m", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"2", " ", 
              RowBox[{
                SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], " ", 
              RowBox[{
                SuperscriptBox["x", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{
                SuperscriptBox["z", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], " ", 
              RowBox[{
                SuperscriptBox["z", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}]}], 
          ")"}]}]}]], "Output"]
}, Closed]],

Cell[TextData[{
  "However, this result includes derivatives of mass with respect to time \
which should not appear for a simple particle that neither sheds nor accretes \
mass.  We specify that ",
  StyleBox["m",
    FontSlant->"Italic"],
  " and ",
  StyleBox["g",
    FontSlant->"Italic"],
  " are constants using the option ",
  StyleBox["Constants", "InlineInput",
    FontWeight->"Bold"],
  ", such that"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dt[energy, t, Constants \[Rule] {m, g}]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"g", " ", "m", " ", 
        RowBox[{
          SuperscriptBox["z", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{\(1\/2\), " ", "m", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"2", " ", 
              RowBox[{
                SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], " ", 
              RowBox[{
                SuperscriptBox["x", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{
                SuperscriptBox["z", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], " ", 
              RowBox[{
                SuperscriptBox["z", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}]}], 
          ")"}]}]}]], "Output"]
}, Closed]],

Cell["\<\
Furthermore, Newton's second law can be used to simplify this result\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dt[energy, t, 
        Constants \[Rule] {m, g}] /. {\(x\^\[DoublePrime]\)[t] \[Rule] 
          0, \(y\^\[DoublePrime]\)[t] \[Rule] 
          0, \(z\^\[DoublePrime]\)[t] \[Rule] \(-g\)}\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Closed]],

Cell["\<\
The dependence of the energy on height is then seen to vanish; in other \
words, energy is conserved.\
\>", "Text"],

Cell[TextData[{
  "Fluid flows at rate ",
  Cell[BoxData[
      \(TraditionalForm\`Q = \(\[Pi]\ p\ r\^4\)\/\(8  \[ScriptL]\ \
\[Eta]\)\)]],
  " through a cylindrical tube with radius ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " and length \[ScriptL] subject to a pressure differential ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  ".  The coefficient of viscosity is \[Eta].  Suppose that the length of the \
tube is constant but that the radius expands at rate ",
  Cell[BoxData[
      \(TraditionalForm\`r\& . \)]],
  " as the pressure differential decreases at rate ",
  Cell[BoxData[
      \(TraditionalForm\`p\& . \)]],
  ".  Find an expression for the time rate of change for ",
  Cell[BoxData[
      \(TraditionalForm\`Q\)]],
  ".  Under what conditions is ",
  Cell[BoxData[
      \(TraditionalForm\`Q\)]],
  " constant?"
}], "Exercise"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Implicit differentiation", "Subsection"],

Cell[TextData[{
  "Suppose that two variables, ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", are connected by an equation of constraint, ",
  StyleBox["eq",
    FontSlant->"Italic"],
  ".  Evaluation of ",
  StyleBox["Dt[", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["eq", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["]", "InlineInput",
    FontWeight->"Bold"],
  " will then produce a relationship between variations of ",
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Dt[", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["x", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["]", "InlineInput",
    FontWeight->"Bold"],
  ", and variations of ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Dt[", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["y", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["]", "InlineInput",
    FontWeight->"Bold"],
  ".  For example, suppose that a ladder of length \[ScriptL] leans against a \
wall but that the base of the ladder slides along the ground.  To compare the \
rate the top falls with the rate the bottom slides, we differentiate the \
equation"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(eq\  = \ x\^2 + y\^2 \[Equal] \[ScriptL]\^2;\)\), "\n", 
    \(newEq = Dt[eq]\)}], "Input"],

Cell[BoxData[
    \(2\ x\ Dt[x] + 2\ y\ Dt[y] \[Equal] 
      2\ \[ScriptL]\ Dt[\[ScriptL]]\)], "Output"]
}, Closed]],

Cell["\<\
that evaluates the length of the ladder in terms of the coordinates of its \
ends.  Requiring the length to be constant then implies\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = \(Solve[newEq /. Dt[\[ScriptL]] \[Rule] 0, 
          Dt[y]]\)\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \({Dt[y] \[Rule] \(-\(\(x\ Dt[x]\)\/y\)\)}\)], "Output"]
}, Closed]],

Cell["\<\
We can express the result in terms of the position of the bottom ladder by \
using the solution to the constraint equation\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol\[LeftDoubleBracket]1, 
        2\[RightDoubleBracket]\  /. \(Solve[eq, 
          y]\)\[LeftDoubleBracket]2\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \(\(-\(\(x\ Dt[x]\)\/\@\(\(-x\^2\) + \[ScriptL]\^2\)\)\)\)], "Output"]
}, Closed]],

Cell["\<\
Although we could have solved the equation of constraint first and then \
differentiated the result, we chose the approach above in order to illustrate \
the technique of implicit differentiation with a simple example.\
\>", "Text"],

Cell[TextData[{
  "A ",
  StyleBox["lemniscate",
    FontSlant->"Italic"],
  " is described by the equation ",
  Cell[BoxData[
      \(TraditionalForm\`\((x\^2 + y\^2)\)\^2 \[Equal] x\^2 - y\^2\)]],
  ".  Use ImplicitPlot to display this curve and implicit differentiation to \
find the points at which its tangent is horizontal."
}], "Exercise"],

Cell["\<\
A person who is 6 ft tall walks toward a street lamp that is 20 ft above its \
base.  How fast does that person's shadow shrink?  Use similar triangles to \
establish a constraint equation and implicit differentiation to relate the \
length change to the distance walked.\
\>", "Exercise"]
}, Closed]],

Cell[CellGroupData[{

Cell["Derivatives as functionals", "Subsection"],

Cell[TextData[{
  StyleBox["D", "InlineInput"],
  StyleBox[" will evaluate the derivatives for any function for which ",
    FontWeight->"Plain"],
  StyleBox["Mathematica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" knows the necessary rules, but when rules are not available it \
returns a generic ",
    FontWeight->"Plain"],
  ButtonBox["Derivative",
    ButtonStyle->"RefGuideLink"],
  StyleBox[" object.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g = \[PartialD]\_\({x, n}, {y, m}\)f[x, y]\)], "Input"],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["f", 
        TagBox[\((n, m)\),
          Derivative],
        MultilineFunction->None], "[", \(x, y\), "]"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullForm[g]\)], "Input"],

Cell[BoxData[
    TagBox[
      StyleBox[\(\(\(Derivative[n, m]\)[f]\)[x, y]\),
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output"]
}, Closed]],

Cell[TextData[{
  "Notice that ",
  StyleBox["Derivative[n,m][f]", "InlineInput",
    FontWeight->"Bold"],
  " represents a pure function whose arguments are ",
  StyleBox["[x,y]", "InlineInput",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Head[g] // FullForm\)], "Input"],

Cell[BoxData[
    TagBox[
      StyleBox[\(\(Derivative[n, m]\)[f]\),
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f\^\[Prime] // FullForm\)], "Input"],

Cell[BoxData[
    TagBox[
      StyleBox[\(\(Derivative[1]\)[f]\),
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output"]
}, Closed]],

Cell[TextData[{
  "This internal representation of derivatives actually embodies a very \
important concept.  Consider for a moment the traditional notation ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            StyleBox["f",
              "Text"], "\[Prime]"], 
          StyleBox["[",
            "Text"], 
          StyleBox["x",
            "Text"], 
          StyleBox["]",
            "Text"]}], TraditionalForm]]],
  ".  This notation really means"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(f\^\[Prime]\)[
        x] = \ \((\[PartialD]f[t]\/\[PartialD]t)\)\_\(t = x\)\)], \
"DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " is a dummy variable that replaced by the desired argument after the \
derivative is evaluated.  Hence, we interpret ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\[Prime]\)[2]\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(f\^\[Prime]\)[x])\)\_\(x = 2\)\)]],
  " even though no variable appears in the traditional notation.  Thus, \
differentiation is an operator which acts upon a function to produce another \
function.  In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " the result of differentiation is represented by a pure function that can \
be evaluated either for symbolic or numerical arguments.  The operation of \
differentiation itself can be viewed as a pure function whose argument is a \
function."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Head[g]\)], "Input"],

Cell[BoxData[
    SuperscriptBox["f", 
      TagBox[\((n, m)\),
        Derivative],
      MultilineFunction->None]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Head[Head[g]]\)], "Input"],

Cell[BoxData[
    \(Derivative[n, m]\)], "Output"]
}, Closed]],

Cell["\<\
By this means one can view the symbolic differentiation rules associated with \
standard mathematical functions.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f = Sin\^\[Prime]\)], "Input"],

Cell[BoxData[
    \(Cos[#1] &\)], "Output"]
}, Closed]],

Cell["\<\
The result is a pure function which can be applied to any argument.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({f[x], f[\[Pi]\/2]}\)], "Input"],

Cell[BoxData[
    \({Cos[x], 0}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[f[x], x]\)], "Input"],

Cell[BoxData[
    \(Sin[x]\)], "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Locating minima", "Section"],

Cell[CellGroupData[{

Cell["Using FindMinimum", "Subsection"],

Cell[TextData[{
  "The extrema of a function (maxima, minima, and inflection points) can be \
determined by solving equations, either symbolically or numerically, that set \
first derivatives to zero and then ascertaining the characteristics of the \
second derivatives.  Symbolic methods will usually reveal all extrema, while \
numerical methods search for extrema near a specified starting point.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " provides a built-in function ",
  ButtonBox["FindMinimum",
    ButtonStyle->"RefGuideLink"],
  " which searches for a local minimum near the starting point automatically, \
without the user having to establish the equations for the first derivative \
or to test the second.  The result is usually the nearest minimum, which may \
not be the absolute minimum of the function \[LongDash] it is simply a nearby \
local minimum.  If you need an absolute minimum, it is usually necessary to \
examine the function graphically in order to supply a reasonably good \
starting value or set of starting values.  You also need to check that the \
result truly is the desired minimum \[LongDash] sometimes ",
  StyleBox["FindMinimum", "InlineInput",
    FontWeight->"Bold"],
  " wanders away from your starting values and sometimes it returns incorrect \
results."
}], "Text"],

Cell[CellGroupData[{

Cell["Example: a function of one variable", "Subsubsection"],

Cell[TextData[{
  "The basic syntax is ",
  StyleBox["FindMinimum[", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["f,", "InlineInput",
    FontSlant->"Italic"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`{x, x\_0}\)], "InlineInput"], "InlineInput"],
  StyleBox["]", "InlineInput",
    FontWeight->"Bold"],
  " where ",
  StyleBox["f ",
    FontSlant->"Italic"],
  " is a function of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  " is the starting value.  The function must evaluate to a real number given \
a numerical value for ",
  StyleBox["x",
    FontSlant->"Italic"],
  ".  You can limit the range of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " by including ",
  StyleBox["xmin",
    FontSlant->"Italic"],
  ",",
  StyleBox[" xmax",
    FontSlant->"Italic"],
  " after ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f];\)\), "\n", 
    \(\(f = \((1 + x - x\^2)\)\ Exp[\(-x\^2\)/4];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[f, {x, \(-5\), 5}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.371896 0.194185 [
[.11905 .3594 -6 -9 ]
[.11905 .3594 6 0 ]
[.30952 .3594 -6 -9 ]
[.30952 .3594 6 0 ]
[.69048 .3594 -3 -9 ]
[.69048 .3594 3 0 ]
[.88095 .3594 -3 -9 ]
[.88095 .3594 3 0 ]
[.4875 .08062 -24 -4.5 ]
[.4875 .08062 0 4.5 ]
[.4875 .17771 -12 -4.5 ]
[.4875 .17771 0 4.5 ]
[.4875 .2748 -24 -4.5 ]
[.4875 .2748 0 4.5 ]
[.4875 .46899 -18 -4.5 ]
[.4875 .46899 0 4.5 ]
[.4875 .56608 -6 -4.5 ]
[.4875 .56608 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .3719 m
.11905 .37815 L
s
[(-4)] .11905 .3594 0 1 Mshowa
.30952 .3719 m
.30952 .37815 L
s
[(-2)] .30952 .3594 0 1 Mshowa
.69048 .3719 m
.69048 .37815 L
s
[(2)] .69048 .3594 0 1 Mshowa
.88095 .3719 m
.88095 .37815 L
s
[(4)] .88095 .3594 0 1 Mshowa
.125 Mabswid
.16667 .3719 m
.16667 .37565 L
s
.21429 .3719 m
.21429 .37565 L
s
.2619 .3719 m
.2619 .37565 L
s
.35714 .3719 m
.35714 .37565 L
s
.40476 .3719 m
.40476 .37565 L
s
.45238 .3719 m
.45238 .37565 L
s
.54762 .3719 m
.54762 .37565 L
s
.59524 .3719 m
.59524 .37565 L
s
.64286 .3719 m
.64286 .37565 L
s
.7381 .3719 m
.7381 .37565 L
s
.78571 .3719 m
.78571 .37565 L
s
.83333 .3719 m
.83333 .37565 L
s
.07143 .3719 m
.07143 .37565 L
s
.02381 .3719 m
.02381 .37565 L
s
.92857 .3719 m
.92857 .37565 L
s
.97619 .3719 m
.97619 .37565 L
s
.25 Mabswid
0 .3719 m
1 .3719 L
s
.5 .08062 m
.50625 .08062 L
s
[(-1.5)] .4875 .08062 1 0 Mshowa
.5 .17771 m
.50625 .17771 L
s
[(-1)] .4875 .17771 1 0 Mshowa
.5 .2748 m
.50625 .2748 L
s
[(-0.5)] .4875 .2748 1 0 Mshowa
.5 .46899 m
.50625 .46899 L
s
[(0.5)] .4875 .46899 1 0 Mshowa
.5 .56608 m
.50625 .56608 L
s
[(1)] .4875 .56608 1 0 Mshowa
.125 Mabswid
.5 .10004 m
.50375 .10004 L
s
.5 .11946 m
.50375 .11946 L
s
.5 .13887 m
.50375 .13887 L
s
.5 .15829 m
.50375 .15829 L
s
.5 .19713 m
.50375 .19713 L
s
.5 .21655 m
.50375 .21655 L
s
.5 .23597 m
.50375 .23597 L
s
.5 .25539 m
.50375 .25539 L
s
.5 .29422 m
.50375 .29422 L
s
.5 .31364 m
.50375 .31364 L
s
.5 .33306 m
.50375 .33306 L
s
.5 .35248 m
.50375 .35248 L
s
.5 .39131 m
.50375 .39131 L
s
.5 .41073 m
.50375 .41073 L
s
.5 .43015 m
.50375 .43015 L
s
.5 .44957 m
.50375 .44957 L
s
.5 .48841 m
.50375 .48841 L
s
.5 .50783 m
.50375 .50783 L
s
.5 .52724 m
.50375 .52724 L
s
.5 .54666 m
.50375 .54666 L
s
.5 .0612 m
.50375 .0612 L
s
.5 .04178 m
.50375 .04178 L
s
.5 .02236 m
.50375 .02236 L
s
.5 .00295 m
.50375 .00295 L
s
.5 .5855 m
.50375 .5855 L
s
.5 .60492 m
.50375 .60492 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36103 m
.04262 .35556 L
.06244 .34739 L
.08255 .3359 L
.10458 .31868 L
.12415 .29863 L
.14509 .27169 L
.18653 .20203 L
.22646 .12197 L
.24474 .08621 L
.26488 .05186 L
.27443 .03855 L
.28471 .02708 L
.29039 .02222 L
.29557 .01877 L
.29807 .01747 L
.30079 .01633 L
.30203 .01591 L
.30336 .01552 L
.30459 .01523 L
.30574 .01502 L
.30699 .01485 L
.30764 .01479 L
.30835 .01474 L
.30909 .01472 L
.30979 .01472 L
.3111 .01477 L
.31233 .01489 L
.31346 .01505 L
.31471 .0153 L
.31603 .01564 L
.31876 .0166 L
.32132 .01781 L
.32716 .02171 L
.33222 .02641 L
.33686 .03181 L
.34733 .04781 L
.35713 .0676 L
.36625 .09003 L
.38695 .15399 L
.426 .30831 L
.44591 .3915 L
.46749 .47416 L
.4776 .50777 L
.4883 .53865 L
.49832 .56258 L
.50748 .57981 L
.51199 .5866 L
.51691 .59269 L
.51961 .59545 L
Mistroke
.52211 .59764 L
.52466 .59949 L
.52705 .6009 L
.52929 .60193 L
.53046 .60236 L
.5317 .60272 L
.53275 .60296 L
.5339 .60316 L
.53495 .60327 L
.53592 .60332 L
.53715 .60331 L
.53831 .60322 L
.53935 .60308 L
.54048 .60287 L
.54171 .60255 L
.54302 .60213 L
.54536 .60114 L
.54775 .59984 L
.55027 .59816 L
.55476 .59437 L
.56487 .58237 L
.57362 .56849 L
.58317 .55014 L
.62378 .44961 L
.66288 .35184 L
.68426 .31031 L
.69406 .29526 L
.70443 .28224 L
.71398 .27288 L
.71905 .26893 L
.72448 .26544 L
.72947 .26291 L
.73403 .26113 L
.73622 .26045 L
.7386 .25984 L
.74087 .25938 L
.74294 .25906 L
.74408 .25892 L
.74527 .25881 L
.74647 .25872 L
.74778 .25867 L
.74892 .25864 L
.75014 .25865 L
.75128 .25868 L
.75233 .25873 L
.75297 .25877 L
.75366 .25882 L
.75489 .25894 L
.75766 .2593 L
.76006 .25973 L
Mistroke
.7627 .26031 L
.76792 .26178 L
.77354 .26382 L
.78369 .2685 L
.82494 .29544 L
.86467 .32303 L
.90288 .34385 L
.92257 .35173 L
.94355 .35815 L
.96036 .36201 L
.97619 .36477 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0.625, 0}, {0, 0.625}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oe`3oool0
0`000000oooo0?ooo`3F0?ooo`00e`3oool300000=H0oooo003G0?ooo`030000003oool0oooo0=H0
oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo003G
0?ooo`030000003oool0oooo0=H0oooo00220?ooo`L00000CP3oool00`000000oooo0?ooo`3F0?oo
o`00P03oool2000000L0oooo0P00001<0?ooo`030000003oool0oooo0=H0oooo001o0?ooo`030000
003oool0oooo00T0oooo0P00001:0?ooo`030000003oool0oooo0=H0oooo001m0?ooo`8000003P3o
ool00`000000oooo0?ooo`170?ooo`<00000eP3oool007/0oooo0P00000A0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool0eP3oool007X0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo0=H0oooo001i0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3F0?ooo`00N03oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0eP3oool007P0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0=H0oooo001g
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`3F
0?ooo`00MP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0eP3oool007D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo0=H0oooo001e0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
@03oool300000=H0oooo001d0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`3F0?ooo`00L`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool0eP3oool007<0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo0=H0oooo001b0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`3F0?ooo`00L@3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0eP3oool00740oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0=H0oooo001`
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3F
0?ooo`00L03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03`0oooo0`00003F0?oo
o`00K`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0eP3oool006h0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo0=H0oooo001^0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`3F0?ooo`00K@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool0eP3oool006d0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0J0?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool00P3oool00`2o
M0000000001d_`050?ooo`050;md0000000000000000001d_ol01`3oool00`000000oooo0?ooo`3F
0?ooo`00K03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01d0oooo00<0W4Q809cO
o`3oool01@3oool00`2oM0000000001d_`040?ooo`070;md0000M;l0oooo0?ooo`3ogi`0B00007Bo
o`060?ooo`030000003oool0oooo0=H0oooo001[0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool07@3oool00`2LB4P0W=oo0?ooo`0A0?ooo`030?noM000M;l0oooo00D0oooo00<00000
0?ooo`3oool0eP3oool006/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0L0?oo
o`0309a8B02Lgol0oooo0140oooo00<0okmd001d_`3oool01@3oool400000=D0oooo001Z0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool0403oool00`2LB00000000000000300000003
0018W03oool0oooo00<0oooo00<0W4Q809cOo`3oool04@3oool00`2LB000M;oo0?ooo`050?ooo`03
0000003oool0oooo0=H0oooo001Z0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
703oool00`2LB4P0W=oo0?ooo`0<0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0
1@3oool00`000000oooo0?ooo`3F0?ooo`00J@3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo01/0oooo00<0W4Q809cOo`3oool0303oool00`3ookl0M01d0;ooo`0:0?ooo`030000003o
ool0oooo0=H0oooo001X0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0603oool0
1@3OW4P000000018W02LB4P0W=oo00d0oooo00<0oono07@0M02oool02P3oool00`000000oooo0?oo
o`3F0?ooo`00J03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01X0oooo00<0gia8
0000B02Lgol03@3oool00`3ookl0M00000000002000000030000M02oool0oooo00D0oooo00<00000
0?ooo`3oool0eP3oool006L0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo0=H0oooo001W0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`3F0?ooo`00IP3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool0eP3oool006H0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0e0?ooo`<00000eP3oool006D0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0=H0oooo001U0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3F0?ooo`00I03oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0eP3oool006@0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0=H0oooo
001S0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`3F0?ooo`00H`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool0eP3oool00680oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo0=H0oooo001R0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool0<`3oool300000=H0oooo001Q0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`3F0?ooo`00H@3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool0eP3oool00600oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0=H0oooo001P0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`3F0?ooo`00G`3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0eP3oool005l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0=H0oooo
001N0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`3F0?ooo`00GP3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0300oooo0`00003F
0?ooo`00G@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool0eP3oool005d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0=H0oooo001L0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`3F0?ooo`00G03oool00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool0eP3oool005/0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0=H0oooo001K0?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3F0?ooo`00FP3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0eP3oool005X0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0=H0oooo
001I0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0;@3oool300000=H0oooo001I
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`3F
0?ooo`00F03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0eP3oool005P0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo0=H0oooo001G0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`3F0?ooo`00E`3oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo01l0oooo00<0okmd0000000000000`0000000`00M;l0oooo0?ooo`040?ooo`030000003o
ool0oooo0=H0oooo001F0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool08P3oool0
0`2LB4P0W=oo0?ooo`070?ooo`030000003oool0oooo0=H0oooo001F0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool08P3oool00`2LB4P0W=oo0?ooo`070?ooo`030000003oool0oooo
0=H0oooo001E0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool08@3oool00`2LB4P0
W=oo0?ooo`070?ooo`@00000e@3oool005D0oooo00<000000?ooo`3oool0D@3oool00`000000oooo
0?ooo`0E0?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool00`3oool00`2LB4P0W=oo
0?ooo`070?ooo`030000003oool0oooo0=H0oooo001D0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool08@3oool00`2LB4P0W=oo0?ooo`070?ooo`030000003oool0oooo0=H0oooo001D
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool08@3oool00`2LB4P0W=oo0?ooo`07
0?ooo`030000003oool0oooo0=H0oooo001C0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool07@3oool01@3OW4P000000018W02LB4P0W=oo00P0oooo00<000000?ooo`3oool0eP3oool0
05<0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0O0?ooo`030=nLB00004P0W=oo
00P0oooo00<000000?ooo`3oool0eP3oool00580oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo0=H0oooo001B0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3F0?ooo`00D@3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo02T0oooo0`00003F0?ooo`00D@3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0eP3oool00500oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0=H0oooo001@0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3F0?ooo`00
C`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
eP3oool004l0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo0=H0oooo001>0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`3F0?ooo`00CP3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool0eP3oool004d0oooo00<000000?ooo`3oool0G@3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo0=H0oooo001<0?ooo`030000003oool0oooo05h0oooo
00<000000?ooo`3oool09`3oool300000=H0oooo001<0?ooo`030000003oool0oooo05h0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`3F0?ooo`00B`3oool00`000000oooo0?ooo`1O
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0eP3oool004/0oooo00<000000?oo
o`3oool0H03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0=H0oooo001:0?ooo`03
0000003oool0oooo0640oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3F0?ooo`00
B@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
eP3oool004T0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo0=H0oooo00180?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`3F0?ooo`00B03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo
02D0oooo0`00003F0?ooo`00A`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0eP3oool004H0oooo00<000000?ooo`3oool0I`3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo0=H0oooo00160?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`3F0?ooo`00A@3oool00`000000oooo0?ooo`1X
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0eP3oool004D0oooo00<000000?oo
o`3oool0J03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0=H0oooo00140?ooo`03
0000003oool0oooo06X0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`3F0?ooo`00
@`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
eP3oool004<0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0S0?ooo`<00000eP3o
ool00480oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo0=H0oooo00120?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`1T0?ooo`X00000J03oool00440oooo00<000000?ooo`3oool0KP3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo0680oooo0P00000:0?ooo`@00000I03oool00400oooo
00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0600oooo
0P00000@0?ooo`800000HP3oool00400oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?oo
o`040?ooo`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`050?ooo`050;md
0000000000000000001d_ol01`3oool00`000000oooo0?ooo`1M0?ooo`<00000503oool200000600
oooo000o0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool00`3oool01P2LB7@0_ooo
0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l0103oool01`2oM00007Bo0?ooo`3oool0
omnL04P0001d_ol01P3oool00`000000oooo0?ooo`1K0?ooo`8000006@3oool2000005h0oooo000o
0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool00P3oool00`3o_g@007Bo0?ooo`02
0?ooo`030=nLB018W=l0oooo00l0oooo00<0okmd001d_`3oool01@3oool00`000000oooo0?ooo`1J
0?ooo`030000003oool0oooo01/0oooo0P00001L0?ooo`00?P3oool00`000000oooo0?ooo`1b0?oo
o`030000003oool0oooo0080oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0?0?oo
o`030?noM000M;l0oooo00D0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo05T0oooo000m0?ooo`030000003oool0oooo06l0oooo00<0W4P000000000
00000`0000001@00B9`0oooo0?ooo`3OW4P0B9cO00<0oooo00<0okmd001d_`3oool03`3oool00`2L
B000M;oo0?ooo`050?ooo`@00000E`3oool00`000000oooo0?ooo`0P0?ooo`800000F@3oool003`0
oooo00<000000?ooo`3oool0M@3oool01P000000oooo0?ooo`3oool0gia804RLg`<0oooo00<0okmd
001d_`3oool02P3oool00`3ookl0M000000000020000000304RLg`3oool0oooo00D0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo05H0oooo000l0?oo
o`030000003oool0oooo07D0oooo00H000000?ooo`3oool0oooo0?noM018W=l30?ooo`030=nLB018
W=l0oooo00X0oooo00<0oono07@0M02oool02P3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo02D0oooo0P00001F0?ooo`00>`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo0080oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`030?oo_`1d07@0_ooo00X0oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo05<0oooo
000j0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00P3oool01@3ookl0M0000000
000004P0W=oo00`0oooo00<0oono07@0000000000P0000000`0007@0_ooo0?ooo`050?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool0:P3oool2000005<0oooo000i0?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1C0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0D03oool003P0oooo00<000000?ooo`3oool0NP3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0;`3oool2
00000500oooo000g0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`1B0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0C@3oool003L0
oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0O0?ooo`<00000D@3oool00`000000
oooo0?ooo`0c0?ooo`800000C@3oool003H0oooo00<000000?ooo`3oool0O@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`1:0?ooo`00=@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0h0?ooo`800000BP3oool003@0oooo00<00000
0?ooo`3oool0O`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`170?ooo`00<`3oool00`000000oooo0?ooo`200?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo04H0oooo000b0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo03h0oooo0P0000160?ooo`00
<@3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo04<0oooo000a0?ooo`030000003o
ool0oooo08<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo0480oooo0P0000130?ooo`00<03oool00`000000oooo0?ooo`240?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo0400oooo000_0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0703oool30000
04/0oooo00<000000?ooo`3oool0AP3oool200000400oooo000^0?ooo`030000003oool0oooo08L0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool0?@3oool002d0oooo00<000000?ooo`3oool0R03oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`0l0?ooo`00:`3oool2000008/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo04`0oooo0P00000l0?ooo`00:P3oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo03T0oooo000Y0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0500oooo0P00000i0?oo
o`009`3oool200000900oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo0580oooo0P00000g0?ooo`009P3oool00`000000oooo0?ooo`0=0?ooo`050?oO
W018000000000000001d_ol0BP3oool00`3ookl0M000000000040000000307Boo`3oool0oooo02X0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`170?ooo`050000003oool0oooo0?oo
_`1d00001@0000000`1d_ol0oooo0?ooo`1;0?ooo`@0000000<0M;oo0?ooo`3oool0<03oool002@0
oooo0P00000B0?ooo`030;md001d_ol0oooo04/0oooo00<0_g@00000M02oool00P3oool00`3OW7@0
W=oo0?ooo`0/0?ooo`030000003oool0oooo01X0oooo0`0000170?ooo`070000003oool0oooo0?oo
o`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo04h0oooo00<0000007Boo`3oool0<P3oool0
02<0oooo00<000000?ooo`3oool04P3oool00`2oM000M;oo0?ooo`1<0?ooo`030?noM00004P0W=oo
0300oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
00<0oooo00<0okmd0000B02Lgol0DP3oool00`2oM00000000000000b0?ooo`008@3oool200000140
oooo00<0gia80000000000000`0000000`1d_ol0oooo0?ooo`1;0?ooo`030?oOW0180000B9cO02l0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00@0
oooo00<0omnL04P00018W=l0C@3oool00`3OW4P00000000000030000000307Boo`00000000000300
oooo000P0?ooo`030000003oool0oooo00P0oooo00<0W4P00000000000000`0000002@00B9`0oooo
0?ooo`3o_g@0001d0;ooo`3oool0_g@007Boo`130?ooo`0309a800000000000000<0000000<004RL
0?ooo`3oool0103oool00`2LB000B9cO0?ooo`0]0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`070?ooo`0309a80018W=l0oooo04/0oooo00H0okmd
0000M02oool0oooo0;md001d_ol30?ooo`800000;P3oool001h0oooo0P00000E0?ooo`050=nLB000
M;l0oooo0;md001d_ol0D@3oool00`2LB7@0_ooo0?ooo`0]0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`080?ooo`0309a8M02oool0oooo04/0oooo
00D0gia8001d_`3oool0_g@007Boo`050?ooo`800000;03oool001`0oooo0P00000H0?ooo`0409a8
0018W=l0_g@007Bood`0oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`0]0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`040?ooo`03
0=nLB01d_ol0oooo0080oooo00<0_g@007Boo`3oool0C03oool0102LB000B9cO0;md001d_ol70?oo
o`800000:P3oool001X0oooo0P00000J0?ooo`040?oOW01804P0B4P007Bood`0oooo00L0okmd0000
M02oool0oooo0?noM00004P0W=oo02h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo00@0oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo04d0
oooo00@0omnL04P0B018B000M;oo2@3oool3000002L0oooo000H0?ooo`8000007@3oool00`3o_g@0
000007Boo`1=0?ooo`050?noM000000000000000B02Lgol0;`3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool01P3oool01@3o_g@000000000000004P0
W=oo04l0oooo00<0okmd0000001d_ol0303oool3000002@0oooo000F0?ooo`800000Y03oool00`00
0000oooo0?ooo`0H0?ooo`<00000@`3oool00`000000oooo0?ooo`1/0?ooo`<000008@3oool001@0
oooo0P00002V0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`1_0?ooo`<000007P3oool00140oooo0`00002X0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool000d0oooo1000
002[0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`1f0?ooo`D000005P3oool000X0oooo0`00002`0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`1l0?ooo`D000004@3oool00;d0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0840oooo1000000=0?oo
o`00_@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0Q@3oool2000000/0oooo002m0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`2C0?ooo`00_P3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool0T`3oool00?l00000/00000010?ooo`002P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00T0oooo000c0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0380
oooo002o0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`2E0?ooo`00_`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool0U@3oool00;l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo09H0oooo002o0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`2F0?ooo`00`03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool0UP3oool00<00oooo00<000000?ooo`3oool0
503oool3000003`0oooo00<000000?ooo`3oool0U`3oool00<00oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo09L0oooo00300?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`2H0?ooo`00`@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0V03oool00<40
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo09T0
oooo00310?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`2I0?ooo`00`@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0V@3oool00<80oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo09X0oooo00320?ooo`030000003oool0oooo0180oooo0`00000i0?oo
o`030000003oool0oooo09X0oooo00320?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`2K0?ooo`00`P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0V`3oool00<<0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo09/0oooo00330?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2L0?ooo`00``3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0W03oool00<<0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo09d0
oooo00340?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`2M0?ooo`00a03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0W@3oool00<@0oooo00<000000?ooo`3oool0403oool3000003D0oooo00<00000
0?ooo`3oool0WP3oool00<@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo09h0oooo00350?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`2O0?ooo`00a@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0W`3oool00<D0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo09l0oooo00350?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`2P0?ooo`00aP3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0X03oool00<H0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0:40
oooo00360?ooo`030000003oool0oooo00h0oooo0`00000b0?ooo`030000003oool0oooo0:40oooo
00360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`2Q0?ooo`00a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0XP3oool00<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo0:80oooo00370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`2S0?ooo`00^@3oool01@3o_g@00000000000000000M;oo00D0
oooo00D0_g@000000000M;l0oooo000000030?ooo`050;md0000000000000000001d_ol01`3oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0:<0oooo002i0?ooo`0609a8M02oool0oooo
0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`020?ooo`040000003oool0_g@0001d_`80oooo
00<0omnL04P0001d_ol01P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0:<0oooo
002h0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool0203oool00`000000oooo0?oo
o`040?ooo`030?noM000M;l0oooo00D0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`2T0?ooo`00^03oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00P0oooo00<00000
0?ooo`3oool0103oool00`3o_g@007Bo0?ooo`050?ooo`@00000;P3oool00`000000oooo0?ooo`2T
0?ooo`00^03oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00P0oooo00<000000?oo
o`3oool0103oool00`2LB000M;oo0?ooo`050?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool0Y@3oool00;P0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`090?ooo`03
0000003ookl0M00000<0000000<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo0:D0oooo002h0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool0
2@3oool010000000oono07@0M02oool:0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool0Y@3oool00;T0oooo00H0W4P007Boo`3oool0omnL04P0M02oool:0?ooo`040000003ookl0M01d
0;ooo`X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2V0?ooo`00^@3oool01@3o
okl0M0000000000004P0W=oo00`0oooo00<0000007@0000000000P0000000`0007@0_ooo0?ooo`05
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0YP3oool00<X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0:L0oooo003:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`2W0?ooo`00
bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
Y`3oool00</0oooo00<000000?ooo`3oool02@3oool3000002/0oooo00<000000?ooo`3oool0Z03o
ool00</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo0:P0oooo003;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`2Y0?ooo`00c03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0Z@3oool00<`0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0:T0oooo003<0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`2Z0?ooo`00c03oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0ZP3oool00<d0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0:X0oooo003=0?ooo`03
0000003oool0oooo00L0oooo0`00000X0?ooo`030000003oool0oooo0:/0oooo003=0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`2[0?ooo`00cP3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0[03o
ool00<h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo0:`0oooo003?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`2/0?ooo`00c`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0[@3oool00<l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo0:d0oooo003@0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`2^0?ooo`00d03oool00`000000oooo0?ooo`04
0?ooo`<000009@3oool00`000000oooo0?ooo`2^0?ooo`00d03oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0[P3oool00=40oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0:l0oooo003A0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`2_0?ooo`00dP3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0/03o
ool00=80oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo0;00oooo003B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`2`0?ooo`00d`3oool01@000000oooo0?ooo`3oool0000002@0oooo00<000000?oo
o`3oool0/@3oool00=<0oooo00D000000?ooo`3oool0oooo0000000T0?ooo`030000003oool0oooo
0;40oooo003C0?ooo`040000003oool0oooo0?ooo`<000008@3oool00`000000oooo0?ooo`2b0?oo
o`00e03oool010000000oooo0?ooo`00000S0?ooo`030000003oool0oooo0;80oooo003D0?ooo`04
0000003oool0oooo00000280oooo00<000000?ooo`3oool0/`3oool00=D0oooo00<000000?ooo`00
00008P3oool00`000000oooo0?ooo`2c0?ooo`00e@3oool00`000000oooo0000000Q0?ooo`030000
003oool0oooo0;@0oooo003:0?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool00P3o
ool00`000000oooo0000000Q0?ooo`030000003oool0oooo0;@0oooo003=0?ooo`0309a8B02Lgol0
oooo00H0oooo0P00000P0?ooo`030000003oool0oooo0;D0oooo003=0?ooo`0309a8B02Lgol0oooo
00H0oooo0P00000P0?ooo`030000003oool0oooo0;D0oooo003=0?ooo`0309a8B02Lgol0oooo00L0
oooo1000000L0?ooo`030000003oool0oooo0;H0oooo003=0?ooo`0309a8B02Lgol0oooo00L0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`2f0?ooo`00c@3oool00`2LB4P0W=oo0?oo
o`070?ooo`8000007@3oool00`000000oooo0?ooo`2g0?ooo`00c@3oool00`2LB4P0W=oo0?ooo`07
0?ooo`8000007@3oool00`000000oooo0?ooo`2g0?ooo`00bP3oool01@3OW4P000000018W02LB4P0
W=oo00P0oooo00<000000?ooo`0000006`3oool00`000000oooo0?ooo`2h0?ooo`00c03oool00`3O
W4P0001809cOo`080?ooo`030000003oool0000001X0oooo00<000000?ooo`3oool0^@3oool00=L0
oooo00@000000?ooo`3oool000006@3oool00`000000oooo0?ooo`2i0?ooo`00e`3oool01@000000
oooo0?ooo`3oool0000001L0oooo00<000000?ooo`3oool0^P3oool00=L0oooo00D000000?ooo`3o
ool0oooo0000000F0?ooo`030000003oool0oooo0;/0oooo003G0?ooo`<000000P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0;`0oooo003G0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`2l0?ooo`00e`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0_@3oool00=L0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0;h0oooo003G0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2o0?oo
o`00e`3oool00`000000oooo0?ooo`060?ooo`8000002`3oool00`000000oooo0?ooo`300?ooo`00
e`3oool00`000000oooo0?ooo`080?ooo`8000001`3oool200000<<0oooo003G0?ooo`030000003o
ool0oooo00X0oooo1`0000350?ooo`00e`3oool300000=H0oooo003G0?ooo`030000003oool0oooo
0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo
003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-5.25985, -1.91518, \
0.0366114, 0.0179561}}]
}, Closed]],

Cell[TextData[{
  "The positive minimum is found using an appropriate choice of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ".  The result is returned as a list whose first element is the value of \
the function as the minimum and the second is a list of replacement rules \
specifying the location of the minimum."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMinimum[f, {x, 3}]\)], "Input"],

Cell[BoxData[
    \({\(-0.5832341837212811`\), {x \[Rule] 2.6180339887527815`}}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Both minima can be found by mapping ",
  StyleBox["FindMinimum", "InlineInput",
    FontWeight->"Bold"],
  " onto a list of starting points.  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\(FindMinimum[f, {x, #}] &\)\  /@ {\(-3\), 3}\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \({{\(-1.8393972058572114`\), {x \[Rule] \(-2.000000005029083`\)}}, \
{\(-0.5832341837212811`\), {x \[Rule] 2.6180339887527815`}}}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "How can you locate the maximum using ",
  StyleBox["FindMinimum",
    FontWeight->"Bold"],
  "?  Try it!"
}], "Exercise"],

Cell["Radial maxima for hydrogenic wave functions", "Exercise"],

Cell[TextData[{
  "Apart from normalization, the radial wave functions for the hydrogen atom \
have the form ",
  Cell[BoxData[
      \(TraditionalForm\`R\_\(n, \[ScriptL]\) \[Proportional] \(\((2  \
\[Kappa]\ r)\)\^\(\(\[ScriptL]\)\(\ \)\)\) 
          Exp[\(-\[Kappa]\)\ r]\ LaguerreL[n - \[ScriptL] - 1, 
            2  \[ScriptL] + 1, 2  \[Kappa]\ r]\)]],
  " where ",
  ButtonBox["LaguerreL",
    ButtonStyle->"RefGuideLink"],
  " is a generalized Laguerre function.  The probability density that an \
electron can be found between ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`r + \[DifferentialD]r\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`P[
            r] \[DifferentialD]r = \(\[LeftBracketingBar]R\_\(n, \[ScriptL]\)[
                  r]\[RightBracketingBar]\^2\) \(r\^2\) \
\[DifferentialD]r\)]],
  ".  Determine the most probable radius when ",
  Cell[BoxData[
      \(TraditionalForm\`{n \[Rule] 5, \[ScriptL] \[Rule] 3}\)]],
  " in units of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\^\(-1\)\)]],
  "."
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: a function of two variables", "Subsubsection"],

Cell[TextData[{
  "The basic syntax is ",
  StyleBox["FindMinimum[", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["f,", "InlineInput",
    FontSlant->"Italic"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`{x, x\_0}\)], "InlineInput"], "InlineInput"],
  StyleBox[",", "InlineInput"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`{y, y\_0}\)], "InlineInput"], "InlineInput"],
  StyleBox["]", "InlineInput",
    FontWeight->"Bold"],
  " where ",
  StyleBox["f ",
    FontSlant->"Italic"],
  " is a function of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["y",
    FontSlant->"Italic"],
  " and where the starting point has coordinates {",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`y\_0\)]],
  "}.  Additional variables can be appended as necessary.  You can limit the \
variable ranges in the same manner as before, also."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f];\)\), "\n", 
    \(\(f = \(x\^2\) Sin[x\ y]\ Exp[\(-x\^2\)];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ContourPlot[f, {x, \(-2\), 2}, {y, \(-2\), 2}, 
        ContourShading \[Rule] False];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.240385 0.5 0.240385 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.25962 -0.0125 -6 -9 ]
[.25962 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74038 -0.0125 -3 -9 ]
[.74038 -0.0125 3 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -12 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -12 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -6 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-2)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(-1)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(1)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(2)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-2)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(-1)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(1)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(2)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.7526 .98077 m
.76995 .94071 L
.78045 .91595 L
.78723 .90064 L
.80694 .86058 L
.8077 .82051 L
.80932 .78045 L
.79344 .74038 L
.78045 .73182 L
.74866 .74038 L
.74038 .74708 L
.7186 .78045 L
.70292 .82051 L
.70032 .82869 L
.69013 .86058 L
.68584 .90064 L
.68108 .94071 L
.67828 .98077 L
s
.32172 .01923 m
.31892 .05929 L
.31416 .09936 L
.30987 .13942 L
.29968 .17131 L
.29708 .17949 L
.2814 .21955 L
.25962 .25292 L
.25134 .25962 L
.21955 .26818 L
.20656 .25962 L
.19068 .21955 L
.1923 .17949 L
.19306 .13942 L
.21277 .09936 L
.21955 .08405 L
.23005 .05929 L
.2474 .01923 L
s
.78328 .98077 m
.80224 .94071 L
.81858 .90064 L
.82051 .89488 L
.83375 .86058 L
.84668 .82051 L
.8547 .78045 L
.85609 .74038 L
.84851 .70032 L
.82051 .67134 L
.78045 .66053 L
.74038 .67528 L
.70727 .70032 L
.70032 .72649 L
.6935 .74038 L
.67856 .78045 L
.6683 .82051 L
.66155 .86058 L
.66026 .87348 L
.65634 .90064 L
.65136 .94071 L
.64701 .98077 L
s
.35299 .01923 m
.34864 .05929 L
.34366 .09936 L
.33974 .12652 L
.33845 .13942 L
.3317 .17949 L
.32144 .21955 L
.3065 .25962 L
.29968 .27351 L
.29273 .29968 L
.25962 .32472 L
.21955 .33947 L
.17949 .32866 L
.15149 .29968 L
.14391 .25962 L
.1453 .21955 L
.15332 .17949 L
.16625 .13942 L
.17949 .10512 L
.18142 .09936 L
.19776 .05929 L
.21672 .01923 L
s
.80806 .98077 m
.82051 .9538 L
.82699 .94071 L
.84655 .90064 L
.86058 .87056 L
.86473 .86058 L
.88053 .82051 L
.89248 .78045 L
.89865 .74038 L
.89696 .70032 L
.88343 .66026 L
.86058 .6326 L
.84103 .62019 L
.82051 .61213 L
.78045 .60829 L
.74038 .61927 L
.73802 .62019 L
.70032 .65271 L
.69457 .66026 L
.67304 .70032 L
.66026 .73865 L
.65977 .74038 L
.65004 .78045 L
.64246 .82051 L
.63635 .86058 L
.63133 .90064 L
.62716 .94071 L
.62372 .98077 L
s
.37628 .01923 m
.37284 .05929 L
.36867 .09936 L
.36365 .13942 L
.35754 .17949 L
.34996 .21955 L
.34023 .25962 L
.33974 .26135 L
.32696 .29968 L
.30543 .33974 L
.29968 .34729 L
.26198 .37981 L
.25962 .38073 L
.21955 .39171 L
.17949 .38787 L
.15897 .37981 L
.13942 .3674 L
.11657 .33974 L
.10304 .29968 L
.10135 .25962 L
.10752 .21955 L
.11947 .17949 L
.13527 .13942 L
.13942 .12944 L
.15345 .09936 L
.17301 .05929 L
.17949 .0462 L
.19194 .01923 L
s
.83125 .98077 m
.85421 .94071 L
.86058 .92999 L
.8766 .90064 L
.89965 .86058 L
.90064 .85887 L
.91912 .82051 L
.93568 .78045 L
.94071 .76472 L
.94657 .74038 L
.95034 .70032 L
.94502 .66026 L
.94071 .64311 L
.92617 .62019 L
.90064 .594 L
.87753 .58013 L
.86058 .57353 L
.82051 .56438 L
.78045 .563 L
.74038 .56963 L
.71138 .58013 L
.70032 .5888 L
.66984 .62019 L
.66026 .63617 L
.64939 .66026 L
.63618 .70032 L
.62653 .74038 L
.62019 .77409 L
.61947 .78045 L
.61516 .82051 L
.6112 .86058 L
.60757 .90064 L
.60426 .94071 L
.60127 .98077 L
s
.39873 .01923 m
.39574 .05929 L
.39243 .09936 L
.3888 .13942 L
.38484 .17949 L
.38053 .21955 L
.37981 .22591 L
.37347 .25962 L
.36382 .29968 L
.35061 .33974 L
.33974 .36383 L
.33016 .37981 L
.29968 .4112 L
.28862 .41987 L
.25962 .43037 L
.21955 .437 L
.17949 .43562 L
.13942 .42647 L
.12247 .41987 L
.09936 .406 L
.07383 .37981 L
.05929 .35689 L
.05498 .33974 L
.04966 .29968 L
.05343 .25962 L
.05929 .23528 L
.06432 .21955 L
.08088 .17949 L
.09936 .14113 L
.10035 .13942 L
.1234 .09936 L
.13942 .07001 L
.14579 .05929 L
.16875 .01923 L
s
.98077 .81781 m
.97902 .82051 L
.95022 .86058 L
.94071 .87198 L
.91543 .90064 L
.90064 .9237 L
.88645 .94071 L
.86058 .97967 L
.85981 .98077 L
s
.98077 .55962 m
.94089 .54006 L
.94071 .54 L
.90064 .52943 L
.86058 .52374 L
.82051 .52105 L
.78045 .52071 L
.74038 .52292 L
.70032 .52919 L
.66836 .54006 L
.66026 .54443 L
.6244 .58013 L
.62019 .58697 L
.60925 .62019 L
.59823 .66026 L
.58959 .70032 L
.58284 .74038 L
.58013 .75963 L
.57792 .78045 L
.57425 .82051 L
.57117 .86058 L
.56855 .90064 L
.56627 .94071 L
.56427 .98077 L
s
.01923 .93747 m
.03624 .94071 L
.05929 .95195 L
.09739 .98077 L
s
.98077 .06253 m
.96376 .05929 L
.94071 .04805 L
.90261 .01923 L
s
.01923 .44038 m
.05911 .45994 L
.05929 .46 L
.09936 .47057 L
.13942 .47626 L
.17949 .47895 L
.21955 .47929 L
.25962 .47708 L
.29968 .47081 L
.33164 .45994 L
.33974 .45557 L
.3756 .41987 L
.37981 .41303 L
.39075 .37981 L
.40177 .33974 L
.41041 .29968 L
.41716 .25962 L
.41987 .24037 L
.42208 .21955 L
.42575 .17949 L
.42883 .13942 L
.43145 .09936 L
.43373 .05929 L
.43573 .01923 L
s
.01923 .18219 m
.02098 .17949 L
.04978 .13942 L
.05929 .12802 L
.08457 .09936 L
.09936 .0763 L
.11355 .05929 L
.13942 .02033 L
.14019 .01923 L
s
.98077 .93747 m
.96376 .94071 L
.94071 .95195 L
.90261 .98077 L
s
.01923 .55962 m
.05911 .54006 L
.05929 .54 L
.09936 .52943 L
.13942 .52374 L
.17949 .52105 L
.21955 .52071 L
.25962 .52292 L
.29968 .52919 L
.33164 .54006 L
.33974 .54443 L
.3756 .58013 L
.37981 .58697 L
.39075 .62019 L
.40177 .66026 L
.41041 .70032 L
.41716 .74038 L
.41987 .75963 L
.42208 .78045 L
.42575 .82051 L
.42883 .86058 L
.43145 .90064 L
.43373 .94071 L
.43573 .98077 L
s
.01923 .81781 m
.02098 .82051 L
.04978 .86058 L
.05929 .87198 L
.08457 .90064 L
.09936 .9237 L
.11355 .94071 L
.13942 .97967 L
.14019 .98077 L
s
.98077 .18219 m
.97902 .17949 L
.95022 .13942 L
.94071 .12802 L
.91543 .09936 L
.90064 .0763 L
.88645 .05929 L
.86058 .02033 L
.85981 .01923 L
s
.98077 .44038 m
.94089 .45994 L
.94071 .46 L
.90064 .47057 L
.86058 .47626 L
.82051 .47895 L
.78045 .47929 L
.74038 .47708 L
.70032 .47081 L
.66836 .45994 L
.66026 .45557 L
.6244 .41987 L
.62019 .41303 L
.60925 .37981 L
.59823 .33974 L
.58959 .29968 L
.58284 .25962 L
.58013 .24037 L
.57792 .21955 L
.57425 .17949 L
.57117 .13942 L
.56855 .09936 L
.56627 .05929 L
.56427 .01923 L
s
.01923 .06253 m
.03624 .05929 L
.05929 .04805 L
.09739 .01923 L
s
.39873 .98077 m
.39574 .94071 L
.39243 .90064 L
.3888 .86058 L
.38484 .82051 L
.38053 .78045 L
.37981 .77409 L
.37347 .74038 L
.36382 .70032 L
.35061 .66026 L
.33974 .63617 L
.33016 .62019 L
.29968 .5888 L
.28862 .58013 L
.25962 .56963 L
.21955 .563 L
.17949 .56438 L
.13942 .57353 L
.12247 .58013 L
.09936 .594 L
.07383 .62019 L
.05929 .64311 L
.05498 .66026 L
.04966 .70032 L
.05343 .74038 L
.05929 .76472 L
.06432 .78045 L
.08088 .82051 L
.09936 .85887 L
.10035 .86058 L
.1234 .90064 L
.13942 .92999 L
.14579 .94071 L
.16875 .98077 L
s
.83125 .01923 m
.85421 .05929 L
.86058 .07001 L
.8766 .09936 L
.89965 .13942 L
.90064 .14113 L
.91912 .17949 L
.93568 .21955 L
.94071 .23528 L
.94657 .25962 L
.95034 .29968 L
.94502 .33974 L
.94071 .35689 L
.92617 .37981 L
.90064 .406 L
.87753 .41987 L
.86058 .42647 L
.82051 .43562 L
.78045 .437 L
.74038 .43037 L
.71138 .41987 L
.70032 .4112 L
.66984 .37981 L
.66026 .36383 L
.64939 .33974 L
.63618 .29968 L
.62653 .25962 L
.62019 .22591 L
.61947 .21955 L
.61516 .17949 L
.6112 .13942 L
.60757 .09936 L
.60426 .05929 L
.60127 .01923 L
s
.37628 .98077 m
.37284 .94071 L
.36867 .90064 L
.36365 .86058 L
.35754 .82051 L
.34996 .78045 L
.34023 .74038 L
.33974 .73865 L
.32696 .70032 L
.30543 .66026 L
.29968 .65271 L
.26198 .62019 L
.25962 .61927 L
.21955 .60829 L
.17949 .61213 L
.15897 .62019 L
.13942 .6326 L
.11657 .66026 L
.10304 .70032 L
.10135 .74038 L
.10752 .78045 L
.11947 .82051 L
.13527 .86058 L
.13942 .87056 L
.15345 .90064 L
.17301 .94071 L
.17949 .9538 L
.19194 .98077 L
s
.80806 .01923 m
.82051 .0462 L
.82699 .05929 L
.84655 .09936 L
.86058 .12944 L
.86473 .13942 L
.88053 .17949 L
.89248 .21955 L
.89865 .25962 L
.89696 .29968 L
.88343 .33974 L
.86058 .3674 L
.84103 .37981 L
.82051 .38787 L
.78045 .39171 L
.74038 .38073 L
.73802 .37981 L
.70032 .34729 L
.69457 .33974 L
.67304 .29968 L
.66026 .26135 L
.65977 .25962 L
.65004 .21955 L
.64246 .17949 L
.63635 .13942 L
.63133 .09936 L
.62716 .05929 L
.62372 .01923 L
s
.35299 .98077 m
.34864 .94071 L
.34366 .90064 L
.33974 .87348 L
.33845 .86058 L
.3317 .82051 L
.32144 .78045 L
.3065 .74038 L
.29968 .72649 L
.29273 .70032 L
.25962 .67528 L
.21955 .66053 L
.17949 .67134 L
.15149 .70032 L
.14391 .74038 L
.1453 .78045 L
.15332 .82051 L
.16625 .86058 L
.17949 .89488 L
.18142 .90064 L
.19776 .94071 L
.21672 .98077 L
s
.78328 .01923 m
.80224 .05929 L
.81858 .09936 L
.82051 .10512 L
.83375 .13942 L
.84668 .17949 L
.8547 .21955 L
.85609 .25962 L
.84851 .29968 L
.82051 .32866 L
.78045 .33947 L
.74038 .32472 L
.70727 .29968 L
.70032 .27351 L
.6935 .25962 L
.67856 .21955 L
.6683 .17949 L
.66155 .13942 L
.66026 .12652 L
.65634 .09936 L
.65136 .05929 L
.64701 .01923 L
s
.32172 .98077 m
.31892 .94071 L
.31416 .90064 L
.30987 .86058 L
.29968 .82869 L
.29708 .82051 L
.2814 .78045 L
.25962 .74708 L
.25134 .74038 L
.21955 .73182 L
.20656 .74038 L
.19068 .78045 L
.1923 .82051 L
.19306 .86058 L
.21277 .90064 L
.21955 .91595 L
.23005 .94071 L
.2474 .98077 L
s
.7526 .01923 m
.76995 .05929 L
.78045 .08405 L
.78723 .09936 L
.80694 .13942 L
.8077 .17949 L
.80932 .21955 L
.79344 .25962 L
.78045 .26818 L
.74866 .25962 L
.74038 .25292 L
.7186 .21955 L
.70292 .17949 L
.70032 .17131 L
.69013 .13942 L
.68584 .09936 L
.68108 .05929 L
.67828 .01923 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`007P3oool00`3ookl0M0000000
00040000000307Boo`3oool0oooo05T0oooo00<0okmd0000000000000`0000000`00M;l0oooo0?oo
o`1F0?ooo`050?noM000000000000000001d_ol0G03oool00`3o_g@000000000000300000003001d
_`3oool0oooo05P0oooo00<0oono07@000000000100000000`1d_ol0oooo0?ooo`040?ooo`007`3o
ool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo05d0oooo00<0W4Q809cOo`3oool0F@3o
ool01P2LB7@0_ooo0?ooo`3ookl0M01d0;oooeh0oooo00<0W4Q809cOo`3oool0G03oool00`2oM000
001d0;ooo`020?ooo`030=nLM02Lgol0oooo00D0oooo000P0?ooo`030?noM00004P0W=oo0640oooo
00<0W4Q809cOo`3oool0F03oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo05d0oooo
00<0W4Q809cOo`3oool0G@3oool00`3o_g@0001809cOo`090?ooo`008@3oool00`3ogi`0B00004RL
g`1P0?ooo`0309a8B02Lgol0oooo05P0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?oo
o`1M0?ooo`0309a8B02Lgol0oooo05h0oooo00<0omnL04P00018W=l0203oool001H0oooo00<0W4P0
0000000000000`0000000`00B9`0oooo0?ooo`040?ooo`0309a80018W=l0oooo0580oooo00<0W4P0
0000000000000`0000000`00B9`0oooo0?ooo`030?ooo`0309a8B02Lgol0oooo05P0oooo00<0gia8
04RLg`3oool00P3oool00`3o_g@007Bo0?ooo`1M0?ooo`0309a8B02Lgol0oooo0600oooo00<0W4P0
04RLg`3oool01P3oool002@0oooo00<0W4Qd0;ooo`3oool0G@3oool00`2LB4P0W=oo0?ooo`1H0?oo
o`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0G@3oool00`2LB4P0W=oo0?ooo`1Q0?oo
o`0309a8M02oool0oooo00D0oooo000O0?ooo`030=nLB01d_ol0oooo0080oooo00<0_g@007Boo`3o
ool0G@3oool00`2LB4P0W=oo0?ooo`1H0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3o
ool0G@3oool00`2LB4P0W=oo0?ooo`1L0?ooo`030=nLB01d_ol0oooo0080oooo00<0_g@007Boo`3o
ool01@3oool001l0oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo05/0oooo00D0gia80000
0000B9`0W4Q809cOo`1J0?ooo`0609a8001d_ol0oooo0?oOW01807@0_oooF`3oool01@3OW4P00000
0018W02LB4P0W=oo05d0oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo00H0oooo000P0?oo
o`050?noM000000000000000B02Lgol0GP3oool00`3OW4P0001809cOo`1J0?ooo`050?oo_`1d0000
00000000B02Lgol0GP3oool00`3OW4P0001809cOo`1N0?ooo`050?noM000000000000000B02Lgol0
1`3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool001L0ooooo`00002I00000040
oooo000G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`050?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1O
0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1O
0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oo
oiD0oooo0@0000010?ooo`002@3oool00`3ookl0M000000000040000000307Boo`3oool0oooo00@0
oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3oool000X0oooo00<0_g@00000M02oool0
0P3oool00`3OW7@0W=oo0?ooo`050?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo
000;0?ooo`030?noM00004P0W=oo00T0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`4000000@3o
ool000`0oooo00<0omnL04P00018W=l0203oool3000002@0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08P3oool3
00000040oooo00000`3oool0W4P000000004000000030018W03oool0oooo00@0oooo00<0W4P004RL
g`3oool01P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02<0oooo0@0000010?oo
o`003`3oool00`2LB7@0_ooo0?ooo`050?ooo`030000003oool0oooo0240oooo0P00000A0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0403oool2000002<0oooo0@0000010?ooo`00
2P3oool00`3OW4P0M;oo0?ooo`020?ooo`030;md001d_ol0oooo00D0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0P0?ooo`4000000@3oool000X0oooo00L0okmd0000M02oool0oooo
0?noM00004P0W=oo00H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0O0?ooo`40
00000@3oool000/0oooo00D0okmd000000000000001809cOo`070?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool07P3oool100000040oooo000G0?ooo`030000003oool0oooo01`0oooo
0P00000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04`3oool2000001h0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01/0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01T0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`0G0?ooo`8000005P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo01D0oooo0P00000I0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0F0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0E0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool04`3oool2
000001P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`8000005@3oool1
00000040oooo000G0?ooo`030000003oool0oooo0140oooo0P00000J0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0603oool2000001<0oooo0@0000010?ooo`005`3oool00`000000
oooo0?ooo`0?0?ooo`8000006`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01T0
oooo0P00000A0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool03@3oool2000001d0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0K0?ooo`8000003`3oool100000040oooo
000G0?ooo`030000003oool0oooo00P0oooo1@00000N0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0703oool4000000/0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`04
0?ooo`@000008P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01l0oooo10000007
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo02T0oooo0@0000010?ooo`005`3oool2000002T0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0W0?ooo`8000000@3oool001L0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02P0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09`3o
ool100000040oooo000G0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0V0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo02D0oooo0@0000010?ooo`005`3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0903oool100000040
oooo000G0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0T0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo02<0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool08P3oool100000040oooo000G0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0R0?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0240oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0803oool100000040oooo000G0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0P0?ooo`4000000@3o
ool001L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo01l0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool07P3oool100000040oooo000G0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0M0?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01d0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0703oool100000040oooo000G0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0K0?ooo`4000000@3oool001L0oooo0P00000K0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo03D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool06@3oool200000040oooo000G0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0I0?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo01P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0603oool100000040oooo000G0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
01H0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool05@3oool100000040oooo000G0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0D0?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01<0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool04P3oool100000040oooo000G0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
403oool100000040oooo000G0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0?0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00h0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool10000
0040oooo000G0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0=0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00`0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02`3oool100000040oooo000G
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0;
0?ooo`4000000@3oool001L0oooo0P00000;0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool02@3oool200000040oooo000G0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`090?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00T0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0203o
ool100000040oooo000G0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`070?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`005`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01P3oool100000040
oooo000G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`050?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0M
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool07@3oool100000040oooo000G0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo01`0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0L0?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool06`3oool100000040oooo000G0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo01/0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0K0?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool06P3oool100000040oooo000G0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01X0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0I0?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool06@3oool100000040oooo000G0?ooo`8000006@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool05`3oool200000040oooo000G0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo01P0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool05`3oool100000040oooo000G0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo01L0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0F0?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool05P3oool100000040oooo000G0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03d0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01H0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0E0?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool05@3oool100000040oooo000G0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01D0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0D0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
503oool100000040oooo000G0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01@0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0D0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04`3oool10000
0040oooo000:0?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool0103oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0C0?ooo`4000000@3oool000d0oooo00<0W4Q809cOo`3oool01`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0C0?ooo`4000000@3oool000d0oooo00<0W4Q809cOo`3oool01`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo0100oooo0P00000D0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool04@3oool2000001<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool100000040oooo000=
0?ooo`0309a8B02Lgol0oooo00L0oooo0`00000B0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00h0oooo0P00000F
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04`3oool300000100oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0403oool300000040oooo00000`3oool0W4P000000004000000030018W03oool0oooo
00<0oooo00<0W4Q809cOo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
00X0oooo0`00000G0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05P3oool30000
00`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool04P3oool100000040oooo000=0?ooo`0309a8B02Lgol0oooo00L0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool06@3oool2000000H0oooo1000000J0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0603oool4000000H0oooo0P00000K0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`4000000@3oool000d0oooo
00<0W4Q809cOo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00<00000
7@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo0`0000020?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0180oooo0@0000010?ooo`002P3oool01@3OW4P000000018W02LB4P0W=oo00P0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool06`3oool200000200oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0N0?ooo`8000007@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool04P3oool100000040oooo000<0?ooo`030=nLB00004P0W=oo00P0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool04P3oool100000040oooo000G0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
4@3oool100000040oooo000G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0A0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04@3oool10000
0040oooo000G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0A0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0140oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04@3oool100000040oooo000G
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0A
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo0140oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0d0?ooo`80
00003@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0A0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`800000=03oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool04@3oool100000040oooo000G0?ooo`8000004P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0100oooo0P0000010?ooo`005`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0]0?ooo`800000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`800000;@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04P3oool10000
0040oooo000G0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0D0?ooo`800000:@3oool200000180oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0:03oool2000001H0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0B0?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0180oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo0P00
000U0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0B0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0803oool2000001@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool04P3oool100000040oooo000G0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01d0oooo0P00000E0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?oo
o`800000803oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool04P3oool100000040oooo000G0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0I0?ooo`8000006`3oool2000001L0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo0`00000K0?ooo`80
00006`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
6P3oool3000001D0oooo0`00000H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0F0?ooo`<000005@3oool3000001`0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0C0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01d0oooo0`00000?0?ooo`<000006`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool06@3o
ool200000100oooo0`00000O0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04`3o
ool100000040oooo000G0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0P0?ooo`@000002@3oool2000001d0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01X0oooo0`0000090?ooo`@000008P3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01<0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool08`3oool30000
00<0oooo0`00000O0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0M0?ooo`<000000`3oool3000002D0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0C0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo02H0oooo0`00000Q0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0O0?ooo`<00000:03oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo01<0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo01<0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo01@0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo01@0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo01@0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0@@3oool2000001<0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool04P3oool200000480oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0D0?ooo`40
00000@3oool001L0oooo0P00000F0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
D@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01@0oooo0P0000010?ooo`005`3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0DP3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01D0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0DP3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01H0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0DP3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo01H0oooo0@0000010?ooo`005`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0=`3oool2000001L0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool05@3oool2000003P0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0G0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0H0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0K0?ooo`800000=03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0<@3oool2000001h0oooo00<000000?ooo`3oool0603oool100000040oooo000G
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06@3oool100000040oooo000G0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0703oool2000002h0oooo0P00000I0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo01L0oooo0P00000]0?ooo`8000007`3oool00`000000oooo0?ooo`0J0?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0N0?ooo`80
0000:`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0:03oool200000240oooo00<000000?ooo`3oool06P3oool100000040oooo000G0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool07`3oool2000002P0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0K0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0P0?ooo`800000903oool2000001/0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0603o
ool3000002@0oooo0P00000R0?ooo`030000003oool0oooo01`0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0240oooo0P00000N0?ooo`@00000703oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0J0?ooo`@000007P3oool2000002<0oooo00<000000?ooo`3oool07@3oool1
00000040oooo000G0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool08P3oool20000
01P0oooo1000000O0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01d0oooo1000000H0?ooo`800000903oool00`00
0000oooo0?ooo`0N0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0S0?ooo`T000002`3oool400000280oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0803oool4000000/0
oooo2@00000U0?ooo`030000003oool0oooo01l0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo02/0oooo2`00000U0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02<0oooo
2`00000]0?ooo`030000003oool0oooo0200oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?oo
o`0P0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool08@3oool100000040oooo000G0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo05/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo0280oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo05D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0S0?ooo`40
00000@3oool001L0oooo0P00000U0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
D`3oool00`000000oooo0?ooo`0S0?ooo`8000000@3oool001L0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool09@3o
ool100000040oooo000G0?ooo`030000003oool0oooo02H0oooo0P00001@0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo04h0oooo0P00000X0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0:03oool20000
04d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0B`3oool2000002X0oooo0@0000010?ooo`005`3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`1O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`0Z0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0:`3oool2000004L0oooo
0P00000Q0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool07`3oool2000004L0oooo
0P00000]0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0;@3oool2000004@0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0@P3oool2000002l0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0_
0?ooo`800000@03oool2000002<0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0Q
0?ooo`800000@03oool200000340oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0a0?oo
o`<00000>P3oool3000002@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0R0?oo
o`<00000>@3oool4000003<0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0d0?ooo`@0
0000<`3oool3000002H0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0T0?ooo`80
0000=03oool3000003L0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0h0?ooo`@00000
;03oool3000002P0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0U0?ooo`<00000
;@3oool4000003X0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0l0?ooo`@00000903o
ool4000002X0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0W0?ooo`@000009@3o
ool4000003h0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`100?ooo`@000006`3oool5
000002d0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0Z0?ooo`H000006`3oool4
00000480oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`140?ooo`X000002`3oool60000
0340oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0_0?ooo`H000002`3oool:0000
04H0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`1>0?ooo`/00000=@3oool200000780
oooo0P00000e0?ooo`/00000D03oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo
0P0000270?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo
0?ooo`050?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool01P3oool2000008@0oooo00<0
00000?ooo`3oool0MP3oool00`000000oooo0?ooo`220?ooo`800000203oool100000040oooo000G
0?ooo`030000003oool0oooo00P0oooo0P0000210?ooo`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool0O`3oool2000000X0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0:0?oo
o`800000OP3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo07`0oooo0P00000<0?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool0303oool2000007/0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`1i0?ooo`8000003P3oool100000040oooo000G0?ooo`800000
3`3oool2000007P0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`1f0?ooo`800000
3`3oool200000040oooo000G0?ooo`030000003oool0oooo0100oooo0P00001e0?ooo`030000003o
ool0oooo0800oooo00<000000?ooo`3oool0L`3oool200000180oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`0B0?ooo`800000L@3oool2000008@0oooo0P00001a0?ooo`800000503oool1
00000040oooo000G0?ooo`030000003oool0oooo01@0oooo0`00001/0?ooo`800000R03oool20000
06`0oooo0`00000F0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool05`3oool4000006D0
oooo0`00002<0?ooo`<00000I@3oool4000001T0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`0K0?ooo`@00000G@3oool400000980oooo1000001M0?ooo`@000007@3oool100000040oooo
000G0?ooo`030000003oool0oooo01l0oooo1000001F0?ooo`<00000VP3oool3000005H0oooo1000
000Q0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool08`3oool5000004d0oooo1000002P
0?ooo`@00000C@3oool5000002D0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0X0?oo
o`D00000@P3oool600000:P0oooo1@0000120?ooo`H00000:P3oool100000040oooo000G0?ooo`03
0000003oool0oooo02d0oooo1P00000f0?ooo`H00000/`3oool6000003H0oooo1P00000`0?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool0<`3oool;00000240oooo2P00002o0?ooo`/00000
8@3oool:000003H0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0n0?ooob400000e03o
oolQ00000400oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000
oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`3o0?oooiD0oooo
0@0000010?ooo`002`3oool01@3o_g@00000000000000000M;oo00L0oooo00<000000?ooo`3oool0
o`3ooonE0?ooo`4000000@3oool000/0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool60?ooo`03
0000003oool0oooo0?l0ooooU@3oool100000040oooo000:0?ooo`030?noM000M;l0oooo0080oooo
00<0gia804RLg`3oool01@3oool00`000000oooo0?ooo`3o0?oooiD0oooo0@0000010?ooo`002P3o
ool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00D0oooo0`00003o0?oooi<0oooo0`00
00010?ooo`002P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00D0oooo00<00000
0?ooo`3oool0o`3ooonE0?ooo`4000000@3oool000X0oooo00<0gia804RLg`3oool00P3oool00`3o
_g@007Bo0?ooo`050?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000:0?ooo`03
0?noM018W=l0oooo0080oooo00<0gia804RLg`3oool01@3oool00`000000oooo0?ooo`3o0?oooiD0
oooo0@0000010?ooo`002`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`H0oooo00<000000?oo
o`3oool0o`3ooonE0?ooo`4000000@3oool000/0oooo00D0oono07@000000000001809cOo`070?oo
o`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0
ooooU@3oool100000040oooo000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo
000G0?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000G0?ooo`030000003oool0
oooo03h0oooo8000003E0?ooob000000@@3oool100000040oooo000G0?ooo`030000003oool0oooo
0380oooo3000000P0?ooo`d00000_03oool<00000200oooo3@00000d0?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool0:P3oool8000003T0oooo2000002/0?ooo`P00000>@3oool8000002`0
oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0T0?ooo`H00000B@3oool600000:00oooo
1P0000190?ooo`H000009P3oool100000040oooo000G0?ooo`030000003oool0oooo0240oooo0`00
001E0?ooo`800000W03oool2000005D0oooo0`00000S0?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool07P3oool3000005X0oooo0`00002F0?ooo`<00000FP3oool300000200oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`0J0?ooo`@00000H03oool300000900oooo0`00001P0?oo
o`@00000703oool100000040oooo000G0?ooo`030000003oool0oooo01L0oooo0`00001W0?ooo`80
0000S03oool2000006L0oooo0`00000I0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
503oool3000006`0oooo0`0000260?ooo`<00000K03oool2000001L0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`0B0?ooo`800000LP3oool200000880oooo0P00001a0?ooo`8000005@3o
ool100000040oooo000G0?ooo`030000003oool0oooo0100oooo0P00001f0?ooo`030000003oool0
oooo07h0oooo00<000000?ooo`3oool0L`3oool2000001<0oooo0@0000010?ooo`005`3oool20000
00l0oooo0P00001i0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0MP3oool20000
0100oooo0P0000010?ooo`005`3oool00`000000oooo0?ooo`0<0?ooo`800000O03oool00`000000
oooo0?ooo`1j0?ooo`030000003oool0oooo07T0oooo0P00000?0?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool02P3oool2000007l0oooo00<000000?ooo`3oool0N03oool00`000000oooo
0?ooo`1l0?ooo`8000003@3oool100000040oooo000G0?ooo`030000003oool0oooo00P0oooo0P00
00220?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0O`3oool2000000/0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`060?ooo`800000Q@3oool00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0880oooo0P0000090?ooo`4000000@3oool001L0oooo00<000000?oo
o`3oool0103oool2000008P0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`250?oo
o`8000001`3oool100000040oooo000G0?ooo`030000003oool0oooo04l0oooo2P00000f0?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool0=03oool:00000540oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`140?ooo`/000002P3oool500000380oooo00<000000?ooo`3oool0
KP3oool00`000000oooo0?ooo`0_0?ooo`H000002P3oool;000004H0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`0n0?ooo`H000006P3oool6000002d0oooo00<000000?ooo`3oool0K03o
ool00`000000oooo0?ooo`0Z0?ooo`H000006`3oool500000440oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`0h0?ooo`H000009P3oool4000002X0oooo00<000000?ooo`3oool0JP3oool0
0`000000oooo0?ooo`0W0?ooo`@000009P3oool6000003/0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`0e0?ooo`<00000<03oool3000002P0oooo00<000000?ooo`3oool0J03oool00`00
0000oooo0?ooo`0U0?ooo`<00000<03oool4000003L0oooo0@0000010?ooo`005`3oool00`000000
oooo0?ooo`0c0?ooo`800000=P3oool3000002H0oooo00<000000?ooo`3oool0IP3oool00`000000
oooo0?ooo`0T0?ooo`800000=`3oool2000003D0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`0a0?ooo`800000>`3oool3000002@0oooo00<000000?ooo`3oool0I03oool00`000000oooo
0?ooo`0R0?ooo`<00000>`3oool2000003<0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`0_0?ooo`800000@03oool2000002<0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?oo
o`0Q0?ooo`800000@03oool200000340oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0]
0?ooo`800000A03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0640oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`120?ooo`800000;`3oool100000040oooo000G0?oo
o`030000003oool0oooo02/0oooo0P0000170?ooo`8000008@3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo01l0oooo0P0000170?ooo`800000;@3oool100000040oooo000G0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo05l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo02X0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0X0?ooo`800000
C@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`1;0?ooo`800000:P3oool100000040oooo000G0?ooo`030000003o
ool0oooo02H0oooo0P00001@0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo04h0oooo0P00000X0?ooo`4000000@3o
ool001L0oooo0P00000V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`1M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`0T0?ooo`8000000@3oool001L0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0G03oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0903oool10000
0040oooo000G0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo02<0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`1K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0R0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`1I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool08@3oool100000040oooo000G
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0<03oool5000002H0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0903oool500000380oooo00<000000?ooo`3oool0803oool100000040oooo000G0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:@3oool8000000D0oooo0`00000T0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo0240oooo100000050?ooo`P00000:`3oool00`000000oooo0?ooo`0O0?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0T0?ooo`H0
0000403oool300000280oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool07`3oool300000140oooo1P00000V0?ooo`03
0000003oool0oooo01h0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0280oooo0`00000I0?ooo`@000007`3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0M0?ooo`<00000
6P3oool2000002D0oooo00<000000?ooo`3oool07@3oool100000040oooo000G0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0803oool300000200oooo0`00000M0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo01X0oooo1000000O0?ooo`<000008`3oool00`000000oooo0?ooo`0L0?ooo`4000000@3o
ool001L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0O0?ooo`8000009P3oool3
000001/0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool06@3oool2000002H0oooo0P00000R0?ooo`030000003oool0
oooo01/0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01h0oooo0P00000[0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0X0?ooo`8000008@3oool00`000000oooo0?ooo`0J0?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0J0?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0L0?ooo`800000<03oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0;@3oool2000001l0oooo
00<000000?ooo`3oool06@3oool100000040oooo000G0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool06P3oool2000003<0oooo0P00000H0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo0P00
000b0?ooo`8000007@3oool00`000000oooo0?ooo`0I0?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0H0?ooo`4000000@3oool001L0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0G0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0F0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0F0?ooo`4000000@3oool001L0oooo0P00000F0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo01@0oooo0P0000010?ooo`005`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0@03oool2000001@0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`1@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool20000
0440oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0E0?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0500
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0D0?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0500oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0D0?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0D0?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04P0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0D0?ooo`4000000@3oool001L0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0C0?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02H0oooo0`00000Q0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0O0?ooo`<0
0000:03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01<0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
8P3oool4000000<0oooo0P00000P0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0M0?ooo`<000000`3oool4000002@0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0C0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01l0oooo100000090?ooo`<000007@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool06P3o
ool3000000X0oooo1000000Q0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04`3o
ool100000040oooo000G0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0K0?ooo`@00000403oool3000001/0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01T0oooo0P00000A0?ooo`@000007@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01<0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0603oool30000
01L0oooo0P00000I0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`1<0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0F0?ooo`<000005`3oool3000001X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0C0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06P3oool3000001L0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04`0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0
oooo0`00000M0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0B0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool07P3oool2000001D0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180oooo
0P00000Q0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0B0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool08@3oool2000001@0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool04P3oool100000040oooo000G0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool04@3oool2000002H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0180oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool04P3oool100000040oooo000G0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo02P0oooo0P00000B0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0180oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo0P00000]0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0B0?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0;@3oool200000100oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3o
ool100000040oooo000G0?ooo`8000004P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`180?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0100oooo0P0000010?ooo`005`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00`0oooo0P00000d0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0A0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0=03oool2000000d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool04@3oool100000040oooo000G0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0A0?ooo`4000000@3oool001L0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool04@3oool100000040oooo000G0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0A0?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
4@3oool100000040oooo000G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0A0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool10000
0040oooo000G0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0B0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0180oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool100000040oooo000G
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B
0?ooo`4000000@3oool000X0oooo00<0okmd0000000000000`0000000`00M;l0oooo0?ooo`040?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01/0oooo0`00000O0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool07@3oool3000001d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0180oooo0@0000010?ooo`003@3oool00`2LB4P0W=oo0?ooo`070?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo01X0oooo0P0000030?ooo`@00000703oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01X0oooo100000030?ooo`800000703oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool100000040oooo000=0?ooo`0309a8
B02Lgol0oooo00L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0603oool2000000T0oooo1000000H0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool05P3oool4000000T0oooo0P00000J0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`400000
0@3oool000d0oooo00<0W4Q809cOo`3oool01`3oool300000180oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03@3o
ool3000001H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0D0?ooo`<000003`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0@0?ooo`<000000@3oool000d0oooo00<0W4Q809cOo`3oool01`3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0B0?ooo`4000000@3oool000d0oooo00<0W4Q809cOo`3oool01`3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo0P00000D0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
01<0oooo0@0000010?ooo`003@3oool00`2LB4P0W=oo0?ooo`070?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01<0
oooo0@0000010?ooo`002P3oool01@3OW4P000000018W02LB4P0W=oo00P0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool04`3oool100000040oooo000<0?ooo`030=nLB00004P0W=oo00P0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
503oool100000040oooo000G0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01@0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0D0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0503oool10000
0040oooo000G0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01D0oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0E0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05@3oool100000040oooo000G
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01H0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool05P3oool100000040oooo000G0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo03`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo01H0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`4000000@3o
ool001L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool05`3oool100000040oooo000G0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
01L0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`4000000@3oool001L0oooo
0P00000I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0G0?ooo`8000000@3oool001L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool06@3oool100000040oooo000G
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo01T0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0J0?oo
o`4000000@3oool001L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool06P3oool100000040oooo000G0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo01/0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0K0?ooo`4000000@3o
ool001L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool06`3oool100000040oooo000G0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
01`0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0L0?ooo`4000000@3oool001L0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool07@3oool100000040oooo000G0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01d0oooo0@00
00010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool01@3oool100000040oooo000G0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`050?ooo`4000000@3oool001L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`00
5`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
1`3oool100000040oooo000G0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`070?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00P0oooo0@0000010?ooo`005`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02@3oool10000
0040oooo000G0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0:0?ooo`4000000@3oool001L0oooo0P00000;0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool02@3oool200000040oooo000G0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0;0?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool03@3oool100000040oooo000G0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0=0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00h0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03`3o
ool100000040oooo000G0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0@0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo0@0000010?ooo`005`3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo0P00000=0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0
oooo0P00000C0?ooo`030000003oool0oooo0140oooo0@0000010?ooo`005`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool100000040oooo
000G0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0C0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo01<0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0503oool100000040oooo000G0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`40
00000@3oool001L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo01H0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool05`3oool100000040oooo000G0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`4000000@3oool0
01L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
01P0oooo0@0000010?ooo`005`3oool2000001X0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0H0?ooo`8000000@3oool001L0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01X0oooo0@0000010?ooo`005`3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool06`3oool100000040oooo000G
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0L
0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo01d0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool07@3oool100000040oooo000G0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0N0?ooo`400000
0@3oool001L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo01l0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0803oool100000040oooo000G0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0P0?ooo`4000000@3oool001L0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0240
oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool08P3oool100000040oooo000G0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0R0?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0oooo0@000001
0?ooo`005`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0903oool100000040oooo000G0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0T0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02D0oooo0@0000010?ooo`005`3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool09P3o
ool100000040oooo000G0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0W0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo02P0oooo0@0000010?ooo`005`3oool2000002T0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0W0?ooo`8000000@3oool001L0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02T0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`@000008P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0200oooo0`0000070?ooo`4000000@3oool001L0oooo00<00000
0?ooo`3oool0203oool4000001l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0M
0?ooo`@000002P3oool100000040oooo000G0?ooo`030000003oool0oooo00`0oooo0P00000N0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0703oool2000000h0oooo0@0000010?oo
o`005`3oool00`000000oooo0?ooo`0>0?ooo`800000703oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01X0oooo0P00000@0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool0
403oool2000001/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0I0?ooo`800000
4P3oool100000040oooo000G0?ooo`030000003oool0oooo0180oooo0P00000I0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0603oool2000001@0oooo0@0000010?ooo`005`3oool0
0`000000oooo0?ooo`0D0?ooo`800000603oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01H0oooo0P00000F0?ooo`4000000@3oool001L0oooo00<000000?ooo`3oool05P3oool20000
01L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0E0?ooo`800000603oool10000
0040oooo000G0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0603oool100000040
oooo000G0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06@3oool100000040oooo
000G0?ooo`030000003oool0oooo01X0oooo0P00000E0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0380oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool04`3oool2000001`0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01`0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo01d0oooo0@0000010?ooo`005`3oool00`000000oooo0?ooo`0N0?ooo`80
00004P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo0P00000P0?ooo`40
00000@3oool000T0oooo00<0oono07@000000000100000000`1d_ol0oooo0?ooo`040?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0803oool100000040oooo000:0?ooo`030;md0000
07@0_ooo0080oooo00<0giad09cOo`3oool01@3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0240oooo0@0000010?ooo`002`3oool00`3o_g@0001809cOo`090?ooo`030000003oool0
oooo0280oooo0P00000@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool2
000002@0oooo0@0000010?ooo`00303oool00`3ogi`0B00004RLg`080?ooo`<00000903oool00`00
0000oooo0?ooo`0>0?ooo`8000002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0280oooo0`0000010?ooo`003P3oool00`2LB000B9cO0?ooo`060?ooo`030000003oool0oooo0?l0
ooooU@3oool100000040oooo000?0?ooo`0309a8M02oool0oooo00D0oooo00<000000?ooo`3oool0
o`3ooonE0?ooo`4000000@3oool000X0oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?oo
o`050?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo000:0?ooo`070?noM00007@0
_ooo0?ooo`3o_g@0001809cOo`060?ooo`030000003oool0oooo0?l0ooooU@3oool100000040oooo
000;0?ooo`050?noM000000000000000B02Lgol01`3oool00`000000oooo0?ooo`3o0?oooiD0oooo
0@0000010?ooo`005`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool0G`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool01@3oool100000040oooo000G0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`005`3ooooo000009T000000@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-2.31568, -2.29368, 0.0153049, \
0.0153049}}]
}, Closed]],

Cell[TextData[{
  "Although ",
  StyleBox["ContourPlot", "InlineInput",
    FontWeight->"Bold"],
  " does not reveal the sign of the function directly, inspection of the \
definition suggests that minima are found in quadrants 2 and 4, while maxima \
live in quadrants 1 and 3.  ",
  StyleBox["Plot3D", "InlineInput",
    FontWeight->"Bold"],
  " would show this, but is unnecessary.  Therefore, we give ",
  StyleBox["FindMinimum", "InlineInput",
    FontWeight->"Bold"],
  " starting values in quadrant 2 and it reports the following minimum."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMinimum[f, {x, \(-1\)}, {y, 1}]\)], "Input"],

Cell[BoxData[
    \({\(-0.36787944117144233`\), {x \[Rule] \(-0.9999999999865836`\), 
        y \[Rule] 1.5707963268270582`}}\)], "Output"]
}, Closed]],

Cell["\<\
It is useful to verify this extremum by examining the function in its \
immediate vicinity.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ContourPlot[f, {x, \(-1.1\), \(-0.9\)}, {y, 1.4, 1.8}, 
        Contours \[Rule] 50, ContourShading \[Rule] False];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.30769 4.80769 -3.34615 2.40385 [
[.01923 -0.0125 -12 -9 ]
[.01923 -0.0125 12 0 ]
[.25962 -0.0125 -15 -9 ]
[.25962 -0.0125 15 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.74038 -0.0125 -15 -9 ]
[.74038 -0.0125 15 0 ]
[.98077 -0.0125 -12 -9 ]
[.98077 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -18 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -18 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -18 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -18 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-1.1)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(-1.05)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(-1)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(-0.95)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(-0.9)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(1.4)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(1.5)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(1.6)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(1.7)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(1.8)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.01923 .97165 m
.02671 .98077 L
s
.01923 .95992 m
.03632 .98077 L
s
.01923 .94803 m
.04603 .98077 L
s
.01923 .93599 m
.02306 .94071 L
.05586 .98077 L
s
.01923 .92379 m
.03295 .94071 L
.05929 .97289 L
.0658 .98077 L
s
.01923 .91141 m
.04295 .94071 L
.05929 .96068 L
.07586 .98077 L
s
.01923 .89885 m
.02067 .90064 L
.05308 .94071 L
.05929 .94831 L
.08604 .98077 L
s
.01923 .88611 m
.03087 .90064 L
.05929 .93576 L
.06333 .94071 L
.09636 .98077 L
s
.01923 .87316 m
.0412 .90064 L
.05929 .92303 L
.07371 .94071 L
.09936 .9718 L
.10681 .98077 L
s
.01923 .86001 m
.01968 .86058 L
.05166 .90064 L
.05929 .9101 L
.08424 .94071 L
.09936 .95905 L
.11741 .98077 L
s
.01923 .84665 m
.03023 .86058 L
.05929 .89697 L
.06226 .90064 L
.0949 .94071 L
.09936 .94611 L
.12816 .98077 L
s
.01923 .83305 m
.04092 .86058 L
.05929 .88362 L
.073 .90064 L
.09936 .93297 L
.10572 .94071 L
.13907 .98077 L
s
.01923 .81921 m
.02024 .82051 L
.05175 .86058 L
.05929 .87005 L
.08391 .90064 L
.09936 .91961 L
.1167 .94071 L
.13942 .96801 L
.15014 .98077 L
s
.01923 .80512 m
.03119 .82051 L
.05929 .85624 L
.06275 .86058 L
.09497 .90064 L
.09936 .90603 L
.12785 .94071 L
.13942 .95461 L
.16139 .98077 L
s
.01923 .79075 m
.04229 .82051 L
.05929 .84218 L
.0739 .86058 L
.09936 .89222 L
.1062 .90064 L
.13918 .94071 L
.13942 .941 L
.17282 .98077 L
s
.01923 .7761 m
.02256 .78045 L
.05355 .82051 L
.05929 .82785 L
.08523 .86058 L
.09936 .87816 L
.11761 .90064 L
.13942 .92715 L
.15069 .94071 L
.17949 .97492 L
.18446 .98077 L
s
.01923 .76113 m
.03395 .78045 L
.05929 .81324 L
.06498 .82051 L
.09675 .86058 L
.09936 .86383 L
.12922 .90064 L
.13942 .91305 L
.1624 .94071 L
.17949 .961 L
.1963 .98077 L
s
.98077 .03616 m
.96956 .01923 L
s
.01923 .74584 m
.04551 .78045 L
.05929 .79833 L
.07661 .82051 L
.09936 .84923 L
.10845 .86058 L
.13942 .8987 L
.14102 .90064 L
.17432 .94071 L
.17949 .94684 L
.20836 .98077 L
s
.98077 .05513 m
.95706 .01923 L
s
.01923 .7302 m
.02685 .74038 L
.05726 .78045 L
.05929 .7831 L
.08843 .82051 L
.09936 .83433 L
.12036 .86058 L
.13942 .88406 L
.15303 .90064 L
.17949 .93241 L
.18647 .94071 L
.21955 .97948 L
.22066 .98077 L
s
.98077 .07455 m
.97099 .05929 L
.94434 .01923 L
s
.01923 .71418 m
.03874 .74038 L
.05929 .76753 L
.06921 .78045 L
.09936 .81912 L
.10046 .82051 L
.13248 .86058 L
.13942 .86913 L
.16528 .90064 L
.17949 .91771 L
.19885 .94071 L
.21955 .96494 L
.23321 .98077 L
s
.98077 .09446 m
.9583 .05929 L
.94071 .03288 L
.93136 .01923 L
s
.01923 .69775 m
.02111 .70032 L
.05084 .74038 L
.05929 .75159 L
.08137 .78045 L
.09936 .80357 L
.11271 .82051 L
.13942 .85389 L
.14484 .86058 L
.17777 .90064 L
.17949 .90271 L
.21149 .94071 L
.21955 .95013 L
.24604 .98077 L
s
.98077 .11489 m
.97114 .09936 L
.94537 .05929 L
.94071 .05228 L
.91812 .01923 L
s
.01923 .68088 m
.03339 .70032 L
.05929 .73525 L
.06316 .74038 L
.09377 .78045 L
.09936 .78765 L
.12519 .82051 L
.13942 .83832 L
.15744 .86058 L
.17949 .8874 L
.19051 .90064 L
.21955 .93503 L
.22441 .94071 L
.25916 .98077 L
s
.98077 .13589 m
.95822 .09936 L
.94071 .07217 L
.93218 .05929 L
.9046 .01923 L
s
.01923 .66353 m
.04588 .70032 L
.05929 .71848 L
.07571 .74038 L
.09936 .77135 L
.1064 .78045 L
.13793 .82051 L
.13942 .82238 L
.1703 .86058 L
.17949 .87175 L
.20352 .90064 L
.21955 .9196 L
.23761 .94071 L
.25962 .96602 L
.27258 .98077 L
s
.98077 .15751 m
.96995 .13942 L
.94505 .09936 L
.94071 .0926 L
.9187 .05929 L
.90064 .03313 L
.89078 .01923 L
s
.01923 .64566 m
.0296 .66026 L
.05861 .70032 L
.05929 .70125 L
.08851 .74038 L
.09936 .75463 L
.11929 .78045 L
.13942 .80606 L
.15093 .82051 L
.17949 .85575 L
.18345 .86058 L
.21685 .90064 L
.21955 .90384 L
.25114 .94071 L
.25962 .95044 L
.28635 .98077 L
s
.98077 .17982 m
.98057 .17949 L
.95676 .13942 L
.94071 .11361 L
.93159 .09936 L
.90492 .05929 L
.90064 .05309 L
.87664 .01923 L
s
.01923 .6272 m
.04254 .66026 L
.05929 .68352 L
.0716 .70032 L
.09936 .73745 L
.10158 .74038 L
.13246 .78045 L
.13942 .78933 L
.16423 .82051 L
.17949 .83936 L
.1969 .86058 L
.21955 .88772 L
.23048 .90064 L
.25962 .93452 L
.26501 .94071 L
.29968 .97985 L
.3005 .98077 L
s
.98077 .20288 m
.96733 .17949 L
.94328 .13942 L
.94071 .13526 L
.91782 .09936 L
.90064 .0736 L
.89082 .05929 L
.86214 .01923 L
s
.01923 .60811 m
.02756 .62019 L
.05574 .66026 L
.05929 .66522 L
.08487 .70032 L
.09936 .71979 L
.11493 .74038 L
.13942 .77215 L
.14592 .78045 L
.17784 .82051 L
.17949 .82255 L
.21068 .86058 L
.21955 .8712 L
.24447 .90064 L
.25962 .91822 L
.27925 .94071 L
.29968 .96371 L
.31504 .98077 L
s
.98077 .22677 m
.97676 .21955 L
.9538 .17949 L
.94071 .15761 L
.9295 .13942 L
.90372 .09936 L
.90064 .09473 L
.87637 .05929 L
.86058 .03725 L
.84728 .01923 L
s
.01923 .5883 m
.04101 .62019 L
.05929 .64631 L
.06923 .66026 L
.09843 .70032 L
.09936 .70157 L
.12859 .74038 L
.13942 .75447 L
.1597 .78045 L
.17949 .8053 L
.19177 .82051 L
.21955 .85427 L
.22481 .86058 L
.25885 .90064 L
.25962 .90153 L
.2939 .94071 L
.29968 .94719 L
.33003 .98077 L
s
.98077 .2516 m
.96314 .21955 L
.94071 .18074 L
.93996 .17949 L
.91537 .13942 L
.90064 .11651 L
.88928 .09936 L
.86154 .05929 L
.86058 .05795 L
.832 .01923 L
s
.01923 .5677 m
.02749 .58013 L
.05476 .62019 L
.05929 .62672 L
.08303 .66026 L
.09936 .68276 L
.11231 .70032 L
.13942 .73626 L
.14258 .74038 L
.17383 .78045 L
.17949 .78756 L
.20608 .82051 L
.21955 .83689 L
.23933 .86058 L
.25962 .88442 L
.27362 .90064 L
.29968 .93027 L
.309 .94071 L
.33974 .97451 L
.34551 .98077 L
s
.98077 .27749 m
.9713 .25962 L
.94921 .21955 L
.94071 .20473 L
.92578 .17949 L
.90089 .13942 L
.90064 .13903 L
.87445 .09936 L
.86058 .07929 L
.84631 .05929 L
.82051 .02473 L
.81628 .01923 L
s
.01923 .54619 m
.04154 .58013 L
.05929 .60638 L
.06883 .62019 L
.09717 .66026 L
.09936 .66329 L
.12654 .70032 L
.13942 .71747 L
.15693 .74038 L
.17949 .76929 L
.18834 .78045 L
.21955 .81901 L
.22079 .82051 L
.25428 .86058 L
.25962 .86684 L
.28887 .90064 L
.29968 .9129 L
.32459 .94071 L
.33974 .95728 L
.36154 .98077 L
s
.98077 .30459 m
.97827 .29968 L
.95724 .25962 L
.94071 .22969 L
.93493 .21955 L
.91122 .17949 L
.90064 .16236 L
.88603 .13942 L
.86058 .10134 L
.85921 .09936 L
.83063 .05929 L
.82051 .04574 L
.80008 .01923 L
s
.01923 .52365 m
.02969 .54006 L
.05592 .58013 L
.05929 .58516 L
.08326 .62019 L
.09936 .64308 L
.11167 .66026 L
.13942 .69802 L
.14114 .70032 L
.17167 .74038 L
.17949 .75043 L
.20325 .78045 L
.21955 .8006 L
.23592 .82051 L
.25962 .84876 L
.26969 .86058 L
.29968 .89506 L
.30461 .90064 L
.33974 .9396 L
.34075 .94071 L
.37819 .98077 L
s
.98077 .33309 m
.96402 .29968 L
.94281 .25962 L
.94071 .25576 L
.92026 .21955 L
.90064 .18661 L
.89627 .17949 L
.87074 .13942 L
.86058 .12416 L
.84352 .09936 L
.82051 .06743 L
.81445 .05929 L
.78333 .01923 L
s
.01923 .49987 m
.01931 .5 L
.04443 .54006 L
.05929 .56298 L
.07068 .58013 L
.09807 .62019 L
.09936 .62204 L
.12656 .66026 L
.13942 .67785 L
.15615 .70032 L
.17949 .73092 L
.18684 .74038 L
.21863 .78045 L
.21955 .78159 L
.25154 .82051 L
.25962 .83013 L
.28562 .86058 L
.29968 .8767 L
.32092 .90064 L
.33974 .92142 L
.35751 .94071 L
.37981 .96438 L
.39551 .98077 L
s
.98077 .36323 m
.96953 .33974 L
.94941 .29968 L
.94071 .28309 L
.92799 .25962 L
.90518 .21955 L
.90064 .21188 L
.88089 .17949 L
.86058 .14786 L
.85499 .13942 L
.82733 .09936 L
.82051 .08988 L
.79775 .05929 L
.78045 .03713 L
.76599 .01923 L
s
.01923 .47469 m
.03448 .5 L
.05929 .53964 L
.05957 .54006 L
.08585 .58013 L
.09936 .60006 L
.11329 .62019 L
.13942 .65687 L
.14189 .66026 L
.17161 .70032 L
.17949 .71069 L
.20247 .74038 L
.21955 .76193 L
.23449 .78045 L
.25962 .81089 L
.2677 .82051 L
.29968 .85776 L
.30214 .86058 L
.33787 .90064 L
.33974 .9027 L
.375 .94071 L
.37981 .94577 L
.41365 .98077 L
s
.98077 .39535 m
.9737 .37981 L
.95466 .33974 L
.94071 .3119 L
.93438 .29968 L
.91273 .25962 L
.90064 .23832 L
.88965 .21955 L
.86502 .17949 L
.86058 .17253 L
.83873 .13942 L
.82051 .11317 L
.8106 .09936 L
.78045 .05932 L
.78043 .05929 L
.74798 .01923 L
s
.01923 .44776 m
.02624 .45994 L
.05007 .5 L
.05929 .51499 L
.07514 .54006 L
.09936 .57699 L
.10147 .58013 L
.12898 .62019 L
.13942 .63496 L
.15768 .66026 L
.17949 .68965 L
.18756 .70032 L
.21864 .74038 L
.21955 .74154 L
.25092 .78045 L
.25962 .79098 L
.28445 .82051 L
.29968 .83821 L
.31929 .86058 L
.33974 .88338 L
.35552 .90064 L
.37981 .9266 L
.39327 .94071 L
.41987 .96791 L
.4327 .98077 L
s
.98077 .42989 m
.97646 .41987 L
.95853 .37981 L
.94071 .34245 L
.93937 .33974 L
.91888 .29968 L
.90064 .26612 L
.89699 .25962 L
.87362 .21955 L
.86058 .19831 L
.84864 .17949 L
.8219 .13942 L
.82051 .13742 L
.79325 .09936 L
.78045 .08235 L
.76245 .05929 L
.74038 .03237 L
.72922 .01923 L
s
.01923 .41866 m
.01989 .41987 L
.04235 .45994 L
.05929 .48874 L
.06612 .5 L
.09121 .54006 L
.09936 .55266 L
.11757 .58013 L
.13942 .612 L
.14517 .62019 L
.174 .66026 L
.17949 .66769 L
.20406 .70032 L
.21955 .72034 L
.23537 .74038 L
.25962 .77033 L
.26796 .78045 L
.29968 .81796 L
.30188 .82051 L
.3372 .86058 L
.33974 .8634 L
.37402 .90064 L
.37981 .90678 L
.4125 .94071 L
.41987 .94816 L
.45285 .98077 L
s
.98077 .46752 m
.97771 .45994 L
.96091 .41987 L
.9429 .37981 L
.94071 .37512 L
.92358 .33974 L
.90287 .29968 L
.90064 .29552 L
.88073 .25962 L
.86058 .22538 L
.85703 .21955 L
.83166 .17949 L
.82051 .16273 L
.80446 .13942 L
.78045 .10631 L
.77522 .09936 L
.7437 .05929 L
.74038 .05526 L
.70959 .01923 L
s
.01923 .38681 m
.03663 .41987 L
.05897 .45994 L
.05929 .46051 L
.08271 .5 L
.09936 .52681 L
.10781 .54006 L
.13422 .58013 L
.13942 .5878 L
.16192 .62019 L
.17949 .64468 L
.19091 .66026 L
.21955 .69819 L
.22119 .70032 L
.25278 .74038 L
.25962 .74884 L
.28571 .78045 L
.29968 .79693 L
.32007 .82051 L
.33974 .84269 L
.35593 .86058 L
.37981 .88627 L
.39345 .90064 L
.41987 .92774 L
.43281 .94071 L
.45994 .96712 L
.47429 .98077 L
s
.98077 .50925 m
.97732 .5 L
.9617 .45994 L
.94487 .41987 L
.94071 .41041 L
.92673 .37981 L
.90723 .33974 L
.90064 .32682 L
.88632 .29968 L
.86388 .25962 L
.86058 .25394 L
.83985 .21955 L
.82051 .18928 L
.81404 .17949 L
.7863 .13942 L
.78045 .13134 L
.75642 .09936 L
.74038 .07909 L
.7241 .05929 L
.70032 .03182 L
.68898 .01923 L
s
.01923 .35118 m
.03316 .37981 L
.05391 .41987 L
.05929 .42984 L
.07617 .45994 L
.09936 .49913 L
.09989 .5 L
.125 .54006 L
.13942 .56215 L
.15147 .58013 L
.17931 .62019 L
.17949 .62044 L
.20847 .66026 L
.21955 .675 L
.23899 .70032 L
.25962 .7264 L
.27091 .74038 L
.29968 .77503 L
.30427 .78045 L
.33917 .82051 L
.33974 .82116 L
.37569 .86058 L
.37981 .86497 L
.41404 .90064 L
.41987 .90654 L
.45448 .94071 L
.45994 .94592 L
.49739 .98077 L
s
.98077 .55683 m
.9751 .54006 L
.96074 .5 L
.94514 .45994 L
.94071 .4491 L
.92823 .41987 L
.90996 .37981 L
.90064 .36047 L
.89029 .33974 L
.86913 .29968 L
.86058 .28427 L
.8464 .25962 L
.82196 .21955 L
.82051 .21727 L
.79568 .17949 L
.78045 .15758 L
.76735 .13942 L
.74038 .10399 L
.73672 .09936 L
.70348 .05929 L
.70032 .05566 L
.66719 .01923 L
s
.01923 .30996 m
.03228 .33974 L
.05124 .37981 L
.05929 .39588 L
.07185 .41987 L
.09404 .45994 L
.09936 .46917 L
.11771 .5 L
.13942 .53472 L
.14286 .54006 L
.16942 .58013 L
.17949 .59478 L
.19739 .62019 L
.21955 .65057 L
.22678 .66026 L
.25762 .70032 L
.25962 .70285 L
.28991 .74038 L
.29968 .75213 L
.32376 .78045 L
.33974 .79871 L
.35927 .82051 L
.37981 .84279 L
.3966 .86058 L
.41987 .8845 L
.43598 .90064 L
.45994 .92389 L
.47776 .94071 L
.5 .96094 L
.52249 .98077 L
s
.98077 .61383 m
.97081 .58013 L
.95783 .54006 L
.94355 .5 L
.94071 .49243 L
.92793 .45994 L
.91093 .41987 L
.90064 .39709 L
.89253 .37981 L
.87266 .33974 L
.86058 .31678 L
.85124 .29968 L
.82816 .25962 L
.82051 .24697 L
.80331 .21955 L
.78045 .18524 L
.77647 .17949 L
.74747 .13942 L
.74038 .13011 L
.71601 .09936 L
.70032 .0806 L
.68171 .05929 L
.66026 .03604 L
.64403 .01923 L
s
.01923 .25913 m
.0194 .25962 L
.03443 .29968 L
.05134 .33974 L
.05929 .35729 L
.07007 .37981 L
.09054 .41987 L
.09936 .43623 L
.11263 .45994 L
.1363 .5 L
.13942 .50511 L
.16147 .54006 L
.17949 .56737 L
.18814 .58013 L
.21631 .62019 L
.21955 .62467 L
.24595 .66026 L
.25962 .67805 L
.27713 .70032 L
.29968 .72809 L
.3099 .74038 L
.33974 .77519 L
.34436 .78045 L
.37981 .8196 L
.38065 .82051 L
.41898 .86058 L
.41987 .86148 L
.45967 .90064 L
.45994 .90089 L
.5 .93784 L
.5032 .94071 L
.54006 .97225 L
.55038 .98077 L
s
.98077 .68986 m
.97419 .66026 L
.96412 .62019 L
.95267 .58013 L
.94071 .54263 L
.93984 .54006 L
.9256 .5 L
.90995 .45994 L
.90064 .43765 L
.89289 .41987 L
.87435 .37981 L
.86058 .352 L
.85427 .33974 L
.83256 .29968 L
.82051 .27873 L
.8091 .25962 L
.78374 .21955 L
.78045 .21458 L
.75631 .17949 L
.74038 .15766 L
.72653 .13942 L
.70032 .1068 L
.69408 .09936 L
.66026 .06119 L
.65849 .05929 L
.62019 .02025 L
.61914 .01923 L
s
.01923 .18528 m
.02791 .21955 L
.0402 .25962 L
.05471 .29968 L
.05929 .31135 L
.07128 .33974 L
.08978 .37981 L
.09936 .39918 L
.11007 .41987 L
.13208 .45994 L
.13942 .47269 L
.15571 .5 L
.17949 .53778 L
.18097 .54006 L
.20777 .58013 L
.21955 .59703 L
.23615 .62019 L
.25962 .65173 L
.26613 .66026 L
.29775 .70032 L
.29968 .70269 L
.33108 .74038 L
.33974 .75045 L
.36626 .78045 L
.37981 .79527 L
.4035 .82051 L
.41987 .83737 L
.44308 .86058 L
.45994 .87682 L
.48547 .90064 L
.5 .91365 L
.53144 .94071 L
.54006 .94777 L
.58013 .9791 L
.58234 .98077 L
s
.9568 .98077 m
.9679 .94071 L
.97416 .90064 L
.97675 .86058 L
.97646 .82051 L
.97381 .78045 L
.96914 .74038 L
.96268 .70032 L
.95455 .66026 L
.94486 .62019 L
.94071 .6046 L
.93366 .58013 L
.92096 .54006 L
.90678 .5 L
.90064 .48381 L
.89114 .45994 L
.874 .41987 L
.86058 .39077 L
.8553 .37981 L
.83499 .33974 L
.82051 .31307 L
.81295 .29968 L
.78906 .25962 L
.78045 .24594 L
.76316 .21955 L
.74038 .1869 L
.735 .17949 L
.70431 .13942 L
.70032 .13448 L
.6707 .09936 L
.66026 .08768 L
.63359 .05929 L
.62019 .04586 L
.59215 .01923 L
s
.91951 .98077 m
.93638 .94071 L
.94071 .92607 L
.94588 .90064 L
.95073 .86058 L
.95213 .82051 L
.95077 .78045 L
.94709 .74038 L
.94136 .70032 L
.94071 .69629 L
.93379 .66026 L
.92449 .62019 L
.91355 .58013 L
.90102 .54006 L
.90064 .53891 L
.88698 .5 L
.87134 .45994 L
.86058 .43444 L
.85413 .41987 L
.83527 .37981 L
.82051 .35075 L
.81468 .33974 L
.79228 .29968 L
.78045 .27983 L
.76789 .25962 L
.74131 .21955 L
.74038 .21821 L
.71234 .17949 L
.70032 .1639 L
.68058 .13942 L
.66026 .11572 L
.64553 .09936 L
.62019 .07286 L
.60649 .05929 L
.58013 .0348 L
.56234 .01923 L
s
.62079 .98077 m
.62019 .98036 L
.58013 .95281 L
.56375 .94071 L
.54006 .92202 L
.51426 .90064 L
.5 .88819 L
.46953 .86058 L
.45994 .85148 L
.42828 .82051 L
.41987 .81196 L
.3898 .78045 L
.37981 .76959 L
.35367 .74038 L
.33974 .72425 L
.31962 .70032 L
.29968 .67572 L
.28748 .66026 L
.25962 .62357 L
.25712 .62019 L
.22845 .58013 L
.21955 .56719 L
.20145 .54006 L
.17949 .50545 L
.17615 .5 L
.1525 .45994 L
.13942 .43643 L
.1306 .41987 L
.11048 .37981 L
.09936 .35591 L
.09227 .33974 L
.07607 .29968 L
.06206 .25962 L
.05929 .25116 L
.05045 .21955 L
.04152 .17949 L
.0356 .13942 L
.03323 .09936 L
.03513 .05929 L
.04245 .01923 L
s
.86757 .98077 m
.89765 .94071 L
.90064 .93457 L
.91329 .90064 L
.92173 .86058 L
.92546 .82051 L
.92574 .78045 L
.92326 .74038 L
.91844 .70032 L
.91153 .66026 L
.90273 .62019 L
.90064 .61161 L
.89219 .58013 L
.87993 .54006 L
.86599 .5 L
.86058 .48559 L
.8504 .45994 L
.8331 .41987 L
.82051 .39298 L
.81405 .37981 L
.79317 .33974 L
.78045 .317 L
.77033 .29968 L
.74534 .25962 L
.74038 .25208 L
.71803 .21955 L
.70032 .19547 L
.68803 .17949 L
.66026 .14564 L
.6549 .13942 L
.62019 .10159 L
.61804 .09936 L
.58013 .06263 L
.57648 .05929 L
.54006 .02835 L
.52858 .01923 L
s
.67182 .98077 m
.66026 .97433 L
.62019 .95163 L
.6028 .94071 L
.58013 .92498 L
.54743 .90064 L
.54006 .89475 L
.5 .86125 L
.49923 .86058 L
.45994 .82466 L
.45558 .82051 L
.41987 .78502 L
.41543 .78045 L
.37981 .74228 L
.37809 .74038 L
.34312 .70032 L
.33974 .6963 L
.31027 .66026 L
.29968 .64678 L
.27939 .62019 L
.25962 .59315 L
.25038 .58013 L
.22317 .54006 L
.21955 .53454 L
.19772 .5 L
.17949 .46938 L
.17409 .45994 L
.15227 .41987 L
.13942 .3945 L
.13237 .37981 L
.11446 .33974 L
.09936 .3014 L
.09874 .29968 L
.0853 .25962 L
.07446 .21955 L
.06653 .17949 L
.06196 .13942 L
.06139 .09936 L
.06579 .05929 L
.07685 .01923 L
s
.48873 .01923 m
.5 .0271 L
.54006 .05741 L
.54238 .05929 L
.58013 .09239 L
.58753 .09936 L
.62019 .13236 L
.62677 .13942 L
.66026 .17788 L
.66158 .17949 L
.69287 .21955 L
.70032 .22974 L
.72116 .25962 L
.74038 .28928 L
.74682 .29968 L
.77019 .33974 L
.78045 .35863 L
.79142 .37981 L
.81068 .41987 L
.82051 .44202 L
.82805 .45994 L
.84362 .5 L
.85735 .54006 L
.86058 .55022 L
.8693 .58013 L
.87939 .62019 L
.8875 .66026 L
.89347 .70032 L
.89703 .74038 L
.8978 .78045 L
.89512 .82051 L
.88783 .86058 L
.87327 .90064 L
.86058 .92171 L
.84532 .94071 L
.82051 .95681 L
.78045 .96865 L
.74038 .9677 L
.70032 .95814 L
.66026 .94212 L
.65708 .94071 L
.62019 .92088 L
.58782 .90064 L
.58013 .89521 L
.54006 .86565 L
.53358 .86058 L
.5 .83255 L
.48631 .82051 L
.45994 .79606 L
.44377 .78045 L
Mistroke
.41987 .75624 L
.40475 .74038 L
.37981 .71304 L
.36858 .70032 L
.33974 .66621 L
.33486 .66026 L
.30333 .62019 L
.29968 .61537 L
.27383 .58013 L
.25962 .55977 L
.24631 .54006 L
.22074 .5 L
.21955 .49807 L
.19704 .45994 L
.17949 .42783 L
.17535 .41987 L
.15565 .37981 L
.13942 .34286 L
.13815 .33974 L
.12291 .29968 L
.11022 .25962 L
.10037 .21955 L
.09936 .21458 L
.0937 .17949 L
.09085 .13942 L
.09269 .09936 L
.09936 .0641 L
.1007 .05929 L
.11752 .01923 L
Mfstroke
.4375 .01923 m
.45994 .03201 L
.5 .05797 L
.50189 .05929 L
.54006 .08873 L
.55265 .09936 L
.58013 .12451 L
.59532 .13942 L
.62019 .16572 L
.63245 .17949 L
.66026 .21306 L
.66535 .21955 L
.69484 .25962 L
.70032 .26757 L
.72142 .29968 L
.74038 .33107 L
.74537 .33974 L
.76705 .37981 L
.78045 .40689 L
.78653 .41987 L
.80401 .45994 L
.81945 .5 L
.82051 .50292 L
.83299 .54006 L
.84451 .58013 L
.85393 .62019 L
.86058 .65652 L
.8611 .66026 L
.86584 .70032 L
.86768 .74038 L
.86593 .78045 L
.86058 .818 L
.85937 .82051 L
.84577 .86058 L
.82051 .89612 L
.81752 .90064 L
.78045 .92054 L
.74038 .92601 L
.70032 .92038 L
.66026 .90695 L
.64465 .90064 L
.62019 .88751 L
.58013 .86307 L
.57633 .86058 L
.54006 .83433 L
.52239 .82051 L
.5 .80165 L
.47607 .78045 L
.45994 .76525 L
.43457 .74038 L
Mistroke
.41987 .72518 L
.39667 .70032 L
.37981 .68133 L
.36172 .66026 L
.33974 .63339 L
.32932 .62019 L
.29968 .58073 L
.29924 .58013 L
.27127 .54006 L
.25962 .52237 L
.24545 .5 L
.22174 .45994 L
.21955 .45607 L
.2001 .41987 L
.18072 .37981 L
.17949 .37713 L
.16361 .33974 L
.14904 .29968 L
.13942 .26814 L
.13727 .25962 L
.12859 .21955 L
.12359 .17949 L
.12307 .13942 L
.12837 .09936 L
.13942 .06409 L
.14197 .05929 L
.16976 .01923 L
Mfstroke
.34023 .01923 m
.37981 .02913 L
.41987 .04471 L
.44942 .05929 L
.45994 .06557 L
.5 .09164 L
.51065 .09936 L
.54006 .12291 L
.55892 .13942 L
.58013 .15968 L
.59948 .17949 L
.62019 .20248 L
.63468 .21955 L
.66026 .25221 L
.66574 .25962 L
.69346 .29968 L
.70032 .31035 L
.71826 .33974 L
.74038 .37978 L
.7404 .37981 L
.76024 .41987 L
.77774 .45994 L
.78045 .46656 L
.79311 .5 L
.80629 .54006 L
.81717 .58013 L
.82051 .59354 L
.8257 .62019 L
.83165 .66026 L
.83455 .70032 L
.8337 .74038 L
.82771 .78045 L
.82051 .80545 L
.81403 .82051 L
.78075 .86058 L
.78045 .86077 L
.74038 .87734 L
.70032 .87759 L
.66026 .8678 L
.63765 .86058 L
.62019 .85075 L
.58013 .8279 L
.56847 .82051 L
.54006 .80015 L
.51469 .78045 L
.5 .76796 L
.46908 .74038 L
.45994 .73162 L
.42852 .70032 L
.41987 .69116 L
Mistroke
.39173 .66026 L
.37981 .6464 L
.35804 .62019 L
.33974 .59688 L
.32708 .58013 L
.29968 .54162 L
.29862 .54006 L
.27242 .5 L
.25962 .47897 L
.24859 .45994 L
.22707 .41987 L
.21955 .4048 L
.20797 .37981 L
.19142 .33974 L
.17949 .30558 L
.17771 .29968 L
.16704 .25962 L
.16 .21955 L
.15733 .17949 L
.16025 .13942 L
.17117 .09936 L
.17949 .08157 L
.19528 .05929 L
.21955 .0394 L
.25962 .02119 L
.26767 .01923 L
Mfstroke
.25962 .07475 m
.29968 .06191 L
.33974 .06097 L
.37981 .06839 L
.41987 .08264 L
.4542 .09936 L
.45994 .10297 L
.5 .12905 L
.51406 .13942 L
.54006 .16094 L
.56057 .17949 L
.58013 .199 L
.59936 .21955 L
.62019 .24394 L
.63278 .25962 L
.66026 .29711 L
.66203 .29968 L
.68797 .33974 L
.70032 .3608 L
.71083 .37981 L
.731 .41987 L
.74038 .4405 L
.74859 .45994 L
.76376 .5 L
.77636 .54006 L
.78045 .55436 L
.78638 .58013 L
.79362 .62019 L
.79756 .66026 L
.79744 .70032 L
.79164 .74038 L
.78045 .77296 L
.77676 .78045 L
.74038 .81649 L
.73165 .82051 L
.70032 .8271 L
.66026 .8229 L
.65116 .82051 L
.62019 .80929 L
.58013 .78858 L
.56632 .78045 L
.54006 .76212 L
.5115 .74038 L
.5 .73056 L
.46619 .70032 L
.45994 .69422 L
.4264 .66026 L
.41987 .65315 L
.39071 .62019 L
.37981 .60702 L
Mistroke
.3584 .58013 L
.33974 .55506 L
.32906 .54006 L
.30243 .5 L
.29968 .49563 L
.27835 .45994 L
.25962 .4251 L
.25699 .41987 L
.23822 .37981 L
.22244 .33974 L
.21955 .3322 L
.20977 .29968 L
.20073 .25962 L
.19607 .21955 L
.19699 .17949 L
.20589 .13942 L
.21955 .11105 L
.22827 .09936 L
.25962 .07475 L
Mfstroke
.29968 .12057 m
.33974 .11138 L
.37981 .11456 L
.41987 .12653 L
.45029 .13942 L
.45994 .1458 L
.5 .17179 L
.51044 .17949 L
.54006 .20449 L
.55627 .21955 L
.58013 .2444 L
.5937 .25962 L
.62019 .29263 L
.62548 .29968 L
.65304 .33974 L
.66026 .35132 L
.67694 .37981 L
.69753 .41987 L
.70032 .42572 L
.71527 .45994 L
.73004 .5 L
.74038 .5347 L
.74171 .54006 L
.75036 .58013 L
.75529 .62019 L
.75555 .66026 L
.74892 .70032 L
.74038 .72354 L
.7327 .74038 L
.70032 .7623 L
.66026 .76869 L
.62019 .76065 L
.58013 .74316 L
.57448 .74038 L
.54006 .71857 L
.51474 .70032 L
.5 .68783 L
.46887 .66026 L
.45994 .6514 L
.42958 .62019 L
.41987 .60927 L
.39498 .58013 L
.37981 .56084 L
.3642 .54006 L
.33974 .50452 L
.3368 .5 L
.31231 .45994 L
.29968 .43694 L
.29103 .41987 L
.27278 .37981 L
Mistroke
.25962 .34466 L
.25808 .33974 L
.247 .29968 L
.24051 .25962 L
.23987 .21955 L
.24785 .17949 L
.25962 .15408 L
.2705 .13942 L
.29968 .12057 L
Mfstroke
.37981 .17326 m
.41663 .17949 L
.41987 .18045 L
.45994 .19745 L
.49606 .21955 L
.5 .22316 L
.54006 .25714 L
.54269 .25962 L
.57972 .29968 L
.58013 .30019 L
.61047 .33974 L
.62019 .35436 L
.63601 .37981 L
.65735 .41987 L
.66026 .42579 L
.67514 .45994 L
.68921 .5 L
.69908 .54006 L
.70032 .54694 L
.70466 .58013 L
.7042 .62019 L
.70032 .641 L
.69633 .66026 L
.66026 .69422 L
.62019 .69872 L
.58013 .68752 L
.54006 .66595 L
.53069 .66026 L
.5 .63649 L
.48066 .62019 L
.45994 .59973 L
.44101 .58013 L
.41987 .55545 L
.40737 .54006 L
.37981 .50209 L
.37838 .5 L
.35303 .45994 L
.33974 .43577 L
.33186 .41987 L
.31434 .37981 L
.30144 .33974 L
.29968 .33261 L
.29342 .29968 L
.29212 .25962 L
.29968 .22491 L
.30134 .21955 L
.33974 .18053 L
.34242 .17949 L
.37981 .17326 L
s
.41987 .25809 m
.43258 .25962 L
.45994 .26798 L
.5 .29243 L
.5103 .29968 L
.54006 .32894 L
.5501 .33974 L
.57969 .37981 L
.58013 .38054 L
.60377 .41987 L
.62019 .45955 L
.62032 .45994 L
.6327 .5 L
.63833 .54006 L
.63211 .58013 L
.62019 .59645 L
.58013 .60775 L
.54006 .59419 L
.51741 .58013 L
.5 .56743 L
.46787 .54006 L
.45994 .52925 L
.43464 .5 L
.41987 .47837 L
.408 .45994 L
.38624 .41987 L
.37981 .41007 L
.37107 .37981 L
.36176 .33974 L
.3625 .29968 L
.37981 .27218 L
.40307 .25962 L
.41987 .25809 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`007`3oool00`3o_g@000000000
000300000003001d_`3oool0oooo0080oooo00<0_g@000000000M;l0103oool00`3o_g@000000000
000300000003001d_`3oool0oooo03h0oooo00<0okmd0000000000000`0000000`00M;l0oooo0?oo
o`020?ooo`030;md0000000007Bo00D0oooo00D0okmd000000000000000007Boo`040?ooo`050;md
0000000000000000001d_ol0BP3oool00`3o_g@000000000000300000003001d_`3oool0oooo04P0
oooo00D0okmd000000000000000007Boo`050?ooo`030;md0000000007Bo00@0oooo00D0omnL04P0
000000000000001d_`050?ooo`050;md0000000000000000001d_ol0@P3oool01@3o_g@000000000
00000000M;oo00D0oooo00<0_g@000000000M;l0103oool01@3ogi`0B00000000000000007Bo00@0
oooo000R0?ooo`0309a8B02Lgol0oooo00D0oooo00<0_g@000000000M;l01`3oool00`2LB4P0W=oo
0?ooo`140?ooo`0309a8B02Lgol0oooo00D0oooo00<0_g@000000000M;l01@3oool01P2LB7@0_ooo
0?ooo`3ookl0M01d0;ooo`80oooo00L0_g@0001d_`3oool0oooo0?oOW0180000M;oo04`0oooo00<0
W4Q809cOo`3oool0B`3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000
M;l0203oool00`2oM00004RL0?ooo`020?ooo`070;md0000M;l0oooo0?ooo`3ogi`0B00007Boo`11
0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`080?ooo`030;md
0000B9`0oooo0080oooo000R0?ooo`0309a8B02Lgol0oooo00l0oooo00<0W4Q809cOo`3oool0A03o
ool00`2LB4P0W=oo0?ooo`0<0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool01P3o
ool00`3o_g@007Bo0?ooo`1;0?ooo`0309a8B02Lgol0oooo04X0oooo00<0okmd001d_`3oool00P3o
ool00`3OW4P0B9cO0?ooo`0?0?ooo`030;md0018W=l0oooo00H0oooo00<0okmd001d_`3oool0?`3o
ool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo00l0oooo00<0_g@004RLg`3oool00@3o
ool00280oooo00<0W4Q809cOo`3oool03`3oool00`2LB4P0W=oo0?ooo`140?ooo`0309a8B02Lgol0
oooo00`0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`060?ooo`030?noM000M;l0
oooo04/0oooo00<0W4Q809cOo`3oool0BP3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0
oooo00l0oooo00<0okmd0018W03oool01P3oool00`3o_g@007Bo0?ooo`0o0?ooo`030=nLB018W=l0
oooo0080oooo00<0okmd001d_`3oool03`3oool00`3o_g@004RL0?ooo`010?ooo`005P3oool00`2L
B000000000000003000000030018W03oool0oooo00<0oooo00<0W4Q809cOo`3oool03`3oool00`2L
B4P0W=oo0?ooo`0h0?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool00`3oool00`2L
B4P0W=oo0?ooo`0<0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool01P3oool00`2L
B000M;oo0?ooo`0o0?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool00`3oool00`2L
B4P0W=oo0?ooo`110?ooo`0309a800000000000000<0000000D004RL0?ooo`3oool0gia804RLg`03
0?ooo`030?noM000M;l0oooo00/0oooo00H0okmd000000000000000004QdM018B9`70?ooo`0309a8
001d_ol0oooo03H0oooo00<0W4P00000000000000`0000001@00B9`0oooo0?ooo`3OW4P0B9cO00<0
oooo00<0okmd001d_`3oool02`3oool01P3o_g@00000000000000000B7Ad04Q8W080oooo000R0?oo
o`0309a8B02Lgol0oooo00l0oooo00<0W4Q809cOo`3oool0A03oool00`2LB4P0W=oo0?ooo`0<0?oo
o`030=nLB018W=l0oooo0080oooo00H0okmd001d_`3oool0oooo0?oo_`1d00030000000304RLg`3o
ool0oooo04/0oooo00<0W4Q809cOo`3oool0BP3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000
M;l0oooo00X0oooo00<0oono07@0B02Lgol00P3oool01P2LB00004RL0?ooo`3oool0oono07@000<0
000000<0B9cO0?ooo`3oool0?`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0
oooo00<0oono07@0B02Lgol00P3oool00`2LB00004RL0?ooo`010?ooo`008P3oool00`2LB4P0W=oo
0?ooo`0?0?ooo`0309a8B02Lgol0oooo04@0oooo00<0W4Q809cOo`3oool0303oool00`3o_g@0B9cO
0?ooo`020?ooo`070=nLB018W=l0oooo0?ooo`3ookl0M01d0;ooo`1@0?ooo`0309a8B02Lgol0oooo
04X0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030?noM000M;l0oooo
0080oooo00L0omnL07BLg`3oool0oooo0?oo_`1d07@0_ooo04@0oooo00<0okmd04RLg`3oool00P3o
ool00`3OW4P0B9cO0?ooo`0:0?ooo`030?noM000M;l0oooo0080oooo00<0omnL07BLg`3oool00@3o
ool001l0oooo00D0gia800000000B9`0W4Q809cOo`0=0?ooo`050=nLB000000004RL09a8B02Lgol0
@P3oool01@3OW4P000000018W02LB4P0W=oo00h0oooo00H0W4P007Boo`3oool0omnL04P0M02oool2
0?ooo`030?oo_`1d07@0_ooo04d0oooo00D0gia800000000B9`0W4Q809cOo`1<0?ooo`0609a8001d
_ol0oooo0?oOW01807@0_ooo2`3oool01`3ookl0M01809cOo`3oool0oono07@0B02Lgol00P3oool0
0`3ookl0M01d0;ooo`150?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2`3oool01`3ookl0M018
09cOo`3oool0oono07@0B02Lgol00P3oool00240oooo00<0gia80000B02Lgol03`3oool00`3OW4P0
001809cOo`140?ooo`030=nLB00004P0W=oo00h0oooo00D0oono07@000000000001809cOo`030?oo
o`030?oo_`1d000000000080000000<0001d0;ooo`3oool0BP3oool00`3OW4P0001809cOo`1<0?oo
o`050?oo_`1d000000000000B02Lgol03@3oool01@3o_g@00000000000000000M;oo00<0oooo00<0
oono07@0000000000P0000000`0007@0_ooo0?ooo`100?ooo`050?oo_`1d000000000000B02Lgol0
3@3oool01@3o_g@00000000000000000M;oo00<0oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo000O0?ooool00000Q`00000;0?ooo`007`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003o
ool0oooo0?l0ooooP`3oool00`000000oooo0?ooo`090?ooo`0000<0oooo0?noM000000010000000
0`00M;l0oooo0?ooo`020?ooo`030;md0000000007Bo00H0oooo00D0omnL04P000000000000007Bo
o`050?ooo`030000003oool0oooo0?l0ooooP`3oool00`000000oooo0?ooo`090?ooo`00103oool0
0`2LB4P0W=oo0?ooo`050?ooo`030;md0000000007Bo00P0oooo00<0_g@007Boo`3oool01@3oool0
0`000000oooo0?ooo`3o0?oooh<0oooo00<000000?ooo`3oool02@3oool000@0oooo00<0W4Q809cO
o`3oool0403oool00`2oM000M;oo0?ooo`050?ooo`030000003oool0oooo0?l0ooooP`3oool00`00
0000oooo0?ooo`090?ooo`00103oool00`2LB4P0W=oo0?ooo`0<0?ooo`030=nLB0000000000000<0
000000<0M;oo0?ooo`3oool00`3oool4000000d0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool08P3oool2000001`0
oooo0P00000S0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`070?ooo`<000002`3oool000@0oooo00<0W4Q809cOo`3oool0303oool01P3o_g@0001d
0;ooo`3oool0_g@007Boo`H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0P0?oo
o`<00000803oool400000200oooo0P00000B0?ooo`8000003P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00T0oooo00040?ooo`0309a8B02Lgol0oooo00d0oooo00D0gia8001d_`3o
ool0_g@007Boo`060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07P3oool20000
02L0oooo1000000N0?ooo`8000004P3oool2000000d0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`090?ooo`00103oool00`2LB4P0W=oo0?ooo`0>0?ooo`0409a80018W=l0_g@007Bo
o`H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0M0?ooo`800000;@3oool40000
01`0oooo0P00000B0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool20000
00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00T0oooo00001P3oool0gia800000000B9`0W4Q809cOo`l0oooo00@0omnL04P0B018B000M;oo1P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01`0oooo0P00000c0?ooo`<000006`3o
ool200000140oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00T0oooo00030?ooo`030=nLB00004P0W=oo0100oooo00<0okmd0000001d_ol01P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01X0oooo0P00000h0?ooo`8000006`3oool0
0`000000oooo0?ooo`0?0?ooo`800000303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00T0oooo000O0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool06@3oool20000
03`0oooo0`00000I0?ooo`8000004@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0G0?ooo`800000@@3oool3000001P0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0:0?ooo`800000303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo01H0oooo0P0000160?ooo`8000005`3oool200000100oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0B03oool3000001H0oooo0P00000?0?ooo`800000
303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01@0oooo0P00001>0?ooo`8000005P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0500oooo0P00000E0?ooo`8000003`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`1C0?ooo`8000005@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05H0oooo0P00000D0?oo
o`8000003P3oool2000000/0oooo0P00000;0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000001@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0180oooo0P00001K0?ooo`800000503oool2000000h0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo0P0000080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00T0oooo000O0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`1M0?ooo`800000503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo000O0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool09P3ooolD000002P0oooo0P00000B0?ooo`8000003P3oool00`000000oooo0?oo
o`0:0?ooo`8000002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo000O
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0S
0?ooo`<00000503oool800000280oooo0P00000B0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool02@3oool001l0oooo0`00000;0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool08@3oool3000001l0oooo1P00000N0?ooo`8000004@3oool00`000000oooo0?ooo`0<0?oo
o`800000303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0P00000;0?oo
o`007`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool07P3oool4000002P0oooo0P00000N0?ooo`030000003oool0oooo00l0oooo0P00000>0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0K0?ooo`<00000;P3oool3000001`0oooo0P00000A0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01X0oooo0P00000d0?ooo`<000006`3o
ool200000100oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`007`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0g0?ooo`8000006`3oool00`000000oooo0?ooo`0>0?ooo`8000003@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool02@3oool001l0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo0P00000l
0?ooo`<000006@3oool200000100oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:
0?ooo`8000002@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0o0?oo
o`<00000603oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo000O0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo04<0oooo0P00000G0?ooo`8000003`3oool2000000`0oooo0P00000<0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool00000
00T0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo01H0oooo0P0000180?ooo`8000005`3oool2000000l0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0BP3oool2000001L0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`1=0?ooo`8000005P3oool00`000000oooo0?ooo`0=0?ooo`800000303oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?oo
o`3oool0000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000L0
oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo01@0oooo0P00001B0?ooo`8000005@3oool2000000l0oooo
00<000000?ooo`3oool02P3oool2000000/0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`1D0?ooo`8000005@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo000O
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`09
0?ooo`007`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02@3oool001l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0FP3oool2000001@0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool02@3oool001l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02X0oooo2@00000[0?ooo`8000004`3o
ool2000000h0oooo0P00000<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3o
ool001l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool09`3oool4000000T0oooo2P00000S0?ooo`8000004`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?oo
o`090?ooo`007`3oool3000000X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo02<0oooo1000000G0?ooo`<000008P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`8000002`3oool001l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0803oool4000001h0oooo0`00000P0?oo
o`8000004P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02@3oool001l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool07P3oool2000002D0oooo1000000N0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01d0oooo0P00000[0?ooo`<00000
703oool200000140oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01/0oooo0P00000`0?ooo`<000006`3o
ool200000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00T0oooo000O0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0<`3oool2
000001/0oooo00<000000?ooo`3oool03P3oool2000000h0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0I0?ooo`800000>03oool20000
01X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0603oool2000003`0
oooo0P00000I0?ooo`800000403oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05P3oool200000400oooo
0P00000I0?ooo`030000003oool0oooo00h0oooo0P00000=0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`120?ooo`800000603oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0AP3oool2000001L0oooo0P00000@0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02@3oool001l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
B`3oool2000001L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo04l0oooo0P00000F0?ooo`8000003`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00T0oooo000O0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0D@3oool20000
01H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00T0oooo000O0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool001l0oooo0`00000<0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo05D0oooo0P00000E0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo0P00000;0?ooo`00
7`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0F@3oool2000001@0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo05/0oooo0P00000C0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool0
01l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0]0?ooo`D00000;03oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool001l0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0X0?ooo`D000001@3oool4000002T0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0
oooo000O0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0903oool5000000h0oooo
1@00000U0?ooo`8000004P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo
000O0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0803oool4000001P0oooo1P00
000Q0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo0P0000060?ooo`030000003oool0oooo00T0oooo000O
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P
0?ooo`800000803oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo000O0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo02<0oooo0P00000O0?ooo`8000004@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`007`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0V0?ooo`8000007`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02T0oooo0P00000N0?ooo`030000
003oool0oooo00l0oooo0P00000=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0/0?ooo`8000007@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo02l0oooo0P00000L0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool0
01l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0<P3oool2000001/0oooo0P00000A0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00T0oooo000O0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo03D0oooo0P00000K0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0>03oool2000001X0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0k0?ooo`8000006@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool001l0oooo0`0000070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`100?oo
o`800000603oool2000000l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?oo
o`8000002`3oool001l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0@`3oool2000001P0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool02@3oool001l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0AP3oool2000001L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
2@3oool001l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00T0oooo000O0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0C03oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0C`3oool2000001D0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo000O
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0DP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
2@3oool001l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`007`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00000`3oool0okmd000000040000
0003001d_`3oool0oooo0080oooo00<0_g@000000000M;l01@3oool01@2oM0000000000000000000
M;oo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0F03oool2000001@0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00040?ooo`0309a8B02Lgol0oooo
00D0oooo00<0_g@000000000M;l0103oool01`2oM00007Bo0?ooo`3oool0omnL04P0001d_ol01@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00040?ooo`0309a8B02Lgol0
oooo0140oooo00<0okmd001d_`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`00103oool00`2L
B4P0W=oo0?ooo`0A0?ooo`030?noM000M;l0oooo00@0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0;03oool50000
02`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00T0oooo00040?ooo`0309a8B02Lgol0oooo0140oooo00<0W4P007Boo`3oool0103oool4000000@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0:03oool4000000D0oooo1000000Y0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01P3oool3000000/0oooo00040?ooo`0309a8B02Lgol0oooo00`0oooo
00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool09P3oool2000000d0oooo1000000V0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`00103oool00`2LB4P0W=oo0?oo
o`0<0?ooo`030?oo_`1d07@0_ooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0T0?ooo`8000004`3oool4000002<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00T0oooo00001P3oool0gia800000000B9`0W4Q809cOo`d0oooo
00<0oono07@0M02oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0280oooo
0P00000I0?ooo`8000008P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool02@3oool000<0oooo00<0gia80000B02Lgol03@3oool00`3ookl0M0000000
0002000000030000M02oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0P0?ooo`8000007@3oool200000240oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo000O0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0Q0?oo
o`800000803oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool02@3oool001l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo02<0oooo0P00000O0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02P0oooo0P00000N0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0/0?ooo`8000007@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0_0?ooo`800000703oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0<`3oool2000001/0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0=P3oool2000001X0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo000O0?ooo`<00000
303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
203oool2000000/0oooo000O0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0?03oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool001l0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo000O
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`09
0?ooo`007`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool02@3oool001l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo000O0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool0
01l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`090?ooo`007`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04P0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00T0oooo000O0?ooo`<000001P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`80
00002`3oool001l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0BP3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04`0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo000O0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0C@3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool001l0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02@3oool001l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`00
7`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`007`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool0
01l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00T0oooo000O0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`1@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`007`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo000O0?oo
o`<000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0540oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0203oool2000000/0oooo000O0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool001l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`007`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0DP3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0D@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1A
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0DP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo000O0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
D@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1A0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo000O0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
01l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`1@0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`007`3oool3000000H0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01`3oool2000000/0oooo000O0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0D03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0500oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`007`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3o
ool001l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00T0oooo000O0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0CP3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo000O0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`0000<0oooo
0?noM0000000100000000`00M;l0oooo0?ooo`020?ooo`030;md0000000007Bo00H0oooo00D0_g@0
000000000000001d0;ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`090?ooo`00103oool00`2LB4P0W=oo0?ooo`050?ooo`030;md00000000
07Bo00D0oooo00H0gia8001d_`3oool0oooo0?noM000M;l50?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`00103oool00`2LB4P0W=oo0?oo
o`0<0?ooo`030?oo_`1d0000M;oo0080oooo00<0oono07A8W03oool0103oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool000@0oooo00<0W4Q8
09cOo`3oool0303oool01`3o_g@004Q807@0M02oool0oooo0=nLB000M;l01@3oool4000000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`<000002`3oool000@0oooo00<0
W4Q809cOo`3oool0303oool00`3ogi`0B4RL0?noM002000000030018W03oool0oooo00@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool02@3oool000@0oooo00<0W4Q809cOo`3oool0303oool00`3ookl0M01d0;ooo`09
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00T0oooo00040?ooo`0309a8B02Lgol0oooo00d0oooo00<0_g@004RL
g`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`090?ooo`0000H0oooo0=nLB000000004RL09a8B02Lgol>
0?ooo`030?oo_`1d000007Bo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool000<0oooo00<0gia80000
B02Lgol0403oool0102oM000000000000000B9`50?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`007`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`007`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`09
0?ooo`007`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool2000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`8000002P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02@3oool001l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0D0?ooo`800000?P3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00T0oooo000O0?ooo`<000001P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool2000000/0oooo000O0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0F0?ooo`800000>@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00T0oooo000O0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool001l0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0G0?ooo`800000=@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`09
0?ooo`007`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo000O0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool06@3oool2000002h0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool001l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`007`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0J0?ooo`800000:@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?oo
o`007`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo01/0oooo0P00000U0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`007`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0M0?ooo`800000803oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`007`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0N0?ooo`8000007P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`007`3oool3000000L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01l0
oooo0`00000I0?ooo`800000803oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo0P00000;0?ooo`007`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?ooo`<000004P3oool400000280oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo
000O0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo02<0oooo1000000:0?ooo`@000009P3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool001l0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000001P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool09P3o
ool3000000<0oooo1000000Z0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02P0oooo0`00
000^0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`090?ooo`007`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo000O0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool001l0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool001l0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04@3oool2000005<0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool001l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0B0?ooo`800000CP3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`007`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01<0oooo0P00001:
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool001l0oooo0`0000090?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`8000002`3oool0
01l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00T0oooo000O0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0D0?ooo`800000A@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0
oooo000O0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2@3oool001l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`8000005P3o
ool200000400oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`007`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool0
01l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000001P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00T0oooo000O0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01D0oooo0P00000f0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool05P3oool2000003<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`00
7`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
3P3oool2000001P0oooo0P00000`0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
2@3oool001l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool05`3oool2000002d0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`050?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo0P00
000Z0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool001l0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0I0?ooo`8000009`3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00T0oooo000O0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool06P3oool2
000002@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`007`3oool00`00
0000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000001@3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo01/0oooo0`00000P0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3o
ool001l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0M0?ooo`@000006`3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo000O0?ooo`<00000203oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0P0?ooo`@000005P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0303oool2000000/0oooo000O0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool08`3oool4000000X0oooo2000000Q0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo
0?ooo`050?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`80
00004@3oool00`000000oooo0?ooo`0V0?ooo`X00000:@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00L0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03`3oool2000005P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01@000000
oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?oo
o`007`3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool001l0
oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0@0?ooo`800000D`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3o
ool01@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool001l0
oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0<0?ooo`8000004P3oool2000004l0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04`0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo000O0?oo
o`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`800000B`3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool0
01l0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0B03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0180oooo0P00
00180?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`007`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`0000<0oooo0?noM0000000100000000`00M;l0oooo0?ooo`020?ooo`030;md0000
000007Bo00H0oooo00<0omnL04Q8W03oool01`3oool00`000000oooo0?ooo`050?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0C0?ooo`800000A03oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool000@0oooo00<0
W4Q809cOo`3oool01@3oool00`2oM0000000001d_`070?ooo`0309a8B02Lgol0oooo00H0oooo00<0
00000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0503oool200000440
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00040?ooo`0309a8B02Lgol0oooo00l0oooo00<0gia804RLg`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`05
0000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00T0oooo00040?ooo`0309a8B02Lgol0oooo00l0oooo00<0omnL04Q8W03oool01P3oool00`000000
oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0E0?oo
o`800000?@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool000@0oooo00<0W4Q809cOo`3oool0403oool00`2LB4P0W=oo0?ooo`050?ooo`@0
00001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo0P0000090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo0`00000;0?ooo`00103oool00`2LB4P0
W=oo0?ooo`0@0?ooo`030=nLB018W=l0oooo00D0oooo00<000000?ooo`3oool02@3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00d0oooo0P00000G0?ooo`<00000=`3oool2000001L0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`00103oool00`2LB4P0W=oo0?ooo`0@0?ooo`03
0?oOW018B9`0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0G0?ooo`800000=03oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool000060?ooo`3OW4P00000
0018W02LB4P0W=oo3@3oool00`2oM4P0W=oo0?ooo`020?ooo`030;mdB02Lgol0oooo00@0oooo00<0
00000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo0P00000?0?ooo`030000
003oool0oooo01P0oooo0`00000_0?ooo`8000006@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo00030?ooo`030=nLB00004P0W=oo00d0oooo00<0_g@00000000000000`00
00000`1d_ol0oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00d0oooo0P00000K0?ooo`800000;03oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool001l0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`080?ooo`8000003@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo01X0oooo0`00000W0?ooo`8000006`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0703oool2000002@0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo0P00000N0?oo
o`<000007`3oool2000001h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?oo
o`007`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0;0?ooo`800000403oool00`000000oooo0?ooo`0N0?ooo`@00000603oool30000
01l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000
oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00h0oooo0P00000R0?ooo`@000003`3oool500000280oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08`3oool4000000D0oooo
1P00000W0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool001l0oooo00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo02H0oooo1@00000/0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02@3oool001l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`090?ooo`007`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0403oool2000005<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0140oooo0P00001>0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool02@3oool001l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool2
000000d0oooo0P00000C0?ooo`800000B`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00T0oooo000O0?ooo`<00000203oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo0P0000180?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo0P00000;0?ooo`007`3oool00`000000oooo0?ooo`050?ooo`050000003oool0
oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0C0?ooo`800000A@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01@0oooo0P0000120?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool02@3oool001l0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0:0?ooo`8000003@3oool2000001H0oooo0P00000o0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05@3oool20000
03`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000
oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0
000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0F0?ooo`800000>@3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00T0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0<0?ooo`800000603oool2000003H0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo01L0oooo0P00000c0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool0
01l0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0H0?ooo`80
0000<03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo0P00000J0?oo
o`800000;@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo000O0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool06@3oool2000002X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`09
0?ooo`007`3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01X0
oooo0`00000V0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool001l0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool2000001d0oooo0P00
000R0?ooo`8000007@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`05
0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo
00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`<00000703oool30000
01l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool01P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0
oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`8000002P3oool2000000`0oooo0P00000@0?ooo`8000007`3oool:000000`0
oooo1P00000Q0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00L0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000001@3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool03`3oool2000002L0oooo3000000V0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo
000O0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000
003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`060?ooo`800000203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00T0oooo0P00000<0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`080?ooo`05
0000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`80
00004@3oool2000005D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool0
1@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0100oooo0P00001B0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00T0oooo000O0?ooo`<000001P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`8000004P3o
ool2000004l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00D0oooo0P00000;0?ooo`007`3oool00`000000oooo0?ooo`070?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
1@3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`8000003@3oool0
0`000000oooo0?ooo`0A0?ooo`800000C03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`007`3oool00`00
0000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0203oool2000000`0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0B0?ooo`800000B@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?oo
o`080?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo0P00000D0?oo
o`800000AP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`050?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0C0?ooo`800000@`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0303oool2000001D0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?oo
o`007`3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000000`3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000001@3oool01@000000oooo0?oo
o`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`8000003P3oool00`000000oooo0?ooo`0C0?oo
o`800000?`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`070?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0D0?ooo`800000?03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?oo
o`080?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool2
000000X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`8000005P3oool2
000003T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool01@3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`8000000`3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo01D0oooo0P00000e0?ooo`800000603oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
3@3oool2000001L0oooo0`00000`0?ooo`8000006@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool03P3oool2000001P0oooo0`00000[0?ooo`8000006`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool001l0
oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`<000009P3oool2000001`0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0
oooo000O0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool2000000`0oooo
0P00000@0?ooo`8000006`3oool4000001l0oooo0`00000M0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?oo
o`050?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0703oool4000001T0oooo0P00
000O0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`090?ooo`007`3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000@0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0
000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`8000002P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00l0oooo0P00000P0?ooo`@000004`3oool200000240oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo000O
0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
0000103oool01@000000oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00/0oooo0P00000A0?ooo`030000003oool0oooo0240oooo4`00000R
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`09
0?ooo`007`3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo0P00001E0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`007`3oool00`00
0000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool001l0oooo0`0000050?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00`0oooo0P00000A0?ooo`800000D@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo0P00000;0?ooo`007`3oool00`000000oooo0?ooo`060?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool2000000h0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo
0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo0P00000:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0@0?ooo`800000C03oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool0
1`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0<0?ooo`8000004P3oool2000004X0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00P0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`800000A`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool001l0oooo00<0
00000?ooo`3oool01@3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`00
0000103oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool2000000h0oooo0P00000C0?ooo`800000A03oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool0
1@3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool300000440oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo000O0?ooo`03
0000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000040?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`8000001`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:
0?ooo`8000003P3oool2000001D0oooo0`00000l0?ooo`8000005@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00L0oooo00D000000?oo
o`3oool0oooo000000030?ooo`040000003oool0oooo000000D0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`800000303oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo01D0oooo0`00000g0?ooo`8000005`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00T0oooo000O0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool000000`3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool2000000X0oooo00<000000?ooo`3oool02P3oool2000000h0oooo0P00000H0?ooo`800000<`3o
ool2000001P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`007`3oool0
0`000000oooo0?ooo`050?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo0P0000090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo01L0oooo0`00000_0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`060?ooo`040000003oool0
oooo000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo0P0000070?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`8000006P3oool3000002X0oooo0P00000J
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?oo
o`3oool01`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool2000000`0oooo0P00000?0?ooo`030000003oool0oooo01X0oooo0P00000V0?ooo`8000006`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0
oooo00L0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0
oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo0P00000L0?ooo`<000008@3oool2000001d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo
0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`8000002P3oool00`00
0000oooo0?ooo`0;0?ooo`8000003`3oool2000001d0oooo1@00000H0?ooo`@000007P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00D0
oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00h0oooo0P00000P0?ooo`P00000203oool800000240oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?oo
o`0000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`000000103o
ool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo0P00000=0?ooo`800000403o
ool2000002H0oooo2000000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool001l0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@0
00000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P0000090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`80
0000D`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo000O0?ooo`<00000
1`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`8000002@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool200000140oooo
0P00001A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00P0oooo0P00000;0?ooo`007`3oool00`000000oooo0?oo
o`080?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000040?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`8000002P3oool2000000h0oooo00<000000?ooo`3oool0403oool2000004h0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?oo
o`050?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00`0oooo0P00000B0?ooo`800000B`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo000O0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
0P0000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04@3oool2000004P0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`007`3oool00`000000oooo0?oo
o`070?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`800000
3P3oool00`000000oooo0?ooo`0B0?ooo`800000A03oool2000001<0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool001l0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo01<0oooo0P0000110?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool01@3oool010000000
oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
0000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`8000005@3o
ool3000003d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`007`3oool0
0`000000oooo0?ooo`060?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`800000203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo
0P00000>0?ooo`030000003oool0oooo01D0oooo0`00000h0?ooo`8000005@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`090?ooo`007`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0203oool2000000`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0G0?ooo`80
0000=@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo000O0?ooo`030000
003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo0000
00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000@0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`8000003@3oool2000001T0oooo0`00000`0?ooo`8000005`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?oo
o`007`3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?oo
o`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo0P00000:0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0303oool2000001X0oooo0`00000[0?ooo`800000603oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`090?ooo`007`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo0P00000<0?ooo`030000003oool0oooo00d0oooo0P00000K0?ooo`@0
00008`3oool4000001T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool001l0oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`800000203oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool2
000000l0oooo00<000000?ooo`3oool0703oool4000001/0oooo1000000M0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00T0oooo000O0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo
0P00000P0?ooo`@000004`3oool400000200oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool001l0oooo00<0
00000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool0
0000103oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000103oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo0P00000<0?oo
o`030000003oool0oooo00h0oooo0P00000R0?oooa<000008`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?oo
o`007`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo0P00000@0?ooo`800000EP3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`090?ooo`0000<0oooo0?noM0000000100000000`00M;l0oooo0?ooo`02
0?ooo`030;md0000000007Bo00D0oooo00D0_g@00000000000000000001d_`060?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool000000080
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`05
0000003oool0oooo0?ooo`0000001@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0?0?ooo`800000D`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`00103oool0
0`2LB4P0W=oo0?ooo`050?ooo`030;md0000000007Bo00@0oooo00<0okmd001d_`3oool00P3oool0
0`2oM4P0W=oo0?ooo`040?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo0P0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0:0?ooo`800000303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool02@3oool000@0oooo00<0W4Q809cOo`3oool0303oool00`3OW4P0
B9cO0?ooo`020?ooo`030;md001d_ol0oooo00@0oooo00<000000?ooo`3oool01`3oool010000000
oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
0P0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`800000303oool00`000000oooo0?ooo`0:0?ooo`8000004@3oool2000004l0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool02@3oool000@0oooo00<0W4Q809cOo`3oool0303oool00`3o_g@004RL0?oo
o`020?ooo`0309a8B02Lgol0oooo00@0oooo100000070?ooo`040000003oool0oooo000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool200000140oooo0P00001<
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<
0?ooo`<000002`3oool000@0oooo00<0W4Q809cOo`3oool03@3oool01@3OW4P00000000000000000
B9cO00H0oooo00<000000?ooo`3oool0o`3ooon30?ooo`030000003oool0oooo00T0oooo00040?oo
o`0309a8B02Lgol0oooo00`0oooo00<0oono07A8W03oool00P3oool00`2LB7@0_ooo0?ooo`040?oo
o`030000003oool0oooo0?l0ooooP`3oool00`000000oooo0?ooo`090?ooo`00103oool00`2LB4P0
W=oo0?ooo`0<0?ooo`030?noM018W=l0oooo0080oooo00<0_g@007Boo`3oool0103oool00`000000
oooo0?ooo`3o0?oooh<0oooo00<000000?ooo`3oool02@3oool000060?ooo`3OW4P000000018W02L
B4P0W=oo3@3oool01`3ogi`0B01d0;ooo`3oool0omnL04P0M02oool01@3oool00`000000oooo0?oo
o`3o0?oooh<0oooo00<000000?ooo`3oool02@3oool000<0oooo00<0gia80000B02Lgol03P3oool0
1@3o_g@000000000000004P0W=oo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?oo
o`1K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool001l0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`007`3ooooo000008L000002`3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-1.12105, 1.35948, 0.000802859, \
0.00160571}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Classifying critical points", "Subsection"],

Cell["\<\
The Taylor series expansion of a multidimensional function can be expressed \
in the form\
\>", "Text"],

Cell[BoxData[
    \(f[x] \[TildeTilde] 
      f[x\_0] + 
        g[x\_0] . \((x - x\_0)\)\  + \ \(1\/2\) \((x - x\_0)\) . 
            h[x\_0] . \((x - x\_0)\)\  + \ \[CenterEllipsis]\)], "InlineInput",\

  Evaluatable->False,
  TextAlignment->Center,
  TextJustification->0],

Cell["where", "Text"],

Cell[BoxData[
    \(g[x\_0]\  = \ 
      Table[\(\[PartialD]f[x]\/\[PartialD]x\_i\) 
          \[VerticalSeparator]\_\(x \[Rule] x\_0\), {i, 1, n}]\)], 
  "InlineInput",
  Evaluatable->False,
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "is the gradient vector evaluated at ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  " and"
}], "Text"],

Cell[BoxData[
    \(h[x\_0]\  = \ 
      Table[\(\[PartialD]\^2 f[x]\/\(\[PartialD]x\_i \[PartialD]x\_j\)\( 
              \[VerticalSeparator] \_\(x \[Rule] x\_0\)\)\), {i, 1, n}, {j, 
          1, n}]\)], "InlineInput",
  Evaluatable->False,
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "is the matrix of second derivatives sometimes known as the ",
  StyleBox["Hessian",
    FontSlant->"Italic"],
  " matrix.  We assume that the function ",
  StyleBox["f[x]", "InlineInput"],
  " is analytic at ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(x\_0\),
          "InlineInput"], TraditionalForm]]],
  " and, hence, that the Hessian matrix is symmetric.  Therefore, an \
important theorem of linear algebra tells us that an ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-dimensional Hessian matrix has ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " real eigenvalues and that the corresponding eigenvectors are mutually \
orthogonal.  Furthermore, the Hessian matrix is diagonalized by the \
transformation ",
  Cell[BoxData[
      StyleBox[\(d\  = \ S\^\(-1\) . h . S\),
        "InlineInput"]]],
  " where ",
  StyleBox["S", "InlineInput"],
  " is the orthogonal matrix whose columns contain the normalized \
eigenvectors of  ",
  StyleBox["h", "InlineInput"],
  " and where ",
  StyleBox["d", "InlineInput"],
  " is the diagonal matrix composed of the corresponding eigenvalues."
}], "Text"],

Cell[TextData[{
  "A point ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(x\_0\),
          "InlineInput"], TraditionalForm]]],
  " where the gradient vanishes, such that ",
  Cell[BoxData[
      StyleBox[\(g[x\_0] \[Equal] 0\),
        "InlineInput"]]],
  ", is called a critical point and is considered an ordinary critical point \
if it lies within the domain of analyticity of ",
  StyleBox["f[x]", "InlineInput"],
  ".  In one dimension an ordinary critical point is a local minimum if the \
second derivative is positive, a local maximum if the second derivative is \
negative, or an inflection point if the second derivative vanishes.  In two \
dimensions, a critical point is classified as a saddle point if it is a local \
minimum for variations along one direction (not necessarily a coordinate \
direction) while simultaneously a local maximum for variations along the \
orthogonal direction.  Finally, the function exhibits a ridge if there exists \
a direction in which the both the first and second derivatives vanish.  \
Simple examples of a saddle and a ridge are shown below."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[y\^2 - x\^2, {x, \(-2\), 2}, {y, \(-2\), 2}, 
        PlotLabel \[Rule] "\<A Simple Saddle\>"];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.5 .82364 -47 0 ]
[.5 .82364 47 12.5625 ]
[.02757 .24618 -12 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -11.7989 -9 ]
[.17646 .18758 .20112 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.50253 .05935 -5.27396 -9 ]
[.50253 .05935 .72604 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 12 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 12 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 6 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02411 .26511 -12 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01568 .31795 -12 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00208 .42927 -6 -2.88161 ]
[-0.00208 .42927 0 6.11839 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
75.000 12.813 moveto
(Simple) show
117.000 12.813 moveto
(Saddle) show
153.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-2)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-1)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(1)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(2)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-2)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(-1)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(1)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(2)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(-4)] .02411 .26511 1 -0.3906 Mshowa
.02795 .31328 m
.03408 .31095 L
s
[(-2)] .01568 .31795 1 -0.38067 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01027 .42483 m
.01644 .42261 L
s
[(2)] -0.00208 .42927 1 -0.35964 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(4)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03427 .2734 m
.03794 .27198 L
s
.03218 .28658 m
.03585 .28517 L
s
.03007 .29987 m
.03375 .29847 L
s
.0258 .3268 m
.02949 .32541 L
s
.02364 .34044 m
.02733 .33906 L
s
.02146 .3542 m
.02515 .35283 L
s
.01704 .38208 m
.02074 .38072 L
s
.01481 .3962 m
.0185 .39485 L
s
.01255 .41045 m
.01625 .40911 L
s
.00797 .43933 m
.01168 .43801 L
s
.00565 .45397 m
.00936 .45265 L
s
.00331 .46873 m
.00703 .46743 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.422 .465 .799 r
.38916 .67425 .40169 .70185 .42321 .71189 .41063 .68407 Metetra
.449 .48 .799 r
.41063 .68407 .42321 .71189 .44514 .72067 .43252 .69265 Metetra
.473 .494 .799 r
.43252 .69265 .44514 .72067 .46747 .72815 .45482 .69992 Metetra
.496 .507 .798 r
.45482 .69992 .46747 .72815 .49017 .73428 .47749 .70586 Metetra
.518 .519 .796 r
.47749 .70586 .49017 .73428 .51323 .73904 .50053 .71042 Metetra
.537 .53 .794 r
.50053 .71042 .51323 .73904 .53663 .74238 .52391 .71357 Metetra
.556 .54 .792 r
.52391 .71357 .53663 .74238 .56034 .74427 .54761 .71528 Metetra
.573 .549 .79 r
.54761 .71528 .56034 .74427 .58434 .74468 .5716 .71551 Metetra
.589 .558 .787 r
.5716 .71551 .58434 .74468 .6086 .74358 .59587 .71423 Metetra
.604 .566 .784 r
.59587 .71423 .6086 .74358 .6331 .74094 .62038 .71142 Metetra
.618 .573 .781 r
.62038 .71142 .6331 .74094 .65782 .73675 .64511 .70707 Metetra
.632 .58 .778 r
.64511 .70707 .65782 .73675 .68272 .73097 .67003 .70114 Metetra
.644 .587 .775 r
.67003 .70114 .68272 .73097 .70776 .72361 .6951 .69363 Metetra
.656 .593 .772 r
.6951 .69363 .70776 .72361 .73294 .71465 .72031 .68452 Metetra
.668 .598 .768 r
.72031 .68452 .73294 .71465 .7582 .70408 .74561 .67382 Metetra
.678 .604 .765 r
.74561 .67382 .7582 .70408 .78352 .6919 .77097 .66151 Metetra
.689 .609 .762 r
.77097 .66151 .78352 .6919 .80886 .67812 .79637 .6476 Metetra
.698 .614 .758 r
.79637 .6476 .80886 .67812 .8342 .66273 .82176 .6321 Metetra
.708 .619 .755 r
.82176 .6321 .8342 .66273 .85949 .64575 .84711 .61501 Metetra
.717 .623 .752 r
.84711 .61501 .85949 .64575 .88471 .62719 .8724 .59636 Metetra
.725 .627 .748 r
.8724 .59636 .88471 .62719 .90982 .60708 .89758 .57615 Metetra
.733 .631 .745 r
.89758 .57615 .90982 .60708 .93479 .58543 .92263 .55442 Metetra
.741 .635 .742 r
.92263 .55442 .93479 .58543 .95958 .56227 .9475 .53119 Metetra
.749 .639 .738 r
.9475 .53119 .95958 .56227 .98416 .53763 .97218 .50649 Metetra
.41 .468 .81 r
.37649 .64787 .38916 .67425 .41063 .68407 .39793 .6575 Metetra
.438 .485 .81 r
.39793 .6575 .41063 .68407 .43252 .69265 .41979 .66588 Metetra
.465 .5 .81 r
.41979 .66588 .43252 .69265 .45482 .69992 .44205 .67296 Metetra
.49 .513 .809 r
.44205 .67296 .45482 .69992 .47749 .70586 .46471 .67871 Metetra
.512 .526 .807 r
.46471 .67871 .47749 .70586 .50053 .71042 .48773 .68309 Metetra
.534 .537 .805 r
.48773 .68309 .50053 .71042 .52391 .71357 .5111 .68606 Metetra
.553 .548 .802 r
.5111 .68606 .52391 .71357 .54761 .71528 .5348 .68758 Metetra
.571 .557 .8 r
.5348 .68758 .54761 .71528 .5716 .71551 .5588 .68764 Metetra
.589 .566 .797 r
.5588 .68764 .5716 .71551 .59587 .71423 .58308 .6862 Metetra
.604 .575 .794 r
.58308 .6862 .59587 .71423 .62038 .71142 .60761 .68323 Metetra
.619 .582 .79 r
.60761 .68323 .62038 .71142 .64511 .70707 .63236 .67871 Metetra
.633 .589 .787 r
.63236 .67871 .64511 .70707 .67003 .70114 .65731 .67263 Metetra
.647 .596 .784 r
.65731 .67263 .67003 .70114 .6951 .69363 .68243 .66497 Metetra
.659 .602 .78 r
.68243 .66497 .6951 .69363 .72031 .68452 .70768 .65572 Metetra
.671 .608 .777 r
.70768 .65572 .72031 .68452 .74561 .67382 .73303 .64488 Metetra
.682 .614 .773 r
.73303 .64488 .74561 .67382 .77097 .66151 .75845 .63244 Metetra
.693 .619 .769 r
.75845 .63244 .77097 .66151 .79637 .6476 .7839 .6184 Metetra
.703 .624 .766 r
.7839 .6184 .79637 .6476 .82176 .6321 .80936 .60278 Metetra
.712 .628 .762 r
.80936 .60278 .82176 .6321 .84711 .61501 .83479 .58558 Metetra
.722 .633 .758 r
.83479 .58558 .84711 .61501 .8724 .59636 .86016 .56682 Metetra
.73 .637 .755 r
.86016 .56682 .8724 .59636 .89758 .57615 .88543 .54652 Metetra
.739 .641 .751 r
.88543 .54652 .89758 .57615 .92263 .55442 .91056 .5247 Metetra
.747 .645 .748 r
.91056 .5247 .92263 .55442 .9475 .53119 .93553 .50138 Metetra
.755 .649 .744 r
.93553 .50138 .9475 .53119 .97218 .50649 .9603 .47661 Metetra
.396 .472 .821 r
.36368 .6227 .37649 .64787 .39793 .6575 .38508 .63214 Metetra
.427 .49 .822 r
.38508 .63214 .39793 .6575 .41979 .66588 .40692 .64034 Metetra
.456 .506 .821 r
.40692 .64034 .41979 .66588 .44205 .67296 .42916 .64724 Metetra
.482 .52 .82 r
.42916 .64724 .44205 .67296 .46471 .67871 .4518 .65281 Metetra
.507 .533 .818 r
.4518 .65281 .46471 .67871 .48773 .68309 .47482 .65701 Metetra
.529 .545 .816 r
.47482 .65701 .48773 .68309 .5111 .68606 .49819 .65981 Metetra
.55 .556 .813 r
.49819 .65981 .5111 .68606 .5348 .68758 .5219 .66117 Metetra
.57 .567 .81 r
.5219 .66117 .5348 .68758 .5588 .68764 .54592 .66106 Metetra
.588 .576 .807 r
.54592 .66106 .5588 .68764 .58308 .6862 .57022 .65945 Metetra
.605 .584 .804 r
.57022 .65945 .58308 .6862 .60761 .68323 .59478 .65632 Metetra
.62 .592 .8 r
.59478 .65632 .60761 .68323 .63236 .67871 .61957 .65165 Metetra
.635 .6 .797 r
.61957 .65165 .63236 .67871 .65731 .67263 .64456 .64542 Metetra
.649 .606 .793 r
.64456 .64542 .65731 .67263 .68243 .66497 .66972 .63761 Metetra
.662 .613 .789 r
.66972 .63761 .68243 .66497 .70768 .65572 .69503 .62822 Metetra
.674 .619 .785 r
.69503 .62822 .70768 .65572 .73303 .64488 .72044 .61724 Metetra
.686 .624 .781 r
.72044 .61724 .73303 .64488 .75845 .63244 .74593 .60467 Metetra
.697 .629 .777 r
.74593 .60467 .75845 .63244 .7839 .6184 .77146 .5905 Metetra
.707 .634 .773 r
.77146 .5905 .7839 .6184 .80936 .60278 .797 .57476 Metetra
.717 .639 .769 r
.797 .57476 .80936 .60278 .83479 .58558 .82252 .55744 Metetra
.727 .643 .766 r
.82252 .55744 .83479 .58558 .86016 .56682 .84797 .53857 Metetra
.736 .648 .762 r
.84797 .53857 .86016 .56682 .88543 .54652 .87334 .51816 Metetra
.744 .652 .758 r
.87334 .51816 .88543 .54652 .91056 .5247 .89857 .49623 Metetra
.753 .655 .754 r
.89857 .49623 .91056 .5247 .93553 .50138 .92365 .47283 Metetra
.761 .659 .75 r
.92365 .47283 .93553 .50138 .9603 .47661 .94853 .44796 Metetra
.38 .476 .833 r
.35069 .59872 .36368 .6227 .38508 .63214 .37207 .60799 Metetra
.414 .495 .834 r
.37207 .60799 .38508 .63214 .40692 .64034 .39389 .61601 Metetra
.445 .512 .834 r
.39389 .61601 .40692 .64034 .42916 .64724 .41613 .62274 Metetra
.474 .528 .833 r
.41613 .62274 .42916 .64724 .4518 .65281 .43876 .62815 Metetra
.5 .542 .831 r
.43876 .62815 .4518 .65281 .47482 .65701 .46178 .63219 Metetra
.524 .554 .828 r
.46178 .63219 .47482 .65701 .49819 .65981 .48517 .63482 Metetra
.547 .566 .825 r
.48517 .63482 .49819 .65981 .5219 .66117 .50889 .63602 Metetra
.568 .577 .822 r
.50889 .63602 .5219 .66117 .54592 .66106 .53293 .63575 Metetra
.587 .586 .819 r
.53293 .63575 .54592 .66106 .57022 .65945 .55727 .63398 Metetra
.605 .595 .815 r
.55727 .63398 .57022 .65945 .59478 .65632 .58187 .6307 Metetra
.621 .603 .811 r
.58187 .6307 .59478 .65632 .61957 .65165 .6067 .62588 Metetra
.637 .611 .807 r
.6067 .62588 .61957 .65165 .64456 .64542 .63175 .61949 Metetra
.651 .617 .803 r
.63175 .61949 .64456 .64542 .66972 .63761 .65697 .61154 Metetra
.665 .624 .799 r
.65697 .61154 .66972 .63761 .69503 .62822 .68234 .602 Metetra
.678 .63 .794 r
.68234 .602 .69503 .62822 .72044 .61724 .70783 .59088 Metetra
.69 .636 .79 r
.70783 .59088 .72044 .61724 .74593 .60467 .7334 .57817 Metetra
.701 .641 .786 r
.7334 .57817 .74593 .60467 .77146 .5905 .75901 .56388 Metetra
.712 .646 .782 r
.75901 .56388 .77146 .5905 .797 .57476 .78465 .548 Metetra
.722 .65 .777 r
.78465 .548 .797 .57476 .82252 .55744 .81026 .53056 Metetra
.732 .655 .773 r
.81026 .53056 .82252 .55744 .84797 .53857 .83582 .51157 Metetra
.741 .659 .769 r
.83582 .51157 .84797 .53857 .87334 .51816 .86129 .49104 Metetra
.75 .663 .765 r
.86129 .49104 .87334 .51816 .89857 .49623 .88664 .469 Metetra
.759 .667 .76 r
.88664 .469 .89857 .49623 .92365 .47283 .91184 .44549 Metetra
.767 .67 .756 r
.91184 .44549 .92365 .47283 .94853 .44796 .93684 .42053 Metetra
.362 .48 .845 r
.33752 .57591 .35069 .59872 .37207 .60799 .35889 .58502 Metetra
.399 .501 .846 r
.35889 .58502 .37207 .60799 .39389 .61601 .38069 .59288 Metetra
.433 .519 .847 r
.38069 .59288 .39389 .61601 .41613 .62274 .40293 .59946 Metetra
.464 .536 .846 r
.40293 .59946 .41613 .62274 .43876 .62815 .42557 .60471 Metetra
.493 .551 .844 r
.42557 .60471 .43876 .62815 .46178 .63219 .4486 .60859 Metetra
.519 .564 .841 r
.4486 .60859 .46178 .63219 .48517 .63482 .47201 .61107 Metetra
.543 .576 .838 r
.47201 .61107 .48517 .63482 .50889 .63602 .49576 .61211 Metetra
.565 .587 .835 r
.49576 .61211 .50889 .63602 .53293 .63575 .51983 .61169 Metetra
.585 .597 .831 r
.51983 .61169 .53293 .63575 .55727 .63398 .54421 .60977 Metetra
.604 .606 .827 r
.54421 .60977 .55727 .63398 .58187 .6307 .56886 .60634 Metetra
.622 .615 .822 r
.56886 .60634 .58187 .6307 .6067 .62588 .59375 .60136 Metetra
.638 .622 .818 r
.59375 .60136 .6067 .62588 .63175 .61949 .61886 .59483 Metetra
.653 .63 .814 r
.61886 .59483 .63175 .61949 .65697 .61154 .64415 .58673 Metetra
.668 .636 .809 r
.64415 .58673 .65697 .61154 .68234 .602 .6696 .57705 Metetra
.681 .642 .804 r
.6696 .57705 .68234 .602 .70783 .59088 .69517 .56579 Metetra
.694 .648 .8 r
.69517 .56579 .70783 .59088 .7334 .57817 .72083 .55294 Metetra
.706 .653 .795 r
.72083 .55294 .7334 .57817 .75901 .56388 .74655 .53851 Metetra
.717 .658 .79 r
.74655 .53851 .75901 .56388 .78465 .548 .77229 .5225 Metetra
.727 .663 .786 r
.77229 .5225 .78465 .548 .81026 .53056 .79801 .50492 Metetra
.738 .667 .781 r
.79801 .50492 .81026 .53056 .83582 .51157 .82369 .4858 Metetra
.747 .671 .776 r
.82369 .4858 .83582 .51157 .86129 .49104 .84928 .46515 Metetra
.756 .675 .772 r
.84928 .46515 .86129 .49104 .88664 .469 .87476 .44299 Metetra
.765 .679 .767 r
.87476 .44299 .88664 .469 .91184 .44549 .90008 .41936 Metetra
.773 .682 .763 r
.90008 .41936 .91184 .44549 .93684 .42053 .92522 .39428 Metetra
.342 .484 .857 r
.32415 .55427 .33752 .57591 .35889 .58502 .3455 .56323 Metetra
.382 .507 .86 r
.3455 .56323 .35889 .58502 .38069 .59288 .36731 .57095 Metetra
.419 .527 .86 r
.36731 .57095 .38069 .59288 .40293 .59946 .38954 .57738 Metetra
.453 .544 .86 r
.38954 .57738 .40293 .59946 .42557 .60471 .4122 .58248 Metetra
.484 .56 .858 r
.4122 .58248 .42557 .60471 .4486 .60859 .43525 .58621 Metetra
.512 .575 .855 r
.43525 .58621 .4486 .60859 .47201 .61107 .45868 .58854 Metetra
.538 .588 .852 r
.45868 .58854 .47201 .61107 .49576 .61211 .48247 .58944 Metetra
.562 .599 .848 r
.48247 .58944 .49576 .61211 .51983 .61169 .50659 .58887 Metetra
.584 .61 .844 r
.50659 .58887 .51983 .61169 .54421 .60977 .53102 .58681 Metetra
.604 .619 .839 r
.53102 .58681 .54421 .60977 .56886 .60634 .55573 .58322 Metetra
.623 .628 .835 r
.55573 .58322 .56886 .60634 .59375 .60136 .58069 .5781 Metetra
.64 .635 .83 r
.58069 .5781 .59375 .60136 .61886 .59483 .60588 .57143 Metetra
.656 .643 .825 r
.60588 .57143 .61886 .59483 .64415 .58673 .63125 .56318 Metetra
.671 .649 .82 r
.63125 .56318 .64415 .58673 .6696 .57705 .65679 .55336 Metetra
.685 .655 .815 r
.65679 .55336 .6696 .57705 .69517 .56579 .68246 .54195 Metetra
.698 .661 .81 r
.68246 .54195 .69517 .56579 .72083 .55294 .70823 .52895 Metetra
.71 .666 .805 r
.70823 .52895 .72083 .55294 .74655 .53851 .73406 .51438 Metetra
.722 .671 .8 r
.73406 .51438 .74655 .53851 .77229 .5225 .75991 .49823 Metetra
.733 .676 .794 r
.75991 .49823 .77229 .5225 .79801 .50492 .78576 .48051 Metetra
.743 .68 .789 r
.78576 .48051 .79801 .50492 .82369 .4858 .81156 .46125 Metetra
.753 .684 .784 r
.81156 .46125 .82369 .4858 .84928 .46515 .83729 .44046 Metetra
.763 .688 .779 r
.83729 .44046 .84928 .46515 .87476 .44299 .86291 .41818 Metetra
.772 .691 .774 r
.86291 .41818 .87476 .44299 .90008 .41936 .88838 .39441 Metetra
.78 .695 .77 r
.88838 .39441 .90008 .41936 .92522 .39428 .91366 .36921 Metetra
.318 .488 .869 r
.31055 .53378 .32415 .55427 .3455 .56323 .3319 .54261 Metetra
.363 .512 .873 r
.3319 .54261 .3455 .56323 .36731 .57095 .35371 .55019 Metetra
.403 .534 .874 r
.35371 .55019 .36731 .57095 .38954 .57738 .37596 .55648 Metetra
.44 .554 .874 r
.37596 .55648 .38954 .57738 .4122 .58248 .39864 .56145 Metetra
.474 .571 .873 r
.39864 .56145 .4122 .58248 .43525 .58621 .42172 .56504 Metetra
.505 .586 .87 r
.42172 .56504 .43525 .58621 .45868 .58854 .44519 .56723 Metetra
.533 .6 .866 r
.44519 .56723 .45868 .58854 .48247 .58944 .46902 .56799 Metetra
.558 .612 .862 r
.46902 .56799 .48247 .58944 .50659 .58887 .4932 .56728 Metetra
.582 .623 .858 r
.4932 .56728 .50659 .58887 .53102 .58681 .51769 .56507 Metetra
.603 .633 .853 r
.51769 .56507 .53102 .58681 .55573 .58322 .54247 .56135 Metetra
.623 .641 .848 r
.54247 .56135 .55573 .58322 .58069 .5781 .56751 .55608 Metetra
.641 .649 .842 r
.56751 .55608 .58069 .5781 .60588 .57143 .59278 .54926 Metetra
.658 .657 .837 r
.59278 .54926 .60588 .57143 .63125 .56318 .61825 .54087 Metetra
.674 .663 .831 r
.61825 .54087 .63125 .56318 .65679 .55336 .6439 .5309 Metetra
.689 .669 .826 r
.6439 .5309 .65679 .55336 .68246 .54195 .66968 .51934 Metetra
.702 .675 .82 r
.66968 .51934 .68246 .54195 .70823 .52895 .69556 .5062 Metetra
.715 .68 .815 r
.69556 .5062 .70823 .52895 .73406 .51438 .72151 .49148 Metetra
.727 .685 .809 r
.72151 .49148 .73406 .51438 .75991 .49823 .74749 .47518 Metetra
.739 .69 .804 r
.74749 .47518 .75991 .49823 .78576 .48051 .77348 .45732 Metetra
.75 .694 .798 r
.77348 .45732 .78576 .48051 .81156 .46125 .79943 .43791 Metetra
.76 .698 .793 r
.79943 .43791 .81156 .46125 .83729 .44046 .8253 .41698 Metetra
.769 .701 .787 r
.8253 .41698 .83729 .44046 .86291 .41818 .85107 .39455 Metetra
.779 .705 .782 r
.85107 .39455 .86291 .41818 .88838 .39441 .87669 .37064 Metetra
.787 .708 .777 r
.87669 .37064 .88838 .39441 .91366 .36921 .90214 .3453 Metetra
.291 .491 .881 r
.29671 .51444 .31055 .53378 .3319 .54261 .31806 .52314 Metetra
.34 .518 .886 r
.31806 .52314 .3319 .54261 .35371 .55019 .33988 .5306 Metetra
.385 .542 .889 r
.33988 .5306 .35371 .55019 .37596 .55648 .36215 .53677 Metetra
.426 .563 .889 r
.36215 .53677 .37596 .55648 .39864 .56145 .38486 .54161 Metetra
.462 .582 .888 r
.38486 .54161 .39864 .56145 .42172 .56504 .40798 .54507 Metetra
.496 .598 .885 r
.40798 .54507 .42172 .56504 .44519 .56723 .4315 .54714 Metetra
.526 .613 .882 r
.4315 .54714 .44519 .56723 .46902 .56799 .45539 .54776 Metetra
.554 .626 .878 r
.45539 .54776 .46902 .56799 .4932 .56728 .47962 .54691 Metetra
.579 .637 .873 r
.47962 .54691 .4932 .56728 .51769 .56507 .50419 .54457 Metetra
.602 .647 .867 r
.50419 .54457 .51769 .56507 .54247 .56135 .52905 .54071 Metetra
.623 .656 .862 r
.52905 .54071 .54247 .56135 .56751 .55608 .55418 .5353 Metetra
.643 .664 .856 r
.55418 .5353 .56751 .55608 .59278 .54926 .57955 .52833 Metetra
.661 .672 .85 r
.57955 .52833 .59278 .54926 .61825 .54087 .60513 .5198 Metetra
.677 .679 .844 r
.60513 .5198 .61825 .54087 .6439 .5309 .63089 .50968 Metetra
.693 .685 .838 r
.63089 .50968 .6439 .5309 .66968 .51934 .65679 .49797 Metetra
.707 .69 .832 r
.65679 .49797 .66968 .51934 .69556 .5062 .6828 .48468 Metetra
.72 .695 .826 r
.6828 .48468 .69556 .5062 .72151 .49148 .70889 .4698 Metetra
.733 .7 .819 r
.70889 .4698 .72151 .49148 .74749 .47518 .73502 .45335 Metetra
.745 .705 .813 r
.73502 .45335 .74749 .47518 .77348 .45732 .76116 .43533 Metetra
.756 .709 .808 r
.76116 .43533 .77348 .45732 .79943 .43791 .78726 .41577 Metetra
.766 .712 .802 r
.78726 .41577 .79943 .43791 .8253 .41698 .8133 .39468 Metetra
.776 .716 .796 r
.8133 .39468 .8253 .41698 .85107 .39455 .83923 .37209 Metetra
.786 .719 .79 r
.83923 .37209 .85107 .39455 .87669 .37064 .86503 .34803 Metetra
.795 .723 .784 r
.86503 .34803 .87669 .37064 .90214 .3453 .89065 .32253 Metetra
.26 .493 .891 r
.28261 .49624 .29671 .51444 .31806 .52314 .30397 .50484 Metetra
.314 .524 .899 r
.30397 .50484 .31806 .52314 .33988 .5306 .3258 .51218 Metetra
.364 .55 .903 r
.3258 .51218 .33988 .5306 .36215 .53677 .3481 .51824 Metetra
.408 .573 .904 r
.3481 .51824 .36215 .53677 .38486 .54161 .37084 .52296 Metetra
.449 .594 .904 r
.37084 .52296 .38486 .54161 .40798 .54507 .39401 .52631 Metetra
.485 .611 .901 r
.39401 .52631 .40798 .54507 .4315 .54714 .41758 .52825 Metetra
.518 .627 .898 r
.41758 .52825 .4315 .54714 .45539 .54776 .44154 .52874 Metetra
.548 .64 .893 r
.44154 .52874 .45539 .54776 .47962 .54691 .46585 .52777 Metetra
.576 .652 .888 r
.46585 .52777 .47962 .54691 .50419 .54457 .4905 .52529 Metetra
.601 .663 .883 r
.4905 .52529 .50419 .54457 .52905 .54071 .51546 .52129 Metetra
.623 .672 .876 r
.51546 .52129 .52905 .54071 .55418 .5353 .54069 .51574 Metetra
.644 .681 .87 r
.54069 .51574 .55418 .5353 .57955 .52833 .56617 .50863 Metetra
.663 .688 .864 r
.56617 .50863 .57955 .52833 .60513 .5198 .59187 .49995 Metetra
.68 .695 .857 r
.59187 .49995 .60513 .5198 .63089 .50968 .61776 .48968 Metetra
.697 .701 .85 r
.61776 .48968 .63089 .50968 .65679 .49797 .64379 .47782 Metetra
.712 .707 .844 r
.64379 .47782 .65679 .49797 .6828 .48468 .66995 .46437 Metetra
.726 .712 .837 r
.66995 .46437 .6828 .48468 .70889 .4698 .69619 .44934 Metetra
.739 .716 .83 r
.69619 .44934 .70889 .4698 .73502 .45335 .72247 .43272 Metetra
.751 .72 .824 r
.72247 .43272 .73502 .45335 .76116 .43533 .74877 .41454 Metetra
.763 .724 .817 r
.74877 .41454 .76116 .43533 .78726 .41577 .77505 .39482 Metetra
.773 .728 .811 r
.77505 .39482 .78726 .41577 .8133 .39468 .80126 .37356 Metetra
.784 .731 .804 r
.80126 .37356 .8133 .39468 .83923 .37209 .82737 .3508 Metetra
.793 .735 .798 r
.82737 .3508 .83923 .37209 .86503 .34803 .85335 .32657 Metetra
.802 .738 .792 r
.85335 .32657 .86503 .34803 .89065 .32253 .87916 .30091 Metetra
.224 .494 .899 r
.26821 .47919 .28261 .49624 .30397 .50484 .28959 .48769 Metetra
.284 .528 .91 r
.28959 .48769 .30397 .50484 .3258 .51218 .31145 .49494 Metetra
.339 .558 .916 r
.31145 .49494 .3258 .51218 .3481 .51824 .33378 .50089 Metetra
.388 .583 .919 r
.33378 .50089 .3481 .51824 .37084 .52296 .35657 .5055 Metetra
.433 .606 .92 r
.35657 .5055 .37084 .52296 .39401 .52631 .37979 .50874 Metetra
.473 .625 .918 r
.37979 .50874 .39401 .52631 .41758 .52825 .40343 .51056 Metetra
.509 .642 .915 r
.40343 .51056 .41758 .52825 .44154 .52874 .42746 .51094 Metetra
.542 .656 .91 r
.42746 .51094 .44154 .52874 .46585 .52777 .45186 .50984 Metetra
.571 .669 .905 r
.45186 .50984 .46585 .52777 .4905 .52529 .4766 .50723 Metetra
.598 .68 .898 r
.4766 .50723 .4905 .52529 .51546 .52129 .50166 .5031 Metetra
.622 .69 .892 r
.50166 .5031 .51546 .52129 .54069 .51574 .52701 .49742 Metetra
.645 .698 .885 r
.52701 .49742 .54069 .51574 .56617 .50863 .55261 .49017 Metetra
.665 .706 .878 r
.55261 .49017 .56617 .50863 .59187 .49995 .57845 .48133 Metetra
.684 .713 .871 r
.57845 .48133 .59187 .49995 .61776 .48968 .60447 .47091 Metetra
.701 .719 .863 r
.60447 .47091 .61776 .48968 .64379 .47782 .63066 .4589 Metetra
.716 .724 .856 r
.63066 .4589 .64379 .47782 .66995 .46437 .65697 .44529 Metetra
.731 .729 .849 r
.65697 .44529 .66995 .46437 .69619 .44934 .68338 .43009 Metetra
.745 .733 .841 r
.68338 .43009 .69619 .44934 .72247 .43272 .70983 .4133 Metetra
.757 .737 .834 r
.70983 .4133 .72247 .43272 .74877 .41454 .73631 .39495 Metetra
.769 .741 .827 r
.73631 .39495 .74877 .41454 .77505 .39482 .76277 .37505 Metetra
.78 .745 .82 r
.76277 .37505 .77505 .39482 .80126 .37356 .78917 .35362 Metetra
.791 .748 .813 r
.78917 .35362 .80126 .37356 .82737 .3508 .81548 .33068 Metetra
.801 .751 .807 r
.81548 .33068 .82737 .3508 .85335 .32657 .84166 .30627 Metetra
.81 .753 .8 r
.84166 .30627 .85335 .32657 .87916 .30091 .86768 .28042 Metetra
.183 .493 .903 r
.2535 .46328 .26821 .47919 .28959 .48769 .2749 .4717 Metetra
.249 .531 .918 r
.2749 .4717 .28959 .48769 .31145 .49494 .2968 .47886 Metetra
.309 .564 .928 r
.2968 .47886 .31145 .49494 .33378 .50089 .31917 .48472 Metetra
.364 .593 .933 r
.31917 .48472 .33378 .50089 .35657 .5055 .34201 .48923 Metetra
.413 .618 .935 r
.34201 .48923 .35657 .5055 .37979 .50874 .3653 .49237 Metetra
.458 .639 .934 r
.3653 .49237 .37979 .50874 .40343 .51056 .38901 .49409 Metetra
.498 .657 .931 r
.38901 .49409 .40343 .51056 .42746 .51094 .41313 .49435 Metetra
.533 .673 .927 r
.41313 .49435 .42746 .51094 .45186 .50984 .43762 .49313 Metetra
.566 .686 .921 r
.43762 .49313 .45186 .50984 .4766 .50723 .46247 .4904 Metetra
.595 .698 .915 r
.46247 .4904 .4766 .50723 .50166 .5031 .48765 .48614 Metetra
.621 .708 .908 r
.48765 .48614 .50166 .5031 .52701 .49742 .51312 .48032 Metetra
.645 .717 .9 r
.51312 .48032 .52701 .49742 .55261 .49017 .53886 .47293 Metetra
.666 .725 .893 r
.53886 .47293 .55261 .49017 .57845 .48133 .56484 .46395 Metetra
.686 .731 .885 r
.56484 .46395 .57845 .48133 .60447 .47091 .59102 .45337 Metetra
.704 .737 .877 r
.59102 .45337 .60447 .47091 .63066 .4589 .61737 .4412 Metetra
.721 .743 .869 r
.61737 .4412 .63066 .4589 .65697 .44529 .64385 .42742 Metetra
.736 .747 .861 r
.64385 .42742 .65697 .44529 .68338 .43009 .67044 .41205 Metetra
.751 .752 .853 r
.67044 .41205 .68338 .43009 .70983 .4133 .69708 .39509 Metetra
.764 .756 .845 r
.69708 .39509 .70983 .4133 .73631 .39495 .72375 .37656 Metetra
.776 .759 .838 r
.72375 .37656 .73631 .39495 .76277 .37505 .75041 .35647 Metetra
.788 .762 .83 r
.75041 .35647 .76277 .37505 .78917 .35362 .77702 .33484 Metetra
.798 .765 .823 r
.77702 .33484 .78917 .35362 .81548 .33068 .80354 .31171 Metetra
.809 .768 .815 r
.80354 .31171 .81548 .33068 .84166 .30627 .82993 .28711 Metetra
.818 .77 .808 r
.82993 .28711 .84166 .30627 .86768 .28042 .85617 .26106 Metetra
.137 .488 .902 r
.23846 .44853 .2535 .46328 .2749 .4717 .25989 .45688 Metetra
.209 .531 .922 r
.25989 .45688 .2749 .4717 .2968 .47886 .28182 .46396 Metetra
.275 .569 .936 r
.28182 .46396 .2968 .47886 .31917 .48472 .30425 .46974 Metetra
.336 .601 .945 r
.30425 .46974 .31917 .48472 .34201 .48923 .32715 .47417 Metetra
.39 .629 .949 r
.32715 .47417 .34201 .48923 .3653 .49237 .35051 .47721 Metetra
.44 .653 .95 r
.35051 .47721 .3653 .49237 .38901 .49409 .3743 .47883 Metetra
.484 .673 .948 r
.3743 .47883 .38901 .49409 .41313 .49435 .39851 .47899 Metetra
.523 .69 .944 r
.39851 .47899 .41313 .49435 .43762 .49313 .42312 .47766 Metetra
.558 .705 .938 r
.42312 .47766 .43762 .49313 .46247 .4904 .44808 .47481 Metetra
.59 .717 .932 r
.44808 .47481 .46247 .4904 .48765 .48614 .47339 .47042 Metetra
.618 .728 .924 r
.47339 .47042 .48765 .48614 .51312 .48032 .499 .46446 Metetra
.644 .737 .916 r
.499 .46446 .51312 .48032 .53886 .47293 .52489 .45693 Metetra
.667 .745 .908 r
.52489 .45693 .53886 .47293 .56484 .46395 .55102 .4478 Metetra
.689 .752 .9 r
.55102 .4478 .56484 .46395 .59102 .45337 .57737 .43707 Metetra
.708 .757 .891 r
.57737 .43707 .59102 .45337 .61737 .4412 .6039 .42473 Metetra
.725 .763 .882 r
.6039 .42473 .61737 .4412 .64385 .42742 .63057 .41078 Metetra
.741 .767 .874 r
.63057 .41078 .64385 .42742 .67044 .41205 .65735 .39523 Metetra
.756 .771 .865 r
.65735 .39523 .67044 .41205 .69708 .39509 .68419 .37809 Metetra
.77 .775 .857 r
.68419 .37809 .69708 .39509 .72375 .37656 .71107 .35936 Metetra
.783 .778 .848 r
.71107 .35936 .72375 .37656 .75041 .35647 .73795 .33908 Metetra
.795 .781 .84 r
.73795 .33908 .75041 .35647 .77702 .33484 .76478 .31725 Metetra
.806 .783 .832 r
.76478 .31725 .77702 .33484 .80354 .31171 .79152 .29391 Metetra
.816 .786 .824 r
.79152 .29391 .80354 .31171 .82993 .28711 .81815 .26909 Metetra
.826 .788 .816 r
.81815 .26909 .82993 .28711 .85617 .26106 .84462 .24283 Metetra
.085 .48 .894 r
.22305 .43494 .23846 .44853 .25989 .45688 .24451 .44323 Metetra
.163 .529 .921 r
.24451 .44323 .25989 .45688 .28182 .46396 .26649 .45024 Metetra
.236 .571 .94 r
.26649 .45024 .28182 .46396 .30425 .46974 .28897 .45595 Metetra
.303 .608 .953 r
.28897 .45595 .30425 .46974 .32715 .47417 .31195 .4603 Metetra
.363 .64 .961 r
.31195 .4603 .32715 .47417 .35051 .47721 .33539 .46326 Metetra
.418 .666 .964 r
.33539 .46326 .35051 .47721 .3743 .47883 .35928 .46479 Metetra
.466 .689 .963 r
.35928 .46479 .3743 .47883 .39851 .47899 .38359 .46485 Metetra
.51 .708 .96 r
.38359 .46485 .39851 .47899 .42312 .47766 .40831 .46341 Metetra
.549 .724 .955 r
.40831 .46341 .42312 .47766 .44808 .47481 .43341 .46045 Metetra
.583 .737 .949 r
.43341 .46045 .44808 .47481 .47339 .47042 .45885 .45594 Metetra
.614 .748 .941 r
.45885 .45594 .47339 .47042 .499 .46446 .48461 .44985 Metetra
.642 .758 .933 r
.48461 .44985 .499 .46446 .52489 .45693 .51067 .44218 Metetra
.667 .766 .924 r
.51067 .44218 .52489 .45693 .55102 .4478 .53697 .4329 Metetra
.69 .773 .915 r
.53697 .4329 .55102 .4478 .57737 .43707 .56351 .42201 Metetra
.711 .779 .905 r
.56351 .42201 .57737 .43707 .6039 .42473 .59023 .4095 Metetra
.729 .784 .896 r
.59023 .4095 .6039 .42473 .63057 .41078 .6171 .39538 Metetra
.746 .788 .887 r
.6171 .39538 .63057 .41078 .65735 .39523 .64408 .37964 Metetra
.762 .792 .877 r
.64408 .37964 .65735 .39523 .68419 .37809 .67115 .3623 Metetra
.776 .795 .868 r
.67115 .3623 .68419 .37809 .71107 .35936 .69825 .34338 Metetra
.79 .798 .859 r
.69825 .34338 .71107 .35936 .73795 .33908 .72536 .32288 Metetra
.802 .8 .85 r
.72536 .32288 .73795 .33908 .76478 .31725 .75243 .30084 Metetra
.813 .802 .841 r
.75243 .30084 .76478 .31725 .79152 .29391 .77942 .27728 Metetra
.824 .804 .833 r
.77942 .27728 .79152 .29391 .81815 .26909 .80629 .25223 Metetra
.834 .806 .824 r
.80629 .25223 .81815 .26909 .84462 .24283 .83302 .22573 Metetra
.027 .466 .877 r
.20724 .42251 .22305 .43494 .24451 .44323 .22874 .43076 Metetra
.112 .521 .911 r
.22874 .43076 .24451 .44323 .26649 .45024 .25078 .43773 Metetra
.191 .57 .938 r
.25078 .43773 .26649 .45024 .28897 .45595 .27333 .44338 Metetra
.264 .612 .956 r
.27333 .44338 .28897 .45595 .31195 .4603 .29638 .44766 Metetra
.331 .648 .968 r
.29638 .44766 .31195 .4603 .33539 .46326 .31991 .45055 Metetra
.391 .678 .975 r
.31991 .45055 .33539 .46326 .35928 .46479 .3439 .45199 Metetra
.445 .704 .977 r
.3439 .45199 .35928 .46479 .38359 .46485 .36834 .45196 Metetra
.493 .725 .975 r
.36834 .45196 .38359 .46485 .40831 .46341 .39318 .45043 Metetra
.536 .743 .971 r
.39318 .45043 .40831 .46341 .43341 .46045 .41842 .44735 Metetra
.575 .757 .965 r
.41842 .44735 .43341 .46045 .45885 .45594 .44402 .44272 Metetra
.609 .77 .957 r
.44402 .44272 .45885 .45594 .48461 .44985 .46994 .4365 Metetra
.639 .78 .948 r
.46994 .4365 .48461 .44985 .51067 .44218 .49617 .42868 Metetra
.666 .788 .939 r
.49617 .42868 .51067 .44218 .53697 .4329 .52267 .41925 Metetra
.691 .795 .929 r
.52267 .41925 .53697 .4329 .56351 .42201 .5494 .4082 Metetra
.713 .801 .92 r
.5494 .4082 .56351 .42201 .59023 .4095 .57632 .39552 Metetra
.732 .805 .909 r
.57632 .39552 .59023 .4095 .6171 .39538 .60341 .38121 Metetra
.75 .81 .899 r
.60341 .38121 .6171 .39538 .64408 .37964 .63063 .36529 Metetra
.767 .813 .889 r
.63063 .36529 .64408 .37964 .67115 .3623 .65793 .34775 Metetra
.782 .816 .879 r
.65793 .34775 .67115 .3623 .69825 .34338 .68527 .32861 Metetra
.796 .818 .87 r
.68527 .32861 .69825 .34338 .72536 .32288 .71263 .30789 Metetra
.809 .821 .86 r
.71263 .30789 .72536 .32288 .75243 .30084 .73995 .28562 Metetra
.82 .822 .851 r
.73995 .28562 .75243 .30084 .77942 .27728 .7672 .26182 Metetra
.831 .824 .841 r
.7672 .26182 .77942 .27728 .80629 .25223 .79435 .23653 Metetra
.842 .825 .832 r
.79435 .23653 .80629 .25223 .83302 .22573 .82134 .20978 Metetra
0 .447 .849 r
.19101 .41128 .20724 .42251 .22874 .43076 .21256 .41949 Metetra
.055 .508 .892 r
.21256 .41949 .22874 .43076 .25078 .43773 .23465 .42642 Metetra
.14 .563 .926 r
.23465 .42642 .25078 .43773 .27333 .44338 .25728 .43203 Metetra
.219 .612 .952 r
.25728 .43203 .27333 .44338 .29638 .44766 .28041 .43626 Metetra
.293 .653 .97 r
.28041 .43626 .29638 .44766 .31991 .45055 .30405 .43908 Metetra
.359 .688 .981 r
.30405 .43908 .31991 .45055 .3439 .45199 .32815 .44045 Metetra
.419 .717 .986 r
.32815 .44045 .3439 .45199 .36834 .45196 .35271 .44034 Metetra
.473 .741 .987 r
.35271 .44034 .36834 .45196 .39318 .45043 .3777 .43871 Metetra
.521 .761 .984 r
.3777 .43871 .39318 .45043 .41842 .44735 .40309 .43553 Metetra
.563 .778 .979 r
.40309 .43553 .41842 .44735 .44402 .44272 .42885 .43077 Metetra
.6 .791 .972 r
.42885 .43077 .44402 .44272 .46994 .4365 .45496 .42443 Metetra
.634 .802 .963 r
.45496 .42443 .46994 .4365 .49617 .42868 .48138 .41647 Metetra
.663 .811 .954 r
.48138 .41647 .49617 .42868 .52267 .41925 .50807 .40689 Metetra
.69 .818 .944 r
.50807 .40689 .52267 .41925 .5494 .4082 .53502 .39567 Metetra
.713 .823 .933 r
.53502 .39567 .5494 .4082 .57632 .39552 .56217 .38281 Metetra
.735 .828 .923 r
.56217 .38281 .57632 .39552 .60341 .38121 .58949 .36831 Metetra
.754 .832 .912 r
.58949 .36831 .60341 .38121 .63063 .36529 .61695 .35219 Metetra
.771 .835 .901 r
.61695 .35219 .63063 .36529 .65793 .34775 .6445 .33443 Metetra
.787 .838 .89 r
.6445 .33443 .65793 .34775 .68527 .32861 .67211 .31507 Metetra
.802 .84 .88 r
.67211 .31507 .68527 .32861 .71263 .30789 .69973 .29412 Metetra
.815 .842 .87 r
.69973 .29412 .71263 .30789 .73995 .28562 .72733 .27161 Metetra
.827 .843 .859 r
.72733 .27161 .73995 .28562 .7672 .26182 .75486 .24755 Metetra
.838 .844 .849 r
.75486 .24755 .7672 .26182 .79435 .23653 .78229 .222 Metetra
.849 .845 .84 r
.78229 .222 .79435 .23653 .82134 .20978 .80957 .19498 Metetra
0 .422 .809 r
.17432 .40125 .19101 .41128 .21256 .41949 .19592 .40945 Metetra
0 .489 .861 r
.19592 .40945 .21256 .41949 .23465 .42642 .21808 .41635 Metetra
.084 .551 .904 r
.21808 .41635 .23465 .42642 .25728 .43203 .24079 .42193 Metetra
.169 .605 .938 r
.24079 .42193 .25728 .43203 .28041 .43626 .26402 .42612 Metetra
.249 .653 .963 r
.26402 .42612 .28041 .43626 .30405 .43908 .28776 .42888 Metetra
.322 .693 .98 r
.28776 .42888 .30405 .43908 .32815 .44045 .31199 .43019 Metetra
.388 .727 .99 r
.31199 .43019 .32815 .44045 .35271 .44034 .33669 .43 Metetra
.448 .755 .994 r
.33669 .43 .35271 .44034 .3777 .43871 .36183 .42828 Metetra
.5 .778 .994 r
.36183 .42828 .3777 .43871 .40309 .43553 .38738 .42499 Metetra
.547 .797 .991 r
.38738 .42499 .40309 .43553 .42885 .43077 .41333 .42013 Metetra
.589 .812 .985 r
.41333 .42013 .42885 .43077 .45496 .42443 .43963 .41365 Metetra
.625 .824 .977 r
.43963 .41365 .45496 .42443 .48138 .41647 .46625 .40555 Metetra
.658 .833 .967 r
.46625 .40555 .48138 .41647 .50807 .40689 .49316 .39582 Metetra
.687 .841 .957 r
.49316 .39582 .50807 .40689 .53502 .39567 .52034 .38443 Metetra
.712 .847 .946 r
.52034 .38443 .53502 .39567 .56217 .38281 .54773 .37139 Metetra
.735 .851 .935 r
.54773 .37139 .56217 .38281 .58949 .36831 .5753 .3567 Metetra
.756 .855 .924 r
.5753 .3567 .58949 .36831 .61695 .35219 .60302 .34036 Metetra
.774 .858 .912 r
.60302 .34036 .61695 .35219 .6445 .33443 .63084 .32238 Metetra
.791 .86 .901 r
.63084 .32238 .6445 .33443 .67211 .31507 .65873 .30279 Metetra
.806 .862 .89 r
.65873 .30279 .67211 .31507 .69973 .29412 .68664 .28159 Metetra
.82 .863 .879 r
.68664 .28159 .69973 .29412 .72733 .27161 .71453 .25881 Metetra
.833 .864 .868 r
.71453 .25881 .72733 .27161 .75486 .24755 .74236 .23449 Metetra
.845 .865 .857 r
.74236 .23449 .75486 .24755 .78229 .222 .77009 .20866 Metetra
.856 .865 .847 r
.77009 .20866 .78229 .222 .80957 .19498 .79768 .18135 Metetra
0 .392 .758 r
.15713 .39244 .17432 .40125 .19592 .40945 .17879 .40064 Metetra
0 .464 .818 r
.17879 .40064 .19592 .40945 .21808 .41635 .20103 .40754 Metetra
.024 .531 .87 r
.20103 .40754 .21808 .41635 .24079 .42193 .22382 .41309 Metetra
.114 .592 .913 r
.22382 .41309 .24079 .42193 .26402 .42612 .24716 .41725 Metetra
.199 .647 .946 r
.24716 .41725 .26402 .42612 .28776 .42888 .27102 .41998 Metetra
.278 .693 .97 r
.27102 .41998 .28776 .42888 .31199 .43019 .29539 .42123 Metetra
.351 .733 .986 r
.29539 .42123 .31199 .43019 .33669 .43 .32023 .42097 Metetra
.417 .766 .996 r
.32023 .42097 .33669 .43 .36183 .42828 .34554 .41916 Metetra
.475 .792 .999 r
.34554 .41916 .36183 .42828 .38738 .42499 .37127 .41579 Metetra
.527 .814 .998 r
.37127 .41579 .38738 .42499 .41333 .42013 .39741 .41081 Metetra
.573 .831 .994 r
.39741 .41081 .41333 .42013 .43963 .41365 .42391 .40421 Metetra
.614 .844 .987 r
.42391 .40421 .43963 .41365 .46625 .40555 .45076 .39597 Metetra
.65 .855 .978 r
.45076 .39597 .46625 .40555 .49316 .39582 .4779 .38607 Metetra
.681 .863 .968 r
.4779 .38607 .49316 .39582 .52034 .38443 .50532 .37451 Metetra
.709 .87 .957 r
.50532 .37451 .52034 .38443 .54773 .37139 .53297 .36128 Metetra
.734 .874 .946 r
.53297 .36128 .54773 .37139 .5753 .3567 .56082 .34639 Metetra
.756 .878 .934 r
.56082 .34639 .5753 .3567 .60302 .34036 .58882 .32983 Metetra
.776 .881 .922 r
.58882 .32983 .60302 .34036 .63084 .32238 .61693 .31162 Metetra
.794 .883 .91 r
.61693 .31162 .63084 .32238 .65873 .30279 .64511 .29178 Metetra
.81 .884 .898 r
.64511 .29178 .65873 .30279 .68664 .28159 .67333 .27032 Metetra
.825 .885 .887 r
.67333 .27032 .68664 .28159 .71453 .25881 .70153 .24727 Metetra
.838 .885 .875 r
.70153 .24727 .71453 .25881 .74236 .23449 .72969 .22266 Metetra
.85 .886 .864 r
.72969 .22266 .74236 .23449 .77009 .20866 .75774 .19652 Metetra
.861 .885 .853 r
.75774 .19652 .77009 .20866 .79768 .18135 .78566 .1689 Metetra
0 .357 .698 r
.13941 .3849 .15713 .39244 .17879 .40064 .16114 .39311 Metetra
0 .432 .764 r
.16114 .39311 .17879 .40064 .20103 .40754 .18345 .40001 Metetra
0 .505 .824 r
.18345 .40001 .20103 .40754 .22382 .41309 .20635 .40556 Metetra
.055 .572 .875 r
.20635 .40556 .22382 .41309 .24716 .41725 .2298 .4097 Metetra
.144 .633 .917 r
.2298 .4097 .24716 .41725 .27102 .41998 .25379 .41239 Metetra
.229 .686 .949 r
.25379 .41239 .27102 .41998 .29539 .42123 .2783 .4136 Metetra
.307 .732 .973 r
.2783 .4136 .29539 .42123 .32023 .42097 .3033 .41328 Metetra
.379 .77 .988 r
.3033 .41328 .32023 .42097 .34554 .41916 .32878 .4114 Metetra
.444 .802 .997 r
.32878 .4114 .34554 .41916 .37127 .41579 .35471 .40793 Metetra
.502 .827 1 r
.35471 .40793 .37127 .41579 .39741 .41081 .38105 .40284 Metetra
.553 .847 .998 r
.38105 .40284 .39741 .41081 .42391 .40421 .40778 .39612 Metetra
.598 .863 .993 r
.40778 .39612 .42391 .40421 .45076 .39597 .43486 .38774 Metetra
.637 .875 .986 r
.43486 .38774 .45076 .39597 .4779 .38607 .46226 .37768 Metetra
.672 .884 .976 r
.46226 .37768 .4779 .38607 .50532 .37451 .48994 .36595 Metetra
.703 .892 .966 r
.48994 .36595 .50532 .37451 .53297 .36128 .51787 .35252 Metetra
.73 .897 .954 r
.51787 .35252 .53297 .36128 .56082 .34639 .546 .33742 Metetra
.754 .901 .943 r
.546 .33742 .56082 .34639 .58882 .32983 .5743 .32063 Metetra
.776 .903 .93 r
.5743 .32063 .58882 .32983 .61693 .31162 .60273 .30218 Metetra
.795 .905 .918 r
.60273 .30218 .61693 .31162 .64511 .29178 .63123 .28207 Metetra
.812 .906 .906 r
.63123 .28207 .64511 .29178 .67333 .27032 .65977 .26033 Metetra
.828 .906 .894 r
.65977 .26033 .67333 .27032 .70153 .24727 .68831 .23699 Metetra
.842 .906 .881 r
.68831 .23699 .70153 .24727 .72969 .22266 .71681 .21207 Metetra
.854 .906 .87 r
.71681 .21207 .72969 .22266 .75774 .19652 .74521 .18562 Metetra
.866 .906 .858 r
.74521 .18562 .75774 .19652 .78566 .1689 .77348 .15766 Metetra
.273 0 0 r
.12112 .37863 .13941 .3849 .16114 .39311 .14291 .38688 Metetra
0 .396 .702 r
.14291 .38688 .16114 .39311 .18345 .40001 .16532 .39381 Metetra
0 .472 .767 r
.16532 .39381 .18345 .40001 .20635 .40556 .18831 .39936 Metetra
0 .544 .825 r
.18831 .39936 .20635 .40556 .2298 .4097 .21188 .40349 Metetra
.086 .611 .875 r
.21188 .40349 .2298 .4097 .25379 .41239 .23601 .40617 Metetra
.174 .671 .916 r
.23601 .40617 .25379 .41239 .2783 .4136 .26068 .40734 Metetra
.258 .723 .948 r
.26068 .40734 .2783 .4136 .3033 .41328 .28586 .40697 Metetra
.336 .768 .97 r
.28586 .40697 .3033 .41328 .32878 .4114 .31153 .40502 Metetra
.407 .805 .985 r
.31153 .40502 .32878 .4114 .35471 .40793 .33766 .40146 Metetra
.47 .835 .993 r
.33766 .40146 .35471 .40793 .38105 .40284 .36423 .39627 Metetra
.527 .859 .995 r
.36423 .39627 .38105 .40284 .40778 .39612 .39119 .38943 Metetra
.577 .878 .993 r
.39119 .38943 .40778 .39612 .43486 .38774 .41853 .3809 Metetra
.621 .892 .988 r
.41853 .3809 .43486 .38774 .46226 .37768 .4462 .37068 Metetra
.659 .903 .98 r
.4462 .37068 .46226 .37768 .48994 .36595 .47416 .35877 Metetra
.693 .911 .971 r
.47416 .35877 .48994 .36595 .51787 .35252 .50239 .34515 Metetra
.723 .917 .96 r
.50239 .34515 .51787 .35252 .546 .33742 .53083 .32982 Metetra
.749 .922 .948 r
.53083 .32982 .546 .33742 .5743 .32063 .55945 .3128 Metetra
.773 .924 .936 r
.55945 .3128 .5743 .32063 .60273 .30218 .5882 .29409 Metetra
.793 .926 .923 r
.5882 .29409 .60273 .30218 .63123 .28207 .61705 .2737 Metetra
.812 .927 .911 r
.61705 .2737 .63123 .28207 .65977 .26033 .64594 .25167 Metetra
.828 .927 .898 r
.64594 .25167 .65977 .26033 .68831 .23699 .67484 .22802 Metetra
.843 .927 .886 r
.67484 .22802 .68831 .23699 .71681 .21207 .7037 .20277 Metetra
.857 .926 .873 r
.7037 .20277 .71681 .21207 .74521 .18562 .73248 .17597 Metetra
.869 .925 .861 r
.73248 .17597 .74521 .18562 .77348 .15766 .76112 .14766 Metetra
.321 0 0 r
.1022 .37369 .12112 .37863 .14291 .38688 .12407 .38199 Metetra
.24 0 0 r
.12407 .38199 .14291 .38688 .16532 .39381 .14657 .38895 Metetra
0 .434 .702 r
.14657 .38895 .16532 .39381 .18831 .39936 .16968 .39453 Metetra
0 .509 .765 r
.16968 .39453 .18831 .39936 .21188 .40349 .19338 .39868 Metetra
.027 .581 .822 r
.19338 .39868 .21188 .40349 .23601 .40617 .21766 .40134 Metetra
.117 .647 .871 r
.21766 .40134 .23601 .40617 .26068 .40734 .24249 .40249 Metetra
.205 .706 .91 r
.24249 .40249 .26068 .40734 .28586 .40697 .26786 .40207 Metetra
.287 .757 .941 r
.26786 .40207 .28586 .40697 .31153 .40502 .29373 .40007 Metetra
.363 .8 .962 r
.29373 .40007 .31153 .40502 .33766 .40146 .32008 .39643 Metetra
.432 .836 .976 r
.32008 .39643 .33766 .40146 .36423 .39627 .34688 .39114 Metetra
.495 .864 .984 r
.34688 .39114 .36423 .39627 .39119 .38943 .37411 .38417 Metetra
.55 .887 .986 r
.37411 .38417 .39119 .38943 .41853 .3809 .40171 .3755 Metetra
.598 .905 .984 r
.40171 .3755 .41853 .3809 .4462 .37068 .42967 .36512 Metetra
.641 .918 .978 r
.42967 .36512 .4462 .37068 .47416 .35877 .45794 .35302 Metetra
.679 .928 .97 r
.45794 .35302 .47416 .35877 .50239 .34515 .48648 .33919 Metetra
.712 .935 .961 r
.48648 .33919 .50239 .34515 .53083 .32982 .51525 .32364 Metetra
.741 .94 .95 r
.51525 .32364 .53083 .32982 .55945 .3128 .54421 .30637 Metetra
.766 .944 .938 r
.54421 .30637 .55945 .3128 .5882 .29409 .57332 .28738 Metetra
.789 .946 .926 r
.57332 .28738 .5882 .29409 .61705 .2737 .60253 .26671 Metetra
.809 .947 .913 r
.60253 .26671 .61705 .2737 .64594 .25167 .6318 .24437 Metetra
.826 .947 .901 r
.6318 .24437 .64594 .25167 .67484 .22802 .66109 .22038 Metetra
.842 .946 .888 r
.66109 .22038 .67484 .22802 .7037 .20277 .69033 .19479 Metetra
.857 .945 .875 r
.69033 .19479 .7037 .20277 .73248 .17597 .7195 .16763 Metetra
.869 .944 .863 r
.7195 .16763 .73248 .17597 .76112 .14766 .74855 .13893 Metetra
.361 0 0 r
.08261 .37011 .1022 .37369 .12407 .38199 .10457 .37849 Metetra
.287 0 0 r
.10457 .37849 .12407 .38199 .14657 .38895 .12716 .3855 Metetra
.206 0 0 r
.12716 .3855 .14657 .38895 .16968 .39453 .15039 .39112 Metetra
0 .47 .698 r
.15039 .39112 .16968 .39453 .19338 .39868 .17423 .39529 Metetra
0 .545 .759 r
.17423 .39529 .19338 .39868 .21766 .40134 .19867 .39796 Metetra
.059 .615 .814 r
.19867 .39796 .21766 .40134 .24249 .40249 .22368 .3991 Metetra
.148 .679 .861 r
.22368 .3991 .24249 .40249 .26786 .40207 .24924 .39865 Metetra
.234 .737 .899 r
.24924 .39865 .26786 .40207 .29373 .40007 .27533 .39659 Metetra
.314 .786 .928 r
.27533 .39659 .29373 .40007 .32008 .39643 .30192 .39288 Metetra
.389 .828 .949 r
.30192 .39288 .32008 .39643 .34688 .39114 .32898 .38749 Metetra
.456 .862 .962 r
.32898 .38749 .34688 .39114 .37411 .38417 .35648 .3804 Metetra
.516 .89 .97 r
.35648 .3804 .37411 .38417 .40171 .3755 .38437 .3716 Metetra
.57 .911 .972 r
.38437 .3716 .40171 .3755 .42967 .36512 .41264 .36105 Metetra
.617 .928 .969 r
.41264 .36105 .42967 .36512 .45794 .35302 .44123 .34876 Metetra
.659 .94 .964 r
.44123 .34876 .45794 .35302 .48648 .33919 .47011 .33472 Metetra
.695 .949 .956 r
.47011 .33472 .48648 .33919 .51525 .32364 .49923 .31893 Metetra
.727 .956 .947 r
.49923 .31893 .51525 .32364 .54421 .30637 .52856 .30139 Metetra
.756 .96 .936 r
.52856 .30139 .54421 .30637 .57332 .28738 .55805 .28212 Metetra
.78 .962 .924 r
.55805 .28212 .57332 .28738 .60253 .26671 .58765 .26114 Metetra
.802 .964 .912 r
.58765 .26114 .60253 .26671 .6318 .24437 .61732 .23847 Metetra
.821 .964 .9 r
.61732 .23847 .6318 .24437 .66109 .22038 .64701 .21413 Metetra
.839 .963 .887 r
.64701 .21413 .66109 .22038 .69033 .19479 .67668 .18817 Metetra
.854 .962 .874 r
.67668 .18817 .69033 .19479 .7195 .16763 .70627 .16062 Metetra
.868 .961 .861 r
.70627 .16062 .7195 .16763 .74855 .13893 .73574 .13152 Metetra
.395 0 0 r
.0623 .36795 .08261 .37011 .10457 .37849 .08434 .37641 Metetra
.327 0 0 r
.08434 .37641 .10457 .37849 .12716 .3855 .10705 .38351 Metetra
.252 0 0 r
.10705 .38351 .12716 .3855 .15039 .39112 .1304 .38918 Metetra
.171 0 0 r
.1304 .38918 .15039 .39112 .17423 .39529 .15439 .39339 Metetra
.086 0 0 r
.15439 .39339 .17423 .39529 .19867 .39796 .179 .39608 Metetra
.002 .577 .75 r
.179 .39608 .19867 .39796 .22368 .3991 .2042 .39722 Metetra
.091 .645 .802 r
.2042 .39722 .22368 .3991 .24924 .39865 .22997 .39675 Metetra
.178 .708 .846 r
.22997 .39675 .24924 .39865 .27533 .39659 .25629 .39464 Metetra
.261 .763 .882 r
.25629 .39464 .27533 .39659 .30192 .39288 .28313 .39087 Metetra
.339 .811 .91 r
.28313 .39087 .30192 .39288 .32898 .38749 .31046 .38539 Metetra
.412 .851 .93 r
.31046 .38539 .32898 .38749 .35648 .3804 .33825 .37818 Metetra
.477 .884 .943 r
.33825 .37818 .35648 .3804 .38437 .3716 .36646 .36923 Metetra
.536 .91 .95 r
.36646 .36923 .38437 .3716 .41264 .36105 .39505 .35852 Metetra
.588 .93 .952 r
.39505 .35852 .41264 .36105 .44123 .34876 .42399 .34603 Metetra
.633 .946 .95 r
.42399 .34603 .44123 .34876 .47011 .33472 .45323 .33177 Metetra
.674 .958 .945 r
.45323 .33177 .47011 .33472 .49923 .31893 .48273 .31573 Metetra
.709 .966 .938 r
.48273 .31573 .49923 .31893 .52856 .30139 .51245 .29792 Metetra
.74 .972 .928 r
.51245 .29792 .52856 .30139 .55805 .28212 .54234 .27836 Metetra
.767 .976 .918 r
.54234 .27836 .55805 .28212 .58765 .26114 .57236 .25705 Metetra
.791 .978 .907 r
.57236 .25705 .58765 .26114 .61732 .23847 .60246 .23403 Metetra
.813 .978 .895 r
.60246 .23403 .61732 .23847 .64701 .21413 .63258 .20932 Metetra
.831 .978 .882 r
.63258 .20932 .64701 .21413 .67668 .18817 .66269 .18296 Metetra
.848 .977 .87 r
.66269 .18296 .67668 .18817 .70627 .16062 .69273 .15499 Metetra
.863 .976 .857 r
.69273 .15499 .70627 .16062 .73574 .13152 .72266 .12545 Metetra
.422 0 0 r
.0412 .36725 .0623 .36795 .08434 .37641 .06334 .37583 Metetra
.36 0 0 r
.06334 .37583 .08434 .37641 .10705 .38351 .08616 .38302 Metetra
.291 0 0 r
.08616 .38302 .10705 .38351 .1304 .38918 .10965 .38877 Metetra
.216 0 0 r
.10965 .38877 .1304 .38918 .15439 .39339 .13379 .39304 Metetra
.135 0 0 r
.13379 .39304 .15439 .39339 .179 .39608 .15858 .39577 Metetra
.051 0 0 r
.15858 .39577 .179 .39608 .2042 .39722 .18398 .39691 Metetra
.035 .606 .736 r
.18398 .39691 .2042 .39722 .22997 .39675 .20998 .39644 Metetra
.122 .672 .785 r
.20998 .39644 .22997 .39675 .25629 .39464 .23655 .3943 Metetra
.206 .732 .827 r
.23655 .3943 .25629 .39464 .28313 .39087 .26366 .39046 Metetra
.287 .785 .861 r
.26366 .39046 .28313 .39087 .31046 .38539 .29128 .3849 Metetra
.362 .831 .888 r
.29128 .3849 .31046 .38539 .33825 .37818 .31937 .37758 Metetra
.432 .869 .907 r
.31937 .37758 .33825 .37818 .36646 .36923 .34791 .36848 Metetra
.495 .9 .919 r
.34791 .36848 .36646 .36923 .39505 .35852 .37685 .3576 Metetra
.552 .925 .926 r
.37685 .3576 .39505 .35852 .42399 .34603 .40616 .34491 Metetra
.602 .945 .928 r
.40616 .34491 .42399 .34603 .45323 .33177 .43579 .33042 Metetra
.646 .96 .927 r
.43579 .33042 .45323 .33177 .48273 .31573 .46569 .31412 Metetra
.685 .971 .922 r
.46569 .31412 .48273 .31573 .51245 .29792 .49583 .29603 Metetra
.72 .979 .915 r
.49583 .29603 .51245 .29792 .54234 .27836 .52615 .27615 Metetra
.75 .984 .906 r
.52615 .27615 .54234 .27836 .57236 .25705 .55662 .2545 Metetra
.776 .987 .896 r
.55662 .2545 .57236 .25705 .60246 .23403 .58717 .2311 Metetra
.799 .989 .885 r
.58717 .2311 .60246 .23403 .63258 .20932 .61776 .206 Metetra
.82 .989 .874 r
.61776 .206 .63258 .20932 .66269 .18296 .64834 .17922 Metetra
.838 .989 .862 r
.64834 .17922 .66269 .18296 .69273 .15499 .67887 .1508 Metetra
.854 .987 .85 r
.67887 .1508 .69273 .15499 .72266 .12545 .70928 .12079 Metetra
.444 0 0 r
.01926 .36808 .0412 .36725 .06334 .37583 .04149 .37679 Metetra
.387 0 0 r
.04149 .37679 .06334 .37583 .08616 .38302 .06443 .3841 Metetra
.324 0 0 r
.06443 .3841 .08616 .38302 .10965 .38877 .08806 .38995 Metetra
.254 0 0 r
.08806 .38995 .10965 .38877 .13379 .39304 .11238 .39429 Metetra
.179 0 0 r
.11238 .39429 .13379 .39304 .15858 .39577 .13735 .39708 Metetra
.1 0 0 r
.13735 .39708 .15858 .39577 .18398 .39691 .16297 .39826 Metetra
.017 0 0 r
.16297 .39826 .18398 .39691 .20998 .39644 .18921 .39778 Metetra
.067 .631 .718 r
.18921 .39778 .20998 .39644 .23655 .3943 .21604 .39562 Metetra
.151 .694 .765 r
.21604 .39562 .23655 .3943 .26366 .39046 .24343 .39173 Metetra
.233 .751 .804 r
.24343 .39173 .26366 .39046 .29128 .3849 .27136 .38608 Metetra
.31 .802 .836 r
.27136 .38608 .29128 .3849 .31937 .37758 .29979 .37865 Metetra
.383 .846 .861 r
.29979 .37865 .31937 .37758 .34791 .36848 .32868 .36942 Metetra
.45 .882 .879 r
.32868 .36942 .34791 .36848 .37685 .3576 .35799 .35836 Metetra
.51 .912 .891 r
.35799 .35836 .37685 .3576 .40616 .34491 .38769 .34547 Metetra
.565 .936 .898 r
.38769 .34547 .40616 .34491 .43579 .33042 .41773 .33074 Metetra
.613 .955 .9 r
.41773 .33074 .43579 .33042 .46569 .31412 .44806 .31417 Metetra
.656 .969 .899 r
.44806 .31417 .46569 .31412 .49583 .29603 .47865 .29578 Metetra
.694 .979 .895 r
.47865 .29578 .49583 .29603 .52615 .27615 .50943 .27556 Metetra
.727 .987 .889 r
.50943 .27556 .52615 .27615 .55662 .2545 .54037 .25355 Metetra
.756 .992 .88 r
.54037 .25355 .55662 .2545 .58717 .2311 .57141 .22977 Metetra
.782 .995 .871 r
.57141 .22977 .58717 .2311 .61776 .206 .6025 .20424 Metetra
.804 .996 .861 r
.6025 .20424 .61776 .206 .64834 .17922 .63359 .17701 Metetra
.824 .996 .85 r
.63359 .17701 .64834 .17922 .67887 .1508 .66463 .14811 Metetra
.842 .996 .838 r
.66463 .14811 .67887 .1508 .70928 .12079 .69556 .11761 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-2)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-1)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(1)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(2)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{318.813, 258.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007N0001Pb000`400?l00000o`00003oo`3ooooO
0?ooo`00o`3ooolk0?ooo`030?oo_`1d0000000000@0000000<0M;oo0?ooo`3oool0VP3oool00?l0
oooo?03oool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo09/0oooo003o0?ooocd0oooo
00<0okmd0000B02Lgol0W`3oool00?l0oooo?P3oool00`3ogi`0B00004RLg`2N0?ooo`00o`3ooom0
0?ooo`0309a80018W=l0oooo09`0oooo003o0?oood40oooo00<0W4Qd0;ooo`3oool0V`3oool00?l0
oooo?03oool00`3OW4P0M;oo0?ooo`020?ooo`030;md001d_ol0oooo09/0oooo003o0?oooc`0oooo
00L0okmd0000M02oool0oooo0?noM00004P0W=oo09`0oooo003o0?ooocd0oooo00D0okmd00000000
0000001809cOo`0B0?ooo`030?oo_`1d0000000000@0000000<0M;oo0?ooo`3oool0P@3oool00?l0
ooooE@3oool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo0880oooo003o0?oooeH0oooo
00<0okmd0000B02Lgol0QP3oool00?l0ooooE`3oool00`3ogi`0B00004RLg`250?ooo`00o`3ooom<
0?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool0103oool00`2LB000B9cO0?ooo`23
0?ooo`00o`3ooomJ0?ooo`0309a8M02oool0oooo0880oooo003o0?oooeD0oooo00<0gia807Boo`3o
ool00P3oool00`2oM000M;oo0?ooo`220?ooo`00o`3ooomE0?ooo`070?noM00007@0_ooo0?ooo`3o
_g@0001809cOo`230?ooo`00o`3ooomF0?ooo`050?noM000000000000000B02Lgol0Q03oool00?l0
ooooA@3oool2000009P0oooo003o0?oood<0oooo0P0000000`3oool000000000002G0?ooo`00o`3o
oom00?ooo`<000000`3oool2000009L0oooo003o0?oooch0oooo0P0000060?ooo`030000003oool0
000009H0oooo003o0?oooc/0oooo0`0000080?ooo`040000003oool0oooo000009D0oooo003o0?oo
ocP0oooo0`00000;0?ooo`040000003oool0oooo000009D0oooo003o0?ooocH0oooo0P00000>0?oo
o`050000003oool0oooo0?ooo`000000U03oool00?l0oooo<`3oool3000000030?ooo`000000oooo
00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2A0?ooo`00o`3ooola0?ooo`80
00004`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0940oooo003o0?ooobh0oooo
0`00000F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0T03oool00?l0oooo;03o
ool2000001T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2?0?ooo`00o`3ooolY
0?ooo`<000006`3oool010000000oooo0?ooo`3oool300000940oooo003o0?ooobH0oooo0`00000N
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00>l0oooo00<0ohle0000
000000000`0000000`00=Hl0oooo0?ooo`0[0?ooo`8000000P3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00?80oooo00<0Ga@D05o4o`3o
ool0:`3oool3000002<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2=0?ooo`00
lP3oool00`1O51@0GlCo0?ooo`0Y0?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo08`0oooo003b0?ooo`0305lD501Oa?l0oooo02H0oooo0`00000X0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0S03oool00?80oooo00<0Ga@D05o4o`3oool0903oool2
000002/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2;0?ooo`00lP3oool00`1O
51@0GlCo0?ooo`0Q0?ooo`<00000;@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
08X0oooo003b0?ooo`0305lD501Oa?l0oooo01h0oooo0`0000020?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2:0?ooo`00k`3oool01@34Ga@00000
000DG`1O51@0GlCo01d0oooo0P00000c0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0R@3oool00?40oooo00<0a5lD0000501Oa?l06P3oool3000003D0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`280?ooo`00o`3oool=0?ooo`800000>03oool00`000000oooo0?oo
o`080?ooo`<00000RP3oool00?l0oooo2P3oool3000003X0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`270?ooo`00o`3oool80?ooo`800000?@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo08H0oooo003o0?ooo`D0oooo0`0000020?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`260?ooo`00o`3oool30?ooo`800000
@P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo08D0oooo003o0?ooo`<00000A@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo08@0oooo003l0?ooo`<00000B03oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo08@0oooo003i0?ooo`<00000B`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo08<0oooo003g0?ooo`<00000C@3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0880oooo003e0?ooo`8000000`3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0PP3oool00?80oooo0`00
00050?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`210?ooo`00l03oool2000005D0oooo00<000000?ooo`3oool03P3oool2000000030?ooo`000000
oooo0840oooo003]0?ooo`<00000E`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0800oooo003Z0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo07l0
oooo003X0?ooo`80000000<0oooo0000003oool0FP3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo07h0oooo003U0?ooo`<00000G`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo07h0oooo003S0?ooo`800000HP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo07d0oooo003P0?ooo`<00000I03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
07d0oooo003N0?ooo`800000I`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo07`0
oooo002X0?ooo`050?n?=@00000000000000000eSol0;P3oool3000006T0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`1k0?ooo`00Z03oool01P1O53D0Sooo0?ooo`3oohl0=@0e08oo
obX0oooo0`0000020?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`1k0?ooo`00Y`3oool00`3oScD003F?0?ooo`020?ooo`030<AO500DGl@0oooo02L0
oooo0P00001_0?ooo`030000003oool0oooo01D0oooo0`00001l0?ooo`00Y`3oool00`34Ga@055o4
0?ooo`020?ooo`030?n?=@00=Hl0oooo02@0oooo0`00001b0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0N@3oool00:L0oooo00<0a5lD01AOa03oool00P3oool00`3oScD003F?0?oo
o`0R0?ooo`800000M@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo00<0
okmd0000000000000`0000000`00M;l0oooo0?ooo`1N0?ooo`00Y`3oool00`34Ga@055o40?ooo`02
0?ooo`030?n?=@00=Hl0oooo01l0oooo0`00001g0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0503oool00`2LB4P0W=oo0?ooo`1Q0?ooo`00Y`3oool00`3oScD055o40?ooo`020?oo
o`030<AO500DGl@0oooo01d0oooo0`00001i0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool04`3oool00`2LB4P0W=oo0?ooo`1Q0?ooo`00Z03oool01P1O5000=Hoo0?ooo`3oa5l0500e
08oooa/0oooo0`0000030?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0C0?ooo`0309a8B02Lgol0oooo0640oooo002X0?ooo`050?ooS`0e00000000
0000501Oa?l06P3oool2000007l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`06
0?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool00`3oool00`2LB4P0W=oo0?ooo`1Q
0?ooo`00a03oool300000800oooo0`00000L0?ooo`030000003oool0oooo0140oooo00<0W4Q809cO
o`3oool0H@3oool00<40oooo0`0000220?ooo`040000003Go]H000000=OnePD000005`3oool00`00
0000oooo0?ooo`0A0?ooo`0309a8B02Lgol0oooo0640oooo002o0?ooo`800000Q03oool010000000
eokF0=OneP0000030=OneP030000003Jo=T0f_cI00<000005@3oool00`000000oooo0?ooo`0=0?oo
o`050=nLB000000004RL09a8B02Lgol0HP3oool00;`0oooo0`0000020?ooo`030000003oool0oooo
0800oooo00D000000=OneP3Go]H0eokF000000020=OneP030000003Jo=T0f_cI00@0f_cI0P00000C
0?ooo`800000403oool00`3OW4P0001809cOo`1R0?ooo`00^P3oool2000008L0oooo00<000000=On
eP3Go]H00P3Go]H00`000000eokF000000070=[lf@040000003LnM/00000000000l0oooo0P000000
0`3oool000000?ooo`1d0?ooo`00]`3oool3000008P0oooo00<000000=OneP3Go]H00`3Go]H20000
00L0f_cI00<000000=cif`3LnM/00P3LnM/200000140oooo00<000000?ooo`3oool0LP3oool00;D0
oooo0P00002:0?ooo`030000003Go]H0eokF00@0eokF00<000000=[lf@3Jo=T01@3Jo=T00`000000
g?WK0=cif`050=cif`800000403oool00`000000oooo0?ooo`1a0?ooo`00/P3oool3000008/0oooo
00<000000=OneP3Go]H0103Go]H2000000H0f_cI00<000000=cif`3LnM/01P3LnM/010000000g_KL
00000000000>0?ooo`030000003oool0oooo0740oooo002_0?ooo`<0000000<0oooo0000003oool0
RP3oool00`000000eokF0=OneP040=OneP030000003Jo=T0000000D0f_cI00<000000=cif`3LnM/0
1P3LnM/00`000000g_KL0=kfg0020=kfg08000003@3oool00`000000oooo0?ooo`1`0?ooo`00[@3o
ool2000000D0oooo00<000000?ooo`3oool0Q`3oool00`000000eokF0=OneP040=OneP040000003J
o=T0f_cI000000@0f_cI00<000000=cif`3LnM/01P3LnM/00`000000g_KL0=kfg0050=kfg0030000
003oool0oooo00/0oooo00<000000?ooo`3oool0K`3oool00:X0oooo0`00002@0?ooo`030000003G
o]H0eokF00@0eokF00D000000=[lf@3Jo=T0f_cI000000030=[lf@030000003LnM/0g?WK00H0g?WK
00<000000=kfg03Nm]`01@3Nm]`010000000g_7L00000000000;0?ooo`030000003oool0oooo06l0
oooo002X0?ooo`800000TP3oool00`000000eokF0=OneP040=OneP030000003Jo=T0f_cI00<0f_cI
00<000000=[lf@000000203LnM/00`000000g_KL0=kfg0050=kfg0030000003NlM`0g_7L0080g_7L
0P00000:0?ooo`030000003oool0oooo06h0oooo002U0?ooo`<00000T`3oool00`000000eokF0=On
eP040=OneP030000003Jo=T0f_cI00@0f_cI0P0000070=cif`8000001`3Nm]`00`000000g_7L0=ka
g0050=kag0030000003oool0oooo00P0oooo00<000000?ooo`3oool0K@3oool00:<0oooo0P00002E
0?ooo`<00000103Go]H00`000000f_cI0=[lf@050=[lf@030000003LnM/0g?WK00D0g?WK00<00000
0=kfg03Nm]`01P3Nm]`00`000000g_7L0=kag0050=kag0030000003Nk=`0000000T0oooo00<00000
0?ooo`3oool0K@3oool00:00oooo0`0000020?ooo`030000003oool0oooo0940oooo00@000000=;n
f@3Bo]T0d_kI1@0000060=[lf@8000001P3LnM/00`000000g_KL0=kfg0060=kfg0030000003NlM`0
g_7L00D0g_7L00D000000=k/g03Nk=`0g^cL000000060?ooo`80000000<0oooo0000003oool0K@3o
ool009h0oooo0P00002H0?ooo`030000003Bo]T0d_kI00@0d_kI00<000000=Kmg03FoM`00`000002
0=[lf@030000003LnM/0000000D0g?WK00<000000=kfg03Nm]`01P3Nm]`00`000000g_7L0=kag005
0=kag0030000003Nk=`0g^cL00<0g^cL0P0000070?ooo`030000003oool0oooo06`0oooo002K0?oo
o`<00000V@3oool00`000000d_kI0=;nf@040=;nf@030000003FoM`0e_gL00@0e_gL0`0000000`3L
nM/000000=cif`030=cif`030000003Nm]`0g_KL00H0g_KL00<000000=kag03NlM`01@3NlM`00`00
0000g^cL0=k/g0060=k/g0030000003oool0oooo00D0oooo00<000000?ooo`3oool0J`3oool006<0
oooo00<0ohle0000000000000`0000000`00=Hl0oooo0?ooo`0/0?ooo`<00000V`3oool00`000000
d_kI0=;nf@040=;nf@030000003FoM`0e_gL00D0e_gL00<000000=WjgP3In]h00`0000020=cif`03
0000003Nm]`0g_KL00H0g_KL00<000000=kag03NlM`01@3NlM`00`000000g^cL0=k/g0080=k/g003
0000003oool0oooo00D0oooo00<000000?ooo`3oool0JP3oool006H0oooo00<0Ga@D05o4o`3oool0
;@3oool2000009d0oooo00<000000=;nf@3Bo]T0103Bo]T00`000000e_gL0=Kmg0050=Kmg0030000
003In]h0fO[N0080fO[N00@000000=WjgP0000000000203Nm]`00`000000g_7L0=kag0050=kag003
0000003Nk=`0g^cL00P0g^cL00<000000=gWf`0000001P3oool00`000000oooo0?ooo`1Z0?ooo`00
IP3oool00`1O51@0GlCo0?ooo`0Z0?ooo`<0000000<0oooo000000000000VP3oool2000000H0d_kI
00<000000=Kmg03FoM`0103FoM`2000000D0fO[N00@000000=WjgP000000f_KO0P0000050=kfg003
0000003NlM`0g_7L00D0g_7L00<000000=k/g03Nk=`0203Nk=`010000000gNOK0=gWf`3Mim/20000
00D0oooo00<000000?ooo`3oool0J@3oool006H0oooo00<0Ga@D05o4o`3oool0:03oool2000009l0
oooo00<000000=;nf@3Bo]T0103Bo]T2000000H0e_gL00<000000=WjgP3In]h01@3In]h2000000@0
f_KO0P0000020=kfg0030000003NlM`0g_7L00D0g_7L00<000000=k/g03Nk=`0203Nk=`00`000000
gNOK0=gWf`040=gWf`030000003oool0oooo00<0oooo00<000000?ooo`3oool0J03oool005X0oooo
00<0Ga@00000000000000`0000000`0055l0oooo0?ooo`030?ooo`0305lD501Oa?l0oooo02D0oooo
0`00002P0?ooo`030000003Bo]T0d_kI00@0d_kI00<000000=Kmg03FoM`01@3FoM`00`000000fO[N
0=WjgP060=WjgP030000003Jm]l0f_KO00D0f_KO0P0000070=kag0030000003Nk=`0g^cL00P0g^cL
00<000000=gWf`3Mim/01P3Mim/00`000000oooo0?ooo`020?ooo`030000003oool0oooo06P0oooo
001V0?ooo`0305lD501Oa?l0oooo02<0oooo0P00002R0?ooo`030000003Bo]T0d_kI00@0d_kI00<0
00000=Kmg03FoM`01@3FoM`00`000000fO[N0=WjgP060=WjgP8000001`3Jm]l010000000fo7O0000
000000040=kag0030000003Nk=`0g^cL00P0g^cL00<000000=gWf`3Mim/01P3Mim/00`000000g>;J
000000040?ooo`030000003oool0oooo06L0oooo001V0?ooo`0305lD501Oa?l0oooo0200oooo0`00
002S0?ooo`030000003Bo]T0d_kI00@0d_kI00<000000=Kmg03FoM`01@3FoM`00`000000fO[N0=Wj
gP060=WjgP030000003Jm]l0000000H0f_KO00<000000=_ag`3KlMl00P3KlMl2000000030=kag000
0000g^cL00T0g^cL00<000000=gWf`3Mim/01P3Mim/01@000000g>;J0=cRfP3Lh]X000000080oooo
0`00001X0?ooo`00H`3oool01@34Ga@00000000DG`1O51@0GlCo01h0oooo0`0000000`3oool00000
0?ooo`2R0?ooo`030000003Bo]T0d_kI00@0d_kI00<000000=Kmg03FoM`0103FoM`2000000L0fO[N
0P0000020=[fg`030000003Jm]l0f_KO0080f_KO0P0000070=_ag`030000003Nk=`0g^cL00P0g^cL
00<000000=gWf`3Mim/01P3Mim/00`000000g>;J0=cRfP020=cRfP030000003oool0oooo0080oooo
00<000000?ooo`3oool0IP3oool006D0oooo00<0a5lD0000501Oa?l0703oool200000:L0oooo0`00
00040=;nf@030000003FoM`0e_gL00@0e_gL00<000000=WjgP3In]h01P3In]h00`000000f_KO0=[f
g`020=[fg`050000003Jm]l0f_KO0=[fg`000000203KlMl00`000000fngO000000080=k/g0030000
003Mim/0gNOK00H0gNOK00<000000=cRfP3Lh]X0103Lh]X00`000000oooo0?ooo`020?ooo`030000
003oool0oooo06D0oooo00210?ooo`<00000Z03oool010000000cOkL0<gng03=o]`6000000@0e_gL
00<000000=WjgP3In]h01P3In]h00`000000f_KO0=[fg`030=[fg`040000003Jm]l0f_KO000000P0
fo7O00D000000=_]g`3KkMl0fngO000000060=k/g0030000003Mim/0gNOK00H0gNOK00<000000=cR
fP3Lh]X01P3Lh]X00`000000oooo0?ooo`020?ooo`030000003oool0oooo06@0oooo001o0?ooo`80
0000ZP3oool00`000000cOkL0<gng0040<gng0040000003AoMl0dOgO0=7mg`@00000203In]h00`00
0000f_KO0=[fg`040=[fg`030000003Jm]l0000000P0fo7O00<000000=_]g`3KkMl00`3KkMl20000
00<0g^cL00<000000=gWf`3Mim/01P3Mim/00`000000g>;J0=cRfP080=cRfP050000003oool0oooo
0?ooo`000000IP3oool007`0oooo0`00002Z0?ooo`8000001P3=o]`00`000000dOgO0=7mg`040=7m
g`040000003Dn^400000000000D0fO[N00<000000=[fg`3Jm]l01@3Jm]l2000000P0fo7O00<00000
0=_]g`3KkMl01P3KkMl00`000000g^cL000000080=gWf`030000003Lh]X0g>;J00P0g>;J00<00000
0=_Mf00000000`3oool00`000000oooo0?ooo`1S0?ooo`00NP3oool300000:/0oooo00<000000<gn
g03=o]`0103=o]`2000000H0dOgO00<000000=Cjh@3Dn^400P3Dn^4200000080fO[N00<000000=[f
g`3Jm]l01@3Jm]l3000000L0fo7O00<000000=_]g`3KkMl0203KkMl00`000000gNOK0=gWf`060=gW
f`030000003Lh]X0g>;J00P0g>;J00D000000=_Mf03KgMP0fmgH000000030?ooo`030000003oool0
oooo0680oooo001g0?ooo`<000000`3oool00`000000oooo0?ooo`2W0?ooo`030000003=o]`0cOkL
00@0cOkL00<000000=7mg`3AoMl01@3AoMl00`000000e?[Q0=Cjh@050=Cjh@<000001P3Jm]l01000
0000fo7O0=_ag`0000060=_ag`030000003KkMl0fngO00P0fngO00<000000=[WgP0000001P3Mim/0
0`000000g>;J0=cRfP080=cRfP030000003KgMP0fmgH0080fmgH00D000000?ooo`3oool0oooo0000
001T0?ooo`00M03oool300000:l0oooo00<000000<gng03=o]`0103=o]`00`000000dOgO0=7mg`05
0=7mg`030000003Dn^40e?[Q00H0e?[Q00<000000=Kfh`3Fm^<00`0000020=[fg`050000003KlMl0
fo7O0=_ag`0000001@3KlMl00`000000fngO0=_]g`080=_]g`040000003Jimh0f^ON0=[WgP800000
0`3Mim/00`000000g>;J0=cRfP080=cRfP030000003KgMP0fmgH00@0fmgH00D000000?ooo`3oool0
oooo0000001S0?ooo`00LP3oool200000;40oooo00<000000<gng03=o]`0103=o]`00`000000dOgO
0=7mg`050=7mg`030000003Dn^40e?[Q00H0e?[Q00<000000=Kfh`3Fm^<0103Fm^<2000000@0fo7O
00<000000=_ag`3KlMl00P3KlMl00`000000fngO0=_]g`070=_]g`8000001P3Jimh00`000000gNOK
0000000:0=cRfP030000003KgMP0fmgH00H0fmgH00D000000?ooo`3oool0oooo0000001R0?ooo`00
K`3oool300000;40oooo0P0000060<gng0030000003AoMl0dOgO00D0dOgO00<000000=Cjh@3Dn^40
1P3Dn^400`000000e_KS0=Kfh`050=Kfh`040000003Gl^<0000000000080fo7O00D000000=_ag`3K
lMl0fo7O000000090=_]g`030000003Jimh0f^ON00L0f^ON00<000000=cRfP3Lh]X01`3Lh]X20000
00X0fmgH1000001R0?ooo`00K@3oool2000000030?ooo`000000oooo0;00oooo00<000000<gng03=
o]`0103=o]`2000000L0dOgO00<000000=Cjh@3Dn^401P3Dn^400`000000e_KS0=Kfh`050=Kfh`03
0000003Gl^<0eo;S0080eo;S00<000000=_ag`0000000P3KlMl00`000000fngO0=_]g`070=_]g`03
0000003Jimh0f^ON00L0f^ON00<000000=WRg@0000001`3Lh]X00`000000fmgH0=_Mf0090=_Mf003
0000003If=L000000080oooo00<000000?ooo`3oool0G`3oool006X0oooo0`0000040?ooo`030000
003oool0oooo0:d0oooo00<000000<gng03=o]`0103=o]`00`000000dOgO0=7mg`060=7mg`030000
003Dn^40e?[Q00H0e?[Q00<000000=Kfh`3Fm^<01@3Fm^<00`000000eo;S0=Obh`040=Obh`800000
00<0fo7O0000003KkMl0203KkMl00`000000f^ON0=[WgP070=[WgP050000003Ih]d0fN;M0=WRg@00
00001@3Lh]X00`000000fmgH0=_Mf0090=_Mf0050000003If=L0fMSG0=WHe`0000000P3oool00`00
0000oooo0?ooo`1N0?ooo`00J03oool200000;H0oooo0`0000040<gng0030000003AoMl0dOgO00H0
dOgO00<000000=Cjh@3Dn^401@3Dn^42000000L0e_KS00<000000=Obh`3Gl^<01P3Gl^<2000000T0
fngO00<000000=[WgP3Jimh01`3Jimh00`000000fN;M0=WRg@030=WRg@050000003Lh]X0g>;J0=cR
fP0000002`3KgMP00`000000fMSG0=WHe`020=WHe`040000003oool0oooo00000600oooo001U0?oo
o`<00000]`3oool010000000b?kN0<SngP38o]h5000000L0dOgO00<000000=Cjh@3Dn^401@3Dn^40
0`000000e_KS0=Kfh`060=Kfh`030000003Gl^<0eo;S00L0eo;S00<000000=O]hP0000001P3KkMl2
000000T0f^ON00<000000=WRg@3Ih]d01@3Ih]d00`000000g>;J0000000;0=_Mf0030000003If=L0
fMSG00@0fMSG00@000000?ooo`3oool00000G`3oool00680oooo0`00002i0?ooo`0300000038o]h0
b?kN00@0b?kN00<000000<cmhP3<oN80100000020=7mg`030000003Dn^40e?[Q00D0e?[Q00<00000
0=Kfh`3Fm^<01@3Fm^<2000000T0eo;S0P0000020=O]hP8000000`3KkMl00`000000f^ON0=[WgP08
0=[WgP030000003Ih]d0fN;M00L0fN;M00<000000=_Mf03KgMP02@3KgMP00`000000fMSG0=WHe`06
0=WHe`040000003oool0oooo000005h0oooo001P0?ooo`<00000^@3oool2000000H0b?kN00<00000
0<cmhP3<oN801@3<oN83000000H0e?[Q00<000000=Kfh`3Fm^<01@3Fm^<00`000000eo;S0=Obh`08
0=Obh`030000003GkN80000000@0engR00<000000=_]g`0000002@3Jimh2000000T0fN;M00<00000
0=SMf`000000203KgMP2000000X0fMSG00<000000?ooo`000000GP3oool005d0oooo0`0000030?oo
o`030000003oool0oooo0;D0oooo00<000000<SngP38o]h01038o]h2000000P0c?gR00<000000=3j
i@3@n^D00`0000020=Cjh@030000003Fm^<0e_KS00D0e_KS00<000000=Obh`3Gl^<0203Gl^<01000
0000engR0=O]hP0000050=O]hP030000003Jimh0f^ON00L0f^ON00<000000=WRg@3Ih]d0203Ih]d0
1@000000f=gK0=SMf`3HgM/0000000H0fmgH00<000000=WHe`3If=L02@3If=L01@000000em?D0000
003oool0000005d0oooo001K0?ooo`800000_@3oool00`000000b?kN0<SngP040<SngP030000003<
oN80c?gR00H0c?gR0P0000060=3ji@<000001P3Fm^<00`000000eo;S0=Obh`080=Obh`050000003G
kN80engR0=O]hP000000103GkN8010000000enOQ0000000000060=[WgP030000003Ih]d0fN;M00P0
fN;M00<000000=SMf`3HgM/00P3HgM/00`000000fmgH0=_Mf0030=_Mf0030000003If=L0fMSG00T0
fMSG00H000000=OCe03Gdm@000000?ooo`00001M0?ooo`00F03oool300000;h0oooo00<000000<Sn
gP38o]h01038o]h00`000000c?gR0<cmhP060<cmhP030000003@n^D0d?[U00H0d?[U00<000000=;f
iP3Bm^H00`0000020=Kfh`030000003Gl^<0eo;S00L0eo;S0P0000040=O]hP050000003GkN80engR
0=O]hP000000103Gin400`000000f^ON0=[WgP020=[WgP030000003Ih]d0fN;M00P0fN;M00<00000
0=SMf`3HgM/0103HgM/01@000000fmgH0=_Mf03KgMP0000000/0fMSG00<000000=OCe03Gdm@00P3G
dm@3000005`0oooo000S0?ooo`030?ooS`0e0000000000@0000000<0=Hoo0?ooo`3oool0:03oool3
00000<00oooo00<000000<SngP38o]h01038o]h00`000000c?gR0<cmhP060<cmhP030000003@n^D0
d?[U00D0d?[U0P0000060=;fiP8000002@3Gl^<00`000000engR0=O]hP040=O]hP040000003GkN80
0000000000H0enOQ0P0000000`3Jimh000000=WRg@090=WRg@030000003HgM/0f=gK00H0f=gK00<0
00000=_Mf00000002`3If=L00`000000em?D0=OCe0040=OCe0030000003oool0000000/0oooo00D0
okmd000000000000000007Boo`1;0?ooo`00903oool00`2?=@00000e08ooo`020?ooo`030<AO=@1O
a?l0oooo02L0oooo0`0000300?ooo`8000001P38o]h00`000000c?gR0<cmhP050<cmhP8000001`3@
n^D00`000000d_KV0=;fiP060=;fiP040000003Cl^H00000000000H0eo;S00<000000=O]hP3GkN80
1@3GkN82000000X0enOQ00<000000=WRg@3Ih]d01`3Ih]d2000000X0f=gK00<000000=WHe`3If=L0
2@3If=L00`000000em?D0=OCe0060=OCe08000002`3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;oo
odX0oooo000U0?ooo`030?n?=@0001@0GlCo02T0oooo0P0000030?ooo`030000003oool0oooo0;`0
oooo00<000000<SngP38o]h01038o]h2000000L0c?gR00<000000=3ji@3@n^D01P3@n^D00`000000
d_KV0=;fiP060=;fiP030000003Cl^H0do;V0080do;V00<000000=Obh`3Gl^<00P3Gl^<00`000000
engR0=O]hP060=O]hP030000003Gin40enOQ00P0enOQ00<000000=KRg`0000001`3Ih]d00`000000
f=gK0=SMf`090=SMf`030000003Ff=T0000000P0fMSG0P0000090=OCe0030000003oool0000000T0
oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`190?ooo`009P3oool00`3oa5l05000
01AOa00U0?ooo`<00000``3oool00`000000b?kN0<SngP040<SngP030000003<oN80c?gR00H0c?gR
00<000000=3ji@3@n^D01@3@n^D2000000L0d_KV0P0000060=?biP80000000<0eo;S0000003GkN80
1`3GkN800`000000enOQ000000080=OWh@050000003Fh]l0e^;O0=KRg`0000001@3Ih]d00`000000
f=gK0=SMf`090=SMf`050000003Ff=T0e]SI0=KHf@0000001P3If=L00`000000em?D0=OCe00:0=OC
e0030000003oool0000000P0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`190?oo
o`006`3oool00`2LB00000000000000300000003000DG`3oool0oooo00@0oooo00<0Ga@001AOa03o
ool0803oool300000<D0oooo0`0000040<SngP030000003<oN80c?gR00D0c?gR0P0000070=3ji@03
0000003Bm^H0d_KV00H0d_KV00<000000=?biP3Cl^H0203Cl^H00`000000engR0=O]hP060=O]hP04
0000003Gin40enOQ000000L0enOQ00<000000=KRg`3Fh]l00`3Fh]l01@000000fN;M0=WRg@3Ih]d0
000000/0f=gK00<000000=KHf@3Ff=T00P3Ff=T00`000000fMSG0=WHe`030=WHe`030000003Gdm@0
em?D00X0em?D00@000000=G>dP0000000000203oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000
M;l0oooo04T0oooo000Y0?ooo`0305lD=@2?ool0oooo01d0oooo0P0000370?ooo`0400000031oN40
`OgQ0<7mh@L00000103<oN800`000000d?[U0=3ji@060=3ji@030000003Bm^H0d_KV00H0d_KV00<0
00000=?biP3Cl^H0203Cl^H010000000dngU0000000000040=O]hP8000000`3Gin400`000000enOQ
0=OWh@040=OWh@030000003Fh]l0e^;O00D0e^;O00<000000=WRg@0000002`3HgM/00`000000e]SI
0=KHf@040=KHf@050000003If=L0fMSG0=WHe`000000303Gdm@01P000000eLkB0=G>dP000000oooo
000000L0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`190?ooo`00903oool00`34
Ga@0=Hoo0?ooo`020?ooo`0308le000eSol0oooo01X0oooo100000360?ooo`8000001P31oN400`00
0000a_cU0<Kli@020<Kli@D000001P3@n^D2000000P0d_KV00<000000=?biP3Cl^H01`3Cl^H20000
00@0dngU0P0000000`3GkN8000000=OWh@040=OWh@030000003Gin40enOQ00<0enOQ00<000000=KR
g`3Fh]l01`3Fh]l00`000000f=gK0=SMf`090=SMf`030000003Ff=T0e]SI00H0e]SI00<000000=WH
e`000000303Gdm@00`000000eLkB0=G>dP020=G>dP030000003oool0000000H0oooo00<0okmd04RL
g`3oool00P3oool00`3OW4P0B9cO0?ooo`190?ooo`00903oool01`3oScD0000e08ooo`3oool0ohle
0000501Oa?l06@3oool2000000@0oooo00<000000?ooo`3oool0`P3oool00`000000`OgQ0<7mh@04
0<7mh@8000001`36o>D00`000000b_[X0<[jj00300000080d?[U00<000000=;fiP3Bm^H01`3Bm^H0
0`000000do;V0=?biP070=?biP030000003CkND0dngU00H0dngU00<000000=OWh@3Gin40103Gin40
10000000enOQ0=OWh@3Gin42000000T0e^;O00<000000=GMgP0000002@3HgM/00`000000e]SI0=KH
f@080=KHf@030000003Gdm@0em?D00X0em?D00<000000=G>dP3Ec]80103Ec]82000000L0oooo00H0
W4P007Boo`3oool0omnL04P0M02ooom:0?ooo`009@3oool01@3oScD000000000000001@0GlCo01L0
oooo0`00003:0?ooo`0300000031oN40`OgQ00@0`OgQ00<000000<Kli@36o>D01@36o>D2000000H0
b_[X0P0000080=;fiP8000002@3Cl^H00`000000dngU0=?]i@060=?]i@030000003Cin@0000000D0
enOQ00@000000=OWh@3Gin4000002P3Fh]l01@000000eMgN0=GMgP3EgMh0000000L0f=gK00<00000
0=KHf@3Ff=T0203Ff=T00`000000e=;G0000000:0=OCe0030000003Ec]80eLkB00H0eLkB0P000006
0?ooo`050?oo_`1d000000000000B02Lgol0B`3oool003l0oooo0P00003;0?ooo`8000001P31oN40
0`000000a_cU0<Kli@050<Kli@030000003:n^P0b_[X00H0b_[X00@000000<gfj@00000000001@3B
m^H00`000000do;V0=?biP070=?biP800000203CkND01@000000dnOT0=?Wi03Cin@0000000@0enOQ
00<000000=OWh@0000002P3Fh]l00`000000eMgN0=GMgP030=GMgP030000003HgM/0f=gK00<0f=gK
00<000000=KHf@3Ff=T0203Ff=T010000000e=;G0=CBe`0000080=OCe08000002@3Ec]800`000000
oooo0000001E0?ooo`00?03oool300000<`0oooo00<000000<7mh@31oN401031oN42000000L0a_cU
00<000000<[jj03:n^P01P3:n^P00`000000cOKY0<gfj@020<gfj@8000000P3Bm^H00`000000do;V
0=?biP070=?biP030000003CkND0dngU00H0dngU0P0000050=?Wi08000000P3Gin42000000X0e^;O
00<000000=GMgP3EgMh01@3EgMh01@000000f=gK0=SMf`3HgM/0000000X0e]SI00<000000=CBe`3D
d]L00P3Dd]L00`000000em?D0=OCe0040=OCe0030000003Ec]80eLkB00X0eLkB0P00001E0?ooo`00
>@3oool3000000030?ooo`000000oooo0</0oooo00<000000<7mh@31oN401031oN400`000000a_cU
0<Kli@050<Kli@8000001`3:n^P2000000L0cOKY0P0000090=?biP030000003CkND0dngU00H0dngU
00<000000=?Wi03Cin@01`3Cin@3000000X0e^;O00<000000=GMgP3EgMh01`3EgMh00`000000f=gK
0000000:0=KHf@030000003Dd]L0e=;G00@0e=;G00<000000=OCe03Gdm@00P3Gdm@00`000000eLkB
0=G>dP0:0=G>dP040000003CbM000000000005@0oooo000g0?ooo`800000c`3oool2000000H0`OgQ
00<000000<Kli@36o>D01@36o>D00`000000b_[X0<[jj0060<[jj0030000003=m^T0cOKY00L0cOKY
00@000000<obj@00000000001@3Cl^H2000000P0dngU00<000000=?Wi03Cin@01P3Cin@400000003
0=KRg`000000e^;O00L0e^;O00<000000=GMgP3EgMh02@3EgMh00`000000e]SI0=KHf@080=KHf@03
0000003Dd]L0e=;G00H0e=;G00@000000=OCe03Gdm@00000303Ec]801P000000dlW@0=?9d0000000
oooo000005<0oooo000d0?ooo`<00000d03oool00`000000`OgQ0<7mh@040<7mh@8000001`36o>D0
0`000000b_[X0<[jj0060<[jj0030000003=m^T0cOKY00H0cOKY0P0000040<obj@8000000P3Cl^H0
0`000000dngU0=?]i@070=?]i@030000003Cin@0dnOT00@0dnOT0`0000020=?Wi0040000003Ch^<0
0000000000L0e^;O00<000000=GMgP3EgMh02@3EgMh00`000000dmOK000000080=KHf@030000003D
d]L0e=;G00L0e=;G00<000000=OCe0000000303Ec]800`000000dlW@0=?9d0020=?9d0800000D`3o
ool00380oooo0P00003B0?ooo`<000001031oN400`000000a_cU0<Kli@050<Kli@800000203:n^P0
0`000000cOKY0<gfj@060<gfj@030000003?l^T0co;Y00H0co;Y0P0000090=?]i@030000003Cin@0
dnOT0080dnOT0`0000040=?Wi0040000003Ch^<0dn;S0=?Rh`8000001@3Fh]l00`000000eMgN0=GM
gP090=GMgP050000003Cem/0dmOK0=?Gf`0000001P3Ff=T00`000000e=;G0=CBe`090=CBe`030000
003Ec]80eLkB00X0eLkB00<000000=?9d03CbM000`3CbM000`000000oooo0000001B0?ooo`00<03o
ool200000=80oooo0P0000030;[lh`L000001036o>D00`000000b_[X0<[jj0070<[jj0030000003=
m^T0cOKY00H0cOKY00<000000<obj@3?l^T01`3?l^T010000000cngY0000000000050=?]i@800000
0`3Cin@2000000D0dnOT0P0000050=?Rh`8000000`3Fh]l00`000000eMgN0=GMgP080=GMgP800000
103Cem/00`000000e]SI0=KHf@030=KHf@030000003Dd]L0e=;G00T0e=;G00<000000=;=e@000000
2P3Ec]800`000000dlW@0=?9d0050=?9d0030000003oool000000540oooo000`0?ooo`<00000d03o
ool00`000000^_cS0;[lh`040;[lh`800000102onnL5000000L0b_[X0P0000070<gfj@800000203?
l^T2000000@0cngY0P0000020=?]i@030000003Cin@0dnOT00<000001P3Cin@00`000000dn;S0=?R
h`070=?Rh`030000003Fh]l0000000X0eMgN00<000000=?Gf`3Cem/01@3Cem/01@000000e]SI0=KH
f@3Ff=T0000000/0e=;G00D000000=;=e@3BcMD0d/gE000000080=G>dP030000003CbM00dlW@00L0
dlW@0P00001A0?ooo`00;`3oool2000000030?ooo`000000oooo0<h0oooo00<000000;[lh`2jo><0
102jo><00`000000_o_W0;oki`050;oki`8000000P34nN/400000080b_[X00<000000<gfj@3=m^T0
1P3=m^T00`000000co;Y0<obj@070<obj@030000003?kNT0cngY00H0cngY1@0000080=?Wi0030000
003Ch^<0dn;S00P0dn;S0P00000:0=GMgP030000003Cem/0dmOK00L0dmOK00<000000=KHf@000000
2`3Dd]L00`000000d/gE0=;=e@030=;=e@030000003Ec]80eLkB00@0eLkB00<000000=?9d03CbM00
203CbM0300000500oooo000`0?ooo`040000003oool0oooo00000<`0oooo0P0000050;[lh`800000
1`2onnL00`000000a?W[0<Cij`060<Cij`<000001`3=m^T00`000000co;Y0<obj@070<obj@030000
003?kNT0cngY00H0cngY100000090=?Wi0030000003Ch^<0dn;S00T0dn;S0`0000080=GMgP030000
003Cem/0dmOK00T0dmOK00<000000=CBe`3Dd]L02@3Dd]L00`000000d/gE0=;=e@040=;=e@030000
003Ec]80eLkB00<0eLkB00<000000=?9d03CbM002P3CbM000`000000oooo0000001?0?ooo`00903o
ool01@3ogi`0B000000000000000M;oo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`380?ooo`030000002jo><0^_cS00@0^_cS00<000000;oki`2onnL01@2onnL2000000P0a?W[
0P0000020<Ofk0<000000P3=m^T2000000P0co;Y0P0000060<o]j@@000000`3?inL00`000000dnOT
0=?Wi0050=?Wi0030000003Ch^<0dn;S00P0dn;S0P0000020=7Lh@8000001P3EgMh00`000000dmOK
0=?Gf`090=?Gf`030000003Ad]T0000000T0e=;G00<000000=;=e@3BcMD01P3BcMD01@000000eLkB
0=G>dP3Ec]80000000`0dlW@00@000000=75cP0000000000C`3oool002H0oooo00<0_g@007Boo`3o
ool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0<D0oooo0P0000060;[lh`03
0000002onnL0_o_W00D0_o_W00<000000<Cij`34nN/01`34nN/00`000000aoK/0<Ofk0050<Ofk080
00002@3?l^T00`000000cngY0<o]j@030<o]j@<0000000<0cngY0000000000001@3?inL2000000<0
dnOT0P00000:0=?Rh`030000003Ag>40dMcQ00<0dMcQ0P0000030=GMgP8000002`3Cem/010000000
dM;I0=7Bf@0000080=CBe`030000003BcMD0d/gE00P0d/gE00<000000=G>dP000000303CbM001P00
0000dLG>0=75cP000000oooo000004h0oooo000V0?ooo`030;md001d_ol0oooo00H0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`330?ooo`030000002jo><0^_cS00@0^_cS0P000007
0;oki`0300000034nN/0a?W[00H0a?W[0P0000080<Ofk00400000039l^d00000000000H0co;Y00@0
00000<o]j@3?kNT0cngY0`0000030<o]j@030000003?inL0cnOW00L0cnOW00<000000=?Wi0000000
2`3Ch^<00`000000dMcQ0=7Lh@040=7Lh@050000003Ag>4000000=GMgP0000002`3Cem/2000000@0
dM;I00<000000=CBe`3Dd]L0103Dd]L00`000000d/gE0=;=e@0:0=;=e@030000003CbM00dlW@00X0
dlW@00<000000=75cP3AaLh00P3AaLh00`000000oooo0000001=0?ooo`008P3oool00`3OW4P00000
000000030000000307Boo`3oool0oooo00@0oooo0P0000060?ooo`800000`P3oool00`000000^_cS
0;[lh`040;[lh`030000002onnL0_o_W00D0_o_W0P0000080<Cij`0300000037m^`0aoK/00H0aoK/
0P0000040<Wbk@8000000P3?l^T2000000040<o]j@0000000000000000D0cngY00<000000<oWi`3?
inL02@3?inL00`000000dn;S0=?Rh`080=?Rh`800000203Ag>400`000000dMcQ0000000;0=?Gf`03
0000003Ad]T0dM;I00D0dM;I00<000000=CBe`3Dd]L00P3Dd]L00`000000d/gE0=;=e@0:0=;=e@03
0000003@bM80000000X0dlW@00<000000=75cP3AaLh00`3AaLh00`000000oooo0000001=0?ooo`00
6@3oool00`2LB000000000000003000000090018W03oool0oooo0?noM00007@0_ooo0?ooo`2oM000
M;oo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2m0?ooo`8000001@2jo><2
000000L0_o_W00<000000<Cij`34nN/01`34nN/00`000000aoK/0<Ofk0060<Ofk00300000039l^d0
bO;]00H0bO;]0P0000000`3?kNT00000000000070<o]j@030000003?inL0cnOW00T0cnOW00@00000
0<oRi@00000000001`3Ch^<00`000000dMcQ0=7Lh@090=7Lh@030000003@emh0000000T0dmOK00<0
00000=7Bf@3Ad]T01`3Ad]T010000000e=;G0=CBe`00000<0=;=e@040000003@bM80d<WB000000T0
dlW@00<000000=75cP3AaLh01@3AaLh00`000000oooo0000001<0?ooo`008`3oool01@3OW4P007Bo
0?ooo`2oM000M;oo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2k0?ooo`/0
0000102onnL2000000P0a?W[0P0000080<Ofk00300000039l^d0bO;]00L0bO;]100000070<o]j@03
0000003?inL0cnOW00P0cnOW0P0000040<oRi@030000003Ch^<0dn;S00<0dn;S00<000000=7Lh@3A
g>402@3Ag>4200000080d=ON00<000000=?Gf`3Cem/01@3Cem/00`000000dM;I0=7Bf@080=7Bf@03
0000003Dd]L0000000`0d/gE00<000000=39dP3@bM800P3@bM800`000000dlW@0=?9d0050=?9d003
0000003AaLh0dLG>00L0dLG>0P00001<0?ooo`00903oool0102LB000B9cO0;md001d_ol60?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0^03oool2000000D0/O[U0P0000040;SjjPD0
00002034nN/00`000000aoK/0<Ofk0060<Ofk08000001`39l^d3000000@0bng/00<000000<o]j@3?
kNT00P3?kNT2000000X0cnOW00<000000<oRi@3?h^D01@3?h^D2000000030=?Rh`000000000000X0
dMcQ0P0000020=3GgP030000003@emh0000000H0dmOK00<000000=7Bf@3Ad]T02P3Ad]T00`000000
d/gE0=;=e@0:0=;=e@030000003@bM80d<WB00<0d<WB00<000000=?9d03CbM00103CbM000`000000
dLG>0=75cP080=75cP030000003oool0000004/0oooo000T0?ooo`040?oOW01804P0B4P007Boo`H0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2e0?ooo`8000001P2an^D00`000000
^?[Z0;SjjP050;SjjP8000000P2mn>d400000080a?W[0P0000080<Ofk00300000039l^d0bO;]00@0
bO;]100000070<_]k080000000<0cngY0000003?inL02P3?inL00`000000cn;U0<oRi@080<oRi@03
0000003Ag>40dMcQ00T0dMcQ00<000000=3GgP3@emh00`3@emh00`000000d=ON000000030=?Gf`80
0000303Ad]T00`000000d<gG0000000:0=;=e@030000003@bM80d<WB00D0d<WB00<000000=?9d03C
bM000P3CbM000`000000dLG>0=75cP0:0=75cP030000003oool0000004X0oooo000U0?ooo`030?no
M0000000M;oo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2c0?ooo`030000
002an^D0/O[U00@0/O[U0P0000070;SjjP030000002mn>d0_OS]00H0_OS]0`0000080<Ofk0030000
0039l^d0bO;]0080bO;]0`0000020<Wbk@030000003;kN`0bng/00P0bng/00<000000<oWi`3?inL0
203?inL2000000X0cn;U00<000000<kLh`0000002@3Ag>400`000000d=ON0=3GgP050=3GgP050000
003@emh000000=?Gf`0000003@3Ad]T010000000d<gG0=3=e`0000080=;=e@8000002@3@bM801000
0000dlW@0=?9d000000<0=75cP80000000<0oooo0000003oool0B@3oool002h0oooo0P00000>0?oo
o`030000003oool0oooo0;00oooo0P0000060;7ji@030000002hn^X0^?[Z00D0^?[Z0P0000080;gh
k@8000000P31mNl400000080aoK/0P0000020<Wbk@<000000`39l^d2000000T0bng/0P0000000`3;
in/00000000000070<oWi`030000003?h^D0cn;U00P0cn;U0P0000030<kLh`030000003Ag>40dMcQ
00D0dMcQ00<000000=3GgP3@emh01P3@emh010000000d=ON0=3GgP00000=0=7Bf@030000003@cML0
d<gG0080d<gG00<000000=;=e@3BcMD0103BcMD00`000000d<WB0=39dP090=39dP030000003CbM00
000000`0dLG>00H000000<o0c03?`<`000000?ooo`0000190?ooo`00;P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0:h0oooo00<000000;7ji@2an^D0102an^D2000000L0^?[Z00<0
00000;ghk@2mn>d01`2mn>d00`000000`OG_0<7ek`060<7ek`80000000@0bO;]0000000000000000
1@39l^d00`000000bng/0<_]k0080<_]k0030000003;in/0bnO[00<0bnO[00<000000<oWi`3?inL0
0`3?inL00`000000cn;U0<oRi@080<oRi@030000003>g><0c]cS00<0c]cS00<000000=7Lh@3Ag>40
103Ag>400`000000d=ON0=3GgP080=3GgP80000000<0cm;L0000003Ad]T02P3Ad]T00`000000d<gG
0=3=e`040=3=e`030000003BcMD0d/gE0080d/gE00<000000=39dP3@bM802`3@bM800`000000dLG>
0=75cP0:0=75cP050000003?`<`0cl3<0<o0c00000000P3oool00`000000oooo0?ooo`160?ooo`00
;P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0:/0oooo0P0000060;7ji@030000
002hn^X0^?[Z00D0^?[Z0P0000080;ghk@8000002031mNl5000000H0bO;]00<000000<_]k03;kN`0
1`3;kN`2000000L0bnO[0P0000000`3?inL000000000000:0<oRi@030000003>g><0c]cS00D0c]cS
00@000000=7Lh@3Ag>40dMcQ0P00000;0=3GgP8000000P3?d]`00`000000dM;I0=7Bf@060=7Bf@80
0000203@cML010000000d/gE0=;=e@00000=0=39dP030000003?a=00000000X0dLG>00<000000<o0
c03?`<`00`3?`<`00`000000oooo000000180?ooo`00;@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0:P0oooo0P0000060;7ji@8000001`2hn^X00`000000_OS]0;ghk@070;ghk@03
00000031mNl0`OG_00H0`OG_0`0000040<Cal08000000P39l^d2000000T0bng/00<000000<_Wj`3;
in/02@3;in/00`000000cn;U0<oRi@080<oRi@8000002@3>g><00`000000dMcQ0000000<0=3GgP04
0000003?d]`0cm;L00000080cm;L00<000000=7Bf@3Ad]T0103Ad]T00`000000d<gG0=3=e`080=3=
e`030000003BcMD0000000d0d<WB00@000000<o4d03?a=0000002@3AaLh00`000000cl3<0<o0c004
0<o0c0040000003oool0oooo000004L0oooo000]0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0YP3oool<000000@0^?[Z0P0000080;ghk@8000001`31mNl3000000P0a?7`0P000009
0<_]k08000002P3;in/2000000030<_Rj0000000000000L0cn;U00<000000<kLh`3>g><02P3>g><0
0`000000d=ON0=3GgP0:0=3GgP050000003?d]`0cm;L0<oBg00000000P3?d]`00`000000dM;I0=7B
f@030=7Bf@030000003@cML0d<gG00X0d<gG00<000000=39dP3@bM802P3@bM82000000@0clC@00<0
00000=75cP3AaLh01@3AaLh00`000000cl3<0<o0c0060<o0c0040000003oool0oooo000004H0oooo
000]0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0X`3oool2000000H0YoSV0P00
00040:ohk0D00000202mn>d00`000000`OG_0<7ek`040<7ek`@000002@34lO02000000030<G/k`00
0000000000H0bng/00<000000<_Wj`3;in/02@3;in/00`000000bn;X0<_Rj0030<_Rj0030000003?
h^D0cn;U00<0cn;U00<000000<kLh`3>g><02P3>g><00`000000cMOQ000000090=3GgP8000001@3?
d]`010000000cm;L0<oBg00000030=7Bf@030000003@cML0d<gG00X0d<gG00<000000<k8e0000000
2P3@bM800`000000clC@0<o4d0040<o4d0030000003AaLh0dLG>00@0dLG>00<000000<o0c03?`<`0
1`3?`<`010000000oooo0?ooo`0000160?ooo`00;@3oool2000001D0oooo00<000000?ooo`3oool0
X03oool2000000H0YoSV0P0000070:ohk08000000P2emo0400000080_OS]0P0000040<7ek`<00000
00<0`OG_00000034lO002@34lO000`000000aNc_0<G/k`030<G/k`8000000P3;kN`2000000X0bnO[
0P0000070<_Rj080000000<0cn;U0000000000002`3>g><2000000<0cMOQ00<000000=3GgP3@emh0
1@3@emh00`000000cm;L0<oBg0060<oBg0060000003?d]`0cm;L0000003Ad]T00000303@cML01000
0000c/SD0<k8e00000090=39dP030000003?a=00clC@00H0clC@00<000000=75cP3AaLh00P3AaLh0
0`000000cl3<0<o0c0090<o0c0@00000A@3oool002d0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`2N0?ooo`030000002Wn>H0YoSV00D0YoSV00<000000:ohk02_n>`01@2_n>`20000
00P0]OO`0`0000020<7ek`<000000P31mNl2000000T0a?7`0P0000080<G/k`8000002`3;in/00`00
0000bn;X0<_Rj0090<_Rj0030000003>g><0c]cS00X0c]cS00<000000<gGh@3=en40103=en400`00
0000d=ON0=3GgP030=3GgP030000003?d]`0cm;L00L0cm;L00D000000<oBg03?d]`0cm;L0000000<
0=3=e`030000003>b=@0c/SD0080c/SD00<000000=39dP3@bM801@3@bM800`000000clC@0<o4d008
0<o4d0040000003AaLh0dLG>000000`0cl3<00D000000?ooo`3oool0oooo000000140?ooo`00;@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo09/0oooo0P0000060:OhiP8000001`2_
n>`00`000000]OO`0;Ggl0070;Ggl080000000<0^_Cb0000000000000P0000020<7ek`8000002P34
lO000`000000aNc_0<G/k`070<G/k`80000000<0a^O^0000000000001`3;in/2000000/0bn;X00<0
00000<[LiP0000002P3>g><00`000000cMOQ0<gGh@060<gGh@050000003@emh0d=ON0=3GgP000000
2`3?d]`01@000000cm;L0000003=c=T0000000X0d<gG00<000000<k8e03>b=@0103>b=@00`000000
d<WB0=39dP030=39dP030000003?a=00clC@00T0clC@00<000000=75cP000000303?`<`00`000000
cKc:000000020?ooo`030000003oool0oooo0480oooo000/0?ooo`030000003oool0oooo01P0oooo
0P00002J0?ooo`030000002Wn>H0YoSV00D0YoSV00<000000:ohk02_n>`01@2_n>`2000000P0]OO`
1@0000040;[dlP<000002@34lO02000000T0aNc_00<000000<KWkP36inh00`36inh00`000000bnO[
0<_Wj`030<_Wj`030000003;h^P0bn;X00T0bn;X0P0000030<[LiP030000003>g><0c]cS00D0c]cS
0P00000:0<gGh@030000003@emh0000000`0cm;L0P0000020<g<f@030000003@cML0d<gG00H0d<gG
0P0000080<k8e0030000003@bM80d<WB008000003@3?a=000`000000cl3<0<o0c00:0<o0c0040000
003=_<X0cKc:000000<0oooo00<000000?ooo`3oool0@@3oool002`0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`2E0?ooo`8000001P2Wn>H2000000L0[oS/00<000000;Ggl02emo00
1P2emo04000000H0^_Cb0P0000020;g`l`8000001P34lO000`000000aNc_0<G/k`070<G/k`800000
1`36inh2000000030<_Wj`000000000000/0bn;X00<000000<[LiP3:g>H00`3:g>H00`000000c]cS
0<kLh`040<kLh`030000003=en40cMOQ00/0cMOQ00<000000<oBg03?d]`02P3?d]`010000000cLcI
0<g<f@0000020<g<f@030000003@cML0d<gG00@0d<gG00<000000<k8e03>b=@0203>b=@00`000000
d<WB0000000>0<o4d08000002`3?`<`00`000000cKc:0<flbP020<flbP050000003oool0oooo0?oo
o`000000@P3oool002`0oooo00<000000?ooo`0000006`3oool00`000000oooo0?ooo`2B0?ooo`80
00001P2Wn>H2000000L0[oS/0P0000070;Ggl0<000001`2jm?82000000H0_O3c0P0000020<Cal080
00002@35k>l00`000000a^O^0<KWkP090<KWkP030000003;h^P0bn;X00X0bn;X00<000000<[LiP3:
g>H01@3:g>H00`000000c]cS0<kLh`020<kLh`030000003=en40cMOQ00X0cMOQ0P0000000`3;dMh0
00000<oBg0090<oBg0050000003=c=T0cLcI0<g<f@0000000`3=c=T00`000000d<gG0=3=e`020=3=
e`030000003>b=@0c/SD00X0c/SD00<000000<o4d03?a=00303?a=0010000000cL3>0<g0cP000009
0<o0c0030000003=_<X0cKc:00<0cKc:00D000000?ooo`3oool0oooo000000120?ooo`00;03oool2
000001d0oooo00<000000?ooo`3oool0T03oool<000000@0[oS/0P0000070;Ggl0<00000202jm?80
0`000000_O3c0;g`l`080;g`l`8000002@35k>l2000000X0a^O^0P0000000`36hN`000000<_Rj008
0<_Rj08000002@3:g>H010000000c]cS00000000000<0<gGh@030000003;dMh0bm7N0080bm7N00<0
00000<oBg03?d]`01@3?d]`2000000D0cLcI00D000000<g<f@3=c=T0cLcI000000020=3=e`030000
003>b=@0c/SD00X0c/SD00<000000<c3dP0000002`3?a=02000000<0cL3>00<000000<o0c03?`<`0
1@3?`<`2000000L0cKc:00D000000?ooo`3oool0oooo000000110?ooo`00;03oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo08d0oooo0P00000609cdiP800000102UmNd7000000<0]OO`
0`0000090;[dlP8000002P2ml?<2000000030;o/lP000000000000H0aNc_00<000000<KWkP36inh0
2@36inh00`000000a^7/0<KQk0020<KQk0030000003;h^P0bn;X00D0bn;X00<000000<[LiP3:g>H0
2P3:g>H00`000000cMOQ0<gGh@0:0<gGh@8000001@3;dMh00`000000cm;L0<oBg0040<oBg0030000
003=c=T0cLcI00H0cLcI00H000000<g<f@3=c=T000000=3=e`00000<0<k8e0040000003<`m80c<?B
000000X0clC@00<000000<g0cP3=`<h0103=`<h00`000000cl3<0<o0c0030<o0c0030000003=_<X0
cKc:00L0cKc:00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0n0?ooo`007P3oool00`3o
okl0M000000000040000000307Boo`3oool0oooo00@0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`2:0?ooo`8000001P2Lm>H2000000L0YOG]0P0000040:cel@D00000202jm?820000
00X0_O3c0P0000050;o/lP8000000P35k>l2000000X0a^O^0P0000060<KQk0800000103;h^P00`00
0000b]cV0<[LiP090<[LiP80000000<0bMKS0000003=en402@3=en400`000000bm7N0<_AgP060<_A
gP030000003?d]`0cm;L0080cm;L00<000000<g<f@3=c=T0203=c=T010000000cLcI0<g<f@00000<
0<k8e0030000003<`m80c<?B0080c<?B00<000000<o4d03?a=001P3?a=000`000000cL3>0<g0cP05
0<g0cP030000003?`<`0cl3<0080cl3<00<000000<flbP3=_<X02@3=_<X01@000000oooo0?ooo`3o
ool000000400oooo000O0?ooo`030;md000007@0_ooo0080oooo00<0giad09cOo`3oool01@3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo08L0oooo0P00000609cdiP8000001`2UmNd2
000000<0[?Ga0`0000000`2/mO400000000000020;7bm0@000000P2jm?82000000X0_O3c0P000009
0;o/lP8000002`36inh00`000000a^7/0<KQk0080<KQk0040000003;h^P00000000000/0b]cV00<0
00000<WFh`39e^<00P39e^<00`000000cMOQ0<gGh@050<gGh@8000002P3;dMh010000000cm;L0000
0000000;0<g<f@050000003=c=T000000<_7e`0000002P3>b=@00`000000c<?B0<c3dP030<c3dP03
0000003?a=00clC@00D0clC@00<000000<g0cP3=`<h01`3=`<h010000000cl3<0<o0c000000<0<fl
bP060000003oool0oooo0000003oool000002P3oool00`3o_g@000000000000300000003001d_`3o
ool0oooo02`0oooo000P0?ooo`030?noM00004P0W=oo00P0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`240?ooo`8000001P2Lm>H2000000L0YOG]0P0000020:cel@<000000P2/mO42
000000P0/O;d0P00000:0;g`l`8000002P2ok?82000000030<7Vl@000000000000L0a^O^0P00000<
0<KQk0030000003:g>H0b]cV00X0b]cV00<000000<WFh`39e^<01039e^<2000000@0cMOQ00<00000
0<_AgP3;dMh02`3;dMh00`000000cLcI0<g<f@0;0<g<f@8000000P3;amL00`000000c/SD0<k8e006
0<k8e08000001`3<`m800`000000clC@0<o4d0030<o4d0030000003=`<h0cL3>00P0cL3>00<00000
0<o0c00000003P3=_<X00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<0W4Q8
09cOo`3oool0;`3oool00240oooo00<0omnL04P00018W=l01`3oool2000002<0oooo00<000000?oo
o`3oool0P@3oool2000000H0W?CV0P0000070:Gek@80000000@0[?Ga0000000000000000102/mO40
0`000000/O;d0;7bm0070;7bm080000000<0]^of0000000000001P2ml?<2000000X0_ncb0P000005
0<7Vl@0300000036inh0a^O^00<0a^O^00<000000<KQk036hN`02P36hN`2000000030<KKj@000000
b]cV00P0b]cV0P0000090<WFh`040000003=en400000000000d0bm7N00<000000<[<f`0000002`3=
c=T010000000blOG0<_7e`0000020<_7e`030000003>b=@0c/SD00@0c/SD00<000000<c3dP3<`m80
203<`m800`000000clC@0<o4d002000000`0cL3>00<000000<flbP3=_<X0303=_<X00`000000bkW8
000000030?ooo`030000003oool0oooo00X0oooo00<0W4Q809cOo`3oool0;`3oool001H0oooo00<0
W4P00000000000000`0000000`00B9`0oooo0?ooo`040?ooo`0309a80018W=l0oooo00D0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`1n0?ooo`8000001P2Lm>H2000000L0YOG]1@00
00050:cel@800000202al_@2000000D0]^of0P0000020;g`l`8000002`2ok?800`000000`NKa0<7V
l@060<7Vl@80000000<0a^O^0000000000002`36hN`2000000@0a]_Y00<000000<[LiP3:g>H01@3:
g>H00`000000bMKS0<WFh`0:0<WFh`030000003;dMh0bm7N00/0bm7N0P0000020<[<f`030000003=
c=T0cLcI00P0cLcI00D000000<_7e`3;amL0blOG000000030<_7e`030000003>b=@0c/SD0080c/SD
00<000000<c3dP3<`m802@3<`m800`000000clC@0000000=0<g0cP8000003@3=_<X010000000bkW8
0<^ib00000040?ooo`030000003oool0oooo00T0oooo00<0W4Q809cOo`3oool0;`3oool002@0oooo
00<0W4Qd0;ooo`3oool0103oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo07`0oooo
300000040:Gek@@000001P2/mO42000000T0/O;d00<000000;K_mP2fkoH01`2fkoH3000000X0_ncb
0P00000;0<7Vl@0300000036hN`0a^7/00X0a^7/00<000000<KKj@36fnT01@36fnT2000000@0b]cV
00<000000<WFh`39e^<02@39e^<2000000030<S@h@000000bm7N00X0bm7N00<000000<[<f`3:c=/0
0`3:c=/00`000000cLcI0<g<f@050<g<f@8000001@3;amL01@000000blOG0<_7e`3;amL000000080
c/SD00<000000<c3dP3<`m802`3<`m800`000000cL3>0<g0cP0;0<g0cP040000003;_<`0bkc<0000
00/0cKc:00<000000<^ib03;^LP00P3;^LP00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00P0oooo00<0W4Q809cOo`3oool0;`3oool001l0oooo00<0gia807Boo`3oool00P3oool00`2oM000
M;oo0?ooo`040?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0N@3oool2000000H0
T>oU0P00000409[ak@L000001@2/mO42000000T0/O;d0P0000090;K_mP8000000P2ij_D2000000H0
_ncb0P00000;0<7Vl@80000000<0`N3_0000000000002036hN`2000000X0a]_Y00@000000<[LiP00
000000002`39e^<00`000000b=3Q0<S@h@020<S@h@030000003;dMh0bm7N00L0bm7N00<000000<[<
f`3:c=/01@3:c=/00`000000cLcI0<g<f@030<g<f@030000003;amL0blOG00H0blOG00H000000<_7
e`3;amL000000<k8e000000=0<c3dP030000003:_m00000000/0cL3>00D000000<^lc03;_<`0bkc<
0000000:0<flbP030000003;^LP0bkW800<0bkW800<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`080?ooo`0309a8B02Lgol0oooo02l0oooo000O0?ooo`070?noM00007@0_ooo0?ooo`3o_g@0
001809cOo`050?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0MP3oool2000000H0
T>oU0P00000609[ak@<00000102Rl_<6000000P0/O;d0P0000090;K_mP8000001P2ij_D200000080
_ncb0P00000;0<7Vl@8000001@31h>l00`000000a^7/0<KQk0030<KQk08000003@36fnT00`000000
bMKS0<WFh`090<WFh`8000001P38d>400`000000bm7N0<_AgP050<_AgP030000003:c=/0b/cK00L0
b/cK00D000000<g<f@3=c=T0cLcI0000000:0<_7e`040000003;amL0blOG000000d0c<?B00@00000
0<Zod03:_m0000002P3=`<h00`000000bkc<0<^lc0030<^lc0030000003=_<X0cKc:00H0cKc:00<0
00000<^ib03;^LP01@3;^LP00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<0
W4Q809cOo`3oool0;`3oool00200oooo00D0okmd000000000000001809cOo`050?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0M03oool00`000000T>oU093_i@04093_i@8000001@2J
lNd4000000L0X_;c0P0000030:S`mP@000000P2al_@2000000T0]^of0P00000:0;WZm@8000003031
i_400`000000`N3_0<7Pk`060<7Pk`80000000<0a^7/0000000000003@36fnT2000000030<GEiP00
0000bMKS00P0bMKS00<000000<S@h@38d>401P38d>400`000000bm7N0<_AgP040<_AgP030000003:
c=/0b/cK00P0b/cK00@000000<g<f@00000000002`3;amL01@000000blOG00000039`m@0000000/0
c<?B00<000000<Zod03:_m000P3:_m000`000000cL3>0<g0cP060<g0cP030000003;_<`0bkc<00@0
bkc<00<000000<flbP3=_<X01@3=_<X00`000000bkW80<^ib0060<^ib0030000003oool0oooo0080
oooo0P0000050?ooo`050=nLB000000004RL09a8B02Lgol0<03oool002X0oooo0`00000Y0?ooo`03
0000003oool0oooo0740oooo0P000005093_i@800000102JlNd5000000L0X_;c0P0000090:S`mP<0
0000202fkoH2000000/0^N[e0P0000000`2jiO@00000000000080<7Vl@8000002`31h>l00`000000
a]_Y0<KKj@0;0<KKj@8000001035eNH00`000000bMKS0<WFh`040<WFh`8000002P38d>4010000000
bm7N0<_AgP3;dMh2000000`0b/cK00<000000<_7e`3;amL02`3;amL200000080bL?D00<000000<c3
dP3<`m80203<`m800`000000b[o@0<Zod0030<Zod0030000003=`<h0cL3>00D0cL3>00<000000<^l
c03;_<`01P3;_<`00`000000cKc:0<flbP030<flbP030000003;^LP0bkW800P0bkW800H000000?oo
o`00000000000?ooo`0000070?ooo`030=nLB00004P0W=oo0300oooo000Z0?ooo`030000003oool0
oooo02X0oooo0P00001_0?ooo`8000001@2@knD2000000<0V_7]0`0000000`2JlNd0000000000007
0:;bl`8000002@2Xl?H2000000<0[Ngh0`0000030;K_mP8000002`2ij_D2000000D0^^Gd00<00000
0<7Vl@31i_400`31i_42000000/0`N3_0P0000000`31f^`000000<KKj@0:0<KKj@0300000035eNH0
aMGV00D0aMGV00<000000<WFh`39e^<00P39e^<00`000000b=3Q0<S@h@0;0<S@h@030000003;dMh0
000000`0b/cK0P0000000`38amT000000<_7e`0:0<_7e`0400000039`m@0bL?D00000080bL?D00<0
00000<c3dP3<`m801@3<`m82000000L0b[o@00<000000<g0cP3=`<h00`3=`<h00`000000bkc<0<^l
c0070<^lc0030000003=_<X0cKc:0080cKc:00<000000<^ib03;^LP02@3;^LP00`000000oooo0?oo
o`030?ooo`030000003oool0oooo03L0oooo000Z0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool0JP3oool200000080T>oU2P00000209[ak@8000001`2Rl_<2000000T0Z?3f0P000008
0:g]n0<000002`2ij_D2000000P0^^Gd0P0000000`31i_4000000000000;0<7Pk`8000001031f^`0
0`000000a]_Y0<KKj@060<KKj@8000002@35eNH010000000bMKS00000000000?0<S@h@030000003:
c=/0b/cK00X0b/cK00<000000<S7f@38amT00P38amT00`000000blOG0<_7e`070<_7e`0300000039
`m@0bL?D0080bL?D00<000000<W3e00000001P3<`m800`000000b[o@0<Zod0070<Zod0030000003=
`<h0cL3>0080cL3>00<000000<^lc03;_<`02@3;_<`010000000cKc:0<flbP00000=0<^ib0030000
003oool0oooo0080oooo00<000000?ooo`3oool0=`3oool002X0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`1W0?ooo`P000000P2=k>d:000000D0X_;c0P0000090:S`mP8000002@2]
kOP200000080/NWh0P0000070;WZm@800000302jiO@00`000000`N3_0<7Pk`0:0<7Pk`0300000031
f^`0`M[/00D0`M[/0P0000040<KKj@8000003035eNH00`000000b=3Q0<S@h@0=0<S@h@80000000<0
a/_N0000003:c=/02@3:c=/00`000000b<OI0<S7f@040<S7f@030000003;amL0blOG00D0blOG00<0
00000<W3e039`m@00`39`m@010000000bL?D0<W3e00000040<c3dP030000003:_m00b[o@00T0b[o@
00@000000<g0cP3=`<h00000303;_<`00`000000cKc:0000000=0<^ib08000001@3oool00`000000
oooo0?ooo`0f0?ooo`00:P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo06@0oooo
0P00000408;Yi08000000P2=k>d2000000<0SNc]0P00000509K^l`D000002@2Xl?H2000000T0[Ngh
0P0000060;7Yn08000000`2ij_D2000000`0^^Gd0P0000000`2kgo800000000000080<7Pk`800000
2P31f^`010000000a]_Y00000000000<0<GEiP80000000<0a=3S00000038d>403038d>400`000000
a/_N0<K;gP020<K;gP030000003:c=/0b/cK00D0b/cK0P0000070<S7f@030000003;amL0blOG00@0
blOG00<000000<W3e039`m@01@39`m@010000000bL?D0<W3e00000020<c3dP030000003:_m00b[o@
00X0b[o@00<000000<g0cP0000003P3;_<`00`000000bkW80<^ib00;0<^ib00400000039]LH0bKG6
000000D0oooo00<000000?ooo`3oool0=@3oool002T0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`1P0?ooo`<000001022jN@20000000408g/k@0000000000000000<0SNc]0P000007
09K^l`8000000`2MkOP4000000<0Z?3f0P0000090:g]n08000002P2ajOP3000000`0^^Gd0P000005
0;_OlP0300000031h>l0`N3_00<0`N3_0P00000=0<7Jk00300000035eNH0aMGV00/0aMGV00<00000
0<C@h`34d><00P34d><00`000000b=3Q0<S@h@080<S@h@8000001@36bmh00`000000b/cK0<[<f`04
0<[<f`0300000038amT0b<OI00P0b<OI00@000000<_7e`3;amL0blOG0P0000090<W3e00500000039
`m@000000<c3dP0000003P3:_m000`000000bkc<0<^lc00<0<^lc00300000039^<X0000000/0bkW8
00D000000<VeaP39]LH0bKG6000000050?ooo`030000003oool0oooo03D0oooo000Y0?ooo`<00000
<@3oool00`000000oooo0?ooo`1L0?ooo`<000001@22jN@5000000<0SNc]0`00000709K^l`800000
2@2MkOP3000000T0[Ngh0P00000;0;7Yn080000000<0/nCg0000000000002@2jiO@2000000P0^mob
0P0000000`31h>l000000000000=0<7Jk080000000<0`MCY00000035eNH02P35eNH00`000000a=3S
0<C@h`040<C@h`0300000038d>40b=3Q00H0b=3Q00<000000<K;gP36bmh01P36bmh00`000000b/cK
0<[<f`020<[<f`0300000038amT0b<OI00X0b<OI00<000000<_7e`0000003039`m@00`000000bL?D
0000000>0<Zod00300000038^ld0000000`0bkc<00@000000<VhbP39^<X000002P3;^LP00`000000
bKG60<VeaP030<VeaP030000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool002T0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`1I0?ooo`8000001P22jN@4000000@0SNc]
0P00000709K^l`<000002@2MkOP2000000<0Y>_j100000030:g]n08000002`2ajOP2000000D0/nCg
00<000000;[Um02jiO@0102jiO@2000000`0^mob00<000000<7Jk031f^`02`31f^`2000000@0`MCY
00<000000<GEiP35eNH01P35eNH2000000L0a=3S00<000000<S@h@38d>401038d>42000000X0a/_N
00@000000<[<f`00000000003P38amT00`000000bL?D0<W3e00;0<W3e080000000<0akkA0000003:
_m002P3:_m0200000080b;_=00<000000<^lc03;_<`02@3;_<`00`000000bKS:0<VhbP020<VhbP03
0000003;^LP0bkW800H0bkW800<000000<VeaP39]LH01039]LH00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo03<0oooo000Y0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
E@3ooolE000000D0U^kc0P00000:09g]n08000002@2TjoX3000000/0/NWh0P0000080;?Tm`800000
0P2jiO@2000000`0^mob0P0000000`2lfNl000000<7Jk00:0<7Jk00300000031e>T0`MCY00D0`MCY
00<000000<GEiP35eNH01035eNH00`000000a=3S0<C@h`080<C@h`0300000038d>40b=3Q0080b=3Q
00<000000<K;gP36bmh02`36bmh00`000000b<OI0<S7f@0=0<S7f@0300000036`]H0000000/0bL?D
0`0000000`37_]4000000<Zod0090<Zod00300000038^ld0b;_=00<0b;_=00<000000<^lc03;_<`0
1`3;_<`00`000000bKS:0<VhbP030<VhbP030000003;^LP0bkW800D0bkW800<000000<VeaP39]LH0
1P39]LH010000000oooo0?ooo`3oool3000003D0oooo000Y0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0DP3oool2000000D0Ln7Q1000000507kVj`8000001@29j?<5000000T0WNgh
0`0000090:C[nP8000000`2XioX2000000L0/NWh0P00000<0;?Tm`8000003@2kgo800`000000_=W_
0;cIk`020;cIk`0300000031f^`0`M[/00H0`M[/0P0000090<7Dj@0300000035eNH0aMGV0080aMGV
00<000000<C@h`34d><02P34d><010000000b=3Q00000000000<0<K;gP80000000<0aLKK00000038
amT02`38amT200000080a/;F00<000000<W3e039`m@02039`m@01`000000akkA0<Nnd@37_]400000
0<Nnd@000000203:_m000`000000b;_=0<Rkc@040<Rkc@030000003;_<`0bkc<00D0bkc<0P000007
0<VhbP030000003;^LP0bkW800<0bkW800<000000<VeaP39]LH01`39]LH00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0380oooo000Y0?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool0C`3oool2000000@0Ln7Q1000000607kVj`8000001`29j?<2000000<0TNWh1000000309g]
n08000002P2TjoX2000000L0Z>Oj0P0000030;7Yn0800000302ci?L2000000030;GNm00000000000
00X0^mob0P0000060;cIk`8000001031f^`2000000`0`MCY00@000000<GEiP00000000003P34d><0
0`000000a/_N0<K;gP0;0<K;gP0500000035a]/0aLKK0<G6f`0000002`38amT00`000000a/;F0<K2
eP030<K2eP0300000039`m@0bL?D00H0bL?D00<000000<Nnd@37_]400P37_]400`000000akkA0000
00070<Zod00300000038^ld0b;_=00H0b;_=00<000000<^lc03;_<`00`3;_<`00`000000bKS:0<Vh
bP070<VhbP030000003;^LP0bkW80080bkW800<000000<VeaP39]LH02@39]LH00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0340oooo000X0?ooo`040000003oool00000000003H0oooo00<0
00000?ooo`3oool0B`3oool3000000<0Ln7Q1000000607kVj`<000001`29j?<2000000T0TNWh0`00
000:0:C[nP8000002`2XioX3000000`0/nCg0P0000050;GNm0030000002kgo80^mob00D0^mob0P00
000:0;cIk`0400000031f^`00000000000l0`MCY00<000000<C@h`34d><03034d><2000000030<?:
h0000000a/_N00X0a/_N00<000000<G6f`35a]/00`35a]/00`000000b<OI0<S7f@070<S7f@030000
0036`]H0a/;F00@0a/;F00<000000<W3e039`m@01@39`m@00`000000akkA0<Nnd@040<Nnd@030000
0037_]40000000D0b[o@00<000000<Rkc@38^ld01`38^ld00`000000bkc<0<^lc0020<^lc0030000
0039^<X0bKS:00T0bKS:00@000000<^ib03;^LP000003039]LH00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0340oooo000X0?oooaL00000903oool00`000000oooo0?ooo`180?ooo`800000
00<0Ln7Q0000000000001@00000607kVj`8000001`29j?<3000000P0TNWh0`00000309WWn`@00000
102TjoX2000000/0Z>Oj0P0000020:cRn@8000002@2ci?L2000000P0]Mkd00<000000;_OlP2kgo80
0`2kgo800`000000_=W_0;cIk`0;0;cIk`0300000031e>T0`MCY00d0`MCY0P0000000`2ocnH00000
0<C@h`0;0<C@h`0300000033b^00`l[P0080`l[P00<000000<K;gP36bmh01P36bmh2000000H0aLKK
00<000000<S7f@38amT01@38amT2000000P0a/;F00<000000<W3e039`m@00`39`m@00`000000akkA
0<Nnd@060<Nnd@0300000037_]4000000080b[o@0P00000;0<Rkc@040000003;_<`0bkc<000000`0
bKS:00<000000<^ib00000003P39]LH00`000000oooo0?ooo`040?ooo`030000003oool0oooo0300
oooo000X0?ooo`040000003oool00000000000L0L@000`00000606`00080000000<0I@0000000000
00001P00000M0?ooo`030000003oool0oooo04@0oooo2P00000306kNj0P000001@29j?<2000000T0
TNWh0P00000:09WWn`@000002`2XioX2000000H0[>;i0P0000050;?Tm`8000002`2eg_@200000003
0;_OlP000000000000`0_=W_0P0000000`2ldn`000000<7Dj@0;0<7Dj@800000102ocnH00`000000
a=3S0<C@h`070<C@h`8000001P33b^000`000000a/_N0<K;gP040<K;gP0300000035a]/0aLKK00L0
aLKK00<000000<S7f@38amT00`38amT00`000000a/;F0<K2eP090<K2eP0300000039`m@0bL?D0080
00002P37_]42000000030<Zod0000000b;_=00`0b;_=00<000000<^lc00000003P39^<X00`000000
bKG60<VeaP0=0<VeaP030000003oool0oooo00D0oooo00<000000?ooo`3oool0;`3oool001`0oooo
00D0okmd000000000000000007Boo`070?ooo`040000003oool0oooo0?ooo`<000001`1a00040000
00@0K0000`00000406D000P00000603oool00`000000oooo0?ooo`100?ooo`<000000P1Rf=`50000
00D0K]kX1000000507[Rl@L000001P2AjOP3000000/0VNOk0P00000209kTo08000001`2XioX30000
00X0[>;i0P0000000`2ci?L000000000000>0;GNm0800000302lfNl2000000@0_=?/00<000000<7D
j@31e>T02031e>T00`000000_loV0;o?iP050;o?iP0300000034d><0a=3S00@0a=3S0P0000090<?:
h00300000036bmh0a/_N0080a/_N00<000000<G6f`35a]/02@35a]/01@000000b<OI0<S7f@38amT0
000000`0a/;F00<000000<W3e00000003037_]400`000000akkA0000000?0<Rkc@0300000039^<X0
bKS:00`0bKS:0P00000>0<VeaP8000001`3oool00`000000oooo0?ooo`0_0?ooo`00703oool01P2L
B7@0_ooo0?ooo`3ookl0M01d0;ooo`H0oooo00<000000?ooo`3oool0103oool2000000H0L@002@00
00000`1/000000000000000406D000800000101L0002000001L0oooo0P00000l0?ooo`@000000P1R
f=`5000000@0K]kX1000000707[Rl@@000001@24hoP6000000`0VNOk0P00000609kTo08000000`2X
ioX2000000h0[>;i0P00000>0;GNm08000000P2ff?82000000P0_=W_0P0000070;cCk00300000031
e>T0`MCY00D0`MCY0P0000090;o?iP0300000034d><0a=3S0080a=3S00<000000<?:h033b^002P33
b^0010000000a/_N00000000000<0<G6f`0400000038amT00000000000h0a/;F00<000000<Nnd@37
_]403037_]400`000000aK[?0000000=0<Rkc@0300000036]l/0000000`0bKS:00@000000<Ndb037
]<P000003039]LH010000000ak750<Naa@0000070?ooo`030000003oool0oooo02h0oooo000K0?oo
o`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool01@3oool00`000000oooo0?ooo`060?oo
o`H000001P1S000;0000000306D000000000000000@0G0000`00000F0?ooo`030000003oool0oooo
03H0oooo4`00000607[Rl@@000002@24hoP3000000<0S>?l0P00000709WWn`<000002P2Ni?`30000
00h0[>;i0P0000020:kLm`8000002P2eg_@2000000H0]]Sb00<000000;cIk`2lfNl00`2lfNl20000
00X0_=?/00<000000<7Dj@31e>T00P31e>T2000000`0_loV00@000000<C@h`00000000003P33b^00
0`000000aLKK0<G6f`0=0<G6f`0300000036`]H0a/;F00d0a/;F00<000000<Bmd`0000002`37_]42
000000030<Fjc`000000000000/0b;_=0P0000020<Jgb`0300000039^<X0bKS:00T0bKS:00D00000
0<Ndb037]<P0akC80000000;0<VeaP0500000037/LD0ak750<Naa@0000001@3oool2000000030?oo
o`000000oooo02h0oooo000K0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool01@3o
ool2000000X0oooo0`00000906<000@000000P1L000;0000000405`0000000000000000001@0oooo
00<000000?ooo`3oool0<P3oool;00000080G=CS1000000506WIkPH000002P24hoP3000000P0S>?l
0P00000309WWn`8000002P2Ni?`300000080Xmol0P00000;0:cRn@8000001P2^g?L00`000000]Mkd
0;GNm0040;GNm0<000002@2ff?82000000030;cIk`000000000000d0_=?/00@000000<7Dj@000000
00003`2ocnH00`000000`l[P0<?:h00<0<?:h080000000<0`LGM00000035a]/02`35a]/200000003
0<?1f0000000a/;F00/0a/;F0P0000020<Bmd`0300000037_]40akkA00P0akkA00<000000<Fjc`35
^/l00P35^/l2000000T0b;_=00<000000<Jgb`36]l/00`36]l/00`000000bKS:0<VhbP070<VhbP03
00000037]<P0akC800<0akC800<000000<VeaP39]LH01`39]LH00`000000ak750<Naa@030<Naa@03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0;@3oool001/0oooo00<0gia804RLg`3oool0
0P3oool00`3o_g@007Bo0?ooo`040?ooo`8000003P3oool3000000L0H`002`00000205<000/00000
4@3oool00`000000oooo0?ooo`0]0?ooo`@0000000<0ClgF0000000000001@0000000`1Le><00000
00000002000000L0JMW^1000000307CLmP@000001024hoP3000000d0S>?l0`00000:09kTo0800000
1`2Sgo`2000000H0[>;i0`0000090:kLm`8000000P2eg_@2000000h0]]Sb00<000000;cCk02ldn`0
3P2ldn`00`000000_loV0;o?iP0=0;o?iP80000000<0_/WS00000033b^002`33b^001@000000`LGM
0<75g@31aMd0000000/0aLKK00D000000<?1f033`MP0`l7H0000000;0<K2eP0300000034_M<0a;gC
00<0a;gC00<000000<Nnd@37_]401P37_]400`000000aK[?0<Fjc`030<Fjc`8000002038^ld00`00
0000a[O;0<Jgb`050<Jgb`0300000039^<X0bKS:00D0bKS:00<000000<Ndb037]<P01037]<P00`00
0000bKG60<VeaP050<VeaP8000001P37/LD00`000000oooo0?ooo`060?ooo`030000003oool0oooo
02`0oooo000K0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0103oool00`000000
oooo0?ooo`0@0?ooo`L000001P1B000>00000080B@001P00000>0?ooo`030000003oool0oooo02P0
oooo4P00000606WIkP@000002`1dg?H4000000`0S>?l1000000309?PoP@000000`2Ni?`3000000/0
Xmol0P0000020:cRn@8000003@2^g?L3000000h0]]Sb0P0000000`2fd^h000000;cCk00<0;cCk080
000000<0^lkX0000002ocnH02`2ocnH2000000<0_/WS00<000000<?:h033b^002033b^02000000D0
`LGM00<000000<G6f`35a]/01`35a]/00`000000`l7H0<?1f0030<?1f00300000036`]H0a/;F00L0
a/;F00<000000<Bmd`34_M<01034_M<00`000000akkA0<Nnd@050<Nnd@0300000035^/l0aK[?00D0
aK[?0P0000060<Rkc@0300000036]l/0a[O;00H0a[O;00<000000<VhbP39^<X01039^<X00`000000
akC80<Ndb0060<Ndb00300000039]LH0bKG600<0bKG600<000000<Naa@37/LD01`37/LD00`000000
oooo0?ooo`060?ooo`030000003oool0oooo02/0oooo000K0?ooo`030?noM018W=l0oooo0080oooo
00<0gia804RLg`3oool0103oool00`000000oooo0?ooo`0D0?ooo`D000001`1B000400000080BP00
3`00000=0?ooo`030000003oool0oooo0280oooo2P00000304W8g0D000001@1FcnP6000000`0M=cf
1000000307kMn`@00000102<ho`4000000/0Tn3n0`00000?0:?Oo0<000003@2^g?L200000080[mOd
00<000000;KHlP2ff?802P2ff?82000000@0]];^00<000000;cCk02ldn`0202ldn`2000000@0^lkX
00<000000;o?iP2ocnH0202ocnH00`000000_/WS0;k9h`040;k9h`0300000033b^00`l[P00H0`l[P
00<000000<75g@31aMd01@31aMd00`000000aLKK0<G6f`050<G6f`8000001`33`MP00`000000a/;F
0<K2eP050<K2eP0300000034_M<0a;gC00H0a;gC00<000000<Nnd@37_]400`37_]400`000000aK[?
0<Fjc`070<Fjc`0300000038^ld0b;_=00<0b;_=00<000000<Jgb`36]l/02036]l/00`000000bKS:
0<VhbP020<VhbP0300000037]<P0akC800L0akC800<000000<VeaP39]LH00P39]LH00`000000ak75
0<Naa@080<Naa@030000003oool0oooo00H0oooo00<000000?ooo`3oool0:`3oool001`0oooo00H0
W4P007Boo`3oool0omnL04P0M02oool50?ooo`030000003oool0oooo01T0oooo7`00000;0?ooo`03
0000003oool0oooo01/0oooo1P00000203_0c@@000001019b=`4000000P0E/oX1000000306?ClP@0
0000101dg?H4000000/0O]gk1000000<09?PoP<000000P2Ig?h2000000/0Xmol0`0000020:KJnP80
00002P2^g?L2000000D0[mOd00<000000;KHlP2ff?801`2ff?82000000L0]];^00<000000;cCk02l
dn`01@2ldn`2000000L0^lkX00<000000;o?iP2ocnH01@2ocnH2000000P0_/WS00<000000<?:h033
b^000`33b^02000000T0`LGM00<000000<G6f`35a]/00`35a]/00`000000`l7H0<?1f0080<?1f003
00000036`]H0a/;F00<0a/;F00<000000<Bmd`34_M<02034_M<00`000000akkA0<Nnd@02000000X0
aK[?0P0000020<Rkc@8000003036]l/010000000bKS:0<VhbP00000;0<Ndb00400000039]LH0bKG6
000000`0ak7500<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Z0?ooo`00703oool01@3o
okl0M0000000000004P0W=oo00H0oooo00<000000?ooo`3oool07P3oool6000000@0@@001@000003
03L000`00000203oool00`000000oooo0?ooo`0D0?oooaL000001`1FcnP4000000X0Hm?b1@00000;
07kMn`@000000`26foh2000000P0Tn3n0`00000709WLoP030000002Sgo`0Xmol00D0Xmol0`000007
0:KJnP030000002^g?L0[]cg00@0[]cg0`0000080:oGm08000001@2ff?82000000X0]];^00<00000
0;cCk02ldn`00P2ldn`2000000X0^lkX00<000000;o?iP2ocnH00P2ocnH2000000/0_/WS00D00000
0<?:h033b^00`l[P0000000<0<75g@0500000035a]/0aLKK0<G6f`0000002`33`MP010000000a/;F
0<K2eP36`]H2000000/0a;gC00<000000<Nnd@0000003@35^/l00`000000b;_=0000000>0<Jgb`03
00000039^<X0000000`0akC800<000000<VeaP0000003@37/LD00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo02T0oooo000W0?ooo`8000009@3ooolM000000@0oooo00<000000?ooo`3oool0
3@3ooolD00000080@/?Q0`00000304;3h@T000001`1Sdo86000000@0K]Ki1000000407kMn`@00000
2@26foh2000000<0Tn3n0`00000;09WLoP8000000P2Sgo`3000000/0Y][j0P0000020:kLm`800000
3@2_eo@00`000000]]Sb0;KHlP02000000d0]];^00@000000;cCk000000000003@2kc^P010000000
_loV00000000000=0;k9h`0400000033b^000000000000d0`LGM00@000000<G6f`00000000003@33
`MP00`000000a/;F0000000>0<Bmd`0300000035^/l0aK[?00d0aK[?00<000000<Jgb`36]l/03P36
]l/00`000000akC80<Ndb00<0<Ndb00300000037/LD0ak7500d0ak7500<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0Y0?ooo`009P3oool2000002d0oooo<`00000802fef0/000002@1@bNd7
000000h0K]Ki1000000?08KKoP<000003`2Ig?h3000000l0Y][j0`00000?0:oGm0<000003`2fd^h2
00000100^lkX00<000000;k9h`2nbN<03P2nbN<00`000000`LGM0<75g@0>0<75g@0300000033`MP0
`l7H00h0`l7H00<000000<Bmd`34_M<03034_M<00`000000`kWA0000000=0<Fjc`0300000034]/d0
000000h0a[O;0P00000=0<Ndb08000003P37/LD2000000H0oooo0P0000000`3oool000000?ooo`0Y
0?ooo`009P3oool00`000000oooo0?ooo`0g0?oooc8000001@0k_>H4000000D0D<W]1P00000405c<
mP@000001@1^e_T6000000@0N=Gn0P00000908KKoP@000000`2=f?l2000000T0VMcn1000000209gH
o08000002`2Vf_X300000080Z=Gg0P00000<0:oGm08000000P2`dO400`000000]];^0;KBkP0;0;KB
kP8000000P2fcN/00`000000^lkX0;_>j00;0;_>j080000000<0^/SU0000002nbN<0302nbN<20000
00030;g4g`000000`LGM00`0`LGM0P0000000`30`=X000000<?1f00<0<?1f080000000<0`KcE0000
0034_M<02P34_M<200000080`kWA00<000000<Fjc`35^/l02@35^/l200000080a;K=00<000000<Jg
b`36]l/02`36]l/010000000a;?90<Bcb@00000;0<Ndb00400000035/<H0aK36000000`0ak7500@0
00000<F^``35[/<00000203oool00`000000oooo0?ooo`0X0?ooo`009P3oool00`000000oooo0?oo
o`110?ooo`L0000000<007S40000000000004@00000702F]g0@00000200k_>H8000000d0G<cf1P00
000<07SEoP8000000`26foh4000000T0SMSo0P00000309WLoP@00000202Mf?`2000000L0Y][j0P00
00070:SEm`030000002_eo@0[mOd00L0[mOd0P0000050;3Al@030000002fd^h0]];^00P0]];^0P00
00050;K=j`030000002kc^P0^lkX00P0^lkX0P0000040;[8i@030000002nbN<0_/WS00P0_/WS0P00
00040;g4g`0300000031aMd0`LGM00T0`LGM00<000000<30fP30`=X00P30`=X00`000000`l7H0<?1
f0090<?1f00500000031_=D0`KcE0<6le@0000002P34_M<00`000000`kWA0<>id@030<>id@030000
0035^/l0aK[?00L0aK[?00<000000<Bfc@34]/d00`34]/d00`000000a[O;0<Jgb`090<Jgb`050000
0034/lT0a;?90<Bcb@0000002P37]<P01@000000aK360<F`aP35/<H0000000/0ak7500D000000<F^
``35[/<0aJk3000000090?ooo`030000003oool0oooo02L0oooo000V0?ooo`030000003oool0oooo
0480oooo300000000`00Rm<000000000000N000000L0BL7`1000000405c<mPH00000101Xc_`20000
00d0N=Gn1000000?08gHo`<000003P2Mf?`200000080Y][j0`00000:0:SEm`030000002_eo@0[mOd
00@0[mOd0P0000080;3Al@8000001@2fd^h3000000P0]/g[00<000000;_>j02kc^P01@2kc^P20000
00L0^/SU00<000000;k9h`2nbN<01@2nbN<2000000L0_LCO00<000000<75g@31aMd01P31aMd20000
00H0`<3J00<000000<?1f033`MP01P33`MP2000000D0`KcE00<000000<Bmd`34_M<01P34_M<00`00
0000`kWA0<>id@040<>id@0300000035^/l0aK[?00H0aK[?00<000000<Bfc@34]/d01034]/d20000
00T0a[O;00<000000<Bcb@34/lT00`34/lT00`000000akC80<Ndb0060<Ndb00300000035/<H0aK36
00<0aK3600<000000<Naa@37/LD01`37/LD00`000000aJk30<F^``030<F^``030000003oool0oooo
00L0oooo00<000000?ooo`3oool09P3oool002H0oooo00<000000?ooo`3oool0A03oool700000080
087B1@0000001000Rm<000000000000FW=l>000000L0=;CX1000000704W1l0P00000301Xc_`30000
00@0N=Gn1P000004083Co`8000002@2=f?l400000080T]Cn0P00000>09gHo0<000003P2XeOL20000
0080[mOd0P00000<0;3Al@030000002fd^h0]];^00800000302fcN/00`000000^lkX0;_>j0020;_>
j08000002P2jb>D00`000000_/WS0;k9h`020;k9h`8000002@2ma=l00`000000`LGM0<75g@040<75
g@8000002030`=X00`000000`l7H0<?1f0040<?1f08000001`31_=D00`000000a;gC0<Bmd`050<Bm
d`0300000033^M40`kWA00H0`kWA00<000000<Fjc`35^/l01035^/l00`000000a;K=0<Bfc@060<Bf
c@8000001P36]l/2000000H0a;?900<000000<Ndb037]<P01@37]<P00`000000aK360<F`aP040<F`
aP0300000037/LD0ak7500H0ak7500<000000<F^``35[/<01035[/<00`000000oooo0?ooo`070?oo
o`030000003oool0oooo02H0oooo000V0?ooo`030000003oool0oooo04H0oooo100000000`00M]40
00000000000200000080087B1`00000301JLg`@000000P0/ZnXE000000L0E/Ch0P00000=06S>o0D0
00003020dol2000000<0SMSo1000000809;DoP800000202Mf?`400000080Wm;j00<000000:SEm`2X
eOL03@2XeOL3000000h0/=7a0`00000?0;K=j`040000002kc^P00000000000d0^/SU00@000000;k9
h`0000000000302ma=l00`000000`LGM0<75g@020<75g@0300000030`=X0`<3J00T0`<3J00<00000
0<?1f033`MP00P33`MP00`000000`KcE0<6le@080<6le@0300000034_M<0a;gC00<0a;gC00<00000
0<>id@33^M401`33^M400`000000aK[?0<Fjc`030<Fjc`0300000034]/d0a;K=00P0a;K=00<00000
0<Jgb`36]l/00`36]l/00`000000a;?90<Bcb@070<Bcb@0300000037]<P0akC800<0akC800<00000
0<F`aP35/<H01P35/<H00`000000ak750<Naa@040<Naa@0300000035[/<0aJk300H0aJk300<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0U0?ooo`009@3oool3000004T0oooo100000000`00
M]40000000000006000000803Y;O1`000000100FW=l0000000000000000602b[jP@000001P12^O84
000000T0E/Ch0`00000406S>o0H00000101acOl2000000`0P=?o1000000>09;DoP8000000P2Mf?`4
000000L0Wm;j00<000000:SEm`2XeOL02@2XeOL300000080ZLod00<000000;3Al@2`dO402P2`dO42
00000080/<_]00<000000;K=j`2fcN/03@2fcN/200000100^/SU00<000000;g4g`2ma=l03@2ma=l0
10000000`LGM00000000000=0<30fP0400000033`MP00000000000`0`KcE00<000000<Bmd`34_M<0
0P00000;0<>id@0300000035^/l0aK[?008000002`34]/d2000000<0a[O;00<000000<Bcb@34/lT0
2034/lT00`000000akC80<Ndb0020<Ndb00300000035/<H0aK3600L0aK3600<000000<Naa@37/LD0
0`37/LD00`000000aJk30<F^``070<F^``030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1`3oool00`3ookl0M000000000040000000307Boo`3oool0oooo01<0oooo000U0?ooo`030000003o
ool0oooo04X0oooo2000000300J7gPD000000P0>T]l20000000302BRjP000000000002H00000301a
cOl2000000@0P=?o1P00000308K@o`8000003P2Be?h3000000`0Wm;j0P0000060:SEm`<000001P2Y
co@00`000000/=7a0;3Al@070;3Al@8000001@2`bnd00`000000]/g[0;K=j`0:0;K=j`8000000P2f
anL00`000000^/SU0;[8i@0;0;[8i@80000000<0^L?Q0000002ma=l03P2ma=l00`000000`<3J0<30
fP0>0<30fP0300000031_=D0`KcE00`0`KcE00<000000<Bmd`0000003@33^M400`000000aK[?0000
000>0<Bfc@80000000<0a[O;00000034/lT02`34/lT010000000akC80<Ndb000000;0<F`aP050000
0037/LD0ak750<Naa@0000002`35[/<00`000000oooo0?ooo`050?ooo`<000002P3oool00`2oM000
001d0;ooo`020?ooo`030=nLM02Lgol0oooo01@0oooo000U0?ooo`030000003oool0oooo04`0oooo
2P00000200J7gPP000001P0TX^X2000000L0>Zob0P00000904jkn@8000002P1QaO`2000000`0LLgo
1@00000;08K@o`800000202Be?h400000080U/ol00<0000009oBnP2Od_X0302Od_X00`000000Z=Gg
0:SEm`03000000X0ZLod0P0000050;3Al@800000202`bnd00`000000]/g[0;K=j`070;K=j`800000
1@2fanL00`000000^/SU0;[8i@080;[8i@8000000`2i`n400`000000_LCO0;g4g`0;0;g4g`800000
00<0_;oL00000030`=X03030`=X2000000030;jke`000000`KcE00d0`KcE00<000000<>id@33^M40
3@33^M400`000000a;K=0<Bfc@0=0<Bfc@<000003@34/lT00`000000akC80000000<0<F`aP040000
0037/LD0ak75000000`0aJk300<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0?noM00004P0W=oo01P0oooo000U0?ooo`030000003oool0oooo04d0oooo00<00000001bf@000000
0`0000000`00OM`0000000000002000000801XON0P00000301fGj@L000000P0TX^X2000000L0>Zob
0P00000904jkn@8000002P1QaO`2000000@0LLgo1P00000307W:o`8000003@26d?l200000080T]Cn
1000000709K?o0030000002Od_X0Wm;j00/0Wm;j0`00000?0:W?m0030000002`dO40/=7a00800000
2`2`bnd00`000000]/g[0;K=j`030;K=j`<00000202fanL00`000000^/SU0;[8i@050;[8i@800000
1P2i`n400`000000_LCO0;g4g`080;g4g`8000000`2l_m`00`000000`<3J0<30fP090<30fP800000
0`2n^mL00`000000`KcE0<6le@0:0<6le@80000000<0`;SB00000033^M403033^M400`000000`KG>
0000000?0<Bfc@8000003P34/lT00`000000aK360<F`aP0<0<F`aP8000003P35[/<00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<0omnL04P00018W=l05`3oool002D0oooo00<0
00000?ooo`3oool0C@3oool300000004001bf@00000000000000008007gL2000000401fGj@800000
0P0bYO8:000000<0>Zob0P00000904jkn@8000001P1QaO`8000000/0NL[o0P00000;08K@o`@00000
302Fco`2000000L0Wm;j100000020:;=mP8000003P2Yco@3000000h0/<_]00<000000;K=j`2fcN/0
0P00000<0;K7i`030000002jb>D0^/SU0080^/SU0P0000090;W3h@030000002ma=l0_LCO00D0_LCO
0P0000060;bog00300000030`=X0`<3J00L0`<3J00<000000;jke`2n^mL0102n^mL00`000000`KcE
0<6le@080<6le@0500000030^=80`;SB0<2hdP0000002`33^M4200000080`KG>00<000000<Bfc@34
]/d03034]/d2000000030<Bcb@000000a;?900/0a;?90P00000>0<F`aP0300000035[/<0aJk300d0
aJk300<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`0309a80018W=l0oooo01D0
oooo000U0?ooo`<00000BP3oool3000000<0oooo0P0000000`00L]T000000000000200000003001m
g0000000000000805HgW1@00000301fGj@8000001P0bYO8200000080Ak7h5P00000606[4oP800000
3@1ib_l2000000<0Q]3o1P00000308c<o@030000002Fco`0U/ol00`0U/ol00<0000009oBnP2Od_X0
100000080:;=mP030000002Yco@0ZLod00P0ZLod0`0000020:[9l0030000002`bnd0/<_]00`0/<_]
0`00000?0;K7i`040000002jb>D00000000000`0^L?Q00<000000;g4g`2ma=l00P2ma=l2000000T0
_;oL00<000000<30fP30`=X01030`=X2000000L0_[_G00<000000<6le@31_=D01`31_=D00`000000
`;SB0<2hdP030<2hdP0300000033^M40`kWA00L0`kWA00<000000<6ecP31]Lh00`31]Lh00`000000
a;K=0<Bfc@090<Bfc@8000000P32///00`000000a;?90000000:0<Bcb@0400000033/<L0`k370000
00`0aK360P00000>0<F^``8000002`3oool00`000000oooo0?ooo`0:0?ooo`0309a8M02oool0oooo
01@0oooo000T0?ooo`800000BP3oool2000000L0oooo0`0000000`00L]T0000000j2i005000000<0
5HgW2@00000603:UlP8000001`17/OP2000000T0FK_l0P00000:06[4oP8000002`1ib_l5000000X0
S<cm00<0000009K?o02Fco`02`2Fco`3000000d0X/gf00<000000:W?m02Yco@01@2Yco@2000000H0
Z/W`00<000000;3;k@2`bnd02@2`bnd200000080/<GZ00<000000;K7i`2fanL03@2fanL2000000h0
^L?Q00<000000;g4g`2ma=l00P00000<0;bog00400000030`=X0`<3J0<30fP8000002P2n^mL00`00
0000`KcE0<6le@040<6le@8000001P30^=800`000000`kWA0<>id@060<>id@0300000031]Lh0`KG>
00@0`KG>00<000000<Bfc@34]/d02034]/d00`000000`[;;0<:bb`020<:bb`0300000034/lT00000
00T0a;?900D000000<>`a`33/<L0`k370000000;0<F`aP0400000033[L@0`jg4000000`0aJk300@0
00000<B[`@34Zl4000002`3oool00`000000oooo0?ooo`040?ooo`030=nLB01d_ol0oooo0080oooo
00<0_g@007Boo`3oool0503oool002@0oooo00<000000?ooo`3oool0AP3oool3000000X0oooo00<0
000000Igh00000000P00000400j2i0@000000P0ESNL2000000<0:i[`1`00000303:UlP8000001`17
/OP2000000T0FK_l0P00000:06[4oP8000000`1ib_l6000000<0OlOn00<0000008c<o@2<c?d02P2<
c?d2000000L0U/ol1000000209W:n08000003@2RcOH200000080ZLod0`0000090:[9l0030000002`
bnd0/<_]00H0/<_]0P0000050;35jP030000002fanL0]/OW00X0]/OW0P0000020;G1i0030000002i
`n40^L?Q00`0^L?Q0P00000>0;bog00400000030`=X00000000000`0_[_G00<000000<6le@31_=D0
0`31_=D00`000000`;SB0<2hdP070<2hdP0300000033^M40`kWA00@0`kWA00<000000<6ecP31]Lh0
1P31]Lh00`000000a;K=0<Bfc@060<Bfc@0300000032///0`[;;00@0`[;;00<000000<Bcb@000000
1`34/lT00`000000`k370<>`a`030<>`a`0300000035/<H0aK3600L0aK3600D000000<>]a033[L@0
`jg40000000;0<F^``0500000034Zl40a:_10<B[`@0000002`3oool00`000000oooo0?ooo`040?oo
o`070?noM00007@0_ooo0?ooo`3o_g@0001809cOo`0E0?ooo`005P3oool00`3ookl0M00000000004
0000000307Boo`3oool0oooo00@0oooo00<000000?ooo`3oool0@`3oool3000000h0oooo0P000000
1006Mn00000000000000000400j2i0030000000ST>d0000000D00000100[V_0200000080?jOf:000
000:07o7oP030000002<c?d0S<cm00/0S<cm00<0000009K?o02Fco`01000000809W:n0030000002R
cOH0X/gf00/0X/gf0`00000=0:[9l0030000002`bnd0/<_]00<0/<_]0P0000080;35jP030000002f
anL0]/OW00L0]/OW0P0000040;G1i0030000002i`n40^L?Q00X0^L?Q0P0000000`2h_]h000000;bo
g00>0;bog0030000002n^mL0_[_G00d0_[_G00D000000<6le@31_=D0`KcE0000000:0<2hdP030000
0033^M40`kWA00<0`kWA00<000000<6ecP31]Lh02031]Lh00`000000a;K=0<Bfc@040<Bfc@030000
0032///0`[;;00D0`[;;00@000000<Bcb@34/lT000001034/lT2000000H0`k3700<000000<F`aP35
/<H01P35/<H00`000000`jg40<>]a0030<>]a00300000035[/<0aJk300L0aJk300<000000<B[`@34
Zl400`34Zl400`000000oooo0?ooo`080?ooo`8000001P3oool01@3o_g@000000000000004P0W=oo
01H0oooo000G0?ooo`030;md000007@0_ooo0080oooo00<0giad09cOo`3oool01@3oool00`000000
oooo0?ooo`100?ooo`<000004`3oool00`0000001WOP00Igh003000000<03X;T00<0000002>@k@0S
T>d00P0ST>d5000000<0:i[`0P00000603nWmP800000201B/OX2000000T0Hk[m0P00000907;1oP80
00002`1oaoh2000000X0S<cm1000000=09W:n0030000002RcOH0X/gf00H0X/gf100000020:?7lP03
0000002ZbO00Z/W`00`0Z/W`00<000000;3;k@2`bnd00P00000;0;35jP030000002fanL0]/OW00<0
]/OW0`0000070;G1i0030000002i`n40^L?Q00L0^L?Q0P0000030;RngP030000002l_m`0_;oL00/0
_;oL0P0000000`2k^]T000000;jke`0=0;jke`0400000031_=D00000000000`0`;SB00<000000<>i
d@33^M400P00000;0<6ecP0300000034]/d0a;K=00<0a;K=00<000000<:bb`32///01`32///01000
0000a;?90<Bcb@0000020<Bcb@0300000033/<L0`k3700L0`k3700<000000<F`aP35/<H01035/<H0
0`000000`jg40<>]a0040<>]a00300000035[/<0aJk300H0aJk300<000000<B[`@34Zl401034Zl40
0`000000oooo0?ooo`050?ooo`<0000000<0oooo0000003oool0803oool001P0oooo00<0okmd0000
B02Lgol02@3oool00`000000oooo0?ooo`0m0?ooo`<000005`3oool0100000001WOP00Igh006Mn04
0000000300j2i0000000000000D08i3]2@00000603nWmP800000201B/OX00`000000Hk[m06>jo@08
06>jo@030000001b`Oh0L/7n00P0L/7n00<0000007o7oP1oaoh02P1oaoh010000000S<cm08c<o@2<
c?d6000000<0T<Oj0P00000=09W:n08000000P2RcOH4000000L0XlOb00<000000:[9l02ZbO002`2Z
bO03000000h0/<GZ00<000000;K7i`2fanL00P00000;0;G1i0030000002i`n40^L?Q00@0^L?Q0P00
00060;RngP030000002l_m`0_;oL00T0_;oL00D000000;^jf@2k^]T0^k[I0000000?0;jke`030000
0030^=80`;SB00`0`;SB00<000000<>id@0000003P31]Lh00`000000a;K=0<Bfc@02000000X0`[;;
00H000000<Bcb@34/lT000000<Bcb@00000:0<>`a`0300000035/<H0aK3600<0aK3600<000000<>]
a033[L@01P33[L@00`000000aJk30<F^``040<F^``0300000034Zl40a:_100D0a:_100@000000?oo
o`3oool0oooo100000040?ooo`030000003oool0oooo01l0oooo000I0?ooo`030?oOW0180000B9cO
00P0oooo00<000000?ooo`3oool0>P3oool3000001/0oooo0P00000300Igh0030000000LQNT00000
00<000001P0ST>d00`000000>9cc03RLl`0203RLl`L000000`0oYoH2000000L0D[7j00<0000006>j
o@1S^_d0201S^_d00`000000L/7n07;1oP0807;1oP8000001P1oaoh8000000/0T<Oj00<0000009W:
n02Ib_P02`2Ib_P3000000`0XlOb00<000000:[9l02ZbO001`2ZbO0300000080Z/C/00<000000;35
jP2`aNX0302`aNX3000000h0]L7T00@000000;W3h@2i`n40^L?Q0P0000090;RngP030000002l_m`0
_;oL00H0_;oL0P0000050;^jf@030000002n^mL0_[_G00X0_[_G0P0000000`2m]m@000000<2hdP0=
0<2hdP0300000031]Lh0`KG>00d0`KG>00<000000<Bfc@0000003@32///010000000a;?90<Bcb@00
000<0<>`a`0500000035/<H0aK360<F`aP0000002@33[L@00`000000aJk30<F^``030<F^``030000
0034Zl40a:_100L0a:_10`0000080?ooo`030000003oool0oooo01l0oooo000K0?ooo`0309a80018
W=l0oooo00D0oooo0`00000h0?ooo`<000007`3oool40000000300Igh000000078GY008078GY1000
000402>@k@030000000hW?<0>9cc00@0>9cc0P00000204^Wn0X000000`1B/OX2000000T0Hk[m0P00
000607;1oPX000001P25`_/2000000`0T<Oj00<0000009W:n02Ib_P01P2Ib_P400000080VlGd00<0
00000:?7lP2Sao802`2Sao800`000000Z/W`0:[9l0040:[9l08000001P2Za>`00`000000/<GZ0;35
jP090;35jP8000000P2``>H00`000000]L7T0;G1i00<0;G1i0040000002i`n400000000000`0^;kN
00<000000;bog02l_m`00`2l_m`2000000P0^k[I00<000000;jke`2n^mL0202n^mL01@000000_KOD
0;fge02m]m@0000000`0`;SB0P0000000`2n]=0000000<6ecP0>0<6ecP0300000032///0`[;;00`0
`[;;00D000000<Bcb@000000`k370000000;0<>`a`0400000035/<H0aK36000000/0`jg400D00000
0<F^``35[/<0aJk30000000:0<B[`@030000003oool0oooo00T0oooo00<000000?ooo`3oool07P3o
ool001`0oooo00<0W4Qd0;ooo`3oool0103oool00`000000oooo0?ooo`0e0?ooo`<000008`3oool0
0`0000005G[T01Eji004000000<078GY2@00000603RLl`030000001;YoP0BjOh00D0BjOh0P000002
05^`naH000001@1i_O`2000000/0QL;k00<000000937nP2@aoX02P2@aoX200000080VL[h10000007
09_5m0030000002Sao80XlOb00/0XlOb00<000000:[9l02ZbO000`0000090:[4k0030000002`aNX0
/<GZ00H0/<GZ0P0000050;30iP030000002e`N@0]L7T00/0]L7T0P00000>0;RngP030000002l_m`0
_;oL0080_;oL00<000000;^jf@2k^]T0202k^]T00`000000_[_G0;jke`060;jke`8000001@2m]m@0
0`000000`;SB0<2hdP080<2hdP050000002n]=00_[C@0;jdd00000003@31]Lh3000000l0`[;;00@0
00000<>`a`33/<L000003033/<L2000000`0`jg400@000000<F^``35[/<000003034Zl400`000000
oooo0?ooo`080?ooo`030000003oool0oooo01h0oooo000G0?ooo`030=nLB01d_ol0oooo0080oooo
00<0_g@007Boo`3oool0103oool00`000000oooo0?ooo`0c0?ooo`8000009`3oool2000000<05G[T
0`00000301b5j@030000000`TO00<97`0080<97`1@00000403RLl`030000001;YoP0BjOh00H0BjOh
00<0000005^`n`1K/?/01@1K/?/2000000T0JkOl00<0000007Vmo01i_O`02@1i_O`00`000000QL;k
08G2n`0908G2n`030000002@aoX0T<Oj00T0T<Oj1000000<09_5m0030000002Sao80XlOb00X0XlOb
0`00000=0:[4k0030000002`aNX0/<GZ00<0/<GZ0P0000080;30iP030000002e`N@0]L7T00P0]L7T
0P0000020;Blh0030000002h_]h0^;kN00`0^;kN00@000000;bog00000000000302k^]T00`000000
_[_G0;jke`030;jke`8000001`2m]m@00`000000`;SB0<2hdP060<2hdP8000001@2n]=000`000000
`KG>0<6ecP090<6ecP050000002o/L`0_k7<0;nac00000003@32///2000000<0`k3700<000000<>`
a`33/<L02@33/<L00`000000`jg40<>]a00<0<>]a08000003@34Zl400`000000oooo0?ooo`080?oo
o`030000003oool0oooo01h0oooo000G0?ooo`070?noM00007@0_ooo0?ooo`3o_g@0001809cOo`05
0?ooo`030000003oool0oooo0300oooo0`00000[0?ooo`030000000EN^@05G[T00805G[T10000000
0`0LQNT00000032Al005032Al0T000001`1;YoP00`000000Fk3k05^`n`0605^`n`030000001[]o`0
JkOl00L0JkOl00<0000007Vmo01i_O`02@1i_O`00`000000QL;k08G2n`0908G2n`8000000`2@aoX6
000000<0Tl7g00<0000009_5m02KaO@02`2KaO@00`000000XlOb0:?7lP050:?7lP@000000P2T`^h0
0`000000Z/C/0:[4k00<0:[4k0030000002`aNX0/<GZ008000002P2``>H00`000000]L7T0;G1i006
0;G1i0800000102d_>000`000000^;kN0;RngP0=0;RngP030000002k^]T0^k[I00d0^k[I00D00000
0;jke`2n^mL0_[_G0000000:0;fge00300000030^=80`;SB00<0`;SB0P0000080;jdd00300000031
]Lh0`KG>00L0`KG>00<000000;nac02o/L`00P2o/L`00`000000`[;;0<:bb`090<:bb`8000000P30
[lP01@000000`k370<>`a`33/<L0000000T0`k370P00000>0<>]a00300000034Zl40a:_100d0a:_1
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0N0?ooo`00603oool01@3o_g@000000000
000004P0W=oo00H0oooo00<000000?ooo`3oool0;@3oool3000002l0oooo0P00000301Eji0030000
000YQn/0:HO[00@000001P0`TO000`000000@icd04>Lm00204>Lm0L000000`1;YoP2000000L0Fk3k
00<0000006^go01[]o`01`1[]o`2000000X0NKgl0P00000608G2n`P000002P2C`OL00`000000VlGd
09_5m00;09_5m0030000002Sao80XlOb00@000001`2T`^h00`000000Z/C/0:[4k00;0:[4k0<00000
3@2``>H00`000000]L7T0;G1i0030;G1i08000001`2d_>000`000000^;kN0;RngP0:0;RngP800000
00<0]kWK0000002k^]T03@2k^]T010000000_[_G00000000000<0;fge00500000030^=80`;SB0<2h
dP0000002P2n]=000`000000`KG>0<6ecP050<6ecP8000001P2o/L`00`000000`[;;0<:bb`070<:b
b`0300000030[lP0`:o80080`:o800<000000<>`a`33/<L00P33/<L00`000000`k370<>`a`040<>`
a`8000000P31[<D00`000000`jg40<>]a00:0<>]a08000003`34Zl400`000000oooo0?ooo`070?oo
o`030000003oool0oooo01h0oooo000S0?ooo`030000003oool0oooo02X0oooo0`00000c0?ooo`<0
00000P0EN^@00`000000:HO[02V7j`0202V7j`@00000100`TO000`000000@icd04>Lm00404>Lm004
0000001DYOL0E:Gg05BUm`X000000`1K/?/2000000T0JkOl00<0000007Vmo01i_O`0101i_O`;0000
00H0RKkh00<0000009?1m`2C`OL02P2C`OL2000000X0VlGd1000000<0:C2kP030000002Za>`0Z/C/
00L0Z/C/0`0000020:Znj0030000002``>H0/<3V00`0/<3V00<000000;G1i02e`N@00P00000:0;Bl
h0030000002h_]h0^;kN00L0^;kN0P0000030;Nif`030000002k^]T0^k[I00d0^k[I00<000000;fg
e02m]m@0302m]m@010000000`;SB00000000000<0;jdd00300000031]Lh0`KG>00<0`KG>00<00000
0;nac02o/L`01P2o/L`00`000000`[;;0<:bb`060<:bb`0300000030[lP0`:o800@0`:o800D00000
0<>`a`33/<L0`k37000000050<>`a`0300000031[<D0`Jc50080`Jc500<000000<>]a033[L@02@33
[L@010000000`Z[20<:Z`P00000=0<B[`@8000002@3oool00`000000oooo0?ooo`0N0?ooo`008`3o
ool2000002P0oooo0`00000g0?ooo`060000000SO>H000000000000EN^@000001@0YQn/00`000000
?9;`00000006000000D0@icd00<0000005BUm`1DYOL01P1DYOL010000000I:gi06B]n@1T[OTE0000
00H0O[Wi00<0000008Vnn029__P02@29__P00`000000Tl7g09?1m`0;09?1m`040000002KaO@0VlGd
09_5m0H000000`2M_o000`000000Y<;^0:C2kP0;0:C2kP030000002Za>`0Z/C/00@0Z/C/0P000006
0:Znj0030000002``>H0/<3V00/0/<3V0`00000=0;Blh0030000002h_]h0^;kN00@0^;kN0P000006
0;Nif`030000002k^]T0^k[I00X0^k[I0P0000000`2i]]H000000;fge00=0;fge0030000002n]=00
_[C@00d0_[C@00D000000<6ecP31]Lh0`KG>0000000:0;nac00300000032///0`[;;00@0`[;;00<0
00000<2_b030[lP01@30[lP00`000000`k370<>`a`020<>`a`0500000033/<L0`k370<>`a`000000
1P31[<D00`000000`jg40<>]a0070<>]a00500000032Z/80`Z[20<:Z`P0000003034Zl4010000000
`ZRo0<:X_`0000080?ooo`030000003oool0oooo01h0oooo000R0?ooo`8000009P3oool3000003/0
oooo00<0000002=liP0SO>H00`00000502V7j`030000000lT_00?9;`00<0?9;`1@00000304>Lm080
00001`1DYOL00`000000I:gi06B]n@0606B]n@800000201a]?X2000000X0O[Wi00<0000008Vnn029
__P02@29__P2000000X0Tl7g1@00000:09fol0030000002T`^h0Y<;^00/0Y<;^00<000000:[4k02Z
a>`00`0000090:Znj0030000002``>H0/<3V00P0/<3V0P0000020:nkhP030000002d_>00];cP00/0
];cP00<000000;RngP2h_]h00P2h_]h2000000T0]kWK00<000000;^jf@2k^]T01`2k^]T2000000<0
^KKF00<000000;fge02m]m@02P2m]m@2000000030;^cd@000000_[C@00d0_[C@00@000000<6ecP00
000000002`2o/L`00`000000`[;;0<:bb`030<:bb`0300000030[lP0`:o800L0`:o800<000000<>`
a`33/<L00P33/<L00`000000`k37000000070<6/a@0300000033[L@0`jg400H0`jg400<000000<:Z
`P32Z/800`32Z/800`000000a:_10<B[`@080<B[`@0500000032Z;l0`ZRo0<:X_`0000002@3oool0
0`000000oooo0?ooo`0M0?ooo`008P3oool00`000000oooo0?ooo`0R0?ooo`<00000?`3oool01000
00008gcV02=liP0SO>H3000000@0:HO[0P00000603bBl0030000001=Vo<0000000<0000000<0@icd
0000001DYOL01P1DYOL00`000000I:gi06B]n@0706B]n@030000001a]?X0LKCj00L0LKCj00<00000
07jin@1n^OT0201n^OT00`000000RKkh08Vnn00:08Vnn0040000002C`OL0Tl7g09?1m`H000000`2E
_?800`000000WKo`09fol00:09fol0030000002T`^h0Y<;^00X0Y<;^0`00000<0:Znj0030000002`
`>H0/<3V00H0/<3V0P0000040:nkhP030000002d_>00];cP00`0];cP00@000000;RngP0000000000
302g^M/00`000000^k[I0;^jf@040;^jf@8000001P2i]]H00`000000_KOD0;fge0080;fge0050000
002k/m40^k?A0;^cd@0000003`2n]=000`000000_k7<0;nac00<0;nac00300000032///0`[;;0080
00002P30[lP00`000000`k370<>`a`030<>`a`0300000031[<D0`Jc500L0`Jc500<000000<>]a033
[L@01033[L@00`000000`Z[20<:Z`P040<:Z`P0300000034Zl40a:_100L0a:_100<000000<:X_`32
Z;l00`32Z;l00`000000oooo0?ooo`060?ooo`030000003oool0oooo01d0oooo000R0?ooo`030000
003oool0oooo01l0oooo0`0000130?ooo`030000000SO>H08gcV00808gcV1000000302V7j`030000
000lT_00?9;`00@0?9;`00<0000004fKl`1=Vo<00P1=Vo<5000000D0E:Gg00<0000006B]n@1T[OT0
1`1T[OT00`000000LKCj076dnP07076dnP030000001n^OT0O[Wi00P0O[Wi00<0000008Vnn029__P0
2029__P5000000X0UKcb00<0000009fol02M_o002P2M_o000`000000Y<;^0:C2kP050:C2kP@00000
0P2T_>X00`000000Z[kX0:Znj00;0:Znj0030000002``>H0/<3V00<0/<3V0P0000070:nkhP030000
002d_>00];cP00/0];cP0P00000>0;Nif`030000002k^]T0^k[I0080^k[I0P0000080;VfeP030000
002m]m@0_KOD00H0_KOD0P0000050;^cd@030000002n]=00_[C@00X0_[C@0`00000>0;nac0030000
0032///0000000d0`:o800<000000<>`a`33/<L00`0000090<6/a@0300000033[L@0`jg400<0`jg4
00<000000<:Z`P32Z/801@32Z/800`000000a:_10<B[`@060<B[`@0300000032Z;l0`ZRo00@0`ZRo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0M0?ooo`008P3oool00`000000oooo0?oo
o`0M0?ooo`800000A`3oool00`0000008gcV02=liP0202=liP030000000eQn`0=HO/00D000001P0l
T_000`000000CI_c04fKl`0404fKl`030000001LXoH0000000@0000000<0E:Gg0000001T[OT0201T
[OT2000000P0LKCj0P00000907jin@0400000029__P0RKkh08Vnn0H000000`2<^O@00`000000UKcb
09FllP0:09FllP030000002M_o00WKo`00X0WKo`00<000000:C2kP2T`^h0100000070:BljP030000
002Z_^P0Z[kX00/0Z[kX00<000000;30iP2``>H00P00000:0:nkhP030000002d_>00];cP00P0];cP
0P0000020;>hg0030000002g^M/0]kWK00`0]kWK00@000000;^jf@00000000002`2i]]H00`000000
_KOD0;fge0030;fge08000001`2k/m400`000000_[C@0;jdd0090;jdd0050000002m/<d0_K3=0;f`
c@0000003P2o/L`00`000000`:o80<2_b00<0<2_b00300000033/<L0000000<0`Jc500<000000<6/
a@31[<D01`31[<D01@000000`jg40<>]a033[L@0000000T0`Z[200<000000<B[`@34Zl401034Zl40
0`000000`ZRo0<:X_`050<:X_`030000003oool0oooo00H0oooo00<000000?ooo`3oool07@3oool0
0280oooo00<000000?ooo`3oool06P3oool3000004X0oooo0P00000302=liP800000100eQn`40000
00@0?9;`00<0000004fKl`1=Vo<0101=Vo<00`000000G:?f05bSmP0305bSmR@000002P2<^O@00`00
0000UKcb09FllP0909FllP030000002M_o00WKo`00X0WKo`0`00000<0:BljP030000002Z_^P0Z[kX
00X0Z[kX0`00000=0:nkhP030000002d_>00];cP00D0];cP0P0000040;>hg0030000002g^M/0]kWK
00d0]kWK00<000000;VfeP2i]]H0302i]]H01@000000_KOD0;fge02m]m@0000000X0^k?A00<00000
0;jdd02n]=001`2n]=000`000000_K3=0;f`c@020;f`c@030000002o/L`0_k7<00X0_k7<0`00000?
0<2_b00300000031[<D0`Jc500<0`Jc500<000000<6/a@31[<D01P31[<D010000000`jg40<>]a000
000:0<:Z`P0300000034Zl40a:_100<0a:_100<000000<:X_`32Z;l01`32Z;l00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01d0oooo000R0?ooo`800000603oool3000004h0oooo10000002
02=liP030000000eQn`0=HO/00<0=HO/00<0000004JAk`0000000`0000000`0lT_00000004fKl`05
04fKl`8000001P1LXoH2000000T0Jj[f00<0000007N`mP1g/?H01`1g/?H00`000000P[Ge08:em@07
08:em@030000002<^O@0S;Wd00X0S;Wd00<0000009FllP2E_?802@2E_?800`000000WKo`09fol005
09fol0@000000P2N^^`00`000000Y;cZ0:BljP0:0:BljP030000002Z_^P0Z[kX00L0Z[kX0`000002
0:Zii0030000002_^n80[k_R00/0[k_R00<000000;Blh02d_>000`2d_>02000000L0/kSL00<00000
0;Nif`2g^M/02P2g^M/2000000030;Jdf0000000^KKF00`0^KKF00@000000;fge00000000000302k
/m400`000000_[C@0;jdd0040;jdd08000001P2m/<d00`000000_k7<0;nac0080;nac0050000002n
[/T0_Zk90;j^b@0000003@30[lP2000000D0`Jc500<000000<6/a@31[<D01`31[<D2000000`0`Z[2
00D000000<B[`@34Zl40a:_10000000:0<:X_`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool07@3oool00240oooo0P00000F0?ooo`<00000DP3oool00`000000;WkW02ini`04000000D0=HO/
00<0000004JAk`16TNl00P16TNl5000000D0CI_c00<0000005bSmP1LXoH01@1LXoH00`000000Jj[f
06^ZmP0706^ZmP030000001g/?H0Mk3f00L0Mk3f00<0000008:em@22]OD01`22]OD00`000000S;Wd
08bim00:08bim0030000002E_?80UKcb00T0UKcb00<0000009fol02M_o001000000709jjk0030000
002T_>X0Y;cZ00X0Y;cZ00<000000:Znj02Z_^P0102Z_^P2000000H0Z[WT00<000000:nkhP2_^n80
2`2_^n800`000000];cP0;Blh002000000T0/kSL00<000000;Nif`2g^M/0202g^M/2000000<0][CH
00<000000;VfeP2i]]H0302i]]H00`000000^k?A0;^cd@0<0;^cd@030000002n]=00_[C@00<0_[C@
00<000000;f`c@2m/<d01P2m/<d00`000000_k7<0;nac0070;nac0030000002n[/T0_Zk90080_Zk9
00<000000<2_b030[lP02@30[lP200000080_j_600<000000<6/a@31[<D00`31[<D00`000000`Jc5
0<6/a@060<6/a@0300000032Z/80`Z[200/0`Z[200@000000<B[`@34Zl4000003032Z;l00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01d0oooo000Q0?ooo`030000003oool0oooo0180oooo
0`00001F0?ooo`030000000^O^L0;WkW0080;WkW0`00000403F7k00300000016TNl0AY7_00@0AY7_
00<0000005JIl@000000100000000`1=Vo<0000005bSmP0605bSmP030000001[Z_H0Jj[f00L0Jj[f
00<0000007N`mP1g/?H01`1g/?H00`000000P[Ge08:em@0708:em@8000002`2<^O@00`000000UKcb
09FllP0409FllPL00000302N^^`00`000000Y;cZ0:BljP0:0:BljP030000002Z_^P0Z[kX00<00000
2@2Z^N@00`000000[k_R0:nkhP0:0:nkhP<00000302c^=`00`000000]kWK0;Nif`050;Nif`800000
1P2f]=P00`000000^KKF0;VfeP090;VfeP<000003`2k/m401@000000_[C@0;jdd02n]=00000000X0
_K3=00<000000;nac02o/L`0102o/L`2000000H0_Zk900<000000<2_b030[lP01`30[lP00`000000
_j_60;n[aP020;n[aP0300000031[<D0`Jc500@0`Jc500<000000<6/a@31[<D01031[<D2000000h0
`Z[20P00000=0<:X_`030000003oool0oooo00@0oooo00<000000?ooo`3oool07@3oool00240oooo
00<000000?ooo`3oool03`3oool3000005X0oooo00<0000002ini`0^O^L00`0^O^L400000080=HO/
00<0000004JAk`16TNl01016TNl00`000000EYWa05JIl@0305JIl@L000000`1LXoH2000000P0Jj[f
00<0000007N`mP1g/?H01`1g/?H00`000000P[Ge08:em@0808:em@030000002<^O@0S;Wd00L0S;Wd
2000000609NgkP030000002N^^`0W[[/00X0W[[/00<000000:BljP2T_>X02P2T_>X3000000`0Z[WT
00<000000:nkhP2_^n801`2_^n8300000080[kKN00<000000;>hg02c^=`02`2c^=`00`000000]kWK
0;Nif`020;Nif`800000202f]=P00`000000^KKF0;VfeP080;VfeP050000002h/M<0^;7C0;Rad`00
00003P2k/m4010000000_[C@00000000000;0;f`c@030000002o/L`0_k7<00<0_k7<00<000000;j^
b@2n[/T01P2n[/T00`000000`:o80<2_b0060<2_b0030000002oZlH0_j_600@0_j_600<000000<6/
a@31[<D01031[<D010000000`Jc50<6/a@31[<D200000080_jW300<000000<:Z`P32Z/802`32Z/80
0`000000`ZRo0<:X_`0=0<:X_`030000003oool0oooo00@0oooo00<000000?ooo`3oool0703oool0
0240oooo00<000000?ooo`3oool0303oool3000005h0oooo00<0000002ini`0^O^L00`0^O^L00`00
0000?hO[03n7j`04000000H0AY7_00<0000005JIl@1FVO401@1FVO4010000000Hj7b06>QlP1SXO8:
000000@0Jj[f00<0000007N`mP1g/?H01`1g/?H00`000000P[Ge08:em@0808:em@040000002<^O@0
S;Wd08bim0D000000`2>]?000`000000UkO^09NgkP0909NgkP030000002N^^`0W[[/00X0W[[/00<0
00000:BljP2T_>X01@2T_>X400000080YKOV00<000000:Zii02Z^N@02`2Z^N@00`000000[k_R0:nk
hP040:nkhP8000001@2_]]h00`000000/kSL0;>hg00;0;>hg0030000002g^M/0]kWK008000002`2f
]=P00`000000^KKF0;VfeP050;VfeP800000102h/M<00`000000^k?A0;^cd@0=0;^cd@030000002m
/<d0_K3=00`0_K3=00D000000;nac02o/L`0_k7<0000000:0;j^b@0300000030[lP0`:o800@0`:o8
00<000000;n[aP2oZlH01@2oZlH00`000000`Jc50<6/a@040<6/a@0400000031[<D0`Jc5000000@0
_jW300<000000<:Z`P32Z/802P32Z/82000000l0`ZRo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0L0?ooo`008@3oool00`000000oooo0?ooo`090?ooo`<00000HP3oool2000000@0;WkW
00<0000003n7j`0oQn/00P0oQn/3000000D0AY7_00<0000005JIl@1FVO401@1FVO400`000000Hj7b
06>QlP0606>QlP040000001`Yo<0L:Oc072Wlad000002@2>]?000`000000UkO^09NgkP0909NgkP03
0000002N^^`0W[[/00X0W[[/00<000000:BljP2T_>X0100000070:FgiP030000002Z^N@0Z[WT00/0
Z[WT00<000000:nkhP2_^n800`0000080:nfgP030000002c^=`0/kSL00X0/kSL0`00000=0;Jdf003
0000002i]]H0^KKF00<0^KKF0P0000070;Rad`030000002k/m40^k?A00X0^k?A0P0000000`2j[ll0
00000;f`c@0<0;f`c@040000002o/L`00000000000/0_Zk900<000000<2_b030[lP00`30[lP00`00
0000_j_60;n[aP070;n[aP0300000031[<D0`Jc500@0`Jc50P0000060;nY``0300000032Z/80`Z[2
00P0`Z[200@000000<2W`@30Yl4000003@32Z;l2000000H0oooo00<000000?ooo`3oool0703oool0
0240oooo0`0000070?ooo`800000IP3oool300000080;WkW00<0000003n7j`0oQn/0100oQn/40000
00<0AY7_00<0000005JIl@1FVO401@1FVO400`000000Hj7b06>QlP0606>QlP030000001`Yo<0L:Oc
00H0L:Oc00<0000007^/lP1k[?801`1k[?800`000000QK3a08F`l@0808F`l@030000002>]?00S[C`
00T0S[C`00<0000009NgkP2G]nh02@2G]nh00`000000W[[/09jjk00809jjk0@00000302U]nH00`00
0000Z[WT0:Zii00:0:Zii0<000002`2_]]h00`000000/kSL0;>hg0080;>hg08000000P2b/mT00`00
0000][CH0;Jdf00<0;Jdf0050000002i]]H0^KKF0;VfeP0000002@2h/M<00`000000^k?A0;^cd@08
0;^cd@8000000`2j[ll00`000000_K3=0;f`c@0<0;f`c@030000002n[/T0_Zk900`0_Zk900<00000
0<2_b030[lP00P00000:0;n[aP0300000031[<D0`Jc500@0`Jc50P0000060;nY``0300000032Z/80
`Z[200L0`Z[200D000000<2W`@30Yl40`:O10000000<0<:X_`0400000031Y[h0`JJn000000D0oooo
00<000000?ooo`3oool0703oool00200oooo0P0000060?ooo`<00000J03oool00`000000>GkV03Un
iP020000000302ini`000000?hO[00D0?hO[00<0000004n@k@1?T>d01@00000605JIl@030000001S
XO80Hj7b00L0Hj7b00<00000072Wl`1`Yo<01P1`Yo<00`000000Njcb07^/lP0707^/lP0300000025
/?40QK3a00P0QK3a00<0000008jdl02>]?00202>]?000`000000UkO^09NgkP0:09NgkP040000002N
^^`0W[[/09jjk0H000000`2N]NP00`000000YKOV0:FgiP0:0:FgiP030000002Z^N@0Z[WT00L0Z[WT
0`0000020:Zdh0030000002_]]h0[kKN00X0[kKN00<000000;>hg02c^=`01@2c^=`2000000@0/[?I
00<000000;Jdf02f]=P0302f]=P010000000^KKF00000000000;0;Rad`030000002k/m40^k?A00H0
^k?A00<000000;Z_c`2j[ll0102j[ll00`000000_K3=0;f`c@090;f`c@<000003P2n[/T00`000000
`:o80000000=0;n[aP0300000031[<D0`Jc50080`Jc500@000000;nY``2oZL<000001@2oZL<00`00
0000`Z[20<:Z`P060<:Z`P0300000030Yl40`:O100<0`:O100<000000<:X_`32Z;l02032Z;l01@00
0000`JJn0<6V_P31Y[h0000000D0oooo00<000000?ooo`3oool0703oool00200oooo00<000000?oo
o`3oool00P3oool3000006`0oooo00@0000003UniP0iO^H0>GkV0`00000603n7j`030000001?T>d0
Ci3]00<0Ci3]1000000405JIl@030000001SXO80Hj7b00H0Hj7b00<00000072Wl`1`Yo<01`1`Yo<0
0`000000Njcb07^/lP0707^/lP0300000025/?40QK3a00P0QK3a00<0000008jdl02>]?00202>]?00
0`000000UkO^09NgkP0809NgkPD000002P2N]NP00`000000YKOV0:FgiP0:0:FgiP030000002Z^N@0
Z[WT00@0Z[WT0P0000050:Zdh0030000002_]]h0[kKN00/0[kKN00<000000;>hg02c^=`00P2c^=`2
000000L0/[?I00<000000;Jdf02f]=P02`2f]=P2000000d0^;7C00<000000;^cd@2k/m40102k/m42
000000L0^Zo?00<000000;f`c@2m/<d0202m/<d01@000000^jg;0;^]b`2k[L/0000000h0_Zk900<0
00000;n[aP2oZlH0302oZlH00`000000`Jc50<6/a@02000000<0_jW300<000000;nY``2oZL<0102o
ZL<00`000000`Z[20<:Z`P040<:Z`P0300000030Yl40`:O100@0`:O100<000000<:X_`32Z;l01`32
Z;l00`000000`JJn0<6V_P030<6V_P030000003oool0oooo0080oooo00<000000?ooo`3oool0703o
ool001D0oooo00D0omnL04P000000000000007Boo`060?ooo`030000003oool0000000800000L03o
ool00`000000>GkV03UniP0203UniP<00000100oQn/00`000000Ci3]04n@k@0504n@k@030000001M
Unh0000000<0000000<0EYWa0000001SXO801`1SXO800`000000L:Oc072Wl`06072Wl`030000001k
[?80Njcb00L0Njcb00<0000008F`l@25/?402@25/?400`000000S[C`08jdl00808jdl0040000002G
]nh0UkO^09NgkPH000000`2H/^X00`000000W[GX09jej00:09jej0030000002U]nH0YKOV00X0YKOV
00<000000:Zii02Z^N@00`0000080:Zdh0030000002_]]h0[kKN00X0[kKN00<000000;>hg02c^=`0
0P00000:0;:cf@030000002f]=P0][CH00P0][CH0P0000020;B`e0030000002h/M<0^;7C00/0^;7C
00@000000;^cd@2k/m40^k?A0P00000:0;Z_c`030000002m/<d0_K3=00D0_K3=0P0000040;^]b`03
0000002n[/T0_Zk900X0_Zk90`00000?0;n[aP8000001P2oZL<00`000000_jW30;nY``030;nY``03
00000032Z/80`Z[200<0`Z[200<000000<2W`@30Yl401@30Yl400`000000`ZRo0<:X_`060<:X_`03
00000031Y[h0`JJn00@0`JJn00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`00
5`3oool00`2oM000M;oo0?ooo`060?ooo`800000M03oool00`000000>GkV03UniP0303UniP@00000
0P0oQn/00`000000Ci3]04n@k@0504n@k@030000001MUnh0GIO^0080GIO^1`00000406>QlP030000
001`Yo<0L:Oc00H0L:Oc00<0000007^/lP1k[?801`1k[?800`000000QK3a08F`l@0908F`l@030000
002>]?00S[C`00@0S[C`1`00000:09RbjP030000002N]NP0W[GX00T0W[GX00<000000:FgiP2U]nH0
2P2U]nH3000000/0Z[CP00<000000:nfgP2_]]h02P2_]]h3000000d0/[?I00<000000;Jdf02f]=P0
1@2f]=P2000000@0];3D00<000000;Rad`2h/M<02`2h/M<010000000^k?A00000000000<0;Z_c`03
0000002m/<d0_K3=00<0_K3=0P0000070;^]b`030000002n[/T0_Zk900P0_Zk900D000000;bZa`2l
Z/L0_:[70000000>0;n[aP030000002oZL<0_jW300H0_jW300<000000;nY``2oZL<00`2oZL<01@00
0000`Z[20<:Z`P32Z/80000000T0`:O100<000000<:X_`32Z;l01032Z;l00`000000`JJn0<6V_P05
0<6V_P030000003oool0oooo00<0oooo00<000000?ooo`3oool06`3oool001L0oooo00<0_g@007Bo
o`3oool01`3oool00`000000oooo0?ooo`1b0?ooo`030000000iO^H0>GkV00@0>GkV00<0000004R7
j018QnP01000000704n@k@030000001MUnh0GIO^00@0GIO^00@0000006VNk`1YW^l0JIk_2P000004
072Wl`030000001k[?80Njcb00L0Njcb00<0000008F`l@25/?401025/?4;000000D0T:o[00<00000
09RbjP2H/^X02P2H/^X00`000000W[GX09jej00909jej0030000002U]nH0YKOV00D0YKOV10000002
0:FbhP030000002Z]>00Z[CP00X0Z[CP00<000000:nfgP2_]]h01P2_]]h300000080[[7K00<00000
0;:cf@2b/mT02`2b/mT00`000000][CH0;Jdf0030;Jdf08000001`2d/=@00`000000^;7C0;Rad`0;
0;Rad`030000002j[ll0^Zo?00d0^Zo?00D000000;f`c@2m/<d0_K3=000000090;^]b`030000002n
[/T0_Zk900L0_Zk900<000000;bZa`2lZ/L00P2lZ/L00`000000_j_60;n[aP0;0;n[aP800000202o
ZL<00`000000_jW30;nY``030;nY``0400000032Z/80`Z[2000000X0`:O100<000000<:X_`32Z;l0
0`32Z;l00`000000`JJn0<6V_P070<6V_P030000003oool0oooo0080oooo00<000000?ooo`3oool0
6`3oool001<0oooo00<0gia80000000000000`0000000`1d_ol0oooo0?ooo`060?ooo`800000L`3o
ool00`000000>GkV03UniP0403UniP0300000018QnP0B8OX0080B8OX0`00000504n@k@030000001M
Unh0GIO^00D0GIO^00<0000006VNk`1YW^l01P1YW^l010000000MJ?_07FSk`1eXnlE000000H0R:c]
00<00000092_j`2@[n/0202@[n/00`000000V;;Z09RbjP0909RbjP030000002N]NP0W[GX00X0W[GX
00<000000:FgiP2U]nH0100000060:FbhP030000002Z]>00Z[CP00/0Z[CP00<000000:nfgP2_]]h0
0`2_]]h2000000D0[[7K00<000000;:cf@2b/mT0302b/mT00`000000][CH0;Jdf002000000T0];3D
00<000000;Rad`2h/M<02@2h/M<2000000030;N^d0000000^Zo?00d0^Zo?00@000000;f`c@000000
00002`2k[L/00`000000_Zk90;j^b@040;j^b@8000001P2lZ/L00`000000_j_60;n[aP080;n[aP80
00000P2mZ<@00`000000_jW30;nY``060;nY``030000002oZL<0_jW300<0_jW30P00000<0<2W`@05
00000032Z;l0`ZRo0<:X_`0000002P31Y[h00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01/0oooo000C0?ooo`060?noM00007@0_ooo0?ooo`2oM000M;oo2`3oool00`000000oooo0?ooo`1a
0?ooo`800000100iO^H00`000000B8OX04R7j00404R7j0@000000`1?T>d00`000000GIO^05fGkP05
05fGkP030000001YW^l0JIk_00H0JIk_00<0000007FSk`1eXnl01P1eXnl00`000000OjS^07nXkP07
07nXkP0300000028[>d0R:c]00T0R:c]00<00000092_j`2@[n/0202@[n/00`000000V;;Z09RbjP09
09RbjP030000002N]NP0W[GX00P0W[GX1000000;0:FbhP030000002Z]>00Z[CP00X0Z[CP00<00000
0:nfgP2_]]h00`0000080:jaf`030000002b/mT0/[?I00/0/[?I0`00000<0;B`e0030000002h/M<0
^;7C00H0^;7C0P0000030;N^d0030000002j[ll0^Zo?00d0^Zo?00<000000;^]b`2k[L/02`2k[L/0
0`000000_Zk90;j^b@030;j^b@030000002lZ/L0_:[700H0_:[700<000000;n[aP2oZlH01`2oZlH0
0`000000_JS40;fXa0020;fXa0030000002oZL<0_jW300L0_jW300<000000;nY``2oZL<00P2oZL<0
0`000000`:O10<2W`@0;0<2W`@0400000032Z;l0`ZRo000000/0`JJn00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0K0?ooo`00503oool01@3OW4P007Bo0?ooo`2oM000M;oo00`0oooo00<0
00000?ooo`3oool0L@3oool400000080>GkV00<0000004R7j018QnP01018QnP00`000000EXkZ05J>
jP05000000L0GIO^00<0000006VNk`1YW^l01P1YW^l00`000000MJ?_07FSk`0607FSk`030000001o
Z>h0OjS^00L0OjS^00<0000008R/k@28[>d02@28[>d00`000000T:o[092_j`07092_j`030000002H
/^X0V;;Z00X0V;;Z00@0000009jej02N]NP0W[GX1P00000309n`i0030000002U/^80YK;R00T0YK;R
00<000000:Zdh02Z]>002P2Z]>03000000`0[[7K00<000000;:cf@2b/mT0202b/mT200000080/JoF
00<000000;B`e02d/=@02P2d/=@00`000000^;7C0;Rad`040;Rad`8000001P2g[]000`000000^Zo?
0;Z_c`0:0;Z_c`<000003P2k[L/01@000000_Zk90;j^b@2n[/T0000000X0_:[700<000000;n[aP2o
ZlH01@2oZlH00`000000_JS40;fXa0040;fXa0030000002oZL<0_jW300L0_jW300<000000;nY``2o
ZL<00P00000>0<2W`@8000003@31Y[h01@000000oooo0?ooo`3oool0000001d0oooo000E0?ooo`04
09a80018W=l0_g@007Boo`d0oooo00<000000?ooo`3oool0L@3oool00`000000@WkT049ni0040000
00H0B8OX00<0000005J>jP1FS^X00`1FS^X6000000<0GIO^00<0000006VNk`1YW^l01@1YW^l00`00
0000MJ?_07FSk`0707FSk`030000001oZ>h0OjS^00L0OjS^00<0000008R/k@28[>d02028[>d00`00
0000T:o[092_j`08092_j`030000002H/^X0V;;Z00P0V;;Z1@00000909n`i0030000002U/^80YK;R
00X0YK;R00<000000:Zdh02Z]>001P2Z]>0300000080ZK3M00<000000:jaf`2^/M/02`2^/M/00`00
0000/[?I0;:cf@050;:cf@800000102a[mH00`000000];3D0;B`e00;0;B`e0040000002h/M<0^;7C
0;Rad`8000002@2g[]000`000000^Zo?0;Z_c`080;Z_c`050000002hZl`0^:_<0;R[c00000003@2k
[L/010000000_Zk900000000000;0;bZa`030000002oZlH0_j_600@0_j_600<000000;fXa02mZ<@0
1@2mZ<@00`000000_jW30;nY``070;nY``<000000P2nY/800`000000`:O10<2W`@0;0<2W`@030000
0031Y[h0`JJn00`0`JJn00D000000?ooo`3oool0oooo0000000M0?ooo`005@3oool0103ogi`0B018
04Q8001d_ol>0?ooo`800000LP3oool00`000000@WkT049ni002049ni0<000001018QnP00`000000
EXkZ05J>jP0505J>jP040000001SUN/0HiG[06>Ej`L000001@1YW^l00`000000MJ?_07FSk`0607FS
k`030000001oZ>h0OjS^00P0OjS^00<0000008R/k@28[>d02028[>d00`000000T:o[092_j`08092_
j`040000002H/^X0V;;Z09RbjPH000000`2I[^D00`000000Wk3T09n`i00909n`i0030000002U/^80
YK;R00X0YK;R00<000000:Zdh02Z]>000`2Z]>02000000D0ZK3M00<000000:jaf`2^/M/02`2^/M/0
0`000000/[?I0;:cf@030;:cf@8000001`2a[mH00`000000];3D0;B`e00:0;B`e0040000002h/M<0
0000000000/0]jk@00<000000;Z_c`2j[ll01P2j[ll2000000@0^:_<00<000000;^]b`2k[L/0302k
[L/00`000000_:[70;bZa`0<0;bZa`030000002oZlH0_j_60080_j_600<000000;fXa02mZ<@01P2m
Z<@00`000000_jW30;nY``070;nY``8000000`2nY/800`000000`:O10<2W`@0:0<2W`@8000003`31
Y[h010000000oooo0?ooo`00000M0?ooo`005P3oool00`3o_g@0000007Boo`0@0?ooo`030000003o
ool0oooo06l0oooo00<00000049ni012O^@01012O^@400000080B8OX00<0000005J>jP1FS^X01@1F
S^X00`000000HiG[06>Ej`0506>Ej`030000001^Vn/0000000@0000000<0JIk_0000001eXnl01`1e
Xnl00`000000OjS^07nXkP0807nXkP0300000028[>d0R:c]00P0R:c]00<00000092_j`2@[n/0102@
[n/7000000T0VJkU00<0000009n`i02O/>@02P2O/>@00`000000YK;R0:FbhP090:FbhP030000002Z
]>00Z[CP00<00000202Y/=d00`000000[[7K0:jaf`0;0:jaf`030000002b/mT0/[?I008000002@2a
[mH00`000000];3D0;B`e00:0;B`e08000003P2g[]000`000000^Zo?0;Z_c`030;Z_c`8000001`2h
Zl`00`000000^jg;0;^]b`090;^]b`<000003P2lZ/L00`000000_j_60;n[aP02000000X0_JS400<0
00000;nY``2oZL<01@2oZL<010000000_ZK20;jV`P0000030;jV`P0300000030Yl40`:O100P0`:O1
00@000000;nU_`2oYKl000003P31Y[h01@000000oooo0?ooo`3oool0000001`0oooo000Z0?ooo`03
0000003oool0oooo06l0oooo00<00000049ni012O^@00`12O^@010000000D8KV0526iP1@Q^H40000
00L0EXkZ00<0000006>Ej`1SUN/0101SUN/00`000000KY_[06jKj`0406jKj`L00000101eXnl00`00
0000OjS^07nXkP0807nXkP0300000028[>d0R:c]00@0R:c]2P00000509:[i`030000002I[^D0VJkU
00T0VJkU00<0000009n`i02O/>@02P2O/>@00`000000YK;R0:FbhP080:FbhP<00000302Y/=d00`00
0000[[7K0:jaf`0:0:jaf`<00000302a[mH00`000000];3D0;B`e0070;B`e08000000P2c[=400`00
0000]jk@0;N^d00<0;N^d0050000002j[ll0^Zo?0;Z_c`0000002@2hZl`00`000000^jg;0;^]b`08
0;^]b`050000002jZLT0^ZW90;ZYb@0000003P2lZ/L2000000`0_JS400<000000;nY``2oZL<0102o
ZL<00`000000_ZK20;jV`P020;jV`P040000002nY/80_ZK2000000T0`:O100D000000;nU_`2oYKl0
_jFo0000000=0<6V_P8000000`3oool00`000000oooo0?ooo`0J0?ooo`00:`3oool00`000000oooo
0?ooo`1_0?ooo`0300000012O^@0@WkT00<0@WkT00<000000526iP1@Q^H00`1@Q^H3000000D0EXkZ
00<0000006>Ej`1SUN/01@1SUN/00`000000KY_[06jKj`0606jKj`040000001iWn/0NIo[07VOjaH0
00001@2:YnP00`000000TZ_W09:[i`0709:[i`030000002I[^D0VJkU00X0VJkU00<0000009n`i02O
/>@02@2O/>@00`000000YK;R0:FbhP050:FbhP<000000P2T[]h00`000000ZK3M0:V`g@0:0:V`g@03
0000002^/M/0[[7K00P0[[7K0P0000020:f]f0030000002a[mH0/JoF00X0/JoF00<000000;B`e02d
/=@01@2d/=@2000000@0/jcA00<000000;N^d02g[]00302g[]0010000000^Zo?00000000000;0;R[
c0030000002k[L/0^jg;00H0^jg;00<000000;ZYb@2jZLT00P2jZLT00`000000_:[70;bZa`0<0;bZ
a`030000002mZ<@0_JS400`0_JS400<000000;nY``2oZL<00P2oZL<00`000000_ZK20;jV`P030;jV
`P040000002nY/80_ZK2000000P0`:O100<000000;nU_`2oYKl00`2oYKl00`000000`JJn0<6V_P09
0<6V_P040000002oXk`0_j>l00000080oooo00<000000?ooo`3oool06P3oool002`0oooo0P00001`
0?ooo`8000001012O^@00`000000D8KV0526iP040526iP@000000`1FS^X00`000000HiG[06>Ej`05
06>Ej`030000001^Vn/0KY_[00H0KY_[00<0000007VOj`1iWn/01P1iWn/00`000000PZCZ08:TjP08
08:TjP030000002:YnP0RZOX00L0RZOX00<0000009:[i`2BZnL0202BZnL00`000000VJkU09V^i@0:
09V^i@030000002O/>@0Wk3T00T0Wk3T00<000000:FbhP2U/^80100000050:B^gP030000002Y/=d0
ZK3M00/0ZK3M00<000000:jaf`2^/M/01@2^/M/2000000@0[JgH00<000000;6_eP2a[mH02`2a[mH0
0`000000];3D0;B`e0020;B`e08000001`2c[=400`000000]jk@0;N^d00<0;N^d0030000002hZl`0
^:_<00/0^:_<00<000000;^]b`2k[L/0102k[L/2000000H0^ZW900<000000;bZa`2lZ/L02@2lZ/L3
000000h0_JS400<000000;nY``2oZL<00P0000070;jV`P040000002nY/80_ZK2000000H0`:O100<0
00000;nU_`2oYKl0102oYKl00`000000`JJn0<6V_P080<6V_P050000002oXk`0_j>l0;nS_0000000
0P3oool00`000000oooo0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1^0?ooo`<000000`12
O^@00`000000D8KV0526iP030526iP040000001MS>L0GHcW05f<i`D000001`1SUN/00`000000KY_[
06jKj`0606jKj`030000001iWn/0NIo[00H0NIo[00<0000008:TjP22Y>X02022Y>X00`000000RZOX
08ZWj00708ZWj0030000002BZnL0TZ_W00P0TZ_W00<0000009V^i@2I[^D02@2I[^D00`000000Wk3T
09n`i00809n`i0@000002P2T[]h00`000000ZK3M0:V`g@0;0:V`g@030000002^/M/0[[7K0080[[7K
0P0000070:f]f0030000002a[mH0/JoF00X0/JoF00<000000;B`e02d/=@00P00000:0;>/d@030000
002g[]00]jk@00T0]jk@0`00000>0;R[c0030000002k[L/0^jg;0080^jg;00<000000;ZYb@2jZLT0
1P2jZLT00`000000_:[70;bZa`080;bZa`050000002kYlD0^jO50;^Wa@0000003P2mZ<@2000000X0
_ZK200<000000;jV`P0000001@30Yl400`000000_jFo0;nU_`050;nU_`0300000031Y[h0`JJn00L0
`JJn00<000000;nS_02oXk`00`2oXk`00`000000oooo0000000L0?ooo`00;`3oool00`000000oooo
0?ooo`1]0?ooo`030000001:ON40BWgQ0080000000<0@WkT0000001@Q^H01@1@Q^H00`000000GHcW
05f<i`0405f<i`@00000101SUN/00`000000KY_[06jKj`0606jKj`030000001iWn/0NIo[00L0NIo[
00<0000008:TjP22Y>X02022Y>X00`000000RZOX08ZWj00708ZWj0030000002BZnL0TZ_W00P0TZ_W
00<0000009V^i@2I[^D02@2I[^D010000000Wk3T09n`i02O/>@6000000<0WjcP00<000000:B^gP2T
[]h02@2T[]h00`000000ZK3M0:V`g@0:0:V`g@030000002^/M/0[[7K008000002P2][MP00`000000
/JoF0;6_eP0:0;6_eP800000302c[=400`000000]jk@0;N^d0070;N^d08000000`2eZ/h00`000000
^:_<0;R[c00;0;R[c0050000002k[L/0^jg;0;^]b`0000002P2jZLT00`000000_:[70;bZa`060;bZ
a`030000002kYlD0^jO50080^jO500<000000;fXa02mZ<@0302mZ<@00`000000_ZK20;jV`P090;jV
`P040000002nY/80_ZK2000000<0`:O100<000000;nU_`2oYKl01`2oYKl00`000000`JJn0<6V_P04
0<6V_P8000001P2oXk`00`000000oooo0000000L0?ooo`00<03oool00`000000oooo0?ooo`1]0?oo
o`040000001:ON40BWgQ04Ymh@<000001P1@Q^H00`000000GHcW05f<i`0505f<i`030000001XT^L0
000000<0000000<0HiG[0000001^Vn/01`1^Vn/00`000000NIo[07VOj`0607VOj`0300000022Y>X0
PZCZ00P0PZCZ00<0000008ZWj02:YnP0202:YnP00`000000TZ_W09:[i`0709:[i`030000002I[^D0
VJkU00P0VJkU1@00000909n/h0030000002T[]h0Y:kN00X0Y:kN00<000000:V`g@2Y/=d02@2Y/=d3
000000`0[JgH00<000000;6_eP2a[mH0202a[mH2000000030;2[d`000000/jcA00`0/jcA00<00000
0;N^d02g[]00102g[]02000000D0]J[>00<000000;R[c02hZl`0302hZl`3000000/0^ZW900<00000
0;bZa`2lZ/L0102lZ/L2000000H0^jO500<000000;fXa02mZ<@02P2mZ<@2000000`0_ZK200<00000
0;jV`P0000000P30Yl400`000000_jFo0;nU_`080;nU_`0300000031Y[h0`JJn00<0`JJn00<00000
0;nS_02oXk`01P2oXk`00`000000oooo0000000L0?ooo`00<@3oool2000006h0oooo00<0000004Ym
h@1:ON400P1:ON43000000D0D8KV00<0000005f<i`1MS>L0101MS>L00`000000J9;W06RBi`0306RB
i`L00000101^Vn/00`000000NIo[07VOj`0607VOj`0300000022Y>X0PZCZ00P0PZCZ00<0000008ZW
j02:YnP01`2:YnP00`000000TZ_W09:[i`0809:[i`040000002I[^D0VJkU09V^i@H000000`2IZN80
0`000000WjcP09n/h00909n/h0030000002T[]h0Y:kN00T0Y:kN00<000000:V`g@2Y/=d01@2Y/=d4
00000080ZJcI00<000000:f]f02][MP02`2][MP00`000000/JoF0;6_eP050;6_eP8000000`2`Zm<0
0`000000/jcA0;>/d@0<0;>/d@040000002g[]00]jk@0;N^d0800000202eZ/h00`000000^:_<0;R[
c00;0;R[c0030000002jZLT0^ZW900`0^ZW900<000000;bZa`2lZ/L00P2lZ/L00`000000^jO50;^W
a@060;^Wa@030000002mZ<@0_JS400P0_JS40P0000020;bU``030000002nY/80_ZK200X0_ZK200@0
00000;jV`P0000000000302oYKl01@000000`JJn0<6V_P31Y[h0000000X0_j>l0P00000L0?ooo`00
<`3oool00`000000oooo0?ooo`1[0?ooo`030000001:ON40BWgQ00@0BWgQ100000020526iP030000
001MS>L0GHcW00D0GHcW00<0000006RBi`1XT^L01@1XT^L010000000LYSW07:Hi`1bV>L:000000@0
NIo[00<0000008:TjP22Y>X02022Y>X00`000000RZOX08ZWj00708ZWj0030000002BZnL0TZ_W00@0
TZ_W1`00000909VYhP030000002O[>00WjcP00T0WjcP00<000000:B^gP2T[]h02P2T[]h00`000000
ZK3M0:V`g@04000000H0ZJcI00<000000:f]f02][MP0302][MP00`000000/JoF0;6_eP020;6_eP80
00001P2`Zm<00`000000/jcA0;>/d@0;0;>/d@040000002g[]000000000000X0]J[>00<000000;R[
c02hZl`02@2hZl`3000000h0^ZW900D000000;bZa`2lZ/L0_:[7000000090;^Wa@030000002mZ<@0
_JS400L0_JS400<000000;bU``2lYL<00P2lYL<00`000000_ZK20;jV`P0;0;jV`P8000003@2oYKl0
10000000`JJn0<6V_P00000;0;nS_0030000003oool0000001/0oooo000d0?ooo`030000003oool0
oooo06/0oooo00<0000004Ymh@1:ON400`1:ON4010000000EhCR05N4hP1GQ>84000000L0GHcW00<0
000006RBi`1XT^L0101XT^L00`000000LYSW07:Hi`0707:Hi`040000001lW>H0O9cV07bLiR000000
1@2CY^<00`000000VJWR09VYhP0909VYhP030000002O[>00WjcP00T0WjcP00<000000:B^gP2T[]h0
2@2T[]h3000000/0ZJcI00<000000:f]f02][MP02`2][MP00`000000/JoF0;6_eP02000000P0/:_C
00<000000;>/d@2c[=40302c[=400`000000]J[>0;FZcP0;0;FZcP030000002hZl`0^:_<00L0^:_<
00D000000;NXbP2gZ<X0]jS:0000000>0;ZYb@<000002`2kYlD00`000000_JS40;fXa0050;fXa003
0000002lYL<0_:G300@0_:G300<000000;jV`P2nY/802P2nY/82000000h0_jFo0P00000<0;nS_003
0000003oool0000001/0oooo000e0?ooo`030000003oool0oooo06/0oooo00<0000004Ymh@1:ON40
0`1:ON400`000000EhCR05N4hP0305N4hP<000001P1MS>L00`000000J9;W06RBi`0406RBi`030000
001bV>L0LYSW00H0LYSW00<0000007bLiP1lW>H01`1lW>H00`000000Q:3U08BPi@0808BPi@030000
002<Xn@0S:?T00L0S:?T00<0000009>Vh`2CY^<01`2CY^<00`000000VJWR09VYhP0:09VYhP030000
002O[>00WjcP00T0WjcP00<000000:B^gP2T[]h0102T[]h400000080Y:WK00<000000:V/f@2Y[=T0
2P2Y[=T00`000000[JgH0:f]f00:0:f]f0<000002`2`Zm<00`000000/jcA0;>/d@090;>/d@<00000
3@2eZ/h00`000000^:_<0;R[c0050;R[c0800000102gZ<X00`000000^ZW90;ZYb@0<0;ZYb@030000
002kYlD0^jO500/0^jO500<000000;fXa02mZ<@0102mZ<@00`000000_:G30;bU``050;bU``030000
002nY/80_ZK200P0_ZK20P0000000`2mY<0000000000000=0;nU_`030000002oXk`0_j>l00`0_j>l
0P00000K0?ooo`00=P3oool00`000000oooo0?ooo`1Z0?ooo`030000001:ON40BWgQ00@0BWgQ00<0
000005N4hP1GQ>80101GQ>84000000<0GHcW00<0000006RBi`1XT^L01@1XT^L00`000000LYSW07:H
i`0607:Hi`030000001lW>H0O9cV00H0O9cV00<0000008BPi@24X>D02024X>D00`000000S:?T08bS
i00708bSi0030000002CY^<0TjKS00P0TjKS00<0000009VYhP2IZN802P2IZN800`000000WjcP09n/
h00809n/h0030000002T[]h0Y:kN00@000001P2TZM/00`000000ZJcI0:V/f@0:0:V/f@030000002]
[MP0[JgH00P0[JgH0P0000000`2/ZM@000000;2[d`0<0;2[d`030000002c[=40/jcA00H0/jcA0P00
00030;:Yc`030000002eZ/h0]J[>00/0]J[>00<000000;R[c02hZl`00P2hZl`2000000L0]jS:00<0
00000;ZYb@2jZLT02@2jZLT3000000h0^jO500<000000;fXa02mZ<@00P2mZ<@00`000000_:G30;bU
``060;bU``030000002nY/80_ZK200L0_ZK200<000000;fT`02mY<000P2mY<000`000000_jFo0;nU
_`0:0;nU_`8000003P2oXk`2000001/0oooo000g0?ooo`800000J`3oool2000000D0BWgQ00<00000
05N4hP1GQ>800`1GQ>8010000000HX[S06::h`1RR^<5000000L0J9;W00<0000007:Hi`1bV>L01P1b
V>L00`000000O9cV07bLiP0607bLiP0300000024X>D0Q:3U00P0Q:3U00<0000008bSi02<Xn@01`2<
Xn@00`000000TjKS09>Vh`0809>Vh`030000002IZN80VJWR00T0VJWR00<0000009n/h02O[>001`2O
[>04000000/0Y:WK00<000000:V/f@2Y[=T02P2Y[=T00`000000[JgH0:f]f0050:f]f0800000102/
ZM@00`000000/:_C0;2[d`0:0;2[d`030000002c[=40/jcA00@0/jcA0P0000050;:Yc`030000002e
Z/h0]J[>00/0]J[>00D000000;R[c02hZl`0^:_<000000090;NXbP030000002jZLT0^ZW900P0^ZW9
00D000000;RVaP2hY/H0^:K60000000=0;^Wa@030000002mZ<@0_JS4008000002P2lYL<00`000000
_ZK20;jV`P050;jV`P030000002mY<00_JC000@0_JC000<000000;nU_`2oYKl0202oYKl010000000
_J:m0;fR_@00000>0;nS_0030000003oool0oooo01T0oooo000i0?ooo`030000003oool0oooo06T0
oooo1000000204Ymh@030000001GQ>80EhCR00@0EhCR00<0000006::h`1RR^<0101RR^<4000000@0
J9;W00<0000007:Hi`1bV>L01`1bV>L00`000000O9cV07bLiP0607bLiP0300000024X>D0Q:3U00L0
Q:3U00<0000008bSi02<Xn@0202<Xn@00`000000TjKS09>Vh`0809>Vh`030000002IZN80VJWR00T0
VJWR00@0000009n/h02O[>00WjcP1@00000309nWg0030000002TZM/0Y:WK00X0Y:WK00<000000:V/
f@2Y[=T02P2Y[=T00`000000[JgH0:f]f0020:f]f08000001P2/ZM@00`000000/:_C0;2[d`0;0;2[
d`040000002c[=40/jcA0;>/d@800000202bZLl00`000000]J[>0;FZcP0;0;FZcP<000002`2gZ<X0
0`000000^ZW90;ZYb@060;ZYb@030000002hY/H0^:K60080^:K600<000000;^Wa@2kYlD0302kYlD2
000000`0_:G300<000000;jV`P2nY/80102nY/800`000000_JC00;fT`0050;fT`0030000002oYKl0
_jFo00L0_jFo00D000000;fR_@2mX[d0_J:m0000000>0;nS_0030000003oool0oooo01T0oooo000j
0?ooo`030000003oool0oooo06P0oooo00@00000055lgP1AO=h0DGcN1000000605N4hP030000001R
R^<0HX[S00D0HX[S00<0000006f@h`0000000`0000000`1XT^L0000007:Hi`0707:Hi`030000001l
W>H0O9cV00L0O9cV00<0000008BPi@24X>D01`24X>D00`000000S:?T08bSi00808bSi0030000002C
Y^<0TjKS00L0TjKS00<0000009VYhP2IZN80202IZN85000000P0WjOL00<000000:BYf`2TZM/02P2T
ZM/00`000000ZJcI0:V/f@0:0:V/f@030000002][MP0[JgH008000002@2/ZM@00`000000/:_C0;2[
d`0:0;2[d`040000002c[=400000000000X0/ZW?00<000000;FZcP2eZ/h02`2eZ/h00`000000]jS:
0;NXbP0;0;NXbP030000002jZLT0^ZW900@0^ZW90P0000060;RVaP030000002kYlD0^jO500/0^jO5
00<000000;bU``2lYL<0302lYL<00`000000_ZK20;jV`P020;jV`P030000002mY<00_JC000H0_JC0
0P0000070;nU_`030000002mX[d0_J:m00<0_J:m00<000000;nS_02oXk`02P2oXk`2000001/0oooo
000k0?ooo`030000003oool0oooo06P0oooo00<00000055lgP1AO=h00`1AO=h3000000D0EhCR00<0
000006::h`1RR^<0101RR^<00`000000KI3S06f@h`0306f@h`L00000101bV>L00`000000O9cV07bL
iP0607bLiP0300000024X>D0Q:3U00P0Q:3U00<0000008bSi02<Xn@01`2<Xn@00`000000TjKS09>V
h`0809>Vh`040000002IZN80VJWR09VYhPH000000`2JYMd00`000000WjOL09nWg00809nWg0030000
002TZM/0Y:WK00X0Y:WK00<000000:V/f@2Y[=T02@2Y[=T3000000/0[:WD00<000000;2[d`2`Zm<0
2P2`Zm<2000000d0/ZW?00<000000;FZcP2eZ/h0202eZ/h3000000h0]jS:00<000000;ZYb@2jZLT0
0P2jZLT00`000000^:K60;RVaP060;RVaP030000002kYlD0^jO500T0^jO50`00000>0;bU``030000
002nY/80_ZK2008000002P2mY<02000000D0_jFo00<000000;fR_@2mX[d0102mX[d00`000000_j>l
0;nS_0090;nS_0040000003oool0oooo000001X0oooo000l0?ooo`800000J@3oool00`000000DGcN
055lgP04055lgP@000000P1GQ>800`000000HX[S06::h`0506::h`030000001]T><0KI3S00D0KI3S
00@0000007JDh`1fU><0MYCS2P00000407bLiP0300000024X>D0Q:3U00L0Q:3U00<0000008bSi02<
Xn@0202<Xn@00`000000TjKS09>Vh`0409>Vh`L000002@2JYMd00`000000WjOL09nWg00909nWg003
0000002TZM/0Y:WK00X0Y:WK00<000000:V/f@2Y[=T0102Y[=T400000080Z:SF00<000000:bYe02/
ZM@02P2/ZM@00`000000/:_C0;2[d`070;2[d`80000000<0[jO@0000002bZLl0302bZLl00`000000
]J[>0;FZcP060;FZcP8000000`2dYl/00`000000]jS:0;NXbP0;0;NXbP050000002jZLT0^ZW90;ZY
b@0000002@2hY/H00`000000^jO50;^Wa@080;^Wa@050000002jY<@0^ZC40;ZTa00000003P2lYL<2
000000`0_JC00P0000040;nU_`030000002mX[d0_J:m00H0_J:m00<000000;nS_02oXk`01`2oXk`0
1@000000oooo0?ooo`3oool0000001X0oooo000n0?ooo`030000003oool0oooo06L0oooo00<00000
055lgP1AO=h00`1AO=h010000000G8?O05b3g`1LPml4000000L0HX[S00<0000006f@h`1]T><0101]
T><00`000000MYCS07JDh`0707JDh`040000001nVN80OYWR07jIhR0000001@2DXml00`000000VZGM
09ZUg@0909ZUg@030000002OYm`0WjOL00P0WjOL00<000000:BYf`2TZM/02P2TZM/00`000000ZJcI
0:V/f@04000000H0Z:SF00<000000:bYe02/ZM@02P2/ZM@00`000000/:_C0;2[d`050;2[d`800000
102_Ym000`000000/ZW?0;:Yc`0;0;:Yc`030000002eZ/h0]J[>00<0]J[>0P0000050;BWb`030000
002gZ<X0]jS:00`0]jS:0`00000;0;RVaP030000002kYlD0^jO500H0^jO500<000000;ZTa02jY<@0
0P2jY<@00`000000_:G30;bU``0<0;bU``030000002mY<00_JC000`0_JC00P0000020;nU_`030000
002mX[d0_J:m00L0_J:m00<000000;nS_02oXk`01P2oXk`00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01P0oooo000o0?ooo`030000003oool0oooo06H0oooo00<00000055lgP1AO=h0101A
O=h00`000000G8?O05b3g`0305b3g`<000001P1RR^<00`000000KI3S06f@h`0406f@h`030000001f
U><0MYCS00H0MYCS00<0000007jIhP1nVN801`1nVN800`000000QYcQ08JLh@0708JLh@030000002=
X>00SJ3P00P0SJ3P00<0000009BSg`2DXml01`2DXml00`000000VZGM09ZUg@0909ZUg@030000002O
Ym`0WjOL00T0WjOL00<000000:BYf`2TZM/02@2TZM/3000000/0Z:SF00<000000:bYe02/ZM@02P2/
ZM@00`000000/:_C0;2[d`020;2[d`8000001P2_Ym000`000000/ZW?0;:Yc`0;0;:Yc`040000002e
Z/h0]J[>0;FZcP800000202dYl/00`000000]jS:0;NXbP0;0;NXbP030000002hY/H0^:K600/0^:K6
00<000000;^Wa@2kYlD0102kYlD2000000H0^ZC400<000000;bU``2lYL<02P2lYL<2000000h0_JC0
00@000000;nU_`00000000002P2mX[d00`000000_j>l0;nS_0050;nS_0030000003oool0oooo00<0
oooo00<000000?ooo`3oool0603oool00400oooo00<000000?ooo`3oool0IP3oool00`000000DGcN
055lgP04055lgP030000001LPml0G8?O00@0G8?O1000000306::h`030000001]T><0KI3S00D0KI3S
00<0000007JDh`1fU><01P1fU><00`000000OYWR07jIhP0607jIhP0300000026W>40QYcQ00L0QYcQ
00<0000008fPh02=X>00202=X>000`000000U:?O09BSg`0809BSg`030000002JYMd0VZGM00T0VZGM
00<0000009nWg02OYm`02@2OYm`00`000000Y:WK0:BYf`040:BYf`@0000000<0Y:KG0000002XZ=H0
2`2XZ=H00`000000[:WD0:bYe00:0:bYe0030000002`Zm<0/:_C008000002@2_Ym000`000000/ZW?
0;:Yc`0;0;:Yc`<000002P2dYl/00`000000]jS:0;NXbP090;NXbP80000000<0]ZG80000002hY/H0
302hY/H00`000000^jO50;^Wa@020;^Wa@030000002jY<@0^ZC400H0^ZC400<000000;bU``2lYL<0
202lYL<200000080^Z?100<000000;fT`02mY<00302mY<03000000/0_J:m00<000000;nS_02oXk`0
102oXk`00`000000oooo0?ooo`030?ooo`030000003oool0oooo01P0oooo00110?ooo`800000I`3o
ool2000000@0DGcN00<0000005b3g`1LPml0101LPml010000000IhSO06N8g`1WR=l5000000L0KI3S
00<0000007JDh`1fU><01P1fU><00`000000OYWR07jIhP0607jIhP0300000026W>40QYcQ00L0QYcQ
00<0000008fPh02=X>00202=X>000`000000U:?O09BSg`0809BSg`030000002JYMd0VZGM00P0VZGM
00<0000009nWg02OYm`02@2OYm`00`000000Y:WK0:BYf`04000000H0Y:KG00<000000:RXeP2XZ=H0
2P2XZ=H00`000000[:WD0:bYe0090:bYe0<000002`2_Ym000`000000/ZW?0;:Yc`0:0;:Yc`800000
3@2dYl/00`000000]jS:0;NXbP060;NXbP8000000`2fYLP00`000000^:K60;RVaP0;0;RVaP050000
002kYlD0^jO50;^Wa@0000002@2jY<@00`000000_:G30;bU``070;bU``030000002jXl40^Z?10080
^Z?100<000000;fT`02mY<00302mY<000`000000_J:m0000000;0;fR_@030000002oXk`0_j>l00<0
_j>l00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0H0?ooo`00@`3oool00`000000oooo
0?ooo`1U0?ooo`<000000`1AO=h00`000000G8?O05b3g`0405b3g`030000001WR=l0IhSO00@0IhSO
1000000406f@h`030000001fU><0MYCS00H0MYCS00<0000007jIhP1nVN801`1nVN800`000000QYcQ
08JLh@0708JLh@030000002=X>00SJ3P00L0SJ3P00<0000009BSg`2DXml0202DXml00`000000VZGM
09ZUg@0909ZUg@030000002OYm`0WjOL00L0WjOL1000000:0:BVe`030000002XZ=H0Z:SF00X0Z:SF
00<000000:bYe02/ZM@01P2/ZM@3000000030:^Vd@000000[jO@00`0[jO@00<000000;:Yc`2bZLl0
1`2bZLl200000080/JG<00<000000;BWb`2dYl/02P2dYl/00`000000]jS:0;NXbP040;NXbP800000
1P2fYLP00`000000^:K60;RVaP0;0;RVaP<000002`2jY<@00`000000_:G30;bU``050;bU``030000
002jXl40^Z?100@0^Z?100<000000;fT`02mY<002P2mY<0200000080_J:m00<000000;fR_@2mX[d0
2@2mX[d01@000000_j>l0;nS_02oXk`0000000L0oooo00<000000?ooo`3oool0603oool004@0oooo
00<000000?ooo`3oool0I03oool00`000000Eg_K05Mkf`0200000080DGcN00<0000005b3g`1LPml0
101LPml00`000000IhSO06N8g`0506N8g`030000001`SMl0000000<0000000<0KI3S0000001fU><0
1`1fU><00`000000OYWR07jIhP0607jIhP0300000026W>40QYcQ00L0QYcQ00<0000008fPh02=X>00
202=X>000`000000U:?O09BSg`0809BSg`030000002JYMd0VZGM00P0VZGM00@0000009nWg02OYm`0
WjOL1P00000309nTf@030000002TY]L0Y:KG00T0Y:KG00<000000:RXeP2XZ=H02P2XZ=H00`000000
[:WD0:bYe0030:bYe08000001@2[Y]400`000000[jO@0:nWd00:0:nWd0030000002bZLl0/ZW?00D0
/ZW?0P0000040;6Uc0030000002dYl/0]:O;00/0]:O;00@000000;NXbP2gZ<X0]jS:0P0000080;JU
b0030000002hY/H0^:K600/0^:K600<000000;ZTa02jY<@02`2jY<@00`000000_:G30;bU``040;bU
``030000002jXl40^Z?100D0^Z?100<000000;fT`02mY<002@2mY<0010000000^j6n0;^Q_P000002
0;fR_@030000002mX[d0_J:m00P0_J:m00@000000;nS_02oXk`000002@3oool00`000000oooo0?oo
o`0G0?ooo`00A@3oool00`000000oooo0?ooo`1T0?ooo`040000001GNm/0Eg_K05Mkf`<000001P1L
Pml00`000000IhSO06N8g`0506N8g`030000001`SMl0L8gO00<0L8gO1@00000607JDh`030000001n
VN80OYWR00H0OYWR00<0000008JLh@26W>401`26W>400`000000SJ3P08fPh00708fPh0030000002D
Xml0U:?O00T0U:?O00<0000009ZUg@2JYMd01P2JYMd5000000T0WjCI00<000000:BVe`2TY]L02@2T
Y]L00`000000Z:SF0:RXeP0:0:RXeP030000002/ZM@0[:WD00<000001`2[Y]400`000000[jO@0:nW
d00;0:nWd0030000002bZLl0/ZW?0080/ZW?0P0000070;6Uc0030000002dYl/0]:O;00X0]:O;00@0
00000;NXbP00000000002`2fYLP00`000000^:K60;RVaP080;RVaP<000003P2jY<@00`000000_:G3
0;bU``020;bU``030000002jXl40^Z?100H0^Z?100<000000;fT`02mY<00202mY<001@000000^j6n
0;^Q_P2kXKh0000000<0_J:m00<000000;fR_@2mX[d0202mX[d2000000X0oooo00<000000?ooo`3o
ool05`3oool004H0oooo0P00001T0?ooo`030000001GNm/0Eg_K00<0Eg_K0`00000505b3g`030000
001WR=l0IhSO00D0IhSO00<00000072=g`1`SMl01@1`SMl00`000000NI;O000000040000000307JD
h`000000OYWR00P0OYWR00<0000008JLh@26W>401`26W>400`000000SJ3P08fPh00708fPh0030000
002DXml0U:?O00P0U:?O00@0000009ZUg@2JYMd0VZGM1@00000309ZRfP030000002OY=T0WjCI00T0
WjCI00<000000:BVe`2TY]L02@2TY]L00`000000Z:SF0:RXeP090:RXeP<000002`2[Y]400`000000
[jO@0:nWd00:0:nWd0030000002bZLl0/ZW?008000002@2aYL`00`000000]:O;0;BWb`0;0;BWb`03
0000002fYLP0]ZG800/0]ZG800<000000;RVaP2hY/H01`2hY/H01@000000]j?40;NSa02gXl@00000
00d0^ZC400<000000;bU``2lYL<00P00000:0;ZS`@030000002mY<00_JC000H0_JC000<000000;^Q
_P2kXKh00`2kXKh010000000_J:m0;fR_@00000:0;fR_@030000003oool0oooo00T0oooo00<00000
0?ooo`3oool05`3oool004P0oooo00<000000?ooo`3oool0HP3oool00`000000Eg_K05Mkf`0405Mk
f`@000000`1LPml00`000000IhSO06N8g`0406N8g`030000001`SMl0L8gO00D0L8gO00<0000007VB
g`1iT]l0101iT]l7000000@0OYWR00<0000008JLh@26W>401`26W>400`000000SJ3P08fPh00708fP
h0030000002DXml0U:?O00@0U:?O2000000809ZRfP030000002OY=T0WjCI00X0WjCI00<000000:BV
e`2TY]L0202TY]L00`000000Z:SF0:RXeP060:RXeP<000000P2WY=<00`000000ZjKA0:^Vd@090:^V
d@030000002_Ym00[jO@00X0[jO@0`00000<0;6Uc0030000002dYl/0]:O;00P0]:O;0`00000>0;JU
b0030000002hY/H0^:K600D0^:K600<000000;NSa02gXl@00P2gXl@00`000000^ZC40;ZTa00<0;ZT
a0800000302jXl400`000000_JC00;fT`0040;fT`08000001P2kXKh01@000000_J:m0;fR_@2mX[d0
000000P0_J:m00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0G0?ooo`00B@3oool00`00
0000oooo0?ooo`1Q0?ooo`030000001GNm/0Eg_K00@0Eg_K00@000000661g01QPM`0HH7L10000007
06N8g`030000001`SMl0L8gO00D0L8gO00<0000007VBg`1iT]l01P1iT]l010000000PIKN086FgP21
U]hO000000H0U9oK00<0000009ZRfP2JX]X0202JX]X00`000000WjCI09nTf@0909nTf@030000002T
Y]L0Y:KG00T0Y:KG00<000000:RXeP2XZ=H00`2XZ=H2000000D0YjCC00<000000:^Vd@2[Y]402P2[
Y]400`000000[jO@0:nWd0070:nWd08000000P2^Y<d00`000000/JG<0;6Uc00;0;6Uc0030000002d
Yl/0]:O;00D0]:O;0P0000030;>Tb@030000002fYLP0]ZG800/0]ZG800<000000;RVaP2hY/H00`2h
Y/H2000000H0]j?400<000000;ZTa02jY<@02`2jY<@00`000000^Z?10;ZS`@0;0;ZS`@030000002m
Y<00_JC000<0_JC000<000000;^Q_P2kXKh01P2kXKh00`000000_J:m0;fR_@020;fR_@030000002m
X[d0_J:m00<0_J:m0P00000=0?ooo`030000003oool0oooo01L0oooo001:0?ooo`030000003oool0
oooo0640oooo00<0000005Mkf`1GNm/0101GNm/00`000000HH7L0661g0030661g0<000001@1WR=l0
0`000000L8gO072=g`06072=g`030000001iT]l0NI;O00D0NI;O00<00000086FgP21U]h01`21U]h0
0`000000R9WM08RIg@0708RIg@030000002>W=`0SYcL00L0SYcL00<0000009BOf`2DWm/0202DWm/0
0`000000VZ;J09ZRfP0809ZRfP030000002OY=T0WjCI00X0WjCI00<000000:BVe`2TY]L0202TY]L0
0`000000Z:SF0:RXeP03000000P0YjCC00<000000:^Vd@2[Y]402@2[Y]400`000000[jO@0:nWd005
0:nWd0800000102^Y<d00`000000/JG<0;6Uc00;0;6Uc0030000002dYl/0]:O;00@0]:O;00<00000
0;>Tb@2cY<T00`2cY<T00`000000]ZG80;JUb00<0;JUb0050000002hY/H0^:K60;RVaP000000202g
Xl@00`000000^ZC40;ZTa00:0;ZTa08000003P2jXl401@000000_JC00;fT`02mY<00000000X0^j6n
00<000000;fR_@2mX[d00P2mX[d01@000000_J:m0;fR_@2mX[d0000000l0oooo00<000000?ooo`3o
ool05`3oool004/0oooo0P00001Q0?ooo`030000001GNm/0Eg_K00@0Eg_K00<000000661g01QPM`0
1@1QPM`4000000<0IhSO00<00000072=g`1`SMl01@1`SMl00`000000NI;O07VBg`0607VBg`030000
0021U]h0PIKN00H0PIKN00<0000008RIg@28VMd01`28VMd00`000000SYcL08jLg00708jLg0030000
002DWm/0U9oK00T0U9oK00<0000009ZRfP2JX]X0202JX]X00`000000WjCI09nTf@0:09nTf@030000
002TY]L0Y:KG00H0Y:KG1000000;0:NTd`030000002[Y]40ZjKA00X0ZjKA00<000000:nWd02_Ym00
0P2_Ym02000000L0[ZC=00<000000;6Uc02aYL`02`2aYL`010000000]:O;0;BWb`2dYl/2000000L0
/jC900<000000;JUb02fYLP02`2fYLP010000000^:K600000000000:0;NSa0030000002jY<@0^ZC4
00L0^ZC40P0000020;RR`P030000002jXl40^Z?100/0^Z?100@000000;fT`02mY<0000002`2kXKh0
0`000000_J:m0;fR_@020;fR_@040000002mX[d0_J:m00000100oooo00<000000?ooo`3oool05`3o
ool004d0oooo00<000000?ooo`3oool0G`3oool2000000D0Eg_K00<000000661g01QPM`0101QPM`0
10000000JhKL06^6g01[Q]`4000000P0L8gO00<0000007VBg`1iT]l01P1iT]l00`000000PIKN086F
gP06086FgP0300000028VMd0R9WM00L0R9WM00<0000008jLg02>W=`01`2>W=`00`000000U9oK09BO
f`0909BOf`030000002JX]X0VZ;J00P0VZ;J00<0000009nTf@2OY=T02@2OY=T010000000Y:KG0:BV
e`2TY]L5000000<0Xj;D00<000000:NTd`2WY=<02P2WY=<00`000000ZjKA0:^Vd@090:^Vd@030000
002_Ym00[jO@008000002@2^Y<d00`000000/JG<0;6Uc00;0;6Uc0040000002dYl/00000000000T0
/jC900<000000;JUb02fYLP0302fYLP00`000000]j?40;NSa00:0;NSa0030000002jY<@0^ZC400H0
^ZC400<000000;RR`P2hX/800P2hX/800`000000^Z?10;ZS`@0<0;ZS`@800000302kXKh00`000000
_J:m0;fR_@030;fR_@8000004@3oool00`000000oooo0?ooo`0G0?ooo`00CP3oool00`000000oooo
0?ooo`1O0?ooo`<000000`1GNm/00`000000HH7L0661g0050661g0030000001[Q]`0JhKL00<0JhKL
10000006072=g`030000001iT]l0NI;O00D0NI;O00<00000086FgP21U]h01`21U]h00`000000R9WM
08RIg@0708RIg@030000002>W=`0SYcL00L0SYcL00<0000009BOf`2DWm/0202DWm/00`000000VZ;J
09ZRfP0809ZRfP030000002OY=T0WjCI00T0WjCI100000080:>Re0030000002WY=<0YjCC00/0YjCC
00<000000:^Vd@2[Y]40202[Y]43000000`0[ZC=00<000000;6Uc02aYL`02`2aYL`00`000000/jC9
0;>Tb@0:0;>Tb@030000002fYLP0]ZG800T0]ZG80`00000=0;NSa0030000002jY<@0^ZC400@0^ZC4
00<000000;RR`P2hX/80102hX/800`000000^Z?10;ZS`@0;0;ZS`@030000002kXKh0^j6n00`0^j6n
00<000000;fR_@2mX[d00P2mX[d200000180oooo00<000000?ooo`3oool05P3oool004l0oooo00<0
00000?ooo`3oool0GP3oool00`000000G7[H05ajf00200000080Eg_K00<000000661g01QPM`0101Q
PM`00`000000JhKL06^6g00506^6g0030000001cRm`0000000@0000000<0L8gO0000001iT]l01`1i
T]l00`000000PIKN086FgP06086FgP0300000028VMd0R9WM00L0R9WM00<0000008jLg02>W=`01`2>
W=`00`000000U9oK09BOf`0909BOf`030000002JX]X0VZ;J00P0VZ;J00<0000009nTf@2OY=T0102O
Y=T40000000309nPe@000000Xj;D00X0Xj;D00<000000:NTd`2WY=<02P2WY=<00`000000ZjKA0:^V
d@060:^Vd@8000000P2[X/l00`000000[ZC=0:jTc@0:0:jTc@030000002aYL`0/JG<00T0/JG<0`00
000<0;>Tb@030000002fYLP0]ZG800P0]ZG800D000000;BRa@2dX/D0]:;50000000<0;NSa0030000
002jY<@0^ZC400<0^ZC400<000000;RR`P2hX/801@2hX/800`000000^Z?10;ZS`@0:0;ZS`@800000
3P2kXKh00`000000_J:m0;fR_@02000000030?ooo`000000oooo0140oooo00<000000?ooo`3oool0
5P3oool00500oooo0P00001O0?ooo`040000001LN]P0G7[H05ajf0<000001`1QPM`00`000000JhKL
06^6g00406^6g0030000001cRm`0Lh_L00@0Lh_L1@00000607VBg`0300000021U]h0PIKN00H0PIKN
00<0000008RIg@28VMd01`28VMd00`000000SYcL08jLg00708jLg0030000002DWm/0U9oK00T0U9oK
00<0000009ZRfP2JX]X01`2JX]X00`000000WjCI09nTf@04000000H0Wj3E00<000000:>Re02SX]@0
2@2SX]@00`000000YjCC0:NTd`0:0:NTd`030000002[Y]40ZjKA0080ZjKA0`0000040:^Rc`030000
002^Y<d0[ZC=00/0[ZC=00<000000;6Uc02aYL`01P2aYL`2000000<0/:;:00<000000;>Tb@2cY<T0
2P2cY<T00`000000]ZG80;JUb0050;JUb0800000102dX/D00`000000]j?40;NSa00;0;NSa0030000
002jY<@0^ZC4008000002@2hX/800`000000^Z?10;ZS`@070;ZS`@8000000P2iX;l00`000000^j6n
0;^Q_P0<0;^Q_P800000103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01H0oooo
001B0?ooo`030000003oool0oooo05`0oooo00<0000005ajf01LN]P00`1LN]P3000000H0HH7L00<0
000006^6g01[Q]`0101[Q]`00`000000Lh_L07>;g00607>;g0030000001kSm/0000000@0000000<0
NI;O00000021U]h02021U]h00`000000R9WM08RIg@0708RIg@030000002>W=`0SYcL00L0SYcL00<0
000009BOf`2DWm/0202DWm/00`000000VZ;J09ZRfP0409ZRfPH000002P2OX=D00`000000Xj;D0:>R
e0090:>Re0030000002WY=<0YjCC00X0YjCC00<000000:^Vd@2[Y]400P0000080:^Rc`030000002^
Y<d0[ZC=00X0[ZC=00<000000;6Uc02aYL`0102aYL`2000000D0/:;:00<000000;>Tb@2cY<T02P2c
Y<T00`000000]ZG80;JUb0030;JUb08000001`2dX/D00`000000]j?40;NSa00:0;NSa0030000002j
Y<@0000000/0^:;200<000000;ZS`@2jXl401P2jXl400`000000^J2o0;VP_`020;VP_`030000002k
XKh0^j6n00`0^j6n00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo01H0oooo001C0?ooo`030000003oool0oooo05`0oooo00<0000005ajf01LN]P0101LN]P3
000000@0HH7L00<0000006^6g01[Q]`01@1[Q]`00`000000Lh_L07>;g00507>;g0030000001kSm/0
NhoK00@0NhoK1`000004086FgP0300000028VMd0R9WM00L0R9WM00<0000008jLg02>W=`01`2>W=`0
0`000000U9oK09BOf`0409BOf`/000001@2JW]H00`000000Wj3E09nPe@0909nPe@030000002SX]@0
Xj;D00T0Xj;D00<000000:NTd`2WY=<02@2WY=<3000000X0Zj;?00<000000:jTc@2^Y<d02`2^Y<d0
10000000/JG<0;6Uc02aYL`2000000P0/:;:00<000000;>Tb@2cY<T02P2cY<T01@000000]ZG80;JU
b02fYLP0000000T0]:;500<000000;NSa02gXl@02`2gXl@00`000000^:;20;RR`P0;0;RR`P030000
002jXl40^Z?100@0^Z?100<000000;VP_`2iX;l0102iX;l00`000000^j6n0;^Q_P0:0;^Q_P030000
003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0F0?ooo`00E03o
ool00`000000oooo0?ooo`1L0?ooo`030000001LN]P0G7[H00<0G7[H00<0000006J0f01VP=P00`00
00020661g0030000001[Q]`0JhKL00@0JhKL00<0000007>;g01cRm`01P1cRm`00`000000NhoK07^?
f`0607^?f`0400000023TmX0Pi?J08>CfQl000001@2EW=P00`000000VYkF09ZNeP0809ZNeP030000
002OX=D0Wj3E00T0Wj3E00<000000:>Re02SX]@02P2SX]@00`000000YjCC0:NTd`040:NTd`@00000
00<0Yj7@0000002[X/l02`2[X/l00`000000[ZC=0:jTc@0:0:jTc@040000002aYL`00000000000X0
/:;:00<000000;>Tb@2cY<T02P2cY<T010000000]ZG800000000000:0;BRa@030000002gXl@0]j?4
00T0]j?40`00000=0;RR`P030000002jXl40^Z?100<0^Z?100<000000;VP_`2iX;l01@2iX;l00`00
0000^j6n0;^Q_P090;^Q_P030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0F0?ooo`00E@3oool2000005`0oooo00<0000005ajf01LN]P0101LN]P00`000000
IX3H06J0f00206J0f0<000001`1[Q]`00`000000Lh_L07>;g00507>;g0030000001kSm/0NhoK00H0
NhoK00<0000008>CfP23TmX01`23TmX00`000000RIKJ08VFfP0708VFfP030000002?VMT0SiWI00L0
SiWI00<0000009FLf02EW=P0202EW=P00`000000VYkF09ZNeP0809ZNeP030000002OX=D0Wj3E00T0
Wj3E00<000000:>Re02SX]@02@2SX]@00`000000YjCC0:NTd`04000000H0Yj7@00<000000:^Rc`2[
X/l02P2[X/l00`000000[ZC=0:jTc@090:jTc@800000302`X/X00`000000/jC90;>Tb@0;0;>Tb@03
0000002dX/D0]:;500/0]:;500<000000;NSa02gXl@01`2gXl@01@000000]Z330;JP``2fX<<00000
00d0^:;200<000000;ZS`@2jXl400P0000080;VP_`030000002kXKh0^j6n00P0^j6n00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01H0oooo001G0?ooo`03
0000003oool0oooo05X0oooo00<0000005ajf01LN]P00`1LN]P00`000000IX3H06J0f00406J0f0@0
00001@1[Q]`00`000000Lh_L07>;g00507>;g0030000001kSm/0NhoK00H0NhoK00<0000008>CfP23
TmX01P23TmX00`000000RIKJ08VFfP0708VFfP030000002?VMT0SiWI00L0SiWI00<0000009FLf02E
W=P0202EW=P00`000000VYkF09ZNeP0909ZNeP030000002OX=D0Wj3E00P0Wj3E00<000000:>Re02S
X]@02@2SX]@3000000X0Yj7@00<000000:^Rc`2[X/l02P2[X/l00`000000[ZC=0:jTc@060:jTc@<0
000000<0[J7;0000002`X/X0302`X/X00`000000/jC90;>Tb@080;>Tb@<000003@2dX/D00`000000
]j?40;NSa0050;NSa0800000102fX<<00`000000^:;20;RR`P0;0;RR`P030000002jXl40000000/0
^J2o00<000000;^Q_P2kXKh01P2kXKh00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool05@3oool005P0oooo00<000000?ooo`3oool0F@3oool00`000000G7[H
05ajf00405ajf0030000001VP=P0IX3H00D0IX3H00<0000006j4f00000000`0000000`1[Q]`00000
07>;g00707>;g0030000001kSm/0NhoK00H0NhoK00<0000008>CfP23TmX01P23TmX00`000000RIKJ
08VFfP0708VFfP030000002?VMT0SiWI00L0SiWI00<0000009FLf02EW=P0202EW=P00`000000VYkF
09ZNeP0809ZNeP030000002OX=D0Wj3E00T0Wj3E00<000000:>Re02SX]@0102SX]@4000000030:>O
d@000000Yj7@00/0Yj7@00<000000:^Rc`2[X/l02P2[X/l00`000000[ZC=0:jTc@030:jTc@800000
1@2]XL/00`000000/:;:0;2RbP0:0;2RbP030000002cY<T0/jC900H0/jC90P0000030;:QaP030000
002dX/D0]:;500/0]:;500<000000;NSa02gXl@00P2gXl@2000000L0]Z3300<000000;RR`P2hX/80
2`2hX/800`000000^J2o0;VP_`0:0;VP_`030000002kXKh0^j6n00@0^j6n0P00000?0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool05@3oool005T0oooo00<000000?ooo`3oool0F@3o
ool2000000D0G7[H00<0000006J0f01VP=P0101VP=P00`000000KXCH06j4f00306j4f0@000001P1c
Rm`00`000000NhoK07^?f`0607^?f`0300000023TmX0Pi?J00H0Pi?J00<0000008VFfP29U]X01`29
U]X00`000000SiWI08nIf@0708nIf@030000002EW=P0UIcH00P0UIcH00<0000009ZNeP2JW]H02@2J
W]H00`000000Wj3E09nPe@0809nPe@030000002SX]@0Xj;D00@000001P2SWm400`000000Yj7@0:NQ
d0090:NQd0030000002[X/l0Zj;?00X0Zj;?00<000000:jTc@2^Y<d00`0000070:fQb`030000002`
X/X0/:;:00/0/:;:00<000000;>Tb@2cY<T00`2cY<T2000000D0/Z7600<000000;BRa@2dX/D02`2d
X/D01@000000]j?40;NSa02gXl@0000000T0]Z3300<000000;RR`P2hX/802@2hX/83000000`0^J2o
00<000000;^Q_P2kXKh00`2kXKh00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool05@3oool005X0oooo0P00001I0?ooo`040000001QNMD00000000000<0G7[H
00<0000006J0f01VP=P01@1VP=P00`000000KXCH06j4f00506j4f0@00000101cRm`00`000000NhoK
07^?f`0607^?f`0300000023TmX0Pi?J00H0Pi?J00<0000008VFfP29U]X01`29U]X00`000000SiWI
08nIf@0708nIf@030000002EW=P0UIcH00P0UIcH00<0000009ZNeP2JW]H02@2JW]H00`000000Wj3E
09nPe@0609nPe@@000002P2SWm400`000000Yj7@0:NQd00:0:NQd0030000002[X/l0Zj;?00T0Zj;?
0`00000;0:fQb`030000002`X/X0/:;:00X0/:;:00@000000;>Tb@2cY<T0/jC90P0000080;:QaP03
0000002dX/D0]:;500/0]:;50`00000:0;JP``030000002hX/80^:;200P0^:;200D000000;NO`02g
Wl00]io00000000<0;VP_`050000002kXKh0^j6n0;^Q_P0000004`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo01D0oooo001L0?ooo`030000003oool0oooo05L0oooo00<00000065i
e@1QNMD00P00000205ajf0030000001VP=P0IX3H00@0IX3H00<0000006j4f01^Q=P01@1^Q=P01000
0000MXWH07J9f01fRMP5000000T0NhoK00<0000008>CfP23TmX01@23TmX00`000000RIKJ08VFfP08
08VFfP030000002?VMT0SiWI00L0SiWI00<0000009FLf02EW=P01`2EW=P00`000000VYkF09ZNeP09
09ZNeP040000002OX=D0Wj3E09nPe@D000000`2OWM800`000000XioA0:>Od@090:>Od@030000002W
XM00Yj7@00T0Yj7@00<000000:^Rc`2[X/l01`2[X/l2000000030:ZOc0000000[J7;00/0[J7;00<0
00000;2RbP2`X/X02`2`X/X3000000X0/Z7600<000000;BRa@2dX/D02`2dX/D00`000000]Z330;JP
``0;0;JP``030000002hX/80^:;200H0^:;200<000000;NO`02gWl000P2gWl000`000000^J2o0;VP
_`0:0;VP_`040000002kXKh0^j6n000001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`1F0?ooo`030000001QNMD0HGWE0080HGWE0`00
000706J0f0030000001^Q=P0KXCH00D0KXCH00<0000007J9f01fRMP0101fRMP6000000@0NhoK00<0
000008>CfP23TmX01P23TmX00`000000RIKJ08VFfP0708VFfP030000002?VMT0SiWI00L0SiWI00<0
000009FLf02EW=P0202EW=P00`000000VYkF09ZNeP0709ZNePD00000202OWM800`000000XioA0:>O
d@090:>Od@030000002WXM00Yj7@00X0Yj7@00<000000:^Rc`2[X/l0102[X/l2000000@0ZYo<00<0
00000:fQb`2]XL/02P2]XL/00`000000/:;:0;2RbP090;2RbP8000003@2bXLH00`000000]:;50;BR
a@080;BRa@<000003@2fX<<00`000000^:;20;RR`P040;RR`P8000001P2gWl000`000000^J2o0;VP
_`0:0;VP_`8000005P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01D0oooo001N
0?ooo`030000003oool0oooo05H0oooo00<00000065ie@1QNMD00`1QNMD3000000D0IX3H00<00000
06j4f01^Q=P01@1^Q=P00`000000MXWH07J9f00507J9f0030000001nSMP0OXgH0080OXgH2P000003
08>CfP0300000029U]X0RIKJ00P0RIKJ00<0000008nIf@2?VMT01`2?VMT00`000000UIcH09FLf007
09FLf0040000002JW]H0VYkF09ZNePH000000P2JVm<00`000000WigB09nMdP0909nMdP030000002S
Wm40XioA00T0XioA00<000000:NQd02WXM002@2WXM000`000000Zj;?0:^Rc`020:^Rc`8000001P2Z
Wl`00`000000[J7;0:fQb`0:0:fQb`030000002`X/X0/:;:00L0/:;:0P0000000`2_WlL000000;:Q
aP0<0;:QaP030000002dX/D0]:;500H0]:;50P0000030;>Oa0030000002fX<<0]Z3300/0]Z3300<0
00000;RR`P2hX/800P2hX/800`000000]io00;NO`0060;NO`0030000002iX;l0^J2o00X0^J2o00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01D0oooo001O
0?ooo`030000003oool0oooo05D0oooo00<00000065ie@1QNMD01@1QNMD4000000<0IX3H00<00000
06j4f01^Q=P01@1^Q=P00`000000MXWH07J9f00507J9f0030000001nSMP0OXgH00H0OXgH00<00000
08B@e`24T=L00P24T=L:000000@0RIKJ00<0000008nIf@2?VMT01`2?VMT00`000000UIcH09FLf004
09FLf0L000002@2JVm<00`000000WigB09nMdP0809nMdP030000002SWm40XioA00T0XioA00<00000
0:NQd02WXM002P2WXM0010000000Zj;?0000000000090:ZOc0030000002]XL/0[J7;00X0[J7;00<0
00000;2RbP2`X/X0102`X/X2000000@0[io700<000000;:QaP2bXLH02`2bXLH00`000000]:;50;BR
a@030;BRa@8000001@2cWl@00`000000]Z330;JP``0;0;JP``050000002hX/80^:;20;RR`P000000
2@2gWl000`000000^J2o0;VP_`090;VP_`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0D0?ooo`00H03oool2000005H0oooo00<00000065ie@1QNMD0101Q
NMD010000000JGkE06Une@1YO]D4000000P0KXCH00<0000007J9f01fRMP0101fRMP00`000000OXgH
07j=f00707j=f00300000024T=L0Q93G00H0Q93G00<0000008^CeP2;TmH00P2;TmHE000000D0UISD
00<0000009ZKd`2JVm<0202JVm<00`000000WigB09nMdP0909nMdP030000002SWm40XioA00T0XioA
00<000000:NQd02WXM00202WXM03000000/0ZYo<00<000000:fQb`2]XL/02P2]XL/00`000000/:;:
0;2RbP020;2RbP8000001P2_WlL00`000000/Z760;:QaP0;0;:QaP040000002dX/D0]:;50;BRa@80
0000202cWl@00`000000]Z330;JP``0;0;JP``<000002`2gWl000`000000^J2o0;VP_`060;VP_`80
0000703oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01@0oooo001R0?ooo`030000
003oool0oooo05<0oooo00<00000065ie@1QNMD01@1QNMD00`000000JGkE06Une@0306Une@<00000
1P1^Q=P00`000000MXWH07J9f00507J9f0030000001nSMP0OXgH00H0OXgH00<0000008B@e`24T=L0
1P24T=L00`000000Ri?F08^CeP0708^CeP030000002@U]D0T9KE00L0T9KE00<0000009FHe02EV=@0
202EV=@00`000000VY_C09ZKd`0909ZKd`030000002OWM80WigB00P0WigB00<000000:>Od@2SWm40
2@2SWm400`000000Yj7@0:NQd0040:NQd0@0000000<0YYg=0000002ZWl`02`2ZWl`00`000000[J7;
0:fQb`0;0:fQb`040000002`X/X00000000000T0[io700<000000;:QaP2bXLH02`2bXLH3000000X0
/io400<000000;JP``2fX<<02`2fX<<00`000000]io00;NO`00;0;NO`0030000002iX;l0^J2o00D0
^J2o00<000000?ooo`3oool0703oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01@0
oooo001S0?ooo`030000003oool0oooo05<0oooo00<00000065ie@1QNMD0101QNMD00`000000JGkE
06Une@0506Une@@00000101^Q=P00`000000MXWH07J9f00407J9f0030000001nSMP0OXgH00L0OXgH
00<0000008B@e`24T=L01P24T=L00`000000Ri?F08^CeP0708^CeP030000002@U]D0T9KE00L0T9KE
00<0000009FHe02EV=@0202EV=@00`000000VY_C09ZKd`0809ZKd`030000002OWM80WigB00T0WigB
00<000000:>Od@2SWm402@2SWm400`000000Yj7@00000003000000H0YYg=00<000000:ZOc02ZWl`0
2P2ZWl`00`000000[J7;0:fQb`090:fQb`<000002`2_WlL00`000000/Z760;:QaP0;0;:QaP030000
002cWl@0/io400X0/io400<000000;JP``2fX<<02@2fX<<3000000d0]io000<000000;VP_`2iX;l0
102iX;l00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
503oool006@0oooo00<000000?ooo`3oool0DP3oool00`000000HGWE065ie@05065ie@030000001Y
O]D0JGkE00@0JGkE00@000000763e@1aPmD0LH?E1@00000707J9f0030000001nSMP0OXgH00H0OXgH
00<0000008B@e`24T=L01P24T=L00`000000Ri?F08^CeP0708^CeP030000002@U]D0T9KE00L0T9KE
00<0000009FHe02EV=@0202EV=@00`000000VY_C09ZKd`0909ZKd`030000002OWM80WigB00P0WigB
00<000000:>Od@2SWm40202SWm43000000X0YYg=00<000000:ZOc02ZWl`02P2ZWl`00`000000[J7;
0:fQb`070:fQb`80000000<0[9k80000002_WlL0302_WlL00`000000/Z760;:QaP080;:QaP<00000
3@2cWl@00`000000]Z330;JP``070;JP``050000002eW/40]Ik10;FN`@0000003@2gWl000`000000
^J2o0;VP_`020;VP_`030000003oool0oooo0200oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0D0?ooo`00I@3oool2000005<0oooo0P000006065ie@030000001YO]D0JGkE00@0JGkE
00<000000763e@1aPmD0101aPmD3000000D0MXWH00<0000007j=f01nSMP01`1nSMP00`000000Q93G
08B@e`0608B@e`030000002;TmH0Ri?F00L0Ri?F00<00000092Fe@2@U]D01`2@U]D00`000000UISD
09FHe00809FHe0030000002JVm<0VY_C00P0VY_C00<0000009nMdP2OWM802@2OWM800`000000XioA
0:>Od@040:>Od@<000000P2SW<h00`000000YYg=0:JMc@090:JMc@030000002ZWl`0ZYo<00X0ZYo<
00<000000:fQb`2]XL/0102]XL/2000000@0[9k800<000000:nOa`2_WlL02P2_WlL00`000000/Z76
0;:QaP060;:QaP8000000`2aW/@00`000000/io40;>Oa00:0;>Oa0030000002fX<<0]Z3300D0]Z33
0P0000040;FN`@030000002gWl00]io000/0]io000<000000;VP_`2iX;l00P00000T0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0503oool006L0oooo00<000000?ooo`3oool0D@3o
ool3000000@0HGWE00<0000006Une@1YO]D0101YO]D00`000000LH?E0763e@050763e@030000001i
QmD00000008000000`1fRMP00`000000OXgH07j=f00607j=f00300000024T=L0Q93G00L0Q93G00<0
000008^CeP2;TmH01P2;TmH00`000000T9KE092Fe@07092Fe@030000002EV=@0UISD00T0UISD00<0
000009ZKd`2JVm<0202JVm<00`000000WigB09nMdP0809nMdP030000002SWm40XioA00@000001@2S
W<h00`000000YYg=0:JMc@090:JMc@030000002ZWl`0ZYo<00X0ZYo<00<000000:fQb`2]XL/00P2]
XL/2000000H0[9k800<000000:nOa`2_WlL02`2_WlL00`000000/Z760;:QaP030;:QaP8000001@2a
W/@00`000000/io40;>Oa00;0;>Oa0030000002fX<<0]Z330080]Z330P0000070;FN`@030000002g
Wl00]io000/0]io00P00000V0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0503o
ool006P0oooo00<000000?ooo`3oool0D03oool00`000000IGSB06EhdP0300000080HGWE00<00000
06Une@1YO]D0101YO]D00`000000LH?E0763e@050763e@040000001iQmD0NHOE07V7e@@000002@1n
SMP00`000000Q93G08B@e`0608B@e`030000002;TmH0Ri?F00L0Ri?F00<00000092Fe@2@U]D01`2@
U]D00`000000UISD09FHe00809FHe0030000002JVm<0VY_C00P0VY_C00<0000009nMdP2OWM801`2O
WM84000000X0Xic>00<000000:JMc@2VWLd02@2VWLd00`000000ZYo<0:ZOc00:0:ZOc0040000002]
XL/00000000000T0[9k800<000000:nOa`2_WlL02P2_WlL010000000/Z760;:QaP2bXLH2000000P0
/Ik400<000000;>Oa02cWl@02P2cWl@01@000000]Z330;JP``2fX<<0000000T0]Ik100<000000;NO
`02gWl002`2gWl000`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0503oool006T0oooo00<000000?ooo`3oool0D03oool00`000000IGSB06EhdP0206EhdP<0
00001P1YO]D00`000000LH?E0763e@050763e@030000001iQmD0NHOE00@0NHOE1P00000407j=f003
00000024T=L0Q93G00L0Q93G00<0000008^CeP2;TmH01P2;TmH00`000000T9KE092Fe@07092Fe@03
0000002EV=@0UISD00T0UISD00<0000009ZKd`2JVm<0202JVm<00`000000WigB09nMdP0600000080
WY[?00<000000:>LcP2SW<h02@2SW<h00`000000YYg=0:JMc@090:JMc@030000002ZWl`0ZYo<00T0
ZYo<0`00000;0:bNb0030000002_WlL0[io700/0[io70`00000:0;6Na0030000002cWl@0/io400/0
/io40`00000:0;FN`@030000002gWl00]io000T0]io00P00000Z0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool04`3oool006X0oooo0P00001@0?ooo`030000001UN=80IGSB00@0IGSB
0`00000506Une@030000001aPmD0LH?E00D0LH?E00<0000007V7e@1iQmD01@1iQmD010000000Oh[D
07n:e01oR]@:000000@0Q93G00<0000008^CeP2;TmH01`2;TmH00`000000T9KE092Fe@07092Fe@03
0000002EV=@0UISD00P0UISD00<0000009ZKd`2JVm<0102JVm<7000000T0WY[?00<000000:>LcP2S
W<h02@2SW<h00`000000YYg=0:JMc@090:JMc@030000002ZWl`0ZYo<00D0ZYo<0`0000020:VLb@03
0000002/W/P0[9k800T0[9k800<000000:nOa`2_WlL02`2_WlL00`000000/Ik40;6Na00:0;6Na003
0000002cWl@0/io400/0/io400<000000;FN`@2eW/402`2eW/400`000000]io00;NO`0070;NO`003
0000003oool0oooo02X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`00
K03oool00`000000oooo0?ooo`1>0?ooo`030000001UN=80IGSB00@0IGSB00@0000006emdP000000
00000`1YO]D00`000000LH?E0763e@050763e@030000001iQmD0NHOE00D0NHOE00<0000007n:e01o
R]@01`1oR]@010000000QXgC08J=d`26SM<:000000@0Ri?F00<00000092Fe@2@U]D01`2@U]D00`00
0000UISD09FHe00409FHe0/000001@2JV=000`000000WY[?09jJc`0809jJc`030000002SW<h0Xic>
00T0Xic>00<000000:JMc@2VWLd02@2VWLd00`000000ZYo<0:ZOc0030:ZOc08000001@2YW<T00`00
0000[9k80:bNb00:0:bNb0030000002_WlL0[io700P0[io70`00000=0;6Na0030000002cWl@0/io4
00P0/io40`00000=0;FN`@030000002gWl00]io000H0]io000<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo001]0?ooo`030000003oool0oooo04d0
oooo00<0000006EhdP1UN=801@1UN=800`000000KGgB06emdP0200000080JGkE00<000000763e@1a
PmD01@1aPmD00`000000NHOE07V7e@0507V7e@030000001oR]@0Oh[D00H0Oh[D00<0000008J=d`26
SM<01`26SM<010000000S93C08b@d`2<T=<E000000D0UYKA00<0000009ZHd02JV=00202JV=000`00
0000WY[?09jJc`0909jJc`030000002SW<h0Xic>00T0Xic>00<000000:JMc@2VWLd02@2VWLd00`00
0000ZYo<00000002000000P0ZIc900<000000:bNb02/W/P02@2/W/P00`000000[io70:nOa`060:nO
a`8000000`2^WLD00`000000/Ik40;6Na00:0;6Na0030000002cWl@0/io400L0/io400D000000;:M
`P2bWL80/Yg20000000<0;FN`@030000002gWl00]io000@0]io00P00000`0?ooo`050000003oool0
oooo0?ooo`0000005@3oool006h0oooo00<000000?ooo`3oool0C@3oool00`000000IGSB06EhdP04
06EhdP030000001]OM80KGgB0080KGgB0`0000070763e@030000001iQmD0NHOE00D0NHOE00<00000
07n:e01oR]@01`1oR]@00`000000QXgC08J=d`0608J=d`030000002<T=<0S93C00L0S93C00<00000
096CdP2ATm801`2ATm800`000000UYKA09JFd@0809JFd@030000002JV=00VYS@00P0VYS@00<00000
09jJc`2NV/l0202NV/l00`000000Xic>0:>LcP090:>LcP030000002VWLd0YYg=00P0YYg=0`00000;
0:VLb@030000002/W/P0[9k800X0[9k800<000000:nOa`2_WlL00`2_WlL2000000D0[Yg500<00000
0;6Na02aW/@02P2aW/@00`000000/io40;>Oa0050;>Oa0800000102bWL800`000000]Ik10;FN`@0;
0;FN`@030000002gWl00]io00080]io000<000000?ooo`3oool0<@3oool010000000oooo0?ooo`00
000E0?ooo`00K`3oool2000004d0oooo00<0000006EhdP1UN=801@1UN=800`000000KGgB06emdP03
06emdP<000001P1aPmD00`000000NHOE07V7e@0507V7e@030000001oR]@0Oh[D00H0Oh[D00<00000
08J=d`26SM<01`26SM<00`000000S93C08b@d`0608b@d`030000002ATm80TI?B00L0TI?B00<00000
09JFd@2FU]40202FU]400`000000VYS@09ZHd00809ZHd0030000002NV/l0WY[?00T0WY[?00<00000
0:>LcP2SW<h02@2SW<h00`000000YYg=0:JMc@040:JMc@<000000P2VVl/00`000000ZIc90:VLb@0:
0:VLb@030000002/W/P0[9k800T0[9k800@000000:nOa`2_WlL0[io70P0000080:jMa@030000002a
W/@0/Ik400X0/Ik400<000000;>Oa02cWl@00P2cWl@2000000L0/Yg200<000000;FN`@2eW/402P2e
W/401@000000]io00;NO`02gWl00000003@0oooo00@000000?ooo`3oool000005@3oool00740oooo
00<000000?ooo`3oool0B`3oool00`000000IGSB06EhdP0406EhdP030000001]OM80KGgB00@0KGgB
00<0000007B1dP0000000P0000030763e@030000001iQmD0NHOE00H0NHOE00<0000007n:e01oR]@0
1P1oR]@00`000000QXgC08J=d`0608J=d`030000002<T=<0S93C00L0S93C00<00000096CdP2ATm80
1`2ATm800`000000UYKA09JFd@0809JFd@030000002JV=00VYS@00P0VYS@00<0000009jJc`2NV/l0
202NV/l00`000000Xic>0:>LcP090:>LcP030000002VWLd0YYg=00@000001@2VVl/00`000000ZIc9
0:VLb@0:0:VLb@030000002/W/P0[9k800X0[9k80`00000:0:jMa@030000002aW/@0/Ik400X0/Ik4
00D000000;>Oa02cWl@0/io4000000090;:M`P030000002eW/40]Ik100/0]Ik10`00000f0?ooo`03
0000003oool0000001D0oooo001b0?ooo`030000003oool0oooo04X0oooo00<0000006EhdP1UN=80
1@1UN=800`000000KGgB06emdP0406emdP040000001dPM80M87B07B1dP<0000000<0LH?E0000001i
QmD01P1iQmD00`000000Oh[D07n:e00607n:e00300000026SM<0QXgC00L0QXgC00<0000008b@d`2<
T=<01P2<T=<00`000000TI?B096CdP07096CdP030000002FU]40UYKA00P0UYKA00<0000009ZHd02J
V=00202JV=000`000000WY[?09jJc`0909jJc`030000002SW<h0Xic>00P0Xic>0`00000:0:JKb`03
0000002YW<T0ZIc900X0ZIc900<000000:bNb02/W/P0202/W/P2000000`0[Yg500<000000;6Na02a
W/@02`2aW/@3000000X0/Yg200<000000;FN`@2eW/402`2eW/400`000000oooo0?ooo`0g0?ooo`03
0000003oool0000001@0oooo001c0?ooo`030000003oool0oooo04X0oooo0P00000506EhdP030000
001]OM80KGgB00@0KGgB00<0000007B1dP1dPM80101dPM84000000H0NHOE00<0000007n:e01oR]@0
1P1oR]@00`000000QXgC08J=d`0608J=d`030000002<T=<0S93C00L0S93C00<00000096CdP2ATm80
1`2ATm800`000000UYKA09JFd@0809JFd@030000002JV=00VYS@00P0VYS@00<0000009jJc`2NV/l0
202NV/l00`000000Xic>0:>LcP040:>LcP@0000000<0XYW<0000002VVl/02P2VVl/00`000000ZIc9
0:VLb@0:0:VLb@030000002/W/P0[9k800H0[9k80P0000000`2[VlH000000:jMa@0<0:jMa@030000
002aW/@0/Ik400X0/Ik400<000000;:M`P2bWL802`2bWL800`000000]Ik10;FN`@080;FN`@800000
>`3oool2000001@0oooo001d0?ooo`800000BP3oool010000000J7O?00000000000406EhdP030000
001]OM80KGgB00@0KGgB00<0000007B1dP1dPM801@1dPM800`000000NhGA000000040000000307V7
e@000000Oh[D00L0Oh[D00<0000008J=d`26SM<01`26SM<00`000000S93C08b@d`0608b@d`030000
002ATm80TI?B00L0TI?B00<0000009JFd@2FU]40202FU]400`000000VYS@09ZHd00809ZHd0030000
002NV/l0WY[?00T0WY[?00<000000:>LcP0000000`0000060::Ic0030000002VVl/0YY_;00T0YY_;
00<000000:VLb@2YW<T02P2YW<T00`000000[9k80:bNb0020:bNb0<00000102[VlH00`000000[Yg5
0:jMa@0:0:jMa@030000002aW/@0/Ik400P0/Ik40`00000=0;:M`P030000002eW/40]Ik100L0]Ik1
00<000000?ooo`3oool0>`3oool2000001@0oooo001f0?ooo`030000003oool0oooo04P0oooo00<0
000006Qgc`1XMll00P00000206EhdP030000001]OM80KGgB00@0KGgB00<0000007B1dP1dPM801@1d
PM800`000000NhGA07^5d@0407^5d@D000001P1oR]@00`000000QXgC08J=d`0608J=d`030000002<
T=<0S93C00L0S93C00<00000096CdP2ATm801`2ATm800`000000UYKA09JFd@0809JFd@030000002J
V=00VYS@00P0VYS@00<0000009jJc`2NV/l01P2NV/l4000000X0XYW<00<000000:JKb`2VVl/02@2V
Vl/00`000000ZIc90:VLb@0:0:VLb@030000002/W/P0[9k8008000001`2[VlH00`000000[Yg50:jM
a@0:0:jMa@030000002aW/@0/Ik400H0/Ik40P0000030;2K``030000002bWL80/Yg200X0/Yg200<0
00000;FN`@2eW/401@2eW/42000003h0oooo0P00000D0?ooo`00M`3oool00`000000oooo0?ooo`17
0?ooo`030000001XMll0J7O?0080J7O?0P0000000`1UN=80000006emdP0506emdP030000001dPM80
M87B00D0M87B00<0000007^5d@1kQM401@1kQM400`000000PHSA0868d@050000000307n:e0000000
QXgC00P0QXgC00<0000008b@d`2<T=<01P2<T=<00`000000TI?B096CdP07096CdP030000002FU]40
UYKA00P0UYKA00<0000009ZHd02JV=00202JV=0010000000WY[?09jJc`2NV/l5000000<0WYO<00<0
00000::Ic02RVL`02@2RVL`00`000000YY_;0:JKb`090:JKb`030000002YW<T0ZIc900T0ZIc90`00
000:0:^KaP030000002^WLD0[Yg500X0[Yg500<000000;6Na02aW/@00`2aW/@2000000D0/9_300<0
00000;:M`P2bWL802`2bWL800`000000]Ik10;FN`@020;FN`@800000?03oool4000001H0oooo001h
0?ooo`030000003oool0oooo04L0oooo00<0000006Qgc`1XMll00`1XMll3000000D0KGgB00<00000
07B1dP1dPM801@1dPM800`000000NhGA07^5d@0607^5d@0300000021R=40PHSA00@0PHSA1`000004
08J=d`030000002<T=<0S93C00L0S93C00<00000096CdP2ATm801`2ATm800`000000UYKA09JFd@08
09JFd@030000002JV=00VYS@00<0VYS@2000000809jGc0030000002RVL`0XYW<00T0XYW<00<00000
0:JKb`2VVl/02@2VVl/00`000000ZIc90:VLb@060:VLb@<0000000<0Z9[70000002[VlH02P2[VlH0
0`000000[Yg50:jMa@0:0:jMa@040000002aW/@0/Ik40;6Na0800000202`Vl<00`000000/Yg20;:M
`P0:0;:M`P050000002eW/40]Ik10;FN`@000000>P3oool4000001X0oooo001i0?ooo`800000A`3o
ool00`000000J7O?06Qgc`0406Qgc`040000001`O<l00000000000@0KGgB00<0000007B1dP1dPM80
1@1dPM800`000000NhGA07^5d@0507^5d@0300000021R=40PHSA00H0PHSA00<0000008N;d027Rm00
0P27Rm0:000000@0S93C00<00000096CdP2ATm801`2ATm800`000000UYKA09JFd@0409JFd@X00000
1@2JULd00`000000WYO<09jGc00909jGc0030000002RVL`0XYW<00T0XYW<00<000000:JKb`2VVl/0
2@2VVl/00`000000ZIc90:VLb@030:VLb@8000001@2XV/L00`000000Zi_60:^KaP090:^KaP030000
002^WLD0[Yg500X0[Yg50`00000:0;2K``030000002bWL80/Yg200/0/Yg20`00000g0?ooo`@00000
7P3oool007/0oooo00<000000?ooo`3oool0A@3oool00`000000J7O?06Qgc`0406Qgc`030000001`
O<l0L7c?008000000P1]OM800`000000M87B07B1dP0507B1dP030000001kQM40NhGA00H0NhGA00<0
00000868d@21R=401P21R=400`000000Qh_@08N;d00608N;d0030000002<S]00S8k@0080S8k@5@00
000509JCcP030000002JULd0VYG=00P0VYG=00<0000009jGc02NUl`0202NUl`00`000000XYW<0::I
c0090::Ic0030000002VVl/0YY_;00T0YY_;00<000000:VLb@2YW<T00`0000070:RJa`030000002[
VlH0Zi_600T0Zi_600<000000:jMa@2^WLD02P2^WLD00`000000/9_30;2K``0;0;2K``030000002b
WL80/Yg200X0/Yg200<000000?ooo`3oool0<`3oool400000280oooo001l0?ooo`030000003oool0
oooo04@0oooo00<0000006Qgc`1XMll0101XMll00`000000L7c?071lc`02071lc`80000000<0KGgB
0000001dPM801P1dPM800`000000NhGA07^5d@0507^5d@0300000021R=40PHSA00H0PHSA00<00000
08N;d027Rm001`27Rm000`000000S8k@08b>d00608b>d0030000002ATLl0TI7?00L0TI7?00<00000
09JCcP2FTlh0202FTlh00`000000VYG=09ZEc@0809ZEc@030000002NUl`0WYO<00T0WYO<00<00000
0::Ic02RVL`02@2RVL`00`000000YY_;0:JKb`080:JKb`<000002`2XV/L00`000000Zi_60:^KaP09
0:^KaP030000002^WLD0[Yg500L0[Yg50`00000=0;2K``030000002bWL80/Yg200P0/Yg20P00000b
0?ooo`@000009P3oool007d0oooo00<000000?ooo`3oool0A03oool00`000000J7O?06Qgc`0406Qg
c`030000001`O<l0L7c?00<0L7c?0`00000607B1dP030000001kQM40NhGA00H0NhGA00<000000868
d@21R=401P21R=400`000000Qh_@08N;d00608N;d0030000002<S]00S8k@00L0S8k@00<00000096A
c`2ATLl01`2ATLl00`000000UY?>09JCcP0809JCcP030000002JULd0VYG=00P0VYG=00<0000009jG
c02NUl`0202NUl`00`000000XYW<0::Ic0090::Ic0030000002VVl/0YY_;00@0YY_;100000000`2U
V<P000000:RJa`0;0:RJa`030000002[VlH0Zi_600T0Zi_600<000000:jMa@2^WLD01@2^WLD20000
00<0[I[300<000000;2K``2`Vl<02`2`Vl<00`000000/Yg20;:M`P060;:M`P030000003oool0oooo
02l0oooo0`00000Z0?ooo`00OP3oool2000004@0oooo00<0000006Qgc`1XMll0101XMll00`000000
L7c?071lc`05071lc`@00000101dPM800`000000NhGA07^5d@0507^5d@0300000021R=40PHSA00H0
PHSA00<0000008N;d027Rm001`27Rm000`000000S8k@08b>d00608b>d0030000002ATLl0TI7?00L0
TI7?00<0000009JCcP2FTlh0202FTlh00`000000VYG=09ZEc@0809ZEc@030000002NUl`0WYO<00T0
WYO<00<000000::Ic02RVL`02@2RVL`00`000000YY_;00000003000000H0YIS800<000000:RJa`2X
V/L02@2XV/L00`000000Zi_60:^KaP0:0:^KaP030000002^WLD0[Yg50080[Yg50P0000050:fJ``03
0000002`Vl<0/9_300/0/9_300<000000;:M`P2bWL801@2bWL800`000000oooo0?ooo`0/0?ooo`@0
0000;@3oool00800oooo00<000000?ooo`3oool0@P3oool00`000000J7O?06Qgc`0406Qgc`030000
001`O<l0L7c?00@0L7c?00@0000007Moc`1gOll0Mgo?1@00000807^5d@0300000021R=40PHSA00H0
PHSA00<0000008N;d027Rm001P27Rm000`000000S8k@08b>d00708b>d0030000002ATLl0TI7?00L0
TI7?00<0000009JCcP2FTlh0202FTlh00`000000VYG=09ZEc@0809ZEc@030000002NUl`0WYO<00P0
WYO<00<000000::Ic02RVL`0202RVL`3000000X0YIS800<000000:RJa`2XV/L02P2XV/L00`000000
Zi_60:^KaP090:^KaP030000002^WLD0[Yg500800000202]V/<00`000000/9_30;2K``0;0;2K``03
0000002bWL80/Yg20080/Yg20P00000[0?ooo`@00000<@3oool00840oooo00<000000?ooo`3oool0
@@3oool2000000D0J7O?00<00000071lc`1`O<l01@1`O<l00`000000Mgo?07Moc`0407Moc`@00000
1@1kQM400`000000PHSA0868d@060868d@0300000027Rm00Qh_@00L0Qh_@00<0000008b>d02<S]00
1P2<S]000`000000TI7?096Ac`07096Ac`030000002FTlh0UY?>00P0UY?>00<0000009ZEc@2JULd0
202JULd00`000000WYO<09jGc00909jGc0030000002RVL`0XYW<00@0XYW<0`0000000`2RU/T00000
0:FHb00;0:FHb0030000002XV/L0Z9[700T0Z9[700<000000:^KaP2[VlH02@2[VlH3000000X0[I[3
00<000000;2K``2`Vl<02`2`Vl<01@000000/Yg20;:M`P2bWL80000002T0oooo1000000e0?ooo`00
PP3oool00`000000oooo0?ooo`100?ooo`040000001/Ml`00000000000@0J7O?00<00000071lc`1`
O<l0101`O<l00`000000Mgo?07Moc`0507Moc`030000001mPll0OH??00@000000P1kQM400`000000
PHSA0868d@060868d@0300000027Rm00Qh_@00H0Qh_@00<0000008b>d02<S]001`2<S]000`000000
TI7?096Ac`07096Ac`030000002FTlh0UY?>00P0UY?>00<0000009ZEc@2JULd0202JULd00`000000
WYO<09jGc00809jGc0030000002RVL`0XYW<00@000001@2RU/T00`000000YIS80:FHb0090:FHb003
0000002XV/L0Z9[700T0Z9[700<000000:^KaP2[VlH01`2[VlH2000000030:^Ia0000000[I[300/0
[I[300<000000;2K``2`Vl<02`2`Vl<3000002H0oooo1000000i0?ooo`00P`3oool200000440oooo
00<0000006agc01/Ml`00P00000206Qgc`030000001`O<l0L7c?00D0L7c?00<0000007Moc`1gOll0
1@1gOll00`000000OH??07f3c`0307f3c`D000001P21R=400`000000Qh_@08N;d00708N;d0030000
002<S]00S8k@00H0S8k@00<00000096Ac`2ATLl01`2ATLl00`000000UY?>09JCcP0809JCcP030000
002JULd0VYG=00P0VYG=00<0000009jGc02NUl`01`2NUl`4000000T0XYK900<000000:FHb02UV<P0
2@2UV<P00`000000Z9[70:RJa`0:0:RJa`030000002[VlH0Zi_600@0Zi_60P0000040:^Ia0030000
002]V/<0[I[300T0[I[300<000000;2K``2`Vl<02`2`Vl<00`000000oooo0?ooo`0S0?ooo`<00000
?@3oool008D0oooo00<000000?ooo`3oool0?P3oool00`000000K7O<06agc00206agc080000000<0
J7O?0000001`O<l01@1`O<l00`000000Mgo?07Moc`0507Moc`030000001mPll0OH??00D0OH??00<0
000008>6cP23Q/h01@0000020868d@0300000027Rm00Qh_@00H0Qh_@00<0000008b>d02<S]001`2<
S]000`000000TI7?096Ac`07096Ac`030000002FTlh0UY?>00P0UY?>00<0000009ZEc@2JULd0202J
ULd00`000000WYO<09jGc00600000080WYC:00<000000::Fb@2RU/T02@2RU/T00`000000YIS80:FH
b0090:FHb0030000002XV/L0Z9[700T0Z9[700<000000:^KaP2[VlH00P2[VlH2000000H0ZiW400<0
00000:fJ``2]V/<02P2]V/<00`000000/9_30;2K``080;2K``8000008P3oool400000400oooo0026
0?ooo`030000003oool0oooo03h0oooo00<0000006agc01/Ml`00`1/Ml`3000000H0L7c?00<00000
07Moc`1gOll01@1gOll00`000000OH??07f3c`0507f3c`0300000023Q/h0PhK>00@0PhK>1`000005
08N;d0030000002<S]00S8k@00H0S8k@00<00000096Ac`2ATLl01`2ATLl00`000000UY?>09JCcP08
09JCcP030000002JULd0VYG=00@0VYG=1`00000909jDbP030000002RU/T0XYK900P0XYK900<00000
0:FHb02UV<P02@2UV<P00`000000Z9[70:RJa`0:0:RJa`040000002[VlH00000000000T0ZiW400<0
00000:fJ``2]V/<02@2]V/<00`000000/9_30;2K``060;2K``800000803oool4000004@0oooo0027
0?ooo`030000003oool0oooo03d0oooo00<0000006agc01/Ml`0101/Ml`010000000LW[<00000000
0004071lc`030000001gOll0Mgo?00D0Mgo?00<0000007f3c`1mPll01@1mPll00`000000PhK>08>6
cP0608>6cP0300000028RLh0R8W>0080R8W>2P00000508b>d0030000002ATLl0TI7?00L0TI7?00<0
000009JCcP2FTlh00`2FTlh;000000@0VY?;00<0000009jDbP2NU<X02@2NU<X00`000000XYK90::F
b@090::Fb@030000002UV<P0YIS800T0YIS800<000000:RJa`2XV/L0202XV/L3000000/0ZiW400<0
00000:fJ``2]V/<02P2]V/<00`000000/9_30;2K``030;2K``8000007P3oool4000004P0oooo0028
0?ooo`800000?P3oool00`000000K7O<06agc00406agc0030000001bN/`0LW[<00<000000P1`O<l0
0`000000Mgo?07Moc`0507Moc`030000001mPll0OH??00D0OH??00<0000008>6cP23Q/h01P23Q/h0
0`000000R8W>08R9cP0608R9cP030000002=S<d0SHc=0080SHc=5@00000509J@c0030000002JTl/0
VY?;00P0VY?;00<0000009jDbP2NU<X02@2NU<X00`000000XYK90::Fb@080::Fb@030000002UV<P0
YIS800T0YIS800<000000:RJa`2XV/L0102XV/L4000000030:NGa@000000ZiW400/0ZiW400<00000
0:fJ``2]V/<02P2]V/<010000000/9_30;2K``2`Vl<2000001`0oooo1000001<0?ooo`00RP3oool0
0`000000oooo0?ooo`0k0?ooo`030000001/Ml`0K7O<00@0K7O<00<00000079jc01bN/`00`1bN/`3
000000L0Mgo?00<0000007f3c`1mPll01@1mPll00`000000PhK>08>6cP0608>6cP0300000028RLh0
R8W>00L0R8W>00<0000008f<c@2=S<d01P2=S<d00`000000TXk<09:>c00709:>c0030000002FT<`0
UY3<00T0UY3<00<0000009ZCb`2JTl/01`2JTl/00`000000WYC:09jDbP0909jDbP030000002RU/T0
XYK900T0XYK900<000000:FHb02UV<P02@2UV<P00`000000Z9[700000003000000H0YiO500<00000
0:^Ia02[VL@02P2[VL@00`000000[I[30:fJ``0:0:fJ``<000006P3oool400000500oooo002;0?oo
o`030000003oool0oooo03/0oooo00<0000006agc01/Ml`0101/Ml`00`000000LW[<079jc004079j
c0<000001P1gOll00`000000OH??07f3c`0507f3c`0300000023Q/h0PhK>00H0PhK>00<0000008R9
cP28RLh01P28RLh00`000000SHc=08f<c@0708f<c@030000002BS/`0TXk<00L0TXk<00<0000009J@
c02FT<`0202FT<`00`000000VY?;09ZCb`0809ZCb`030000002NU<X0WYC:00P0WYC:00<000000::F
b@2RU/T02@2RU/T00`000000YIS80:FHb0080:FHb0<000002P2WUlD00`000000ZiW40:^Ia00:0:^I
a0030000002]V/<0[I[300T0[I[30P00000I0?ooo`<00000E03oool008`0oooo00<000000?ooo`3o
ool0>P3oool00`000000K7O<06agc00406agc0030000001bN/`0LW[<00D0LW[<00<0000007Unc000
00000P00000307Moc`030000001mPll0OH??00D0OH??00<0000008>6cP23Q/h01P23Q/h00`000000
R8W>08R9cP0708R9cP030000002=S<d0SHc=00H0SHc=00<0000009:>c02BS/`01`2BS/`00`000000
UY3<09J@c00909J@c0030000002JTl/0VY?;00L0VY?;00<0000009jDbP2NU<X02@2NU<X00`000000
XYK90::Fb@090::Fb@030000002UV<P0YIS800D0YIS80P0000000`2TU/H000000:NGa@0;0:NGa@03
0000002[VL@0ZiW400T0ZiW400<000000:fJ``2]V/<01`2]V/<2000001L0oooo1000001G0?ooo`00
S@3oool00`000000oooo0?ooo`0j0?ooo`030000001/Ml`0K7O<00@0K7O<00<00000079jc01bN/`0
1@1bN/`010000000NGk<07Unc01iO/`30000000307Moc`000000OH??00H0OH??00<0000008>6cP23
Q/h01P23Q/h00`000000R8W>08R9cP0608R9cP030000002=S<d0SHc=00L0SHc=00<0000009:>c02B
S/`01`2BS/`00`000000UY3<09J@c00809J@c0030000002JTl/0VY?;00P0VY?;00<0000009jDbP2N
U<X0202NU<X00`000000XYK90::Fb@090::Fb@030000002UV<P0YIS80080YIS80`0000040:BFaP03
0000002WUlD0YiO500T0YiO500<000000:^Ia02[VL@02P2[VL@00`000000[I[30:fJ``040:fJ``80
00005@3oool4000005/0oooo002>0?ooo`800000>P3oool00`000000K7O<06agc00406agc0030000
001bN/`0LW[<00D0LW[<00<0000007Unc01iO/`0101iO/`3000000H0OH??00<0000008>6cP23Q/h0
1P23Q/h00`000000R8W>08R9cP0708R9cP030000002=S<d0SHc=00H0SHc=00<0000009:>c02BS/`0
1`2BS/`00`000000UY3<09J@c00809J@c0030000002JTl/0VY?;00P0VY?;00<0000009jDbP2NU<X0
2@2NU<X00`000000XYK90::Fb@090::Fb@040000002UV<P00000000000L0Y9K600<000000:NGa@2W
UlD02@2WUlD00`000000ZiW40:^Ia00:0:^Ia0030000002]V/<0[I[30080[I[30P00000C0?ooo`@0
0000G`3oool00900oooo00<000000?ooo`3oool0>03oool2000000D0K7O<00<00000079jc01bN/`0
1@1bN/`00`000000NGk<07Unc00407Unc0030000001nPL`0000000800000101mPll00`000000PhK>
08>6cP0608>6cP0300000028RLh0R8W>00H0R8W>00<0000008f<c@2=S<d01`2=S<d00`000000TXk<
09:>c00709:>c0030000002FT<`0UY3<00P0UY3<00<0000009ZCb`2JTl/0202JTl/00`000000WYC:
09jDbP0809jDbP030000002RU/T0XYK900L0XYK91000000:0:BFaP030000002WUlD0YiO500T0YiO5
00<000000:^Ia02[VL@02P2[VL@010000000[I[300000000000A0?ooo`@00000H`3oool00940oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`02000000<0K7O<00<00000079jc01bN/`0
1@1bN/`00`000000NGk<07Unc00507Unc0040000001nPL`0OX7<07j1c0D000002023Q/h00`000000
R8W>08R9cP0708R9cP030000002=S<d0SHc=00H0SHc=00<0000009:>c02BS/`01`2BS/`00`000000
UY3<09J@c00809J@c0030000002JTl/0VY?;00P0VY?;00<0000009jDbP2NU<X02@2NU<X00`000000
XYK90::Fb@0600000080XIC700<000000:BFaP2TU/H02@2TU/H00`000000YiO50:NGa@090:NGa@03
0000002[VL@0ZiW400T0ZiW40`00000@0?ooo`<00000I`3oool00980oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`020?ooo`8000000P1/Ml`00`000000LW[<079jc004079jc0030000
001iO/`0NGk<00D0NGk<00<0000007j1c01nPL`01@1nPL`4000000H0PhK>00<0000008R9cP28RLh0
1P28RLh00`000000SHc=08f<c@0708f<c@030000002BS/`0TXk<00L0TXk<00<0000009J@c02FT<`0
202FT<`00`000000VY?;09ZCb`0809ZCb`030000002NU<X0WYC:00H0WYC:1@0000090:6Da`030000
002TU/H0Y9K600T0Y9K600<000000:NGa@2WUlD02@2WUlD00`000000ZiW40:^Ia0050:^Ia0<00000
3`3oool4000006X0oooo002C0?ooo`800000=@3oool00`000000oooo0?ooo`040?ooo`<000001`1b
N/`00`000000NGk<07Unc00507Unc0030000001nPL`0OX7<00D0OX7<00<0000008B4b`24Q</01@00
00000`23Q/h0000008R9cP0808R9cP030000002=S<d0SHc=00H0SHc=00<0000009:>c02BS/`01`2B
S/`00`000000UY3<09J@c00809J@c0030000002JTl/0VY?;00P0VY?;00@0000009jDbP2NU<X0WYC:
1@00000209jBa`030000002QU<L0XIC700T0XIC700<000000:BFaP2TU/H02@2TU/H00`000000YiO5
0:NGa@090:NGa@030000002[VL@0ZiW400<0ZiW40P00000>0?ooo`@00000KP3oool009D0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`060?ooo`<000001@1bN/`00`000000NGk<07Un
c00507Unc0030000001nPL`0OX7<00H0OX7<00<0000008B4b`24Q</01024Q</7000000@0R8W>00<0
000008f<c@2=S<d01`2=S<d00`000000TXk<09:>c00709:>c0030000002FT<`0UY3<00P0UY3<00<0
000009ZCb`2JTl/00`2JTl/8000000P0WY;700<000000:6Da`2QU<L02@2QU<L00`000000Y9K60:BF
aP090:BFaP030000002WUlD0YiO500T0YiO500<000000:^Ia00000000P00000<0?ooo`@00000LP3o
ool009H0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`090?ooo`800000101bN/`0
0`000000NGk<07Unc00507Unc0030000001nPL`0OX7<00D0OX7<00<0000008B4b`24Q</01P24Q</0
0`000000RHO;08V7b`0208V7b`X00000102=S<d00`000000TXk<09:>c00709:>c0030000002FT<`0
UY3<00@0UY3<2P00000509Z@b0030000002NT/L0WY;700P0WY;700<000000:6Da`2QU<L02@2QU<L0
0`000000Y9K60:BFaP090:BFaP030000002WUlD0YiO500P0YiO50`00000;0?ooo`@00000MP3oool0
09L0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0;0?ooo`8000000P1bN/`00`00
0000NGk<07Unc00507Unc0030000001nPL`0OX7<00H0OX7<00<0000008B4b`24Q</01P24Q</00`00
0000RHO;08V7b`0608V7b`030000002>R/X0SX[:0080SX[:5@00000409J>b@030000002JT<P0VY38
00T0VY3800<0000009jBa`2NT/L0202NT/L00`000000XIC70:6Da`080:6Da`030000002TU/H0Y9K6
00X0Y9K600<000000:NGa@2WUlD01@2WUlD2000000X0oooo1000001j0?ooo`00V03oool200000300
oooo00<000000?ooo`3oool03@3oool200000003079jc0000000NGk<00H0NGk<00<0000007j1c01n
PL`01@1nPL`00`000000Q8C;08B4b`0608B4b`0300000029Ql/0RHO;00L0RHO;00<0000008j:bP2>
R/X01P2>R/X00`000000TXc:09:<bP0709:<bP030000002FS/T0UXk900P0UXk900<0000009Z@b02J
T<P0202JT<P00`000000WY;709jBa`0809jBa`030000002QU<L0XIC700T0XIC700<000000:BFaP2T
U/H02@2TU/H00`000000YiO50:NGa@020:NGa@<000002@3oool3000007h0oooo002J0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool03`3oool3000000H0NGk<00<0000007j1c01nPL`0
1@1nPL`00`000000Q8C;08B4b`0708B4b`0300000029Ql/0RHO;00H0RHO;00<0000008j:bP2>R/X0
1`2>R/X00`000000TXc:09:<bP0709:<bP030000002FS/T0UXk900L0UXk900<0000009Z@b02JT<P0
2@2JT<P00`000000WY;709jBa`0709jBa`030000002QU<L0XIC700T0XIC700<000000:BFaP2TU/H0
2P2TU/H010000000YiO50000000000080?ooo`@00000P@3oool009/0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0B0?ooo`<00000101iO/`00`000000OX7<07j1c00507j1c0030000
0024Q</0Q8C;00H0Q8C;00<0000008V7b`29Ql/01`29Ql/00`000000SX[:08j:bP0608j:bP030000
002BS<X0TXc:00L0TXc:00<0000009J>b@2FS/T0202FS/T00`000000VY3809Z@b00809Z@b0030000
002NT/L0WY;700P0WY;700<000000:6Da`2QU<L02@2QU<L00`000000Y9K60:BFaP080:BFaP<00000
1P3oool4000008D0oooo002L0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool05@3o
ool5000000L0OX7<00<0000008B4b`24Q</01P24Q</00`000000RHO;08V7b`0708V7b`030000002>
R/X0SX[:00L0SX[:00<0000009:<bP2BS<X01`2BS<X00`000000UXk909J>b@0709J>b@030000002J
T<P0VY3800P0VY3800<0000009jBa`2NT/L0202NT/L00`000000XIC70:6Da`090:6Da`030000002T
U/H0Y9K600@0Y9K6100000050?ooo`@00000R@3oool009d0oooo0P00000[0?ooo`030000003oool0
oooo01T0oooo0`00000607j1c00300000024Q</0Q8C;00H0Q8C;00<0000008V7b`29Ql/01P29Ql/0
0`000000SX[:08j:bP0708j:bP030000002BS<X0TXc:00L0TXc:00<0000009J>b@2FS/T0202FS/T0
0`000000VY3809Z@b00809Z@b0030000002NT/L0WY;700L0WY;700<000000:6Da`2QU<L02P2QU<L0
0`000000Y9K600000003000000D0oooo1000002=0?ooo`00W`3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo01`0oooo0`00000307j1c00300000024Q</0Q8C;00H0Q8C;00<0000008V7
b`29Ql/01`29Ql/00`000000SX[:08j:bP0608j:bP030000002BS<X0TXc:00L0TXc:00<0000009J>
b@2FS/T0202FS/T00`000000VY3809Z@b00809Z@b0030000002NT/L0WY;700P0WY;700<000000:6D
a`2QU<L0202QU<L3000000H0oooo0`00002A0?ooo`00X03oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo01l0oooo0`0000000`1nPL`0000008B4b`0708B4b`0300000029Ql/0RHO;00H0
RHO;00<0000008j:bP2>R/X01`2>R/X00`000000TXc:09:<bP0709:<bP030000002FS/T0UXk900P0
UXk900<0000009Z@b02JT<P01`2JT<P00`000000WY;709jBa`0809jBa`030000002QU<L0XIC700@0
XIC7100000050?ooo`@00000U03oool00:40oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0R0?ooo`@000001P24Q</00`000000RHO;08V7b`0708V7b`030000002>R/X0SX[:00H0SX[:
00<0000009:<bP2BS<X01`2BS<X00`000000UXk909J>b@0809J>b@030000002JT<P0VY3800P0VY38
00<0000009jBa`2NT/L0202NT/L00`000000XIC700000003000000D0oooo1000002H0?ooo`00XP3o
ool2000002H0oooo00<000000?ooo`3oool09P3oool500000080Q8C;00<0000008V7b`29Ql/01P29
Ql/00`000000SX[:08j:bP0708j:bP030000002BS<X0TXc:00L0TXc:00<0000009J>b@2FS/T0202F
S/T00`000000VY3809Z@b00709Z@b0030000002NT/L0WY;700H0WY;7100000050?ooo`@00000W03o
ool00:@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0[0?ooo`L000001@29Ql/0
0`000000SX[:08j:bP0608j:bP030000002BS<X0TXc:00L0TXc:00<0000009J>b@2FS/T0202FS/T0
0`000000VY3809Z@b00809Z@b0030000002NT/L0WY;700D000001@3oool400000:00oooo002U0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0<P3oool:000000D0SX[:00<0000009:<
bP2BS<X01`2BS<X00`000000UXk909J>b@0809J>b@030000002JT<P0VY3800<0VY381`0000060?oo
o`@00000Y03oool00:H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0l0?ooob00
00002P3oool300000:P0oooo002W0?ooo`8000008@3oool00`000000oooo0?ooo`1R0?ooo`@00000
Z`3oool00:T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1N0?ooo`@00000[`3o
ool00:X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1J0?ooo`@00000/`3oool0
0:/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1F0?ooo`@00000]`3oool00:`0
oooo0P00000L0?ooo`030000003oool0oooo0580oooo1000002k0?ooo`00[P3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo04l0oooo0`00002o0?ooo`00[`3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo04/0oooo100000320?ooo`00/03oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo04L0oooo100000360?ooo`00/@3oool2000001L0oooo00<000000?oo
o`3oool0@`3oool400000<X0oooo002c0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0?`3oool400000<h0oooo002d0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
?03oool300000=80oooo002e0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0>03o
ool400000=D0oooo002f0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0=@3oool4
00000=T0oooo002g0?ooo`800000403oool00`000000oooo0?ooo`0a0?ooo`@00000g@3oool00;T0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0]0?ooo`@00000h@3oool00;X0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0Y0?ooo`@00000i@3oool00;/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0V0?ooo`<00000j@3oool00;`0oooo0P00000;
0?ooo`030000003oool0oooo0280oooo1000003/0?ooo`00_P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo01h0oooo1000003`0?ooo`00_`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01X0oooo1000003d0?ooo`00`03oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01H0oooo1000003h0?ooo`00`@3oool2000000H0oooo00<000000?ooo`3oool04`3o
ool300000?`0oooo00330?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool4
00000?l0oooo00340?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool40000
0?l0oooo103oool00<D0oooo00D000000?ooo`3oool0oooo000000090?ooo`@00000o`3oool80?oo
o`00aP3oool2000000030?ooo`000000oooo00@0oooo1000003o0?ooo``0oooo00380?ooo`800000
00<0oooo0000000000000P00003o0?oooa00oooo00390?ooo`800000o`3ooolD0?ooo`00o`3ooooO
0?ooo`00o`3ooooO0?ooo`00o`3ooooO0?ooo`00o`3ooooO0?ooo`00o`3ooooO0?ooo`00o`3ooooO
0?ooo`00o`3ooooO0?ooo`00o`3ooooO0?ooo`00gP3oool01@2LB00000000000000004P0W=oo0?/0
oooo003O0?ooo`030;md001d_ol0oooo0?`0oooo003O0?ooo`030;md001d_ol0oooo0?`0oooo002`
0?ooo`070?oOW0180000000000000018W=l0oooo0=nLB002000000030000B02Lgol0oooo00P0oooo
00<0W4Q807AdB00000000P0000001@0007@0_ooo0?ooo`3oool0W4P000D0000000h004RL0?oOW018
000000000000M02ookl0M0000000B02Lgol0W4P00000B02Lgol0_g@007AdM0<0000000D0001809cO
o`3oool0oooo09a80005000000050018W03oool0oooo0?ooo`2oM0000`0000000`0007@0_ooo0?oo
o`0:0?ooo`0309a8B01dM4P000000080000000D0001d0;ooo`3oool0oooo0=nLB00300000007001d
M01d0000001809cOo`3oool0omnL04P000030000000607AdM000000004RL0?ooo`3ogi`0B0000`00
00001@1dM7@000000018W03oool0W4P000D0000000D004RL0?ooo`3oool0oooo0;md000300000003
0000M02oool0oooo0:H0oooo002a0?ooo`030?oo_`1d07@0_ooo00<0oooo00<0oono07A8W03oool0
2P3oool00`2LB00004RL0?ooo`020?ooo`030?noM018W=l0oooo00<0oooo00<0oono07@0M02oool0
0`3oool03@3ogi`0B4RL0?ooo`3ookl0M01d0;ooo`3oool0W4Q809cOo`3oool0_g@00000M02oool0
0P3oool00`3ogi`0B4RL0?ooo`030?ooo`030?oo_`1d07@0_ooo00@0oooo00<0_g@0001d_`3oool0
0P3oool00`3o_g@004RL0?ooo`0:0?ooo`0309a80000B9`0oooo0080oooo00H0okmd04RLg`3oool0
oono07@0M02oool20?ooo`030;md000007@0_ooo0080oooo00L0W4Q809cOo`3oool0oooo0?oo_`1d
000007Bo0080oooo00L0W4Q809cOo`3oool0oooo0?oo_`1d000007Bo00@0oooo00<0oono07@0M02o
ool0103oool00`2oM00007Bo0?ooo`020?ooo`030?noM000B9`0oooo0:H0oooo002b0?ooo`030=nL
B0000000000000<0000000<0B9cO0?ooo`3oool02@3oool00`2LB4P0W=oo0?ooo`020?ooo`030?oO
W018B9`0oooo00<0oooo00<0oono07@0M02oool00`3oool0303ogi`0B4RL0?ooo`3ookl0M01d0;oo
o`3oool0W4Q809cOo`3oool0_g@007Boo`@0oooo00<0_g@007Boo`3oool00P3oool00`3ookl0M01d
0;ooo`030?ooo`030?oo_`1d07@0_ooo0100oooo00<0W4Q809cOo`3oool00P3oool01P3ogi`0B4RL
0?ooo`3ookl0M01809cOo`80oooo00H0oono07@0M02oool0oooo0?oOW018M;l40?ooo`050?noM000
M;l0oooo0?oOW018M;l0103oool00`3o_g@007Bo0?ooo`030?ooo`030?oo_`1d07@0_ooo00<0oooo
00<0oono07@0M02oool0[03oool00;80oooo00<0oono07A8W03oool00P3oool00`2LB7@0_ooo0?oo
o`0?0?ooo`0309a80000M;l0oooo00<0oooo00<0oono07@0M02oool00`3oool0303ogi`0B4RL0?oo
o`3ookl0M01d0;ooo`3oool0W4Q809cOo`3oool0_g@004RLg`@0oooo00<0_gA809cOo`3oool00P3o
ool00`3ookl0M01d0;ooo`030?ooo`030?oo_`1d0000000000@0000000<004RL0?ooo`3oool03P3o
ool01P2LB00007Bo0?ooo`3oool0omnL04P000<0000000D0001d0;ooo`3oool0omnL04Qd_`040?oo
o`050?noM000M;l0oooo0?oOW018M;l0103oool00`3o_g@007Bo0?ooo`030?ooo`030?oo_`1d07@0
_ooo00<0oooo00<0oono07@000000000100000000`00B9`0oooo0?ooo`2U0?ooo`00/`3oool01@2o
M000M;oo0?ooo`3o_g@007Bo00d0oooo00D0gia8000000000000000004RLg`050?ooo`030?oo_`1d
07@0_ooo00<0oooo00d0omnL04P0001d_ol0omnL04P00018W=l0oono07@0B02Lgol0oooo0;md0000
0000M;oo0080oooo00<0gia80018W03oool00`3oool00`3ookl0M01d0;ooo`040?ooo`030;md001d
_ol0oooo0080oooo00<0W4P004RLg`3oool02`3oool01@3OW4P00000000000000000B9cO00<0oooo
00L0oono0;noo`3oool0oooo0?oOW01807@0_ooo0080oooo00L0W4P004RLg`3oool0oooo0?noM000
000007Bo0080oooo00L0W4P004RLg`3oool0oooo0?noM000000007Bo00@0oooo00<0oono07@0M02o
ool0103oool00`2oM000M;oo0?ooo`020?ooo`0309a80018W=l0oooo0:H0oooo002c0?ooo`050?oO
W018B9`0oooo09a8B02Lgol0303oool00`3OW4P004RL0?ooo`020?ooo`090?noM000M;l0oooo0?oo
o`3ogi`0B0000000000007@0_ooo0080oooo00h0omnL04P00000B4P0M0000000001d_ol0W4P00000
0000M;l0oooo09a800000000M;no07@00080000000<004RL0?ooo`3oool00`3oool00`3ookl0M01d
0;ooo`040?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool02P3oool00`3OW4P004RL
0?ooo`020?ooo`060?noM000M;l0oooo0?ooo`3ogi`0B0000P0000000`0004P0W=oo0?ooo`030?oo
o`0609a80000000000000000M02o_g@007Bo0`3oool01P2LB00000000000000007@0_kmd001d_`@0
oooo00<0oono07@0M02oool0103oool00`3ookl0M000000000020000000304RLg`3oool0oooo0:H0
oooo002d0?ooo`0309a8B02L_i`0B4RL00d0oooo00L0okmd0018W03oool0oooo0?oo_`1d000007Bo
01l0oooo00<0oono07@0M02oool05P3oool01`3o_g@004RL0?ooo`3oool0oono07@00000M;l0403o
ool00`3o_g@007Bo0?ooo`060?ooo`030?noM000M;l0oooo00<0oooo00<0oono07@0M02oool0/P3o
ool00;80oooo00D0W4P0000000000000000007Boo`0>0?ooo`060=nLB000000000000000001dM7@0
07Bo7`3oool00`3ookl0M01d0;ooo`0G0?ooo`060=nLB000000000000000001dM7@007Bo403oool0
0`3o_g@007Bo0?ooo`060?ooo`030?noM000M;l0oooo00<0oooo00<0oono07@0M02oool0/P3oool0
0<l0oooo00<0okmd0000M02oool05P3oool01@3ogi`0B0000000000007@0_ooo02`0oooo00<0okmd
00000000M;l01P3oool00`3o_g@00000001d_`020?ooo`050?oOW018000000000000M02oool0/P3o
ool00<l0oooo00<0okmd0000M02oool0o`3oool=0?ooo`00o`3ooooO0?ooo`00o`3ooooO0?ooo`00
o`3ooooO0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 477.188}, {386.938, 0}} -> {-0.0727371, 0.0240041, \
0.00336325, 0.00336325}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[\(y\^2\) \((1 - x\^2)\), {x, \(-2\), 2}, {y, \(-2\), 2}, 
        PlotLabel \[Rule] "\<A Simple Ridge\>", 
        ViewPoint \[Rule] {\(-0.122\), \ \(-3.114\), \ 1.260}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .64848 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0327587 1.03276 -0.152943 1.03276 [
[.5 .66098 -44 0 ]
[.5 .66098 44 12.5625 ]
[.02543 -0.01288 -5.58431 -9 ]
[.02543 -0.01288 6.41569 0 ]
[.26454 -0.00829 -5.80138 -9 ]
[.26454 -0.00829 6.19862 0 ]
[.50219 -0.00372 -3.00841 -9 ]
[.50219 -0.00372 2.99159 0 ]
[.73839 .00085 -3.11533 -9 ]
[.73839 .00085 2.88467 0 ]
[.97317 .0054 -3.22146 -9 ]
[.97317 .0054 2.77854 0 ]
[1.01291 .36908 0 -4.43379 ]
[1.01291 .36908 12 4.56621 ]
[.96499 .45476 0 -4.43882 ]
[.96499 .45476 12 4.56118 ]
[.92379 .52844 0 -4.44314 ]
[.92379 .52844 6 4.55686 ]
[.88799 .59247 0 -4.44689 ]
[.88799 .59247 6 4.55311 ]
[.85659 .64862 0 -4.45017 ]
[.85659 .64862 6 4.54983 ]
[.00716 .06423 -12 -4.58288 ]
[.00716 .06423 0 4.41712 ]
[.00192 .13996 -24 -4.57852 ]
[.00192 .13996 0 4.42148 ]
[-0.00345 .21742 -6 -4.57407 ]
[-0.00345 .21742 0 4.42593 ]
[-0.00894 .29667 -18 -4.56951 ]
[-0.00894 .29667 0 4.43049 ]
[ 0 0 0 0 ]
[ 1 .64848 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .66098 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
75.000 12.813 moveto
(Simple) show
117.000 12.813 moveto
(Ridge) show
147.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.02454 0 m
.97412 .01827 L
s
.02454 0 m
.02409 .00644 L
s
[(-2)] .02543 -0.01288 -0.06928 1 Mshowa
.26411 .00461 m
.2639 .01106 L
s
[(-1)] .26454 -0.00829 -0.0331 1 Mshowa
.50223 .00919 m
.50224 .01565 L
s
[(0)] .50219 -0.00372 .0028 1 Mshowa
.73889 .01375 m
.73914 .0202 L
s
[(1)] .73839 .00085 .03844 1 Mshowa
.97412 .01827 m
.97459 .02471 L
s
[(2)] .97317 .0054 .07382 1 Mshowa
.125 Mabswid
.07257 .00092 m
.07233 .00479 L
s
.12054 .00185 m
.12033 .00571 L
s
.16846 .00277 m
.16828 .00664 L
s
.21632 .00369 m
.21616 .00756 L
s
.31185 .00553 m
.31175 .0094 L
s
.35953 .00645 m
.35946 .01032 L
s
.40716 .00736 m
.40711 .01124 L
s
.45472 .00828 m
.4547 .01215 L
s
.54967 .01011 m
.54971 .01398 L
s
.59706 .01102 m
.59713 .01489 L
s
.6444 .01193 m
.64449 .0158 L
s
.69167 .01284 m
.69179 .01671 L
s
.78605 .01465 m
.78623 .01852 L
s
.83315 .01556 m
.83336 .01943 L
s
.8802 .01647 m
.88043 .02033 L
s
.92719 .01737 m
.92744 .02123 L
s
.25 Mabswid
1 .36889 m
.84368 .64848 L
s
1 .36889 m
.99355 .36879 L
s
[(-2)] 1.01291 .36908 -1 -0.01471 Mshowa
.95208 .45459 m
.94563 .4545 L
s
[(-1)] .96499 .45476 -1 -0.0136 Mshowa
.91088 .52828 m
.90443 .5282 L
s
[(0)] .92379 .52844 -1 -0.01264 Mshowa
.87508 .59231 m
.86863 .59224 L
s
[(1)] .88799 .59247 -1 -0.0118 Mshowa
.84368 .64848 m
.83722 .64841 L
s
[(2)] .85659 .64862 -1 -0.01107 Mshowa
.125 Mabswid
.9898 .38713 m
.98593 .38707 L
s
.97993 .40479 m
.97605 .40474 L
s
.97036 .42191 m
.96648 .42185 L
s
.96108 .4385 m
.95721 .43844 L
s
.94335 .4702 m
.93948 .47015 L
s
.93488 .48536 m
.93101 .48531 L
s
.92665 .50008 m
.92278 .50003 L
s
.91865 .51438 m
.91478 .51433 L
s
.90333 .54179 m
.89945 .54174 L
s
.89598 .55494 m
.8921 .55489 L
s
.88882 .56773 m
.88495 .56769 L
s
.88186 .58019 m
.87799 .58014 L
s
.86847 .60413 m
.8646 .60408 L
s
.86204 .61564 m
.85817 .6156 L
s
.85576 .62686 m
.85189 .62682 L
s
.84965 .6378 m
.84577 .63776 L
s
.25 Mabswid
.02454 0 m
0 .35417 L
s
.02007 .06447 m
.02652 .06459 L
s
[(-5)] .00716 .06423 1 .01842 Mshowa
.01483 .14018 m
.02128 .1403 L
s
[(-2.5)] .00192 .13996 1 .01745 Mshowa
.00946 .21763 m
.01591 .21774 L
s
[(0)] -0.00345 .21742 1 .01646 Mshowa
.00397 .29687 m
.01042 .29697 L
s
[(2.5)] -0.00894 .29667 1 .01545 Mshowa
.125 Mabswid
.01903 .07948 m
.0229 .07955 L
s
.01799 .09455 m
.02186 .09462 L
s
.01694 .10969 m
.02081 .10976 L
s
.01588 .1249 m
.01976 .12497 L
s
.01376 .15553 m
.01763 .1556 L
s
.01269 .17095 m
.01657 .17102 L
s
.01162 .18644 m
.01549 .18651 L
s
.01054 .202 m
.01442 .20206 L
s
.00837 .23333 m
.01224 .2334 L
s
.00728 .24911 m
.01115 .24917 L
s
.00618 .26496 m
.01005 .26502 L
s
.00508 .28088 m
.00895 .28094 L
s
.02111 .04953 m
.02498 .0496 L
s
.02214 .03466 m
.02601 .03473 L
s
.02316 .01985 m
.02703 .01992 L
s
.02418 .00511 m
.02806 .00518 L
s
.00286 .31294 m
.00673 .313 L
s
.00174 .32908 m
.00561 .32914 L
s
.00061 .3453 m
.00449 .34536 L
s
.25 Mabswid
.02454 0 m
0 .35417 L
s
0 .35417 m
.09041 .64014 L
s
.09041 .64014 m
.1056 .35945 L
s
.1056 .35945 m
.02454 0 L
s
.97412 .01827 m
.8299 .37007 L
s
.8299 .37007 m
.84368 .64848 L
s
.84368 .64848 m
1 .36889 L
s
1 .36889 m
.97412 .01827 L
s
.02454 0 m
0 .35417 L
s
0 .35417 m
1 .36889 L
s
1 .36889 m
.97412 .01827 L
s
.97412 .01827 m
.02454 0 L
s
.1056 .35945 m
.8299 .37007 L
s
.8299 .37007 m
.84368 .64848 L
s
.84368 .64848 m
.09041 .64014 L
s
.09041 .64014 m
.1056 .35945 L
s
0 0 m
1 0 L
1 .64848 L
0 .64848 L
closepath
clip
newpath
.5 Mabswid
.597 .797 .976 r
.103 .34793 .1056 .35945 .13605 .35989 .13376 .34838 Metetra
.047 .338 .817 r
.13376 .34838 .13605 .35989 .16641 .36182 .16318 .37743 Metetra
.892 .496 .262 r
.16318 .37743 .16641 .36182 .19476 .41236 .19225 .42061 Metetra
.857 .403 .068 r
.19225 .42061 .19476 .41236 .2237 .45821 .22182 .45971 Metetra
.694 .195 0 r
.22182 .45971 .2237 .45821 .25316 .49918 .25184 .49458 Metetra
0 .136 .659 r
.25184 .49458 .25316 .49918 .2831 .53509 .28227 .52512 Metetra
.101 .399 .853 r
.28227 .52512 .2831 .53509 .31344 .56579 .31304 .5512 Metetra
.349 .529 .892 r
.31304 .5512 .31344 .56579 .34413 .59116 .34409 .57273 Metetra
.488 .593 .885 r
.34409 .57273 .34413 .59116 .37508 .61107 .37538 .58963 Metetra
.572 .632 .873 r
.37538 .58963 .37508 .61107 .40624 .62545 .40683 .60185 Metetra
.597 .797 .976 r
.80432 .35832 .79999 .36963 .8299 .37007 .83453 .35876 Metetra
.367 .05 .289 r
.77528 .38627 .77011 .37066 .79999 .36963 .80432 .35832 Metetra
.086 0 .157 r
.74648 .42831 .74198 .42002 .77011 .37066 .77528 .38627 Metetra
.71716 .46635 .71324 .46478 .74198 .42002 .74648 .42831 Metetra
.566 .841 .498 r
.68737 .50023 .68396 .50474 .71324 .46478 .71716 .46635 Metetra
.808 .997 .776 r
.65715 .52983 .65419 .53971 .68396 .50474 .68737 .50023 Metetra
.861 .967 .865 r
.62656 .55504 .62399 .56954 .65419 .53971 .65715 .52983 Metetra
.843 .897 .877 r
.59565 .57574 .59342 .59408 .62399 .56954 .62656 .55504 Metetra
.81 .835 .87 r
.56448 .59185 .56256 .61323 .59342 .59408 .59565 .57574 Metetra
.776 .786 .861 r
.5331 .60331 .53147 .62687 .56256 .61323 .56448 .59185 Metetra
.743 .747 .855 r
.50159 .61007 .50022 .63495 .53147 .62687 .5331 .60331 Metetra
.71 .715 .854 r
.47 .61208 .46888 .63741 .50022 .63495 .50159 .61007 Metetra
.673 .688 .856 r
.43839 .60934 .43753 .63425 .46888 .63741 .47 .61208 Metetra
.629 .661 .862 r
.40683 .60185 .40624 .62545 .43753 .63425 .43839 .60934 Metetra
.322 .585 .938 r
.10035 .33618 .103 .34793 .13376 .34838 .13068 .35142 Metetra
.803 .33 0 r
.13068 .35142 .13376 .34838 .16318 .37743 .15998 .39108 Metetra
.866 .443 .213 r
.15998 .39108 .16318 .37743 .19225 .42061 .18975 .42737 Metetra
.81 .323 0 r
.18975 .42737 .19225 .42061 .22182 .45971 .21994 .46017 Metetra
.602 .076 0 r
.21994 .46017 .22182 .45971 .25184 .49458 .25051 .48939 Metetra
0 .255 .747 r
.25051 .48939 .25184 .49458 .28227 .52512 .28142 .51494 Metetra
.179 .474 .893 r
.28142 .51494 .28227 .52512 .31304 .5512 .31261 .53674 Metetra
.391 .574 .911 r
.31261 .53674 .31304 .5512 .34409 .57273 .34404 .55474 Metetra
.51 .623 .899 r
.34404 .55474 .34409 .57273 .37538 .58963 .37566 .56887 Metetra
.583 .652 .884 r
.37566 .56887 .37538 .58963 .40683 .60185 .40742 .5791 Metetra
.094 0 0 r
.80943 .36144 .80432 .35832 .83453 .35876 .83926 .34723 Metetra
.255 0 .267 r
.78048 .39993 .77528 .38627 .80432 .35832 .80943 .36144 Metetra
.075 0 .085 r
.75104 .43512 .74648 .42831 .77528 .38627 .78048 .39993 Metetra
.72115 .46688 .71716 .46635 .74648 .42831 .75104 .43512 Metetra
.592 .896 .615 r
.69084 .49512 .68737 .50023 .71716 .46635 .72115 .46688 Metetra
.794 .999 .839 r
.66018 .51975 .65715 .52983 .68737 .50023 .69084 .49512 Metetra
.832 .953 .895 r
.62919 .54068 .62656 .55504 .65715 .52983 .66018 .51975 Metetra
.816 .886 .894 r
.59792 .55784 .59565 .57574 .62656 .55504 .62919 .54068 Metetra
.789 .829 .883 r
.56644 .57117 .56448 .59185 .59565 .57574 .59792 .55784 Metetra
.761 .784 .872 r
.53478 .58062 .5331 .60331 .56448 .59185 .56644 .57117 Metetra
.733 .75 .866 r
.50299 .58615 .50159 .61007 .5331 .60331 .53478 .58062 Metetra
.704 .721 .863 r
.47114 .58775 .47 .61208 .50159 .61007 .50299 .58615 Metetra
.672 .698 .866 r
.43926 .5854 .43839 .60934 .47 .61208 .47114 .58775 Metetra
.633 .675 .872 r
.40742 .5791 .40683 .60185 .43839 .60934 .43926 .5854 Metetra
.64 .152 0 r
.09708 .33445 .10035 .33618 .13068 .35142 .12673 .36994 Metetra
.847 .452 .297 r
.12673 .36994 .13068 .35142 .15998 .39108 .1568 .40267 Metetra
.829 .376 .147 r
.1568 .40267 .15998 .39108 .18975 .42737 .18725 .43257 Metetra
.743 .22 0 r
.18725 .43257 .18975 .42737 .21994 .46017 .21805 .45955 Metetra
.48 0 0 r
.21805 .45955 .21994 .46017 .25051 .48939 .24916 .48357 Metetra
0 .373 .825 r
.24916 .48357 .25051 .48939 .28142 .51494 .28055 .50454 Metetra
.252 .543 .925 r
.28055 .50454 .28142 .51494 .31261 .53674 .31217 .52244 Metetra
.43 .616 .928 r
.31217 .52244 .31261 .53674 .34404 .55474 .34398 .53721 Metetra
.53 .65 .911 r
.34398 .53721 .34404 .55474 .37566 .56887 .37593 .54881 Metetra
.593 .672 .895 r
.37593 .54881 .37566 .56887 .40742 .5791 .408 .55723 Metetra
.367 .076 .332 r
.81539 .37995 .80943 .36144 .83926 .34723 .84461 .34565 Metetra
.253 0 .206 r
.78573 .41155 .78048 .39993 .80943 .36144 .81539 .37995 Metetra
.054 0 0 r
.75565 .44038 .75104 .43512 .78048 .39993 .78573 .41155 Metetra
.72519 .46635 .72115 .46688 .75104 .43512 .75565 .44038 Metetra
.61 .936 .727 r
.69438 .4894 .69084 .49512 .72115 .46688 .72519 .46635 Metetra
.771 .989 .891 r
.66326 .50946 .66018 .51975 .69084 .49512 .69438 .4894 Metetra
.801 .936 .919 r
.63188 .52647 .62919 .54068 .66018 .51975 .66326 .50946 Metetra
.789 .873 .91 r
.60026 .54039 .59792 .55784 .62919 .54068 .63188 .52647 Metetra
.768 .822 .895 r
.56845 .55118 .56644 .57117 .59792 .55784 .60026 .54039 Metetra
.745 .783 .883 r
.53649 .5588 .53478 .58062 .56644 .57117 .56845 .55118 Metetra
.722 .752 .876 r
.50442 .56322 .50299 .58615 .53478 .58062 .53649 .5588 Metetra
.697 .728 .874 r
.47229 .56444 .47114 .58775 .50299 .58615 .50442 .56322 Metetra
.67 .708 .876 r
.44013 .56245 .43926 .5854 .47114 .58775 .47229 .56444 Metetra
.637 .69 .883 r
.408 .55723 .40742 .5791 .43926 .5854 .44013 .56245 Metetra
.821 .446 .345 r
.09236 .35712 .09708 .33445 .12673 .36994 .12283 .38575 Metetra
.814 .391 .238 r
.12283 .38575 .12673 .36994 .1568 .40267 .15364 .41211 Metetra
.776 .287 .058 r
.15364 .41211 .1568 .40267 .18725 .43257 .18476 .43615 Metetra
.645 .087 0 r
.18476 .43615 .18725 .43257 .21805 .45955 .21616 .45783 Metetra
0 .221 .64 r
.21616 .45783 .21805 .45955 .24916 .48357 .2478 .4771 Metetra
.057 .482 .889 r
.2478 .4771 .24916 .48357 .28055 .50454 .27966 .49393 Metetra
.319 .605 .95 r
.27966 .49393 .28055 .50454 .31217 .52244 .3117 .50828 Metetra
.464 .654 .942 r
.3117 .50828 .31217 .52244 .34398 .53721 .34389 .52013 Metetra
.548 .677 .923 r
.34389 .52013 .34398 .53721 .37593 .54881 .3762 .52946 Metetra
.601 .692 .906 r
.3762 .52946 .37593 .54881 .408 .55723 .40858 .53625 Metetra
.368 .043 .276 r
.82137 .39576 .81539 .37995 .84461 .34565 .85136 .36827 Metetra
.241 0 .122 r
.79101 .42103 .78573 .41155 .81539 .37995 .82137 .39576 Metetra
.02 0 0 r
.76031 .44404 .75565 .44038 .78573 .41155 .79101 .42103 Metetra
.72929 .46472 .72519 .46635 .75565 .44038 .76031 .44404 Metetra
.615 .955 .825 r
.69798 .48304 .69438 .4894 .72519 .46635 .72929 .46472 Metetra
.741 .97 .931 r
.66642 .49895 .66326 .50946 .69438 .4894 .69798 .48304 Metetra
.767 .916 .938 r
.63463 .51242 .63188 .52647 .66326 .50946 .66642 .49895 Metetra
.761 .861 .923 r
.60265 .52341 .60026 .54039 .63188 .52647 .63463 .51242 Metetra
.747 .817 .907 r
.5705 .5319 .56845 .55118 .60026 .54039 .60265 .52341 Metetra
.729 .782 .895 r
.53824 .53786 .53649 .5588 .56845 .55118 .5705 .5319 Metetra
.711 .756 .887 r
.50587 .54129 .50442 .56322 .53649 .5588 .53824 .53786 Metetra
.69 .735 .885 r
.47346 .54217 .47229 .56444 .50442 .56322 .50587 .54129 Metetra
.667 .718 .887 r
.44101 .54048 .44013 .56245 .47229 .56444 .47346 .54217 Metetra
.639 .704 .894 r
.40858 .53625 .408 .55723 .44013 .56245 .44101 .54048 Metetra
.79 .387 .287 r
.08773 .37631 .09236 .35712 .12283 .38575 .11899 .3987 Metetra
.768 .308 .155 r
.11899 .3987 .12283 .38575 .15364 .41211 .15052 .41929 Metetra
.698 .166 0 r
.15052 .41929 .15364 .41211 .18476 .43615 .18229 .43805 Metetra
.508 0 0 r
.18229 .43805 .18476 .43615 .21616 .45783 .21426 .45496 Metetra
0 .379 .762 r
.21426 .45496 .21616 .45783 .2478 .4771 .24643 .46998 Metetra
.171 .576 .936 r
.24643 .46998 .2478 .4771 .27966 .49393 .27876 .48309 Metetra
.378 .658 .967 r
.27876 .48309 .27966 .49393 .3117 .50828 .31122 .49428 Metetra
.494 .688 .954 r
.31122 .49428 .3117 .50828 .34389 .52013 .34379 .50353 Metetra
.563 .702 .934 r
.34379 .50353 .34389 .52013 .3762 .52946 .37645 .51083 Metetra
.608 .71 .917 r
.37645 .51083 .3762 .52946 .40858 .53625 .40916 .51616 Metetra
.36 0 .197 r
.82737 .40873 .82137 .39576 .85136 .36827 .8581 .38743 Metetra
.214 0 .004 r
.79633 .42828 .79101 .42103 .82137 .39576 .82737 .40873 Metetra
.76502 .44602 .76031 .44404 .79101 .42103 .79633 .42828 Metetra
.366 .812 .674 r
.73345 .46195 .72929 .46472 .76031 .44404 .76502 .44602 Metetra
.609 .953 .9 r
.70165 .47602 .69798 .48304 .72929 .46472 .73345 .46195 Metetra
.707 .944 .958 r
.66964 .48821 .66642 .49895 .69798 .48304 .70165 .47602 Metetra
.733 .896 .953 r
.63745 .49851 .63463 .51242 .66642 .49895 .66964 .48821 Metetra
.733 .849 .935 r
.6051 .50689 .60265 .52341 .63463 .51242 .63745 .49851 Metetra
.725 .811 .919 r
.57261 .51333 .5705 .5319 .60265 .52341 .6051 .50689 Metetra
.713 .782 .906 r
.54003 .51783 .53824 .53786 .5705 .5319 .57261 .51333 Metetra
.699 .76 .899 r
.50736 .52036 .50587 .54129 .53824 .53786 .54003 .51783 Metetra
.682 .743 .897 r
.47464 .52093 .47346 .54217 .50587 .54129 .50736 .52036 Metetra
.663 .729 .899 r
.4419 .51953 .44101 .54048 .47346 .54217 .47464 .52093 Metetra
.64 .719 .905 r
.40916 .51616 .40858 .53625 .44101 .54048 .4419 .51953 Metetra
.745 .304 .203 r
.0832 .39182 .08773 .37631 .11899 .3987 .11522 .40865 Metetra
.698 .193 .035 r
.11522 .40865 .11899 .3987 .15052 .41929 .14744 .42412 Metetra
.578 .005 0 r
.14744 .42412 .15052 .41929 .18229 .43805 .17983 .43821 Metetra
.328 0 0 r
.17983 .43821 .18229 .43805 .21426 .45496 .21237 .45089 Metetra
.007 .52 .861 r
.21237 .45089 .21426 .45496 .24643 .46998 .24504 .46217 Metetra
.271 .653 .967 r
.24504 .46217 .24643 .46998 .27876 .48309 .27783 .47201 Metetra
.429 .702 .979 r
.27783 .47201 .27876 .48309 .31122 .49428 .31072 .48043 Metetra
.52 .718 .963 r
.31072 .48043 .31122 .49428 .34379 .50353 .34367 .4874 Metetra
.576 .724 .944 r
.34367 .4874 .34379 .50353 .37645 .51083 .37669 .49292 Metetra
.613 .729 .928 r
.37669 .49292 .37645 .51083 .40916 .51616 .40974 .49699 Metetra
.336 0 .081 r
.83336 .41873 .82737 .40873 .8581 .38743 .86481 .40295 Metetra
.162 0 0 r
.80168 .43318 .79633 .42828 .82737 .40873 .83336 .41873 Metetra
.76977 .44627 .76502 .44602 .79633 .42828 .80168 .43318 Metetra
.409 .859 .809 r
.73767 .45799 .73345 .46195 .76502 .44602 .76977 .44627 Metetra
.595 .934 .95 r
.70538 .46832 .70165 .47602 .73345 .46195 .73767 .45799 Metetra
.673 .915 .975 r
.67293 .47725 .66964 .48821 .70165 .47602 .70538 .46832 Metetra
.699 .875 .964 r
.64033 .48476 .63745 .49851 .66964 .48821 .67293 .47725 Metetra
.705 .837 .945 r
.60761 .49085 .6051 .50689 .63745 .49851 .64033 .48476 Metetra
.702 .807 .93 r
.57478 .4955 .57261 .51333 .6051 .50689 .60761 .49085 Metetra
.695 .783 .918 r
.54186 .4987 .54003 .51783 .57261 .51333 .57478 .4955 Metetra
.686 .765 .911 r
.50888 .50046 .50736 .52036 .54003 .51783 .54186 .4987 Metetra
.673 .751 .909 r
.47585 .50076 .47464 .52093 .50736 .52036 .50888 .50046 Metetra
.658 .741 .911 r
.4428 .4996 .4419 .51953 .47464 .52093 .47585 .50076 Metetra
.639 .734 .917 r
.40974 .49699 .40916 .51616 .4419 .51953 .4428 .4996 Metetra
.674 .184 .076 r
.07878 .40346 .0832 .39182 .11522 .40865 .11152 .41547 Metetra
.584 .028 0 r
.11152 .41547 .11522 .40865 .14744 .42412 .14439 .4265 Metetra
.401 0 0 r
.14439 .4265 .14744 .42412 .17983 .43821 .17738 .43655 Metetra
0 .458 .747 r
.17738 .43655 .17983 .43821 .21237 .45089 .21047 .4456 Metetra
.162 .634 .93 r
.21047 .4456 .21237 .45089 .24504 .46217 .24364 .45365 Metetra
.355 .711 .986 r
.24364 .45365 .24504 .46217 .27783 .47201 .27689 .46069 Metetra
.471 .737 .986 r
.27689 .46069 .27783 .47201 .31072 .48043 .31019 .46673 Metetra
.541 .744 .97 r
.31019 .46673 .31072 .48043 .34367 .4874 .34354 .47175 Metetra
.585 .745 .953 r
.34354 .47175 .34367 .4874 .37669 .49292 .37692 .47576 Metetra
.615 .746 .939 r
.37692 .47576 .37669 .49292 .40974 .49699 .41031 .47875 Metetra
.28 0 0 r
.83935 .42562 .83336 .41873 .86481 .40295 .87149 .41463 Metetra
.07 0 0 r
.80705 .43565 .80168 .43318 .83336 .41873 .83935 .42562 Metetra
.205 .723 .695 r
.77457 .44472 .76977 .44627 .80168 .43318 .80705 .43565 Metetra
.443 .875 .905 r
.74195 .45282 .73767 .45799 .76977 .44627 .77457 .44472 Metetra
.578 .907 .979 r
.70918 .45993 .70538 .46832 .73767 .45799 .74195 .45282 Metetra
.641 .886 .985 r
.67629 .46605 .67293 .47725 .70538 .46832 .70918 .45993 Metetra
.668 .855 .971 r
.64329 .47117 .64033 .48476 .67293 .47725 .67629 .46605 Metetra
.678 .827 .955 r
.61019 .47529 .60761 .49085 .64033 .48476 .64329 .47117 Metetra
.68 .803 .941 r
.577 .47841 .57478 .4955 .60761 .49085 .61019 .47529 Metetra
.677 .784 .93 r
.54375 .48051 .54186 .4987 .57478 .4955 .577 .47841 Metetra
.672 .77 .924 r
.51044 .4816 .50888 .50046 .54186 .4987 .54375 .48051 Metetra
.663 .76 .922 r
.47708 .48167 .47585 .50076 .50888 .50046 .51044 .4816 Metetra
.651 .753 .924 r
.4437 .48072 .4428 .4996 .47585 .50076 .47708 .48167 Metetra
.636 .748 .929 r
.41031 .47875 .40974 .49699 .4428 .4996 .4437 .48072 Metetra
.551 0 0 r
.07449 .41104 .07878 .40346 .11152 .41547 .10791 .419 Metetra
.398 0 0 r
.10791 .419 .11152 .41547 .14439 .4265 .1414 .42632 Metetra
.166 0 0 r
.1414 .42632 .14439 .4265 .17738 .43655 .17496 .433 Metetra
.09 .616 .875 r
.17496 .433 .17738 .43655 .21047 .4456 .20857 .43903 Metetra
.291 .715 .971 r
.20857 .43903 .21047 .4456 .24364 .45365 .24223 .4444 Metetra
.423 .753 .995 r
.24223 .4444 .24364 .45365 .27689 .46069 .27592 .44913 Metetra
.504 .764 .989 r
.27592 .44913 .27689 .46069 .31019 .46673 .30964 .45319 Metetra
.556 .765 .975 r
.30964 .45319 .31019 .46673 .34354 .47175 .34338 .4566 Metetra
.59 .763 .961 r
.34338 .4566 .34354 .47175 .37692 .47576 .37713 .45936 Metetra
.614 .762 .95 r
.37713 .45936 .37692 .47576 .41031 .47875 .41088 .46145 Metetra
.169 0 0 r
.84533 .42926 .83935 .42562 .87149 .41463 .87811 .42229 Metetra
.81243 .4356 .80705 .43565 .83935 .42562 .84533 .42926 Metetra
.3 .795 .851 r
.77941 .4413 .77457 .44472 .80705 .43565 .81243 .4356 Metetra
.467 .869 .962 r
.74628 .44638 .74195 .45282 .77457 .44472 .77941 .4413 Metetra
.563 .877 .993 r
.71305 .45081 .70918 .45993 .74195 .45282 .74628 .44638 Metetra
.613 .86 .99 r
.67973 .4546 .67629 .46605 .70918 .45993 .71305 .45081 Metetra
.639 .838 .977 r
.64632 .45774 .64329 .47117 .67629 .46605 .67973 .4546 Metetra
.652 .818 .963 r
.61284 .46023 .61019 .47529 .64329 .47117 .64632 .45774 Metetra
.658 .8 .951 r
.57929 .46207 .577 .47841 .61019 .47529 .61284 .46023 Metetra
.659 .787 .942 r
.54568 .46326 .54375 .48051 .577 .47841 .57929 .46207 Metetra
.656 .776 .937 r
.51203 .4638 .51044 .4816 .54375 .48051 .54568 .46326 Metetra
.651 .769 .935 r
.47834 .46367 .47708 .48167 .51044 .4816 .51203 .4638 Metetra
.642 .764 .937 r
.44462 .46289 .4437 .48072 .47708 .48167 .47834 .46367 Metetra
.631 .762 .942 r
.41088 .46145 .41031 .47875 .4437 .48072 .44462 .46289 Metetra
.329 0 0 r
.07034 .41437 .07449 .41104 .10791 .419 .10439 .41912 Metetra
.128 0 0 r
.10439 .41912 .10791 .419 .1414 .42632 .13846 .4235 Metetra
.087 .628 .849 r
.13846 .4235 .1414 .42632 .17496 .433 .17255 .42751 Metetra
.265 .724 .953 r
.17255 .42751 .17496 .433 .20857 .43903 .20667 .43114 Metetra
.391 .767 .992 r
.20667 .43114 .20857 .43903 .24223 .4444 .2408 .43441 Metetra
.475 .782 .998 r
.2408 .43441 .24223 .4444 .27592 .44913 .27493 .4373 Metetra
.53 .785 .991 r
.27493 .4373 .27592 .44913 .30964 .45319 .30907 .43982 Metetra
.567 .782 .98 r
.30907 .43982 .30964 .45319 .34338 .4566 .34321 .44196 Metetra
.592 .779 .969 r
.34321 .44196 .34338 .4566 .37713 .45936 .37734 .44373 Metetra
.61 .777 .96 r
.37734 .44373 .37713 .45936 .41088 .46145 .41145 .44513 Metetra
.85129 .4295 .84533 .42926 .87811 .42229 .88466 .42574 Metetra
.219 .741 .834 r
.81783 .43291 .81243 .4356 .84533 .42926 .85129 .4295 Metetra
.38 .824 .945 r
.7843 .43595 .77941 .4413 .81243 .4356 .81783 .43291 Metetra
.487 .852 .99 r
.75068 .43863 .74628 .44638 .77941 .4413 .7843 .43595 Metetra
.552 .851 .998 r
.71699 .44095 .71305 .45081 .74628 .44638 .75068 .43863 Metetra
.591 .839 .992 r
.68324 .44289 .67973 .4546 .71305 .45081 .71699 .44095 Metetra
.614 .824 .981 r
.64943 .44447 .64632 .45774 .67973 .4546 .68324 .44289 Metetra
.628 .811 .97 r
.61555 .44568 .61284 .46023 .64632 .45774 .64943 .44447 Metetra
.636 .799 .961 r
.58163 .44652 .57929 .46207 .61284 .46023 .61555 .44568 Metetra
.639 .79 .954 r
.54767 .44698 .54568 .46326 .57929 .46207 .58163 .44652 Metetra
.639 .783 .95 r
.51366 .44708 .51203 .4638 .54568 .46326 .54767 .44698 Metetra
.637 .778 .949 r
.47962 .4468 .47834 .46367 .51203 .4638 .51366 .44708 Metetra
.631 .776 .95 r
.44555 .44615 .44462 .46289 .47834 .46367 .47962 .4468 Metetra
.622 .775 .954 r
.41145 .44513 .41088 .46145 .44462 .46289 .44555 .44615 Metetra
.005 .579 .757 r
.06635 .41328 .07034 .41437 .10439 .41912 .10096 .41569 Metetra
.167 .687 .884 r
.10096 .41569 .10439 .41912 .13846 .4235 .13557 .41793 Metetra
.299 .752 .956 r
.13557 .41793 .13846 .4235 .17255 .42751 .17017 .42 Metetra
.396 .784 .989 r
.17017 .42 .17255 .42751 .20667 .43114 .20477 .4219 Metetra
.465 .797 .999 r
.20477 .4219 .20667 .43114 .2408 .43441 .23935 .42364 Metetra
.513 .8 .998 r
.23935 .42364 .2408 .43441 .27493 .4373 .27392 .4252 Metetra
.547 .799 .991 r
.27392 .4252 .27493 .4373 .30907 .43982 .30848 .4266 Metetra
.572 .795 .984 r
.30848 .4266 .30907 .43982 .34321 .44196 .34301 .42783 Metetra
.589 .792 .976 r
.34301 .42783 .34321 .44196 .37734 .44373 .37753 .42889 Metetra
.602 .789 .97 r
.37753 .42889 .37734 .44373 .41145 .44513 .41202 .42979 Metetra
.232 .743 .878 r
.85722 .42624 .85129 .4295 .88466 .42574 .89113 .4248 Metetra
.356 .802 .953 r
.82324 .4275 .81783 .43291 .85129 .4295 .85722 .42624 Metetra
.444 .827 .988 r
.78921 .42861 .7843 .43595 .81783 .43291 .82324 .4275 Metetra
.505 .833 .999 r
.75514 .42954 .75068 .43863 .7843 .43595 .78921 .42861 Metetra
.547 .83 .998 r
.72101 .43032 .71699 .44095 .75068 .43863 .75514 .42954 Metetra
.574 .823 .992 r
.68683 .43092 .68324 .44289 .71699 .44095 .72101 .43032 Metetra
.593 .814 .984 r
.65261 .43136 .64943 .44447 .68324 .44289 .68683 .43092 Metetra
.606 .807 .977 r
.61835 .43164 .61555 .44568 .64943 .44447 .65261 .43136 Metetra
.614 .8 .971 r
.58405 .43175 .58163 .44652 .61555 .44568 .61835 .43164 Metetra
.619 .794 .966 r
.54971 .43169 .54767 .44698 .58163 .44652 .58405 .43175 Metetra
.62 .791 .963 r
.51533 .43147 .51366 .44708 .54767 .44698 .54971 .43169 Metetra
.62 .788 .962 r
.48092 .43107 .47962 .4468 .51366 .44708 .51533 .43147 Metetra
.617 .787 .963 r
.44649 .43051 .44555 .44615 .47962 .4468 .48092 .43107 Metetra
.611 .788 .966 r
.41202 .42979 .41145 .44513 .44555 .44615 .44649 .43051 Metetra
.323 .771 .958 r
.06253 .4076 .06635 .41328 .10096 .41569 .09765 .40858 Metetra
.391 .794 .984 r
.09765 .40858 .10096 .41569 .13557 .41793 .13275 .40951 Metetra
.444 .805 .996 r
.13275 .40951 .13557 .41793 .17017 .42 .16782 .41041 Metetra
.485 .81 1 r
.16782 .41041 .17017 .42 .20477 .4219 .20287 .41126 Metetra
.516 .811 .999 r
.20287 .41126 .20477 .4219 .23935 .42364 .23789 .41206 Metetra
.54 .809 .996 r
.23789 .41206 .23935 .42364 .27392 .4252 .27289 .41283 Metetra
.558 .807 .991 r
.27289 .41283 .27392 .4252 .30848 .4266 .30786 .41355 Metetra
.572 .804 .987 r
.30786 .41355 .30848 .4266 .34301 .42783 .34279 .41423 Metetra
.582 .802 .983 r
.34279 .41423 .34301 .42783 .37753 .42889 .37771 .41487 Metetra
.59 .8 .98 r
.37771 .41487 .37753 .42889 .41202 .42979 .41259 .41546 Metetra
.406 .807 .984 r
.8631 .41932 .85722 .42624 .89113 .4248 .89751 .41932 Metetra
.458 .817 .996 r
.82865 .41928 .82324 .4275 .85722 .42624 .8631 .41932 Metetra
.496 .82 1 r
.79417 .41919 .78921 .42861 .82324 .4275 .82865 .41928 Metetra
.526 .819 .999 r
.75965 .41906 .75514 .42954 .78921 .42861 .79417 .41919 Metetra
.548 .816 .996 r
.7251 .41889 .72101 .43032 .75514 .42954 .75965 .41906 Metetra
.565 .813 .992 r
.6905 .41868 .68683 .43092 .72101 .43032 .7251 .41889 Metetra
.577 .809 .987 r
.65588 .41843 .65261 .43136 .68683 .43092 .6905 .41868 Metetra
.586 .805 .983 r
.62122 .41813 .61835 .43164 .65261 .43136 .65588 .41843 Metetra
.593 .802 .98 r
.58653 .41779 .58405 .43175 .61835 .43164 .62122 .41813 Metetra
.597 .8 .977 r
.5518 .41741 .54971 .43169 .58405 .43175 .58653 .41779 Metetra
.599 .798 .976 r
.51705 .41699 .51533 .43147 .54971 .43169 .5518 .41741 Metetra
.6 .797 .975 r
.48226 .41652 .48092 .43107 .51533 .43147 .51705 .41699 Metetra
.598 .797 .976 r
.44744 .41601 .44649 .43051 .48092 .43107 .48226 .41652 Metetra
.595 .798 .977 r
.41259 .41546 .41202 .42979 .44649 .43051 .44744 .41601 Metetra
.508 .815 1 r
.05889 .39715 .06253 .4076 .09765 .40858 .09446 .39766 Metetra
.521 .815 .999 r
.09446 .39766 .09765 .40858 .13275 .40951 .13 .39816 Metetra
.532 .814 .998 r
.13 .39816 .13275 .40951 .16782 .41041 .1655 .39866 Metetra
.541 .813 .996 r
.1655 .39866 .16782 .41041 .20287 .41126 .20098 .39917 Metetra
.549 .812 .995 r
.20098 .39917 .20287 .41126 .23789 .41206 .23642 .39967 Metetra
.556 .811 .993 r
.23642 .39967 .23789 .41206 .27289 .41283 .27183 .40017 Metetra
.561 .809 .991 r
.27183 .40017 .27289 .41283 .30786 .41355 .30721 .40067 Metetra
.566 .808 .99 r
.30721 .40067 .30786 .41355 .34279 .41423 .34256 .40117 Metetra
.569 .808 .989 r
.34256 .40117 .34279 .41423 .37771 .41487 .37787 .40167 Metetra
.572 .807 .988 r
.37787 .40167 .37771 .41487 .41259 .41546 .41315 .40217 Metetra
.521 .815 .999 r
.86893 .40863 .8631 .41932 .89751 .41932 .90377 .40913 Metetra
.532 .814 .998 r
.83406 .40814 .82865 .41928 .8631 .41932 .86893 .40863 Metetra
.541 .813 .996 r
.79916 .40765 .79417 .41919 .82865 .41928 .83406 .40814 Metetra
.549 .812 .995 r
.76422 .40715 .75965 .41906 .79417 .41919 .79916 .40765 Metetra
.556 .811 .993 r
.72926 .40665 .7251 .41889 .75965 .41906 .76422 .40715 Metetra
.561 .809 .991 r
.69426 .40616 .6905 .41868 .7251 .41889 .72926 .40665 Metetra
.566 .808 .99 r
.65924 .40566 .65588 .41843 .6905 .41868 .69426 .40616 Metetra
.569 .808 .989 r
.62418 .40517 .62122 .41813 .65588 .41843 .65924 .40566 Metetra
.572 .807 .988 r
.58908 .40467 .58653 .41779 .62122 .41813 .62418 .40517 Metetra
.574 .806 .987 r
.55396 .40417 .5518 .41741 .58653 .41779 .58908 .40467 Metetra
.575 .806 .987 r
.51881 .40367 .51705 .41699 .5518 .41741 .55396 .40417 Metetra
.575 .806 .987 r
.48362 .40317 .48226 .41652 .51705 .41699 .51881 .40367 Metetra
.575 .806 .987 r
.4484 .40267 .44744 .41601 .48226 .41652 .48362 .40317 Metetra
.574 .806 .987 r
.41315 .40217 .41259 .41546 .44744 .41601 .4484 .40267 Metetra
.592 .793 .976 r
.05544 .3818 .05889 .39715 .09446 .39766 .09139 .38281 Metetra
.586 .796 .979 r
.09139 .38281 .09446 .39766 .13 .39816 .12732 .38378 Metetra
.579 .799 .983 r
.12732 .38378 .13 .39816 .1655 .39866 .16322 .3847 Metetra
.573 .801 .985 r
.16322 .3847 .1655 .39866 .20098 .39917 .19909 .38558 Metetra
.568 .803 .988 r
.19909 .38558 .20098 .39917 .23642 .39967 .23493 .38642 Metetra
.562 .805 .99 r
.23493 .38642 .23642 .39967 .27183 .40017 .27075 .38722 Metetra
.558 .807 .991 r
.27075 .38722 .27183 .40017 .30721 .40067 .30654 .38796 Metetra
.554 .808 .993 r
.30654 .38796 .30721 .40067 .34256 .40117 .34229 .38867 Metetra
.551 .809 .994 r
.34229 .38867 .34256 .40117 .37787 .40167 .37802 .38933 Metetra
.548 .81 .994 r
.37802 .38933 .37787 .40167 .41315 .40217 .41372 .38995 Metetra
.597 .806 .98 r
.8747 .39406 .86893 .40863 .90377 .40913 .9099 .39408 Metetra
.59 .808 .983 r
.83945 .394 .83406 .40814 .86893 .40863 .8747 .39406 Metetra
.583 .81 .986 r
.80417 .3939 .79916 .40765 .83406 .40814 .83945 .394 Metetra
.576 .811 .988 r
.76886 .39376 .76422 .40715 .79916 .40765 .80417 .3939 Metetra
.57 .812 .99 r
.7335 .39357 .72926 .40665 .76422 .40715 .76886 .39376 Metetra
.565 .813 .992 r
.69811 .39334 .69426 .40616 .72926 .40665 .7335 .39357 Metetra
.559 .813 .993 r
.66268 .39307 .65924 .40566 .69426 .40616 .69811 .39334 Metetra
.555 .813 .994 r
.62722 .39276 .62418 .40517 .65924 .40566 .66268 .39307 Metetra
.551 .813 .994 r
.59172 .3924 .58908 .40467 .62418 .40517 .62722 .39276 Metetra
.549 .813 .995 r
.55618 .39199 .55396 .40417 .58908 .40467 .59172 .3924 Metetra
.547 .813 .995 r
.52062 .39155 .51881 .40367 .55396 .40417 .55618 .39199 Metetra
.546 .813 .995 r
.48502 .39106 .48362 .40317 .51881 .40367 .52062 .39155 Metetra
.546 .812 .995 r
.44938 .39053 .4484 .40267 .48362 .40317 .48502 .39106 Metetra
.546 .811 .995 r
.41372 .38995 .41315 .40217 .4484 .40267 .44938 .39053 Metetra
.624 .751 .938 r
.05221 .36139 .05544 .3818 .09139 .38281 .08847 .36392 Metetra
.612 .762 .95 r
.08847 .36392 .09139 .38281 .12732 .38378 .12472 .36628 Metetra
.6 .771 .962 r
.12472 .36628 .12732 .38378 .16322 .3847 .16097 .36846 Metetra
.587 .78 .971 r
.16097 .36846 .16322 .3847 .19909 .38558 .19721 .37047 Metetra
.574 .787 .98 r
.19721 .37047 .19909 .38558 .23493 .38642 .23343 .3723 Metetra
.56 .793 .986 r
.23343 .3723 .23493 .38642 .27075 .38722 .26964 .37395 Metetra
.547 .799 .991 r
.26964 .37395 .27075 .38722 .30654 .38796 .30584 .37543 Metetra
.535 .803 .995 r
.30584 .37543 .30654 .38796 .34229 .38867 .34201 .37674 Metetra
.525 .806 .997 r
.34201 .37674 .34229 .38867 .37802 .38933 .37816 .37787 Metetra
.517 .809 .999 r
.37816 .37787 .37802 .38933 .41372 .38995 .41428 .37883 Metetra
.653 .797 .952 r
.88039 .37549 .8747 .39406 .9099 .39408 .91588 .37403 Metetra
.639 .805 .963 r
.84483 .37678 .83945 .394 .8747 .39406 .88039 .37549 Metetra
.624 .812 .972 r
.80922 .3779 .80417 .3939 .83945 .394 .84483 .37678 Metetra
.608 .817 .98 r
.77355 .37885 .76886 .39376 .80417 .3939 .80922 .3779 Metetra
.591 .82 .987 r
.73782 .37962 .7335 .39357 .76886 .39376 .77355 .37885 Metetra
.574 .823 .992 r
.70205 .38023 .69811 .39334 .7335 .39357 .73782 .37962 Metetra
.559 .823 .995 r
.66622 .38066 .66268 .39307 .69811 .39334 .70205 .38023 Metetra
.544 .823 .997 r
.63035 .38092 .62722 .39276 .66268 .39307 .66622 .38066 Metetra
.532 .822 .999 r
.59443 .381 .59172 .3924 .62722 .39276 .63035 .38092 Metetra
.521 .82 .999 r
.55847 .38092 .55618 .39199 .59172 .3924 .59443 .381 Metetra
.514 .818 1 r
.52248 .38066 .52062 .39155 .55618 .39199 .55847 .38092 Metetra
.51 .816 1 r
.48645 .38022 .48502 .39106 .52062 .39155 .52248 .38066 Metetra
.509 .814 1 r
.45038 .37961 .44938 .39053 .48502 .39106 .48645 .38022 Metetra
.512 .812 .999 r
.41428 .37883 .41372 .38995 .44938 .39053 .45038 .37961 Metetra
.629 .707 .902 r
.0492 .33581 .05221 .36139 .08847 .36392 .08569 .34089 Metetra
.617 .722 .921 r
.08569 .34089 .08847 .36392 .12472 .36628 .12221 .34557 Metetra
.603 .737 .939 r
.12221 .34557 .12472 .36628 .16097 .36846 .15876 .34987 Metetra
.587 .751 .956 r
.15876 .34987 .16097 .36846 .19721 .37047 .19533 .35376 Metetra
.569 .764 .97 r
.19533 .35376 .19721 .37047 .23343 .3723 .23191 .35726 Metetra
.55 .775 .982 r
.23191 .35726 .23343 .3723 .26964 .37395 .26851 .36037 Metetra
.53 .785 .991 r
.26851 .36037 .26964 .37395 .30584 .37543 .3051 .36308 Metetra
.51 .792 .996 r
.3051 .36308 .30584 .37543 .34201 .37674 .3417 .3654 Metetra
.492 .798 .999 r
.3417 .3654 .34201 .37674 .37816 .37787 .37828 .36732 Metetra
.478 .802 1 r
.37828 .36732 .37816 .37787 .41428 .37883 .41485 .36884 Metetra
.699 .793 .923 r
.88599 .35281 .88039 .37549 .91588 .37403 .9217 .34886 Metetra
.683 .806 .941 r
.85018 .35638 .84483 .37678 .88039 .37549 .88599 .35281 Metetra
.664 .819 .958 r
.81428 .35957 .80922 .3779 .84483 .37678 .85018 .35638 Metetra
.642 .828 .972 r
.77829 .36236 .77355 .37885 .80922 .3779 .81428 .35957 Metetra
.618 .835 .983 r
.74222 .36477 .73782 .37962 .77355 .37885 .77829 .36236 Metetra
.591 .839 .992 r
.70608 .3668 .70205 .38023 .73782 .37962 .74222 .36477 Metetra
.563 .839 .997 r
.66986 .36843 .66622 .38066 .70205 .38023 .70608 .3668 Metetra
.536 .837 .999 r
.63357 .36967 .63035 .38092 .66622 .38066 .66986 .36843 Metetra
.512 .832 .999 r
.59723 .37052 .59443 .381 .63035 .38092 .63357 .36967 Metetra
.491 .827 .999 r
.56084 .37097 .55847 .38092 .59443 .381 .59723 .37052 Metetra
.476 .821 .998 r
.52439 .37103 .52248 .38066 .55847 .38092 .56084 .37097 Metetra
.467 .815 .998 r
.48791 .37069 .48645 .38022 .52248 .38066 .52439 .37103 Metetra
.464 .811 .998 r
.45139 .36996 .45038 .37961 .48645 .38022 .48791 .37069 Metetra
.468 .806 .999 r
.41485 .36884 .41428 .37883 .45038 .37961 .45139 .36996 Metetra
.621 .664 .871 r
.04642 .30495 .0492 .33581 .08569 .34089 .08306 .31362 Metetra
.609 .682 .893 r
.08306 .31362 .08569 .34089 .12221 .34557 .11979 .32159 Metetra
.594 .699 .916 r
.11979 .32159 .12221 .34557 .15876 .34987 .15659 .32886 Metetra
.577 .718 .939 r
.15659 .32886 .15876 .34987 .19533 .35376 .19346 .33543 Metetra
.555 .735 .959 r
.19346 .33543 .19533 .35376 .23191 .35726 .23038 .3413 Metetra
.531 .751 .977 r
.23038 .3413 .23191 .35726 .26851 .36037 .26735 .34646 Metetra
.504 .764 .989 r
.26735 .34646 .26851 .36037 .3051 .36308 .30434 .35091 Metetra
.477 .775 .996 r
.30434 .35091 .3051 .36308 .3417 .3654 .34136 .35466 Metetra
.451 .782 .998 r
.34136 .35466 .3417 .3654 .37828 .36732 .37839 .35769 Metetra
.43 .788 .996 r
.37839 .35769 .37828 .36732 .41485 .36884 .41541 .36001 Metetra
.738 .793 .896 r
.8915 .32594 .88599 .35281 .9217 .34886 .92733 .31847 Metetra
.724 .812 .919 r
.85551 .33273 .85018 .35638 .88599 .35281 .8915 .32594 Metetra
.705 .83 .942 r
.81937 .33884 .81428 .35957 .85018 .35638 .85551 .33273 Metetra
.68 .845 .962 r
.7831 .34427 .77829 .36236 .81428 .35957 .81937 .33884 Metetra
.65 .855 .978 r
.74671 .349 .74222 .36477 .77829 .36236 .7831 .34427 Metetra
.613 .86 .99 r
.7102 .35304 .70608 .3668 .74222 .36477 .74671 .349 Metetra
.573 .86 .996 r
.6736 .35638 .66986 .36843 .70608 .3668 .7102 .35304 Metetra
.532 .853 .997 r
.6369 .35902 .63357 .36967 .66986 .36843 .6736 .35638 Metetra
.492 .843 .995 r
.60012 .36096 .59723 .37052 .63357 .36967 .6369 .35902 Metetra
.458 .831 .991 r
.56327 .36219 .56084 .37097 .59723 .37052 .60012 .36096 Metetra
.432 .818 .988 r
.52637 .36271 .52439 .37103 .56084 .37097 .56327 .36219 Metetra
.416 .808 .987 r
.48942 .36252 .48791 .37069 .52439 .37103 .52637 .36271 Metetra
.41 .799 .989 r
.45243 .36162 .45139 .36996 .48791 .37069 .48942 .36252 Metetra
.415 .793 .992 r
.41541 .36001 .41485 .36884 .45139 .36996 .45243 .36162 Metetra
.604 .623 .843 r
.0439 .26872 .04642 .30495 .08306 .31362 .0806 .28201 Metetra
.592 .64 .867 r
.0806 .28201 .08306 .31362 .11979 .32159 .11747 .29424 Metetra
.576 .659 .894 r
.11747 .29424 .11979 .32159 .15659 .32886 .15447 .30537 Metetra
.557 .68 .921 r
.15447 .30537 .15659 .32886 .19346 .33543 .1916 .31542 Metetra
.533 .7 .947 r
.1916 .31542 .19346 .33543 .23038 .3413 .22883 .32437 Metetra
.504 .72 .969 r
.22883 .32437 .23038 .3413 .26735 .34646 .26616 .33221 Metetra
.471 .737 .986 r
.26616 .33221 .26735 .34646 .30434 .35091 .30355 .33893 Metetra
.435 .75 .994 r
.30355 .33893 .30434 .35091 .34136 .35466 .341 .34454 Metetra
.401 .759 .994 r
.341 .34454 .34136 .35466 .37839 .35769 .37848 .34903 Metetra
.372 .765 .987 r
.37848 .34903 .37839 .35769 .41541 .36001 .41598 .3524 Metetra
.775 .797 .871 r
.89689 .29479 .8915 .32594 .92733 .31847 .93277 .28277 Metetra
.764 .821 .897 r
.86079 .30576 .85551 .33273 .8915 .32594 .89689 .29479 Metetra
.746 .844 .924 r
.82447 .31567 .81937 .33884 .85551 .33273 .86079 .30576 Metetra
.721 .864 .949 r
.78796 .32451 .7831 .34427 .81937 .33884 .82447 .31567 Metetra
.686 .879 .97 r
.75128 .33228 .74671 .349 .7831 .34427 .78796 .32451 Metetra
.641 .886 .985 r
.71443 .33895 .7102 .35304 .74671 .349 .75128 .33228 Metetra
.588 .884 .992 r
.67744 .34453 .6736 .35638 .7102 .35304 .71443 .33895 Metetra
.529 .872 .99 r
.64033 .349 .6369 .35902 .6736 .35638 .67744 .34453 Metetra
.472 .853 .983 r
.6031 .35237 .60012 .36096 .6369 .35902 .64033 .349 Metetra
.42 .831 .973 r
.56579 .35462 .56327 .36219 .60012 .36096 .6031 .35237 Metetra
.381 .809 .966 r
.5284 .35575 .52637 .36271 .56327 .36219 .56579 .35462 Metetra
.355 .792 .965 r
.49096 .35576 .48942 .36252 .52637 .36271 .5284 .35575 Metetra
.346 .779 .969 r
.45348 .35464 .45243 .36162 .48942 .36252 .49096 .35576 Metetra
.352 .771 .977 r
.41598 .3524 .41541 .36001 .45243 .36162 .45348 .35464 Metetra
.582 .582 .818 r
.04164 .22703 .0439 .26872 .0806 .28201 .07832 .246 Metetra
.568 .598 .843 r
.07832 .246 .0806 .28201 .11747 .29424 .11525 .26345 Metetra
.551 .617 .871 r
.11525 .26345 .11747 .29424 .15447 .30537 .1524 .27935 Metetra
.53 .638 .901 r
.1524 .27935 .15447 .30537 .1916 .31542 .18975 .29369 Metetra
.502 .66 .931 r
.18975 .29369 .1916 .31542 .22883 .32437 .22727 .30644 Metetra
.469 .682 .958 r
.22727 .30644 .22883 .32437 .26616 .33221 .26494 .3176 Metetra
.429 .702 .979 r
.26494 .3176 .26616 .33221 .30355 .33893 .30272 .32715 Metetra
.385 .717 .988 r
.30272 .32715 .30355 .33893 .341 .34454 .34061 .33507 Metetra
.341 .726 .984 r
.34061 .33507 .341 .34454 .37848 .34903 .37856 .34137 Metetra
.303 .732 .97 r
.37856 .34137 .37848 .34903 .41598 .3524 .41655 .34604 Metetra
.809 .804 .846 r
.90217 .25928 .89689 .29479 .93277 .28277 .938 .24168 Metetra
.801 .832 .874 r
.86602 .27538 .86079 .30576 .89689 .29479 .90217 .25928 Metetra
.787 .86 .904 r
.82958 .28998 .82447 .31567 .86079 .30576 .86602 .27538 Metetra
.762 .886 .933 r
.79288 .30305 .78796 .32451 .82447 .31567 .82958 .28998 Metetra
.725 .906 .958 r
.75593 .31457 .75128 .33228 .78796 .32451 .79288 .30305 Metetra
.673 .915 .975 r
.71876 .32451 .71443 .33895 .75128 .33228 .75593 .31457 Metetra
.606 .911 .981 r
.6814 .33287 .67744 .34453 .71443 .33895 .71876 .32451 Metetra
.529 .891 .975 r
.64387 .33963 .64033 .349 .67744 .34453 .6814 .33287 Metetra
.45 .86 .96 r
.60619 .34477 .6031 .35237 .64033 .349 .64387 .33963 Metetra
.379 .825 .943 r
.56839 .3483 .56579 .35462 .6031 .35237 .60619 .34477 Metetra
.323 .791 .931 r
.5305 .35019 .5284 .35575 .56579 .35462 .56839 .3483 Metetra
.286 .765 .928 r
.49255 .35044 .49096 .35576 .5284 .35575 .5305 .35019 Metetra
.272 .747 .936 r
.45456 .34906 .45348 .35464 .49096 .35576 .49255 .35044 Metetra
.278 .737 .952 r
.41655 .34604 .41598 .3524 .45348 .35464 .45456 .34906 Metetra
.556 .542 .795 r
.03965 .17985 .04164 .22703 .07832 .246 .07622 .20553 Metetra
.54 .556 .82 r
.07622 .20553 .07832 .246 .11525 .26345 .11314 .22917 Metetra
.52 .573 .849 r
.11314 .22917 .11525 .26345 .1524 .27935 .15038 .25073 Metetra
.496 .592 .88 r
.15038 .25073 .1524 .27935 .18975 .29369 .18791 .27018 Metetra
.465 .614 .913 r
.18791 .27018 .18975 .29369 .22727 .30644 .22569 .28749 Metetra
.426 .637 .944 r
.22569 .28749 .22727 .30644 .26494 .3176 .26368 .30262 Metetra
.378 .658 .967 r
.26368 .30262 .26494 .3176 .30272 .32715 .30186 .31556 Metetra
.324 .674 .977 r
.30186 .31556 .30272 .32715 .34061 .33507 .34019 .32627 Metetra
.27 .684 .968 r
.34019 .32627 .34061 .33507 .37856 .34137 .37862 .33475 Metetra
.224 .688 .945 r
.37862 .33475 .37856 .34137 .41655 .34604 .41712 .34097 Metetra
.841 .812 .822 r
.90731 .21934 .90217 .25928 .938 .24168 .94299 .19516 Metetra
.837 .844 .85 r
.8712 .24155 .86602 .27538 .90217 .25928 .90731 .21934 Metetra
.826 .876 .881 r
.83471 .26172 .82958 .28998 .86602 .27538 .8712 .24155 Metetra
.804 .907 .912 r
.79785 .27984 .79288 .30305 .82958 .28998 .83471 .26172 Metetra
.766 .932 .94 r
.76068 .29584 .75593 .31457 .79288 .30305 .79785 .27984 Metetra
.707 .944 .958 r
.72321 .30971 .71876 .32451 .75593 .31457 .76068 .29584 Metetra
.627 .937 .962 r
.68548 .32141 .6814 .33287 .71876 .32451 .72321 .30971 Metetra
.53 .908 .949 r
.64752 .33092 .64387 .33963 .6814 .33287 .68548 .32141 Metetra
.428 .862 .924 r
.60938 .33822 .60619 .34477 .64387 .33963 .64752 .33092 Metetra
.334 .81 .898 r
.57109 .34328 .56839 .3483 .60619 .34477 .60938 .33822 Metetra
.26 .763 .88 r
.53267 .34609 .5305 .35019 .56839 .3483 .57109 .34328 Metetra
.211 .726 .876 r
.49419 .34664 .49255 .35044 .5305 .35019 .53267 .34609 Metetra
.189 .703 .889 r
.45565 .34494 .45456 .34906 .49255 .35044 .49419 .34664 Metetra
.194 .692 .915 r
.41712 .34097 .41655 .34604 .45456 .34906 .45565 .34494 Metetra
.526 .503 .773 r
.03795 .12714 .03965 .17985 .07622 .20553 .07431 .16053 Metetra
.507 .514 .798 r
.07431 .16053 .07622 .20553 .11314 .22917 .11115 .19132 Metetra
.485 .527 .826 r
.11115 .19132 .11314 .22917 .15038 .25073 .14842 .21945 Metetra
.456 .544 .857 r
.14842 .21945 .15038 .25073 .18791 .27018 .18608 .24486 Metetra
.42 .563 .891 r
.18608 .24486 .18791 .27018 .22569 .28749 .22409 .26748 Metetra
.375 .584 .924 r
.22409 .26748 .22569 .28749 .26368 .30262 .2624 .28727 Metetra
.319 .605 .95 r
.2624 .28727 .26368 .30262 .30186 .31556 .30097 .30417 Metetra
.255 .621 .959 r
.30097 .30417 .30186 .31556 .34019 .32627 .33973 .31816 Metetra
.19 .629 .945 r
.33973 .31816 .34019 .32627 .37862 .33475 .37866 .3292 Metetra
.135 .632 .91 r
.37866 .3292 .37862 .33475 .41712 .34097 .41769 .33726 Metetra
.872 .822 .796 r
.9123 .17494 .90731 .21934 .94299 .19516 .94774 .14317 Metetra
.871 .856 .824 r
.87632 .20419 .8712 .24155 .90731 .21934 .9123 .17494 Metetra
.863 .892 .855 r
.83983 .23084 .83471 .26172 .8712 .24155 .87632 .20419 Metetra
.843 .928 .886 r
.80288 .25482 .79785 .27984 .83471 .26172 .83983 .23084 Metetra
.805 .957 .913 r
.76551 .27607 .76068 .29584 .79785 .27984 .80288 .25482 Metetra
.741 .97 .931 r
.72776 .29454 .72321 .30971 .76068 .29584 .76551 .27607 Metetra
.647 .959 .93 r
.68967 .31016 .68548 .32141 .72321 .30971 .72776 .29454 Metetra
.529 .919 .909 r
.6513 .32291 .64752 .33092 .68548 .32141 .68967 .31016 Metetra
.403 .856 .874 r
.61268 .33273 .60938 .33822 .64752 .33092 .6513 .32291 Metetra
.286 .787 .837 r
.57387 .33961 .57109 .34328 .60938 .33822 .61268 .33273 Metetra
.193 .724 .814 r
.53492 .34351 .53267 .34609 .57109 .34328 .57387 .33961 Metetra
.131 .676 .81 r
.49587 .34442 .49419 .34664 .53267 .34609 .53492 .34351 Metetra
.1 .648 .829 r
.45678 .34234 .45565 .34494 .49419 .34664 .49587 .34442 Metetra
.103 .635 .866 r
.41769 .33726 .41712 .34097 .45565 .34494 .45678 .34234 Metetra
.493 .463 .753 r
.03654 .06889 .03795 .12714 .07431 .16053 .0726 .11097 Metetra
.472 .471 .775 r
.0726 .11097 .07431 .16053 .11115 .19132 .10928 .14986 Metetra
.445 .48 .802 r
.10928 .14986 .11115 .19132 .14842 .21945 .14652 .18546 Metetra
.412 .493 .833 r
.14652 .18546 .14842 .21945 .18608 .24486 .18427 .21767 Metetra
.37 .508 .866 r
.18427 .21767 .18608 .24486 .22409 .26748 .22248 .24638 Metetra
.317 .526 .899 r
.22248 .24638 .22409 .26748 .2624 .28727 .26109 .27151 Metetra
.252 .543 .925 r
.26109 .27151 .2624 .28727 .30097 .30417 .30003 .29299 Metetra
.177 .557 .932 r
.30003 .29299 .30097 .30417 .33973 .31816 .33925 .31076 Metetra
.101 .564 .911 r
.33925 .31076 .33973 .31816 .37866 .3292 .37868 .32476 Metetra
.039 .565 .864 r
.37868 .32476 .37866 .3292 .41769 .33726 .41826 .33496 Metetra
.9 .832 .77 r
.91713 .12603 .9123 .17494 .94774 .14317 .95222 .08571 Metetra
.902 .867 .796 r
.88136 .16325 .87632 .20419 .9123 .17494 .91713 .12603 Metetra
.896 .906 .824 r
.84495 .19727 .83983 .23084 .87632 .20419 .88136 .16325 Metetra
.879 .944 .853 r
.80796 .22795 .80288 .25482 .83983 .23084 .84495 .19727 Metetra
.84 .976 .878 r
.77044 .25522 .76551 .27607 .80288 .25482 .80796 .22795 Metetra
.771 .989 .891 r
.73243 .27897 .72776 .29454 .76551 .27607 .77044 .25522 Metetra
.664 .973 .884 r
.694 .29912 .68967 .31016 .72776 .29454 .73243 .27897 Metetra
.526 .92 .854 r
.65521 .31561 .6513 .32291 .68967 .31016 .694 .29912 Metetra
.376 .841 .807 r
.61611 .32836 .61268 .33273 .6513 .32291 .65521 .31561 Metetra
.238 .753 .763 r
.57676 .33734 .57387 .33961 .61268 .33273 .61611 .32836 Metetra
.127 .675 .734 r
.53724 .34251 .53492 .34351 .57387 .33961 .57676 .33734 Metetra
.05 .618 .732 r
.49761 .34384 .49587 .34442 .53492 .34351 .53724 .34251 Metetra
.01 .583 .758 r
.45793 .34132 .45678 .34234 .49587 .34442 .49761 .34384 Metetra
.007 .567 .806 r
.41826 .33496 .41769 .33726 .45678 .34234 .45793 .34132 Metetra
.505 .601 .883 r
.03318 .03834 .03654 .06889 .0726 .11097 .0711 .05682 Metetra
.433 .427 .753 r
.0711 .05682 .0726 .11097 .10928 .14986 .10753 .10474 Metetra
.402 .432 .777 r
.10753 .10474 .10928 .14986 .14652 .18546 .14468 .14871 Metetra
.364 .439 .805 r
.14468 .14871 .14652 .18546 .18427 .21767 .18248 .18856 Metetra
.315 .449 .837 r
.18248 .18856 .18427 .21767 .22248 .24638 .22085 .22415 Metetra
.254 .461 .869 r
.22085 .22415 .22248 .24638 .26109 .27151 .25974 .25534 Metetra
.179 .474 .893 r
.25974 .25534 .26109 .27151 .30003 .29299 .29906 .28203 Metetra
.092 .484 .897 r
.29906 .28203 .30003 .29299 .33925 .31076 .33873 .30411 Metetra
.006 .488 .868 r
.33873 .30411 .33925 .31076 .37868 .32476 .37869 .3215 Metetra
0 .488 .809 r
.37869 .3215 .37868 .32476 .41826 .33496 .41884 .33413 Metetra
.791 .724 .789 r
.9218 .07259 .91713 .12603 .95222 .08571 .95877 .0557 Metetra
.929 .877 .764 r
.88633 .1187 .88136 .16325 .91713 .12603 .9218 .07259 Metetra
.925 .917 .788 r
.85007 .16096 .84495 .19727 .88136 .16325 .88633 .1187 Metetra
.909 .956 .813 r
.8131 .19919 .80796 .22795 .84495 .19727 .85007 .16096 Metetra
.869 .987 .832 r
.77546 .23325 .77044 .25522 .80796 .22795 .8131 .19919 Metetra
.794 .999 .839 r
.73722 .263 .73243 .27897 .77044 .25522 .77546 .23325 Metetra
.676 .976 .824 r
.69846 .2883 .694 .29912 .73243 .27897 .73722 .263 Metetra
.519 .91 .783 r
.65925 .30905 .65521 .31561 .694 .29912 .69846 .2883 Metetra
.349 .815 .728 r
.61965 .32516 .61611 .32836 .65521 .31561 .65925 .30905 Metetra
.57976 .33655 .57676 .33734 .61611 .32836 .61965 .32516 Metetra
.53965 .34317 .53724 .34251 .57676 .33734 .57976 .33655 Metetra
.027 0 0 r
.49941 .34498 .49761 .34384 .53724 .34251 .53965 .34317 Metetra
.079 0 0 r
.45911 .34197 .45793 .34132 .49761 .34384 .49941 .34498 Metetra
0 .492 .737 r
.41884 .33413 .41826 .33496 .45793 .34132 .45911 .34197 Metetra
.597 .797 .976 r
.02892 .01942 .03318 .03834 .0711 .05682 .06843 .02017 Metetra
.384 .463 .818 r
.06843 .02017 .0711 .05682 .10753 .10474 .10593 .05592 Metetra
.357 .383 .751 r
.10593 .05592 .10753 .10474 .14468 .14871 .14291 .10913 Metetra
.313 .385 .776 r
.14291 .10913 .14468 .14871 .18248 .18856 .1807 .15748 Metetra
.257 .388 .805 r
.1807 .15748 .18248 .18856 .22085 .22415 .21921 .20075 Metetra
.187 .393 .833 r
.21921 .20075 .22085 .22415 .25974 .25534 .25835 .23875 Metetra
.101 .399 .853 r
.25835 .23875 .25974 .25534 .29906 .28203 .29804 .27129 Metetra
.003 .403 .852 r
.29804 .27129 .29906 .28203 .33873 .30411 .33818 .29823 Metetra
0 .404 .816 r
.33818 .29823 .33873 .30411 .37869 .3215 .37867 .31945 Metetra
0 .403 .745 r
.37867 .31945 .37869 .3215 .41884 .33413 .41942 .33484 Metetra
.689 .708 .862 r
.92774 .03649 .9218 .07259 .95877 .0557 .96635 .03723 Metetra
.877 .82 .789 r
.8912 .07049 .88633 .1187 .9218 .07259 .92774 .03649 Metetra
.949 .923 .749 r
.85518 .12187 .85007 .16096 .88633 .1187 .8912 .07049 Metetra
.931 .961 .766 r
.81828 .16849 .8131 .19919 .85007 .16096 .85518 .12187 Metetra
.889 .99 .778 r
.78058 .21014 .77546 .23325 .8131 .19919 .81828 .16849 Metetra
.808 .997 .776 r
.74214 .2466 .73722 .263 .77546 .23325 .78058 .21014 Metetra
.679 .965 .751 r
.70307 .2777 .69846 .2883 .73722 .263 .74214 .2466 Metetra
.509 .888 .701 r
.66343 .30327 .65925 .30905 .69846 .2883 .70307 .2777 Metetra
.322 .779 .64 r
.62334 .32317 .61965 .32516 .65925 .30905 .66343 .30327 Metetra
.58288 .3373 .57976 .33655 .61965 .32516 .62334 .32317 Metetra
.54215 .34556 .53965 .34317 .57976 .33655 .58288 .3373 Metetra
.098 0 0 r
.50127 .34792 .49941 .34498 .53965 .34317 .54215 .34556 Metetra
.163 0 0 r
.46032 .34434 .45911 .34197 .49941 .34498 .50127 .34792 Metetra
.185 0 0 r
.41942 .33484 .41884 .33413 .45911 .34197 .46032 .34434 Metetra
.597 .797 .976 r
.02454 0 .02892 .01942 .06843 .02017 .06457 .00077 Metetra
.573 .78 .977 r
.06457 .00077 .06843 .02017 .10593 .05592 .10445 .00338 Metetra
.309 .333 .724 r
.10445 .00338 .10593 .05592 .14291 .10913 .14121 .0667 Metetra
.259 .329 .745 r
.14121 .0667 .14291 .10913 .1807 .15748 .17894 .1244 Metetra
.197 .325 .769 r
.17894 .1244 .1807 .15748 .21921 .20075 .21755 .17616 Metetra
.118 .322 .792 r
.21755 .17616 .21921 .20075 .25835 .23875 .25693 .2217 Metetra
.022 .32 .807 r
.25693 .2217 .25835 .23875 .29804 .27129 .29698 .26078 Metetra
0 .317 .8 r
.29698 .26078 .29804 .27129 .33818 .29823 .33759 .29316 Metetra
0 .314 .756 r
.33759 .29316 .33818 .29823 .37867 .31945 .37864 .31867 Metetra
0 .315 .676 r
.37864 .31867 .37867 .31945 .41942 .33484 .42001 .33716 Metetra
.597 .797 .976 r
.93501 .01752 .92774 .03649 .96635 .03723 .97412 .01827 Metetra
.716 .667 .801 r
.89598 .01859 .8912 .07049 .92774 .03649 .93501 .01752 Metetra
.965 .925 .705 r
.86027 .07994 .85518 .12187 .8912 .07049 .89598 .01859 Metetra
.946 .959 .714 r
.82352 .1358 .81828 .16849 .85518 .12187 .86027 .07994 Metetra
.9 .983 .716 r
.78579 .18584 .78058 .21014 .81828 .16849 .82352 .1358 Metetra
.813 .982 .703 r
.74719 .22977 .74214 .2466 .78058 .21014 .78579 .18584 Metetra
.675 .942 .669 r
.70782 .26734 .70307 .2777 .74214 .2466 .74719 .22977 Metetra
.494 .856 .613 r
.66777 .2983 .66343 .30327 .70307 .2777 .70782 .26734 Metetra
.62716 .32245 .62334 .32317 .66343 .30327 .66777 .2983 Metetra
.58611 .33966 .58288 .3373 .62334 .32317 .62716 .32245 Metetra
.044 0 0 r
.54475 .34978 .54215 .34556 .58288 .3373 .58611 .33966 Metetra
.162 0 0 r
.50319 .35275 .50127 .34792 .54215 .34556 .54475 .34978 Metetra
.24 0 0 r
.46157 .34854 .46032 .34434 .50127 .34792 .50319 .35275 Metetra
.275 0 0 r
.42001 .33716 .41942 .33484 .46032 .34434 .46157 .34854 Metetra
0 g
.25 Mabswid
.02454 0 m
0 .35417 L
s
0 .35417 m
1 .36889 L
s
1 .36889 m
.97412 .01827 L
s
.97412 .01827 m
.02454 0 L
s
.02454 0 m
.97412 .01827 L
s
.02454 0 m
.02409 .00644 L
s
[(-2)] .02543 -0.01288 -0.06928 1 Mshowa
.26411 .00461 m
.2639 .01106 L
s
[(-1)] .26454 -0.00829 -0.0331 1 Mshowa
.50223 .00919 m
.50224 .01565 L
s
[(0)] .50219 -0.00372 .0028 1 Mshowa
.73889 .01375 m
.73914 .0202 L
s
[(1)] .73839 .00085 .03844 1 Mshowa
.97412 .01827 m
.97459 .02471 L
s
[(2)] .97317 .0054 .07382 1 Mshowa
.125 Mabswid
.07257 .00092 m
.07233 .00479 L
s
.12054 .00185 m
.12033 .00571 L
s
.16846 .00277 m
.16828 .00664 L
s
.21632 .00369 m
.21616 .00756 L
s
.31185 .00553 m
.31175 .0094 L
s
.35953 .00645 m
.35946 .01032 L
s
.40716 .00736 m
.40711 .01124 L
s
.45472 .00828 m
.4547 .01215 L
s
.54967 .01011 m
.54971 .01398 L
s
.59706 .01102 m
.59713 .01489 L
s
.6444 .01193 m
.64449 .0158 L
s
.69167 .01284 m
.69179 .01671 L
s
.78605 .01465 m
.78623 .01852 L
s
.83315 .01556 m
.83336 .01943 L
s
.8802 .01647 m
.88043 .02033 L
s
.92719 .01737 m
.92744 .02123 L
s
.25 Mabswid
1 .36889 m
.84368 .64848 L
s
1 .36889 m
.99355 .36879 L
s
[(-2)] 1.01291 .36908 -1 -0.01471 Mshowa
.95208 .45459 m
.94563 .4545 L
s
[(-1)] .96499 .45476 -1 -0.0136 Mshowa
.91088 .52828 m
.90443 .5282 L
s
[(0)] .92379 .52844 -1 -0.01264 Mshowa
.87508 .59231 m
.86863 .59224 L
s
[(1)] .88799 .59247 -1 -0.0118 Mshowa
.84368 .64848 m
.83722 .64841 L
s
[(2)] .85659 .64862 -1 -0.01107 Mshowa
.125 Mabswid
.9898 .38713 m
.98593 .38707 L
s
.97993 .40479 m
.97605 .40474 L
s
.97036 .42191 m
.96648 .42185 L
s
.96108 .4385 m
.95721 .43844 L
s
.94335 .4702 m
.93948 .47015 L
s
.93488 .48536 m
.93101 .48531 L
s
.92665 .50008 m
.92278 .50003 L
s
.91865 .51438 m
.91478 .51433 L
s
.90333 .54179 m
.89945 .54174 L
s
.89598 .55494 m
.8921 .55489 L
s
.88882 .56773 m
.88495 .56769 L
s
.88186 .58019 m
.87799 .58014 L
s
.86847 .60413 m
.8646 .60408 L
s
.86204 .61564 m
.85817 .6156 L
s
.85576 .62686 m
.85189 .62682 L
s
.84965 .6378 m
.84577 .63776 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{321.875, 208.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007R0001>B000`400?l00000o`00003oo`3ooooS
0?ooo`00o`3ooooS0?ooo`00<P3oool00`3ookl0M000000000040000000307Boo`3oool0oooo0?l0
ooooY`3oool003<0oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?ooo`3o0?ooojP0oooo
000d0?ooo`030?noM00004P0W=oo05l0oooo00<0okmd0000000000000`0000000`00M;l0oooo0?oo
o`3o0?oood@0oooo000e0?ooo`030?oOW0180000B9cO0640oooo00<0W4Q809cOo`3oool0o`3ooom7
0?ooo`00:P3oool00`2LB000000000000003000000030018W03oool0oooo00@0oooo00<0W4P004RL
g`3oool0G`3oool00`2LB4P0W=oo0?ooo`1I0?ooo`050?noM000000000000000001d_ol0j03oool0
03P0oooo00<0W4Qd0;ooo`3oool0GP3oool00`2LB4P0W=oo0?ooo`1I0?ooo`0609a8M02oool0oooo
0?oo_`1d07@0_oooi`3oool003<0oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`1B
0?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool00`3oool00`2LB4P0W=oo0?ooo`1H
0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool0FP3oool00`3o_g@0000000000003
00000003001d_`3oool0oooo08<0oooo000c0?ooo`070?noM00007@0_ooo0?ooo`3o_g@0001809cO
o`1O0?ooo`0309a8B02Lgol0oooo05P0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?oo
o`1M0?ooo`0309a8B02Lgol0oooo08H0oooo000d0?ooo`050?noM000000000000000B02Lgol0H03o
ool00`2LB4P0W=oo0?ooo`1H0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0G@3o
ool00`2LB4P0W=oo0?ooo`1J0?ooo`030?oo_`1d0000000000@0000000<0M;oo0?ooo`3oool08P3o
ool009H0oooo00D0gia800000000B9`0W4Q809cOo`1I0?ooo`030=nLB018W=l0oooo0080oooo00<0
okmd001d_`3oool0G@3oool00`2LB4P0W=oo0?ooo`1K0?ooo`030;md000007@0_ooo0080oooo00<0
giad09cOo`3oool08`3oool009P0oooo00<0gia80000B02Lgol0F@3oool00`3o_g@0B9cO0?ooo`02
0?ooo`030=nLB018W=l0oooo05d0oooo00<0W4Q809cOo`3oool0G03oool00`3o_g@0001809cOo`0W
0?ooo`00m@3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;oooeh0oooo00<0W4Q809cOo`3oool0G@3o
ool00`3ogi`0B00004RLg`0V0?ooo`00m@3oool01@3ookl0M0000000000004P0W=oo05l0oooo00<0
W4Q809cOo`3oool0G`3oool00`2LB000B9cO0?ooo`0T0?ooo`00o`3ooomG0?ooo`050=nLB0000000
04RL09a8B02Lgol0H@3oool00`2LB7@0_ooo0?ooo`0S0?ooo`00o`3ooomI0?ooo`030=nLB00004P0
W=oo05`0oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`0S0?ooo`00o`3ooonh0?oo
o`070?noM00007@0_ooo0?ooo`3o_g@0001809cOo`0T0?ooo`00o`3oooni0?ooo`050?noM0000000
00000000B02Lgol09@3oool00340oooo6@00003o0?oooiT0oooo000a0?ooo`030000002Hc?T0V<ci
00H0V<ci@@00003o0?ooofP0oooo000a0?ooo`030000002Hc?T0V<ci00h0V<ci00@0000009;7nP2B
aoX00000102BaoX9000000H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0;0?oo
oc800000o`3ooolf0?ooo`00<@3oool2000000l0V<ci00<0000009;7nP2BaoX03@2BaoX2000000D0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`020?oooc400000o`3oool50?ooo`00
<@3oool2000000l0V<ci00<0000009;7nP2BaoX03@2BaoX200000400oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
2`3ooola00000=<0oooo000a0?ooo`8000003`2Hc?T00`000000T/Oj09;7nP0=09;7nP030000001?
EKT0000003l0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`040000003o
ool0oooo0?oooc400000XP3oool00340oooo0P00000@09S<n@030000002BaoX0T/Oj00`0T/Oj00<0
000004mE^@000000XP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?oooc800000L03oool00340oooo00<00000
0?ooo`0000003`2Hc?T00`000000T/Oj09;7nP0<09;7nP040000001?EKT0CeFi00000:40oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo<@00
000o0?ooo`00<03oool00`000000oooo0?ooo`08000000P0V<ci00<0000009;7nP2BaoX0302BaoX0
10000000CeFi04mE^@00003o0?ooo`D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103ooolQ000002H0oooo000`
0?ooo`@000001`2Hc?T9000000h0T/Oj00D0000004mE^@1?EKT0CeFi0000003o0?ooo`@0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`030?ooo`800000302gZ/d010000000]j[=0;NZ
c@00000?09S<n@030000003oool0oooo02@0oooo000`0?ooo`040000003oool0oooo000000l0V<ci
0P00000=09;7nP030000001?EKT0CeFi0080CeFi00<000000?ooo`3oool0o`3ooom10?ooo`800000
3P2gZ/d00`000000V<ci09S<n@0=09S<n@8000009P3oool00300oooo00<000000?ooo`3oool00P00
000>09S<n@030000001RM]40000000`0T/Oj00<0000004mE^@1?EKT00P1?EKT00`000000oooo0?oo
o`3o0?oood00oooo00<000000?O/]00000003P2gZ/d00`000000V<ci09S<n@0=09S<n@8000009P3o
ool00300oooo00D000000?ooo`3oool0oooo0000000>09S<n@040000001RM]40HWKA000000/0T/Oj
00<0000004mE^@1?EKT00`1?EKT00`000000oooo0?ooo`3o0?ooocl0oooo00<000000?O/]0000000
3@2gZ/d00`000000V<ci09S<n@0=09S<n@030000003oool0000002H0oooo000`0?ooo`050000003o
ool0oooo0?ooo`0000003P2Hc?T01@000000HWKA069fd@1RM]40000000X0T/Oj00<0000004mE^@1?
EKT00`1?EKT00`000000oooo0?ooo`3o0?oooch0oooo00@000000?O/]03gk;@000003@2gZ/d00`00
0000V<ci09S<n@0=09S<n@030000003oool0000002H0oooo000`0?ooo`050000003oool0oooo0?oo
o`0000003P2Hc?T00`000000HWKA069fd@02069fd@030000002BaoX0T/Oj00P0T/Oj00<0000004mE
^@1?EKT00`1?EKT00`000000oooo0?ooo`3o0?ooocd0oooo00<000000?O/]00000003@2gZ/d00`00
0000V<ci09S<n@0>09S<n@030000003oool0000002H0oooo000`0?ooo`<0000000<0oooo00000000
00003@2Hc?T00`000000HWKA069fd@03069fd@030000002BaoX0T/Oj00L0T/Oj00<0000004mE^@1?
EKT00`1?EKT00`000000oooo0?ooo`3o0?oooc`0oooo00@000000?O/]03gk;@000003@2gZ/d80000
00P0V<ci00D000000?ooo`3oool0oooo0000000U0?ooo`00<03oool00`000000oooo0?ooo`020?oo
o`030000002Hc?T0V<ci00/0V<ci00<00000069fd@1RM]40101RM]400`000000T/Oj09;7nP0609;7
nP030000001?EKT0CeFi00@0CeFi00<000000?ooo`3oool0o`3ooolj0?ooo`050000003gk;@0mnbd
0?O/]0000000302gZ/d2000000L0/;GL2@0000030?ooo`030000003oool0oooo02<0oooo000`0?oo
o`030000003oool0oooo0080oooo0`00000<09S<n@030000001RM]40HWKA00@0HWKA0P00000609;7
nP030000001?EKT0CeFi00D0CeFi00<000000?ooo`3oool0o`3oooli0?ooo`050000003gk;@0mnbd
0?O/]00000002`2gZ/d00`000000h=790000000?0;2eg0050000003oool0oooo0?ooo`0000009@3o
ool00300oooo00<000000?ooo`3oool00P3oool00`000000PIWR086IhP02000000X0V<ci00<00000
069fd@1RM]401P1RM]400`000000T/Oj09;7nP0309;7nP030000001?EKT0CeFi00D0CeFi00<00000
0?ooo`3oool0o`3ooolh0?ooo`030000003gk;@0mnbd0080mnbd00<000000;NZc@2gZ/d0202gZ/d0
0`000000h=790000000?0;2eg0030000003oool0oooo0080oooo00<000000?ooo`3oool08`3oool0
0300oooo00<000000?ooo`3oool00P3oool00`000000PIWR086IhP02086IhP800000202Hc?T00`00
0000HWKA069fd@07069fd@030000002BaoX0T/Oj0080T/Oj00<0000004mE^@1?EKT01P1?EKT00`00
0000oooo0?ooo`3o0?ooocL0oooo00<000000?O/]03gk;@00P3gk;@00`000000]j[=0;NZc@070;NZ
c@040000003PdLT0h=79000000l0/;GL00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0S
0?ooo`00<03oool00`000000oooo0?ooo`020?ooo`0300000021VN80PIWR00@0PIWR0P00000609S<
n@030000001RM]40HWKA00P0HWKA00D0000009;7nP2BaoX0T/Oj0000000804mE^@030000003oool0
oooo0?l0oooo=P3oool00`000000mnbd0?O/]0030?O/]0030000002gZ/d0]j[=00H0]j[=00D00000
0>3Ab@3PdLT0h=790000000>0;2eg0030000003oool0oooo00<0oooo00<000000?ooo`3oool08`3o
ool00300oooo0P0000030?ooo`0300000021VN80PIWR00H0PIWR0P00000409S<n@030000001RM]40
HWKA00T0HWKA00@0000009;7nP2BaoX000002@1?EKT00`000000oooo0?ooo`3o0?oooc@0oooo00<0
00000?O/]03gk;@0103gk;@00`000000]j[=0;NZc@050;NZc@030000003PdLT0h=790080h=7900<0
00000;2eg02`]M`0302`]M`00`000000oooo0?ooo`030?ooo`030000003oool0oooo02<0oooo000`
0?ooo`030000003oool0oooo0080oooo00<00000086IhP21VN802021VN8200000080V<ci00<00000
069fd@1RM]402P1RM]400`000000T/Oj0000000:04mE^@030000003oool0oooo0?l0oooo<`3oool0
0`000000mnbd0?O/]0040?O/]0030000002gZ/d0]j[=00@0]j[=00<000000>3Ab@3PdLT00`3PdLT0
0`000000/;GL0;2eg00;0;2eg0030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool0
02<0oooo00D0_g@0000000000000000007Boo`070?ooo`030000003oool0oooo00@0oooo00<00000
086IhP21VN802@21VN83000000d0HWKA0P00000:04mE^@030000003oool0oooo0?l0oooo<P3oool0
0`000000mnbd0?O/]0050?O/]0030000002gZ/d0]j[=00<0]j[=00<000000>3Ab@3PdLT00`3PdLT0
0`000000/;GL0;2eg00;0;2eg08000001P3oool00`000000oooo0?ooo`0S0?ooo`008P3oool01`2o
M00007Bo0?ooo`3oool0omnL04P0001d_ol01P3oool00`000000oooo0?ooo`040?ooo`0300000021
VN80PIWR00/0PIWR00<00000069fd@1RM]40301RM]400`000000CeFi04mE^@0904mE^@030000003o
ool0oooo0?l0oooo<@3oool00`000000mnbd0?O/]0050?O/]0030000002gZ/d0]j[=0080]j[=00<0
00000>3Ab@3PdLT0103PdLT00`000000/;GL0;2eg0090;2eg080000000<0b[W90000003oool01@3o
ool00`000000oooo0?ooo`0S0?ooo`009`3oool00`3o_g@007Bo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<00000086IhP21VN802`21VN82000000d0HWKA0P00000:04mE^@030000003oool0
oooo0?l0oooo<03oool00`000000mnbd0?O/]0050?O/]0030000002gZ/d0]j[=0080]j[=00<00000
0>3Ab@3PdLT01@3PdLT00`000000/;GL0;2eg0070;2eg08000000`3:^LT00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02<0oooo000W0?ooo`030?noM000M;l0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000PIWR086IhP0;086IhP8000003@1RM]42000000/0CeFi00<000000?oo
o`3oool0o`3oool_0?ooo`030000003gk;@0mnbd00D0mnbd00D000000;NZc@2gZ/d0]j[=00000008
0>3Ab@030000002`]M`0/;GL00D0/;GL0P0000040<Zib@030000003oool0oooo00D0oooo00<00000
0?ooo`3oool08`3oool001T0oooo00<0W4P00000000000000`0000000`00B9`0oooo0?ooo`050?oo
o`0309a8001d_ol0oooo00D0oooo100000030?ooo`0300000021VN80PIWR00/0PIWR00<0000006i]
`0000000301RM]400`000000Ff;00000000:04mE^@030000003oool0oooo0?l0oooo;P3oool00`00
0000mnbd0?O/]0060?O/]0040000002gZ/d0]j[=000000T0h=7900<000000;2eg02`]M`00P2`]M`3
000000H0b[W900<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0S0?ooo`008P3oool00`3o
okl0M000000000020000000304RLg`3oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000PIWR086IhP0;086IhP040000001^KL00KVg0000000/0HWKA00@0000005]R`01KH/0000002P1?
EKT00`000000oooo0?ooo`3o0?ooob`0oooo00<000000?O/]03gk;@01`3gk;@00`000000]j[=0000
00090>3Ab@040000002`]M`0/;GL0;2eg08000002@3:^LT00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0280oooo000R0?ooo`030?oo_`1d07@0_ooo00X0oooo00<000000?ooo`3oool0103o
ool00`000000PIWR086IhP0;086IhP050000001^KL00KVg006i]`00000002P1RM]4010000000Ff;0
05]R`000000:04mE^@800000o`3oool]0?ooo`030000003gk;@0mnbd00L0mnbd0P00000:0>3Ab@04
0000002`]M`00000000000/0b[W900<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0R0?oo
o`008P3oool00`3ookl0M01d0;ooo`0:0?ooo`030000003oool0oooo00@0oooo0P00000<086IhP05
0000001^KL00KVg006i]`00000002P1RM]401@000000Ff;005]R`01KH/00000000T0CeFi0P00003o
0?ooob`0oooo00<000000?O/]03gk;@0203gk;@00`000000h=790>3Ab@090>3Ab@800000303:^LT0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0280oooo000R0?ooo`030?oo_`1d00000000
0080000000<0001d0;ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000001nM/000000
00/0PIWR00<0000006i]`01^KL000P1^KL000`000000HWKA069fd@07069fd@030000001KH/00Ff;0
0080Ff;000<0000004mE^@1?EKT01P1?EKT00`000000@UBn0000003o0?ooob/0oooo00<000000?O/
]03gk;@01`3gk;@2000000X0h=790P00000=0<Zib@030000003oool0oooo00L0oooo00<000000?oo
o`3oool08P3oool002l0oooo00<000000?ooo`3oool0103oool010000000OWK007if`000000:086I
hP030000001^KL00KVg000<0KVg000<00000069fd@1RM]401P1RM]400`000000Ff;005]R`00205]R
`0030000001?EKT0CeFi00H0CeFi00@00000049D_P12E;h00000o`3ooolY0?ooo`030000003gk;@0
mnbd00P0mnbd0P00000:0>3Ab@8000003@3:^LT00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0280oooo000_0?ooo`8000001@3oool01@000000OWK007if`01nM/00000000T0PIWR00<00000
06i]`01^KL00101^KL000`000000HWKA069fd@05069fd@030000001KH/00Ff;000<0Ff;000<00000
04mE^@1?EKT01@1?EKT010000000@UBn049D_P00003o0?ooobT0oooo00<000000?O/]03gk;@01`3g
k;@00`000000l^bo000000090>3Ab@030000003]h<<0000000d0b[W900<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0R0?ooo`00;`3oool00`000000oooo0?ooo`040?ooo`050000001nM/00
OWK007if`00000002@21VN800`000000KVg006i]`00406i]`0030000001RM]40HWKA00D0HWKA00<0
000005]R`01KH/00101KH/000`000000CeFi04mE^@0404mE^@0500000012E;h0@UBn049D_P000000
o`3ooolW0?ooo`030000003gk;@0mnbd00L0mnbd00@000000?;/_`3bk;l00000203PdLT010000000
kN330>gP``00000<0<Zib@030000003oool0oooo00P0oooo00<000000?ooo`3oool08P3oool002l0
oooo00<000000?ooo`3oool0103oool00`000000OWK007if`00207if`00300000021VN80PIWR00H0
PIWR00<0000006i]`01^KL001@1^KL000`000000HWKA069fd@04069fd@030000001KH/00Ff;000@0
Ff;000<0000004mE^@1?EKT0101?EKT00`000000@UBn049D_P02049D_P030000003oool0oooo0?l0
oooo8`3oool2000000P0mnbd00@000000?;/_`3bk;l00000203PdLT01@000000kN330>gP``3]h<<0
000000`0b[W900<000000?ooo`3oool0203oool00`000000oooo0?ooo`0R0?ooo`00;`3oool00`00
0000oooo0?ooo`040?ooo`030000001nM/00OWK000<0OWK000<00000086IhP21VN801P21VN800`00
0000KVg006i]`00506i]`0030000001RM]40HWKA00<0HWKA00<0000005]R`01KH/001@1KH/000`00
0000CeFi04mE^@0304mE^@0300000012E;h0@UBn0080@UBn00<000000?ooo`3oool0o`3ooolS0?oo
o`800000203gk;@010000000l^bo0?;/_`0000080>3Ab@040000003]h<<0kN33000000d0b[W900<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0R0?ooo`00;P3oool00`000000oooo0?ooo`05
0?ooo`030000001nM/00OWK000@0OWK000<00000086IhP21VN801@21VN800`000000KVg006i]`006
06i]`0030000001RM]40HWKA0080HWKA00<0000005]R`01KH/001P1KH/000`000000CeFi04mE^@02
04mE^@0300000012E;h0@UBn00<0@UBn00<000000?ooo`3oool0o`3ooolQ0?ooo`030000003bmKH0
000000L0mnbd00D000000?;/_`3bk;l0l^bo000000070>3Ab@050000003]h<<0kN330>gP``000000
303:^LT2000000X0oooo00<000000?ooo`3oool08P3oool002h0oooo00<000000?ooo`3oool01@3o
ool00`000000OWK007if`00507if`00300000021VN80PIWR00@0PIWR00<0000006i]`01^KL001P1^
KL000`000000HWKA069fd@02069fd@030000001KH/00Ff;000L0Ff;000<0000004mE^@1?EKT00P1?
EKT00`000000@UBn049D_P03049D_P030000003oool0oooo0?l0oooo7`3oool010000000l_Ff0?;e
]P0000060?O/]0030000003bk;l0l^bo0080l^bo00<000000>3Ab@3PdLT0103PdLT00`000000kN33
0>gP``020>gP``030000003:^LT0b[W900T0b[W900<000000>KDa@0000002P3oool00`000000oooo
0?ooo`0R0?ooo`00;P3oool00`000000oooo0?ooo`050?ooo`030000001nM/00OWK000H0OWK000<0
0000086IhP21VN800`21VN800`000000KVg006i]`00706i]`0050000001RM]40HWKA069fd@000000
2@1KH/000`000000CeFi04mE^@0204mE^@0300000012E;h0@UBn00<0@UBn00<000000?ooo`3oool0
o`3ooolO0?ooo`030000003bmKH0000000L0mnbd00<000000?;/_`3bk;l00P3bk;l00`000000h=79
0>3Ab@040>3Ab@030000003]h<<0kN330080kN3300<000000<Zib@3:^LT0203:^LT010000000i]C5
0>KDa@00000:0?ooo`030000003oool0oooo0280oooo000^0?ooo`<000001@3oool00`000000OWK0
07if`00707if`00300000021VN80PIWR0080PIWR00<0000006i]`01^KL00201^KL0010000000HWKA
069fd@00000:05]R`0050000001?EKT0CeFi04mE^@0000001P12E;h00`000000oooo0?ooo`3o0?oo
oad0oooo00@000000?;e]P3bmKH000001P3gk;@00`000000l^bo0?;/_`030?;/_`030000003PdLT0
h=7900<0h=7900<000000>gP``3]h<<00`3]h<<00`000000b[W90<Zib@070<Zib@050000003Ve<D0
i]C50>KDa@0000002P3oool00`000000oooo0?ooo`0R0?ooo`00;P3oool00`000000oooo0?ooo`05
0?ooo`030000001nM/00OWK000P0OWK000D00000086IhP21VN80PIWR0000000;06i]`0030000001R
M]40000000/0Ff;000@0000004mE^@1?EKT000001`12E;h00`000000oooo0?ooo`3o0?oooa/0oooo
00D000000?;e]P3bmKH0l_Ff000000050?O/]0030000003bk;l0l^bo00@0l^bo00<000000>3Ab@3P
dLT00P3PdLT00`000000kN330>gP``040>gP``030000003:^LT0b[W900L0b[W900D000000>KDa@3V
e<D0i]C50000000;0?ooo`030000003oool0oooo0240oooo000^0?ooo`030000003oool0oooo00H0
oooo00<0000007if`01nM/001`1nM/001@000000PIWR086IhP21VN80000000/0KVg000<00000069f
d@0000002`1KH/0010000000CeFi04mE^@000007049D_P030000003oool0oooo0?l0oooo6`3oool0
1@000000l_Ff0?;e]P3bmKH0000000@0mnbd00<000000?;/_`3bk;l01@3bk;l00`000000h=790>3A
b@020>3Ab@030000003]h<<0kN3300@0kN3300<000000<Zib@3:^LT01P3:^LT01@000000i]C50>KD
a@3Ve<D0000000`0oooo00<000000?ooo`3oool08@3oool002h0oooo00<000000?ooo`3oool01P3o
ool00`000000OWK007if`00807if`00400000021VN80PIWR000000`0KVg00P00000<05]R`0030000
001?EKT0000000P0@UBn00<000000?ooo`3oool0o`3ooolI0?ooo`030000003bmKH0l_Ff0080l_Ff
00<000000?O/]03gk;@00P3gk;@00`000000l^bo0?;/_`050?;/_`050000003PdLT0h=790>3Ab@00
00001`3]h<<00`000000b[W90<Zib@050<Zib@030000003Ve<D0i]C50080i]C500<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0Q0?ooo`00;P3oool00`000000oooo0?ooo`060?ooo`030000
001nM/00OWK000T0OWK000<00000086IhP0000003@1^KL000`000000Ff;005]R`00;05]R`0800000
2@12E;h00`000000oooo0?ooo`3o0?oooaL0oooo00<000000?;e]P3bmKH00`3bmKH01@000000mnbd
0?O/]03gk;@0000000P0l^bo00@000000>3Ab@3PdLT00000203]h<<00`000000b[W90<Zib@040<Zi
b@030000003Ve<D0i]C500<0i]C500<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Q0?oo
o`00;P3oool00`000000oooo0?ooo`060?ooo`030000001nM/00OWK000X0OWK00P00000=06i]`080
0000301KH/02000000T0@UBn00<000000?ooo`3oool0o`3ooolG0?ooo`030000003bmKH0l_Ff00<0
l_Ff00@000000?O/]03gk;@00000203bk;l010000000h=790>3Ab@0000090>gP``030000003:^LT0
b[W900<0b[W900<000000>KDa@3Ve<D0103Ve<D00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0240oooo000^0?ooo`8000001`3oool00`000000OWK007if`00;07if`0030000001^KL00KVg0
00/0KVg000<0000006I^aP000000301KH/000`000000@UBn049D_P08049D_P030000003oool0oooo
0?l0oooo5@3oool00`000000l_Ff0?;e]P040?;e]P040000003gk;@0mnbd000000P0l^bo00@00000
0>3Ab@3PdLT000002@3]h<<00`000000b[W90<Zib@020<Zib@030000003Ve<D0i]C500D0i]C500<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0Q0?ooo`00;P3oool00`000000oooo0?ooo`06
0?ooo`030000001nM/00OWK000/0OWK00P00000<06i]`0040000001VK/H0IVk6000000/0Ff;00P00
000:049D_P030000003oool0oooo0?l0oooo503oool00`000000l_Ff0?;e]P030?;e]P040000003g
k;@0mnbd000000T0l^bo00<000000>3Ab@0000002P3]h<<01@000000b[W90<Zib@3:^LT0000000P0
i]C500<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Q0?ooo`00;P3oool00`000000oooo
0?ooo`060?ooo`030000001nM/00OWK000/0OWK000<0000007QhaP0000002`1^KL001@000000IVk6
06I^aP1VK/H0000000X0Ff;000<00000051RaP0000002@12E;h00`000000oooo0?ooo`3o0?oooa<0
oooo00<000000?;e]P3bmKH0103bmKH00`000000mnbd0000000:0?;/_`8000002P3]h<<01@000000
b[W90<Zib@3:^LT0000000T0i]C500<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Q0?oo
o`00;P3oool00`000000oooo0?ooo`060?ooo`030000001nM/00OWK000/0OWK000@0000007QhaP1h
N<H000002P1^KL001@000000IVk606I^aP1VK/H0000000X0Ff;000<00000051RaP0000002P12E;h0
0`000000oooo0?ooo`3o0?oooa40oooo00<000000?;e]P3bmKH01@3bmKH2000000/0l^bo0P00000:
0>gP``050000003:^LT0b[W90<Zib@0000002@3Ve<D00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0240oooo000^0?ooo`030000003oool0oooo00H0oooo00<0000007if`01nM/002`1nM/00
1@000000N7S607QhaP1hN<H0000000T0KVg000<0000006I^aP1VK/H00P1VK/H00`000000Ff;005]R
`00705]R`0040000001@H/H0D6;6000000X0@UBn00<000000?ooo`3oool0o`3oool@0?ooo`030000
003bmKH0l_Ff00D0l_Ff0P00000;0?;/_`030000003]h<<0kN3300T0kN3300@000000<Zib@3:^LT0
00002P3Ve<D00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0240oooo000^0?ooo`030000
003oool0oooo00H0oooo00<0000007if`01nM/002`1nM/001@000000N7S607QhaP1hN<H0000000T0
KVg000<0000006I^aP1VK/H00`1VK/H00`000000Ff;005]R`00605]R`0050000001@H/H0D6;6051R
aP0000002@12E;h00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?;e]P3bmKH01P3bmKH00`00
0000l^bo0?;/_`090?;/_`8000002`3]h<<00`000000b[W90000000;0>KDa@030000003oool0oooo
00X0oooo00<000000?ooo`3oool08@3oool002d0oooo0`0000070?ooo`030000001nM/00OWK000/0
OWK000<0000007QhaP1hN<H00P1hN<H00`000000KVg006i]`00606i]`0030000001VK/H0IVk600@0
IVk600<0000005]R`01KH/001@1KH/000`000000D6;6051RaP02051RaP0300000012E;h0@UBn00L0
@UBn00<000000?ooo`3oool0o`3oool=0?ooo`030000003bmKH0l_Ff00H0l_Ff0P00000:0?;/_`03
0000003/j/T0000000/0kN330P00000<0>KDa@030000003oool0oooo00X0oooo00<000000?ooo`3o
ool08@3oool002d0oooo00<000000?ooo`3oool01`3oool00`000000OWK007if`00;07if`0030000
001hN<H0N7S600<0N7S600<0000006i]`01^KL001@1^KL000`000000IVk606I^aP0506I^aP030000
001KH/00Ff;000@0Ff;000<00000051RaP1@H/H00`1@H/H00`000000@UBn049D_P06049D_P800000
o`3oool>0?ooo`030000003bmKH0l_Ff00D0l_Ff00<000000>kfa00000002@3bk;l010000000k>[9
0>cZb@00000;0>gP``030000003Ve<D0i]C500/0i]C500<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0Q0?ooo`00;@3oool00`000000oooo0?ooo`070?ooo`800000301nM/000`000000N7S6
07QhaP0407QhaP030000001^KL00KVg000D0KVg000<0000006I^aP1VK/H01@1VK/H00`000000Ff;0
05]R`00305]R`0030000001@H/H0D6;600<0D6;600<00000049D_P12E;h01P12E;h00`000000<U?4
0000003o0?ooo``0oooo00<000000?;e]P3bmKH01@3bmKH010000000k_K40>kfa00000080?;/_`05
0000003/j/T0k>[90>cZb@0000002P3]h<<2000000`0i]C500<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0Q0?ooo`003@3oool00`3ookl0M000000000040000000307Boo`3oool0oooo0080
oooo00<0_g@000000000M;l01@3oool01@2oM0000000000000000000M;oo00L0oooo00<000000?oo
o`3oool01`3oool00`000000QX350000000;07if`0030000001hN<H0N7S600D0N7S600<0000006i]
`01^KL00101^KL000`000000IVk606I^aP0606I^aP030000001KH/00Ff;000<0Ff;000<00000051R
aP1@H/H00`1@H/H00`000000@UBn049D_P05049D_P030000000bDl@000000?l0oooo2`3oool00`00
0000l_Ff0?;e]P060?;e]P030000003^m/@0000000T0l^bo00@000000>cZb@3/j/T000002P3]h<<0
0`000000i]g;0000000<0>KDa@030000003oool0oooo00`0oooo00<000000?ooo`3oool0803oool0
00h0oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?ooo`030?ooo`030;md0000000007Bo
00@0oooo00L0_g@0001d_`3oool0oooo0?oOW0180000M;oo00H0oooo00<000000?ooo`3oool01`3o
ool010000000QX3508J0a@00000:07if`0030000001hN<H0N7S600H0N7S600<0000006i]`01^KL00
0`1^KL000`000000IVk606I^aP0706I^aP030000001KH/00Ff;00080Ff;000<00000051RaP1@H/H0
101@H/H00`000000@UBn049D_P04049D_P040000000bDl@0<U?400000?l0oooo2P3oool00`000000
l_Ff0?;e]P050?;e]P040000003^m/@0k_K4000000P0l^bo00D000000>cZb@3/j/T0k>[900000009
0>gP``040000003VgL/0i]g;000000`0i]C500<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0P0?ooo`003`3oool00`3o_g@0001809cOo`0C0?ooo`030?noM000M;l0oooo00D0oooo00<00000
0?ooo`3oool01`3oool01@000000QX3508J0a@26P<D0000000X0OWK000<0000007QhaP1hN<H01P1h
N<H00`000000KVg006i]`00206i]`0030000001VK/H0IVk600P0IVk600D0000005]R`01KH/00Ff;0
00000007051RaP0300000012E;h0@UBn00<0@UBn00D00000039Ca00bDl@0<U?40000003o0?ooo`P0
oooo00<000000?;e]P3bmKH01@3bmKH01@000000k_K40>kfa03^m/@0000000L0l^bo00<000000>cZ
b@3/j/T00P3/j/T00`000000kN330>gP``060>gP``050000003VgL/0i]g;0>KMb`000000303Ve<D0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0200oooo000@0?ooo`030?oOW0180000B9cO
0180oooo00<0okmd001d_`3oool01@3oool00`000000oooo0?ooo`070?ooo`0300000026P<D0QX35
0080QX3500<0000007if`01nM/001`1nM/000`000000N7S607QhaP0707QhaP050000001^KL00KVg0
06i]`00000002P1VK/H01@000000Ff;005]R`01KH/00000000P0D6;600<00000049D_P12E;h00P12
E;h00`000000<U?4039Ca002039Ca0030000003oool0oooo0?l0oooo103oool2000000H0l_Ff00<0
00000>kfa03^m/@00P3^m/@00`000000l^bo0?;/_`040?;/_`030000003/j/T0k>[900<0k>[900<0
00000>gP``3]h<<01@3]h<<01@000000i]g;0>KMb`3VgL/0000000d0i]C500<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0P0?ooo`001@3oool00`2LB000000000000003000000030018W03o
ool0oooo00@0oooo00<0W4P004RLg`3oool0403oool00`2LB000M;oo0?ooo`050?ooo`@000001P3o
ool00`000000QX3508J0a@0308J0a@030000001nM/00OWK000H0OWK000<0000007QhaP1hN<H01`1h
N<H01@000000KVg006i]`01^KL00000000/0IVk600@0000005]R`01KH/000000201@H/H00`000000
@UBn049D_P02049D_P030000000bDl@0<U?40080<U?400<000000?ooo`3oool0o`3oool30?ooo`03
0000003VnkL0000000D0l_Ff00<000000>kfa03^m/@00`3^m/@00`000000l^bo0?;/_`030?;/_`03
0000003/j/T0k>[900@0k>[900<000000>gP``3]h<<0103]h<<00`000000i]g;0>KMb`020>KMb`03
0000003Ve<D0i]C500/0i]C500<000000?ooo`3oool0303oool00`000000oooo0?ooo`0P0?ooo`00
4`3oool00`2LB7@0_ooo0?ooo`0:0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0
1@3oool00`000000oooo0?ooo`070?ooo`0300000026P<D0QX3500@0QX350P00000607if`0030000
001hN<H0N7S600P0N7S600@0000006i]`01^KL000000301VK/H00`000000Ff;000000009051RaP03
00000012E;h0@UBn0080@UBn00<00000039Ca00bDl@00P0bDl@00`000000oooo0?ooo`3o0?ooo`80
oooo0P0000050?;e]P030000003^m/@0k_K400@0k_K400<000000?;/_`3bk;l00P3bk;l00`000000
k>[90>cZb@050>cZb@030000003]h<<0kN3300<0kN3300<000000>KMb`3VgL/00`3VgL/00`000000
i]C50>KDa@0;0>KDa@030000003oool0oooo00`0oooo00<000000?ooo`3oool0803oool000h0oooo
00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`0:0?ooo`030?oo_`1d07@0_ooo00X0oooo
00<000000?ooo`3oool01`3oool00`000000QX3508J0a@0608J0a@030000001nM/00OWK000<0OWK0
00<0000007QhaP1hN<H02@1hN<H00`000000KVg00000000=06I^aP8000002P1@H/H01@000000@UBn
049D_P12E;h0000000D0<U?400<000000?ooo`3oool0o`3oool00`000000i_^g000000050?;e]P03
0000003^m/@0k_K400@0k_K400D000000?;/_`3bk;l0l^bo000000080>cZb@030000003]h<<0kN33
00<0kN3300<000000>KMb`3VgL/00`3VgL/00`000000i]C50>KDa@0:0>KDa@8000003P3oool00`00
0000oooo0?ooo`0P0?ooo`003P3oool01`3o_g@0001d0;ooo`3oool0okmd0000B02Lgol02`3oool0
0`3ookl0M01d0;ooo`0:0?ooo`030000003oool0oooo00L0oooo00<0000008J0a@26P<D01`26P<D0
0`000000OWK007if`00207if`0030000001hN<H0N7S600X0N7S60P00000>06I^aP030000001@H/H0
D6;600T0D6;600@00000049D_P12E;h000001P0bDl@00`000000oooo0?ooo`3m0?ooo`040000003V
nkL0i_^g000000@0l_Ff00<000000>kfa03^m/@01@3^m/@010000000l^bo0?;/_`0000090>cZb@03
0000003]h<<0kN330080kN3300<000000>KMb`3VgL/0103VgL/00`000000i]C50>KDa@090>KDa@03
0000003Od//0000000h0oooo00<000000?ooo`3oool0803oool000l0oooo00D0okmd000000000000
001809cOo`0<0?ooo`030?oo_`1d000000000080000000<0001d0;ooo`3oool01@3oool00`000000
oooo0?ooo`070?ooo`0300000026P<D0QX3500P0QX3500D0000007if`01nM/00OWK00000000=07Qh
aP030000001VK/H0IVk600`0IVk60P00000;051RaP0300000012E;h0000000H0<U?400<000000?oo
o`3oool0o03oool01@000000i_^g0>Kk]`3VnkL0000000<0l_Ff00<000000>kfa03^m/@01@3^m/@0
1@000000l^bo0?;/_`3bk;l0000000T0k>[900D000000>gP``3]h<<0kN33000000070>KMb`030000
003Ve<D0i]C500L0i]C50P0000020=oBb`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
803oool002d0oooo00<000000?ooo`3oool01`3oool00`000000QX3508J0a@0908J0a@040000001n
M/00OWK0000000d0N7S60P00000=06I^aP030000001ML<h0000000X0D6;600<00000049D_P000000
1`0bDl@00`000000oooo0?ooo`3j0?ooo`050000003VnkL0i_^g0>Kk]`0000000`3bmKH00`000000
k_K40>kfa0060>kfa0040000003bk;l0l^bo000000T0k>[900D000000>gP``3]h<<0kN3300000008
0>KMb`030000003Ve<D0i]C500H0i]C500<000000=oBb`3Od//00P3Od//00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0200oooo000]0?ooo`800000203oool00`000000QX3508J0a@0:08J0
a@030000001nM/00000000d0N7S600<00000075jc@000000301VK/H010000000GG3>05e`cP00000:
051RaP800000200bDl@00`000000oooo0?ooo`3i0?ooo`050000003VnkL0i_^g0>Kk]`0000000P3b
mKH00`000000k_K40>kfa0070>kfa0030000003bk;l0000000X0k>[900@000000>gP``3]h<<00000
2@3VgL/00`000000i]C50>KDa@050>KDa@030000003Od//0gm;;00<0gm;;00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0P0?ooo`00;@3oool00`000000oooo0?ooo`070?ooo`0300000026
P<D0QX3500/0QX350P00000=07QhaP040000001aN/d0LG[=000000/0IVk600D0000005e`cP1ML<h0
GG3>0000000:051RaP030000000bDl@0<U?400L0<U?400<000000?ooo`3oool0m`3oool00`000000
i_^g0>Kk]`020>Kk]`030000003bmKH0000000X0k_K40P00000;0>cZb@030000003]h<<0000000X0
i]g;00<000000>KDa@3Ve<D0103Ve<D00`000000gm;;0=oBb`030=oBb`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0803oool002`0oooo00<000000?ooo`3oool0203oool00`000000QX35
08J0a@0<08J0a@030000001hN<H0N7S600/0N7S600@00000075jc@1aN/d0LG[=0P00000906I^aP03
0000001ML<h0GG3>0080GG3>00<00000051RaP1@H/H01`1@H/H2000000P0<U?400<000000?ooo`3o
ool0mP3oool00`000000i_^g0>Kk]`030>Kk]`030000003bmKH0000000X0k_K400<000000>cZb@3/
j/T02P3/j/T2000000/0i]g;00<000000>KDa@3Ve<D00`3Ve<D00`000000gm;;0=oBb`040=oBb`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0803oool002`0oooo00<000000?ooo`3oool0
203oool00`000000QX3508J0a@0<08J0a@800000301hN<H00`000000LG[=075jc@03075jc@030000
001VK/H0IVk600H0IVk600<0000005e`cP1ML<h00`1ML<h00`000000D6;6051RaP06051RaP030000
0011Hlh0000000P0<U?400<000000?ooo`3oool0m03oool00`000000i_^g0>Kk]`030>Kk]`030000
003bmKH0000000X0k_K40P00000<0>cZb@030000003VgL/0i]g;00T0i]g;00<000000>KDa@3Ve<D0
0`3Ve<D00`000000gm;;0=oBb`050=oBb`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
7`3oool002`0oooo00<000000?ooo`3oool0203oool00`000000QX3508J0a@0<08J0a@0300000021
Pl`0000000/0N7S600<00000075jc@1aN/d0101aN/d00`000000IVk606I^aP0506I^aP030000001M
L<h0GG3>00@0GG3>00<00000051RaP1@H/H01@1@H/H010000000@F?>045ScP000008039Ca0030000
003oool0oooo0?80oooo00<000000>Kk]`3VnkL0103VnkL2000000X0k_K400<000000>Sdd0000000
2`3/j/T2000000/0i]g;00<000000>KDa@3Ve<D00P3Ve<D00`000000gm;;0=oBb`060=oBb`030000
003oool0oooo00h0oooo00<000000?ooo`3oool07`3oool002`0oooo00<000000?ooo`3oool0203o
ool00`000000QX3508J0a@0<08J0a@0300000021Pl`0PH?<008000002@1hN<H00`000000LG[=075j
c@05075jc@030000001VK/H0IVk600D0IVk600<0000005e`cP1ML<h0101ML<h00`000000D6;6051R
aP04051RaP0500000011Hlh0@F?>045ScP000000200bDl@00`000000oooo0?ooo`3a0?ooo`030000
003VnkL0i_^g00@0i_^g00<000000>kfa03^m/@0203^m/@00`000000j?C@0000000;0>cZb@030000
003Uim80000000/0i]g;00<000000>KDa@3Ve<D00P0000090=oBb`030000003oool0oooo00h0oooo
00<000000?ooo`3oool07`3oool002`0oooo0`0000080?ooo`0300000026P<D0QX3500`0QX3500<0
00000863c021Pl`00P21Pl`00`000000N7S607QhaP0607QhaP030000001aN/d0LG[=00H0LG[=00<0
000006I^aP1VK/H0101VK/H00`000000GG3>05e`cP0405e`cP030000001@H/H0D6;600@0D6;600D0
0000045ScP11Hlh0@F?>00000008039Ca0030000003oool0oooo0?00oooo00<000000>Kk]`3VnkL0
103VnkL2000000T0k_K400@000000>Sdd03Xm=0000002P3/j/T010000000iNOB0>GWdP00000;0>KM
b`030000003Ve<D0000000/0gm;;00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0O0?oo
o`00;03oool00`000000oooo0?ooo`080?ooo`0300000026P<D0QX3500`0QX3500<000000863c021
Pl`00`21Pl`00`000000N7S607QhaP0607QhaP030000001aN/d0LG[=00H0LG[=00<0000006I^aP1V
K/H00`1VK/H00`000000GG3>05e`cP0505e`cP030000001@H/H0D6;600<0D6;600<00000045ScP11
Hlh00P11Hlh00`000000<U?4039Ca006039Ca0030000003oool0oooo0>h0oooo00<000000>Kk]`3V
nkL0103VnkL00`000000hog7000000080>kfa0050000003Xm=00j?C@0>Sdd0000000203/j/T20000
00<0iNOB00<000000>KMb`3VgL/02@3VgL/2000000`0gm;;00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0O0?ooo`00;03oool00`000000oooo0?ooo`080?ooo`0300000026P<D0QX3500`0
QX3500<000000863c021Pl`01021Pl`00`000000N7S607QhaP0507QhaP030000001aN/d0LG[=00L0
LG[=00<0000006I^aP1VK/H00P1VK/H00`000000GG3>05e`cP0605e`cP030000001@H/H0D6;600<0
D6;600<00000045ScP11Hlh00P11Hlh00`000000<U?4039Ca006039Ca0030000003oool0oooo0>`0
oooo00<000000>Kk]`3VnkL0103VnkL010000000hog70>?ma`0000070>kfa0030000003Xm=00j?C@
0080j?C@00<000000>cZb@3/j/T01@3/j/T00`000000iNOB0>GWdP020>GWdP030000003VgL/0i]g;
00X0i]g;00<000000=oBb`3Od//02`3Od//00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
01l0oooo000/0?ooo`030000003oool0oooo00P0oooo00<0000008J0a@26P<D03026P<D00`000000
PH?<0863c0050863c0030000001hN<H0N7S600@0N7S600<00000075jc@1aN/d0201aN/d200000080
IVk600<0000005e`cP1ML<h01`1ML<h00`000000D6;6051RaP02051RaP0300000011Hlh0@F?>00<0
@F?>00<00000039Ca00bDl@01@0bDl@200000>`0oooo00<000000>Kk]`3VnkL01@3VnkL00`000000
hog7000000070>kfa0030000003Xm=00j?C@00<0j?C@00<000000>cZb@3/j/T0103/j/T00`000000
iNOB0>GWdP030>GWdP030000003VgL/0i]g;00T0i]g;0P00000=0=oBb`030000003oool0oooo00h0
oooo00<000000?ooo`3oool07`3oool002`0oooo00<000000?ooo`3oool0203oool00`000000QX35
08J0a@0<08J0a@0300000021Pl`0PH?<00H0PH?<00<0000007QhaP1hN<H00`1hN<H00`000000LG[=
075jc@0:075jc@030000001VK/H0000000X0GG3>00D00000051RaP1@H/H0D6;600000006045ScP03
0000000bDl@0<U?400@0<U?400<0000001iBbP000000j`3oool00`000000i_^g0>Kk]`040>Kk]`04
0000003SoLL0hog7000000H0k_K400<000000>Sdd03Xm=000`3Xm=000`000000k>[90>cZb@040>cZ
b@030000003Uim80iNOB00@0iNOB00<000000>KMb`3VgL/0203VgL/00`000000g]_B0000000=0=oB
b`030000003oool0oooo00h0oooo00<000000?ooo`3oool07`3oool002`0oooo00<000000?ooo`3o
ool0203oool3000000`0QX3500<000000863c021Pl`01`21Pl`00`000000N7S607QhaP0207QhaP03
0000001aN/d0LG[=00/0LG[=0P00000;05e`cP040000001@H/H0D6;6000000L0@F?>00<00000039C
a00bDl@00`0bDl@0100000007U;:01iBbP00003Y0?ooo`030000003VnkL0i_^g00@0i_^g00D00000
0>?ma`3SoLL0hog7000000050>kfa0030000003Xm=00j?C@00@0j?C@00<000000>cZb@3/j/T00`3/
j/T00`000000iNOB0>GWdP050>GWdP030000003VgL/0i]g;00H0i]g;0P0000020=kKdP030000003O
d//0gm;;00X0gm;;00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0O0?ooo`00;03oool0
0`000000oooo0?ooo`080?ooo`040000002>R//0SX[;000000/0QX3500<000000863c021Pl`02021
Pl`200000080N7S600<00000075jc@1aN/d0301aN/d00`000000GG3>05e`cP0:05e`cP030000001@
H/H0000000P0@F?>00<00000039Ca00bDl@00P0bDl@0100000007U;:01iBbP00003X0?ooo`030000
003VnkL0i_^g00@0i_^g00<000000>?ma`3SoLL00P3SoLL00`000000k_K40>kfa0020>kfa0030000
003Xm=00j?C@00D0j?C@00<000000>cZb@3/j/T00P3/j/T00`000000iNOB0>GWdP060>GWdP030000
003VgL/0i]g;00D0i]g;00<000000=kKdP3Nfm800P3Nfm800`000000gm;;0=oBb`0:0=oBb`030000
003oool0oooo00l0oooo00<000000?ooo`3oool07`3oool002`0oooo0P0000090?ooo`050000002>
R//0SX[;08j:b`0000002P26P<D00`000000PH?<0863c00:0863c0030000001hN<H0000000h0LG[=
0P00000<05e`cP8000002@11Hlh01@000000<U?4039Ca00bDl@0000000<07U;:00<000000?ooo`3o
ool0i03oool2000000D0i_^g00<000000>?ma`3SoLL00`3SoLL01@000000k_K40>kfa03^m/@00000
00P0j?C@00D000000>cZb@3/j/T0k>[9000000090>GWdP030000003VgL/0i]g;00@0i]g;00<00000
0=kKdP3Nfm800P3Nfm800`000000gm;;0=oBb`0;0=oBb`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool07`3oool002`0oooo00<000000?ooo`3oool0203oool00`000000SX[;08j:b`0208j:
b`8000002026P<D00`000000PH?<0863c00;0863c08000003P1aN/d00`000000JGkE0000000<05e`
cP0300000011Hlh0@F?>00P0@F?>00D00000039Ca00bDl@0<U?40000000301iBbP030000003oool0
oooo0>80oooo00<000000=3k/`000000103VnkL00`000000hog70>?ma`040>?ma`040000003^m/@0
k_K4000000T0j?C@00@000000>cZb@00000000002P3Uim800`000000i]g;0>KMb`030>KMb`030000
003Nfm80g]_B00<0g]_B00<000000=oBb`3Od//02`3Od//00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01l0oooo000/0?ooo`030000003oool0oooo00P0oooo00<0000008j:b`2>R//0102>
R//00`000000QX3508J0a@0508J0a@0300000021Pl`0PH?<00`0PH?<00<00000075jc@1aN/d0301a
N/d010000000JGkE06Une@00000;05e`cP8000002@11Hlh01@000000<U?4039Ca00bDl@0000000@0
7U;:00<000000?ooo`3oool0h03oool00`000000d?^c000000050>Kk]`030000003SoLL0hog700<0
hog700@000000>kfa03^m/@000002@3Xm=000`000000k>[90000000<0>GWdP030000003VgL/0i]g;
0080i]g;00<000000=kKdP3Nfm80103Nfm800`000000gm;;0=oBb`0;0=oBb`030000003oool0oooo
00l0oooo00<000000?ooo`3oool07`3oool002/0oooo00<000000?ooo`3oool02@3oool00`000000
SX[;08j:b`0508j:b`0300000026P<D0QX3500@0QX3500<000000863c021Pl`03021Pl`3000000`0
LG[=00D0000006Une@1YO]D0JGkE0000000:05e`cP030000001@L]H0000000T0@F?>00@00000039C
a00bDl@000001@0ND/X00`000000oooo0?ooo`3O0?ooo`030000003@nk<0000000@0i_^g00<00000
0>?ma`3SoLL0103SoLL00`000000k_K40000000:0>Sdd0800000303Uim800`000000i]g;0>KMb`02
0>KMb`030000003Nfm80g]_B00D0g]_B00<000000=oBb`3Od//02`3Od//00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo01h0oooo000[0?ooo`030000003oool0oooo00T0oooo00<0000008j:
b`2>R//01P2>R//2000000@0QX3500<000000863c021Pl`03021Pl`010000000O8KC07b6d`00000;
075jc@030000001YO]D0JGkE0080JGkE00<0000005e`cP1ML<h01`1ML<h010000000D7;F051beP00
0009045ScP030000000bDl@0000000H07U;:00<000000?ooo`3oool0g@3oool010000000d?^c0=3k
/`0000030>Kk]`030000003SoLL0hog700D0hog70P00000;0>Sdd0030000003Uim80iNOB00/0iNOB
00<000000>KMb`3VgL/00P0000080=kKdP030000003Od//0gm;;00T0gm;;0`00000B0?ooo`030000
003oool0oooo01h0oooo000[0?ooo`030000003oool0oooo00T0oooo00<0000008j:b`2>R//0202>
R//01@000000QX3508J0a@26P<D0000000h0PH?<00D0000007b6d`1lQ]<0O8KC0000000:075jc@03
0000001YO]D0JGkE00<0JGkE00<0000005e`cP1ML<h01P1ML<h01@000000D7;F051beP1@L]H00000
00T0@F?>0P00000601iBbP030000003oool0oooo0=`0oooo00D000000=3k/`3@nk<0d?^c00000002
0>Kk]`030000003SoLL0hog700H0hog700<000000>Sdd03Xm=002@3Xm=02000000d0iNOB00<00000
0>KMb`0000002P3Nfm800`000000gm;;0=oBb`080=oBb`040000003Gcm80eloB00000180oooo00<0
00000?ooo`3oool07P3oool002/0oooo0`0000090?ooo`030000002>R//0SX[;00T0SX[;00@00000
08J0a@26P<D000003P21Pl`00`000000O8KC07b6d`0207b6d`800000201aN/d00`000000JGkE06Un
e@0406Une@8000001P1ML<h00`000000D7;F051beP02051beP0300000011Hlh0@F?>00L0@F?>00<0
000001iBbP0ND/X01@0ND/X00`000000oooo0?ooo`3J0?ooo`030000003@nk<0d?^c0080d?^c00<0
00000>Kk]`000000203SoLL2000000X0j?C@00<000000>7afP0000003@3Uim82000000/0g]_B00<0
00000=oBb`3Od//01P3Od//2000000<0eloB00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0N0?ooo`00:`3oool00`000000oooo0?ooo`090?ooo`030000002>R//0SX[;00X0SX[;0`00000>
0863c0030000001lQ]<0O8KC00@0O8KC00<00000075jc@1aN/d01@1aN/d00`000000JGkE06Une@06
06Une@030000001ML<h0GG3>00<0GG3>00<00000051beP1@L]H00`1@L]H00`000000@F?>045ScP06
045ScP8000001`0ND/X00`000000oooo0?ooo`3H0?ooo`030000003@nk<0d?^c00<0d?^c0P000008
0>?ma`030000003No=@0000000P0j?C@0P0000020>7afP030000003Uim80iNOB00/0iNOB00<00000
0=kKdP3Nfm802P3Nfm800`000000gm;;0=oBb`050=oBb`030000003Gcm80eloB00<0eloB00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0N0?ooo`00:`3oool00`000000oooo0?ooo`0:0?oo
o`030000002>R//0SX[;00/0SX[;00<000000863c021Pl`03021Pl`00`000000O8KC07b6d`0507b6
d`030000001aN/d0LG[=00@0LG[=00<0000006Une@1YO]D01`1YO]D00`000000GG3>05e`cP0205e`
cP030000001@L]H0D7;F00@0D7;F0P000006045ScP030000000_I=D0000000L07U;:00<000000?oo
o`3oool0eP3oool00`000000d?^c0=3k/`030=3k/`030000003VnkL0000000L0hog700<000000=kl
e0000000203Xm=001@000000hO7J0>7afP3QlMX0000000`0iNOB0`00000<0=kKdP030000003Od//0
gm;;00<0gm;;0P0000050=O?dP030000003oool0oooo0140oooo00<000000?ooo`3oool07P3oool0
01h0oooo00D0okmd000000000000000007Boo`080?ooo`030000003oool0oooo00X0oooo00<00000
08j:b`2>R//02`2>R//3000000`0PH?<00<0000007b6d`1lQ]<01P1lQ]<2000000@0LG[=00<00000
06Une@1YO]D0201YO]D01@000000GG3>05e`cP1ML<h0000000P0D7;F00<00000045ScP11Hlh00`11
Hlh010000000;fCE02mTe@00000701iBbP030000003oool0oooo0=D0oooo00<000000=3k/`3@nk<0
0`3@nk<2000000L0hog700@000000=kle03No=@000001`3Xm=000`000000hO7J0>7afP020>7afP03
0000003Uim80iNOB00T0iNOB00@000000=cTfP3Li=X000002`3Nfm800`000000gm;;0=oBb`030=oB
b`030000003Gcm80eloB00D0eloB00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0N0?oo
o`007P3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`L0oooo00<000000?ooo`3oool02P3oool0
0`000000SX[;08j:b`0;08j:b`030000002:S]40RXkA008000002`21Pl`00`000000O8KC07b6d`07
07b6d`050000001aN/d0LG[=075jc@0000002`1YO]D010000000GG3>05e`cP000009051beP030000
0011Hlh0@F?>0080@F?>00D0000002mTe@0_I=D0;fCE0000000701iBbP030000003oool0oooo0=<0
oooo00<000000=3k/`3@nk<0103@nk<00`000000hog70>?ma`050>?ma`050000003No=@0g_cD0=kl
e00000001P3Xm=000`000000hO7J0>7afP030>7afP030000003Uim80iNOB00L0iNOB0P0000020=cT
fP030000003Nfm80g]_B00X0g]_B00@000000=oBb`3Od//0gm;;0P0000080=O?dP030000003oool0
oooo0140oooo00<000000?ooo`3oool07P3oool001d0oooo00<0okmd001d_`3oool00P3oool00`3O
W4P0B9cO0?ooo`060?ooo`030000003oool0oooo00X0oooo00<0000008j:b`2>R//02`2>R//00`00
0000RXkA08Z>d@0208Z>d@8000002@21Pl`00`000000O8KC07b6d`0807b6d`040000001aN/d0LG[=
000000`0JGkE00<0000005e`cP0000002P1@L]H01@000000@F?>045ScP11Hlh0000000@0;fCE00<0
000001iBbP0ND/X0100ND/X00`000000oooo0?ooo`3B0?ooo`030000003@nk<0d?^c00@0d?^c0P00
00060>?ma`030000003No=@0g_cD0080g_cD00<000000>Sdd03Xm=000`3Xm=000`000000hO7J0>7a
fP040>7afP030000003Uim80iNOB00H0iNOB00<000000=cTfP3Li=X00P3Li=X00`000000g]_B0=kK
dP0:0=kKdP040000003Od//0gm;;000000X0eloB00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0N0?ooo`007@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00H0oooo00<0
00000?ooo`3oool02P3oool00`000000SX[;08j:b`0;08j:b`030000002:S]40RXkA00@0RXkA00<0
00000863c021Pl`01P21Pl`00`000000O8KC07b6d`0907b6d`<000003@1YO]D2000000/0D7;F00@0
0000045ScP11Hlh000001@0_I=D00`0000007U;:01iBbP0401iBbP030000003oool0oooo0=00oooo
00<000000=3k/`3@nk<0103@nk<00`000000c_o6000000040>?ma`8000001@3No=@00`000000j?C@
0>Sdd0020>Sdd0030000003QlMX0hO7J00D0hO7J00<000000>GWdP3Uim801@3Uim800`000000g>CJ
0=cTfP030=cTfP030000003Nfm80g]_B00X0g]_B0`00000;0=O?dP030000003oool0oooo0140oooo
00<000000?ooo`3oool07P3oool001d0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?oo
o`060?ooo`<000002P3oool00`000000SX[;08j:b`0;08j:b`030000002:S]40RXkA00D0RXkA0P00
00060863c0030000001lQ]<0O8KC00/0O8KC00<0000006Une@1YO]D0301YO]D00`000000D7;F051b
eP0:051beP0300000011Hlh0000000H0;fCE00<0000001iBbP0ND/X0100ND/X00`000000oooo0?oo
o`3>0?ooo`030000003@nk<0d?^c00@0d?^c00<000000<koaP000000103SoLL00`000000g_cD0=kl
e0050=kle0050000003Xm=00j?C@0>Sdd0000000203QlMX00`000000iNOB0>GWdP030>GWdP800000
1P3Li=X00`000000g]_B0=kKdP0:0=kKdP030000003Gcm80eloB00/0eloB00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0N0?ooo`007@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000
M;l0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000SX[;08j:b`0;08j:b`030000002:
S]40RXkA00L0RXkA0P0000040863c0030000001lQ]<0O8KC00/0O8KC0`00000<06Une@800000301@
L]H2000000L0;fCE0P00000501iBbP030000003oool0oooo0<`0oooo00<000000=3k/`3@nk<0103@
nk<010000000c_o60<koaP0000030>?ma`030000003No=@0g_cD00D0g_cD00<000000>Sdd03Xm=00
0P0000090>7afP030000003Uim80iNOB0080iNOB00<000000=cTfP3Li=X01P3Li=X00`000000g]_B
0=kKdP080=kKdP<000003@3Gcm800`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01h0oooo
000M0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool01P3oool00`000000oooo0?oo
o`0:0?ooo`030000002>R//0SX[;00/0SX[;00<0000008Z>d@2:S]402@2:S]4200000080PH?<00<0
000007b6d`1lQ]<02`1lQ]<010000000M8_K07B;f`00000;06Une@040000001NP]d00000000000/0
D7;F00<0000002mTe@0_I=D01`0_I=D00`0000007U;:01iBbP0201iBbP800000c@3oool00`000000
d?^c0=3k/`030=3k/`050000003>olH0c_o60<koaP0000000P3SoLL00`000000g_cD0=kle0060=kl
e0030000003Xm=00000000X0hO7J00@000000>GWdP3Uim80iNOB0P0000080=cTfP030000003Nfm80
g]_B00P0g]_B00@000000=KHf@3Ff=T000003@3Gcm800`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo01h0oooo000N0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo1`3oool00`000000oooo
0?ooo`0:0?ooo`030000002>R//0SX[;00/0SX[;00<0000008Z>d@2:S]402`2:S]43000000d0O8KC
00@0000007B;f`1dRm/0M8_K0P00000906Une@050000001NP]d0GX;M05j2g@0000002P1@L]H20000
00T0;fCE00L0000001iBbP0ND/X07U;:00000005DLh000000</0oooo00<000000=3k/`3@nk<00`3@
nk<00`000000c_o60<koaP020<koaP030000003SoLL0000000T0g_cD0P00000;0>7afP040000003U
im80iNOB000000X0g>CJ00<000000=kKdP3Nfm801P3Nfm82000000<0e]SI00<000000=O?dP3Gcm80
2`3Gcm800`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01d0oooo000N0?ooo`050?oo_`1d
000000000000B02Lgol0203oool00`000000oooo0?ooo`0:0?ooo`8000003@2>R//00`000000RXkA
08Z>d@0<08Z>d@030000001lQ]<0O8KC00/0O8KC00<0000007B;f`1dRm/00`1dRm/00`000000JGkE
06Une@0606Une@030000001NP]d0GX;M0080GX;M00<00000051beP1@L]H01`1@L]H010000000@GKN
00000000000802mTe@040000000ND/X07U;:000000801E7>00<000000?ooo`3oool0a`3oool00`00
0000d?^c0=3k/`030=3k/`030000003>olH0c_o60080c_o600<000000>?ma`0000002P3No=@00`00
0000hO7J0>7afP0:0>7afP<000002`3Li=X00`000000g]_B0=kKdP050=kKdP030000003Ff=T0e]SI
00<0e]SI00<000000=O?dP3Gcm802`3Gcm800`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
01d0oooo000Z0?ooo`030000003oool0oooo00/0oooo00@0000009BDd@00000000002`2>R//00`00
0000RXkA08Z>d@0<08Z>d@<000002`1lQ]<00`000000M8_K07B;f`0407B;f`030000001YO]D0JGkE
00D0JGkE00<0000005j2g@1NP]d00`1NP]d2000000L0D7;F00D00000045fgP11M]h0@GKN00000008
02mTe@040000000ND/X07U;:000000801E7>00<000000?ooo`3oool0a@3oool00`000000d?^c0=3k
/`020=3k/`8000001@3>olH2000000T0g_cD0`00000<0>7afP030000003Li=X0g>CJ00/0g>CJ00<0
00000=kKdP3Nfm800`3Nfm82000000D0e]SI00<000000=O?dP3Gcm802`3Gcm800`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo01d0oooo000Z0?ooo`<000002`3oool010000000U9CA09BDd@2D
U=42000000T0SX[;00<0000008Z>d@2:S]40302:S]400`000000QI;I08FBf@02000000T0O8KC00<0
000007B;f`1dRm/01@1dRm/2000000H0JGkE00<0000005j2g@1NP]d0101NP]d00`000000D7;F051b
eP04051beP0300000011M]h0@GKN0080@GKN00<0000002mTe@0_I=D01P0_I=D00`0000007U;:0000
000300EAcP030000003oool0oooo0<<0oooo0P0000030=3k/`030000003>olH0c_o600D0c_o600<0
00000=kle03No=@01`3No=@010000000eoWP0=Oih000000:0>7afP<000003@3Li=X00`000000g]_B
0=kKdP020=kKdP030000003Ff=T0e]SI00D0e]SI00<000000=O?dP3Gcm802`3Gcm800`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01d0oooo000Z0?ooo`030000003oool0oooo00/0oooo00<0
000009BDd@2DU=400`2DU=42000000L0SX[;00<0000008Z>d@2:S]40302:S]400`000000QI;I08FB
f@0208FBf@030000001lQ]<0O8KC00L0O8KC00<0000007B;f`1dRm/01P1dRm/00`000000JGkE06Un
e@0306Une@030000001NP]d0GX;M00D0GX;M00<00000051beP1@L]H00`1@L]H00`000000@GKN045f
gP03045fgP8000001`0_I=D2000000@01E7>00<000000?ooo`3oool0`@3oool2000000<0d?^c00<0
00000<koaP3>olH01@3>olH2000000P0g_cD00@000000=Oih03GnN0000002P3QlMX010000000engR
0=O]hP00000=0=cTfP030000003Nfm80g]_B00800000203Ff=T00`000000eloB0=O?dP0;0=O?dP03
0000003oool0oooo01<0oooo00<000000?ooo`3oool07@3oool002X0oooo00<000000?ooo`3oool0
2`3oool00`000000U9CA09BDd@0509BDd@8000001@2>R//00`000000RXkA08Z>d@0<08Z>d@030000
0025T]T0QI;I00<0QI;I0P00000707b6d`030000001dRm/0M8_K00L0M8_K0P00000306Une@030000
001NP]d0GX;M00H0GX;M0P000004051beP0300000011M]h0@GKN00@0@GKN00<0000002mTe@0_I=D0
1@0_I=D00`0000001E7>00EAcP0300EAcP030000003oool0oooo0;l0oooo00<000000:caZ`000000
0P3@nk<00`000000c_o60<koaP040<koaP80000000<0booF0000003No=@01@3No=@2000000<0eoWP
00<000000>7afP3QlMX01P3QlMX2000000<0engR00<000000=cTfP3Li=X02P3Li=X010000000g]_B
0=kKdP00000:0=KHf@030000003Gcm80eloB00/0eloB00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0M0?ooo`00:P3oool00`000000oooo0?ooo`0;0?ooo`030000002DU=40U9CA00L0U9CA
0P00000308j:b`030000002:S]40RXkA00`0RXkA00<0000008FBf@25T]T01@25T]T2000000D0O8KC
00<0000007B;f`1dRm/02@1dRm/010000000JGkE06Une@00000:05j2g@050000001@L]H0D7;F051b
eP0000001`11M]h00`000000;fCE02mTe@0402mTe@8000001@05DLh00`000000oooo0?ooo`2m0?oo
o`060000002/lJ/0[?6[0000003@nk<000001P3>olH010000000booF0<_oeP0000060=kle0030000
003GnN00eoWP00<0eoWP00<000000>7afP3QlMX01@3QlMX00`000000engR0=O]hP020=O]hP030000
003Li=X0g>CJ00/0g>CJ0`00000;0=KHf@030000003Gcm80eloB00/0eloB00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0M0?ooo`00:P3oool00`000000oooo0?ooo`0;0?ooo`030000002D
U=40U9CA00T0U9CA0P0000000`2>R//0000008Z>d@0=08Z>d@0300000025T]T0QI;I00L0QI;I00<0
000007b6d`1lQ]<00P1lQ]<00`000000M8_K07B;f`0:07B;f`<000002`1NP]d010000000D7;F051b
eP000008045fgP800000100_I=D0100000006FKJ00000000000400EAcP030000003oool0oooo0;/0
oooo00@000000:caZ`2/lJ/0[?6[0P0000060<koaP050000003;omH0booF0<_oeP0000001@3No=@0
0`000000eoWP0=Oih0040=Oih0030000003QlMX0hO7J00<0hO7J0P0000050=O]hP030000003Li=X0
g>CJ00/0g>CJ00<000000=KHf@3Ff=T02`3Ff=T00`000000eloB0=O?dP0:0=O?dP8000005@3oool0
0`000000oooo0?ooo`0M0?ooo`00:P3oool00`000000oooo0?ooo`0;0?ooo`030000002DU=40U9CA
00/0U9CA0P00000>08Z>d@0300000025T]T0QI;I00P0QI;I0P00000207b6d`030000001dRm/0M8_K
00`0M8_K00<0000005j2g@1NP]d02P1NP]d3000000X0@GKN00D0000002mTe@0_I=D0;fCE00000003
01UVfP0300000005DLh01E7>00801E7>00<000000?ooo`3oool0^@3oool010000000[?6[0:caZ`2/
lJ/2000000D0c_o60P0000040<_oeP040000003No=@0g_cD0=kle08000001`3GnN000`000000hO7J
0>7afP020>7afP030000003GkN80engR00D0engR00<000000=cTfP3Li=X02@3Li=X3000000d0e]SI
00<000000=O?dP3Gcm80203Gcm82000000030<o=f0000000oooo01@0oooo00<000000?ooo`3oool0
7@3oool002X0oooo00<000000?ooo`3oool02`3oool00`000000U9CA09BDd@0<09BDd@<000003@2:
S]400`000000QI;I08FBf@0908FBf@<000003P1dRm/3000000`0GX;M00<00000045fgP11M]h02@11
M]h01@000000;fCE02mTe@0_I=D0000000<06FKJ00<0000000EAcP05DLh00P05DLh00`000000oooo
0?ooo`2g0?ooo`030000002/lJ/0[?6[0080[?6[00<000000<koaP3>olH00`3>olH00`000000booF
0<_oeP040<_oeP040000003No=@0g_cD000000T0eoWP00<000000>7afP3QlMX00P0000080=O]hP03
0000003Li=X0g>CJ00L0g>CJ0P0000020=?Ph@030000003Ff=T0e]SI00/0e]SI00<000000=O?dP3G
cm801P3Gcm82000000<0clgH00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0M0?ooo`00
:P3oool2000000d0oooo00<0000009BDd@2DU=402`2DU=400`000000TIWG096Ie`02000000/0RXkA
00<0000008FBf@25T]T02`25T]T00`000000M8_K07B;f`0<07B;f`030000001[T>@0Ji3T00800000
2P1NP]d3000000X0@GKN0P0000000`0_I=D0000001UVfP0301UVfP0300000005DLh01E7>00801E7>
00<000000?ooo`3oool0]03oool2000000@0[?6[0P0000040<koaP030000003;omH0booF00@0booF
00@000000=kle03No=@000002@3GnN0010000000hO7J0>7afP00000:0=O]hP030000003Li=X0g>CJ
00D0g>CJ0P0000040=?Ph@030000003Ff=T0e]SI00X0e]SI00<000000=O?dP3Gcm801@3Gcm820000
00D0clgH00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0M0?ooo`00:P3oool00`000000
oooo0?ooo`0<0?ooo`030000002DU=40U9CA00/0U9CA00<00000096Ie`2AVML00P2AVML2000000T0
RXkA00<0000008FBf@25T]T02`25T]T3000000`0M8_K00<0000006^@i01[T>@00P1[T>@2000000P0
GX;M00@000000566iP1AQ^H000002`11M]h2000000D06FKJ00<0000000EAcP05DLh00P05DLh00`00
0000oooo0?ooo`2b0?ooo`030000002/lJ/0[?6[0080[?6[0`0000030<koaP8000001`3;omH30000
00X0eoWP0`00000;0=O]hP030000003Li=X0g>CJ00<0g>CJ0P0000050=?Ph@030000003Ff=T0e]SI
00/0e]SI00<000000=O?dP3Gcm800`3Gcm82000000L0clgH00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0M0?ooo`00:P3oool00`000000oooo0?ooo`0<0?ooo`030000002DU=40U9CA00/0
U9CA00<00000096Ie`2AVML0102AVML2000000L0RXkA00<0000008FBf@25T]T02`25T]T00`000000
OYOQ07jGh@02000000X0M8_K00<0000006^@i01[T>@0101[T>@00`000000GX;M05j2g@0505j2g@04
0000001AQ^H0DHKV0566iP8000002P11M]h00`0000006FKJ01UVfP0401UVfP8000000`05DLh00`00
0000oooo0?ooo`2`0?ooo`030000002/lJ/0[?6[0080[?6[00@000000:gg`02]ml0000000P3>olH0
0`000000booF0<_oeP070<_oeP030000003GnN00eoWP00X0eoWP00<000000=O]hP3GkN802P3GkN80
0`000000g>CJ0=cTfP020=cTfP8000001`3Ch>400`000000e]SI0=KHf@0;0=KHf@040000003Gcm80
eloB0=O?dP800000203?cMP00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01d0oooo000Z
0?ooo`030000003oool0oooo00`0oooo00<0000009BDd@2DU=402`2DU=400`000000TIWG096Ie`06
096Ie`8000001@2:S]400`000000QI;I08FBf@0;08FBf@030000001nUn40OYOQ0080OYOQ0P000008
07B;f`030000001[T>@0Ji3T00D0Ji3T0P00000505j2g@030000001AQ^H0DHKV00<0DHKV0P000008
045fgP<000001P0II]X01@0000001E7>00EAcP05DLh000000;00oooo00<000000:caZ`2/lJ/00P2/
lJ/01`000000[OO00:gg`02]ml0000000<koaP000000203;omH3000000X0eoWP0`00000<0=O]hP03
0000003Li=X0g>CJ008000002@3Ch>400`000000e]SI0=KHf@0;0=KHf@040000003Gcm8000000000
00X0clgH00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0L0?ooo`00:P3oool00`000000
oooo0?ooo`0<0?ooo`030000002DU=40U9CA00/0U9CA00<00000096Ie`2AVML0202AVML2000000<0
RXkA00<0000008FBf@25T]T02`25T]T00`000000OYOQ07jGh@0407jGh@8000001`1dRm/00`000000
Ji3T06^@i00606^@i0800000101NP]d00`000000DHKV0566iP040566iP0300000011M]h0@GKN00D0
@GKN00@0000002eii00]NN@000001P0II]X01@0000001E7>00EAcP05DLh000000:h0oooo00<00000
0:caZ`2/lJ/00P2/lJ/010000000[OO00:gg`02]ml03000000P0booF00@000000<Gmi035oN@00000
203GnN0200000080c_CY00<000000=O]hP3GkN802P3GkN83000000/0dn3Q00<000000=KHf@3Ff=T0
2P3Ff=T3000000`0clgH00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0L0?ooo`00:P3o
ool00`000000oooo0?ooo`0<0?ooo`030000002DU=40U9CA00/0U9CA00<00000096Ie`2AVML02P2A
VML20000000308Z>d@000000QI;I00`0QI;I00<0000007jGh@1nUn401P1nUn42000000D0M8_K00<0
000006^@i01[T>@0201[T>@200000080GX;M00<000000566iP1AQ^H01@1AQ^H2000000D0@GKN00@0
000002eii00]NN@0;GWT0P00000501UVfP0500000005DLh01E7>00EAcP000000[03oool00`000000
[?6[0:caZ`020:caZ`030000002]ml00[OO00080[OO000<000000<_oeP3;omH01P3;omH200000080
aOgT00<000000=Oih03GnN001P3GnN001@000000c_CY0<kdj@3>m>T0000000`0engR0P00000=0=?P
h@030000003Ff=T0e]SI00P0e]SI0P0000000`3=e=l000000<o=f00<0<o=f0030000003oool0oooo
01D0oooo00<000000?ooo`3oool0703oool002T0oooo0`00000=0?ooo`030000002DU=40U9CA00`0
U9CA00<00000096Ie`2AVML02`2AVML3000000`0QI;I00<0000007jGh@1nUn40201nUn42000000<0
M8_K00<0000006^@i01[T>@02P1[T>@3000000T0DHKV00<00000045fgP11M]h00P11M]h00`000000
;GWT02eii00302eii0030000000II]X06FKJ00<06FKJ00<0000000EAcP05DLh00P00002Z0?ooo`04
0000002/lJ/0[?6[0:caZ`8000000`2]ml03000000H0booF0P0000040<Gmi0030000003GnN00eoWP
00@0eoWP0P0000040<kdj@030000003GkN80engR00P0engR0P0000000`3=j>T000000=?Ph@0<0=?P
h@030000003Ff=T0e]SI00H0e]SI0P0000030<gDg`030000003?cMP0clgH00/0clgH00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0L0?ooo`00:@3oool00`000000oooo0?ooo`0=0?ooo`03
0000002DU=40U9CA00`0U9CA00<00000096Ie`2AVML0302AVML010000000SIgN00000000000;08FB
f@030000001nUn40OYOQ00T0OYOQ0P0000000`1dRm/0000006^@i00=06^@i0030000001AQ^H0DHKV
00P0DHKV0P000002045fgP030000000]NN@0;GWT00@0;GWT00<0000001UVfP0II]X00`0II]X30000
0003001Ac000000000000:L0oooo00D000000:caZ`2/lJ/0[?6[000000040:gg`0030000002]nM80
000000H0booF00<000000<Gmi035oN@01035oN@00`000000eoWP0=Oih0020=Oih08000001P3>m>T0
0`000000engR0=O]hP060=O]hP8000000`3=j>T00`000000dn3Q0=?Ph@0;0=?Ph@030000003Ff=T0
e]SI00@0e]SI0P0000050<gDg`030000003?cMP0clgH00/0clgH00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0L0?ooo`00:@3oool00`000000oooo0?ooo`0=0?ooo`8000003@2DU=400`00
0000TIWG096Ie`0<096Ie`040000002=WMh0SIgN08fMgP<000002025T]T00`000000OYOQ07jGh@0;
07jGh@8000003P1[T>@3000000X0DHKV0`00000702eii08000001@0II]X200000080057<00<00000
0?ooo`3oool0X`3oool200000080[?6[00@000000:gg`02]ml00[OO00P0000020:gidP030000003;
omH0booF0080booF0P0000070<Gmi0050000003GnN00eoWP0=Oih0000000203>m>T00`000000engR
0=O]hP040=O]hP800000103=j>T00`000000dn3Q0=?Ph@0;0=?Ph@030000003Ff=T0e]SI00<0e]SI
0P0000060<gDg`030000003?cMP0clgH00`0clgH00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0L0?ooo`00:@3oool00`000000oooo0?ooo`0=0?ooo`030000002JWmL00000008000002P2D
U=400`000000TIWG096Ie`0<096Ie`030000002=WMh0SIgN00@0SIgN0P00000608FBf@030000001n
Un40OYOQ00`0OYOQ0`00000<06^@i0030000001OUN`0GiG/008000002P1AQ^H00`000000;GWT02ei
i00702eii0030000000II]X06FKJ00<06FKJ00D00000001Ac000DL`0057<0000002R0?ooo`<00000
0P2/lJ/01@000000[OO00:gg`02]ml00000000@0[OWB00D000000<_oeP3;omH0booF000000080<Gm
i0030000003GnN00eoWP008000002@3>m>T00`000000engR0=O]hP020=O]hP8000001P3=j>T00`00
0000dn3Q0=?Ph@0;0=?Ph@040000003Ff=T0e]SI0=KHf@800000203=e=l00`000000clgH0<o=f00<
0<o=f0030000003oool0oooo01D0oooo00<000000?ooo`3oool0703oool002T0oooo00<000000?oo
o`3oool03@3oool00`000000VYoG09ZOe`0209ZOe`<000001`2DU=400`000000TIWG096Ie`0<096I
e`030000002=WMh0SIgN00H0SIgN0`00000308FBf@030000001nUn40OYOQ00`0OYOQ00<0000007NM
j@1gWNT00P00000:06^@i0030000001OUN`0GiG/0080GiG/0P0000080566iP<00000200]NN@20000
00<06FKJ0`000002001Ac0800000W`3oool00`000000O]^L07kKW003000000<0[OO000<000000:gi
dP2]nM800`2]nM8010000000booF0000000000090<Gmi0<000002P3>m>T010000000engR0=O]hP3G
kN82000000P0cNSY00<000000=?Ph@3Ch>402`3Ch>4010000000e]SI00000000000:0<gDg`030000
003?cMP0clgH00/0clgH00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0L0?ooo`00:@3o
ool00`000000oooo0?ooo`0=0?ooo`030000002JWmL0VYoG00D0VYoG0`00000409BDd@030000002A
VML0TIWG00`0TIWG00<0000008fMgP2=WMh02@2=WMh20000000308FBf@000000OYOQ00d0OYOQ00<0
000007NMj@1gWNT00P1gWNT2000000P0Ji3T00<0000005nEk01OUN`0101OUN`00`000000DHKV0566
iP050566iP0300000010Rn`0@8_/00800000200]NN@0100000006FKJ01UVfP000002001WfP050000
0000DL`0057<001Ac0000000W@3oool00`000000O]^L07kKW002000000<0[OO00P0000050:gidP<0
00002`35oN@00`000000c_CY0<kdj@0:0<kdj@040000003GkN800000000000X0cNSY00<000000=?P
h@3Ch>402P3Ch>43000000`0cMCO00<000000<o=f03?cMP02`3?cMP00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo01`0oooo000Y0?ooo`030000003oool0oooo00d0oooo00<0000009ZOe`2J
WmL0202JWmL30000000309BDd@000000TIWG00d0TIWG00<0000008fMgP2=WMh02`2=WMh3000000d0
OYOQ00<0000007NMj@1gWNT0101gWNT2000000H0Ji3T00<0000005nEk01OUN`01@1OUN`2000000D0
DHKV00<00000042;k010Rn`00P10Rn`2000000L0;GWT0`000003001WfP8000000P00DL`00`000000
oooo0?ooo`2H0?ooo`8000000`1nfi`01@000000[OO00:gg`02]ml00000000L0[OWB00<000000<Gm
i035oN@02@35oN@3000000/0c_CY0`00000<0<gXj@030000003Ch>40dn3Q00P0dn3Q0P0000000`39
g>L000000<gDg`0<0<gDg`030000003?cMP0clgH00/0clgH00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0L0?ooo`00:@3oool3000000d0oooo00<0000009ZOe`2JWmL02`2JWmL3000000h0
TIWG00<0000008fMgP2=WMh02`2=WMh010000000Qj?V00000000000;07jGh@030000001gWNT0MigY
00H0MigY0P00000406^@i0030000001OUN`0GiG/00L0GiG/0P0000040566iP0300000010Rn`0@8_/
00<0@8_/00<0000002eii00]NN@01P0]NN@00`00000006OJ001WfP03001WfP0300000000DL`0057<
00800000U`3oool010000000O]^L07kKW01nfi`200000080[OO00P0000060:gidP<000002@35oN@2
000000030;ghkP000000c_CY00T0c_CY0P0000000`34k_0000000<gXj@0<0<gXj@030000003Ch>40
dn3Q00D0dn3Q0`0000030<WLi`030000003=e=l0cMCO00/0cMCO00<000000<o=f03?cMP02`3?cMP0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01`0oooo000Y0?ooo`030000003oool0oooo
00d0oooo00<0000009ZOe`2JWmL0302JWmL00`000000Uj?M00000002000000/0TIWG00<0000008fM
gP2=WMh02`2=WMh010000000Qj?V08NSiP27XnH3000000T0OYOQ00<0000007NMj@1gWNT01`1gWNT2
00000080Ji3T00<0000005nEk01OUN`02@1OUN`200000080DHKV00<00000042;k010Rn`01010Rn`2
000000H0;GWT0`000004001WfP0500000000DL`0057<001Ac0000000U@3oool00`000000O]^L07kK
W0020000000408;S/`000000[OO0000000H0[OWB0P0000000`2YnN8000000<Gmi0070<Gmi0800000
0`2mn>h00`000000c_CY0<kdj@060<kdj@8000000`34k_000`000000cNSY0<gXj@0:0<gXj@030000
003Ch>40dn3Q00@0dn3Q0P0000050<WLi`030000003=e=l0cMCO00`0cMCO00<000000<o=f03?cMP0
2P3?cMP2000001P0oooo00<000000?ooo`3oool0703oool002T0oooo00<000000?ooo`3oool03@3o
ool00`000000VYoG09ZOe`0<09ZOe`030000002GXmd0Uj?M0080Uj?M0`000008096Ie`030000002=
WMh0SIgN00/0SIgN00<0000008NSiP27XnH01027XnH3000000H0OYOQ00<0000007NMj@1gWNT02@1g
WNT3000000d0GiG/0`000008042;k0800000100]NN@0100000005g_U01Mki@000004001WfP800000
0P00DL`00`000000oooo0?ooo`2@0?ooo`8000000P1nfi`00`000000P^>c08;S/`03000000D0[OWB
0P0000030:WihP0300000035oN@0aOgT00@0aOgT0P0000050;ghkP030000003>m>T0c_CY00@0c_CY
0P0000040<C^l0030000003=j>T0cNSY00/0cNSY00@000000=?Ph@3Ch>40dn3Q0`0000070<WLi`03
0000003=e=l0cMCO00`0cMCO00<000000<o=f03?cMP01`3?cMP3000000030<K<gP000000oooo01L0
oooo00<000000?ooo`3oool0703oool000P0oooo00<0oono07@000000000100000000`1d_ol0oooo
0?ooo`020?ooo`030;md0000000007Bo00D0oooo00D0_g@0000000000000000007Boo`080?ooo`03
0000003oool0oooo00h0oooo00<0000009ZOe`2JWmL02`2JWmL00`000000Uj?M09NSg@0509NSg@@0
0000102AVML00`000000SIgN08fMgP0;08fMgP0300000027XnH0Qj?V00L0Qj?V0P00000407jGh@03
0000001gWNT0MigY00/0MigY0P00000>05nEk08000002@10Rn`200000080;GWT00@0000001Mki@0G
NnD05g_U0P000004001WfP0300000000DL`0057<00800000S`3oool00`000000O]^L07kKW0020000
00<0P^>c00<000000:gidP2]nM800`2]nM82000000D0ZOWR00<000000<Gmi035oN@00P35oN@20000
00L0_OS^00<000000<kdj@3>m>T00P3>m>T2000000H0a>k`00<000000<gXj@3=j>T02`3=j>T01000
0000dn3Q00000000000:0<WLi`030000003=e=l0cMCO00/0cMCO00<000000<o=f03?cMP01@3?cMP3
000000@0a/cN00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0L0?ooo`002@3oool00`2o
M000001d0;ooo`020?ooo`030=nLM02Lgol0oooo00<0oooo00<0_g@000000000M;l0103oool01`2o
M00007Bo0?ooo`3oool0omnL04P0001d_ol01`3oool00`000000oooo0?ooo`0>0?ooo`030000002J
WmL0VYoG00/0VYoG00<0000009NSg@2GXmd02@2GXmd300000003096Ie`000000SIgN00`0SIgN00<0
000008NSiP27XnH02@27XnH30000000307jGh@000000MigY00`0MigY00@0000006fSl@0000000000
301OUN`010000000DI[c000000000009042;k0<000001@0GNnD2000000<006OJ0P000002001Ac003
0000003oool0oooo08/0oooo00@0000007kKW000000000000`22hk<2000000@0[OWB0P0000070:Wi
hP0300000035oN@0aOgT00800000202mn>h010000000c_CY0<kdj@3>m>T2000000P0a>k`00<00000
0<gXj@3=j>T02P3=j>T3000000`0bMcW00<000000<gDg`3=e=l02`3=e=l00`000000clgH0<o=f002
0<o=f0<000001`36c=h00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01/0oooo000:0?oo
o`030?noM00004P0W=oo01<0oooo00<0okmd001d_`3oool01P3oool00`000000oooo0?ooo`0>0?oo
o`030000002JWmL0VYoG00/0VYoG00<0000009NSg@2GXmd0302GXmd3000000d0SIgN00<0000008NS
iP27XnH02`27XnH3000000`0MigY00@0000006fSl@1]Xo40KJ?a0`00000905nEk0040000001AV_<0
DI[c056Jl`8000002@10Rn`2000000H05g_U00<00000001WfP00ImX00P00ImX010000000057<001A
c000002:0?ooo`@000000`22hk<20000000408CXb0000000[OWB0:gidP800000202YnN8010000000
aOgT00000000000:0;ghkP040000003>m>T00000000000X0a>k`00<000000<gXj@3=j>T01`3=j>T3
000000030<?RkP000000bMcW00`0bMcW00<000000<gDg`3=e=l02`3=e=l00`000000clgH00000002
000000T0a/cN00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0K0?ooo`002`3oool00`3o
gi`0B00004RLg`0B0?ooo`030?noM000M;l0oooo00H0oooo00<000000?ooo`3oool03P3oool00`00
0000VYoG09ZOe`0;09ZOe`030000002GXmd0Uj?M00d0Uj?M00<0000009>Xi00000000P00000:08fM
gP0300000027XnH0Qj?V00`0Qj?V00@00000082XkP00000000002P1gWNT00`000000KJ?a06fSl@04
06fSl@<000001P1OUN`00`000000DI[c056Jl`03056Jl`8000001`10Rn`010000000;Hk^00000000
000501Mki@8000000`00ImX5000008L0oooo00<0000007kKW00000000`22hk<200000080Q>S800@0
00000:gidP00000000002@2YnN83000000/0_OS^0`00000<0<C^l0030000003=j>T0cNSY00@0cNSY
0`0000040<?RkP0300000039g>L0bMcW00/0bMcW00<000000<gDg`3=e=l02P3=e=l3000000`0a/cN
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0K0?ooo`003@3oool00`2LB000B9cO0?oo
o`0@0?ooo`0309a8001d_ol0oooo00D0oooo1000000>0?ooo`030000002JWmL0VYoG00`0VYoG00<0
000009NSg@2GXmd0302GXmd00`000000TjST09>Xi00209>Xi0<000001`2=WMh00`000000Qj?V08NS
iP0<08NSiP0400000020Z>h0P:S^082XkP<000001`1gWNT00`000000KJ?a06fSl@0706fSl@800000
101OUN`00`000000DI[c056Jl`05056Jl`<000001010Rn`010000000;Hk^02f>kP0]S^h3000000@0
5g_U00<00000001WfP00ImX00P00ImX0100000000531001@`@0000250?ooo`<000000P22hk<20000
00<0Q>S80`0000090:WihP80000000<0YOG^0000002mn>h02@2mn>h2000000030;Cam@000000a>k`
00/0a>k`00<000000<gXj@3=j>T00P3=j>T3000000H0`n;^00<000000<WLi`39g>L02`39g>L00`00
0000cMCO0<gDg`070<gDg`@0000000<0`m;U00000036c=h03036c=h00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo01/0oooo000>0?ooo`0309a8M02oool0oooo00X0oooo00<0oono07@00000
00000P0000000`18W=l0oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo00<0000009ZOe`2J
WmL0302JWmL00`000000Uj?M09NSg@0<09NSg@030000002CZ>@0TjST00D0TjST0`00000408fMgP03
00000027XnH0Qj?V00`0Qj?V00<00000082XkP20Z>h01020Z>h2000000H0MigY00<0000006fSl@1]
Xo40201]Xo430000000305nEk0000000DI[c00T0DI[c0P000003042;k0030000000]S^h0;Hk^00<0
;Hk^0P00000301Mki@8000000P00ImX300000003001@`@00000000000840oooo0`00000208;S/`80
00000`24j<P20000000308K[fP000000ZOWR00H0ZOWR0`0000020:GekP030000002mn>h0_OS^00H0
_OS^0`0000020;Cam@0300000034k_00a>k`00/0a>k`00<000000<gXj@0000000P0000090<?RkP03
00000039g>L0bMcW00/0bMcW00<000000<gDg`3=e=l00`3=e=l4000000D0`m;U00<000000<K<gP36
c=h02`36c=h00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01/0oooo00090?ooo`030=nL
B01d_ol0oooo0080oooo00<0_g@007Boo`3oool02P3oool00`3ookl0M01d0;ooo`0:0?ooo`030000
003oool0oooo00l0oooo00<0000009ZOe`2JWmL0302JWmL00`000000Uj?M09NSg@0<09NSg@030000
002CZ>@0TjST00P0TjST0`0000000`2=WMh0000008NSiP0=08NSiP0300000020Z>h0P:S^00H0P:S^
0`00000307NMj@030000001]Xo40KJ?a00/0KJ?a0`00000;056Jl`80000000<0@8_/0000000]S^h0
1P0]S^h2000000<05g_U0`000002001Wd080000000<005310000003oool0O@3oool300000080P^>c
0P00000308CXb08000000P26jmX00`000000ZOWR0:WihP030:WihP<000001@2UmNh00`000000_OS^
0;ghkP030;ghkP<000001@2dlOD00`000000a>k`0<C^l00:0<C^l0<000003033h^h00`000000bMcW
0<WLi`0;0<WLi`030000003=e=l0000000<000002@33d^D00`000000a/cN0<K<gP0;0<K<gP030000
003oool0oooo01P0oooo00<000000?ooo`3oool06`3oool000T0oooo00L0okmd0000M02oool0oooo
0?noM00004P0W=oo00/0oooo00<0oono07@0M02oool02P3oool00`000000oooo0?ooo`0?0?ooo`<0
0000302JWmL00`000000Uj?M09NSg@0<09NSg@030000002CZ>@0TjST00/0TjST0`00000=08NSiP03
00000020Z>h0P:S^00T0P:S^0P0000000`1gWNT0000006fSl@0=06fSl@030000001PZ?L000000080
00002P1AV_<3000000P0;Hk^0`00000201Mki@8000000`00Im04000007/0oooo0`0000000`22hk<0
00000000000308CXb08000001026jmX010000000ZOWR0:WihP2YnN82000000P0YOG^00@000000;gh
kP2mn>h0_OS^0P0000080;Cam@0300000034k_00a>k`00L0a>k`0`0000000`2iioD000000<?RkP0<
0<?RkP0300000039g>L0bMcW00X0bMcW0`00000<0<?Bi@0300000036c=h0a/cN00`0a/cN00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0K0?ooo`002P3oool01@3o_g@000000000000004P0
W=oo00`0oooo00<0oono07@0000000000P0000000`0007@0_ooo0?ooo`050?ooo`030000003oool0
oooo00l0oooo00<0000009jYgP2NZMh01@00000709ZOe`030000002GXmd0Uj?M00`0Uj?M00<00000
09>Xi02CZ>@0302CZ>@00`000000SZk[00000003000000T0Qj?V00<00000082XkP20Z>h02`20Z>h3
000000d0KJ?a00<00000062Xm`1PZ?L00P1PZ?L3000000P0DI[c00<00000046Nm@0000000P000008
02f>kP<0000000<00GcN0000000000000`00Im04000007L0oooo0`0000000`1Baj<0000000000002
08CXb0<000001@26jmX00`000000ZOWR00000002000000T0YOG^00<000000;ghkP0000000P00000:
0;Cam@0300000034k_00a>k`00@0a>k`0`0000040;WWm@0300000033h^h0`n;^00/0`n;^00<00000
0<WLi`39g>L01P39g>L4000000030;kHk0000000`m;U00`0`m;U00<000000<K<gP36c=h03036c=h0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01/0oooo000X0?ooo`030000003oool0oooo
00l0oooo00<0000009jYgP2NZMh01@2NZMh500000080VYoG00<0000009NSg@2GXmd03@2GXmd00`00
0000TjST09>Xi00;09>Xi0030000002>[^/0SZk[00<0SZk[1000000508NSiP0300000020Z>h0P:S^
00`0P:S^00<0000007R^m@0000000`00000906fSl@030000001PZ?L0H:Sg00D0H:Sg10000004056J
l`0300000011W_D0@Ike0080@Ike0`00000702f>kP<0000000@00GcN00000000000000000P00Im03
000007@0oooo0`0000000`1Baj<000000000000208CXb08000001`26jmX3000000/0YOG^0`00000<
0;Cam@0300000034k_00a>k`0080a>k`0`0000060;WWm@0300000033h^h0`n;^00/0`n;^00<00000
0<WLi`39g>L00`39g>L4000000D0_]S/00<000000<?Bi@33d^D02`33d^D00`000000a/cN0<K<gP0<
0<K<gP030000003oool0oooo01P0oooo00<000000?ooo`3oool06`3oool002P0oooo0`00000?0?oo
o`030000002NZMh0WZWN00X0WZWN1000000>09NSg@030000002CZ>@0TjST00/0TjST00<0000008j^
j`2>[^/01`2>[^/40000000308NSiP000000P:S^00d0P:S^00<0000007R^m@1h[_D00`1h[_D40000
00H0KJ?a00<00000062Xm`1PZ?L0201PZ?L300000003056Jl`000000@Ike00H0@Ike1000000402f>
kP040000000IT>T00000000000800GcN0P000002001Wd0<00000L03oool30000000505;7X`000000
000000000024j<P00P00000608K[fP<0000000<0Qn_X0000002UmNh0202UmNh3000000030:3_mP00
0000]?7e00`0]?7e00<000000<C^l00000000P0000090;WWm@0300000033h^h0`n;^00/0`n;^00<0
00000<WLi`0000000`0000080;kHk00300000033d^D0`m;U00`0`m;U00<000000<K<gP36c=h02`36
c=h00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01/0oooo000X0?ooo`030000003oool0
oooo00l0oooo00<0000009jYgP2NZMh0302NZMh00`000000VjkT00000003000000X0Uj?M00<00000
09>Xi02CZ>@02`2CZ>@00`000000SZk[08j^j`0;08j^j`<000003@20Z>h00`000000N:ke07R^m@07
07R^m@@000000P1]Xo400`000000H:Sg062Xm`0;062Xm`<000002P11W_D30000000302f>kP000000
6I3Y00806I3Y0`0000000`01O=h0000000000002001Wd0800000KP3oool50000000405W@^P000000
0000000000D0Q^_J0`00000308O[j0030000002UmNh0YOG^00D0YOG^0`0000030:3_mP030000002d
lOD0]?7e00/0]?7e0`00000<0;WWm@0300000033h^h0`n;^00X0`n;^0`00000<0;kHk00300000033
d^D0`m;U00`0`m;U00<000000<K<gP36c=h02`36c=h00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01/0oooo000X0?ooo`030000003oool0oooo00l0oooo00<0000009jYgP2NZMh0302NZMh0
0`000000VjkT09^^i00309^^i0@000001P2GXmd00`000000TjST09>Xi00;09>Xi0030000002>[^/0
SZk[00`0SZk[00<0000008RclP0000000`00000:082XkP030000001h[_D0N:ke00X0N:ke1000000=
062Xm`030000001B[?X00000008000002P11W_D3000000D06I3Y1P0000000`00Im0000000000001Z
0?ooo`@000000P1Id;X3000000<0Q^_J1000000608O[j0040000002UmNh0YOG^0:GekP@000001P2P
koH00`000000]?7e0;Cam@070;Cam@@0000000<0[>[i0000002iioD0302iioD00`000000`n;^0<?R
kP060<?RkP@0000000<0^=gb0000002nf>`0302nf>`00`000000`m;U0<?Bi@0<0<?Bi@0300000036
c=h0a/cN00/0a/cN00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0K0?ooo`00:03oool0
0`000000oooo0?ooo`0?0?ooo`030000002NZMh0WZWN00`0WZWN00<0000009^^i02K[^@01`2K[^@4
00000080Uj?M00<0000009>Xi02CZ>@0302CZ>@00`000000SZk[08j^j`0;08j^j`0300000028/o80
R;?b00<0R;?b10000006082XkP030000001h[_D0N:ke00`0N:ke00<0000006fcnP0000000`000009
062Xm`030000001B[?X0DZcj0080DZcj0`000008046Nm@030000000`XO400000008000001@0IT>T2
00000004005lgP0000000000001Wd0800000IP3oool300000080FM2j0`000002063GcP@000002@27
jnP00`000000YOG^00000002000000X0X>of00<000000;Cam@2dlOD00`2dlOD4000000@0[>[i00<0
00000;WWm@2iioD02`2iioD00`000000`n;^0<?RkP030<?RkP@000001@2hgO800`000000_]S/0;kH
k00;0;kHk00300000033d^D0`m;U00/0`m;U00<000000<K<gP36c=h02P36c=h3000001/0oooo00<0
00000?ooo`3oool06`3oool002P0oooo00<000000?ooo`3oool0403oool00`000000WZWN09jYgP0;
09jYgP030000002K[^@0VjkT00/0VjkT1@00000<09>Xi0030000002>[^/0SZk[00/0SZk[00<00000
08RclP28/o801`28/o8400000080P:S^00<0000007R^m@1h[_D0301h[_D00`000000KK?j06fcnP03
06fcnP@000001@1PZ?L00`000000DZcj05:/nP0505:/nP@000001011W_D00`000000<:7a032Ql@02
032Ql@<00000100IT>T900000600oooo10000000101Id;X00000000000000003063GcP<000002`27
jnP3000000`0X>of00<000000;Cam@2dlOD0100000080:cZn@030000002iioD0^NOe00/0^NOe00<0
00000<?RkP0000000`0000080;SMlP030000002nf>`0_]S/00`0_]S/00<000000<?Bi@33d^D02`33
d^D00`000000a/cN0<K<gP050<K<gPD000000P2lbnD00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo01X0oooo000X0?ooo`030000003oool0oooo0100oooo00<0000009jYgP2NZMh02`2NZMh0
0`000000VjkT09^^i00=09^^i0030000002H/^X0V;;Z00D000001`2CZ>@00`000000SZk[08j^j`0;
08j^j`0300000028/o80R;?b00/0R;?b1@00000<07R^m@030000001]/oX0KK?j00L0KK?j10000000
0`1PZ?L0000005:/nP0:05:/nP<0000000<0@Ike0000000`XO401P0`XO44000000<06I3Y2@00001J
0?ooo`@000000P1Id;X200000080H=O>100000000`1Wfml0000008O[j00708O[j0@0000000<0QnSb
0000002PkoH02P2PkoH5000000`0[>[i00<000000;WWm@2iioD02@2iioD4000000`0^=gb00<00000
0;kHk02nf>`0302nf>`00`000000`m;U0<?Bi@0;0<?Bi@0300000036c=h0a/cN00D000001P2lbnD0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo000X0?ooo`030000003oool0oooo
0100oooo00<0000009jYgP2NZMh02`2NZMh00`000000VjkT09^^i00=09^^i0030000002H/^X0V;;Z
00D0V;;Z1@00000209>Xi0030000002>[^/0SZk[00`0SZk[00<0000008RclP28/o803028/o800`00
0000PKSh086hn005000000L0N:ke00<0000006fcnP1]/oX02`1]/oX4000000`0DZcj10000009032Q
l@<0000000<06I3Y00000009T=d02000001E0?ooo`D0000000<0FM2j0000000000001@00000406OK
g`0300000027jnP0Qn_X00<0Qn_X1000000408OXlP030000002PkoH0X>of00D0X>of1@00000209_Y
n`030000002/j_T0[>[i00`0[>[i00<000000;WWm@2iioD0102iioD500000080[n7h00<000000;SM
lP2hgO802`2hgO800`000000_]S/0;kHk00;0;kHk00300000033d^D0`m;U00T0`m;U1P00000;0;c;
i@030000003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool002P0oooo0P00000A0?ooo`03
0000002NZMh0WZWN00`0WZWN00<0000009^^i02K[^@0302K[^@00`000000V;;Z09RbjP0:09RbjPD0
0000302>[^/00`000000R;?b08RclP0<08RclP0300000021^?P0PKSh00D0PKSh1@00000207R^m@03
0000001]/oX0KK?j00`0KK?j00<0000006:go01R]o`01@00000805:/nP0300000015[oL0AJog00D0
00001`0`XO44000000<02I3M1`00001?0?ooo``00000201Wfml00`000000Qn_X00000003000000P0
QnSb00<000000:3_mP2PkoH01@00000609_Yn`030000002/j_T0[>[i00`0[>[i00<000000;WWm@2i
ioD01@0000060:oQn0030000002hgO80^=gb00`0^=gb00<000000;kHk02nf>`02`2nf>`010000000
`m;U0<?Bi@33d^D8000000<0^Lo[00<000000;c;i@2lbnD02`2lbnD00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01X0oooo000X0?ooo`030000003oool0oooo0100oooo00<0000009jYgP2N
ZMh0302NZMh00`000000VjkT09^^i00<09^^i0030000002H/^X0V;;Z00`0V;;Z00<0000009>gl02C
]o001@00000708j^j`0300000028/o80R;?b00`0R;?b00<00000086hn021^?P02P21^?P5000000`0
KK?j00<0000006:go01R]o`01@1R]o`600000080DZcj00<0000004F_m`15[oL01@15[oL600000080
<:7a00<0000002:Qj00RXNP01@00000200V@g@H00000B@3oool;000000X0Im_O1000000:08OXlPD0
00002`2KjO/00`000000[>[i0:cZn@0:0:cZn@D000002`2_hOP00`000000^=gb0;SMlP0<0;SMlP03
0000002nf>`0_]S/00T0_]S/1P00000;0;W?j`030000002lbnD0_<_U00/0_<_U00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0J0?ooo`00:03oool00`000000oooo0?ooo`0@0?ooo`030000
002NZMh0WZWN00`0WZWN00<0000009^^i02K[^@0302K[^@00`000000V;;Z09RbjP0<09RbjP030000
002C]o00TkO`00D0TkO`1@00000208j^j`0300000028/o80R;?b00`0R;?b00<00000086hn021^?P0
3021^?P00`000000N;cl07Rlo005000000P0KK?j00<0000006:go01R]o`02P1R]o`5000000/0AJog
1@00000502:Qj0`00000@@3oool:00000080BLWF00<0000006OKg`1Wfml01@1Wfml50000000306gL
k0000000QnSb00H0QnSb1@00000208OTn@030000002KjO/0VnWk00/0VnWk00<000000:cZn@2/j_T0
1@2/j_T500000080Y>;l00<000000:oQn02_hOP02`2_hOP00`000000^=gb0;SMlP0;0;SMlP030000
002nf>`0_]S/00D0_]S/1@0000020;CDl@030000002icn/0^Lo[00/0^Lo[00<000000;c;i@2lbnD0
2`2lbnD00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01X0oooo000W0?ooo`030000003o
ool0oooo0140oooo1000000;09jYgP030000002K[^@0VjkT00d0VjkT00<0000009RbjP2H/^X02`2H
/^X00`000000TkO`09>gl00:09>gl0H000002`28/o800`000000PKSh086hn00<086hn0030000001h
_?`0N;cl00D0N;cl1P00000206fcnP030000001R]o`0H[Ol00`0H[Ol00<0000005Nin`1G^O/01@00
000804F_m`030000000i/?40>K3a00D000001P0RXNP50000000304H000000000000000<00000=P3o
ool;000000H0BLWF00<0000006OKg`1Wfml01P00000606gLk00300000027j?80000000D000001P27
i?T00`000000VnWk09_Yn`0;09_Yn`030000002/j_T0[>[i00H000001P2Th_`00`000000[n7h0:oQ
n00<0:oQn0030000002hgO80^=gb00/0^=gb00<000000;kHk02nf>`01@0000070;CDl@030000002i
cn/0^Lo[00/0^Lo[00<000000;c;i@2lbnD02`2lbnD00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01X0oooo000W0?ooo`030000003oool0oooo0140oooo00@000000:6diP2Q]>H0XKCV2000
000309jYgP030000002K[^@0VjkT00d0VjkT00<0000009RbjP2H/^X02`2H/^X00`000000TkO`09>g
l00<09>gl0040000002>_?D0S[ce08jlm@P000000`28/o800`000000PKSh086hn00<086hn0030000
001h_?`0N;cl00/0N;cl1P00000;06:go0030000001G^O/0EkWk00D0EkWk1P00000204F_m`030000
000i/?40>K3a00D0>K3a1P00000202:Qj0030000000JX]d06Z;M00@0000000<0AP00000000000000
1@00000X0?ooo``000000P0;0003000000D0BLWF1P00000806gLk0H000003027i?T00`000000VnWk
09_Yn`0809_Yn`H00000302Th_`00`000000[n7h0:oQn00;0:oQn0030000002hgO80^=gb00T0^=gb
1P00000;0;CDl@030000002icn/0^Lo[00`0^Lo[00<000000;c;i@2lbnD02`2lbnD00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo01X0oooo000W0?ooo`030000003oool0oooo0140oooo00<0
00000:6diP2Q]>H02@2Q]>H7000000`0VjkT00<0000009RbjP2H/^X0302H/^X00`000000TkO`09>g
l00;09>gl0030000002>_?D0S[ce00T0S[ce1`00000<086hn0030000001h_?`0N;cl00`0N;cl00@0
000006nooP1__oh0Kkon2000000306:go0030000001G^O/0EkWk00/0EkWk1P00000:03V`l@`00000
0P16000=00000140oooo5@00000200/000`000000P1EcnD010000000KMc/06gLk01]g>`8000000<0
Lmce00<0000008OTn@27i?T02`27i?T010000000VnWk09_Yn`2KjO/8000000<0U^;m00<000000:CR
o02Th_`0302Th_`00`000000[n7h0:oQn00;0:oQn0040000002hgO80^=gb0;SMlPP000000`2^f?H0
0`000000]=Ca0;CDl@0;0;CDl@030000002icn/0^Lo[00`0^Lo[00<000000;c;i@2lbnD02`2lbnD0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01X0oooo000W0?ooo`030000003oool0oooo
0140oooo00<000000:6diP2Q]>H0302Q]>H010000000WKS[09fhj`2M^>/8000000@0VjkT00<00000
09RbjP2H/^X0302H/^X00`000000TkO`09>gl00;09>gl0030000002>_?D0S[ce00`0S[ce00@00000
08O0nP27`?X0Ql3j20000004086hn0030000001h_?`0N;cl00`0N;cl00<0000006nooP1__oh02@1_
_oh7000000`0EkWk00@0000004fkn01=^oP0CK_h2000000403V`l@030000000a/NX0<K7Z00D0<K7Z
1@00000304H001X0000000<01P000000000000003P00000300/000L000001P1EcnD8000000X0Lmce
00<0000008OTn@27i?T02@27i?T7000000/0U^;m00<000000:CRo02Th_`0302Th_`00`000000[n7h
0:oQn0080:oQn0L000002`2^f?H00`000000]=Ca0;CDl@0;0;CDl@030000002icn/0^Lo[00`0^Lo[
00<000000;c;i@2lbnD02P2lbnD00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01X0oooo
000W0?ooo`<000004@3oool00`000000XKCV0:6diP0<0:6diP030000002M^>/0WKS[00T0WKS[2000
000;09RbjP030000002C]o00TkO`00`0TkO`00<0000008jlm@2>_?D02`2>_?D00`000000Ql3j08O0
nP0908O0nPP000002`1h_?`00`000000Kkon06nooP0<06nooP040000001V`_h0I/;n06K2oPP00000
101G^O/00`000000CK_h04fkn00904fkn0`000001@0a/NX40000000304H000000000?@0000<0?@00
500000000`0I0000000000000009000000@02`000`0000000`12`n40000005G?i@0205G?i@P00000
0`1Qdo400`000000Lmce07?Lm@0<07?Lm@0400000027i?T0QnCi08OTn@P000000`27god00`000000
U^;m09KRo@0;09KRo@030000002Th_`0Y>;l00`0Y>;l00@000000:oQn02_hOP0[n7h200000030:KJ
nP030000002^f?H0[]Sf00/0[]Sf00<000000;CDl@2de?40302de?400`000000^Lo[0;W?j`0<0;W?
j`030000002lbnD0_<_U00X0_<_U00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0J0?oo
o`009`3oool00`000000oooo0?ooo`0A0?ooo`030000002Q]>H0XKCV00d0XKCV00<0000009fhj`2M
^>/0302M^>/010000000V[c`09Zll02J_?08000000<0V;;Z00<0000009>gl02C]o00302C]o000`00
0000S[ce08jlm@0;08jlm@0300000027`?X0Ql3j00d0Ql3j00@000000873o@21`od0PL?m20000003
07Rlo0030000001__oh0Kkon00`0Kkon00<0000006K2oP1V`_h02@1V`_h8000000`0CK_h00<00000
04Nll`17_?<01@17_?<?000000P0?@003@00000802T000030000000;00002`0000`000002P1Qdo40
0`000000Lmce07?Lm@0:07?Lm@L000002P27god00`000000U^;m09KRo@0<09KRo@030000002Th_`0
Y>;l00T0Y>;l1`00000:0:KJnP030000002^f?H0[]Sf00`0[]Sf00<000000;CDl@2de?40302de?40
0`000000^Lo[0;W?j`0;0;W?j`030000002lbnD0_<_U00P0_<_U1000000O0?ooo`030000003oool0
oooo01X0oooo000W0?ooo`030000003oool0oooo0180oooo00<000000:6diP2Q]>H0302Q]>H00`00
0000WKS[09fhj`0<09fhj`030000002J_?00V[c`00T0V[c`2`00000709>gl0030000002>_?D0S[ce
00`0S[ce00<0000008O0nP27`?X03027`?X00`000000PL?m0873o@090873o@L000002`1__oh00`00
0000I/;n06K2oP0=06K2oP040000001O`o`0Gl?l05o3o0P000000`1=^oP00`000000Akcc04Nll`0=
04Nll`0300000015_nl0AKo_00D0AKo_2@00000303d000030000000Y0000:@0000L0:@002`000007
05;:kP030000001Qdo40HM?a00/0HM?a00<0000007?Lm@1cg?D00P1cg?D800000080N=[k00<00000
08OOo@27god03027god00`000000U^;m09KRo@0<09KRo@040000002Th_`0Y>;l0:CRo0P000000`2L
g?d00`000000Y][j0:KJnP0;0:KJnP030000002^f?H0[]Sf00`0[]Sf00<000000;CDl@2de?402`2d
e?400`000000^Lo[0;W?j`0<0;W?j`040000002lbnD0_<_U0;c;i@L000000`2bbn`00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo01X0oooo000W0?ooob<0000000<0XKCV0000002M^>/03@2M
^>/00`000000V[c`09Zll00<09Zll0030000002F`?@0U/3d00D0U/3d2`00000;08jlm@0300000027
`?X0Ql3j00`0Ql3j00<000000873o@21`od03021`od010000000N/Kn07[6oP1ja_h8000000<0Kkon
00<0000006K2oP1V`_h03@1V`_h00`000000Gl?l05o3o00905o3o0/000002017_?<00`000000AKo_
04Fok`0=04Fok`h0000000<0BL?]0000001Bb^h03P1Bb^h00`000000HM?a067Cl@05067Cl@`00000
2P1hf_/00`000000Qmom08OOo@0;08OOo@030000002Fh_d0U^;m00H0U^;m2`00000:09cLo@030000
002Vf_X0Y][j00`0Y][j00<000000:kHmP2^f?H0302^f?H00`000000]=Ca0;CDl@0;0;CDl@030000
002icn/0^Lo[00D0^Lo[2`00000:0;;;k0030000003oool0oooo01h0oooo00<000000?ooo`3oool0
6@3oool002L0oooo00<000000?ooo`3oool04P3oool00`000000XKCV0:6diP0;0:6diTD000001`27
`?X00`000000PL?m0873o@0<0873o@030000001ja_h0N/Kn00T0N/Kn2`00000806K2oP030000001O
`o`0Gl?l00`0Gl?l00<0000005[5nP1JaOX01@1JaOXo000000L0JmCi00<0000007SJn`1hf_/02`1h
f_/00`000000Qmom08OOo@0508OOoA0000001`2Bg?h00`000000W=cm09cLo@0;09cLo@030000002V
f_X0Y][j00`0Y][j00<000000:kHmP2^f?H02`2^f?H00`000000]=Ca0;CDl@090;CDl@/000001`2^
c_000`000000//_/0;;;k00:0;;;k0030000003oool0oooo01l0oooo00<000000?ooo`3oool06@3o
ool002P0oooo00<000000?ooo`3oool04@3oool00`000000XKCV0:6diP0=0:6diP030000002M^>/0
WKS[00`0WKS[00<0000009Zll02J_?002`2J_?000`000000U/3d09K0m00<09K0m0030000002A`oP0
TL?h00T0TL?hD000000?05[5nP030000001HaoP0F<Oh00d0F<Oh00<0000005[:m`1Jb_L0301Jb_L0
0`000000HLog067?m`0=067?m`030000001[e?T0JmCi00/0JmCi00<0000007SJn`1hf_/01@1hf_/?
000000L0R=[o00<0000009;LoP2Bg?h0302Bg?h00`000000W=cm09cLo@0<09cLo@030000002Vf_X0
Y][j00/0Y][j00<000000:kHmP2^f?H0302^f?H010000000]=Ca0;CDl@2de?48000000<0ZM7e00<0
00000:k>l02^c_002`2^c_000`000000//_/0;;;k00;0;;;k0030000003oool0oooo01l0oooo00<0
00000?ooo`3oool06@3oool002P0oooo00<000000?ooo`3oool04@3oool8000000P0XKCV00<00000
09fhj`2M^>/0302M^>/00`000000V[c`09Zll00<09Zll0030000002F`?@0U/3d00/0U/3d00<00000
0973n02A`oP0302A`oP00`000000S<Kk08c6n`0508c6n`l000001`21`od00`000000N/Kn07[6oP0<
07[6oP030000001cb?l0LlSo00d0LlSo00<0000006k9oP1^bOh01@1^bOiL000000L0OMOn00<00000
08SJo`28f_l03028f_l00`000000T]cn09;LoP0<09;LoP030000002Lg?d0W=cm00`0W=cm00<00000
0:KJnP2Vf_X02`2Vf_X00`000000[]Sf0:kHmP050:kHmP/000002P2YdOD00`000000[/k`0:k>l00<
0:k>l0030000002bbn`0//_/00/0//_/00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0;
0?ooo`030?oo_`1d0000000000@0000000<0M;oo0?ooo`3oool0103oool002P0oooo00<000000?oo
o`3oool04@3oool00`000000Wl3`09o0l00509o0l10000001`2M^>/00`000000V[c`09Zll00<09Zl
l0030000002F`?@0U/3d00`0U/3d00<000000973n02A`oP02`2A`oP00`000000S<Kk08c6n`0<08c6
n`0300000027b?d0QlSm00D0QlSm3`00000807[6oP030000001cb?l0LlSo00`0LlSo00<0000006k9
oP1^bOh0301^bOh00`000000J/_m06[;o@0=06[;o@030000001Xc?d0J<cm00D0J<cm;P0000000`1e
e?d0000000000013000000@0Y][j3`0000070:CCn0030000002YdOD0ZM7e00/0ZM7e00<000000:k>
l02^c_00302^c_000`000000//_/0;;;k00;0;;;k0030000003oool0oooo01l0oooo00<000000?oo
o`3oool0303oool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo00D0oooo000Y0?ooo`03
0000003oool0oooo0100oooo00<0000009o0l02O`?003@2O`?000`000000W<?c09c3l`0509c3l`l0
00001`2J_?000`000000U/3d09K0m00<09K0m0030000002A`oP0TL?h00/0TL?h00<0000008c6n`2<
a_/0302<a_/00`000000QlSm08O8o@0<08O8o@0300000022b_h0P/[n00D0P/[n4000000707?8o`03
0000001^bOh0K/Wn00`0K/Wn00<0000006[;o@1Zbod0301Zbod00`000000J<cm06S<o@0=06S<o@03
0000001Zc_`0J/kl00`0J/kl00<0000006kAo01^dO`03@1^dO`00`000000MMCm07GDo@0;07GDo@03
0000001meoh0OMOn00`0OMOn00<0000008SJo`28f_l03028f_l00`000000T]cn09;LoP0<09;LoP03
0000002Lg?d0W=cm00D0W=cmD@00000Q0?ooo`030000003oool0oooo00d0oooo00<0okmd0000B02L
gol02@3oool002T0oooo00<000000?ooo`3oool04@3oool00`000000Wl3`09o0l00<09o0l0030000
002L`o<0W<?c00`0W<?c00<0000009W5mP2IaOH01@2IaOH?000000L0U/3d00<000000973n02A`oP0
302A`oP00`000000S<Kk08c6n`0;08c6n`0300000027b?d0QlSm00`0QlSm00<0000008;:oP22b_h0
3@22b_h00`000000OLco07g<o`0507g<oah000001`1Zbod00`000000J<cm06S<o@0<06S<o@030000
001Zc_`0J/kl00`0J/kl00<0000006kAo01^dO`03@1^dO`00`000000MMCm07GDo@0<07GDo@030000
001meoh0OMOn00`0OMOn00<0000008SJo`28f_l01@28f_lN000000L0UmKm00<0000009kEn`2NeO/0
2`2NeO/00`000000Y=?h0:CCn00<0:CCn0030000002YdOD0ZM7e00/0ZM7e00<000000:k>l02^c_00
302^c_000`000000//_/0;;;k00<0;;;k2<00000403oool00`3ogi`0B00004RLg`080?ooo`00:@3o
ool00`000000oooo0?ooo`0A0?ooo`030000002O`?00Wl3`00`0Wl3`00<0000009c3l`2L`o<0302L
`o<00`000000VLGf09W5mP0<09W5mP030000002FaoP0U/Oh00D0U/Oh3`0000070973n0030000002<
a_/0S<Kk00`0S<Kk00<0000008O8o@27b?d03027b?d00`000000P/[n08;:oP0<08;:oP030000001m
c?l0OLco00`0OLco00<0000007[=o`1jcOl0301jcOl00`000000Mlko07O>o`0507O>oe/000001`29
e_l00`000000T=Ko093Fo`0<093Fo`030000002Ge_d0UmKm00/0UmKm00<0000009kEn`2NeO/0302N
eO/00`000000Y=?h0:CCn00<0:CCn0030000002YdOD0ZM7e00/0ZM7e00<000000:k>l02^c_00302^
c_000`000000//_/0;;;k00;0;;;k0030000003oool0oooo01l0oooo00<000000?ooo`3oool0103o
ool00`2LB000000000000003000000030018W03oool0oooo00@0oooo00<0W4P004RLg`3oool01P3o
ool002T0oooo00<000000?ooo`3oool04@3oool00`000000Wl3`09o0l00<09o0l0030000002L`o<0
W<?c00`0W<?c00<0000009W5mP2IaOH0302IaOH00`000000U/Oh09K7n00<09K7n0030000002BbOX0
T/Wj00D0T/Wj3`00000708c6n`0300000027b?d0QlSm00`0QlSm00<0000008;:oP22b_h03022b_h0
0`000000OLco07g<o`0<07g<o`030000001jcOl0N/go00`0N/go00<0000007O>o`1gc_l0301gc_l0
0`000000M/oo07K?o`0<07K?o`030000001gd?l0Mm3o00`0Mm3o00<0000007WBo`1id_l03@1id_l0
0`000000OM?o07gCo`0<07gCo`0300000023e?l0PmCo00/0PmCo00<0000008WFo`29e_l03029e_l0
0`000000T=Ko093Fo`0<093Fo`030000002Ge_d0UmKm00`0UmKm00<0000009kEn`2NeO/0302NeO/0
0`000000Y=?h0:CCn00<0:CCn0030000002YdOD0ZM7e00/0ZM7e00<000000:k>l02^c_002`2^c_00
0`000000//_/0;;;k00<0;;;k0030000003oool0oooo01l0oooo00<000000?ooo`3oool04P3oool0
0`2LB7@0_ooo0?ooo`050?ooo`00:P3oool00`000000oooo0?ooo`0@0?ooo`030000002O`?00Wl3`
00d0Wl3`00<0000009c3l`2L`o<02`2L`o<00`000000VLGf09W5mP0<09W5mP030000002FaoP0U/Oh
00`0U/Oh00<0000009;9nP2BbOX0302BbOX00`000000Sl_l08o;o00508o;o1h000001`22b_h00`00
0000OLco07g<o`0<07g<o`030000001jcOl0N/go00`0N/go00<0000007O>o`1gc_l0301gc_l00`00
0000M/oo07K?o`0<07K?o`030000001gd?l0Mm3o00`0Mm3o00<0000007WBo`1id_l0301id_l00`00
0000OM?o07gCo`0<07gCo`0300000023e?l0PmCo00`0PmCo00<0000008WFo`29e_l03029e_l00`00
0000T=Ko093Fo`0<093Fo`030000002Ge_d0UmKm00`0UmKm00<0000009kEn`2NeO/0302NeO/00`00
0000Y=?h0:CCn00;0:CCn0030000002YdOD0ZM7e00/0ZM7e00<000000:k>l02^c_001@2^c_0G0000
0200oooo00<000000?ooo`3oool03P3oool00`3OW4P0M;oo0?ooo`020?ooo`030;md001d_ol0oooo
00D0oooo000Z0?ooo`030000003oool0oooo0140oooo00<0000009o0l02O`?00302O`?000`000000
W<?c09c3l`0<09c3l`030000002IaOH0VLGf00`0VLGf00<0000009K7n02FaoP02`2FaoP00`000000
T/Wj09;9nP0<09;9nP030000002?bo`0Sl_l00`0Sl_l00<0000008c<o@2<c?d0302<c?d00`000000
R<gn08S=oP0508S=oQh000001`1jcOl00`000000Mlko07O>o`0<07O>o`030000001fcol0M/oo00`0
M/oo00<0000007O@o`1gd?l0301gd?l00`000000NM;o07WBo`0<07WBo`030000001mdol0OM?o00`0
OM?o00<0000008?Do`23e?l02`23e?l00`000000RMKo08WFo`0<08WFo`030000002@e_l0T=Ko00`0
T=Ko00<0000009OFo@2Ge_d0302Ge_d00`000000W]Gk09kEn`0<09kEn`030000002TdoP0Y=?h00D0
Y=?h7@0000070:?>mP030000002Wc?<0Ylcc00`0Ylcc00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0>0?ooo`070?noM00007@0_ooo0?ooo`3o_g@0001809cOo`060?ooo`00:P3oool00`00
0000oooo0?ooo`0A0?ooo`030000002O`?00Wl3`00`0Wl3`00<0000009c3l`2L`o<0302L`o<00`00
0000VLGf09W5mP0<09W5mP030000002FaoP0U/Oh00/0U/Oh00<0000009;9nP2BbOX0302BbOX00`00
0000Sl_l08o;o00<08o;o0030000002<c?d0S<cm00`0S<cm00<0000008S=oP28cOh03028cOh00`00
0000Q/ko08K>o`0<08K>o`0300000024col0Q<oo00D0Q<ooY000000709_AnP030000002OcoP0Wloh
00/0Wloh00<000000:?>mP2Sc_H02`2Sc_H00`000000Ylcc0:O<l`0<0:O<l`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0403oool01@3o_g@000000000000004P0W=oo00L0oooo000[0?oo
o`030000003oool0oooo0100oooo5`00000709c3l`030000002IaOH0VLGf00`0VLGf00<0000009K7
n02FaoP02`2FaoP00`000000T/Wj09;9nP0<09;9nP030000002?bo`0Sl_l00`0Sl_l00<0000008c<
o@2<c?d0302<c?d00`000000R<gn08S=oP0<08S=oP0300000026c_l0Q/ko00`0Q/ko00<0000008C?
o`24col03024col00`000000Ploo08??o`0<08??o`0300000022d?l0P]3o00`0P]3o00<0000008;@
o`22d?l03022d?l00`000000Pm7o08?Ao`0<08?Ao`0300000025dOl0QM7o00`0QM7o00<0000008SB
o`28d_l02`28d_l00`000000Rm;o08_Bo`0<08_Bo`030000002?d_h0Sm;n00`0Sm;n00<0000009;B
o@2Bd_d0302Bd_d00`000000Um7l09OAo00<09OAo0030000002KdOX0Vm7j00/0Vm7j00<0000009o?
n02OcoP02`2OcoP00`000000Xlkf0:?>mP0<0:?>mP030000002Wc?<0Ylcc00`0Ylcc00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0L0?ooo`00:`3oool00`000000oooo0?ooo`0@0?ooo`03
0000002GboT0Ul_i00`0Ul_i00<0000009K;nP2FboX01@2FboX/000000L0T/Wj00<0000008o;o02?
bo`0302?bo`00`000000S<cm08c<o@0<08c<o@0300000028cOh0R<gn00`0R<gn00<0000008K>o`26
c_l03026c_l00`000000Q<oo08C?o`0<08C?o`0300000023col0Ploo00/0Ploo00<0000008;@o`22
d?l03@22d?l00`000000P]3o08;@o`0<08;@o`0300000023dOl0Pm7o00`0Pm7o00<0000008GAo`25
dOl02`25dOl00`000000R=;o08SBo`0<08SBo`030000002;d_l0Rm;o00`0Rm;o00<0000008oBoP2?
d_h0302?d_h00`000000T];m09;Bo@0;09;Bo@030000002GdO`0Um7l00`0Um7l00<0000009_AnP2K
dOX0302KdOX00`000000Wloh09o?n00;09o?n0030000002Sc_H0Xlkf00`0Xlkf00<000000:O<l`2W
c?<02`2Wc?<00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo000[0?ooo`030000
003oool0oooo0100oooo00<0000009O;n@2GboT0302GboT00`000000U/_j09K;nP0<09K;nP030000
002Dc?/0U<ck00`0U<ck00<0000009;=o02BcO`02`2BcO`00`000000TLgl097=o005097=o2d00000
1`28cOh00`000000Q/ko08K>o`0<08K>o`0300000024col0Q<oo00`0Q<oo00<0000008??o`23col0
2`23col00`000000P]3o08;@o`0<08;@o`0300000022d?l0P]3o00`0P]3o00<0000008?Ao`23dOl0
3023dOl00`000000QM7o08GAo`0<08GAo`0300000028d_l0R=;o00/0R=;o00<0000008_Bo`2;d_l0
302;d_l00`000000Sm;n08oBoP0<08oBoP030000002Bd_d0T];m00`0T];m00<0000009OAo02GdO`0
302GdO`00`000000Vm7j09_AnP0<09_AnP030000002OcoP0Wloh00/0Wloh00<000000:?>mP2Sc_H0
302Sc_H00`000000Ylcc0:O<l`0;0:O<l`030000003oool0oooo01`0oooo0`00000O0?ooo`00;03o
ool00`000000oooo0?ooo`0?0?ooo`030000002GboT0Ul_i00`0Ul_i00<0000009K;nP2FboX0302F
boX00`000000U<ck09C<n`0<09C<n`030000002BcO`0T/gl00/0T/gl00<00000097=o02AcO`0302A
cO`00`000000Slkm08o>o@0<08o>o@030000002>c_d0S/km00`0S/km00<0000008g>oP2=c_h01@2=
c_hk000000L0P]3o00<0000008;@o`22d?l03022d?l00`000000Pm7o08?Ao`0<08?Ao`0300000025
dOl0QM7o00/0QM7o00<0000008SBo`28d_l03028d_l00`000000Rm;o08_Bo`0<08_Bo`030000002?
d_h0Sm;n00`0Sm;n00<0000009;Bo@2Bd_d0302Bd_d00`000000Um7l09OAo00<09OAo0030000002K
dOX0Vm7j00`0Vm7j00<0000009o?n02OcoP02`2OcoP00`000000Xlkf0:?>mP0;0:?>mP030000002W
c?<0Ylcc00`0Ylcc00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`00;03oool0
0`000000oooo0?ooo`0@0?ooo`030000002GboT0Ul_i00`0Ul_i00<0000009K;nP2FboX02`2FboX0
0`000000U<ck09C<n`0<09C<n`030000002BcO`0T/gl00/0T/gl00<00000097=o02AcO`0302AcO`0
0`000000Slkm08o>o@0<08o>o@030000002>c_d0S/km00`0S/km00<0000008g>oP2=c_h0302=c_h0
0`000000SLon08g?oP0<08g?oP030000002<coh0S<on00`0S<on00<0000008_?oP2;coh02`2;coh0
0`000000Rlon08_?oP0508_?oUT000001`2?d_h00`000000T];m09;Bo@0;09;Bo@030000002GdO`0
Um7l00`0Um7l00<0000009_AnP2KdOX0302KdOX00`000000Wloh09o?n00;09o?n0030000002Sc_H0
Xlkf00`0Xlkf00<000000:O<l`2Wc?<02`2Wc?<00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo01l0oooo000/0?ooo`030000003oool0oooo0100oooo00<0000009O;n@2GboT0302GboT00`00
0000U/_j09K;nP0<09K;nP030000002Dc?/0U<ck00`0U<ck00<0000009;=o02BcO`02`2BcO`00`00
0000TLgl097=o00<097=o0030000002?c_d0Slkm00`0Slkm00<0000008k>o@2>c_d02`2>c_d00`00
0000SLkn08g>oP0<08g>oP030000002=coh0SLon00`0SLon00<0000008c?oP2<coh0302<coh00`00
0000Rlon08_?oP0;08_?oP030000002;coh0Rlon00`0Rlon00<0000008_@oP2;d?h0302;d?h00`00
0000S=3n08c@oP0<08c@oP030000002<d?h0S=3n00/0S=3n00<0000008g@oP2=d?h0302=d?h00`00
0000S]3n08k@oP0<08k@oP030000002?d?h0Sm3n00D0Sm3nG`00000O0?ooo`030000003oool0oooo
01l0oooo000]0?ooo`030000003oool0oooo00l0oooo5`00000709K;nP030000002Dc?/0U<ck00`0
U<ck00<0000009;=o02BcO`02`2BcO`00`000000TLgl097=o00<097=o0030000002?c_d0Slkm00`0
Slkm00<0000008k>o@2>c_d02`2>c_d00`000000SLkn08g>oP0<08g>oP030000002=coh0SLon00`0
SLon00<0000008c?oP2<coh02`2<coh00`000000Rlon08_?oP0<08_?oP030000002;coh0Rlon00`0
Rlon00<0000008_@oP2;d?h0302;d?h00`000000S=3n08c@oP0<08c@oP030000002<d?h0S=3n00/0
S=3n00<0000008g@oP2=d?h0302=d?h00`000000S]3n08k@oP0;08k@oP030000002?d?h0Sm3n00d0
Sm3n00<00000093@o@2@d?d02`2@d?d00`000000TLom097?o@0<097?o@030000002Cco`0Tlol00/0
Tlol00<0000009G?o02Eco`0302Eco`00`000000Ulkk09O>n`0;09O>n`030000002Hc_X0V<kj00`0
V<kj00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0P0?ooo`00;@3oool00`000000oooo
0?ooo`0?0?ooo`0300000022d?l0P]3o00`0P]3o00<0000008G@o`25d?l01@25d?m9000000L0S/km
00<0000008g>oP2=c_h0302=c_h00`000000SLon08g?oP0<08g?oP030000002<coh0S<on00/0S<on
00<0000008_?oP2;coh0302;coh00`000000Rlon08_?oP0<08_?oP030000002;d?h0Rm3n00/0Rm3n
00<0000008c@oP2<d?h0302<d?h00`000000S=3n08c@oP0;08c@oP030000002=d?h0SM3n00`0SM3n
00<0000008k@oP2>d?h0302>d?h00`000000Sm3n08o@oP0<08o@oP030000002@d?d0T=3m00/0T=3m
00<00000097?o@2Acod0302Acod00`000000Tlol09??o00<09??o0030000002Eco`0ULol00/0ULol
00<0000009O>n`2Gc_/0302Gc_/00`000000V<kj09S>nP0;09S>nP030000003oool0oooo01d0oooo
00<000000?ooo`3oool0803oool002d0oooo00<000000?ooo`3oool0403oool00`000000P]3o08;@
o`0;08;@o`0300000025d?l0QM3o00`0QM3o00<0000008S@o`28d?l03028d?l00`000000R]3n08[@
oP0;08[@oP030000002<coh0S<on00`0S<on00<0000008k?oP2>coh0302>coh00`000000Slom08o?
o@0408o?oDX000001`2;coh00`000000Rm3n08_@oP0;08_@oP030000002<d?h0S=3n00`0S=3n00<0
000008c@oP2<d?h02`2<d?h00`000000SM3n08g@oP0<08g@oP030000002>d?h0S]3n00`0S]3n00<0
000008o@oP2?d?h0302?d?h00`000000T=3m093@o@0;093@o@030000002Acod0TLom00`0TLom00<0
000009??o02Cco`02`2Cco`00`000000ULol09G?o00<09G?o0030000002Gc_/0Ulkk00/0Ulkk00<0
000009S>nP2Hc_X0302Hc_X00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0240oooo000^
0?ooo`030000003oool0oooo00l0oooo00<0000008;@o`22d?l03022d?l00`000000QM3o08G@o`0;
08G@o`0300000028d?l0R=3o00`0R=3o00<0000008[@oP2:d?h02`2:d?h00`000000S<on08c?oP0<
08c?oP030000002>coh0S/on00`0S/on00<0000008o?o@2?cod02`2?cod00`000000T<km093>o@0<
093>o@030000002Ac_d0TLkm00`0TLkm00<0000009;>o02Bc_`02`2Bc_`00`000000T/kl09;>o00<
09;>o0030000002Cc_`0Tlkl00D0TlklB000000708k@oP030000002?d?h0Sm3n00`0Sm3n00<00000
093@o@2@d?d02`2@d?d00`000000TLom097?o@0<097?o@030000002Cco`0Tlol00`0Tlol00<00000
09G?o02Eco`0302Eco`00`000000Ulkk09O>n`0;09O>n`030000002Hc_X0V<kj00`0V<kj00<00000
0?ooo`3oool06P3oool3000002<0oooo000^0?ooo`030000003oool0oooo0100oooo1`00000708;@
o`0300000025d?l0QM3o00`0QM3o00<0000008S@o`28d?l02`28d?l00`000000R]3n08[@oP0<08[@
oP030000002<coh0S<on00`0S<on00<0000008k?oP2>coh02`2>coh00`000000Slom08o?o@0;08o?
o@030000002@c_d0T<km00`0T<km00<00000097>o@2Ac_d0302Ac_d00`000000T/kl09;>o00;09;>
o0030000002Bc_`0T/kl00`0T/kl00<0000009?>o02Cc_`0302Cc_`00`000000Tlkl09?>o00;09?>
o0030000002Cc_`0Tlkl00`0Tlkl00<0000009;>o02Bc_`02`2Bc_`00`000000T/kl09;>o00<09;>
o0030000002Ac_d0TLkm00@0TLkm>P00000709??o0030000002Eco`0ULol00`0ULol00<0000009O>
n`2Gc_/02`2Gc_/00`000000V<kj09S>nP0<09S>nP030000003oool0oooo01`0oooo00<000000?oo
o`3oool08P3oool002h0oooo00<000000?ooo`3oool0403oool00`000000D/Ge05;5m@0405;5mAd0
00001`28d?l00`000000R]3n08[@oP0<08[@oP030000002<coh0S<on00`0S<on00<0000008k?oP2>
coh02`2>coh00`000000Slom08o?o@0<08o?o@030000002@c_d0T<km00/0T<km00<00000097>o@2A
c_d0302Ac_d00`000000T/kl09;>o00;09;>o0030000002Bc_`0T/kl00`0T/kl00<0000009?>o02C
c_`0302Cc_`00`000000Tlkl09?>o00;09?>o0030000002Cc_`0Tlkl00`0Tlkl00<0000009;>o02B
c_`02`2Bc_`00`000000T/kl09;>o00<09;>o0030000002Ac_d0TLkm00/0TLkm00<00000093>o@2@
c_d0302@c_d00`000000Slom08o?o@0;08o?o@030000002>coh0S/on00`0S/on00<0000008c?oP2<
coh0102<cohd000001d0oooo00<000000?ooo`3oool08`3oool002h0oooo00<000000?ooo`3oool0
4@3oool00`000000D/Ge05;5m@0;05;5m@030000001Tbo/0I<_k00/0I<_k00<00000077>oP1ac_h0
101ac_h/000000L0S/on00<0000008o?o@2?cod0302?cod00`000000T<km093>o@0;093>o@030000
002Ac_d0TLkm00`0TLkm00<0000009;>o02Bc_`02`2Bc_`00`000000T/kl09;>o00<09;>o0030000
002Cc_`0Tlkl00/0Tlkl00<0000009?>o02Cc_`02`2Cc_`00`000000Tlkl09?>o00<09?>o0030000
002Bc_`0T/kl00/0T/kl00<0000009;>o02Bc_`0302Bc_`00`000000TLkm097>o@0<097>o@030000
002@c_d0T<km00/0T<km00<0000008o?o@2?cod0302?cod00`000000S/on08k?oP0;08k?oP030000
002<coh0S<on00/0S<on00<0000008[@oP2:d?h0302:d?h00`000000R=3o08S@o`0;08S@o`030000
0025d?l0QM3o00`0QM3o00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0S0?ooo`00;`3o
ool00`000000oooo0?ooo`0@0?ooo`P000001P1BaOD00`000000I<_k06C;n`0;06C;n`030000001a
c_h0LLkn00/0LLkn00<0000007c?o`1lcol0301lcol00`000000Q<oo08C?o`0<08C?o`030000002:
coh0R/on00@0R/on;0000007097>o@030000002Bc_`0T/kl00/0T/kl00<0000009;>o02Bc_`0302B
c_`00`000000Tlkl09?>o00;09?>o0030000002Cc_`0Tlkl00/0Tlkl00<0000009?>o02Cc_`0302C
c_`00`000000T/kl09;>o00;09;>o0030000002Bc_`0T/kl00`0T/kl00<00000097>o@2Ac_d02`2A
c_d00`000000T<km093>o@0<093>o@030000002?cod0Slom00/0Slom00<0000008k?oP2>coh0302>
coh00`000000S<on08c?oP0;08c?oP030000002:d?h0R]3n00`0R]3n00<0000008S@o`28d?l02`28
d?l00`000000QM3o08G@o`0;08G@o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0903o
ool002l0oooo00<000000?ooo`3oool05P3oool@000000L0I<_k00<00000077>oP1ac_h02P1ac_h0
0`000000O<oo07c?o`0<07c?o`0300000024col0Q<oo00`0Q<oo00<0000008[?oP2:coh02`2:coh0
0`000000S/km08k>o@0<08k>o@030000002BcO`0T/gl00/0T/gl00<0000009C=n`2DcO/01@2DcO]8
000000L0Tlkl00<0000009;>o02Bc_`02`2Bc_`00`000000T/kl09;>o00<09;>o0030000002Ac_d0
TLkm00/0TLkm00<00000093>o@2@c_d02`2@c_d00`000000Slom08o?o@0<08o?o@030000002>coh0
S/on00/0S/on00<0000008c?oP2<coh02`2<coh00`000000R]3n08[@oP0<08[@oP0300000028d?l0
R=3o00/0R=3o00<0000008G@o`25d?l03025d?l00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo02@0oooo000_0?ooo`030000003oool0oooo01d0oooo1`00000202Z_hPh000001`1ac_h00`00
0000O<oo07c?o`0<07c?o`0300000024col0Q<oo00/0Q<oo00<0000008[?oP2:coh02`2:coh00`00
0000S/km08k>o@0<08k>o@030000002BcO`0T/gl00/0T/gl00<0000009C=n`2DcO/0302DcO/00`00
0000Ulcj09O<nP0;09O<nP030000002Hc?X0V<cj00`0V<cj00<0000009W<n@2Ic?T02`2Ic?T00`00
0000VLci09W<n@0;09W<n@030000002Ic?T0VLci00D0VLciU`00000N0?ooo`030000003oool0oooo
02D0oooo000`0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool700000080
:ZoR00<0000004c0m01<`?@0101<`?@M000000L0Q<oo00<0000008[?oP2:coh0302:coh00`000000
S/km08k>o@0;08k>o@030000002BcO`0T/gl00/0T/gl00<0000009C=n`2DcO/0302DcO/00`000000
Ulcj09O<nP0;09O<nP030000002Hc?X0V<cj00`0V<cj00<0000009W<n@2Ic?T02`2Ic?T00`000000
VLci09W<n@0;09W<n@030000002Ic?T0VLci00`0VLci00<0000009S<nP2Hc?X02`2Hc?X00`000000
Ulgj09O=nP0<09O=nP030000002Fc_/0U/kk00/0U/kk00<0000009??o02Cco`02`2Cco`00`000000
T=3m093@o@0<093@o@030000002<d?h0S=3n00/0S=3n00<0000008KAo`26dOl02P26dOl00`000000
O]7o07kAo`0<07kAo`030000001edOh0MM7n00/0MM7n00<0000006O>n`1Wc_/02`1Wc_/00`000000
oooo0?ooo`0K0?ooo`<000009`3oool00300oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`070?ooo`T000002@1<`?@00`000000ILSm06G8o@0<06G8o@030000001gc?l0Mlco00@0Mlco
3`00000708[?oP030000002>c_d0S/km00/0S/km00<0000009;=o02BcO`02`2BcO`00`000000U<gk
09C=n`0<09C=n`030000002Gc?X0Ulcj00/0Ulcj00<0000009S<nP2Hc?X02`2Hc?X00`000000VLci
09W<n@0;09W<n@030000002Ic?T0VLci00`0VLci00<0000009W<n@2Ic?T0302Ic?T00`000000V<cj
09S<nP0;09S<nP030000002GcOX0Ulgj00/0Ulgj00<0000009K>n`2Fc_/0302Fc_/00`000000Tlol
09??o00;09??o0030000002@d?d0T=3m00/0T=3m00<0000008c@oP2<d?h02`2<d?h00`000000Q]7o
08KAo`0;08KAo`030000001ndOl0O]7o00/0O]7o00<0000007GAoP1edOh0301edOh00`000000Ilkk
06O>n`0;06O>n`030000003oool0oooo01`0oooo00<000000?ooo`3oool09P3oool00300oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0<0?ooo`/000000`1<`?@00`000000ILSm06G8
o@0;06G8o@030000001gc?l0Mlco00/0Mlco00<0000008?<o`23c?l01@23c?lL000000L0T/gl00<0
000009C=n`2DcO/0302DcO/00`000000Ulcj09O<nP0;09O<nP030000002Hc?X0V<cj00/0V<cj00<0
000009W<n@2Ic?T02`2Ic?T00`000000VLci09W<n@0<09W<n@030000002Ic?T0VLci00/0VLci00<0
000009S<nP2Hc?X02`2Hc?X00`000000Ulgj09O=nP0<09O=nP030000002Fc_/0U/kk00/0U/kk00<0
000009??o02Cco`02`2Cco`00`000000T=3m093@o@0<093@o@030000002<d?h0S=3n00/0S=3n00<0
000008KAo`26dOl02P26dOl00`000000O]7o07kAo`0<07kAo`030000001edOh0MM7n00@0MM7n5P00
000O0?ooo`030000003oool0oooo02H0oooo000a0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool04@3oool4000000805Z3I2`00000706G8o@030000001gc?l0Mlco00X0Mlco00<00000
08?<o`23c?l03023c?l00`000000S<cm08c<o@0;08c<o@030000002Bbo/0T/_k00@0T/_k7@000007
09O<nP030000002Hc?X0V<cj00/0V<cj00<0000009W<n@2Ic?T02`2Ic?T00`000000VLci09W<n@0<
09W<n@030000002Ic?T0VLci00/0VLci00<0000009S<nP2Hc?X02`2Hc?X00`000000Ulgj09O=nP0;
09O=nP030000002Fc_/0U/kk00`0U/kk00<0000009??o02Cco`02`2Cco`00`000000T=3m093@o@0;
093@o@030000002<d?h0S=3n00/0S=3n00<0000008KAo`26dOl01@26dOlL000000D0Flgc0P000000
0`0k_^00000000000005000002D0oooo00<000000?ooo`3oool09`3oool00340oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0C0?ooo`H0000000<05Z3I00000013^O<01P13^O<;0000
00X0Mlco00<0000008?<o`23c?l02`23c?l00`000000S<cm08c<o@0;08c<o@030000002Bbo/0T/_k
00/0T/_k00<0000009K:n@2Fb_T0302Fb_T00`000000V/Wh09[9n00409[9n4L000001`2Hc?X00`00
0000Ulgj09O=nP0509O=nTL000001@21eOl00`000000LM?l077Co00;077Co0030000001KcO<0Flgc
00@0Flgc2P00000[0?ooo`030000003oool0oooo02P0oooo000a0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool05P3oool8000000/0@kWc00@0000006C4o@1Ta?d0I<Cm1`00000307O<
o`0300000023c?l0Plco00/0Plco00<0000008c<o@2<c?d02`2<c?d00`000000T/_k09;;n`0;09;;
n`030000002Fb_T0U/[i00`0U/[i00<0000009[9n02JbOP02`2JbOP00`000000W<Wg09c9m`0;09c9
m`030000002MbOH0WLWf00/0WLWf00<0000009k9mP2NbOH0302NbOH00`000000W/[f09k:mP0;09k:
mP030000002NboL0W/_g00@0W/_g3`00000609g<n0030000002Kc_X0Vlkj00`0Vlkj00<0000009O@
n`2Gd?/02`2Gd?/00`000000T];m09;Bo@0:09;Bo@030000002<e?l0S=Co00/0S=Co00<00000087E
o`21eOl02`21eOl00`000000LM?l077Co004077Co0h00000=@3oool00`000000oooo0?ooo`0X0?oo
o`00<P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01T0oooo0`00000201NMg`@0
00001`13^O<00`000000I<Cm06C4o@0806C4o@X000001`23c?l00`000000S<cm08c<o@0;08c<o@03
0000002Bbo/0T/_k00/0T/_k00<0000009K:n@2Fb_T02`2Fb_T00`000000V/Wh09[9n00<09[9n003
0000002LbOL0W<Wg00/0W<Wg00<0000009g9mP2MbOH02`2MbOH00`000000W/Wf09k9mP0<09k9mP03
0000002Nb_H0W/[f00/0W/[f00<0000009k;m`2NboL02`2NboL00`000000WLch09g<n00;09g<n003
0000002Kc_X0Vlkj00/0Vlkj00<0000009O@n`2Gd?/02`2Gd?/00`000000T];m09;Bo@0;09;Bo@03
0000002<e?l0S=Co00/0S=Co00<00000087Eo`21eOl01021eOl>00000003067Bl@000000000000@0
00001@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool4000000<05igO1@00000204>il`030000
001Ta?d0I<Cm00/0I<Cm00<0000007W8o`1ib?l0101ib?l>000000L0S<cm00<0000009;;n`2Bbo/0
2`2Bbo/00`000000U/[i09K:n@0;09K:n@030000002JbOP0V/Wh00`0V/Wh00<0000009c9m`2LbOL0
2`2LbOL00`000000WLWf09g9mP0;09g9mP030000002NbOH0W/Wf00`0W/Wf00<0000009k:mP2Nb_H0
2`2Nb_H00`000000W/_g09k;m`0;09k;m`030000002Mc?P0WLch00X0WLch00<0000009_>nP2Kc_X0
302Kc_X00`000000Um3k09O@n`0;09O@n`030000002Bd_d0T];m00X0T];m00<0000008cDo`2<e?l0
1@2<e?l>000000D0O=[m00<00000067Bl@1Qd_401`00000;0?ooo`030000003oool0oooo0340oooo
0`00000[0?ooo`00<P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01l0oooo1000
000401NMg`H000002P1Ta?d00`000000NLSo07W8o`0;07W8o`0300000027b?d0QlSm00@0QlSm3P00
000709;;n`030000002Fb_T0U/[i00/0U/[i00<0000009[9n02JbOP0302JbOP00`000000W<Wg09c9
m`0;09c9m`030000002MbOH0WLWf00/0WLWf00<0000009k9mP2NbOH02`2NbOH00`000000W/[f09k:
mP0;09k:mP030000002NboL0W/_g00/0W/_g00<0000009g<n02Mc?P02`2Mc?P00`000000Vlkj09_>
nP0<09_>nP030000002Gd?/0Um3k00X0Um3k00<0000009;Bo@2Bd_d01@2Bd_d>000000H0SMWo00<0
000007cJo@1lf_d01`1lf_d900000100oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`0Z0?ooo`00<`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0240oooo1`000000
0`0GWMl0000004Zgn00204Zgn0L000000`1Ta?d00`000000NLSo07W8o`0;07W8o`0300000027b?d0
QlSm00/0QlSm00<000000978nP2Ab?X0102Ab?XM000000L0V/Wh00<0000009c9m`2LbOL02`2LbOL0
0`000000WLWf09g9mP0;09g9mP030000002NbOH0W/Wf00/0W/Wf00<0000009k:mP2Nb_H02`2Nb_H0
0`000000W/_g09k;m`0;09k;m`030000002Mc?P0WLch00/0WLch00<0000009_>nP2Kc_X02`2Kc_X0
0`000000Um3k09O@n`0509O@n`h000001P2Ge_d00`000000SMWo08gIo`0:08gIo`030000001lf_d0
O=[m00@0O=[m100000000`1gg_H0000000000003000001<0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0Z0?ooo`00<`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
02<0oooo100000000`00MKl0000000000002000000P0B[Oh1`00000:07W8o`0300000027b?d0QlSm
00/0QlSm00<000000978nP2Ab?X02`2Ab?X00`000000UlOh09O7n00;09O7n0030000002La_D0W<Ke
00D0W<Ke7000000709g9mP030000002NbOH0W/Wf00/0W/Wf00<0000009k:mP2Nb_H02`2Nb_H00`00
0000W/_g09k;m`0;09k;m`030000002Mc?P0WLch00D0WLch7000000609gBn`030000002Ge_d0UmKm
00X0UmKm00<0000008gIo`2=fOl02`2=fOl00`000000O=[m07cJo@0400000080Mmkf1000000G0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool0:`3oool003<0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0U0?ooo`H0000000<0:J;^0000000000000P00000704Zgn004
0000001/`?h0K<3n06c0oPL000000`1ib?l00`000000QlSm08O8o@0;08O8o@030000002Ab?X0TLSj
00/0TLSj00<0000009O7n02GaoP02`2GaoP00`000000W<Ke09c6m@0<09c6m@030000002Oa_@0WlKd
00/0WlKd00<000000:76l`2Qa_<0102Qa_<i000000H0X/cf00<000000:3?n02PcoP02`2PcoP00`00
0000WM;k09gBn`0;09gBn`030000002Ge_d0UmKm00X0UmKm00<0000008gIo`2=fOl01@2=fOl90000
0080Mmkf1P00000I0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool00`3o
ScD000000000000300000003001d_`3oool0oooo01P0oooo000c0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool09`3oool20000000405<0000000000000000000<0:J;^0`00000404Zg
n0030000001/`?h0K<3n00P0K<3n2P00000708O8o@030000002Ab?X0TLSj00/0TLSj00<0000009O7
n02GaoP02`2GaoP00`000000W<Ke09c6m@0<09c6m@030000002Oa_@0WlKd00/0WlKd00<000000:76
l`2Qa_<02`2Qa_<00`000000XlOb0:?7lP0;0:?7lP030000002Sb?<0XlSc00/0XlSc00<000000:?:
m02Sb_@02`2Sb_@00`000000X/cf0:;<mP0;0:;<mP030000002PcoP0X<oh00/0X<oh00<0000009gB
n`2Md_/02P2Md_/00`000000UmKm09OFo@0809OFo@/000001@2@h?h00`000000Mmkf000000060000
01`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0>0?ooo`0305lD501Oa?l0oooo
01/0oooo000d0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0:@3oool300000004
0065g00000000000000000<0:J;^100000000`1:]oP0000006c0oP0;06c0oP0300000021`od0PL?m
00@0PL?m2`00000:0978nP030000002GaoP0UlOh00/0UlOh00<0000009c6m@2La_D0302La_D00`00
0000WlKd09o6m00;09o6m0030000002Qa_<0XLKc00/0XLKc00<000000:?7lP2Sao802`2Sao800`00
0000XlSc0:?8l`0;0:?8l`030000002Sb_@0Xl[d00/0Xl[d00<000000:;<mP2Rc?H02P2Rc?H00`00
0000X<oh0:3?n00;0:3?n0030000002Md_/0WM;k00/0WM;k00@0000009OFo@2Ge_d0UmKm1`000002
09cLo@030000002@h?h0T>3n00P0T>3n2@00000O0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool03`3oool00`1O51@0GlCo0?ooo`0K0?ooo`00=03oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo02/0oooo0`0000020065g08000001@0YX^h4000000X0K<3n00<000000873
o@21`od02`21`od010000000S/?i08k3n@2>`oT7000000<0TLSj00<0000009O7n02GaoP02`2GaoP0
0`000000W<Ke09c6m@0;09c6m@030000002Oa_@0WlKd00/0WlKd00<000000:76l`2Qa_<0302Qa_<0
0`000000XlOb0:?7lP0;0:?7lP030000002Sb?<0XlSc00/0XlSc00<000000:?:m02Sb_@02P2Sb_@0
0`000000X/cf0:;<mP0;0:;<mP030000002PcoP0X<oh00/0X<oh00<0000009gBn`2Md_/01@2Md_/:
000000T0W=cm00<00000093PoP2@h?h0102@h?h40000000309?XnP0000000000008000008`3oool0
0`000000oooo0?ooo`0[0?ooo`@000004@3oool00`1O51@0GlCo0?ooo`0K0?ooo`00=03oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo02`0oooo100000020065g0<000000`0YX^h00`00
0000F[Kl05Zfo004000000L0K<3n00<000000873o@21`od02P21`od00`000000S/?i08k3n@0808k3
n@X000001`2GaoP00`000000W<Ke09c6m@0;09c6m@030000002Oa_@0WlKd00/0WlKd00<000000:76
l`2Qa_<02`2Qa_<00`000000XlOb0:?7lP0;0:?7lP030000002Sb?<0XlSc00/0XlSc00<000000:?:
m02Sb_@02`2Sb_@00`000000X/cf0:;<mP0;0:;<mP030000002PcoP0X<oh00D0X<oh3P0000060:?F
nP030000002Lg?d0W=cm00T0W=cm00<00000093PoP2@h?h01@00000309?XnP@000009@3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo00@0oooo00<0Ga@00000000000000`0000000`00
55l0oooo0?ooo`030?ooo`0305lD501Oa?l0oooo01/0oooo000e0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0;@3oool5000000<00HGL0`0000000`0YX^h0000005Zfo00405Zfo0D0
00000P1/`?h00`000000PL?m0873o@0:0873o@030000002>`oT0S/?i00/0S/?i00<0000009O3mP2G
`oH0102G`oH>000000L0W<Ke00<0000009o6m02Oa_@02`2Oa_@00`000000XLKc0:76l`0;0:76l`03
0000002Sao80XlOb00/0XlOb00<000000:?8l`2Sb?<02`2Sb?<00`000000Xl[d0:?:m00;0:?:m003
0000002Rc?H0X/cf00D0X/cf3P0000060:KAmP030000002Se_X0XmKj00X0XmKj00<0000009cLo@2L
g?d0202Lg?d5000000H0TnSj1000000W0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0403oool00`1O51@0GlCo0?ooo`0K0?ooo`00=@3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo02l0oooo00<00000000hX`0000000`0000040065g0<000002@1J]_`6000000X0PL?m
00<0000008k3n@2>`oT02P2>`oT00`000000Ul?f09O3mP0;09O3mP030000002M`o<0WL?c00@0WL?c
700000070:76l`030000002Sao80XlOb00/0XlOb00<000000:?8l`2Sb?<02`2Sb?<00`000000Xl[d
0:?:m0050:?:m0h000001P2Xc?<00`000000Y]7f0:KAmP0;0:KAmP030000002Se_X0XmKj00X0XmKj
00<0000009cLo@2Lg?d0102Lg?d400000080Y>;l00<0000009?XnP2Cj?X00`2Cj?X5000002T0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0A0?ooo`0305lD501Oa?l0oooo01/0oooo
000e0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0<03oool200000003000hX`00
00000673008000000`01QM`00`000000AJOg00000002000000P0F[Kl00@0000007Rlo01h_?`0N;cl
1`0000030873o@030000002>`oT0S/?i00X0S/?i00<0000009O3mP2G`oH02`2G`oH00`000000WL?c
09g3l`0;09g3l`030000002Q`o40XL?a00/0XL?a00<000000:C3k`2T`nl0102T`nl[000000H0Z<Wa
00<000000:S<l`2Xc?<02`2Xc?<00`000000Y]7f0:KAmP0:0:KAmP030000002Se_X0XmKj00X0XmKj
00<0000009cLo@2Lg?d01@0000050:CRo0040000002Cj?X0TnSj09?XnP<0000000@0V>oc00000000
00000000:P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00h0oooo00D0a5lD0000
000055l0Ga@D05o4o`0L0?ooo`00=P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
0380oooo00D00000000hX`0000000000001Q``02000000030065g0000000AJOg00<0AJOg10000004
05Zfo0030000001h_?`0N;cl00P0N;cl1`00000908k3n@030000002G`oH0Ul?f00/0Ul?f00<00000
09g3l`2M`o<02`2M`o<00`000000XL?a0:73l@0;0:73l@030000002T`nl0Y<?_00/0Y<?_00<00000
0:K4k`2Va>l02`2Va>l00`000000YlK_0:O6k`0;0:O6k`030000002XbO40Z<Wa00/0Z<Wa00<00000
0:S<l`2Xc?<02`2Xc?<00`000000Y]7f0:KAmP0:0:KAmP030000002Se_X0XmKj00L0XmKj1P00000:
0:CRo0040000002Cj?X0000000000080V>oc0`00000/0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool04@3oool00`34Ga@0000D05o4o`0L0?ooo`00=P3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo03<0oooo00@00000000hX`00>:<000000P00HL<3000000L0AJOg0`00
00000`1J]_`0000007Rlo00<07Rlo0040000002:__P0R[kh08Znn0H000000`2>`oT00`000000Ul?f
09O3mP0;09O3mP030000002M`o<0WL?c00/0WL?c00<000000:73l@2Q`o402`2Q`o400`000000Y<?_
0:C3k`0;0:C3k`030000002Va>l0Y/C_00/0Y/C_00<000000:O6k`2Wa^l02`2Wa^l00`000000Z<Wa
0:S9l@0;0:S9l@030000002Xc?<0Z<cc00X0Z<cc00<000000:KAmP2VdOH02`2VdOH010000000XmKj
0:?FnP2Se_X6000000<0Zm[h00<000000:CRo02Th_`0202Th_`400000080V>oc1000000]0?ooo`03
0000003oool0oooo02T0oooo0P00000c0?ooo`00=P3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo03@0oooo0P0000001P00>:<0000000000000HL<0000002^Ck`8000002015YoL30000
00`0N;cl00<0000008Znn02:__P01`2:__P7000000X0Ul?f00<0000009g3l`2M`o<02`2M`o<00`00
0000XL?a0:73l@0;0:73l@030000002T`nl0Y<?_00/0Y<?_00<000000:K4k`2Va>l02`2Va>l00`00
0000YlK_0:O6k`0;0:O6k`030000002XbO40Z<Wa00X0Z<Wa00<000000:S<l`2Xc?<02`2Xc?<00`00
0000Y]7f0:KAmP080:KAmPL00000202[f_P00`000000Y>;l0:CRo0050:CRo0@0000000@0[>[i0000
002Hko<0V>oc1000000_0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0<@3oool0
03L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0e0?ooo`8000000P00>:<30000
0080:i?_0P00000704FWm`030000001]/oX0000000<00000201h_?`00`000000R[kh08Znn00:08Zn
n0040000002E__<0UKkc09Fnl`L000000`2G`oH00`000000WL?c09g3l`0;09g3l`030000002Q`o40
XL?a00/0XL?a00<000000:C3k`2T`nl02`2T`nl00`000000Y/C_0:K4k`0;0:K4k`030000002Wa^l0
YlK_00X0YlK_00<000000:S9l@2XbO402`2XbO400`000000Z<cc0:S<l`0;0:S<l`040000002VdOH0
Y]7f0:KAmPL000000`2]do@00`000000Zm[h0:_Jn0090:_Jn0030000002Th_`0Y>;l00D000001@2/
j_T600000300oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0b0?ooo`00=`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03H0oooo0P000003000hX`030000000[Tnl0
:i?_0080:i?_0`00000404FWm`030000001]/oX0KK?j00<0KK?j0`00000507Rlo0030000002:__P0
R[kh00X0R[kh00<0000009Fnl`2E__<0202E__<:000000L0WL?c00<000000:73l@2Q`o402`2Q`o40
0`000000Y<?_0:C3k`0;0:C3k`030000002Va>l0Y/C_00/0Y/C_00<000000:O6k`2Wa^l02P2Wa^l0
0`000000Z<Wa0:S9l@0;0:S9l@030000002Xc?<0Z<cc00D0Z<cc2P00000:0:gCm0030000002[f_P0
Zm[h00P0Zm[h100000080:cZn@<0000000<0Vo?V000000000000<P3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0380oooo000g0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0=P3oool01@000000VQ<000000000000003RS00<000001@0[Tnl2000000<0AJOg00<00000
06fcnP1]/oX01@1]/oX40000000307Rlo0000000R[kh00/0R[kh00<0000009Fnl`2E__<02`2E__<0
0`000000WKk`09fnl00409fnl0h000001`2Q`o400`000000Y<?_0:C3k`0;0:C3k`030000002Va>l0
Y/C_00/0Y/C_00<000000:O6k`2Wa^l02P2Wa^l00`000000Z<Wa0:S9l@050:S9l@h000001P2^cO00
0`000000[M?d0:gCm00:0:gCm0030000002[f_P0Zm[h00H0Zm[h0`0000000`2bgoH000000:cZn@07
0:cZn@<0000000@0Vo?V0000000000000000<`3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo03<0oooo000g0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0=`3oool0
0`000000VQ<000000002000000803W_S0P00000502^Ck`80000000<0AJOg0000001]/oX02P1]/oX4
000000X0R[kh00<0000009Fnl`2E__<02`2E__<00`000000WKk`09fnl00;09fnl0030000002R_nd0
X[o]00@0X[o]>00000060:g8kP030000002^cO00[/g`00/0[/g`00<000000:gCm02]do@02P2]do@0
0`000000Zm[h0:_Jn0020:_Jn0@00000102bgoH00`000000[>[i0:cZn@030:cZn@<000000P2dlOD4
000003@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0c0?ooo`00>03oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo03P0oooo00@0000009XC000000000000100>Nn<2
000000D0:i?_0`00000;06fcnP0300000025]oH0QKOf00@000001P2:__P00`000000UKkc09Fnl`0;
09Fnl`030000002M__00WKk`00/0WKk`00<000000::ok@2R_nd02`2R_nd00`000000Y/3/0:K0k00;
0:K0k0030000002Y`^`0ZL;/00/0ZL;/00<000000:c5k02/aN`02P2/aN`00`000000[LS^0:g8kP0;
0:g8kP030000002^cO00[/g`00X0[/g`00<000000:gCm02]do@02`2]do@00`000000Zm[h00000002
000000L0/]of00@000000:cZn@2/j_T0[>[i0`0000030;Cam@80000000<0WOCC000000000000=@3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo03@0oooo000h0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0>@3oool00`000000VQ<000000002000000@03W_S0P000004
02^Ck`030000001PZ?L0000000800000201]/oX00`000000QKOf08FgmP0408FgmP@000000P2:__P0
0`000000UKkc09Fnl`0;09Fnl`030000002M__00WKk`00/0WKk`00<000000::ok@2R_nd02`2R_nd0
0`000000Y/3/0:K0k00;0:K0k0030000002Y`^`0ZL;/00/0ZL;/00<000000:c5k02/aN`02P2/aN`0
0`000000[LS^0:g8kP0;0:g8kP030000002^cO00[/g`00X0[/g`00<000000:gCm02]do@0202]do@5
000000X0/]of00@000000:cZn@0000000000102dlOD6000003L0oooo00<000000?ooo`3oool0903o
ool3000003H0oooo000h0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0>@3oool2
0000000409XC0000000005oC000000D03W_S0P00000202^Ck`030000001PZ?L0H:Sg0080H:Sg1000
000406fcnP0300000025]oH0QKOf00P0QKOf1P00000:09Fnl`030000002M__00WKk`00/0WKk`00<0
00000::ok@2R_nd02`2R_nd00`000000Y/3/0:K0k00;0:K0k0030000002Y`^`0ZL;/00/0ZL;/00<0
00000:c5k02/aN`02P2/aN`00`000000[LS^0:g8kP0:0:g8kP030000002^cO00[/g`00/0[/g`00@0
00000:gCm02]do@0[M?d1`0000030;CFl@030000002bgoH0/]of00P0/]of0`0000040;Cam@800000
0P2mn>h00`000000W>nj0000000h0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
=@3oool003T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0j0?ooo`050000002J
4`00000000000000Gm<00P00000500ikh`<00000201PZ?L30000000306fcnP000000QKOf00/0QKOf
00@0000009>il@2C^O40TkWa1`00000309Fnl`030000002M__00WKk`00/0WKk`00<000000::ok@2R
_nd02`2R_nd00`000000Y/3/0:K0k00:0:K0k0030000002Y`^`0ZL;/00/0ZL;/00<000000:c5k02/
aN`02`2/aN`00`000000[LS^0:g8kP0:0:g8kP030000002^cO00[/g`00P0[/g`1`0000090;CFl@03
0000002bgoH0/]of00D0/]of1@0000040;Cam@8000000P2mn>h4000003T0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0f0?ooo`00>@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo03/0oooo0P0000001@00@Kl00000001Od`00Gm<0000000H03W_S0P00000:062Xm`<0
00002`25]oH00`000000TkWa09>il@0809>il@L000002P2M__000`000000X[o]0::ok@0;0::ok@03
0000002V`>`0Y/3/00X0Y/3/00<000000:W2k02Y`^`02`2Y`^`00`000000[<G/0:c5k00;0:c5k003
0000002]b>h0[LS^00X0[LS^00@000000:k=l02^cO00[/g`1`0000030;?>kP030000002de_40]=Ka
00X0]=Ka00<000000;;OmP2bgoH00P2bgoH3000000@0^nGc00<000000;Cam@2dlOD00P0000030;gh
kP0400000035oN@00000000003X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0f
0?ooo`00>@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03`0oooo00<000000011
_`00@Kl00P0000000`00Gm<0000000ikh`0400ikh`040000001AV_<00000000000T0H:Sg00<00000
07j`m00000000`00000708FgmP030000002C^O40TkWa00/0TkWa00@0000009bjk@2L^^d0W;[]1`00
000309fnl0030000002R_nd0X[o]00/0X[o]00<000000:K0k02V`>`02P2V`>`00`000000ZL;/0:W2
k00;0:W2k0030000002/aN`0[<G/00/0[<G/00<000000:g8kP2]b>h0102]b>h:000000X0/lk^00<0
00000;CFl@2de_402@2de_400`000000/]of00000003000000H0^nGc00@000000;Cam@0000000000
0`2mn>h200000080aOgT00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo03L0oooo000j0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?03o
ool2000000<0046o00@00000001Od`00000000000`0>Nn<010000000DI[c056Jl`1AV_<2000000L0
H:Sg00<0000007j`m01n/?@00`1n/?@3000000D0QKOf00<0000009>il@2C^O402P2C^O400`000000
W;[]09bjk@0809bjk@X000001`2R_nd00`000000Y/3/0:K0k00:0:K0k0030000002Y`^`0ZL;/00/0
ZL;/00<000000:c5k02/aN`01@2/aN`=000000H0/LS[00<000000;?>kP2cc^h02`2cc^h00`000000
]=Ka0;CFl@080;CFl@<000002@2kiO<3000000@0_OS^00D000000<Gmi035oN@0aOgT0000000l0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0=`3oool003X0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0n0?ooo`8000000`00@Kl01000000005oC001Od`00000200ik
h`030000001AV_<0DI[c00<0DI[c0P000005062Xm`030000001n/?@0O[3d00H0O[3d100000000`25
]oH0000009>il@0;09>il@030000002L^^d0W;[]00/0W;[]00<000000:>kjP2S^nX0102S^nXZ0000
00H0[l?Y00<000000;78j`2ab>/02P2ab>/00`000000/lk^0;?>kP0:0;?>kP030000002de_40]=Ka
00H0]=Ka0`0000000`2kfNl000000;_Ul`070;_Ul`80000000<0a>[`0000002mn>h00`2mn>h00`00
0000aOgT0<Gmi002000003d0oooo00<000000?ooo`3oool08@3oool2000003X0oooo000j0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0?`3oool2000000<0046o00<00000001Od`00
Gm<00`000007056Jl`8000000`1PZ?L00`000000O[3d07j`m00:07j`m0@000002P2C^O400`000000
W;[]09bjk@0;09bjk@030000002S^nX0Xk_Z00/0Xk_Z00<000000:Rmj@2X_NT02P2X_NT00`000000
[<3X0:c0j00;0:c0j0030000002_`nT0[l?Y00/0[l?Y00<000000;78j`2ab>/02P2ab>/00`000000
/lk^0;?>kP0:0;?>kP030000002de_40]=Ka0080]=Ka100000040;_Ik`030000002kiO<0^nGc00@0
^nGc0P0000030<CZl0030000002mn>h0_OS^008000000P35oN@3000003d0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0h0?ooo`00>`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0400oooo0P0000030011_`0500000000Gm<005oC001Od`0000002@1AV_<200000003
062Xm`000000O[3d00`0O[3d00<00000092ck`2@/nl01000000609>il@030000002L^^d0W;[]00/0
W;[]00<000000:>kjP2S^nX02`2S^nX00`000000Z;gY0:Rmj@0:0:Rmj@030000002/`>P0[<3X00/0
[<3X00<000000:o3j@2_`nT02`2_`nT00`000000/LS[0;78j`090;78j`030000002cc^h0/lk^00/0
/lk^00<000000;CFl@0000000P0000070;_Ik`030000002kiO<0^nGc00<0^nGc0P0000040<CZl004
0000002mn>h0_OS^000000<0aOgT0`00000n0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0>@3oool003/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`110?ooo`80
00000`00@Kl200000004001Od`0000000000000000T0DI[c0`00000<07j`m0030000002@/nl0T;?_
00@0T;?_1000000209>il@030000002L^^d0W;[]00/0W;[]00<000000:>kjP2S^nX02`2S^nX00`00
0000Z;gY0:Rmj@0:0:Rmj@030000002/`>P0[<3X00/0[<3X00<000000:o3j@2_`nT02P2_`nT00`00
0000/LS[0;78j`0:0;78j`030000002cc^h0/lk^00P0/lk^1@00000:0;_Ik`040000002kiO<0^nGc
0;_Ul`8000001P34j_0300000080aOgT1000000o0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0>P3oool003/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`110?oo
o`04000000008ZP00000000000<0046o0P000002042;k0800000201AV_<00`000000MZOa00000002
000000T0O[3d00<00000092ck`2@/nl0202@/nl5000000/0W;[]00<000000:>kjP2S^nX02P2S^nX0
0`000000Z;gY0:Rmj@0;0:Rmj@030000002/`>P0[<3X00X0[<3X00<000000:o3j@2_`nT02`2_`nT0
0`000000/LS[0;78j`0:0;78j`040000002cc^h0/lk^0;?>kPL000000`2icn/00`000000^mW_0;_I
k`090;_Ik`040000002kiO<00000000000P0a>[`00H000000<Gmi035oN@0aOgT0000003;omH20000
0400oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0j0?ooo`00?03oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0480oooo00@00000000RZ0008ZP000000`00@Kl20000
00<0@8_/0P000006056Jl`030000001fYo40MZOa0080MZOa0P00000707j`m0030000002@/nl0T;?_
00X0T;?_00<0000009^ejP2K]NX01000000709bjk@030000002S^nX0Xk_Z00X0Xk_Z00<000000:Rm
j@2X_NT02`2X_NT00`000000[<3X0:c0j00:0:c0j0030000002_`nT0[l?Y00/0[l?Y00<000000;78
j`2ab>/01`2ab>/7000000X0^Lo[00<000000;_Ik`2kfNl0202kfNl3000000P0a>[`0`0000020<Gm
i0040000003;omH0000000000440oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0k
0?ooo`00?03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04<0oooo00@00000000R
Z0008ZP000000`00@Kl00`000000@8_/042;k003042;k0800000101AV_<00`000000MZOa07JWl@04
07JWl@<00000101n/?@00`000000T;?_092ck`0:092ck`030000002K]NX0VkGZ00@0VkGZ1@000002
09bjk@030000002S^nX0Xk_Z00X0Xk_Z00<000000:Rmj@2X_NT02`2X_NT00`000000[<3X0:c0j00:
0:c0j0030000002_`nT0[l?Y00/0[l?Y00@000000;78j`2ab>/0/LS[1P0000030;K8i`030000002i
cn/0^Lo[00/0^Lo[00<000000;_Ik`2kfNl01P2kfNl2000000030<;Lk0000000a>[`00H0a>[`0P00
00000`3=kn/000000<Gmi002000000030<_oeP00000000000480oooo00<000000?ooo`3oool07@3o
ool3000003d0oooo000l0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0A03oool0
1000000002:X000RZ00000020011_`<000001@10Rn`200000080DI[c00<0000007JWl@1fYo401`1f
Yo430000000307j`m0000000T;?_00/0T;?_00<0000009^ejP2K]NX02@2K]NX9000000H0Xk_Z00<0
00000:Rmj@2X_NT02`2X_NT00`000000[<3X0:c0j00:0:c0j0030000002_`nT0[l?Y00D0[l?Y2P00
00090;K8i`030000002icn/0^Lo[00X0^Lo[00<000000;_Ik`2kfNl0102kfNl3000000<0`]c/00<0
00000<CZl034j_000`34j_02000000<0cNo[0P0000020<_oeP800000@`3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo03`0oooo000l0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0A@3oool01P00000002:X000RZ0000000046o00000080;GWT00<00000042;k010Rn`0
1010Rn`3000000`0MZOa0`00000;092ck`030000002K]NX0VkGZ00/0VkGZ00<000000:>hi`2S^>L0
102S^>L=000000L0Z;gY00<000000:c0j02/`>P0102/`>P>000000H0//;V00<000000;K8i`2fb>L0
2P2fb>L00`000000^Lo[0;W?j`0:0;W?j`040000002kfNl0^mW_0;_Ik`<000001@32g>`00`000000
a>[`0<CZl0020<CZl08000001@3=kn/00`000000booF0<_oeP02000004@0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`020?ooo`050?n?=@00000000000000000eSol0=@3oool003d0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`160?ooo`03000000008ZP002:X0080
00000`0]NN@2000000H0@8_/0P00000<07JWl@030000002<[N`0000000800000202@/nl00`000000
VkGZ09^ejP0;09^ejP030000002S^>L0XkSW00X0XkSW00<000000:VjiP2Y^^H0102Y^^H>000000H0
[[kU00<000000;;2iP2b`^H02`2b`^H00`000000]/SW0;K8i`0:0;K8i`030000002icn/0^Lo[00X0
^Lo[00@000000;_Ik`00000000002032g>`00`000000a>[`0<CZl002000000D0cNo[0`0000000`3;
omH00000000000150?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool00`3oool01P1O
53D0Sooo0?ooo`3oohl0=@0e08oooc@0oooo000m0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0A`3oool01000000002:X000RZ000000502eii00300000010Rn`0@8_/00<0@8_/00@0
000006jMk@00000000002P1fYo400`000000S:g/08b]k00208b]k0@00000102@/nl00`000000VkGZ
09^ejP0;09^ejP030000002S^>L0XkSW00X0XkSW00<000000:VjiP2Y^^H02`2Y^^H00`000000[[kU
0:jni@0:0:jni@030000002b`^H0//;V00/0//;V00<000000;K8i`2fb>L02P2fb>L00`000000^Lo[
0;W?j`080;W?j`@000002P32g>`3000000H0cNo[00L000000=Cci@000000booF0000003>olH00000
04D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`030?n?=@00=Hl0oooo
0080oooo00<0a5lD01AOa03oool0<`3oool003d0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`170?ooo`03000000008ZP002:X008000001@0]NN@00`000000@8_/042;k002042;k004
0000001^WNd0KYg]06jMk@800000201fYo400`000000S:g/08b]k00608b]k0<0000000<0T;?_0000
002K]NX02`2K]NX00`000000XkSW0:>hi`0;0:>hi`030000002Y^^H0ZK[V00/0ZK[V00<000000:jn
i@2^_^D02P2^_^D00`000000//;V0;;2iP0;0;;2iP030000002fb>L0]/SW00X0]/SW00<000000;W?
j`2icn/0102icn/400000080_m7X00<000000<;Lk032g>`02032g>`2000000H0cNo[0P0000020=Cc
i@80000000<0c_o60000003oool0A@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
00<0oooo00<0a5lD01AOa03oool00P3oool00`3oScD003F?0?ooo`0c0?ooo`00?P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo04P0oooo00D00000000RZ00000006FKJ0000000502ei
i08000000P10Rn`00`000000KYg]06jMk@0306jMk@<000001@1fYo400`000000S:g/08b]k00908b]
k0@000002P2K]NX00`000000XkSW0:>hi`0;0:>hi`030000002Y^^H0ZK[V00/0ZK[V00<000000:jn
i@2^_^D02P2^_^D00`000000//;V0;;2iP0:0;;2iP030000002fb>L0]/SW00/0]/SW00<000000;W?
j`2icn/0100000060;oAj00300000032g>`0`]c/00H0`]c/0P0000000`39gnP000000<g_j`040<g_
j`030000003DlnD0e??U0080e??U00<000000<koaP000000A`3oool00`000000oooo0?ooo`0I0?oo
o`@000001@3oool00`34Ga@055o40?ooo`020?ooo`030?n?=@00=Hl0oooo03<0oooo000n0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0B@3oool2000000806FKJ0P00000502eii004
00000010Rn`0@8_/000000L0KYg]0P00000307JWl@030000002<[N`0S:g/00X0S:g/00<0000009Va
i`2I/NL01000000609^ejP030000002S^>L0XkSW00/0XkSW00<000000:VjiP2Y^^H02P2Y^^H00`00
0000[[kU0:jni@0;0:jni@030000002b`^H0//;V00X0//;V00<000000;K8i`2fb>L02@2fb>L50000
00X0_m7X00<000000<;Lk032g>`01032g>`2000000<0bMoX00<000000<g_j`3=kn/00P3=kn/00`00
0000e??U0=Cci@020=Cci@030000003>olH0000004P0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`040?ooo`030<AO500DGl@0oooo0080oooo00<0ohle000eS`3oool0<`3oool003h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1:0?ooo`030000000II]X06FKJ0080
6FKJ00<0000002eii00]NN@00`0]NN@3000000T0KYg]0P0000000`1fYo40000008b]k00;08b]k003
0000002I/NL0VK7W00@0VK7W1000000209^ejP030000002S^>L0XkSW00/0XkSW00<000000:VjiP2Y
^^H02P2Y^^H00`000000[[kU0:jni@0;0:jni@030000002b`^H0//;V00X0//;V00<000000;K8i`2f
b>L01@2fb>L400000080^/SU00<000000;oAj02odNP02@2odNP00`000000`]c/0<;Lk0030<;Lk080
00001039gnP010000000cNo[0<g_j`3=kn/2000000@0e??U0`00001:0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool01@3oool00`3oScD055o40?ooo`020?ooo`030<AO500DGl@0oooo
03<0oooo000o0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0B`3oool00`000000
6FKJ01UVfP0201UVfP030000000]NN@0;GWT00@0;GWT00<0000006jMk@1^WNd02@1^WNd3000000/0
S:g/00<0000009Vai`2I/NL0202I/NL6000000X0XkSW00<000000:VjiP2Y^^H02P2Y^^H00`000000
[[kU0:jni@0;0:jni@030000002b`^H0//;V00X0//;V00<000000;K8i`2fb>L01@0000060;[8i@03
0000002odNP0_m7X00T0_m7X00@000000<;Lk032g>`0`]c/0P0000060<WOj0040000003=kn/0cNo[
000000@0e??U1000001;0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool0
1P1O5000=Hoo0?ooo`3oa5l0500e08oooc@0oooo000o0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0C03oool00`0000006FKJ01UVfP0201UVfP030000000]NN@0;GWT00<0;GWT0`00
000:06jMk@0400000027Y^T00000000000T0S:g/00<0000009Vai`2I/NL02P2I/NL010000000XkCT
0:>di02S]>@7000000<0XkSW00<000000:VjiP2Y^^H02P2Y^^H00`000000[[kU0:jni@0;0:jni@03
0000002b`^H0//;V00@0//;V2@00000;0;[8i@030000002odNP0_m7X00T0_m7X00@000000<;Lk000
000000002039gnP3000000@0e??U00@000000=cgg@3Lmmd00000C03oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00L0oooo00D0oon?03D000000000000D05o4o`0e0?ooo`00?`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<0000001UVfP0II]X00P0II]X0
0`000000;GWT02eii00202eii0030000001TT^T0I9;Y00800000201^WNd010000000QjKY08NVj@27
Y^T3000000H0S:g/00<0000009Vai`2I/NL02P2I/NL00`000000XkCT0:>di0080:>di2D000001P2f
`N<00`000000^/SU0;[8i@0:0;[8i@030000002odNP0_m7X00T0_m7X0`00000:0<WOj0030000003D
lnD0e??U00<0e??U00@000000=cgg@3Lmmd00000C@3oool00`000000oooo0?ooo`0F0?ooo`<00000
@`3oool00400oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1?0?ooo`030000000I
I]X06FKJ00806FKJ0P00000202eii0030000001TT^T0I9;Y0080I9;Y00<0000006jMk@1^WNd01@1^
WNd00`000000QjKY08NVj@0408NVj@<000000`2<[N`00`000000VK7W09Vai`0:09Vai`030000002S
]>@0XkCT00/0XkCT00<000000:Zgh`2Z]n<02P2Z]n<00`000000/;cR0;2lhP0;0;2lhP030000002f
`N<0]/7S00X0]/7S00<000000;[8i@2jb>D02P2jb>D00`000000_m7X0;oAj0060;oAj0<0000000<0
a=;U00000039gnP02039gnP3000000@0e??U00@000000=cgg@3Lmmd00000CP3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo0480oooo00100?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0D03oool00`0000006FKJ01UVfP0301UVfP030000000]NN@0000000D0I9;Y0P00
000506jMk@0300000027Y^T0QjKY00L0QjKY0P0000000`2<[N`0000009Vai`0;09Vai`030000002S
]>@0XkCT00/0XkCT00<000000:Zgh`2Z]n<02P2Z]n<00`000000/;cR0;2lhP0;0;2lhP030000002f
`N<0]/7S00X0]/7S00<000000;[8i@2jb>D02P2jb>D00`000000_m7X0;oAj0020;oAj0@000001034
d^D00`000000bMoX0<WOj0050<WOj08000000P3@h^@01@000000e??U0=Cci@3DlnD000000080g?OM
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0480oooo
00100?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0D@3oool00`0000006FKJ01UV
fP0301UVfP8000001`1TT^T00`000000KYg]06jMk@0206jMk@0300000027Y^T0QjKY00T0QjKY0`00
000;09Vai`030000002S]>@0XkCT00/0XkCT00<000000:Zgh`2Z]n<02P2Z]n<00`000000/;cR0;2l
hP0;0;2lhP030000002f`N<0]/7S00T0]/7S00<000000;[8i@2jb>D02`2jb>D00`000000_m7X0000
0002000000P0a=;U00<000000<WOj039gnP00`39gnP2000000<0d>;T00<000000=Cci@3DlnD00P00
00020=cgg@030000003oool0oooo04h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`130?ooo`00@03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0580oooo00<00000
01UVfP0II]X00`0II]X00`000000I9;Y06BBj@0606BBj@8000000P1^WNd00`000000QjKY08NVj@0:
08NVj@030000002G[>D0000000800000202I/NL00`000000XkCT0:>di00;0:>di0030000002Z]n<0
Z[OS00X0Z[OS00<000000;2lhP2`_>802`2`_>800`000000]/7S0;K1h`090;K1h`030000002jb>D0
^/SU00T0^/SU1000000:0<CBi@0300000039gnP0bMoX0080bMoX0P0000050=3Ri0030000003DlnD0
000000<0g?OM00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo04@0oooo00110?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0D`3oool00`00
00006FKJ01UVfP0201UVfP<00000201TT^T3000000`0QjKY00<0000009N/i@2G[>D00P2G[>D40000
00@0VK7W00<000000:>di02S]>@02P2S]>@00`000000Z[OS0:Zgh`0;0:Zgh`030000002`_>80/;cR
00X0/;cR00<000000;K1h`2f`N<02P2f`N<00`000000^/SU0;[8i@050;[8i@@000000P2nb>800`00
0000a=;U0<CBi@090<CBi@0300000039gnP0bMoX008000001`3@h^@2000000<0g?OM00<000000?oo
o`3oool0D03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04@0oooo00110?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0E03oool01@0000006FKJ01UVfP0II]X00000
0080FHOT00<0000006BBj@1TT^T01`1TT^T2000000/0QjKY00<0000009N/i@2G[>D01P2G[>D30000
000309Vai`000000XkCT00/0XkCT00<000000:Zgh`2Z]n<02`2Z]n<00`000000/;cR0;2lhP0:0;2l
hP030000002f`N<0]/7S00X0]/7S00<000000;[8i@2jb>D01@0000060;k8hP0300000034d^D0a=;U
00T0a=;U0`0000090=3Ri0030000003Lmmd0g?OM0080g?OM00<000000?ooo`3oool0D03oool00`00
0000oooo0?ooo`0C0?ooo`<00000AP3oool00440oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`1E0?ooo`040000000II]X06FKJ000000<0FHOT0P00000706BBj@0400000022WnH00000
000000T0QjKY00<0000009N/i@2G[>D02@2G[>D5000000T0XkCT00<000000:Zgh`2Z]n<02`2Z]n<0
0`000000/;cR0;2lhP0:0;2lhP030000002f`N<0]/7S00L0]/7S1P00000;0;k8hP0300000034d^D0
a=;U00P0a=;U0P0000090=3Ri0<000000`3Lmmd00`000000oooo0?ooo`1A0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0A@3oool00480oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`1F0?ooo`030000000II]X0000000D0FHOT00<0000006BBj@1TT^T0101TT^T01000
0000PYoV08:OiP22WnH3000000H0QjKY00<0000009N/i@2G[>D02P2G[>D010000000Xk3R0:>`hP2S
/>86000000<0XkCT00<000000:Zgh`2Z]n<02`2Z]n<00`000000/;cR0;2lhP0:0;2lhP040000002f
`N<0]/7S0;K1h`H000000`2h`>000`000000_/SR0;k8hP0:0;k8hP0300000034d^D0a=;U00L0a=;U
0P0000000`39e>8000000=3Ri0060=3Ri08000000P3GiN0010000000g?OM0=cgg@00001D0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0AP3oool00480oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`1G0?ooo`8000001P1IQn@00`000000I9;Y06BBj@0306BBj@030000
0022WnH0PYoV00@0PYoV0`00000308NVj@030000002G[>D0UjcU00X0UjcU00<000000:>`hP2S/>80
1`2S/>8:000000L0Z[OS00<000000;2lhP2`_>80102`_>8:000000T0^<3P00<000000;k8hP2nb>80
2P2nb>800`000000a=;U0<CBi@040<CBi@<000000`39e>800`000000d>;T0=3Ri0040=3Ri0050000
003GiN00enGP0=OUh00000000P3Lmmd00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0AP3oool00480oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`1H0?ooo`030000001IQn@0FHOT00D0FHOT0P00000306BBj@0300000022WnH0PYoV00L0PYoV
0P0000000`27Y^T0000009N/i@0;09N/i@030000002S/>80Xk3R00X0Xk3R00<000000:^eh02[]N00
102[]N0>000000H0/[[O00<000000;S0h02h`>002P2h`>000`000000_/SR0;k8hP0:0;k8hP040000
0034d^D0a=;U0<CBi@<000001P39e>800`000000d>;T0=3Ri0020=3Ri0800000103GiN000`000000
g?OM0000001F0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0A`3oool004<0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1I0?ooo`030000001IQn@0FHOT00H0FHOT
00@0000006BBj@1TT^T000002`22WnH3000000/0UjcU00<000000:>`hP2S/>802P2S/>800`000000
ZkGP0:^eh00;0:^eh0030000002b^]l0/[[O00X0/[[O00<000000;S0h02h`>002P2h`>000`000000
_/SR0;k8hP0:0;k8hP0400000034d^D00000000000P0bMCR00<000000=3Ri03@h^@00P3@h^@00`00
0000enGP0=OUh0040=OUh0800000E`3oool00`000000oooo0?ooo`0@0?ooo`<00000B@3oool004<0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1J0?ooo`030000001IQn@0FHOT00H0
FHOT0`00000<08:OiP040000002EY^800000000000T0UjcU00<000000:>`hP2S/>802P2S/>800`00
0000ZkGP0:^eh00;0:^eh0030000002b^]l0/[[O00X0/[[O00<000000;S0h02h`>002P2h`>000`00
0000_/SR0;k8hP090;k8hP<000002P39e>800`000000d>;T0=3Ri002000000L0enGP00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04P0oooo00130?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0F`3oool2000000P0FHOT00<0000008:OiP22
WnH02P22WnH010000000UJKR09FVhP2EY^83000000H0UjcU00<000000:>`hP2S/>802P2S/>800`00
0000ZkGP0:^eh00;0:^eh0030000002b^]l0/[[O00X0/[[O00<000000;S0h02h`>002P2h`>000`00
0000_/SR0;k8hP060;k8hP<0000000<0`/SO00000039e>802P39e>83000000P0enGP00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04T0oooo00140?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0G@3oool00`000000FHOT05V7i00505V7i0<0
00002P22WnH00`000000UJKR09FVhP0409FVhP<000000`2G[>D00`000000Xk3R0:>`hP0:0:>`hP03
0000002[]N00ZkGP00/0ZkGP00<000000;:jg`2b^]l02P2b^]l00`000000^<3P0;S0h00:0;S0h003
0000002nb>80_/SR0080_/SR100000040<;8g`0300000039e>80bMCR00T0bMCR00<000000=OUh03G
iN001P3GiN02000005X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`190?ooo`00
A03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo05h0oooo00<0000005V7i01IQn@0
101IQn@00`000000O9OR07bGhP02000000P0PYoV00<0000009FVhP2EY^801`2EY^820000000309N/
i@000000Xk3R00/0Xk3R00<000000:^eh02[]N002P2[]N000`000000/[[O0;:jg`0;0;:jg`030000
002h`>00^<3P00X0^<3P00<000000;k8hP0000000P0000080<;8g`0300000039e>80bMCR00L0bMCR
0`0000070=OUh0030000003oool0oooo05X0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`1:0?ooo`00A03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo05l0oooo00<0
000005V7i01IQn@00`1IQn@00`000000O9OR07bGhP0207bGhP8000001P22WnH00`000000UJKR09FV
hP0909FVhPD000002@2S/>800`000000ZkGP0:^eh00:0:^eh0030000002b^]l0/[[O00/0/[[O00<0
00000;S0h02h`>00202h`>04000000/0`/SO00<000000<WDhP39e>801@39e>8200000080cmGN00<0
00000=OUh03GiN00103GiN000`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00`0oooo0`00
001<0?ooo`00A@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0640oooo00<00000
05V7i01IQn@00P1IQn@00`000000O9OR07bGhP0407bGhP8000001022WnH00`000000UJKR09FVhP0:
09FVhP040000002R[=l0XZcO0::/g`H000000`2S/>800`000000ZkGP0:^eh00:0:^eh0030000002b
^]l0/[[O00/0/[[O00<000000;S0h02h`>00102h`>0400000080^koM00<000000<;8g`32b=l02@32
b=l00`000000bMCR0<WDhP040<WDhP800000103?eMh00`000000enGP0=OUh0020=OUh0800000G`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04/0oooo00150?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0HP3oool200000080FHOT00<0000007bGhP1lUn801P1lUn82
00000080PYoV00<0000009FVhP2EY^802P2EY^800`000000XZcO0::/g`070::/g`X000001P2[]N00
0`000000/[[O0;:jg`0;0;:jg`030000002h`>00^<3P00@000001P2k_md00`000000`/SO0<;8g`09
0<;8g`0300000039e>80bMCR0080bMCR0P0000050<oEgP030000003GiN00enGP0080enGP00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`3oScD01@00
00000`00=Hl0oooo0?ooo`110?ooo`00A@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo06@0oooo00<0000005V7i00000002P1lUn83000000`0UJKR00<000000::/g`2R[=l02P2R[=l0
0`000000[;;M0:bbg@040:bbgAL000002P2k_md00`000000`/SO0<;8g`090<;8g`0300000039e>80
bMCR008000001`3?eMh01@000000enGP0=OUh03GiN0000000680oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`050?ooo`0305lD501Oa?l0oooo04@0oooo00150?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0I@3oool2000000`0O9OR0P00000;09FVhP030000002R[=l0
XZcO00X0XZcO00<000000:bbg@2//]d02P2//]d00`000000];SL0;Bhg00;0;Bhg0030000002k_md0
^koM00X0^koM00<000000<;8g`32b=l02@32b=l3000000T0cmGN00@000000=OUh00000000000H`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<0Ga@D05o4o`3oool0A03o
ool004H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1V0?ooo`030000001lUn80
O9OR00X0O9OR00@0000009:Qg`00000000002@2EY^800`000000XZcO0::/g`0:0::/g`030000002/
/]d0[;;M00X0[;;M00<000000;Bhg02d^=`02`2d^=`00`000000^koM0;^og@090;^og@0300000032
b=l0`/SO00T0`/SO0P00000;0<oEgP800000I@3oool00`000000oooo0?ooo`080?ooo`@00000203o
ool00`1O51@0GlCo0?ooo`140?ooo`00AP3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo06L0oooo0P00000:07bGhP040000002BXMl0TZ7O09:Qg`<000001P2EY^800`000000XZcO0::/
g`0:0::/g`030000002//]d0[;;M00X0[;;M00<000000;Bhg02d^=`02`2d^=`00`000000^koM0;^o
g@090;^og@0300000032b=l0`/SO00L0`/SO0P0000000`36bM`000000<oEgP0:0<oEgP030000003o
ool0oooo06@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`0305lD501O
a?l0oooo04@0oooo00160?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J@3oool0
0`000000O9OR07bGhP0707bGhP030000002BXMl0TZ7O00@0TZ7O0`00000309FVhP030000002R[=l0
XZcO00X0XZcO00<000000:bbg@2//]d02P2//]d00`000000];SL0;Bhg00;0;Bhg0030000002k_md0
^koM00T0^koM00<000000<;8g`32b=l01032b=l3000000<0a/WL00<000000<oEgP3?eMh01`3?eMh2
000006L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`0305lD501Oa?l0
oooo04@0oooo00170?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0JP3oool20000
00L0O9OR00<0000009:Qg`2BXMl01`2BXMl20000000309FVhP000000XZcO00/0XZcO00<000000:bb
g@2//]d02P2//]d00`000000];SL0;Bhg00:0;Bhg0030000002k_md0^koM00X0^koM00@000000<;8
g`32b=l0`/SO0`0000060<K9g0030000003?eMh0cmGN00D0cmGN0P00001Y0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`1O51@0GlCo0?ooo`140?ooo`00A`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo06`0oooo00<0000007bGhP1lUn800`1lUn800`00
0000TZ7O09:Qg`0:09:Qg`@000002P2R[=l00`000000[;;M0:bbg@0:0:bbg@030000002d^=`0];SL
00X0];SL00<000000;^og@2k_md02P2k_md010000000`/SO0000000000090<K9g0030000003?eMh0
cmGN00@0cmGN00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00D0oooo00D0a5lD0000000055l0Ga@D05o4o`150?ooo`00A`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo06d0oooo0P00000307bGhP030000002BXMl0TZ7O00/0TZ7O00<00000
0:6Yg02QZM`0100000060::/g`030000002//]d0[;;M00X0[;;M00<000000;Bhg02d^=`02P2d^=`0
0`000000^koM0;^og@080;^og@@000002P36bM`00`000000cmGN0<oEgP030<oEgP800000K03oool0
0`000000oooo0?ooo`070?ooo`8000002P3oool00`34Ga@0000D05o4o`150?ooo`00B03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo06l0oooo00@0000007bGhP1lUn8000003@2BXMl0
0`000000XJWL0:6Yg0040:6Yg0@000000P2R[=l00`000000[;;M0:bbg@0:0:bbg@030000002d^=`0
];SL00X0];SL00<000000;^og@2k_md0102k_md400000080_[oJ00<000000<K9g036bM`02@36bM`0
0`000000cmGN0<oEgP020<oEgP030000003oool0oooo06`0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`1@0?ooo`00B03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0700oooo0`00000=09:Qg`030000002QZM`0XJWL00P0XJWL2@0000060:bbg@030000002d^=`0];SL
00X0];SL00<000000;^og@2k_md0100000060;jofP0300000036bM`0a/WL00T0a/WL00<000000<oE
gP3?eMh00P00001_0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0D@3oool004P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1b0?ooo`800000302BXMl00`000000
XJWL0:6Yg00:0:6Yg0030000002//=/0[;3K00@0[;3K5P00000:0;jofP0300000036bM`0a/WL00T0
a/WL0`00001a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0DP3oool004T0oooo
00D000000?ooo`3oool0oooo0000001f0?ooo`8000002@2BXMl00`000000XJWL0:6Yg00;0:6Yg003
0000002//=/0[;3K00X0[;3K00<000000;FgfP2e]mX02P2e]mX00`000000_[oJ0;jofP0:0;jofP03
00000036bM`0a/WL00P0a/WL0P00001c0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0DP3oool004T0oooo00D000000?ooo`3oool0oooo0000001h0?ooo`8000001`2BXMl00`000000
XJWL0:6Yg00;0:6Yg0030000002//=/0[;3K00X0[;3K00<000000;FgfP2e]mX02P2e]mX00`000000
_[oJ0;jofP090;jofP0300000036bM`0a/WL00L0a/WL0P00001e0?ooo`030000003oool0oooo00@0
oooo0`00001D0?ooo`00B@3oool01@000000oooo0?ooo`3oool0000007X0oooo0P00000509:Qg`03
0000002QZM`0XJWL00/0XJWL00<000000:b`f`2//=/02P2//=/00`000000]KOJ0;FgfP0:0;FgfP03
0000002n_mX0_[oJ00T0_[oJ00<000000<K9g036bM`01036bM`3000007L0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1C0?ooo`00BP3oool00`000000oooo0000001m0?ooo`800000
0`2BXMl00`000000XJWL0:6Yg00;0:6Yg0030000002//=/0[;3K00X0[;3K00<000000;FgfP2e]mX0
2P2e]mX00`000000_[oJ0;jofP090;jofP0400000036bM`0a/WL0<K9g0<00000NP3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo05@0oooo001:0?ooo`030000003oool0000007l0oooo
0P0000000`2BXMl000000:6Yg00;0:6Yg0030000002//=/0[;3K00/0[;3K00<000000;FgfP2e]mX0
2@2e]mX00`000000_[oJ0;jofP0:0;jofP0400000036bM`00000000007d0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`1D0?ooo`00BP3oool00`000000oooo000000210?ooo`<00000
2`2QZM`00`000000[;3K0:b`f`0:0:b`f`030000002e]mX0]KOJ00X0]KOJ00<000000;jofP2n_mX0
2@2n_mX300000800oooo00<000000?ooo`3oool00`00001G0?ooo`00BP3oool00`000000oooo0000
00240?ooo`<00000202QZM`00`000000[;3K0:b`f`0:0:b`f`030000002e]mX0]KOJ00X0]KOJ00<0
00000;jofP2n_mX01P2n_mX3000008<0oooo00D000000?ooo`3oool0oooo0000001H0?ooo`00B`3o
ool2000008L0oooo100000040:6Yg0030000002//=/0[;3K00X0[;3K00<000000;FgfP2e]mX02P2e
]mX00`000000_[oJ0;jofP020;jofP@00000QP3oool01@000000oooo0?ooo`3oool0000005P0oooo
001;0?ooo`800000R`3oool3000000030:6Yg0000000[;3K00/0[;3K00<000000;FgfP2e]mX02P2e
]mX00`000000_[oJ00000002000008X0oooo00@000000?ooo`3oool00000F@3oool004/0oooo0P00
002>0?ooo`P000001P2//=/00`000000]KOJ0;FgfP040;FgfPP00000S@3oool010000000oooo0?oo
o`00001I0?ooo`00C03oool00`000000oooo0?ooo`2D0?ooo`d00000U@3oool3000005X0oooo001<
0?ooocD00000o`3oool50?ooo`030000003oool000000080oooo00<0oon?03D00000000010000000
0`0eSol0oooo0?ooo`1>0?ooo`00P@3ooomX000009`0oooo0P0000040?ooo`0308le000003D0Sooo
0080oooo00<0a5le05o4o`3oool0C`3oool00>T0ooooJ000000d0?ooo`8000001@3oool00`3oScD0
000D05o4o`1C0?ooo`00o`3ooomB0?ooocD000001`3oool00`3oa5l0500001AOa01B0?ooo`00o`3o
oon@0?ooo`0309a80018W=l0oooo0500oooo003o0?oooi40oooo00<0W4Qd0;ooo`3oool0C`3oool0
0?l0ooooS03oool00`3OW4P0M;oo0?ooo`020?ooo`030;md001d_ol0oooo04l0oooo003o0?oooh`0
oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo0500oooo003o0?ooohd0oooo00D0okmd0000
00000000001809cOo`1A0?ooo`00o`3ooooS0?ooo`00o`3ooooS0?ooo`00o`3ooooS0?ooo`00i03o
ool01@2LB00000000000000004P0W=oo03`0oooo00D0W4P0000000000000001809cOo`2h0?ooo`00
i@3oool00`2oM000M;oo0?ooo`100?ooo`030?oOW01804P0W=oo0;L0oooo003U0?ooo`030;md001d
_ol0oooo0440oooo00<0_gA809cOo`3oool0]P3oool00;H0oooo00L0omnL04P000000000000004RL
g`3oool0gia80080000000<0001809cOo`3oool0203oool00`2LB4P0M7A800000002000000050000
M02oool0oooo0?ooo`2LB0001@0000003P00B9`0omnL04P000000000001d0;oo_`1d0000001809cO
o`2LB000001809cOo`2oM000M7Ad0`0000001@0004P0W=oo0?ooo`3oool0W4P000D0000000D004RL
0?ooo`3oool0oooo0;md0003000000030000M02oool0oooo00T0oooo00/0gia80000000000000018
09cOo`3oool0oono07@00000B9`0oooo09a80005000000050018W03oool0oooo0?oOW01800000`00
00001P1dM7@000000018W03oool0oono07@00080000000<0001d07AdB02Lgol00`3oool01P2oM000
0000000000000000001d0;ooojh0oooo002g0?ooo`030?oo_`1d07@0_ooo00<0oooo00<0oono07A8
W03oool02P3oool00`2LB00004RL0?ooo`020?ooo`030?noM018W=l0oooo00<0oooo00<0oono07@0
M02oool00`3oool03@3ogi`0B4RL0?ooo`3ookl0M01d0;ooo`3oool0W4Q809cOo`3oool0_g@00000
M02oool00P3oool00`3ogi`0B4RL0?ooo`030?ooo`030?oo_`1d07@0_ooo00@0oooo00<0_g@0001d
_`3oool00P3oool00`3o_g@004RL0?ooo`0:0?ooo`030?noM000M;l0oooo0080oooo00<0_g@0001d
_`3oool00`3oool00`3ookl0M01d0;ooo`040?ooo`0709a8B02Lgol0oooo0?ooo`3ookl0M000001d
_`020?ooo`070;md001d_ol0oooo0?ooo`3o_g@0001809cOo`020?ooo`030;md0000M;l0oooo0080
oooo00<0okmd0018W03oool0[@3oool00;P0oooo00<0gia80000000000000`0000000`18W=l0oooo
0?ooo`090?ooo`0309a8B02Lgol0oooo0080oooo00<0omnL04Q8W03oool00`3oool00`3ookl0M01d
0;ooo`030?ooo`0<0?oOW018B9`0oooo0?oo_`1d07@0_ooo0?ooo`2LB4P0W=oo0?ooo`2oM000M;oo
103oool00`2oM000M;oo0?ooo`020?ooo`030?oo_`1d07@0_ooo00<0oooo00<0oono07@0M02oool0
403oool01P3o_g@007Bo0?ooo`3oool0_g@0001d_`D0oooo00<0oono07@0M02oool00`3oool00`3o
gi`0B7Bo0?ooo`030?ooo`050?noM000M;l0oooo0?oo_`1dB9`0103oool01P2LB4P0W=oo0?ooo`3o
okl0M01d0;oook<0oooo002h0?ooo`030?oo_`1dB9`0oooo0080oooo00<0W4Qd0;ooo`3oool03`3o
ool00`2LB00007Bo0?ooo`030?ooo`030?oo_`1d07@0_ooo00<0oooo00`0omnL04Q8W03oool0oono
07@0M02oool0oooo09a8B02Lgol0oooo0;md0018W=l40?ooo`030;mdB02Lgol0oooo0080oooo00<0
oono07@0M02oool00`3oool00`3ookl0M00000000004000000030018W03oool0oooo00T0oooo00H0
okmd00000000000000000000B02Lgol50?ooo`030?oo_`1d07@0_ooo00<0oooo00<0omnL04Qd_`3o
ool00`3oool01@3o_g@007Bo0?ooo`3ookl0M4RL00@0oooo00D0W4Q809cOo`3oool0oono07@00005
000000030018W03oool0oooo0:`0oooo002i0?ooo`050;md001d_ol0oooo0?noM000M;l03@3oool0
1@3OW4P00000000000000000B9cO00D0oooo00<0oono07@0M02oool00`3oool03@3ogi`0B00007Bo
o`3ogi`0B00004RLg`3ookl0M01809cOo`3oool0_g@00000001d_ol00P3oool00`3OW4P004RL0?oo
o`030?ooo`030?oo_`1d07@0_ooo00@0oooo00<0_g@007Boo`3oool00P3oool00`2LB000B9cO0?oo
o`0:0?ooo`070?noM000M;l0oooo0?ooo`3ogi`0B01809cOo`040?ooo`030?oo_`1d07@0_ooo00@0
oooo00L0W4P004RLg`3oool0oooo0?noM000000007Bo0080oooo00L0_g@004RLg`3oool0oooo0;md
000004P0W=oo0080oooo00<0_g@007Boo`3oool00P3oool00`2LB000B9cO0?ooo`2]0?ooo`00^@3o
ool01@3ogi`0B4RL0?ooo`2LB4P0W=oo00`0oooo00<0gia80018W03oool00P3oool02@3o_g@007Bo
0?ooo`3oool0omnL04P000000000001d0;ooo`020?ooo`0>0?oOW018000004Q807@000000000M;oo
09a80000000007Bo0?ooo`2LB000000007Bo_`1d0002000000030018W03oool0oooo00<0oooo00<0
oono07@0M02oool0103oool00`3ookl0M000000000020000000304RLg`3oool0oooo00X0oooo00<0
okmd001d_`3oool00P3oool02@3OW4P0B9cO0?ooo`3oool0omnL04P000000000001d0;ooo`050?oo
o`0609a80000000000000000M02o_g@007Bo0`3oool02P2LB000000000000000M;l0_g@00000001d
_ol0oooo0?oo_`1d00030000000304RLg`3oool0oooo0:d0oooo002j0?ooo`0309a8B02L_i`0B4RL
00d0oooo00L0okmd0018W03oool0oooo0?oo_`1d000007Bo01l0oooo00<0oono07@0M02oool05P3o
ool01`3o_g@007Bo0?ooo`3oool0oono07@0001d_ol0403oool00`3o_g@007Bo0?ooo`2o0?ooo`00
^03oool01@2LB0000000000000000000M;oo00h0oooo00H0gia8000000000000000007AdM000M;lO
0?ooo`030?oo_`1d07@0_ooo01D0oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`0?
0?ooo`030?noM000M;l0oooo0;l0oooo003E0?ooo`030?noM00007@0_ooo01H0oooo00D0omnL04P0
00000000001d0;ooo`0Q0?ooo`030?noM00007@0_ooo00P0oooo00<0okmd00000000M;l0`03oool0
0=D0oooo00<0okmd0000M02oool0?03oool00`3o_g@0001d0;ooo`3;0?ooo`00o`3ooooS0?ooo`00
o`3ooooS0?ooo`00o`3ooooS0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 481.813}, {312, 0}} -> {-0.0600398, 0.104119, \
0.00349978, 0.00349978}}]
}, Closed]],

Cell[TextData[{
  "More generally, the behavior of a function near a critical point can be \
characterized in terms of the eigenvalues and eigenvectors of the Hessian \
matrix.  Let ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["{",
            "InlineInput"], 
          StyleBox[
            SubscriptBox[
              StyleBox["v",
                "InlineInput"], \(\(i\)\(\ \)\)],
            "InlineInput",
            FontSlant->"Italic"], 
          StyleBox["}",
            "InlineInput",
            FontSlant->"Italic"]}], TraditionalForm]]],
  " represent the set of orthonormal eigenvectors and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["{",
            "InlineInput"], 
          StyleBox[\(\[Lambda]\_\(\(i\)\(\ \)\)\),
            "InlineInput",
            FontSlant->"Italic"], 
          StyleBox["}",
            "InlineInput",
            FontSlant->"Italic"]}], TraditionalForm]]],
  " the corresponding eigenvalues.  Furthermore, let ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`u\_i = v\_i . \ \((x - x\_0)\)\)], "InlineInput"], 
    "InlineInput"],
  " represent the displacements from the critical point with respect to the \
local coordinate system specified by the eigendirections.  The variation of \
",
  StyleBox["f[x]", "InlineInput"],
  "near the critical point then separates "
}], "Text"],

Cell[BoxData[
    \(f[x] \[TildeTilde] 
      f[x\_0] + 
        \(1\/2\) \(\[Sum]\+\(i = 1\)\%n\( \[Lambda]\_i\) u\_i\^2\)\  + \ 
        \[CenterEllipsis]\)], "InlineInput",
  Evaluatable->False,
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
into a sum of independent contributions.  If all eigenvalues have a common \
sign, the critical point is a local minimum if that sign is positive or a \
local maximum if negative, but if the signs are mixed the critical point is a \
saddle with respect to pairs of directions whose eigenvalues have opposite \
signs.  A vanishing eigenvalue indicates the existence of a ridge along the \
corresponding eigendirection.\
\>", "Text"],

Cell["\<\
This technique finds widespread applications in many fields.  For example, \
data analysis using least-squares fitting of a model function to data is an \
optimization problem in which one searches a multidimensional parameter space \
for the minimum squared deviation between the model and the data.  \
Alternatively, a linear-stability analysis of the behavior of systems obeying \
nonlinear differential equations near a fixed point is performed in this \
manner.\
\>", "Text"],

Cell["\<\
Write a gradient function using Map and a Hessian function using Outer.  [Do \
not use Table!]\
\>", "Exercise"],

Cell["\<\
Evaluate the eigenvalues and eigenvectors of the Hessian matrices for the \
examples shown above.\
\>", "Exercise"],

Cell[TextData[{
  "Each of the following functions has a critical point at the origin.  \
Diagonalize the Hessian matrix and classify the critical point as a minimum, \
maximum, saddle, or ridge.  Also, determine the angle between the eigensystem \
and the original coordinate axes.\na) x y Cos[x y]\t\nb) ",
  Cell[BoxData[
      \(\((x - 2  y)\)\^2\ Exp[\(-\((x\^2 + \ y\^2)\)\)]\)]],
  "\nc) ",
  Cell[BoxData[
      \(\((2  x\^2\  + y\^2)\)\ Exp[\(-\((2  x\^2 + \ y\^2)\)\)]\)]],
  "\t\nd) ",
  Cell[BoxData[
      \(Cos[x + \ y]\ Exp[\(-\((x\^2 + \ y\^2)\)\)]\)]]
}], "Exercise"],

Cell["\<\
Analyze the behavior of the function f=(x+2y-3)(y-z+1)(x+z) near the origin \
by locating a critical point and constructing the eigensystem for the \
corresponding Hessian matrix.  [Hint: if you use Solve for g==0, inverse \
functions are returned because there exists a ridge for which the gradient \
equations are degenerate.]\
\>", "Exercise"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Taylor series", "Section"],

Cell[CellGroupData[{

Cell["Power series in one variable", "Subsection"],

Cell[TextData[{
  "The Taylor series expansion of a function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " about the point ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_0\)]],
  " is produced using ",
  StyleBox["Series[", "InlineInput",
    FontWeight->"Bold"],
  StyleBox[Cell[BoxData[
      FormBox[
        RowBox[{"f", ",", 
          RowBox[{"{", 
            RowBox[{"x", ",", \(x\_0\), ",", 
              StyleBox["n",
                FontSlant->"Italic"]}], 
            StyleBox["}",
              FontSlant->"Italic"]}]}], TraditionalForm]], "InlineInput"], 
    "InlineInput"],
  StyleBox["]", "InlineInput",
    FontWeight->"Bold"],
  " where ",
  StyleBox["n",
    FontSlant->"Italic"],
  " is the highest power retained in the expansion.  ",
  ButtonBox["Series",
    ButtonStyle->"RefGuideLink"],
  " can expand about \[Infinity], will usually detect essential \
singularities, and will give a finite number of negative powers or \
logarithmic terms when necessary.  "
}], "Text"],

Cell["For example, the Lenard-Jones potential", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Symbolize", "[", 
        TagBox[\(v\_0\),
          NotationBoxTag,
          Editable->True], "]"}], ";", " ", 
      RowBox[{"Symbolize", "[", 
        TagBox[\(r\_0\),
          NotationBoxTag,
          Editable->True], "]"}]}]], "Input"],

Cell[BoxData[
    \(\(v = \(-v\_0\)\ \((2 \((r\_0\/r)\)\^6 - \((r\_0\/r)\)\^12)\);\)\)], \
"Input"],

Cell[TextData[{
  "is often used as a simple model of the interaction between two atoms in a \
diatomic molecule.  This parametrization obviously has a minimum at ",
  Cell[BoxData[
      \(TraditionalForm\`r\_0\)]],
  ".  Thus, it is useful to construct a power-series expansion that \
approximates the potential near its minimum."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(vSeries = Series[v, {r, r\_0, 4}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\(-v\_0\), "+", \(\(36\ v\_0\ \((r - r\_0)\)\^2\)\/r\_0\%2\), 
        "-", \(\(252\ v\_0\ \((r - r\_0)\)\^3\)\/r\_0\%3\), 
        "+", \(\(1113\ v\_0\ \((r - r\_0)\)\^4\)\/r\_0\%4\), "+", 
        InterpretationBox[\(O[r - r\_0]\^5\),
          SeriesData[ 
          r, r\[UnderBracket]Subscript\[UnderBracket]0, {}, 0, 5, 1],
          Editable->False]}],
      SeriesData[ r, r\[UnderBracket]Subscript\[UnderBracket]0, {
        Times[ -1, v\[UnderBracket]Subscript\[UnderBracket]0], 0, 
        Times[ 36, 
          Power[ r\[UnderBracket]Subscript\[UnderBracket]0, -2], 
          v\[UnderBracket]Subscript\[UnderBracket]0], 
        Times[ -252, 
          Power[ r\[UnderBracket]Subscript\[UnderBracket]0, -3], 
          v\[UnderBracket]Subscript\[UnderBracket]0], 
        Times[ 1113, 
          Power[ r\[UnderBracket]Subscript\[UnderBracket]0, -4], 
          v\[UnderBracket]Subscript\[UnderBracket]0]}, 0, 5, 1],
      Editable->False]], "Output"]
}, Closed]],

Cell[TextData[{
  "Although this result appears, at first glance, to be printed as an \
ordinary expression, the presence of the final term representing all omitted \
terms of order ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\)]],
  " and higher shows that this expression is not simply an algebraic \
expression.  (How would one evaluate the truncation term?).  In fact, ",
  StyleBox["Series", "InlineInput",
    FontWeight->"Bold"],
  " actually returns a ",
  StyleBox["SeriesData", "InlineInput",
    FontWeight->"Bold"],
  " object whose arguments are the expansion variable, the expansion point, a \
list of terms, and a description of the omitted terms."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullForm[vSeries]\)], "Input"],

Cell[BoxData[
    TagBox[
      StyleBox[\(SeriesData[r, r\[UnderBracket]Subscript\[UnderBracket]0, 
          List[Times[\(-1\), v\[UnderBracket]Subscript\[UnderBracket]0], 0, 
            Times[36, 
              Power[r\[UnderBracket]Subscript\[UnderBracket]0, \(-2\)], 
              v\[UnderBracket]Subscript\[UnderBracket]0], 
            Times[\(-252\), 
              Power[r\[UnderBracket]Subscript\[UnderBracket]0, \(-3\)], 
              v\[UnderBracket]Subscript\[UnderBracket]0], 
            Times[1113, 
              Power[r\[UnderBracket]Subscript\[UnderBracket]0, \(-4\)], 
              v\[UnderBracket]Subscript\[UnderBracket]0]], 0, 5, 1]\),
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output"]
}, Closed]],

Cell[TextData[{
  "A ",
  StyleBox["SeriesData", "InlineInput",
    FontWeight->"Bold"],
  " object is converted to an ordinary algebraic expression using ",
  ButtonBox["Normal",
    ButtonStyle->"RefGuideLink"],
  StyleBox["[", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["SeriesDataObject", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["]", "InlineInput",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Normal[vSeries]\)], "Input"],

Cell[BoxData[
    \(\(-v\_0\) + \(1113\ \((r - r\_0)\)\^4\ v\_0\)\/r\_0\%4 - \(252\ \((r - \
r\_0)\)\^3\ v\_0\)\/r\_0\%3 + \(36\ \((r - r\_0)\)\^2\ v\_0\)\/r\_0\%2\)], \
"Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullForm[Normal[vSeries]]\)], "Input"],

Cell[BoxData[
    TagBox[
      StyleBox[\(Plus[
          Times[\(-1\), v\[UnderBracket]Subscript\[UnderBracket]0], 
          Times[1113, 
            Power[Plus[r, 
                Times[\(-1\), r\[UnderBracket]Subscript\[UnderBracket]0]], 
              4], Power[r\[UnderBracket]Subscript\[UnderBracket]0, \(-4\)], 
            v\[UnderBracket]Subscript\[UnderBracket]0], 
          Times[\(-252\), 
            Power[Plus[r, 
                Times[\(-1\), r\[UnderBracket]Subscript\[UnderBracket]0]], 
              3], Power[r\[UnderBracket]Subscript\[UnderBracket]0, \(-3\)], 
            v\[UnderBracket]Subscript\[UnderBracket]0], 
          Times[36, 
            Power[Plus[r, 
                Times[\(-1\), r\[UnderBracket]Subscript\[UnderBracket]0]], 
              2], Power[r\[UnderBracket]Subscript\[UnderBracket]0, \(-2\)], 
            v\[UnderBracket]Subscript\[UnderBracket]0]]\),
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output"]
}, Closed]],

Cell[TextData[{
  "The coefficient of the term with order ",
  StyleBox["n",
    FontSlant->"Italic"],
  " is selected by ",
  ButtonBox["SeriesCoefficient",
    ButtonStyle->"RefGuideLink"],
  StyleBox["[", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["series,n", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["]", "InlineInput",
    FontWeight->"Bold"],
  ".  Thus, in this case the coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`\((r - r\_0)\)\^3\)]],
  " is"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SeriesCoefficient[vSeries, 3]\)], "Input"],

Cell[BoxData[
    \(\(-\(\(252\ v\_0\)\/r\_0\%3\)\)\)], "Output"]
}, Closed]],

Cell[TextData[
"Let U[y]=Tanh[y] or U[\[Tau]]=Tanh[1/\[Tau]] be two representations of the \
same function.  Compare the Taylor expansion of U[y] for small y with the \
Taylor expansion of U[\[Tau]] for large \[Tau] (expand about \[Infinity])."], 
  "Exercise"],

Cell[TextData[{
  "Use series expansions to characterize the behavior of ",
  Cell[BoxData[
      \(TraditionalForm\`f[z] = 1 - z\/\@\(z\^2 + R\^2\)\)]],
  " for both small and large values of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`R > 0\)]],
  ".  Compare these approximations with the original function graphically and \
describe their regions of validity.  How does one obtain a useful \
approximation for ",
  Cell[BoxData[
      \(TraditionalForm\`z \[TildeTilde] R\)]],
  "?"
}], "Exercise"]
}, Closed]],

Cell[CellGroupData[{

Cell["Singularities", "Subsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will often be able to provide useful expansions near singularities.  \
Consider the familiar function ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma][x]\)]],
  " with singularities for negative integers."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gamma[\(-5\)]\)], "Input"],

Cell[BoxData[
    \(ComplexInfinity\)], "Output"]
}, Closed]],

Cell[TextData[{
  "If a function ",
  Cell[BoxData[
      \(TraditionalForm\`f[x]\)]],
  " has a simple pole at ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_0\)]],
  ", the power series takes the form"
}], "Text"],

Cell[BoxData[
    \(f[x] \[TildeTilde] \ 
      R\/\(x - x\_0\) + \ 
        a\_0 + \ \(a\_1\) \((x - 
              x\_0)\)\  + \ \[CenterEllipsis]\)], "DisplayFormula",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " is the residue of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  ".  Thus, for this function we find"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Series[Gamma[x], {x, \(-5\), 2}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\(-\(1\/\(120\ \((x + 5)\)\)\)\), 
        "+", \((\(-\(137\/7200\)\) + EulerGamma\/120)\), 
        "+", \(\((\(-\(12019\/432000\)\) + \(137\ EulerGamma\)\/7200 + 
              1\/240\ \((\(-EulerGamma\^2\) - \[Pi]\^2\/6)\))\)\ \((x + 
              5)\)\), "+", \(\((\(-\(874853\/25920000\)\) + \(12019\ \
EulerGamma\)\/432000 - \(137\ \((EulerGamma\^2 + \[Pi]\^2\/6)\)\)\/14400 + 
              1\/720\ \((EulerGamma\^3 + \(EulerGamma\ \[Pi]\^2\)\/2 - 
                    PolyGamma[2, 1])\))\)\ \((x + 5)\)\^2\), "+", 
        InterpretationBox[\(O[x + 5]\^3\),
          SeriesData[ x, -5, {}, -1, 3, 1],
          Editable->False]}],
      SeriesData[ x, -5, {
        Rational[ -1, 120], 
        Plus[ 
          Rational[ -137, 7200], 
          Times[ 
            Rational[ 1, 120], EulerGamma]], 
        Plus[ 
          Rational[ -12019, 432000], 
          Times[ 
            Rational[ 137, 7200], EulerGamma], 
          Times[ 
            Rational[ 1, 240], 
            Plus[ 
              Times[ -1, 
                Power[ EulerGamma, 2]], 
              Times[ 
                Rational[ -1, 6], 
                Power[ Pi, 2]]]]], 
        Plus[ 
          Rational[ -874853, 25920000], 
          Times[ 
            Rational[ 12019, 432000], EulerGamma], 
          Times[ 
            Rational[ -137, 14400], 
            Plus[ 
              Power[ EulerGamma, 2], 
              Times[ 
                Rational[ 1, 6], 
                Power[ Pi, 2]]]], 
          Times[ 
            Rational[ 1, 720], 
            Plus[ 
              Power[ EulerGamma, 3], 
              Times[ 
                Rational[ 1, 2], EulerGamma, 
                Power[ Pi, 2]], 
              Times[ -1, 
                PolyGamma[ 2, 1]]]]]}, -1, 3, 1],
      Editable->False]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Residue[Gamma[x], {x, \(-5\)}]\)], "Input"],

Cell[BoxData[
    \(\(-\(1\/120\)\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  StyleBox["Series", "InlineInput"],
  StyleBox[" sometimes returns an expansion in fractional powers",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Series[Sin[\@x], {x, 0, 2}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\(\@x\), "-", \(x\^\(3/2\)\/6\), "+", 
        InterpretationBox[\(O[x]\^\(5/2\)\),
          SeriesData[ x, 0, {}, 1, 5, 2],
          Editable->False]}],
      SeriesData[ x, 0, {1, 0, 
        Rational[ -1, 6]}, 1, 5, 2],
      Editable->False]], "Output"]
}, Closed]],

Cell["or will isolate other characteristic behaviors.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Series[PolyLog[2, z], {z, 1, 2}] // Normal\) // Simplify\)], "Input"],

Cell[BoxData[
    \(1\/12\ \((2\ \[Pi]\^2 - 3\ \((\(-1\) + z)\)\^2 + 
          6\ \((3 - 4\ z + z\^2)\)\ \((\(-1\) + \[ImaginaryI]\ \[Pi] - 
                2\ \[ImaginaryI]\ \[Pi]\ Ceiling[
                    Arg[\(-1\) + z]\/\(2\ \[Pi]\)] + 
                Log[\(-1\) + z])\))\)\)], "Output"]
}, Closed]],

Cell["\<\
Useful information can often be obtained even near an essential \
singularity.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Series[Exp[Sin[x]], {x, \[Infinity], 2}]\)], "Input"],

Cell[BoxData[
    RowBox[{\(Series::"esss"\), \(\(:\)\(\ \)\), "\<\"Essential singularity \
encountered in \\!\\(Sin[\\(\\(\\*InterpretationBox[\\(1\\/\\(1\\/x\\) + \
\\*InterpretationBox[\\(\\(O[\\(\\(1\\/x\\)\\)]\\)\\^3\\), SeriesData[x, \
DirectedInfinity[1], List[], -1, 3, 1], Rule[Editable, False]]\\), \
SeriesData[x, DirectedInfinity[1], List[1], -1, 3, 1], Rule[Editable, False]]\
\\)\\)]\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Series::esss\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Series::"esss"\), \(\(:\)\(\ \)\), "\<\"Essential singularity \
encountered in \\!\\(Sin[\\(\\(\\*InterpretationBox[\\(1\\/x + \
\\*InterpretationBox[\\(\\(O[x]\\)\\^3\\), SeriesData[x, 0, List[], -1, 3, \
1], Rule[Editable, False]]\\), SeriesData[x, 0, List[1], -1, 3, 1], \
Rule[Editable, False]]\\)\\)]\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Series::esss\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(\[ExponentialE]\^Sin[x]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell["Limit[Exp[Sin[x]], x\[Rule]\[Infinity]]", "Input",
  CellTags->"S3.6.8"],

Cell[BoxData[
    \(Interval[{1\/\[ExponentialE], \[ExponentialE]}]\)], "Output",
  CellTags->"S3.6.8"]
}, Closed]],

Cell["\<\
Here we are told that even though this function oscillates wildly near its \
essential singularity, the range of oscillation is confined to a finite \
interval.  \
\>", "Text"],

Cell["Directional limits can be obtained for some functions.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[1\/x, x \[Rule] 0, Direction \[Rule] \(-1\)]\)], "Input"],

Cell[BoxData[
    \(\[Infinity]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[1\/x, x \[Rule] 0, Direction \[Rule] \(+1\)]\)], "Input"],

Cell[BoxData[
    \(\(-\[Infinity]\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Find the residue of ",
  Cell[BoxData[
      \(TraditionalForm\`x\ \(tan(x)\)\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/2\)]],
  "."
}], "Exercise"],

Cell[TextData[{
  "Evaluate the limit of ",
  Cell[BoxData[
      \(TraditionalForm\`Tanh[1\/x]\)]],
  " as x\[Rule]0.  How does the result depend upon direction?"
}], "Exercise"],

Cell["\<\
Compare the behaviors of BesselJ[2,z] and BesselK[2,z] as \
z\[Rule]\[Infinity].\
\>", "Exercise"]
}, Closed]],

Cell[CellGroupData[{

Cell["Multivariate power series", "Subsection"],

Cell[TextData[{
  "Series[",
  StyleBox["f, ",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"{", 
              RowBox[{
                StyleBox["x",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                FormBox[
                  
                  SubscriptBox["\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"x\\\\\\\"\\\
\", \\\"TI\\\"]\\)\"\>", "0"],
                  "TraditionalForm"], 
                StyleBox[",",
                  "MR"], " ", 
                FormBox[
                  
                  SubscriptBox["\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\
\", \\\"TI\\\"]\\)\"\>", "x"],
                  "TraditionalForm"]}], 
              FormBox["}",
                "TraditionalForm"]}],
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[",",
            "MR",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox[
            RowBox[{
              FormBox["{",
                "TraditionalForm"], 
              RowBox[{
                StyleBox["y",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                FormBox[
                  
                  SubscriptBox["\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"y\\\\\\\"\\\
\", \\\"TI\\\"]\\)\"\>", "0"],
                  "TraditionalForm"], 
                StyleBox[",",
                  "MR"], " ", 
                FormBox[
                  
                  SubscriptBox["\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\
\", \\\"TI\\\"]\\)\"\>", "y"],
                  "TraditionalForm"]}], 
              FormBox["}",
                "TraditionalForm"]}],
            FontWeight->"Plain",
            FontSlant->"Italic"]}], TraditionalForm]]],
  " ]",
  StyleBox[" expands a function of two variables with respect to ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`x\)],
    FontWeight->"Plain"],
  " ",
  StyleBox["first, then with respect to ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox["y",
          FontWeight->"Plain"], TraditionalForm]]],
  ".  ",
  StyleBox["Additional variables can be added to the sequence also.  Note \
that the reference guide describes the order of these operations incorrectly; \
the net result is usually the same in either order, but the presentation \
depends upon order.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Series[Log[1 - x\ y], {x, 1, 3}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\(Log[1 - y]\), "+", \(\(y\ \((x - 1)\)\)\/\(\(-1\) + y\)\), 
        "-", \(\(y\^2\ \((x - 1)\)\^2\)\/\(2\ \((1 - y)\)\^2\)\), 
        "-", \(\(y\^3\ \((x - 1)\)\^3\)\/\(3\ \((1 - y)\)\^3\)\), "+", 
        InterpretationBox[\(O[x - 1]\^4\),
          SeriesData[ x, 1, {}, 0, 4, 1],
          Editable->False]}],
      SeriesData[ x, 1, {
        Log[ 
          Plus[ 1, 
            Times[ -1, y]]], 
        Times[ 
          Power[ 
            Plus[ -1, y], -1], y], 
        Times[ 
          Rational[ -1, 2], 
          Power[ 
            Plus[ 1, 
              Times[ -1, y]], -2], 
          Power[ y, 2]], 
        Times[ 
          Rational[ -1, 3], 
          Power[ 
            Plus[ 1, 
              Times[ -1, y]], -3], 
          Power[ y, 3]]}, 0, 4, 1],
      Editable->False]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Series[%, {y, 0, 3}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{\(-y\), "-", \(y\^2\/2\), "-", \(y\^3\/3\), "+", 
              InterpretationBox[\(O[y]\^4\),
                SeriesData[ y, 0, {}, 1, 4, 1],
                Editable->False]}],
            SeriesData[ y, 0, {-1, 
              Rational[ -1, 2], 
              Rational[ -1, 3]}, 1, 4, 1],
            Editable->False], ")"}], "+", 
        RowBox[{
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{\(-y\), "-", \(y\^2\), "-", \(y\^3\), "+", 
                InterpretationBox[\(O[y]\^4\),
                  SeriesData[ y, 0, {}, 1, 4, 1],
                  Editable->False]}],
              SeriesData[ y, 0, {-1, -1, -1}, 1, 4, 1],
              Editable->False], ")"}], " ", \((x - 1)\)}], "+", 
        RowBox[{
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{\(-\(y\^2\/2\)\), "-", \(y\^3\), "+", 
                InterpretationBox[\(O[y]\^4\),
                  SeriesData[ y, 0, {}, 2, 4, 1],
                  Editable->False]}],
              SeriesData[ y, 0, {
                Rational[ -1, 2], -1}, 2, 4, 1],
              Editable->False], ")"}], " ", \(\((x - 1)\)\^2\)}], "+", 
        RowBox[{
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{\(-\(y\^3\/3\)\), "+", 
                InterpretationBox[\(O[y]\^4\),
                  SeriesData[ y, 0, {}, 3, 4, 1],
                  Editable->False]}],
              SeriesData[ y, 0, {
                Rational[ -1, 3]}, 3, 4, 1],
              Editable->False], ")"}], " ", \(\((x - 1)\)\^3\)}], "+", 
        InterpretationBox[\(O[x - 1]\^4\),
          SeriesData[ x, 1, {}, 0, 4, 1],
          Editable->False]}],
      SeriesData[ x, 1, {
        SeriesData[ y, 0, {-1, 
          Rational[ -1, 2], 
          Rational[ -1, 3]}, 1, 4, 1], 
        SeriesData[ y, 0, {-1, -1, -1}, 1, 4, 1], 
        SeriesData[ y, 0, {
          Rational[ -1, 2], -1}, 2, 4, 1], 
        SeriesData[ y, 0, {
          Rational[ -1, 3]}, 3, 4, 1]}, 0, 4, 1],
      Editable->False]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(xySeries\  = Series[Log[1 - x\ y], {x, 1, 3}, {y, 0, 3}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{\(-y\), "-", \(y\^2\/2\), "-", \(y\^3\/3\), "+", 
              InterpretationBox[\(O[y]\^4\),
                SeriesData[ y, 0, {}, 1, 4, 1],
                Editable->False]}],
            SeriesData[ y, 0, {-1, 
              Rational[ -1, 2], 
              Rational[ -1, 3]}, 1, 4, 1],
            Editable->False], ")"}], "+", 
        RowBox[{
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{\(-y\), "-", \(y\^2\), "-", \(y\^3\), "+", 
                InterpretationBox[\(O[y]\^4\),
                  SeriesData[ y, 0, {}, 1, 4, 1],
                  Editable->False]}],
              SeriesData[ y, 0, {-1, -1, -1}, 1, 4, 1],
              Editable->False], ")"}], " ", \((x - 1)\)}], "+", 
        RowBox[{
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{\(-\(y\^2\/2\)\), "-", \(y\^3\), "+", 
                InterpretationBox[\(O[y]\^4\),
                  SeriesData[ y, 0, {}, 2, 4, 1],
                  Editable->False]}],
              SeriesData[ y, 0, {
                Rational[ -1, 2], -1}, 2, 4, 1],
              Editable->False], ")"}], " ", \(\((x - 1)\)\^2\)}], "+", 
        RowBox[{
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{\(-\(y\^3\/3\)\), "+", 
                InterpretationBox[\(O[y]\^4\),
                  SeriesData[ y, 0, {}, 3, 4, 1],
                  Editable->False]}],
              SeriesData[ y, 0, {
                Rational[ -1, 3]}, 3, 4, 1],
              Editable->False], ")"}], " ", \(\((x - 1)\)\^3\)}], "+", 
        InterpretationBox[\(O[x - 1]\^4\),
          SeriesData[ x, 1, {}, 0, 4, 1],
          Editable->False]}],
      SeriesData[ x, 1, {
        SeriesData[ y, 0, {-1, 
          Rational[ -1, 2], 
          Rational[ -1, 3]}, 1, 4, 1], 
        SeriesData[ y, 0, {-1, -1, -1}, 1, 4, 1], 
        SeriesData[ y, 0, {
          Rational[ -1, 2], -1}, 2, 4, 1], 
        SeriesData[ y, 0, {
          Rational[ -1, 3]}, 3, 4, 1]}, 0, 4, 1],
      Editable->False]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(yxSeries = Series[Log[1 - x\ y], {y, 0, 3}, {x, 1, 3}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{\(-1\), "-", \((x - 1)\), "+", 
                InterpretationBox[\(O[x - 1]\^4\),
                  SeriesData[ x, 1, {}, 0, 4, 1],
                  Editable->False]}],
              SeriesData[ x, 1, {-1, -1}, 0, 4, 1],
              Editable->False], ")"}], " ", "y"}], "+", 
        RowBox[{
          RowBox[{"(", 
            InterpretationBox[
              
              RowBox[{\(-\(1\/2\)\), "-", \((x - 1)\), 
                "-", \(1\/2\ \((x - 1)\)\^2\), "+", 
                InterpretationBox[\(O[x - 1]\^4\),
                  SeriesData[ x, 1, {}, 0, 4, 1],
                  Editable->False]}],
              SeriesData[ x, 1, {
                Rational[ -1, 2], -1, 
                Rational[ -1, 2]}, 0, 4, 1],
              Editable->False], ")"}], " ", \(y\^2\)}], "+", 
        RowBox[{
          RowBox[{"(", 
            InterpretationBox[
              
              RowBox[{\(-\(1\/3\)\), "-", \((x - 1)\), 
                "-", \(\((x - 1)\)\^2\), "-", \(1\/3\ \((x - 1)\)\^3\), "+", 
                InterpretationBox[\(O[x - 1]\^4\),
                  SeriesData[ x, 1, {}, 0, 4, 1],
                  Editable->False]}],
              SeriesData[ x, 1, {
                Rational[ -1, 3], -1, -1, 
                Rational[ -1, 3]}, 0, 4, 1],
              Editable->False], ")"}], " ", \(y\^3\)}], "+", 
        InterpretationBox[\(O[y]\^4\),
          SeriesData[ y, 0, {}, 1, 4, 1],
          Editable->False]}],
      SeriesData[ y, 0, {
        SeriesData[ x, 1, {-1, -1}, 0, 4, 1], 
        SeriesData[ x, 1, {
          Rational[ -1, 2], -1, 
          Rational[ -1, 2]}, 0, 4, 1], 
        SeriesData[ x, 1, {
          Rational[ -1, 3], -1, -1, 
          Rational[ -1, 3]}, 0, 4, 1]}, 1, 4, 1],
      Editable->False]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Normal[xySeries] - Normal[yxSeries] // Simplify\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Symbolic integration", "Section"],

Cell[CellGroupData[{

Cell["Symbolic integration in one dimension", "Subsection"],

Cell[TextData[{
  "The basic syntax for symbolic one-dimensional integration is ",
  ButtonBox["Integrate",
    ButtonStyle->"RefGuideLink"],
  StyleBox["[", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["f[x],x", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["]", "InlineInput",
    FontWeight->"Bold"],
  " for an indefinite integral or ",
  StyleBox["Integrate[", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["f[x],{x,a,b}", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["]", "InlineInput",
    FontWeight->"Bold"],
  " for a definite integral over the range ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  ".  The traditional forms can be entered from the ",
  StyleBox["BasicInput", "InlineInput",
    FontWeight->"Bold"],
  " palette as"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[Integral]f[x] \[DifferentialD]x\)], "DisplayFormula",\

  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell["for indefinite, or", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[Integral]\_a\%b f[
          x] \[DifferentialD]x\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "for definite integrals, where ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\)]],
  " is not an ordinary ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " but a differential operator that can be entered as \[EscapeKey]dd\
\[EscapeKey].  Most integrals one might find in standard tables will be \
evaluated successfully, although it is usually prudent to simplify integrands \
before requesting integration."
}], "Text"],

Cell[CellGroupData[{

Cell["Indefinite integrals", "Subsubsection"],

Cell["Notice that indefinite integrals", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\(x\^n\) \(a\^x\) \[DifferentialD]x\)], "Input"],

Cell[BoxData[
    \(\(-x\^\(1 + n\)\)\ Gamma[
        1 + n, \(-x\)\ Log[
            a]]\ \((\(-x\)\ Log[a])\)\^\(\(-1\) - n\)\)], "Output"]
}, Closed]],

Cell["\<\
are returned without constants of integration and can be checked easily by \
differentiation\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[%, x] // Simplify\)], "Input"],

Cell[BoxData[
    \(a\^x\ x\^n\)], "Output"]
}, Closed]],

Cell[TextData[{
  "although simplification is often needed to recover the original form.  \
Also notice that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " makes no ",
  StyleBox["a priori",
    FontSlant->"Italic"],
  " assumptions about the parameters involved in indefinite integrals"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]Exp[\(-a\)\ x] Cos[b\ x] \[DifferentialD]x\  // 
      Simplify\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-a\)\ x\)\ \((\(-a\)\ Cos[b\ x] + b\ Sin[b\ \
x])\)\)\/\(a\^2 + b\^2\)\)], "Output"]
}, Closed]],

Cell["\<\
so that the results apply to real or complex parameters.  On the other hand, \
it does not check special cases either.  Thus, the following integral \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\(x\^\[Mu]\) \[DifferentialD]x\)], "Input"],

Cell[BoxData[
    \(x\^\(1 + \[Mu]\)\/\(1 + \[Mu]\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "does not appear to be correct if the parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\)]],
  " happens to be ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  ".  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " assumes that parameters in indefinite integrals should be interpreted ",
  StyleBox["generically",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[TextData[{
  "Consider the generic indefinite integral\n ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Integral]\_a\%b\( x\^\[Mu]\) \[DifferentialD]x\), "=", 
          FormBox[\(\(b\^\(\[Mu] + 1\) - a\^\(\[Mu] + 1\)\)\/\(\[Mu] + 1\)\),
            "TraditionalForm"]}], TraditionalForm]]],
  "  \n for ",
  Cell[BoxData[
      \(TraditionalForm\`b > a > 0\)]],
  ".  Show that the correct result for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu] = \(-1\)\)]],
  " can be obtained by series expansion with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\)]],
  ".\n"
}], "Exercise"],

Cell[TextData[{
  "Evaluate and check the following integrals.\na) ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\(x\^m\/\(a + 
                x\^n\)\) \[DifferentialD]x\)]],
  " \t\t\nb) \[Integral] BesselJ[n,x] BesselJ[m,x] x \[DifferentialD]x"
}], "Exercise"]
}, Closed]],

Cell[CellGroupData[{

Cell["Definite integrals", "Subsubsection"],

Cell["\<\
Definite integrals with symbolic parameters in the integrand often return a \
conditional statement rather than a unique result.  Thus,\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_0\%1\( x\^n\) \[DifferentialD]x\)], "Input"],

Cell[BoxData[
    \(If[Re[n] > \(-1\), 1\/\(1 + n\), 
      Integrate[x\^n, {x, 0, 1}, 
        Assumptions \[Rule] Re[n] \[LessEqual] \(-1\)]]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "correctly restricts its evaluation to exponents greater than ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  ".   Similarly,"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_0\%\[Infinity] Exp[a\ x] \[DifferentialD]x\)], "Input",
  CellTags->"Integrate"],

Cell[BoxData[
    \(If[Re[a] < 0, \(-\(1\/a\)\), 
      Integrate[\[ExponentialE]\^\(a\ x\), {x, 0, \[Infinity]}, 
        Assumptions \[Rule] Re[a] \[GreaterEqual] 0]]\)], "Output",
  CellTags->"Integrate"]
}, Closed]],

Cell[TextData[{
  "can be evaluated only when the parameter ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " has negative real part.  If we happen to know that the parameter will \
always satisfy this condition, we can incorporate this assumption in the \
integration command using the option ",
  StyleBox["Assumptions", "InlineInput",
    FontWeight->"Bold"],
  " as follows."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[Exp[a\ x], {x, 0, \[Infinity]}, 
      Assumptions \[Rule] Re[a] < 0]\)], "Input"],

Cell[BoxData[
    \(\(-\(1\/a\)\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Assumptions can be supplied to typeset integrals using ",
  ButtonBox["Assuming",
    ButtonStyle->"RefGuideLink"],
  StyleBox["[", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["assumptions,expression", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["]", "InlineInput",
    FontWeight->"Bold"],
  " where ",
  StyleBox["assumptions", "InlineInput",
    FontWeight->"Bold"],
  " is a list of assumptions to be used in evaluation of an expression.  \
Thus, the preceding result can also be obtained as follows."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Assuming[
      Re[a] < 0, \[Integral]\_0\%\[Infinity] Exp[
            a\ x] \[DifferentialD]x]\)], "Input"],

Cell[BoxData[
    \(\(-\(1\/a\)\)\)], "Output"]
}, Closed]],

Cell["\<\
Alternatively, a reckless person could disable conditional-testing using\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[Exp[a\ x], {x, 0, \[Infinity]}, 
      GenerateConditions \[Rule] False]\)], "Input"],

Cell[BoxData[
    \(\(-\(1\/a\)\)\)], "Output"]
}, Closed]],

Cell["\<\
but that practice is apt to generate nonsense and is strongly discouraged \
unless you are certain that the conditions would be satisfied for your \
parameters.\
\>", "Text"],

Cell["\<\
Definite integrals with several parameters are often expressed in terms of \
composite conditions:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(result = 
      Integrate[
        Exp[\(-a\)\ x]\/\(b\^2 + x\^2\), {x, 0, \[Infinity]}]\)], "Input"],

Cell[BoxData[
    \(If[Re[a] > 
          0 && \((Im[b\^2] \[NotEqual] 0 || 
            Re[b\^2] \[GreaterEqual] 0)\) && \((Re[b] \[NotEqual] 0 || 
            Im[b] \[Equal] 0)\), 
      1\/2\ \@\(1\/b\^2\)\ \((2\ CosIntegral[a\/\@\(1\/b\^2\)]\ Sin[
                a\ \@\(1\/b\^2\)\ b\^2] + 
            Cos[a\ \@\(1\/b\^2\)\ b\^2]\ \((\[Pi] - 
                  2\ SinIntegral[a\/\@\(1\/b\^2\)])\))\), 
      Integrate[\[ExponentialE]\^\(\(-a\)\ x\)\/\(b\^2 + x\^2\), {x, 
          0, \[Infinity]}, 
        Assumptions \[Rule] \((Im[b\^2] \[Equal] 0 && 
                Re[b\^2] < 0)\) || \((Re[b] \[Equal] 0 && 
                Im[b] \[NotEqual] 0)\) || Re[a] \[LessEqual] 0]]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Assuming that the conditions are satisfied, the desired integral can be \
extracted from the second part of ",
  StyleBox["result", "InlineInput",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(result\[LeftDoubleBracket]2\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \(1\/2\ \@\(1\/b\^2\)\ \((2\ CosIntegral[a\/\@\(1\/b\^2\)]\ Sin[
              a\ \@\(1\/b\^2\)\ b\^2] + 
          Cos[a\ \@\(1\/b\^2\)\ b\^2]\ \((\[Pi] - 
                2\ SinIntegral[a\/\@\(1\/b\^2\)])\))\)\)], "Output"]
}, Closed]],

Cell["\<\
In previous versions definite integrals with symbolic limits were treated in \
much the same manner as indefinite integrals and, hence, were evaluated \
without regard to restrictions upon the values of their parameters or limits. \
 In version 5 we obtain a compilation of possibilities according to the \
nature of the symbolic limits.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_a\%b\( x\^n\) \[DifferentialD]x\)], "Input"],

Cell[BoxData[
    \(\((\(-a\) + b)\)\ If[
        Re[a\/\(a - b\)] \[GreaterEqual] 1 || 
          Re[a\/\(\(-a\) + b\)] \[GreaterEqual] 0 || 
          Im[a\/\(\(-a\) + b\)] \[NotEqual] 
            0, \(a\^\(1 + n\) - b\^\(1 + n\)\)\/\(\((a - b)\)\ \((1 + n)\)\), 
        Integrate[\((a + \((\(-a\) + b)\)\ x)\)\^n, {x, 0, 1}, 
          Assumptions \[Rule] \(! \((Re[a\/\(a - b\)] \[GreaterEqual] 1 || 
                  Re[a\/\(\(-a\) + b\)] \[GreaterEqual] 0 || 
                  Im[a\/\(\(-a\) + b\)] \[NotEqual] 0)\)\)]]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "However, this procedure does not appear to examine the nature of the \
parameters in the integrand and is not correct for ",
  Cell[BoxData[
      \(TraditionalForm\`n = \(-1\)\)]],
  " even when the limits are real. "
}], "Text"],

Cell[TextData[{
  "Compare\na) ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Integral]\_0\%\[Pi]\),
          "InlineInput"], 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(Cos[t]\),
              "InlineInput"], \(3\/2\)], 
          StyleBox[\(\[DifferentialD]t\),
            "InlineInput"]}]}]]],
  "\nb) ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Integral]\_0\%\[Pi]\),
          "InlineInput"], 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(Cos[t]\),
              "InlineInput"], \(n + 1\/2\)], 
          StyleBox[\(\[DifferentialD]t\),
            "InlineInput"]}]}]]]
}], "Exercise"],

Cell[TextData[{
  "Evaluate the following integrals.\na) ",
  Cell[BoxData[
      StyleBox[\(\[Integral]\_0\%\[Infinity]\(\( 
                  x\ BesselJ[n, 
                    x]\)\/\((1 + x\^2)\)\^\(m + 1\/2\)\) \[DifferentialD]x\),
        "InlineInput"]]],
  " \t"
}], "Exercise"],

Cell[TextData[{
  "Evaluate the following integrals.\na) ",
  Cell[BoxData[
      StyleBox[\(\[Integral]\_0\%\(2\ \[Pi]\)Cos[
              z\ Sin[t]] \[DifferentialD]t\),
        "InlineInput"]]],
  "\t\nb) ",
  Cell[BoxData[
      StyleBox[\(\[Integral]\_0\%\(2\ \[Pi]\)Exp[
              z\ Sin[t]] \[DifferentialD]t\),
        "InlineInput"]]],
  "\n"
}], "Exercise"],

Cell[TextData[{
  "Evaluate ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\[Omega]D\( \[Omega]\^3\/\(\
\[ExponentialE]\^\(\[Omega]/T\) - 1\)\) \[DifferentialD]\[Omega]\)]],
  " which occurs in the Debye theory of lattice vibrations."
}], "Exercise"],

Cell[TextData[{
  "Evaluate ",
  Cell[BoxData[
      \(\[Integral]\_0\%\[Infinity]\(\( \[Omega]\^4\) \[ExponentialE]\^\
\[Omega]\)\/\((\[ExponentialE]\^\[Omega] - 1)\)\^2\)]],
  "."
}], "Exercise"],

Cell["rms radius for spherical distribution (symbolic)", "Exercise"],

Cell["\<\
The root-mean-square (rms) radius for a spherically symmetric radial \
distribution function \[Rho](r) is defined as\
\>", "ExerciseText"],

Cell[BoxData[
    \(TraditionalForm\`rms = \@\(\(\[Integral]\_0\%\[Infinity] \[Rho]\ \(r\^4\
\) \[DifferentialD]r\)\/\(\[Integral]\_0\%\[Infinity] \[Rho]\ \(r\^2\) \
\[DifferentialD]r\)\)\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "Write a function which evaluates the rms radius for an arbitrary \
distribution symbolically.  Test using a uniform distribution for ",
  Cell[BoxData[
      \(TraditionalForm\`r \[LessEqual] 1\)]],
  ".  Then evaluate the rms radius for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = Exp[\(-\((r/a)\)\^2\)]\)]],
  "."
}], "ExerciseText",
  CellDingbat->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Principal value", "Subsubsection"],

Cell[TextData[{
  "In general one must treat singularities of an integrand with great care.  \
For the present purposes it suffices to mention that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " provides an option for the Cauchy principal value in which a small \
interval surrounding a singularity is excised and the integral is evaluated \
in the limit that the excluded interval shrinks to zero."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pv = 
      Integrate[
        Exp[x]\/\(\((x + 1)\) \((x + 2)\)\), {x, \(-\[Infinity]\), 0}, 
        PrincipalValue \[Rule] True]\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\ ExpIntegralEi[1] - ExpIntegralEi[2]\)\/\
\[ExponentialE]\^2\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pv // N\)], "Input"],

Cell[BoxData[
    \(0.026692173444992785`\)], "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Line integrals", "Subsection"],

Cell["\<\
A line integral evaluates and integrates a function along a specified path \
through a multidimensional space, returning a scalar result.  Here we \
consider two types of line integral.  The integral of scalar function against \
the path length for a curve in two dimensions takes the form\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[Integral]\_C f[x, 
          y] \[DifferentialD]s\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "where C denotes a curve and ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[DifferentialD]s = \@\(\((\[DifferentialD]x)\)\^2 + \((\
\[DifferentialD]y)\)\^2\)\),
          FontWeight->"Plain"], TraditionalForm]], "InlineInput",
    Evaluatable->False],
  StyleBox[" ", "InlineInput"],
  "represents the path length along the curve.  The curve is generally \
represented by the parametric equations ",
  Cell[BoxData[
      \(TraditionalForm\`C = {x \[Rule] x[t], y \[Rule] y[t]}\)]],
  " ",
  StyleBox["such that the path length becomes ",
    Evaluatable->False],
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]s = \[DifferentialD]t \@\(\((\
\[DifferentialD]x\/\[DifferentialD]t)\)\^2 + \((\[DifferentialD]y\/\
\[DifferentialD]t)\)\^2\)\)], "InlineInput",
    Evaluatable->False,
    FontWeight->"Plain"],
  ".  For example, if ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " represents mass density, an integral of this type could be used to \
determine the total mass of a rope with nonuniform density or cross-sectional \
area.  "
}], "Text"],

Cell["\<\
Similarly, the component of a vector field that is parallel to a curve is \
integrated using\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[Integral]\_C f\&\[RightVector][x, 
          y] . \[DifferentialD]s\&\[RightVector]\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]s\&\[RightVector] = \
\[DifferentialD]t {\[DifferentialD]x\/\[DifferentialD]t, \[DifferentialD]y\/\
\[DifferentialD]t}\)], "InlineInput",
    Evaluatable->False,
    FontWeight->"Plain"],
  StyleBox[" ", "InlineInput"],
  "is the differential displacement along the curve.  For example, the work \
performed by a force ",
  Cell[BoxData[
      \(TraditionalForm\`f\&\[RightVector]\)]],
  " that acts on a particle whose trajectory is described by the parametric \
curve ",
  Cell[BoxData[
      \(TraditionalForm\`C = {x \[Rule] x[t], y \[Rule] y[t]}\)]],
  " ",
  StyleBox["is given by an integral of this type.",
    Evaluatable->False],
  "\nThe following function evaluates these types of path integrals \
symbolically.  Here we present a relatively simple implementation and do not \
attempt to cover all possible methods for specifying the function or path.  \
The path-integration function can be generalized later if needed.  We assume \
that the function is an implicit function of the two variables represented by \
patterns ",
  StyleBox["x_", "InlineInput",
    FontWeight->"Bold"],
  " and ",
  StyleBox["y_", "InlineInput",
    FontWeight->"Bold"],
  ".  The path is defined using a pattern argument ",
  StyleBox["path:{", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["pattern rules", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["}", "InlineInput",
    FontWeight->"Bold"],
  " in which the pattern rules are a list of rewrite rules of the form ",
  StyleBox["x_\[Rule]u_", "InlineInput",
    FontWeight->"Bold"],
  " that replace the variable on the lhs by the pattern on the rhs; hence, \
blank patterns are used on both sides of the arrow.  The parameter defining \
the progress along the curve is given by ",
  StyleBox["t_", "InlineInput",
    FontWeight->"Bold"],
  ".  Two versions are given, one for scalar functions and the other for \
vector functions in two dimensions.  Obviously, it is simple matter to \
generalize to arbitrary dimensionality."
}], "Text"],

Cell[BoxData[
    \(ClearAll[pathIntegrate]\)], "Input"],

Cell[BoxData[{
    \(\(pathIntegrate::usage = \
"\<pathIntegrate[f,{x\[Rule]u,y\[Rule]v},t,tmin,tmax,opts] evaluates the line \
integral of the scalar function f along a curve expressed as a parametric \
function of t. \n\n pathIntegrate[{fx,fy},{x\[Rule]u,y\[Rule]v},t,tmin,tmax] \
evaluates the line integral of the tangential component of a vector field \
along a curve expressed as a parametric function of t.\>";\)\n\t\t\n\t\t\), "\
\n", 
    \(\(\(pathIntegrate[f_ /; \((Not[VectorQ[f]])\), 
          path : {x_ \[Rule] u_, y_ \[Rule] v_}, t_, tmin_, tmax_, 
          opts___Rule]\  := 
        Integrate[
          f\ \[Sqrt]\((D[u, t]\^2 + D[v, t]\^2)\) /. path, {t, tmin, tmax}, 
          opts];\)\(\n\)
    \)\), "\n", 
    \(pathIntegrate[field : {f_, g_}, path : {x_ \[Rule] u_, y_ \[Rule] v_}, 
        t_, tmin_, tmax_, opts___Rule]\  := 
      Integrate[\((f\ D[u, t] + g\ D[v, t])\) /. path, {t, tmin, tmax}, 
        opts]\)}], "Input"],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pathIntegrate[1\/\(x\^2 + y\^2\), {x \[Rule] Cos[t], y \[Rule] Sin[t]}, 
      t, 0, 2  \[Pi]]\)], "Input"],

Cell[BoxData[
    \(2\ \[Pi]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pathIntegrate[1\/\(x\^2 + y\^2\), {x \[Rule] t, y \[Rule] t}, t, 1, 
      2]\)], "Input"],

Cell[BoxData[
    \(1\/\(2\ \@2\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pathIntegrate[1\/\(x\^2 + y\^2\), {x \[Rule] a\  + t, y \[Rule] b\ t}, 
      t, 0, 1, Assumptions \[Rule] {a \[Element] Reals, 
          b \[Element] Reals}]\)], "Input"],

Cell[BoxData[
    \(\@\(1 + b\^2\)\ If[
        1 + a \[Equal] 0 || 
          b \[NotEqual] 
            0 || \((1 + a \[LessEqual] 0 && \@\(\(-1\) - a\) \[GreaterEqual] 
                b && \@\(\(-1\) - a\) + b \[GreaterEqual] 0)\) || 
          a \[GreaterEqual] 
            0, \(\(-ArcCot[b]\) + ArcCot[\(a\ b\)\/\(1 + a + b\^2\)]\)\/\(a\ \
b\), Integrate[1\/\(b\^2\ t\^2 + \((a + t)\)\^2\), {t, 0, 1}, 
          Assumptions \[Rule] 
            a \[Element] Reals && b \[Element] Reals && b \[Equal] 0 && 
              a < 0 && 1 + a \[NotEqual] 
                0 && \((1 + a > 0 || \@\(\(-1\) - a\) < 
                    b || \@\(\(-1\) - a\) + b < 0)\)]]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pathIntegrate[{x\^2, y}, {x \[Rule] t, y \[Rule] t}, t, 0, 
      2]\)], "Input"],

Cell[BoxData[
    \(14\/3\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pathIntegrate[{x\^2, y}, {x \[Rule] 2  Sin[t], y \[Rule] 2  Sin[t]}, t, 
      0, \[Pi]\/2]\)], "Input"],

Cell[BoxData[
    \(14\/3\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pathIntegrate[{y, x}, {x \[Rule] a\ t\^n, y \[Rule] b\ t\^m}, t, 0, 
      1]\)], "Input"],

Cell[BoxData[
    \(If[Re[m + n] > 0, a\ b, 
      Integrate[a\ b\ \((m + n)\)\ t\^\(\(-1\) + m + n\), {t, 0, 1}, 
        Assumptions \[Rule] Re[m + n] \[LessEqual] 0]]\)], "Output"]
}, Closed]],

Cell["\<\
Write line integration functions applicable to arbitrary dimensionality.\
\>", "Exercise"],

Cell["Proper time", "Exercise"],

Cell[TextData[{
  "Proper time ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_C\[DifferentialD]\[Tau]\)]],
  " in special relativity is defined by a path length through space-time \
based upon the invariant interval ",
  Cell[BoxData[
      \(TraditionalForm
      \`\((\[DifferentialD]\[Tau])\)\^2 = \ 
        \((\[DifferentialD]t)\)\^2 - \((\[DifferentialD]x)\)\^2 - 
          \((\[DifferentialD]y)\)\^2 - \((\[DifferentialD]z)\)\^2\)]],
  ".  Write a function which computes the proper time for an arbitrary path \
in space-time.  One can show that the proper time measures the aging of a \
particle (or person) in its own rest frame.  However, the elapsed times for \
other observers who see the particle moving can be quite different.  Compare \
the proper times for the following two paths, which are relevant to the \
famous twin paradox.  Peter remains on earth while Paul travels at 99% of \
light speed away from earth for 25 earth years and then turns instantly and \
returns at the same speed.  Show that qualitatively similar results are \
obtained for more realistic itineraries (without incredible acceleration near \
the turn)."
}], "ExerciseText"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Multiple integrals", "Subsection"],

Cell["\<\
Multiple integrals are entered simply by replacing the integration variable \
(and limits) with a sequence of integration variables.  The integrals are \
evaluated from right to left, so that the integration limits for earlier \
variables can be functions of the later variables to define a region of \
integration that is not simply rectangular.  Thus,\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[f, x, y, xmin, xmax, ymin, ymax];\)\), "\[IndentingNewLine]", 
    \(Integrate[f[x, \ y], {y, ymin, ymax}, {x, xmin, xmax}]\)}], "Input"],

Cell[BoxData[
    \(\[Integral]\_ymin\%ymax\(\[Integral]\_xmin\%xmax f[x, 
            y] \[DifferentialD]x \[DifferentialD]y\)\)], "Output"]
}, Closed]],

Cell["A trivial indefinite double integral is", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[x\ y\^2, x, y]\)], "Input"],

Cell[BoxData[
    \(\(x\^2\ y\^3\)\/6\)], "Output"]
}, Closed]],

Cell["while the integration over a rectangular region is given by", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[x\ y\^2, {x, xmin, xmax}, {y, ymin, ymax}]\)], "Input"],

Cell[BoxData[
    \(1\/6\ \((xmax\^2 - xmin\^2)\)\ \((ymax\^3 - ymin\^3)\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "The following example integrates within the triangular wedge defined by ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] x \[LessEqual] y\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] y \[LessEqual] 2\)]],
  ".  Thus,"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[x\ y\^2, {y, 0, 2}, {x, 0, y}]\)], "Input"],

Cell[BoxData[
    \(16\/5\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_0\%2\(\[Integral]\_0\%y 
          x\ \ \(y\^2\) \[DifferentialD]x \[DifferentialD]y\)\)], "Input"],

Cell[BoxData[
    \(16\/5\)], "Output"]
}, Closed]],

Cell[TextData[{
  "A more interesting example is the function ",
  StyleBox["ylmCoeff", "InlineInput",
    FontWeight->"Bold"],
  " which uses the orthonormality of spherical harmonics to produce expansion \
coefficients for angular functions."
}], "Text"],

Cell[BoxData[
    \(ylmCoeff[\[Lambda]_, m_, f_] := \ \(\((\(-1\))\)\^m\) 
        Integrate[
          f\ SphericalHarmonicY[\[Lambda], \(-m\), \[Theta], \[Phi]] 
            Sin[\[Theta]], {\[Theta], 0, \[Pi]}, {\[Phi], 0, 
            2  \[Pi]}]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
      ylmCoeff[2, m, 
        SphericalHarmonicY[2, \(-1\), \[Theta], \[Phi]]], {m, \(-2\), 
        2}]\)], "Input"],

Cell[BoxData[
    \({0, 1, 0, 0, 0}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
        ylmCoeff[2, m, \(Cos[\[Theta]]\^2\) Sin[2  \[Phi]]], {m, \(-2\), 2}] // 
      Simplify\)], "Input"],

Cell[BoxData[
    \({\[ImaginaryI]\ \@\(\[Pi]\/30\), 0, 0, 
      0, \(-\[ImaginaryI]\)\ \@\(\[Pi]\/30\)}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[ylmCoeff[2, m, Cos[\[Theta]] Sin[\[Phi]]], {m, \(-2\), 2}] // 
      Simplify\)], "Input"],

Cell[BoxData[
    \({0, 1\/16\ \[ImaginaryI]\ \@\(15\/2\)\ \[Pi]\^\(3/2\), 0, 
      1\/16\ \[ImaginaryI]\ \@\(15\/2\)\ \[Pi]\^\(3/2\), 0}\)], "Output"]
}, Closed]],

Cell["Area using change of variables", "Exercise"],

Cell[TextData[{
  "Here is a typical problem in multiple integration drawn from a calculus \
text.  We seek to compute the area in the first quadrant bounded by the \
curves ",
  Cell[BoxData[
      \(borders[x, y] = {x\^2 - y\^2 \[Equal] a\^2, 
          x\^2 - y\^2 \[Equal] b\^2, y \[Equal] 0, \ 
          y \[Equal] \(1\/2\) x}\)], "InlineInput"],
  "\nwhere ",
  Cell[BoxData[
      \(TraditionalForm\`b \[GreaterEqual] a \[GreaterEqual] 0\)]],
  ".",
  StyleBox["\na) Use ", "Text"],
  StyleBox["Graphics`ImplicitPlot`", "InlineInput",
    FontWeight->"Bold"],
  StyleBox[" to display the region bounded by these curves.   For the sake of \
display choose ", "Text"],
  Cell[BoxData[
      \(TraditionalForm\`{a \[Rule] 1, \ b \[Rule] 2}\)]],
  ", but the integral is to be computed for arbitrary {",
  StyleBox["a,b",
    FontSlant->"Italic"],
  "} consistent with ",
  Cell[BoxData[
      \(TraditionalForm\`b \[GreaterEqual] a \[GreaterEqual] 0\)]],
  ".\nb) Evaluate ",
  StyleBox["borders[u,v]", "InlineInput"],
  StyleBox["obtained by the change of variables ", "Text"],
  StyleBox["{x \[Rule] u Cosh[v],y \[Rule] u Sinh[v]}", "InlineInput"],
  StyleBox[".  Show that the region is rectangular in these variables.  Note \
that to use ", "Text"],
  StyleBox["ImplicitPlot", "InlineInput",
    FontWeight->"Bold"],
  StyleBox[" here it will be necessary to specify ranges for both ", "Text"],
  StyleBox["u", "Text",
    FontSlant->"Italic"],
  StyleBox[" and ", "Text"],
  StyleBox["v", "Text",
    FontSlant->"Italic"],
  StyleBox[".\nc) Compute the Jacobian of transformation using the function \
derived earlier (based upon ", "Text"],
  StyleBox["Outer", "InlineInput",
    FontWeight->"Bold"],
  StyleBox[", ", "Text"],
  StyleBox["D", "InlineInput",
    FontWeight->"Bold"],
  StyleBox[", and ", "Text"],
  StyleBox["Det", "InlineInput",
    FontWeight->"Bold"],
  StyleBox[").\nd) Integrate the Jacobian over the appropriate region of ", 
    "Text"],
  StyleBox["{u,v}", "InlineInput",
    FontWeight->"Bold"],
  StyleBox[".", "Text"]
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Contour integration", "Subsection"],

Cell[TextData[{
  "Contour integrals are very similar to line integrals except that the path \
lives in the complex plane.  If ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " is a complex variable, a contour can be defined by a parametric function \
",
  Cell[BoxData[
      \(TraditionalForm\`z \[Rule] \[Zeta][t]\)]],
  " where ",
  StyleBox["t",
    FontSlant->"Italic"],
  " varies between values that take ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta][t]\)]],
  " from the beginning to the end of the desired path.  The following \
function replaces the complex variable by its value on the contour and \
converts the displacement from ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]z\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]t\)]],
  " by means of the partial derivative ",
  Cell[BoxData[
      \(TraditionalForm\`D[\[Zeta], t]\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(contourIntegrate[f_, 
        contour : \((z_ \[Rule] \[Zeta]_)\), {t_, tmin_, tmax_}] := 
      Integrate[f\ D[\[Zeta], t] /. contour, {t, tmin, tmax}]\)], "Input"],

Cell[TextData[{
  "The ",
  StyleBox["theorem of residues",
    FontSlant->"Italic"],
  " tells us that the integral of a function that is regular (analytic and \
single-valued) on a simple, closed, counterclockwise contour and the enclosed \
domain, except for a finite number of isolated singularities, is equal to ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\ \[ImaginaryI]\)]],
  "times the sum of the residues for the singularities within the contour.  \
Hence, we test our function using a function whose one simple pole has unit \
residue"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(contourIntegrate[1\/\(z - 1\/2\), 
      z \[Rule] Cos[t] + \[ImaginaryI]\ Sin[t], {t, 0, 2  \[Pi]}]\)], "Input"],

Cell[BoxData[
    \(2\ \[ImaginaryI]\ \[Pi]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "and obtain the correct answer.  Integration along the more complicated \
lima\[CCedilla]on contour suggested by Gass should give ",
  Cell[BoxData[
      \(TraditionalForm\`4  \[Pi]\[VeryThinSpace]\ \[ImaginaryI]\)]],
  " because the contour encircles the pole twice.  "
}], "Text"],

Cell[BoxData[
    \(plotContour[f_, {t_, tmin_, tmax_}, opts___Rule] := 
      ParametricPlot[Evaluate[{Re[f], Im[f]}], {t, tmin, tmax}, 
        opts]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[{plotContour[Exp[I\ t] \((2  Cos[t] + 1)\), {t, 0, 2  \[Pi]}, 
            AspectRatio \[Rule] Automatic, DisplayFunction \[Rule] Identity], 
          Graphics[{AbsolutePointSize[10], Point[{1\/2, 0}]}]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.12651 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0619041 0.304762 0.563252 0.304762 [
[.21429 .55075 -9 -9 ]
[.21429 .55075 9 0 ]
[.36667 .55075 -3 -9 ]
[.36667 .55075 3 0 ]
[.51905 .55075 -9 -9 ]
[.51905 .55075 9 0 ]
[.67143 .55075 -3 -9 ]
[.67143 .55075 3 0 ]
[.82381 .55075 -9 -9 ]
[.82381 .55075 9 0 ]
[.97619 .55075 -3 -9 ]
[.97619 .55075 3 0 ]
[.0494 .10611 -24 -4.5 ]
[.0494 .10611 0 4.5 ]
[.0494 .25849 -12 -4.5 ]
[.0494 .25849 0 4.5 ]
[.0494 .41087 -24 -4.5 ]
[.0494 .41087 0 4.5 ]
[.0494 .71563 -18 -4.5 ]
[.0494 .71563 0 4.5 ]
[.0494 .86801 -6 -4.5 ]
[.0494 .86801 0 4.5 ]
[.0494 1.0204 -18 -4.5 ]
[.0494 1.0204 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.12651 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .56325 m
.21429 .5695 L
s
[(0.5)] .21429 .55075 0 1 Mshowa
.36667 .56325 m
.36667 .5695 L
s
[(1)] .36667 .55075 0 1 Mshowa
.51905 .56325 m
.51905 .5695 L
s
[(1.5)] .51905 .55075 0 1 Mshowa
.67143 .56325 m
.67143 .5695 L
s
[(2)] .67143 .55075 0 1 Mshowa
.82381 .56325 m
.82381 .5695 L
s
[(2.5)] .82381 .55075 0 1 Mshowa
.97619 .56325 m
.97619 .5695 L
s
[(3)] .97619 .55075 0 1 Mshowa
.125 Mabswid
.09238 .56325 m
.09238 .567 L
s
.12286 .56325 m
.12286 .567 L
s
.15333 .56325 m
.15333 .567 L
s
.18381 .56325 m
.18381 .567 L
s
.24476 .56325 m
.24476 .567 L
s
.27524 .56325 m
.27524 .567 L
s
.30571 .56325 m
.30571 .567 L
s
.33619 .56325 m
.33619 .567 L
s
.39714 .56325 m
.39714 .567 L
s
.42762 .56325 m
.42762 .567 L
s
.45809 .56325 m
.45809 .567 L
s
.48857 .56325 m
.48857 .567 L
s
.54952 .56325 m
.54952 .567 L
s
.58 .56325 m
.58 .567 L
s
.61048 .56325 m
.61048 .567 L
s
.64095 .56325 m
.64095 .567 L
s
.7019 .56325 m
.7019 .567 L
s
.73238 .56325 m
.73238 .567 L
s
.76286 .56325 m
.76286 .567 L
s
.79333 .56325 m
.79333 .567 L
s
.85429 .56325 m
.85429 .567 L
s
.88476 .56325 m
.88476 .567 L
s
.91524 .56325 m
.91524 .567 L
s
.94571 .56325 m
.94571 .567 L
s
.03143 .56325 m
.03143 .567 L
s
.00095 .56325 m
.00095 .567 L
s
.25 Mabswid
0 .56325 m
1 .56325 L
s
.0619 .10611 m
.06815 .10611 L
s
[(-1.5)] .0494 .10611 1 0 Mshowa
.0619 .25849 m
.06815 .25849 L
s
[(-1)] .0494 .25849 1 0 Mshowa
.0619 .41087 m
.06815 .41087 L
s
[(-0.5)] .0494 .41087 1 0 Mshowa
.0619 .71563 m
.06815 .71563 L
s
[(0.5)] .0494 .71563 1 0 Mshowa
.0619 .86801 m
.06815 .86801 L
s
[(1)] .0494 .86801 1 0 Mshowa
.0619 1.0204 m
.06815 1.0204 L
s
[(1.5)] .0494 1.0204 1 0 Mshowa
.125 Mabswid
.0619 .13659 m
.06565 .13659 L
s
.0619 .16706 m
.06565 .16706 L
s
.0619 .19754 m
.06565 .19754 L
s
.0619 .22801 m
.06565 .22801 L
s
.0619 .28897 m
.06565 .28897 L
s
.0619 .31944 m
.06565 .31944 L
s
.0619 .34992 m
.06565 .34992 L
s
.0619 .38039 m
.06565 .38039 L
s
.0619 .44135 m
.06565 .44135 L
s
.0619 .47182 m
.06565 .47182 L
s
.0619 .5023 m
.06565 .5023 L
s
.0619 .53278 m
.06565 .53278 L
s
.0619 .59373 m
.06565 .59373 L
s
.0619 .6242 m
.06565 .6242 L
s
.0619 .65468 m
.06565 .65468 L
s
.0619 .68516 m
.06565 .68516 L
s
.0619 .74611 m
.06565 .74611 L
s
.0619 .77659 m
.06565 .77659 L
s
.0619 .80706 m
.06565 .80706 L
s
.0619 .83754 m
.06565 .83754 L
s
.0619 .89849 m
.06565 .89849 L
s
.0619 .92897 m
.06565 .92897 L
s
.0619 .95944 m
.06565 .95944 L
s
.0619 .98992 m
.06565 .98992 L
s
.0619 .07563 m
.06565 .07563 L
s
.0619 .04516 m
.06565 .04516 L
s
.0619 .01468 m
.06565 .01468 L
s
.0619 1.05087 m
.06565 1.05087 L
s
.0619 1.08135 m
.06565 1.08135 L
s
.0619 1.11182 m
.06565 1.11182 L
s
.25 Mabswid
.0619 0 m
.0619 1.12651 L
s
0 0 m
1 0 L
1 1.12651 L
0 1.12651 L
closepath
clip
newpath
.5 Mabswid
.97619 .56325 m
.97614 .57034 L
.97602 .57679 L
.97579 .58424 L
.97547 .59127 L
.97469 .60376 L
.97352 .6173 L
.97184 .63217 L
.96962 .64786 L
.96451 .67583 L
.95772 .70435 L
.95 .73067 L
.92759 .78881 L
.89817 .84487 L
.86585 .8926 L
.82272 .94273 L
.77664 .98478 L
.7315 1.01754 L
.68031 1.04671 L
.62976 1.06854 L
.58263 1.08339 L
.556 1.08961 L
.54139 1.09237 L
.52773 1.09455 L
.51508 1.09623 L
.50354 1.09747 L
.49074 1.09852 L
.4837 1.09896 L
.47704 1.09928 L
.4705 1.0995 L
.46328 1.09965 L
.45966 1.09968 L
.45577 1.09968 L
.44872 1.09961 L
.4421 1.09946 L
.43514 1.09919 L
.42921 1.09889 L
.42274 1.09847 L
.40813 1.0972 L
.39264 1.09537 L
.3651 1.09081 L
.3376 1.08456 L
.31283 1.07739 L
.25937 1.05649 L
.21562 1.03305 L
.17335 1.00366 L
.1389 .97332 L
.10655 .93755 L
.08088 .90161 L
.06126 .86673 L
Mistroke
.0438 .8254 L
.03679 .80329 L
.03101 .77968 L
.02893 .76885 L
.02708 .75719 L
.02572 .74622 L
.0252 .74102 L
.02479 .73618 L
.02446 .73144 L
.02422 .72714 L
.02401 .72237 L
.02387 .71728 L
.02381 .71241 L
.02383 .70713 L
.02392 .70218 L
.02408 .69762 L
.0243 .69292 L
.02461 .68801 L
.02536 .67931 L
.02642 .67003 L
.02788 .66003 L
.03128 .64242 L
.03532 .62653 L
.04751 .59205 L
.056 .57406 L
.06464 .55862 L
.08272 .53252 L
.1044 .50857 L
.13054 .48689 L
.15613 .47137 L
.18115 .46066 L
.19531 .45638 L
.20202 .45477 L
.20821 .45353 L
.21388 .4526 L
.22011 .4518 L
.22311 .45149 L
.22633 .45123 L
.22973 .45101 L
.2329 .45088 L
.23569 .45081 L
.23873 .45079 L
.24189 .45083 L
.24481 .45093 L
.24754 .45107 L
.25001 .45123 L
.25551 .45174 L
.26117 .45248 L
.26729 .45353 L
.27933 .45639 L
Mistroke
.28999 .45989 L
.29952 .46387 L
.31909 .47514 L
.32882 .48275 L
.33685 .49041 L
.34351 .49805 L
.34973 .50671 L
.35436 .51456 L
.35856 .52337 L
.36072 .52892 L
.36241 .5341 L
.36374 .53902 L
.36492 .54447 L
.36533 .54685 L
.36572 .5494 L
.366 .55162 L
.36625 .55403 L
.36637 .55545 L
.36646 .55676 L
.36659 .55935 L
.36665 .5617 L
.36666 .5642 L
.36661 .56649 L
.3665 .56899 L
.36632 .5716 L
.36609 .57402 L
.36554 .57836 L
.36474 .58296 L
.36353 .58834 L
.36212 .59335 L
.3588 .60257 L
.35483 .61106 L
.35048 .61862 L
.33833 .63451 L
.33122 .64162 L
.32281 .64865 L
.30572 .65955 L
.2942 .66496 L
.28259 .66914 L
.27167 .67206 L
.26531 .67334 L
.25931 .67429 L
.25612 .67469 L
.25274 .67504 L
.24982 .67529 L
.24661 .67549 L
.24479 .67558 L
.24312 .67564 L
.24119 .67568 L
.23936 .67571 L
Mistroke
.2361 .6757 L
.23424 .67566 L
.23253 .67561 L
.22944 .67548 L
.22654 .67529 L
.22335 .67503 L
.21989 .67468 L
.21283 .67374 L
.20632 .67262 L
.19417 .66983 L
.18088 .66574 L
.15686 .65551 L
.1304 .63952 L
.10772 .62107 L
.08378 .59531 L
.06407 .56694 L
.04832 .53633 L
.0417 .51977 L
.03555 .5008 L
.03126 .484 L
.0293 .47454 L
.02771 .46544 L
.02647 .45688 L
.02538 .44746 L
.02499 .44327 L
.02464 .4388 L
.02436 .43462 L
.02416 .43072 L
.02398 .4262 L
.02386 .42124 L
.02381 .41638 L
.02384 .41117 L
.02394 .40629 L
.02411 .40167 L
.02432 .3975 L
.0246 .39298 L
.02549 .38253 L
.02679 .37142 L
.03009 .35139 L
.03425 .33276 L
.03912 .31533 L
.05372 .27597 L
.07511 .2343 L
.10066 .19648 L
.16168 .13238 L
.19948 .1038 L
.24382 .07762 L
.28907 .05744 L
.33246 .04331 L
.35754 .03724 L
Mistroke
.37146 .03449 L
.38456 .0323 L
.39679 .03059 L
.40801 .02931 L
.42054 .0282 L
.42746 .02772 L
.43403 .02736 L
.44053 .0271 L
.4477 .02691 L
.45132 .02685 L
.45522 .02682 L
.46228 .02685 L
.46895 .02696 L
.47598 .02719 L
.48198 .02746 L
.48856 .02784 L
.5035 .02903 L
.51947 .03082 L
.54818 .03536 L
.57741 .04177 L
.60411 .04926 L
.66317 .07166 L
.71314 .09761 L
.76306 .13109 L
.80534 .16673 L
.8466 .20997 L
.88087 .25473 L
.90841 .2994 L
.93471 .35412 L
.9459 .38357 L
.95628 .41685 L
.96311 .44422 L
.9689 .47412 L
.97138 .49073 L
.9732 .50604 L
.97454 .52072 L
.97506 .52812 L
.97552 .53623 L
.97582 .54306 L
.97601 .54928 L
.97615 .55646 L
.97619 .56325 L
Mfstroke
10 Mabswid
.21429 .56325 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{255.625, 287.938},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005o0001[b000`400?l00000o`00003oo`3ooon0
0?ooo`00o`3ooon00?ooo`00o`3ooon00?ooo`00o`3ooon00?ooo`00o`3ooon00?ooo`00o`3ooon0
0?ooo`00o`3ooon00?ooo`00o`3ooon00?ooo`00o`3ooon00?ooo`00o`3ooon00?ooo`00:03oool0
0`000000oooo0?ooo`3o0?oooeD0oooo000X0?ooo`030000003oool0oooo0?l0ooooE@3oool002P0
oooo00<000000?ooo`3oool0o`3ooomE0?ooo`00:03oool00`000000oooo0?ooo`3o0?oooeD0oooo
000X0?ooo`030000003oool0oooo0?l0ooooE@3oool002P0oooo0P00003o0?oooeH0oooo000X0?oo
o`030000003oool0oooo0?l0ooooE@3oool002P0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`00
:03oool00`000000oooo0?ooo`3o0?oooeD0oooo000X0?ooo`030000003oool0oooo0?l0ooooE@3o
ool002P0oooo00<000000?ooo`3oool0NP3ooolW00000;<0oooo000X0?ooo`030000003oool0oooo
07H0oooo1000000W0?ooo`H00000[@3oool002P0oooo00<000000?ooo`3oool0K03oool:00000340
oooo1@00002X0?ooo`00:03oool00`000000oooo0?ooo`1X0?ooo`@00000@03oool500000:<0oooo
000X0?ooo`030000003oool0oooo06D0oooo0`0000190?ooo`H00000W@3oool002P0oooo00<00000
0?ooo`3oool0HP3oool300000580oooo1000002I0?ooo`00:03oool200000600oooo0`00001I0?oo
o`<00000UP3oool002P0oooo00<000000?ooo`3oool0G03oool3000005l0oooo1000002B0?ooo`00
:03oool00`000000oooo0?ooo`1I0?ooo`<00000IP3oool3000008l0oooo000X0?ooo`030000003o
ool0oooo05D0oooo1000001/0?ooo`800000S@3oool002P0oooo00<000000?ooo`3oool0DP3oool3
00000780oooo0`00002:0?ooo`00:03oool00`000000oooo0?ooo`1?0?ooo`<00000N03oool30000
08L0oooo000X0?ooo`030000003oool0oooo04d0oooo0P00001n0?ooo`800000Q@3oool002P0oooo
00<000000?ooo`3oool0BP3oool300000880oooo0`0000220?ooo`00:03oool00`000000oooo0?oo
o`180?ooo`800000R03oool3000007l0oooo000X0?ooo`030000003oool0oooo04H0oooo0P00002=
0?ooo`800000O@3oool002P0oooo00<000000?ooo`3oool0@`3oool300000940oooo0P00001k0?oo
o`00:03oool200000480oooo0P00002F0?ooo`800000N@3oool002P0oooo00<000000?ooo`3oool0
?`3oool2000009X0oooo0P00001g0?ooo`00:03oool00`000000oooo0?ooo`0m0?ooo`800000WP3o
ool2000007D0oooo000X0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0X03oool2
000007<0oooo000X0?ooo`030000003oool0oooo03X0oooo0P00002U0?ooo`800000L@3oool002P0
oooo00<000000?ooo`3oool0>03oool200000:T0oooo0P00001_0?ooo`00:03oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo0:/0oooo0P00001]0?ooo`00:03oool00`000000oooo0?oo
o`0e0?ooo`800000/03oool2000006/0oooo000:0?ooo`030?noM0000000000000<0000000<007Bo
0?ooo`3oool00P3oool00`2oM0000000001d_`050?ooo`050;md0000000000000000001d_ol01P3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0;80oooo0P00001Y0?ooo`003@3oool0
0`2LB4P0W=oo0?ooo`050?ooo`030;md0000000007Bo00@0oooo00L0_g@0001d_`3oool0oooo0?oO
W0180000M;oo00D0oooo00<000000?ooo`3oool0<P3oool200000;L0oooo0P00001W0?ooo`003@3o
ool00`2LB4P0W=oo0?ooo`0A0?ooo`030?noM000M;l0oooo00@0oooo00<000000?ooo`3oool0<03o
ool200000;/0oooo00<000000?ooo`3oool0I03oool000d0oooo00<0W4Q809cOo`3oool04@3oool0
0`3o_g@007Bo0?ooo`040?ooo`<00000;`3oool00`000000oooo0?ooo`2l0?ooo`800000I03oool0
00030?ooo`2LB000000000@0000000<004RL0?ooo`3oool00`3oool00`2LB4P0W=oo0?ooo`0A0?oo
o`0309a8001d_ol0oooo00@0oooo00<000000?ooo`3oool0;@3oool200000<40oooo00<000000?oo
o`3oool0H@3oool000d0oooo00<0W4Q809cOo`3oool0303oool00`3ookl0M0000000000200000003
04RLg`3oool0oooo00@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`320?ooo`80
0000H@3oool000d0oooo00<0W4Q809cOo`3oool0303oool00`3ookl0M01d0;ooo`090?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`1N0?ooo`002P3o
ool01@3OW4P000000018W02LB4P0W=oo00d0oooo00<0oono07@0M02oool02@3oool00`000000oooo
0?ooo`0Y0?ooo`800000b@3oool00`000000oooo0?ooo`1M0?ooo`00303oool00`3OW4P0001809cO
o`0=0?ooo`030?oo_`1d000000000080000000<0001d0;ooo`3oool0103oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo0<X0oooo0P00001M0?ooo`00:03oool00`000000oooo0?ooo`0V
0?ooo`800000c`3oool00`000000oooo0?ooo`1J0?ooo`00:03oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo0=00oooo0P00001J0?ooo`00:03oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo0=<0oooo00<000000?ooo`3oool0E`3oool002P0oooo00<000000?ooo`3oool0
8P3oool200000=L0oooo0P00001G0?ooo`00:03oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo0=T0oooo00<000000?ooo`3oool0E03oool002P0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`3K0?ooo`030000003oool0oooo05<0oooo000X0?ooo`800000803oool00`00
0000oooo0?ooo`3M0?ooo`030000003oool0oooo0580oooo000X0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0g`3oool200000580oooo000X0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0hP3oool00`000000oooo0?ooo`1?0?ooo`00:03oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3oool0CP3oool002P0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`3V0?ooo`030000003oool0oooo04d0oooo000X0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0j03oool00`000000oooo0?ooo`1<0?oo
o`00:03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0>X0oooo00<000000?ooo`3o
ool0B`3oool002P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3/0?ooo`030000
003oool0oooo04X0oooo000X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0kP3o
ool2000004X0oooo000X0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0l@3oool0
0`000000oooo0?ooo`170?ooo`00:03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0?80oooo00<000000?ooo`3oool0AP3oool002P0oooo0P00000F0?ooo`030000003oool0oooo0?@0
oooo00<000000?ooo`3oool0A@3oool002P0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`3f0?ooo`030000003oool0oooo04@0oooo000X0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0n03oool00`000000oooo0?ooo`130?ooo`00:03oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0?X0oooo00<000000?ooo`3oool0@P3oool002P0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`3l0?ooo`030000003oool0oooo0440oooo000X0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0oP3oool00`000000oooo0?ooo`100?ooo`00
:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo0@3oool00`000000oooo
0?ooo`0o0?ooo`00:03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo0`3o
ool00`000000oooo0?ooo`0n0?ooo`00:03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0?l0oooo1@3oool00`000000oooo0?ooo`0m0?ooo`00:03oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0?l0oooo1`3oool00`000000oooo0?ooo`0l0?ooo`00:03oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo0?ooo`0k0?ooo`00
:03oool2000000/0oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000003oool0oooo03X0oooo
000X0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3oool<0?ooo`030000003o
ool0oooo03T0oooo000X0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3oool>
0?ooo`030000003oool0oooo03P0oooo000X0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`030000003oool0oooo03L0oooo000X0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0o`3ooolA0?ooo`030000003oool0oooo03H0oooo000X0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`030000003oool0oooo03D0oooo
000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`030000003o
ool0oooo03@0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooolE
0?ooo`030000003oool0oooo03@0oooo000X0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0o`3ooolG0?ooo`030000003oool0oooo03<0oooo000X0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0o`3ooolH0?ooo`030000003oool0oooo0380oooo000X0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`030000003oool0oooo0340oooo
000X0?ooo`800000103oool00`000000oooo0?ooo`3o0?oooa/0oooo00<000000?ooo`3oool0<@3o
ool002P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<00000
0?ooo`3oool0<03oool002P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oo
oah0oooo00<000000?ooo`3oool0;`3oool002P0oooo00D000000?ooo`3oool0oooo0000003o0?oo
ob80oooo00<000000?ooo`3oool0;P3oool002P0oooo00D000000?ooo`3oool0oooo0000003o0?oo
ob80oooo00<000000?ooo`3oool0;P3oool002P0oooo00@000000?ooo`3oool00000o`3ooolT0?oo
o`030000003oool0oooo02d0oooo000X0?ooo`040000003oool0oooo00000?l0oooo9@3oool00`00
0000oooo0?ooo`0/0?ooo`00703oool00`3o_g@000000000000300000003001d_`3oool0oooo00<0
oooo00<000000?ooo`000000o`3ooolW0?ooo`030000003oool0oooo02/0oooo000O0?ooo`0309a8
B02Lgol0oooo00H0oooo00<000000?ooo`000000o`3ooolW0?ooo`030000003oool0oooo02/0oooo
000O0?ooo`0309a8B02Lgol0oooo00H0oooo0P00003o0?ooobT0oooo00<000000?ooo`3oool0:P3o
ool001l0oooo00<0W4Q809cOo`3oool01P3oool200000?l0oooo:P3oool00`000000oooo0?ooo`0Y
0?ooo`004`3oool00`2LB000000000000003000000030018W03oool0oooo00<0oooo00<0W4Q809cO
o`3oool01P3oool300000?l0oooo:P3oool00`000000oooo0?ooo`0X0?ooo`007`3oool00`2LB4P0
W=oo0?ooo`060?ooo`030000003oool0oooo0?l0oooo:P3oool00`000000oooo0?ooo`0X0?ooo`00
7`3oool00`2LB4P0W=oo0?ooo`050?ooo`800000o`3oool]0?ooo`030000003oool0oooo02L0oooo
000L0?ooo`050=nLB000000004RL09a8B02Lgol01P3oool200000?l0oooo;@3oool00`000000oooo
0?ooo`0W0?ooo`007P3oool00`3OW4P0001809cOo`050?ooo`030000003oool000000?l0oooo;P3o
ool00`000000oooo0?ooo`0V0?ooo`009P3oool00`000000oooo0000003o0?ooobl0oooo00<00000
0?ooo`3oool09@3oool002D0oooo00@000000?ooo`3oool00000o`3oool_0?ooo`030000003oool0
oooo02D0oooo000U0?ooo`040000003oool0oooo00000?l0oooo<03oool00`000000oooo0?ooo`0T
0?ooo`00903oool01@000000oooo0?ooo`3oool000000?l0oooo<@3oool00`000000oooo0?ooo`0S
0?ooo`00903oool01@000000oooo0?ooo`3oool000000?l0oooo<@3oool00`000000oooo0?ooo`0S
0?ooo`00903oool01@000000oooo0?ooo`3oool000000?l0oooo<P3oool00`000000oooo0?ooo`0R
0?ooo`008`3oool00`000000oooo0?ooo`020?ooo`800000o`3ooola0?ooo`030000003oool0oooo
0280oooo000S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooola0?ooo`03
0000003oool0oooo0240oooo000S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
o`3ooolb0?ooo`030000003oool0oooo0200oooo000R0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0o`3ooolb0?ooo`030000003oool0oooo0200oooo000R0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0o`3ooolc0?ooo`030000003oool0oooo01l0oooo000R0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooolc0?ooo`030000003oool0oooo
01l0oooo000Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooold0?ooo`03
0000003oool0oooo01h0oooo000Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
o`3ooold0?ooo`030000003oool0oooo01h0oooo000Q0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0o`3ooole0?ooo`030000003oool0oooo01d0oooo000P0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0o`3ooole0?ooo`030000003oool0oooo01d0oooo000P0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`030000003oool0oooo
01`0oooo000P0?ooo`030000003oool0oooo00D0oooo0P00003o0?ooocL0oooo00<000000?ooo`3o
ool0703oool001l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooocL0oooo
00<000000?ooo`3oool06`3oool001l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`3o0?ooocL0oooo00<000000?ooo`3oool06`3oool001l0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`3o0?ooocL0oooo00<000000?ooo`3oool06`3oool001h0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3oool06P3oool001h0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooocP0oooo00<000000?ooo`3o
ool06P3oool001h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooocT0oooo
00<000000?ooo`3oool06@3oool001d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`3o0?ooocT0oooo00<000000?ooo`3oool06@3oool001d0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`3o0?ooocX0oooo00<000000?ooo`3oool0603oool001d0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`3o0?ooocX0oooo00<000000?ooo`3oool0603oool001d0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oooc/0oooo00<000000?ooo`3o
ool05`3oool001`0oooo00<000000?ooo`3oool02@3oool200000?l0oooo?03oool00`000000oooo
0?ooo`0G0?ooo`00703oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo?03o
ool00`000000oooo0?ooo`0F0?ooo`00703oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0?l0oooo?03oool00`000000oooo0?ooo`0F0?ooo`00703oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0?l0oooo?03oool00`000000oooo0?ooo`0F0?ooo`00703oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo?@3oool00`000000oooo0?ooo`0E0?ooo`00
6`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo?@3oool00`000000oooo
0?ooo`0E0?ooo`006`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo?@3o
ool00`000000oooo0?ooo`0E0?ooo`006`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0?l0oooo?P3oool00`000000oooo0?ooo`0D0?ooo`006`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0?l0oooo?P3oool00`000000oooo0?ooo`0D0?ooo`006`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo?`3oool00`000000oooo0?ooo`0C0?ooo`00
6`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo?`3oool00`000000oooo
0?ooo`0C0?ooo`006`3oool00`000000oooo0?ooo`0:0?ooo`800000o`3ooom00?ooo`030000003o
ool0oooo01<0oooo000K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooom0
0?ooo`030000003oool0oooo0180oooo000K0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0o`3ooom00?ooo`030000003oool0oooo0180oooo000J0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0o`3ooom00?ooo`030000003oool0oooo0180oooo000J0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooom10?ooo`030000003oool0oooo0140oooo
000J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooom10?ooo`030000003o
ool0oooo0140oooo000J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooom1
0?ooo`030000003oool0oooo0140oooo000J0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0o`3ooom20?ooo`030000003oool0oooo0100oooo000;0?ooo`050?noM000000000000000
001d_ol01@3oool00`2oM0000000001d_`020?ooo`040000003oool0oooo0;md00<0000000<0M;oo
0?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oood80oooo00<000000?ooo`3oool0403oool0
00/0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo0080oooo00@0
00000?ooo`2oM00007Bo0P3oool00`3ogi`0B00007Boo`050?ooo`030000003oool0oooo0?l0oooo
@P3oool00`000000oooo0?ooo`0@0?ooo`002P3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018
W=l0oooo00P0oooo00<000000?ooo`3oool0103oool00`3o_g@007Bo0?ooo`040?ooo`030000003o
ool0oooo0?l0oooo@`3oool00`000000oooo0?ooo`0?0?ooo`002P3oool00`3OW4P0B9cO0?ooo`02
0?ooo`030?noM000M;l0oooo00P0oooo00<000000?ooo`3oool0103oool00`3o_g@007Bo0?ooo`04
0?ooo`030000003oool0oooo0?l0oooo@`3oool00`000000oooo0?ooo`0?0?ooo`0000<0oooo09a8
00000000100000001@00B9`0oooo0?ooo`3OW4P0B9cO00<0oooo00<0okmd001d_`3oool0203oool0
0`000000oooo0?ooo`040?ooo`0309a8001d_ol0oooo00@0oooo0`00003o0?oood<0oooo00<00000
0?ooo`3oool03`3oool000X0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`080?oo
o`040000003oool0oono07@000<0000000<0B9cO0?ooo`3oool0103oool00`000000oooo0?ooo`3o
0?oood@0oooo00<000000?ooo`3oool03P3oool000X0oooo00<0okmd04RLg`3oool00P3oool00`3O
W4P0B9cO0?ooo`080?ooo`050000003oool0oono07@0M02oool02@3oool00`000000oooo0?ooo`3o
0?oood@0oooo00<000000?ooo`3oool03P3oool000/0oooo00H0W4P007Boo`3oool0omnL04P0M02o
ool90?ooo`050000003oool0oono07@0M02oool02@3oool00`000000oooo0?ooo`3o0?oood@0oooo
00<000000?ooo`3oool03P3oool000/0oooo00D0oono07@000000000001809cOo`0:0?ooo`040000
003oool0oono07@000<0000000<0001d0;ooo`3oool0103oool00`000000oooo0?ooo`3o0?oood@0
oooo00<000000?ooo`3oool03P3oool001X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`3o0?ooodD0oooo00<000000?ooo`3oool03@3oool001X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`3o0?ooodD0oooo00<000000?ooo`3oool03@3oool001X0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooodD0oooo00<000000?ooo`3oool03@3oool0
01X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooodD0oooo00<000000?oo
o`3oool03@3oool001X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooodD0
oooo00<000000?ooo`3oool03@3oool001X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0303oool001/0oooo00<000000?ooo`3oool02P3o
ool200000?l0ooooA`3oool00`000000oooo0?ooo`0<0?ooo`006`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`0<0?ooo`006`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`0<0?oo
o`006`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03H0oooo3`00003o0?ooo`80
oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0b0?ooo`@000003`3oool500000?`0oooo00<000000?ooo`3oool02`3oool001/0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0]0?ooo`D00000603oool400000?P0oooo00<0
00000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0[
0?ooo`8000008@3oool300000?D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0X0?ooo`<000009P3oool200000?@0oooo00<000000?oo
o`3oool02P3oool001`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0V0?ooo`80
0000:`3oool200000?80oooo00<000000?ooo`3oool02P3oool001`0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0S0?ooo`<00000;`3oool200000?00oooo00<000000?ooo`3oool0
2P3oool001`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Q0?ooo`800000=03o
ool200000>h0oooo00<000000?ooo`3oool02P3oool001`0oooo00<000000?ooo`3oool02@3oool2
00000200oooo0P00000h0?ooo`800000k@3oool00`000000oooo0?ooo`090?ooo`00703oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01d0oooo0P00000l0?ooo`030000003oool0oooo
0>X0oooo00<000000?ooo`3oool02@3oool001`0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0K0?ooo`800000?`3oool00`000000oooo0?ooo`3Y0?ooo`030000003oool0oooo00T0
oooo000M0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06@3oool200000480oooo
00<000000?ooo`3oool0j03oool00`000000oooo0?ooo`090?ooo`007@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo01L0oooo0P0000150?ooo`030000003oool0oooo0>L0oooo00<0
00000?ooo`3oool02@3oool001d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0i`3oool00`000000oooo0?ooo`08
0?ooo`007@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`3V0?ooo`030000003oool0oooo00P0oooo000M0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo0>D0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04`0oooo0P00003U0?ooo`030000
003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3o
ool200000540oooo00<000000?ooo`3oool0hP3oool00`000000oooo0?ooo`080?ooo`007P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0DP3oool0
0`000000oooo0?ooo`3Q0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo
00L0oooo0P00000@0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0h@3oool00`00
0000oooo0?ooo`080?ooo`007`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo00P0
oooo000O0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo0=l0oooo00<000000?ooo`3oool0203oool00200oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0g`3oool00`000000oooo0?ooo`080?ooo`00803oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`3N
0?ooo`030000003oool0oooo00P0oooo000Q0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0=l0oooo00<000000?oo
o`3oool01`3oool00240oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo01d0oooo00D0okmd000000000000000007Boo`050?ooo`030;md0000000007Bo
00D0oooo00D0_g@0000000000000000007Boo`0X0?ooo`030000003o_g@0000000@0000000<007Bo
0?ooo`3oool09@3oool00`3o_g@000000000000300000003001d_`3oool0oooo0080oooo00<0_g@0
00000000M;l01@3oool01@2oM0000000000000000000M;oo02P0oooo00<0oono07@0000000001000
00000`1d_ol0oooo0?ooo`0T0?ooo`030?oo_`1d0000000000@0000000<0M;oo0?ooo`3oool00P3o
ool00`2oM0000000001d_`050?ooo`050;md0000000000000000001d_ol0:P3oool01@2oM0000000
000000000000B9cO00L0oooo000Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0M0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2o
M0000000001d_`040?ooo`070;md0000M;l0oooo0?ooo`3ogi`0B00007Boo`0X0?ooo`050000003o
ool0oooo09a8B02Lgol0;03oool00`2LB4P0W=oo0?ooo`050?ooo`030;md0000000007Bo00@0oooo
00L0_g@0001d_`3oool0oooo0?oOW0180000M;oo02P0oooo00<0_g@00000M02oool00P3oool00`3O
W7@0W=oo0?ooo`0V0?ooo`030;md000007@0_ooo0080oooo00<0giad09cOo`3oool00`3oool00`2o
M0000000001d_`040?ooo`070;md0000M;l0oooo0?ooo`3ogi`0B00007Boo`0X0?ooo`070;md0000
M;l0oooo0000003ookl0M00004RLg`060?ooo`008P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool07@3oool00`3o_g@007Bo0?ooo`020?ooo`030=nL
B018W=l0oooo00l0oooo00<0okmd001d_`3oool09`3oool01@000000oooo0?ooo`2LB4P0W=oo02`0
oooo00<0W4Q809cOo`3oool04@3oool00`3o_g@007Bo0?ooo`0X0?ooo`030?noM00004P0W=oo02/0
oooo00<0okmd0000B02Lgol04`3oool00`3o_g@007Bo0?ooo`0Z0?ooo`040000003oool0okmd001d
_`H0oooo000R0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0N0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03`3oool00`3o_g@0
07Bo0?ooo`0W0?ooo`050000003oool0oooo09a8B02Lgol0;03oool00`2LB4P0W=oo0?ooo`0A0?oo
o`030?noM000M;l0oooo02T0oooo00<0omnL04P00018W=l0:`3oool00`3ogi`0B00004RLg`0B0?oo
o`030?noM000M;l0oooo02X0oooo00@000000?oOW01804P0W=oo1P3oool00280oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01l0oooo00<0gia804RL
g`3oool00P3oool00`3o_g@007Bo0?ooo`0?0?ooo`0309a8001d_ol0oooo02P0oooo00@000000?oo
o`2LB4P0W=oo;03oool00`2LB4P0W=oo0?ooo`0A0?ooo`0309a8001d_ol0oooo02/0oooo00<0W4P0
04RLg`3oool0:`3oool00`2LB000B9cO0?ooo`0@0?ooo`0309a8001d_ol0oooo02T0oooo00@0gia8
0000000004P0W=oo1`3oool002<0oooo00<000000?ooo`3oool00P3oool2000000H0oooo00<00000
0?ooo`3oool0803oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0oono
07@0000000000P0000000`18W=l0oooo0?ooo`0Y0?ooo`030000002LB4P0W=oo02`0oooo00<0W4Q8
09cOo`3oool0303oool00`3ookl0M000000000020000000304RLg`3oool0oooo02`0oooo00<0W4Qd
0;ooo`3oool0:`3oool00`2LB7@0_ooo0?ooo`0:0?ooo`030?oo_`1d000000000080000000<0B9cO
0?ooo`3oool0:P3oool010000000omnL04P0B02Lgol60?ooo`008`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08@3oool00`3o_g@0B9cO0?ooo`02
0?ooo`030=nLB018W=l0oooo00X0oooo00<0oono07@0M02oool0;P3oool00`000000W4Q809cOo`0/
0?ooo`0309a8B02Lgol0oooo00`0oooo00<0oono07@0M02oool0;03oool00`3OW4P0M;oo0?ooo`02
0?ooo`030;md001d_ol0oooo02H0oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`0:
0?ooo`030?oo_`1d07@0_ooo02l0oooo00@000000?ooo`2oM000M;oo1P3oool002@0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo02<0oooo00H0W4P007Boo`3oool0omnL
04P0M02oool;0?ooo`030?oo_`1d07@0_ooo02`0oooo00D0gia8000000000000W4Q809cOo`0Y0?oo
o`050=nLB000000004RL09a8B02Lgol03@3oool00`3ookl0M01d0;ooo`0/0?ooo`070?noM00007@0
_ooo0?ooo`3o_g@0001809cOo`0W0?ooo`070?noM00007@0_ooo0?ooo`3o_g@0001809cOo`0;0?oo
o`030?oo_`1d07@0_ooo02`0oooo00L0okmd0000B02Lgol000000?oOW01804P0W=oo00H0oooo000T
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0S0?ooo`050?oo_`1d
000000000000B02Lgol0303oool00`3ookl0M00000000002000000030000M02oool0oooo02T0oooo
00<000000000B02Lgol0:`3oool00`3OW4P0001809cOo`0=0?ooo`030?oo_`1d0000000000800000
00<0001d0;ooo`3oool0:03oool01@3o_g@000000000000004P0W=oo02T0oooo00D0okmd00000000
0000001809cOo`0<0?ooo`030?oo_`1d000000000080000000<0001d0;ooo`3oool0:03oool01@3o
gi`0B000000000000000M;oo00L0oooo000U0?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0;P3oool5000003<0oooo00<000000?ooo`3oool0g03oool00`000000oooo0?ooo`07
0?ooo`009@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02d0oooo2@00000b
0?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`0]0?ooo`/00000<@3oool00`000000oooo0?ooo`3K0?oo
o`030000003oool0oooo00L0oooo000V0?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool0;03oool=00000300oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`070?ooo`00
9`3oool2000000030?ooo`000000oooo02h0oooo3@00000`0?ooo`030000003oool0oooo0=/0oooo
00<000000?ooo`3oool01`3oool002L0oooo0`00000_0?ooo`l00000;`3oool00`000000oooo0?oo
o`3K0?ooo`030000003oool0oooo00L0oooo000X0?ooo`030000003oool0oooo02h0oooo3`00000_
0?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3oool01`3oool00180ooooo`00001^0000
00004P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo0`0000090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo3`0000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo000W0?ooo`800000
00<0oooo0000003oool0;@3oool?000002l0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`070?ooo`009P3oool01@000000oooo0000003oool0000002l0oooo3@00000`0?ooo`030000
003oool0oooo0=/0oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`0000000P3o
ool00`000000oooo0?ooo`0/0?ooo`d00000<03oool00`000000oooo0?ooo`3K0?ooo`030000003o
ool0oooo00L0oooo000V0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0;03oool;
00000340oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`070?ooo`009@3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo02d0oooo2@00000b0?ooo`030000003oool0
oooo0=/0oooo00<000000?ooo`3oool01`3oool002D0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0^0?ooo`D00000<`3oool00`000000oooo0?ooo`3L0?ooo`030000003oool0
oooo00L0oooo000T0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo0=`0oooo00<000000?ooo`3oool01`3oool002@0oooo00D000000?oo
o`3oool0oooo000000050?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0g03oool0
0`000000oooo0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo
00L0oooo000S0?ooo`030000003oool0oooo0080oooo0P0000050?ooo`030000003oool0oooo06<0
oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`070?ooo`008`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`3M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0=h0oooo00<0
00000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0gP3oool00`000000oooo0?ooo`07
0?ooo`008@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0GP3oool00`000000oooo0?ooo`3N0?ooo`030000003oool0oooo00L0oooo000Q0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo0=l0oooo00<000000?ooo`3oool01`3oool00200oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
g`3oool00`000000oooo0?ooo`070?ooo`00803oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3O0?ooo`030000003o
ool0oooo00P0oooo000P0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0=l0oooo00<000000?ooo`3oool0203oool0
01l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`080?ooo`007`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`3Q0?ooo`030000003oool0oooo00P0oooo000N0?ooo`030000003oool0oooo00L0oooo
0P00000@0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0h@3oool00`000000oooo
0?ooo`080?ooo`007P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0D@3oool00`000000oooo0?ooo`3R0?ooo`030000003oool0oooo00P0oooo000N
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0><0oooo00<000000?ooo`3oool0203oool001h0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`800000C`3oool00`000000oooo0?ooo`3S0?oo
o`030000003oool0oooo00P0oooo000M0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3o
ool0203oool001d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool0i@3oool00`000000oooo0?ooo`080?ooo`007@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`3U0?ooo`030000003oool0oooo00T0oooo000M0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool05`3oool2000004H0oooo00<000000?ooo`3oool0iP3oool0
0`000000oooo0?ooo`090?ooo`007@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
01T0oooo0P0000120?ooo`800000j@3oool00`000000oooo0?ooo`090?ooo`007@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`3Y0?ooo`030000003oool0oooo00T0oooo000L0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0703oool2000003`0oooo0P00003/0?ooo`030000003oool0oooo00T0oooo
000L0?ooo`030000003oool0oooo00T0oooo0P00000O0?ooo`800000>@3oool00`000000oooo0?oo
o`3/0?ooo`030000003oool0oooo00T0oooo000L0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0803oool2000003D0oooo0P00003^0?ooo`030000003oool0oooo00X0oooo000L0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool08P3oool200000380oooo00<000000?oo
o`3oool0kP3oool00`000000oooo0?ooo`0:0?ooo`00703oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo02@0oooo0`00000]0?ooo`800000l@3oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02L0oooo0`00000W0?ooo`<00000
l`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo02X0oooo0P00000S0?ooo`800000mP3oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02`0oooo1000000L0?ooo`<00000m`3oool0
0`000000oooo0?ooo`0;0?ooo`006`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0300oooo1P00000A0?ooo`D00000nP3oool00`000000oooo0?ooo`0;0?ooo`006`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo03H0oooo4@00003o0?ooo`030000003oool0oooo00/0
oooo000K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooom70?ooo`030000
003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3o
oom70?ooo`030000003oool0oooo00/0oooo000J0?ooo`030000003oool0oooo00/0oooo0P00003o
0?ooodL0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0303oool001X0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0303oool001X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0
303oool001X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooodH0oooo00<0
00000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o
0?ooodD0oooo00<000000?ooo`3oool03@3oool001X0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`3o0?ooodD0oooo00<000000?ooo`3oool03@3oool001X0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`3o0?ooodD0oooo00<000000?ooo`3oool03@3oool000/0oooo
00D0okmd000000000000000007Boo`050?ooo`030;md0000000007Bo0080oooo00@000000?ooo`3o
ool0_g@00`0000000`1d_ol0oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooA@3oool00`00
0000oooo0?ooo`0=0?ooo`002`3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@0
00000000M;l00P3oool010000000oooo0;md0000M;l20?ooo`030?oOW0180000M;oo00D0oooo00<0
00000?ooo`3oool0o`3ooom40?ooo`030000003oool0oooo00h0oooo000:0?ooo`030?noM000M;l0
oooo0080oooo00<0gia804RLg`3oool0203oool00`000000oooo0?ooo`040?ooo`030?noM000M;l0
oooo00@0oooo00<000000?ooo`3oool0o`3ooom40?ooo`030000003oool0oooo00h0oooo000:0?oo
o`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0203oool00`000000oooo0?ooo`040?oo
o`030?noM000M;l0oooo00@0oooo00<000000?ooo`3oool0o`3ooom40?ooo`030000003oool0oooo
00h0oooo000:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0203oool00`000000
oooo0?ooo`040?ooo`0309a8001d_ol0oooo00@0oooo0`00003o0?oood<0oooo00<000000?ooo`3o
ool03`3oool000X0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`080?ooo`040000
003oool0oono07@000<0000000<0B9cO0?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oood<0
oooo00<000000?ooo`3oool03`3oool000X0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO
0?ooo`080?ooo`050000003oool0oono07@0M02oool02@3oool00`000000oooo0?ooo`3o0?oood<0
oooo00<000000?ooo`3oool03`3oool000/0oooo00H0W4P007Boo`3oool0omnL04P0M02oool90?oo
o`050000003oool0oono07@0M02oool02@3oool00`000000oooo0?ooo`3o0?oood<0oooo00<00000
0?ooo`3oool03`3oool000/0oooo00D0oono07@000000000001809cOo`0:0?ooo`040000003oool0
oono07@000<0000000<0001d0;ooo`3oool0103oool00`000000oooo0?ooo`3o0?oood80oooo00<0
00000?ooo`3oool0403oool001X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o
0?oood80oooo00<000000?ooo`3oool0403oool001X0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`3o0?oood80oooo00<000000?ooo`3oool0403oool001/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`3o0?oood40oooo00<000000?ooo`3oool04@3oool001/0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oood40oooo00<000000?ooo`3oool0
4@3oool001/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oood00oooo00<0
00000?ooo`3oool04P3oool001/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o
0?oood00oooo00<000000?ooo`3oool04P3oool001/0oooo00<000000?ooo`3oool02P3oool20000
0?l0oooo@@3oool00`000000oooo0?ooo`0B0?ooo`006`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0?l0oooo?`3oool00`000000oooo0?ooo`0C0?ooo`006`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo?`3oool00`000000oooo0?ooo`0C0?ooo`006`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo?`3oool00`000000oooo0?oo
o`0C0?ooo`006`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo?P3oool0
0`000000oooo0?ooo`0D0?ooo`006`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0?l0oooo?P3oool00`000000oooo0?ooo`0D0?ooo`006`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0?l0oooo?@3oool00`000000oooo0?ooo`0E0?ooo`00703oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0?l0oooo?@3oool00`000000oooo0?ooo`0E0?ooo`00703o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo?@3oool00`000000oooo0?oo
o`0E0?ooo`00703oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo?03oool0
0`000000oooo0?ooo`0F0?ooo`00703oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0?l0oooo?03oool00`000000oooo0?ooo`0F0?ooo`007@3oool00`000000oooo0?ooo`080?ooo`80
0000o`3ooolm0?ooo`030000003oool0oooo01H0oooo000M0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0o`3ooolk0?ooo`030000003oool0oooo01L0oooo000M0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`030000003oool0oooo01L0oooo000M
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`030000003oool0
oooo01P0oooo000N0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolj0?oo
o`030000003oool0oooo01P0oooo000N0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0o`3oooli0?ooo`030000003oool0oooo01T0oooo000N0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01T0oooo000N0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo01X0oooo000O
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0
oooo01X0oooo000O0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooolg0?oo
o`030000003oool0oooo01/0oooo000O0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0o`3ooolg0?ooo`030000003oool0oooo01/0oooo000O0?ooo`030000003oool0oooo00H0oooo
0P00003o0?ooocL0oooo00<000000?ooo`3oool0703oool001l0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`3o0?ooocH0oooo00<000000?ooo`3oool0703oool00200oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooocD0oooo00<000000?ooo`3oool07@3oool0
0200oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooocD0oooo00<000000?oo
o`3oool07@3oool00200oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oooc@0
oooo00<000000?ooo`3oool07P3oool00200oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`3o0?oooc@0oooo00<000000?ooo`3oool07P3oool00240oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`3o0?oooc<0oooo00<000000?ooo`3oool07`3oool00240oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooc<0oooo00<000000?ooo`3oool07`3oool0
0240oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooc80oooo00<000000?oo
o`3oool0803oool00280oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oooc80
oooo00<000000?ooo`3oool0803oool00280oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`3o0?oooc40oooo00<000000?ooo`3oool08@3oool002<0oooo00<000000?ooo`3oool00P3o
ool200000?l0oooo<P3oool00`000000oooo0?ooo`0Q0?ooo`008`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0?l0oooo<03oool00`000000oooo0?ooo`0R0?ooo`00903oool01@00
0000oooo0?ooo`3oool000000?l0oooo<P3oool00`000000oooo0?ooo`0R0?ooo`00903oool01@00
0000oooo0?ooo`3oool000000?l0oooo<@3oool00`000000oooo0?ooo`0S0?ooo`009@3oool01000
0000oooo0?ooo`00003o0?oooc00oooo00<000000?ooo`3oool0903oool002D0oooo00@000000?oo
o`3oool00000o`3oool`0?ooo`030000003oool0oooo02@0oooo000V0?ooo`030000003oool00000
0?l0oooo;`3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0000003o0?ooobh0
oooo00<000000?ooo`3oool09P3oool001`0oooo00<0okmd0000000000000`0000000`00M;l0oooo
0?ooo`020?ooo`800000o`3oool]0?ooo`030000003oool0oooo02L0oooo000O0?ooo`0309a8B02L
gol0oooo00D0oooo0P00003o0?ooobd0oooo00<000000?ooo`3oool09`3oool001l0oooo00<0W4Q8
09cOo`3oool01P3oool00`000000oooo0?ooo`3o0?ooobX0oooo00<000000?ooo`3oool0:03oool0
01l0oooo00<0W4Q809cOo`3oool01P3oool300000?l0oooo:@3oool00`000000oooo0?ooo`0Y0?oo
o`007`3oool00`2LB4P0W=oo0?ooo`060?ooo`800000o`3ooolZ0?ooo`030000003oool0oooo02T0
oooo000O0?ooo`0309a8B02Lgol0oooo00H0oooo0P00003o0?ooobT0oooo00<000000?ooo`3oool0
:P3oool001l0oooo00<0W4Q809cOo`3oool01P3oool00`000000oooo0000003o0?ooobL0oooo00<0
00000?ooo`3oool0:`3oool001`0oooo00D0gia800000000B9`0W4Q809cOo`070?ooo`030000003o
ool000000?l0oooo9`3oool00`000000oooo0?ooo`0[0?ooo`007P3oool00`3OW4P0001809cOo`07
0?ooo`040000003oool0oooo00000?l0oooo9@3oool00`000000oooo0?ooo`0/0?ooo`00:03oool0
10000000oooo0?ooo`00003o0?ooob@0oooo00<000000?ooo`3oool0;@3oool002P0oooo00D00000
0?ooo`3oool0oooo0000003o0?ooob80oooo00<000000?ooo`3oool0;P3oool002P0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oooal0oooo00<000000?ooo`3oool0;P3oool0
02P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oooah0oooo00<000000?oo
o`3oool0;`3oool002P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oooa`0
oooo00<000000?ooo`3oool0<03oool002P0oooo0P0000040?ooo`030000003oool0oooo0?l0oooo
6`3oool00`000000oooo0?ooo`0a0?ooo`00:03oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0?l0oooo6@3oool00`000000oooo0?ooo`0b0?ooo`00:03oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0?l0oooo5`3oool00`000000oooo0?ooo`0c0?ooo`00:03oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo5`3oool00`000000oooo0?ooo`0c0?oo
o`00:03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo5@3oool00`000000
oooo0?ooo`0d0?ooo`00:03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo
4`3oool00`000000oooo0?ooo`0e0?ooo`00:03oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0?l0oooo4P3oool00`000000oooo0?ooo`0f0?ooo`00:03oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0g0?ooo`00:03oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo3P3oool00`000000oooo0?ooo`0h0?oo
o`00:03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo303oool00`000000
oooo0?ooo`0i0?ooo`00:03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo
2`3oool00`000000oooo0?ooo`0j0?ooo`00:03oool2000000`0oooo00<000000?ooo`3oool0o`3o
ool90?ooo`030000003oool0oooo03/0oooo000X0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0o`3oool80?ooo`030000003oool0oooo03/0oooo000X0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0o`3oool70?ooo`030000003oool0oooo03`0oooo000X0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3oool50?ooo`030000003oool0oooo03d0
oooo000X0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3oool30?ooo`030000
003oool0oooo03h0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3o
ool10?ooo`030000003oool0oooo03l0oooo000X0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0oP3oool00`000000oooo0?ooo`100?ooo`00:03oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0?d0oooo00<000000?ooo`3oool0@@3oool002P0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`3k0?ooo`030000003oool0oooo0480oooo000X0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0n@3oool00`000000oooo0?ooo`130?ooo`00:03o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?L0oooo00<000000?ooo`3oool0A03o
ool002P0oooo0P00000E0?ooo`030000003oool0oooo0?D0oooo00<000000?ooo`3oool0A@3oool0
02P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3c0?ooo`030000003oool0oooo
04H0oooo000X0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0l@3oool00`000000
oooo0?ooo`170?ooo`00:03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?00oooo
00<000000?ooo`3oool0B03oool002P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`3^0?ooo`030000003oool0oooo04T0oooo000X0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0k03oool00`000000oooo0?ooo`1:0?ooo`00:03oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo0>X0oooo00<000000?ooo`3oool0B`3oool002P0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`3X0?ooo`030000003oool0oooo04`0oooo000X0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`1=0?ooo`00:03o
ool00`000000oooo0?ooo`0L0?ooo`800000i@3oool00`000000oooo0?ooo`1>0?ooo`00:03oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0>40oooo00<000000?ooo`3oool0C`3oool0
02P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3N0?ooo`800000DP3oool002P0
oooo0P00000Q0?ooo`030000003oool0oooo0=`0oooo00<000000?ooo`3oool0DP3oool002P0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo05<0oooo
000X0?ooo`030000003oool0oooo0280oooo0P00003H0?ooo`800000EP3oool002P0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo05H0oooo000X0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0d@3oool2000005T0oooo000X0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`1I0?ooo`00
:03oool00`000000oooo0?ooo`0W0?ooo`800000c@3oool2000005`0oooo000:0?ooo`030?noM000
0000000000<0000000<007Bo0?ooo`3oool00P3oool00`2oM0000000001d_`050?ooo`050;md0000
000000000000001d_ol01P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0<T0oooo
00<000000?ooo`3oool0G03oool000d0oooo00<0W4Q809cOo`3oool01@3oool00`2oM0000000001d
_`040?ooo`070;md0000M;l0oooo0?ooo`3ogi`0B00007Boo`050?ooo`030000003oool0oooo02X0
oooo0P0000380?ooo`030000003oool0oooo05d0oooo000=0?ooo`0309a8B02Lgol0oooo0140oooo
00<0okmd001d_`3oool0103oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0<<0oooo
0P00001P0?ooo`003@3oool00`2LB4P0W=oo0?ooo`0A0?ooo`030?noM000M;l0oooo00@0oooo00<0
00000?ooo`3oool0;@3oool200000<80oooo00<000000?ooo`3oool0H03oool000d0oooo00<0W4Q8
09cOo`3oool04@3oool00`2LB000M;oo0?ooo`040?ooo`<00000;`3oool00`000000oooo0?ooo`2m
0?ooo`800000H`3oool000d0oooo00<0W4Q809cOo`3oool0303oool00`3ookl0M000000000020000
000304RLg`3oool0oooo00@0oooo00<000000?ooo`3oool0<03oool200000;/0oooo0P00001U0?oo
o`003@3oool00`2LB4P0W=oo0?ooo`0<0?ooo`030?oo_`1d07@0_ooo00T0oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`2f0?ooo`800000I`3oool000X0oooo00D0gia800000000B9`0
W4Q809cOo`0=0?ooo`030?oo_`1d07@0_ooo00T0oooo00<000000?ooo`3oool0<`3oool200000;@0
oooo0P00001Y0?ooo`00303oool00`3OW4P0001809cOo`0=0?ooo`030?oo_`1d0000000000800000
00<0001d0;ooo`3oool0103oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo
0P00001[0?ooo`00:03oool00`000000oooo0?ooo`0f0?ooo`800000[@3oool2000006d0oooo000X
0?ooo`030000003oool0oooo03P0oooo0P00002Y0?ooo`800000K`3oool002P0oooo00<000000?oo
o`3oool0>P3oool200000:D0oooo0P00001a0?ooo`00:03oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo0:00oooo0P00001c0?ooo`00:03oool00`000000oooo0?ooo`0m0?ooo`800000
WP3oool2000007D0oooo000X0?ooo`030000003oool0oooo03l0oooo0P00002J0?ooo`800000M`3o
ool002P0oooo0P0000120?ooo`800000UP3oool2000007T0oooo000X0?ooo`030000003oool0oooo
04<0oooo0P00002B0?ooo`800000N`3oool002P0oooo00<000000?ooo`3oool0A@3oool2000008d0
oooo0`00001m0?ooo`00:03oool00`000000oooo0?ooo`170?ooo`<00000R03oool200000800oooo
000X0?ooo`030000003oool0oooo04X0oooo0`0000230?ooo`800000PP3oool002P0oooo00<00000
0?ooo`3oool0C@3oool2000007l0oooo0P0000240?ooo`00:03oool00`000000oooo0?ooo`1?0?oo
o`<00000N@3oool3000008H0oooo000X0?ooo`030000003oool0oooo0580oooo0`00001c0?ooo`<0
0000R@3oool002P0oooo00<000000?ooo`3oool0E@3oool3000006d0oooo0`00002<0?ooo`00:03o
ool00`000000oooo0?ooo`1H0?ooo`<00000J03oool2000008l0oooo000X0?ooo`030000003oool0
oooo05/0oooo0`00001R0?ooo`<00000T@3oool002P0oooo0P00001O0?ooo`<00000G03oool30000
09@0oooo000X0?ooo`030000003oool0oooo0640oooo1000001D0?ooo`@00000U`3oool002P0oooo
00<000000?ooo`3oool0I@3oool5000004X0oooo1@00002K0?ooo`00:03oool00`000000oooo0?oo
o`1Z0?ooo`D00000@03oool500000:00oooo000X0?ooo`030000003oool0oooo06l0oooo1@00000f
0?ooo`D00000Y@3oool002P0oooo00<000000?ooo`3oool0M03oool5000002P0oooo2@00002Z0?oo
o`00:03oool00`000000oooo0?ooo`1i0?oooa000000203oool@00000;<0oooo000X0?ooo`030000
003oool0oooo08T0oooo200000330?ooo`00:03oool00`000000oooo0?ooo`3o0?oooeD0oooo000X
0?ooo`030000003oool0oooo0?l0ooooE@3oool002P0oooo00<000000?ooo`3oool0o`3ooomE0?oo
o`00:03oool200000?l0ooooEP3oool002P0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`00:03o
ool00`000000oooo0?ooo`3o0?oooeD0oooo000X0?ooo`030000003oool0oooo0?l0ooooE@3oool0
02P0oooo00<000000?ooo`3oool0o`3ooomE0?ooo`00:03oool00`000000oooo0?ooo`3o0?oooeD0
oooo003o0?oooh00oooo003o0?oooh00oooo003o0?oooh00oooo003o0?oooh00oooo003o0?oooh00
oooo003o0?oooh00oooo003o0?oooh00oooo003o0?oooh00oooo003o0?oooh00oooo003o0?oooh00
oooo0000\
\>"],
  ImageRangeCache->{{{0, 382.438}, {430.875, 0}} -> {-0.365174, -1.9397, \
0.0135054, 0.0135054}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(contourIntegrate[1\/\(z - 1\/2\), 
        z \[Rule] Exp[\[ImaginaryI]\ t] \((2  Cos[t] + 1)\), {t, 0, 
          2  \[Pi]}] // Simplify\)], "Input"],

Cell[BoxData[
    \(\((1 + 4\ \[ImaginaryI])\)\ \[Pi]\)], "Output"]
}, Closed]],

Cell["\<\
Version 3 gave only half the correct answer, Version 4 gave the correct \
answer, but Version 5.1 again gives an incorrect answer, this time including \
a spurious real part.  One must always adhere to the nuclear arms control \
adage:\
\>", "Text"],

Cell["Trust but verify!", "Advice"],

Cell["\<\
Evaluate a contour integral in which a simple pole is enclosed by a circle \
that is traversed twice.  Compare with the situation in which two loops of \
different sizes enclose the same pole.\
\>", "Exercise"],

Cell[TextData[{
  "Integrate ",
  Cell[BoxData[
      \(TraditionalForm\`1\/\(z - 1\/2\) - 2\/\(z - \[ImaginaryI] - 1\)\)]],
  " on both of the following contours: z\[Rule]Cos[t]+\[ImaginaryI] Sin[t] \
and z\[Rule]Exp[\[ImaginaryI] t](2Cos[t]+1) for {t,0,2\[Pi]}.  Comment on \
your results."
}], "Exercise"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Numerical integration", "Section"],

Cell[CellGroupData[{

Cell["Basic syntax", "Subsection"],

Cell[TextData[{
  "Although ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will often succeed in producing symbolic integrals for some quite \
unpromising integrands, many interesting integrals cannot be performed \
symbolically.  Furthermore, it is often more efficient to evaluate an \
integral numerically even when a symbolic result is available because many \
symbolic integrals are expressed in terms of rather complicated and \
unfamiliar functions anyway.  Not surprisingly, the function ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " provides for numerical integration is called ",
  ButtonBox["NIntegrate",
    ButtonStyle->"RefGuideLink"],
  " and is used with syntax virtually identical to that for symbolic \
integration.  Of course, the integrand must evaluate to a number, which \
sometimes requires wrapping the function ",
  StyleBox["Evaluate", "InlineInput",
    FontWeight->"Bold"],
  " around the integrand."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[Exp[\ Cos[t]\^2], {t, 0, 2  \[Pi]}]\)], "Input"],

Cell[BoxData[
    \(2\ \@\[ExponentialE]\ \[Pi]\ BesselI[0, 1\/2]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% // N\)], "Input"],

Cell[BoxData[
    \(11.016859547772212`\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NIntegrate[Exp[\ Cos[t]\^2], {t, 0, 2  \[Pi]}]\)], "Input"],

Cell[BoxData[
    \(11.016859547772865`\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Here is an example that ",
  StyleBox["Version 4 ",
    FontSlant->"Italic"],
  "can integrate symbolically, but",
  " ",
  StyleBox["Version 3",
    FontSlant->"Italic"],
  " cannot."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(integral = 
      Integrate[\(\(x\^2\) Exp[\(-x\)]\)\/\(1 + x\^3\), {x, 
          0, \[Infinity]}]\)], "Input"],

Cell[BoxData[
    \(MeijerG[{{0}, {}}, {{0, 0, 1\/3, 2\/3}, {}}, 1\/27]\/\(2\ \@3\ \
\[Pi]\)\)], "Output"]
}, Closed]],

Cell["\<\
However, few would find the symbolic result helpful!  Furthermore, numerical \
evaluation of this symbolic results does take measurable time \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({time1, ans1} = Timing[N[integral]]\)], "Input"],

Cell[BoxData[
    \({0.09399999999999764`\ Second, 0.2798612539023908`}\)], "Output"]
}, Closed]],

Cell["while direct numerical evaluation of the integral is faster", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({time2, ans2} = 
      Timing[NIntegrate[\(\(x\^2\) Exp[\(-x\)]\)\/\(1 + x\^3\), {x, 
            0, \[Infinity]}]]\)], "Input"],

Cell[BoxData[
    \({0.`\ Second, 0.27986125391049904`}\)], "Output"]
}, Closed]],

Cell["and gives the same result to high accuracy", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ans1 - ans2\)], "Input"],

Cell[BoxData[
    \(\(-8.108236304593675`*^-12\)\)], "Output"]
}, Closed]],

Cell["\<\
Although this difference in speed is unimportant for a single evaluation, one \
often needs to evaluate an integral many times within a larger program or \
loop for which efficiency does become important.  \
\>", "Text"],

Cell["\<\
Finally, one should always remember that no numerical algorithm is guaranteed \
to succeed for any input.  The integrand for the present example is so well \
behaved that numerical integration is obviously straightforward  \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[\(\(x\^2\) Exp[\(-x\)]\)\/\(1 + x\^3\), {x, 0, 5}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0147151 3.07657 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .16854 -24 -4.5 ]
[.01131 .16854 0 4.5 ]
[.01131 .32237 -18 -4.5 ]
[.01131 .32237 0 4.5 ]
[.01131 .4762 -24 -4.5 ]
[.01131 .4762 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(1)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(2)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(3)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(4)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16854 m
.03006 .16854 L
s
[(0.05)] .01131 .16854 1 0 Mshowa
.02381 .32237 m
.03006 .32237 L
s
[(0.1)] .01131 .32237 1 0 Mshowa
.02381 .4762 m
.03006 .4762 L
s
[(0.15)] .01131 .4762 1 0 Mshowa
.125 Mabswid
.02381 .04548 m
.02756 .04548 L
s
.02381 .07625 m
.02756 .07625 L
s
.02381 .10701 m
.02756 .10701 L
s
.02381 .13778 m
.02756 .13778 L
s
.02381 .19931 m
.02756 .19931 L
s
.02381 .23008 m
.02756 .23008 L
s
.02381 .26084 m
.02756 .26084 L
s
.02381 .29161 m
.02756 .29161 L
s
.02381 .35314 m
.02756 .35314 L
s
.02381 .3839 m
.02756 .3839 L
s
.02381 .41467 m
.02756 .41467 L
s
.02381 .44544 m
.02756 .44544 L
s
.02381 .50697 m
.02756 .50697 L
s
.02381 .53773 m
.02756 .53773 L
s
.02381 .5685 m
.02756 .5685 L
s
.02381 .59926 m
.02756 .59926 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01483 L
.02605 .01514 L
.02729 .01572 L
.02846 .0165 L
.03053 .01841 L
.03279 .02123 L
.03527 .02519 L
.0379 .03034 L
.04262 .04186 L
.05205 .07284 L
.06244 .1172 L
.10458 .35108 L
.12562 .46152 L
.14487 .53846 L
.15437 .56563 L
.15939 .57694 L
.16474 .5867 L
.16988 .59388 L
.17454 .59859 L
.17679 .60027 L
.17798 .601 L
.17923 .60166 L
.18032 .60215 L
.18152 .60258 L
.18262 .60289 L
.18364 .6031 L
.1849 .60326 L
.18554 .60331 L
.18624 .60332 L
.18748 .60326 L
.18865 .60312 L
.18931 .603 L
.19001 .60284 L
.19127 .60248 L
.19261 .60198 L
.19409 .60132 L
.19922 .59802 L
.20399 .59367 L
.21296 .58255 L
.22255 .5671 L
.26405 .47591 L
.30403 .38021 L
.34249 .29909 L
.38341 .2295 L
.42282 .17777 L
.4607 .13969 L
.50104 .10897 L
.53987 .0867 L
.58114 .06892 L
Mistroke
.6209 .05608 L
.65915 .04669 L
.69985 .03909 L
.73903 .03353 L
.78066 .02905 L
.82078 .02577 L
.85938 .02334 L
.90044 .02135 L
.93998 .01988 L
.97619 .01883 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{2, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00L@3oool00`3o_g@000000000
000300000003001d_`3oool0oooo0480oooo00<0oono07@000000000100000000`1d_ol0oooo0?oo
o`140?ooo`050;md00000000000000000018W=l0B03oool01@3ogi`0B000000000000000M;oo04H0
oooo00D0_g@0000000000000000007Boo`090?ooo`00M03oool00`2LB4P0W=oo0?ooo`160?ooo`03
0;md000007@0_ooo0080oooo00<0giad09cOo`3oool0A03oool01`2oM00007Bo0?ooo`3oool0oono
07@00018W=l0B@3oool00`2oM000M;oo0?ooo`150?ooo`070;md0000M;l0oooo0?ooo`3ogi`0B000
07Boo`080?ooo`00M03oool00`2LB4P0W=oo0?ooo`170?ooo`030?noM00004P0W=oo04d0oooo00<0
okmd001d_`3oool0B03oool00`2oM000M;oo0?ooo`1:0?ooo`030?noM000M;l0oooo00L0oooo001d
0?ooo`0309a8B02Lgol0oooo04P0oooo00<0omnL04P00018W=l0B`3oool00`3ogi`0B01809cOo`15
0?ooo`030=nLB0000000000000<0000000<0M;oo0?ooo`3oool0B03oool00`3o_g@007Bo0?ooo`07
0?ooo`00M03oool00`2LB4P0W=oo0?ooo`1:0?ooo`0309a80018W=l0oooo04L0oooo00@0gia80000
000004P0W=ooAP3oool01P3o_g@0001d0;ooo`3oool0_g@007Bood/0oooo00<0W4P007Boo`3oool0
1`3oool007@0oooo00<0W4Q809cOo`3oool0B`3oool00`2LB7@0_ooo0?ooo`180?ooo`030?oOW018
04P0W=oo04H0oooo00D0gia8001d_`3oool0_g@007Boo`160?ooo`030?oo_`1d0000000000800000
00<0B9cO0?ooo`3oool01`3oool007@0oooo00<0W4Q809cOo`3oool0AP3oool00`3OW4P0M;oo0?oo
o`020?ooo`030;md001d_ol0oooo04T0oooo00<0_g@007Boo`3oool0AP3oool0102LB000B9cO0;md
001d_om60?ooo`030?oo_`1d07@0_ooo00`0oooo001a0?ooo`050=nLB000000004RL09a8B02Lgol0
A`3oool01`3o_g@0001d0;ooo`3oool0okmd0000B02Lgol0A@3oool01`3o_g@0001809cOo`3oool0
omnL04P0B02Lgol0A`3oool0103ogi`0B01804Q8001d_om60?ooo`030?oo_`1d07@0_ooo00`0oooo
001c0?ooo`030=nLB00004P0W=oo04P0oooo00D0okmd000000000000001809cOo`170?ooo`050?oO
W018000000000000001d_ol0B@3oool00`3o_g@0000007Boo`160?ooo`030?oo_`1d000000000080
000000<0001d0;ooo`3oool01`3oool00?l0oooo/@3oool00?l0oooo/@3oool002P0oooo00<00000
0?ooo`3oool0o`3ooon60?ooo`00:03oool00`000000oooo0?ooo`3o0?ooohH0oooo000X0?ooo`03
0000003oool0oooo0?l0ooooQP3oool002P0oooo00<000000?ooo`3oool0o`3ooon60?ooo`00:03o
ool00`000000oooo0?ooo`3o0?ooohH0oooo000X0?ooo`030000003oool0oooo0?l0ooooQP3oool0
01l0ooooo`00002A00000040oooo000X0?ooo`030000003oool0000000d0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0203oool002P0oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00H0oooo5P00000:0?ooo`00:03oool01@000000oooo0?ooo`3oool0000004P0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool08`3ooolA000001D0oooo00<000000?ooo`3oool0203oool002P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oood00oooo4000000a0?ooo`00:03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo<@3oool?00000440oooo000X
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`d00000D03oool0
02P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oooa/0oooo2000001M0?oo
o`00:03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo4`3oool8000006D0
oooo000X0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3oool:0?ooo`P00000
K@3oool002P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooo`@0oooo1P00
001e0?ooo`00:03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?`0oooo1P00001k
0?ooo`00:03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?H0oooo1P0000210?oo
o`00:03oool3000000H0oooo00<000000?ooo`3oool0l@3oool4000008L0oooo000X0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0k@3oool4000008/0oooo000X0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0j@3oool4000008l0oooo000X0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0i03oool4000009<0oooo000X0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0h@3oool3000009L0oooo000X0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0gP3oool3000009X0oooo000X0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0f`3oool3000009d0oooo000X0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0eP3oool400000:00oooo000X0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0d`3oool300000:@0oooo000X0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0d03oool300000:L0oooo000X0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0c@3oool200000:X0oooo000X0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
b`3oool200000:`0oooo000X0?ooo`<000002@3oool00`000000oooo0?ooo`390?ooo`800000[P3o
ool002P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`360?ooo`<00000/03oool0
02P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`330?ooo`800000/`3oool002P0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`310?ooo`800000]@3oool002P0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2o0?ooo`800000]`3oool002P0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`2m0?ooo`800000^@3oool002P0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`2j0?ooo`800000^`3oool002P0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`2h0?ooo`800000_@3oool002P0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo0;d0oooo000X0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0]@3oool200000<00oooo000X0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0/P3oool200000<80oooo000X0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0/03oool200000<@0oooo000X0?ooo`<00000303oool00`00
0000oooo0?ooo`2^0?ooo`800000aP3oool002P0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo0<H0oooo000X0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`370?ooo`00:03oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0:T0oooo0P00003:0?ooo`00:03oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0bP3oool002P0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0</0oooo000X0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0Y@3oool200000<h0oooo000X0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`3>0?ooo`00:03o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0c`3o
ool002P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`2P0?ooo`800000dP3oool0
02P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo
0=80oooo000X0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0WP3oool00`000000
oooo0?ooo`3C0?ooo`00:03oool3000000h0oooo00<000000?ooo`3oool0W03oool200000=H0oooo
000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?oo
o`3F0?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo09T0oooo00<00000
0?ooo`3oool0e`3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2H0?oo
o`030000003oool0oooo0=P0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0U`3oool00`000000oooo0?ooo`3I0?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo09H0oooo00<000000?ooo`3oool0fP3oool002P0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0=/0oooo000X0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`3L0?ooo`00:03oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0g@3oool00080
oooo00D0okmd000000000000000007Boo`050?ooo`030;md0000000007Bo00D0oooo00D0okmd0000
00000000000007Boo`040?ooo`050;md0000000000000000001d_ol01P3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0gP3oool00080oooo00H0W4Qd
0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00D0oooo00H0W4Qd0;ooo`3oool0
oono07@0M02oool20?ooo`070;md0000M;l0oooo0?ooo`3ogi`0B00007Boo`050?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`3O0?ooo`0000<0oooo
0?noM000M;l00`3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030?noM000M;l0oooo0080oooo00<0gia8
04RLg`3oool01P3oool00`3o_g@007Bo0?ooo`040?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`3P0?ooo`0000<0oooo0=nLB018W=l00`3oool00`3o
_g@007Bo0?ooo`0:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool01P3oool00`3o
_g@007Bo0?ooo`040?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`3Q0?ooo`0000<0oooo0=nLB018W=l00`3oool00`3o_g@007Bo0?ooo`0:0?ooo`03
0=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool01P3oool00`2LB000M;oo0?ooo`040?ooo`@0
0000403oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0>80oooo00000`3oool0gia8
04RLg`030?ooo`030?noM000M;l0oooo00X0oooo00<0gia804RLg`3oool00P3oool01P3o_g@007Bo
0?ooo`3oool0oono07@000<0000000<0B9cO0?ooo`3oool0103oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo08/0oooo00<000000?ooo`3oool0h`3oool000030?ooo`3o_g@0B9cO00<0
oooo00<0gia804RLg`3oool02P3oool00`3o_g@0B9cO0?ooo`020?ooo`070=nLB018W=l0oooo0?oo
o`3ookl0M01d0;ooo`090?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0RP3oool0
0`000000oooo0?ooo`3T0?ooo`000P3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo``0oooo00H0
W4P007Boo`3oool0omnL04P0M02oool20?ooo`030?oo_`1d07@0_ooo00T0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0>D0oooo00020?ooo`050?oo
_`1d000000000000B02Lgol03@3oool01@3ookl0M0000000000004P0W=oo00<0oooo00<0oono07@0
000000000P0000000`0007@0_ooo0?ooo`040?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0Q`3oool00`000000oooo0?ooo`3V0?ooo`00:03oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool0i`3oool002P0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0>L0oooo000X0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`3X0?ooo`00:03oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0j@3oool0
02P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo
0>X0oooo000X0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0PP3oool00`000000
oooo0?ooo`3Z0?ooo`00:03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0840oooo
00<000000?ooo`3oool0j`3oool002P0oooo0`00000C0?ooo`030000003oool0oooo0800oooo00<0
00000?ooo`3oool0k03oool002P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1o
0?ooo`030000003oool0oooo0>d0oooo000X0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`3]0?ooo`00:03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo07d0oooo00<000000?ooo`3oool0kP3oool002P0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0>l0oooo000X0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`3`0?ooo`00:03oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0l03oool0
02P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo
0?40oooo000X0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`3b0?ooo`00:03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool0l`3oool002P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo0?<0oooo000X0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0MP3oool00`000000oooo0?ooo`3d0?ooo`00:03oool3000001D0oooo00<000000?oo
o`3oool0M@3oool00`000000oooo0?ooo`3e0?ooo`00:03oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool0mP3oool002P0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0?H0oooo000X0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`3g0?ooo`00:03oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0m`3oool0
02P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo
0?P0oooo000X0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0L@3oool00`000000
oooo0?ooo`3h0?ooo`00:03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0700oooo
00<000000?ooo`3oool0n@3oool002P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`1^0?ooo`030000003oool0oooo0?X0oooo000X0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0KP3oool00`000000oooo0?ooo`3j0?ooo`00:03oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo06d0oooo00<000000?ooo`3oool0n`3oool002P0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0?/0oooo000X0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`3l0?ooo`00:03o
ool3000001L0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`3l0?ooo`00:03oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0o@3oool0
02P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo
0?h0oooo000X0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0J@3oool00`000000
oooo0?ooo`3n0?ooo`00:03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo06P0oooo
00<000000?ooo`3oool0o`3oool002P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`1X0?ooo`030000003oool0oooo0?l0oooo000X0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0IP3oool00`000000oooo0?ooo`3o0?ooo`40oooo000X0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`3o0?ooo`40oooo000X0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3o0?ooo`80
oooo000X0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0I03oool00`000000oooo
0?ooo`3o0?ooo`<0oooo000X0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0I03o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo000X0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0H`3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000X0?ooo`<000006P3oool00`00
0000oooo0?ooo`1R0?ooo`030000003oool0oooo0?l0oooo103oool002P0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0?l0oooo1@3oool002P0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0?l0oooo
1@3oool002P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1P0?ooo`030000003o
ool0oooo0?l0oooo1P3oool002P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1O
0?ooo`030000003oool0oooo0?l0oooo1`3oool002P0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo0?l0oooo1`3oool002P0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0?l0oooo203oool002P0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0?l0oooo
203oool002P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1L0?ooo`030000003o
ool0oooo0?l0oooo2@3oool000/0oooo00D0okmd000000000000000007Boo`050?ooo`030;md0000
000007Bo00@0oooo00<0okmd0000000000000`0000000`00M;l0oooo0?ooo`030?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`3o0?ooo`T0oooo000;
0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`070?ooo`0309a8
B02Lgol0oooo00H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1K0?ooo`030000
003oool0oooo0?l0oooo2P3oool000X0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?oo
o`0=0?ooo`0309a8B02Lgol0oooo00H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo0?l0oooo2P3oool000X0oooo00<0gia804RLg`3oool00P3oool0
0`3o_g@007Bo0?ooo`0=0?ooo`0309a8B02Lgol0oooo00H0oooo1000000K0?ooo`030000003oool0
oooo05T0oooo00<000000?ooo`3oool0o`3oool;0?ooo`002P3oool00`3OW4P0B9cO0?ooo`020?oo
o`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0o`3oool;0?ooo`002P3oool00`3OW4P0
B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool01P3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0o`3oool<0?ooo`00
2P3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00d0oooo00<0W4Q809cOo`3oool0
1P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
o`3oool<0?ooo`002`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00D0gia800000000
B9`0W4Q809cOo`070?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`3o0?ooo`d0oooo000;0?ooo`050?oo_`1d000000000000B02Lgol03P3oool00`3O
W4P0001809cOo`070?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`3o0?ooo`d0oooo000X0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`3o0?ooo`h0oooo000X0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`3o0?ooo`h0oooo000X0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3o0?ooo`l0oooo000X
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3o
0?ooo`l0oooo000X0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0DP3oool00`00
0000oooo0?ooo`3o0?oooa00oooo000X0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`3o0?oooa00oooo000X0?ooo`<000007P3oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo0?l0oooo4@3oool002P0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0?l0oooo4@3oool002P0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0?l0oooo4P3oool0
02P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
0?l0oooo4P3oool002P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo0?l0oooo4`3oool002P0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo0?l0oooo4`3oool002P0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0?l0oooo503oool002P0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0?l0oooo503oool0
02P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
0?l0oooo5@3oool002P0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo0?l0oooo5@3oool002P0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo0?l0oooo5P3oool002P0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0?l0oooo5P3oool002P0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0?l0oooo5P3oool0
02P0oooo0`00000P0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0o`3ooolG0?oo
o`00:03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool0o`3ooolG0?ooo`00:03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool0o`3ooolH0?ooo`00:03oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00:03oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00:03oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0o`3ooolI0?oo
o`00:03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool0o`3ooolI0?ooo`00:03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0o`3ooolJ0?ooo`00:03oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`00:03oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`00:03oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0o`3ooolK0?oo
o`00:03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool0o`3ooolK0?ooo`00:03oool3000002<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`3o0?oooa`0oooo000X0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`3o0?oooa`0oooo000X0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`3o0?oooad0oooo000X0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`3o0?oooad0oooo000X0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`3o0?oooad0
oooo000X0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`3o0?oooah0oooo000X0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`3o0?oooah0oooo000X0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`3o0?oooal0oooo000X0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`3o0?oooal0oooo000X0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`3o0?oooal0
oooo000X0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`3o0?ooob00oooo000X0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`3o0?ooob00oooo000X0?ooo`<000009@3oool00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo0?l0oooo8@3oool002P0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo0?l0oooo8@3oool002P0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0?l0oooo8@3oool002P0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0?l0oooo
8P3oool002P0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo0?l0oooo8P3oool002P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo0?l0oooo8`3oool002P0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo0?l0oooo8`3oool002P0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0?l0oooo903oool002P0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0?l0oooo
903oool00080oooo00D0okmd000000000000000007Boo`050?ooo`030;md0000000007Bo00@0oooo
00<0okmd0000000000000`0000001@00M;l0oooo0?ooo`3oool0_g@000<0000000<0M;oo0?ooo`3o
ool0103oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool0o`3ooolT0?ooo`000P3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@00000
0000M;l01`3oool00`2LB4P0W=oo0?ooo`030?ooo`070;md0000M;l0oooo0?ooo`3ogi`0B00007Bo
o`050?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`3o0?ooobD0oooo00000`3oool0okmd001d_`030?ooo`030=nLB018W=l0oooo00d0oooo00<0W4Q8
09cOo`3oool0203oool00`3o_g@007Bo0?ooo`040?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`3o0?ooobD0oooo00000`3oool0gia804RLg`030?oo
o`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool0203oool00`3o_g@007Bo0?ooo`040?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`3o0?oo
obH0oooo00000`3oool0gia804RLg`030?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3o
ool0203oool00`2LB000M;oo0?ooo`040?ooo`@000009`3oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo0?l0oooo9P3oool000030?ooo`3OW4P0B9cO00<0oooo00<0okmd001d_`3oool0
3@3oool00`2LB4P0W=oo0?ooo`030?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0
103oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
o`3ooolV0?ooo`0000<0oooo0?noM018W=l00`3oool00`3OW4P0B9cO0?ooo`0=0?ooo`0309a8B02L
gol0oooo00<0oooo00<0oono07@0M02oool02@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool0o`3ooolW0?ooo`000P3oool01P2LB000M;oo0?ooo`3o
gi`0B01d0;ooo`/0oooo00D0gia800000000B9`0W4Q809cOo`040?ooo`030?oo_`1d07@0_ooo00T0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0?l0
oooo9`3oool00080oooo00D0oono07@000000000001809cOo`0>0?ooo`030=nLB00004P0W=oo00@0
oooo00<0oono07@0000000000P0000000`0007@0_ooo0?ooo`040?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`3o0?ooobP0oooo000X0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`3o0?ooobP0oooo
000X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`3o0?ooobT0oooo000X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`3o0?ooobT0oooo000X0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`3o0?ooobX0oooo000X0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`3o0?ooobX0oooo000X0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`3o0?ooobX0oooo
000X0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`3o0?ooob/0oooo000X0?ooo`<00000:`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo0?l0oooo:`3oool002P0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo0?l0oooo;03oool002P0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo;03oool002P0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0?l0oooo;@3oool002P0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0oooo;@3o
ool002P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo0?l0oooo;P3oool002P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo0?l0oooo;P3oool002P0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo0?l0oooo;P3oool002P0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0oooo;`3oool002P0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0oooo;`3o
ool002P0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo0?l0oooo<03oool002P0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0?l0oooo<03oool002P0oooo0`00000^0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0o`3ooola0?ooo`00:03oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooola0?ooo`00:03oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0o`3ooolb0?ooo`00:03oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0o`3ooolb
0?ooo`00:03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0o`3ooolb0?ooo`00:03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0o`3ooolc0?ooo`00:03oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooolc0?ooo`00:03oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0o`3ooold0?ooo`00:03oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0o`3ooold
0?ooo`00:03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0o`3ooole0?ooo`00:03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0o`3ooole0?ooo`00:03oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`00:03oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`00:03oool3
000003<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?ooocL0oooo000X0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?oo
ocL0oooo000X0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`3o0?ooocP0oooo000X0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`3o0?ooocT0oooo000X0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooocT0oooo000X0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooocX0oooo000X0?oo
o`030000003oool0oooo03D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?oo
oc/0oooo000X0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`3o0?oooc`0oooo000X0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`3o0?oooc`0oooo000X0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooocd0oooo000X0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oooch0oooo000X0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oo
ocl0oooo000X0?ooo`<00000>P3oool2000000L0oooo00<000000?ooo`3oool0o`3ooom00?ooo`00
:03oool00`000000oooo0?ooo`0k0?ooo`P00000o`3ooom30?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooohH0oooo000X0?ooo`030000003oool0oooo0?l0ooooQP3oool002P0oooo00<000000?oo
o`3oool0o`3ooon60?ooo`00:03oool00`000000oooo0?ooo`3o0?ooohH0oooo000X0?ooo`030000
003oool0oooo0?l0ooooQP3oool002P0oooo00<000000?ooo`3oool0o`3ooon60?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.538723, -0.0176278, \
0.0197114, 0.00122037}}]
}, Closed]],

Cell[TextData[{
  "but Murphy's Law decrees that the integral you need for your work will not \
be as compliant.  You must treat any singularities or unusually rapid changes \
carefully.  Numerical integration often has difficulties with infinite ranges \
if the integrand does not decrease sufficiently rapidly or oscillates.  Often \
one can improve the convergence by a suitable change of variable or by \
subdividing the integration range.  ",
  StyleBox["NIntegrate", "InlineInput",
    FontWeight->"Bold"],
  " also provides several options "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[NIntegrate]\)], "Input"],

Cell[BoxData[
    \({AccuracyGoal \[Rule] \[Infinity], Compiled \[Rule] True, 
      EvaluationMonitor \[Rule] None, GaussPoints \[Rule] Automatic, 
      MaxPoints \[Rule] Automatic, MaxRecursion \[Rule] 6, 
      Method \[Rule] Automatic, MinRecursion \[Rule] 0, 
      PrecisionGoal \[Rule] Automatic, SingularityDepth \[Rule] 4, 
      WorkingPrecision \[Rule] MachinePrecision}\)], "Output"]
}, Closed]],

Cell["\<\
which can often tame a slowly convergent integral by brute force, but insight \
into the properties of your integral is usually preferred.  However, a \
systematic treatment of reluctant integrals is beyond the scope of this \
course.\
\>", "Text"],

Cell[TextData[{
  "Compare symbolic and numerical evaluations of ",
  Cell[BoxData[
      \(\[Integral]\_0\%1\(\( \[Omega]\^4\) \[ExponentialE]\^\[Omega]\)\/\((\
\[ExponentialE]\^\[Omega] - 1)\)\^2\)]],
  "."
}], "Exercise"],

Cell[TextData[{
  "Evaluate ",
  Cell[BoxData[
      \(\[Integral]\_0\%\[Infinity]\(\( \[Omega]\^4\) \[ExponentialE]\^\
\[Omega]\)\/\((\[ExponentialE]\^\[Omega] - 1)\)\^2\)]],
  " numerically.  [Hint: use LogPlot to examine the integrand.]"
}], "Exercise"],

Cell[CellGroupData[{

Cell["Example: finite Fourier-Bessel transform", "Subsubsection"],

Cell["\<\
Consider a spherically symmetric three-dimensional density of charge or mass \
that is relatively large near the origin and vanishingly small for large \
distances.  An example dear to the author's heart is the density of atomic \
nuclei, which is reasonably well approximated by the simple function\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[\[Rho]];\)\), "\n", 
    \(\(\[Rho] = \ \(1 + w\ \((r/c)\)\^2\)\/\(1 + Exp[\((r - \
c)\)/a]\);\)\)}], "Input"],

Cell[TextData[{
  "A typical case is shown below.  Note that the central density is \
normalized artificially to unity.  The density is fairly constant for small \
radii and then decays to zero in a distance of order ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " near the surface radius ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(values\  = \ {c \[Rule] 2.5, a \[Rule] 0.5, 
          w \[Rule] 0.2};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[\[Rho] /. values], {r, 0, 8}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0147151 0.59257 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -3 -9 ]
[.7381 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .13323 -18 -4.5 ]
[.01131 .13323 0 4.5 ]
[.01131 .25174 -18 -4.5 ]
[.01131 .25174 0 4.5 ]
[.01131 .37026 -18 -4.5 ]
[.01131 .37026 0 4.5 ]
[.01131 .48877 -18 -4.5 ]
[.01131 .48877 0 4.5 ]
[.01131 .60728 -6 -4.5 ]
[.01131 .60728 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(2)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(4)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(6)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(8)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.08333 .01472 m
.08333 .01847 L
s
.14286 .01472 m
.14286 .01847 L
s
.20238 .01472 m
.20238 .01847 L
s
.32143 .01472 m
.32143 .01847 L
s
.38095 .01472 m
.38095 .01847 L
s
.44048 .01472 m
.44048 .01847 L
s
.55952 .01472 m
.55952 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.67857 .01472 m
.67857 .01847 L
s
.79762 .01472 m
.79762 .01847 L
s
.85714 .01472 m
.85714 .01847 L
s
.91667 .01472 m
.91667 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13323 m
.03006 .13323 L
s
[(0.2)] .01131 .13323 1 0 Mshowa
.02381 .25174 m
.03006 .25174 L
s
[(0.4)] .01131 .25174 1 0 Mshowa
.02381 .37026 m
.03006 .37026 L
s
[(0.6)] .01131 .37026 1 0 Mshowa
.02381 .48877 m
.03006 .48877 L
s
[(0.8)] .01131 .48877 1 0 Mshowa
.02381 .60728 m
.03006 .60728 L
s
[(1)] .01131 .60728 1 0 Mshowa
.125 Mabswid
.02381 .04434 m
.02756 .04434 L
s
.02381 .07397 m
.02756 .07397 L
s
.02381 .1036 m
.02756 .1036 L
s
.02381 .16286 m
.02756 .16286 L
s
.02381 .19249 m
.02756 .19249 L
s
.02381 .22211 m
.02756 .22211 L
s
.02381 .28137 m
.02756 .28137 L
s
.02381 .311 m
.02756 .311 L
s
.02381 .34063 m
.02756 .34063 L
s
.02381 .39989 m
.02756 .39989 L
s
.02381 .42951 m
.02756 .42951 L
s
.02381 .45914 m
.02756 .45914 L
s
.02381 .5184 m
.02756 .5184 L
s
.02381 .54803 m
.02756 .54803 L
s
.02381 .57766 m
.02756 .57766 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.03279 .60279 L
.04262 .60233 L
.05288 .60197 L
.06244 .60171 L
.08451 .60126 L
.09413 .60103 L
.0992 .60087 L
.10458 .60068 L
.10954 .60046 L
.115 .60016 L
.12462 .59945 L
.13441 .59844 L
.14357 .59713 L
.15395 .59513 L
.16382 .5926 L
.17268 .58969 L
.18234 .58572 L
.20202 .57448 L
.21302 .56598 L
.22299 .55667 L
.24224 .53387 L
.26306 .50135 L
.30406 .41408 L
.34355 .31241 L
.38152 .2187 L
.40266 .17436 L
.42194 .1402 L
.44215 .11084 L
.46085 .08908 L
.47994 .0715 L
.5007 .05678 L
.51936 .04669 L
.53996 .03826 L
.55931 .03234 L
.58017 .02758 L
.60021 .02422 L
.62131 .02161 L
.64105 .01982 L
.65942 .01858 L
.67987 .01754 L
.69846 .01684 L
.71765 .0163 L
.73844 .01587 L
.75832 .01557 L
.77936 .01533 L
.79894 .01517 L
.81725 .01506 L
.83754 .01497 L
.85607 .01491 L
Mistroke
.8751 .01486 L
.89583 .01482 L
.91554 .01479 L
.93653 .01477 L
.95697 .01476 L
.97619 .01475 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00O@3oool00`3ookl0M000000000040000000307Boo`3oool0oooo05X0oooo00D0omnL04P0
00000000000007Boo`1K0?ooo`050;md0000000000000000M02oool0F`3oool01@2oM00000000000
0000000007Bo00X0oooo001n0?ooo`030;md000007@0_ooo0080oooo00<0giad09cOo`3oool0G@3o
ool00`2oM000M;oo0?ooo`1J0?ooo`060=nLB000M;l0oooo0?ooo`3o_g@007BoFP3oool00`3o_g@0
07Bo0?ooo`020?ooo`030;mdB02Lgol0oooo00P0oooo001o0?ooo`030?noM00004P0W=oo0640oooo
00<0_g@007Boo`3oool0F@3oool00`3ookl0M00007Boo`020?ooo`030?oo_`1dB9`0oooo05T0oooo
00<0gia804RLg`3oool00P3oool00`2oM000M;oo0?ooo`080?ooo`00P03oool00`3ogi`0B00004RL
g`1L0?ooo`030=nLB0000000000000<0000000<0M;oo0?ooo`3oool0E`3oool01`3o_g@004Q807@0
M02oool0oooo0=nLB000M;l0FP3oool00`3o_g@004RL0?ooo`020?ooo`0309a8B02Lgol0oooo00P0
oooo00220?ooo`0309a80018W=l0oooo05X0oooo00H0okmd0000M02oool0oooo0;md001d_omJ0?oo
o`030?oOW018B9`0okmd0080000000<004RL0?ooo`3oool0FP3oool01@3OW4P00000000000000000
B9cO00X0oooo00230?ooo`0309a8M02oool0oooo05X0oooo00D0gia8001d_`3oool0_g@007Boo`1J
0?ooo`030?oo_`1d07@0_ooo05h0oooo00<0oono07A8W03oool00P3oool00`2LB7@0_ooo0?ooo`08
0?ooo`00OP3oool00`3OW4P0M;oo0?ooo`020?ooo`030;md001d_ol0oooo05/0oooo00@0W4P004RL
g`2oM000M;ooF`3oool00`2oM000B9cO0?ooo`1M0?ooo`030?noM018W=l0oooo0080oooo00<0_g@0
07Boo`3oool0203oool007h0oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo05`0oooo00@0
omnL04P0B018B000M;ooF`3oool00`3ookl0M000001d_`1M0?ooo`070?oOW01807@0_ooo0?ooo`3o
gi`0B01d0;ooo`090?ooo`00O`3oool01@3o_g@000000000000004P0W=oo05h0oooo00<0okmd0000
001d_ol0G@3oool0102oM000000000000000B9aK0?ooo`050?noM000000000000000B02Lgol02P3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00240oooo00<000000?ooo`3oool0o`3ooon=0?ooo`00
8@3oool00`000000oooo0?ooo`3o0?ooohd0oooo000Q0?ooo`030000003oool0oooo0?l0ooooS@3o
ool00240oooo00<000000?ooo`3oool0o`3ooon=0?ooo`008@3oool00`000000oooo0?ooo`3o0?oo
ohd0oooo000Q0?ooo`030000003oool0oooo0?l0ooooS@3oool001L0ooooo`00002H00000080oooo
000Q0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3ooolX000000/0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool02@3oool00240oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`02
0?oooa0000000`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool02@3oool00240oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1M0?oo
o`030000003oool0oooo02/0oooo2000000[0?ooo`030000003oool0oooo05h0oooo00<000000?oo
o`3oool02@3oool00240oooo00<000000?ooo`3oool0i03oool800000:00oooo000Q0?ooo`030000
003oool0oooo0=d0oooo1`00002X0?ooo`008@3oool00`000000oooo0?ooo`3I0?ooo`@00000[`3o
ool00240oooo00<000000?ooo`3oool0e@3oool400000;<0oooo000Q0?ooo`030000003oool0oooo
0=<0oooo0P00002g0?ooo`008@3oool00`000000oooo0?ooo`3@0?ooo`<00000^@3oool00240oooo
00<000000?ooo`3oool0c@3oool300000;`0oooo000Q0?ooo`030000003oool0oooo0</0oooo0P00
002o0?ooo`008@3oool200000<T0oooo0`0000310?ooo`008@3oool00`000000oooo0?ooo`360?oo
o`800000a03oool00240oooo00<000000?ooo`3oool0a03oool200000<H0oooo000Q0?ooo`030000
003oool0oooo0<80oooo0P0000380?ooo`008@3oool00`000000oooo0?ooo`300?ooo`800000bP3o
ool00240oooo00<000000?ooo`3oool0_P3oool200000<`0oooo000Q0?ooo`030000003oool0oooo
0;d0oooo00<000000?ooo`3oool0c03oool00240oooo00<000000?ooo`3oool0^`3oool200000<l0
oooo000Q0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0c`3oool00240oooo00<0
00000?ooo`3oool0^@3oool00`000000oooo0?ooo`3@0?ooo`008@3oool00`000000oooo0?ooo`2g
0?ooo`800000d`3oool00240oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`3C0?oo
o`008@3oool200000;H0oooo00<000000?ooo`3oool0e03oool00240oooo00<000000?ooo`3oool0
]03oool00`000000oooo0?ooo`3E0?ooo`008@3oool00`000000oooo0?ooo`2c0?ooo`030000003o
ool0oooo0=H0oooo000Q0?ooo`030000003oool0oooo0;40oooo0P00003I0?ooo`008@3oool00`00
0000oooo0?ooo`2`0?ooo`030000003oool0oooo0=T0oooo000Q0?ooo`030000003oool0oooo0:l0
oooo00<000000?ooo`3oool0fP3oool00240oooo00<000000?ooo`3oool0[P3oool00`000000oooo
0?ooo`3K0?ooo`008@3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0=`0oooo000Q
0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0g@3oool00240oooo00<000000?oo
o`3oool0[03oool00`000000oooo0?ooo`3M0?ooo`008@3oool00`000000oooo0?ooo`2[0?ooo`03
0000003oool0oooo0=h0oooo000Q0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0
g`3oool00240oooo0P00002Z0?ooo`030000003oool0oooo0>00oooo000Q0?ooo`030000003oool0
oooo0:T0oooo00<000000?ooo`3oool0h03oool00240oooo00<000000?ooo`3oool0Z03oool00`00
0000oooo0?ooo`3Q0?ooo`008@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0>80
oooo000Q0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0h`3oool00240oooo00<0
00000?ooo`3oool0YP3oool00`000000oooo0?ooo`3S0?ooo`008@3oool00`000000oooo0?ooo`2U
0?ooo`030000003oool0oooo0>@0oooo000Q0?ooo`030000003oool0oooo0:@0oooo00<000000?oo
o`3oool0i@3oool00240oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`3U0?ooo`00
0`3oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l00`3oool00`3ookl0
M000000000040000000307Boo`3oool0oooo00@0oooo00<000000?ooo`3oool0X`3oool00`000000
oooo0?ooo`3V0?ooo`000`3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@00000
0000M;l0103oool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo00D0oooo00<000000?oo
o`3oool0XP3oool00`000000oooo0?ooo`3W0?ooo`000P3oool00`3o_g@007Bo0?ooo`020?ooo`03
0=nLB018W=l0oooo00/0oooo00<0okmd0000B02Lgol02@3oool00`000000oooo0?ooo`2R0?ooo`03
0000003oool0oooo0>L0oooo00020?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0
303oool00`3ogi`0B00004RLg`080?ooo`<00000X@3oool00`000000oooo0?ooo`3X0?ooo`000P3o
ool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00h0oooo00<0W4P004RLg`3oool01P3o
ool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo0>T0oooo00020?ooo`030=nLB018W=l0
oooo0080oooo00<0okmd001d_`3oool03`3oool00`2LB7@0_ooo0?ooo`050?ooo`030000003oool0
oooo0:00oooo00<000000?ooo`3oool0j@3oool00080oooo00<0okmd04RLg`3oool00P3oool00`3O
W4P0B9cO0?ooo`0:0?ooo`030=nLB01d_ol0oooo0080oooo00<0_g@007Boo`3oool01@3oool00`00
0000oooo0?ooo`2O0?ooo`030000003oool0oooo0>X0oooo00030?ooo`0609a8001d_ol0oooo0?oO
W01807@0_ooo2`3oool01`3o_g@0001d0;ooo`3oool0okmd0000B02Lgol01P3oool00`000000oooo
0?ooo`2N0?ooo`030000003oool0oooo0>/0oooo00030?ooo`050?oo_`1d000000000000B02Lgol0
3@3oool01@3o_g@000000000000004P0W=oo00L0oooo00<000000?ooo`3oool0WP3oool00`000000
oooo0?ooo`3[0?ooo`008@3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo0>`0oooo
000Q0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0k03oool00240oooo00<00000
0?ooo`3oool0W03oool00`000000oooo0?ooo`3]0?ooo`008@3oool00`000000oooo0?ooo`2L0?oo
o`030000003oool0oooo0>d0oooo000Q0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3o
ool0kP3oool00240oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`3_0?ooo`008@3o
ool2000009/0oooo00<000000?ooo`3oool0k`3oool00240oooo00<000000?ooo`3oool0V@3oool0
0`000000oooo0?ooo`3`0?ooo`008@3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo
0?00oooo000Q0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0l@3oool00240oooo
00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`3a0?ooo`008@3oool00`000000oooo0?oo
o`2G0?ooo`030000003oool0oooo0?80oooo000Q0?ooo`030000003oool0oooo09H0oooo00<00000
0?ooo`3oool0l`3oool00240oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`3c0?oo
o`008@3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0?@0oooo000Q0?ooo`030000
003oool0oooo09D0oooo00<000000?ooo`3oool0m03oool00240oooo00<000000?ooo`3oool0U03o
ool00`000000oooo0?ooo`3e0?ooo`008@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0
oooo0?D0oooo000Q0?ooo`800000U03oool00`000000oooo0?ooo`3f0?ooo`008@3oool00`000000
oooo0?ooo`2C0?ooo`030000003oool0oooo0?H0oooo000Q0?ooo`030000003oool0oooo0980oooo
00<000000?ooo`3oool0m`3oool00240oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?oo
o`3g0?ooo`008@3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0?P0oooo000Q0?oo
o`030000003oool0oooo0940oooo00<000000?ooo`3oool0n03oool00240oooo00<000000?ooo`3o
ool0T03oool00`000000oooo0?ooo`3i0?ooo`008@3oool00`000000oooo0?ooo`2@0?ooo`030000
003oool0oooo0?T0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0nP3o
ool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`3j0?ooo`008@3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo0?/0oooo000Q0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool0n`3oool00240oooo0P00002?0?ooo`030000003oool0oooo0?/0oooo
000Q0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0o03oool00240oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`3l0?ooo`008@3oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo0?d0oooo000Q0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool0o@3oool00240oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3m0?ooo`008@3o
ool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo0?h0oooo000Q0?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`3oool0oP3oool00240oooo00<000000?ooo`3oool0RP3oool00`00
0000oooo0?ooo`3o0?ooo`000`3oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@00000
0000M;l01P3oool01@3ogi`0B000000000000000M;oo00H0oooo00<000000?ooo`3oool0RP3oool0
0`000000oooo0?ooo`3o0?ooo`000`3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0
_g@000000000M;l0203oool00`2oM000M;oo0?ooo`060?ooo`030000003oool0oooo08X0oooo00<0
00000?ooo`3oool0o`3oool00080oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0>
0?ooo`030;md001d_ol0oooo00H0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`3o
0?ooo`40oooo00020?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool00`3O
W4P00000000000030000000307Boo`3oool0oooo00@0oooo0`0000290?ooo`030000003oool0oooo
0?l0oooo0@3oool00080oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`06
0?noM00007@0_ooo0?ooo`2oM000M;oo1`3oool00`000000oooo0?ooo`280?ooo`030000003oool0
oooo0?l0oooo0P3oool00080oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0;0?oo
o`050=nLB000M;l0oooo0;md001d_ol01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0
oooo0?l0oooo0P3oool00080oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0<0?oo
o`0409a80018W=l0_g@007Boo`L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`3o
0?ooo`80oooo00030?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo3@3oool0103ogi`0B01804Q8
001d_ol70?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0o`3oool30?ooo`000`3o
ool01@3ookl0M0000000000004P0W=oo00l0oooo00<0okmd0000001d_ol01`3oool00`000000oooo
0?ooo`270?ooo`030000003oool0oooo0?l0oooo0`3oool00240oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`3o0?ooo`@0oooo000Q0?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool0o`3oool40?ooo`008@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
0?l0oooo103oool00240oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`3o0?ooo`D0
oooo000Q0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0o`3oool50?ooo`008@3o
ool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0?l0oooo1@3oool00240oooo0P000025
0?ooo`030000003oool0oooo0?l0oooo1P3oool00240oooo00<000000?ooo`3oool0Q03oool00`00
0000oooo0?ooo`3o0?ooo`H0oooo000Q0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3o
ool0o`3oool70?ooo`008@3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo0?l0oooo
1`3oool00240oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`3o0?ooo`L0oooo000Q
0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0o`3oool80?ooo`008@3oool00`00
0000oooo0?ooo`220?ooo`030000003oool0oooo0?l0oooo203oool00240oooo00<000000?ooo`3o
ool0P@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000Q0?ooo`030000003oool0oooo0840oooo
00<000000?ooo`3oool0o`3oool90?ooo`008@3oool00`000000oooo0?ooo`210?ooo`030000003o
ool0oooo0?l0oooo2@3oool00240oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`3o
0?ooo`X0oooo000Q0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0o`3oool:0?oo
o`008@3oool200000800oooo00<000000?ooo`3oool0o`3oool;0?ooo`008@3oool00`000000oooo
0?ooo`1o0?ooo`030000003oool0oooo0?l0oooo2`3oool00240oooo00<000000?ooo`3oool0O`3o
ool00`000000oooo0?ooo`3o0?ooo`/0oooo000Q0?ooo`030000003oool0oooo07h0oooo00<00000
0?ooo`3oool0o`3oool<0?ooo`008@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo
0?l0oooo303oool00240oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`3o0?ooo`d0
oooo000Q0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0o`3oool=0?ooo`008@3o
ool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0?l0oooo3@3oool00240oooo00<00000
0?ooo`3oool0O03oool00`000000oooo0?ooo`3o0?ooo`h0oooo000Q0?ooo`030000003oool0oooo
07`0oooo00<000000?ooo`3oool0o`3oool>0?ooo`008@3oool00`000000oooo0?ooo`1k0?ooo`03
0000003oool0oooo0?l0oooo3`3oool00240oooo00<000000?ooo`3oool0N`3oool00`000000oooo
0?ooo`3o0?ooo`l0oooo000Q0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0o`3o
ool?0?ooo`008@3oool2000007/0oooo00<000000?ooo`3oool0o`3oool@0?ooo`008@3oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo0?l0oooo403oool00240oooo00<000000?ooo`3o
ool0NP3oool00`000000oooo0?ooo`3o0?oooa00oooo000Q0?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool0o`3ooolA0?ooo`008@3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo0?l0oooo4@3oool00240oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`3o
0?oooa80oooo000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0o`3ooolB0?oo
o`008@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0?l0oooo4P3oool000<0oooo
00D0okmd000000000000000007Boo`050?ooo`030;md0000000007Bo00H0oooo00D0_g@000000000
0000001d0;ooo`060?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0o`3ooolC0?oo
o`000`3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l01@3oool0
1P3OW4P007Bo0?ooo`3oool0okmd001d_`H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`3o0?oooa<0oooo00020?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool02P3o
ool00`3ookl0M00007Boo`020?ooo`030?oo_`1dB9`0oooo00D0oooo00<000000?ooo`3oool0MP3o
ool00`000000oooo0?ooo`3o0?oooa@0oooo00020?ooo`030=nLB018W=l0oooo0080oooo00<0okmd
001d_`3oool02P3oool01`3o_g@004Q807@0M02oool0oooo0=nLB000M;l01P3oool00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo0?l0oooo503oool00080oooo00<0gia804RLg`3oool00P3o
ool00`3o_g@007Bo0?ooo`0:0?ooo`030?oOW018B9`0okmd0080000000<004RL0?ooo`3oool01@3o
ool3000007H0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`000P3oool00`3OW4P0B9cO0?ooo`02
0?ooo`030?noM000M;l0oooo00X0oooo00<0oono07@0M02oool02P3oool00`000000oooo0?ooo`1e
0?ooo`030000003oool0oooo0?l0oooo5@3oool00080oooo00<0okmd04RLg`3oool00P3oool00`3O
W4P0B9cO0?ooo`0;0?ooo`030;md0018W=l0oooo00T0oooo00<000000?ooo`3oool0M@3oool00`00
0000oooo0?ooo`3o0?oooaD0oooo00030?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo303oool0
0`3ookl0M000001d_`090?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0o`3ooolF
0?ooo`000`3oool01@3ookl0M0000000000004P0W=oo00l0oooo00@0_g@000000000000004RL1P3o
ool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0?l0oooo5P3oool00240oooo00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`3o0?oooaH0oooo000Q0?ooo`030000003oool0oooo
07<0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`008@3oool00`000000oooo0?ooo`1c0?ooo`03
0000003oool0oooo0?l0oooo5`3oool00240oooo00<000000?ooo`3oool0L`3oool00`000000oooo
0?ooo`3o0?oooaL0oooo000Q0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0o`3o
oolH0?ooo`008@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0?l0oooo603oool0
0240oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`3o0?oooaT0oooo000Q0?ooo`80
0000LP3oool00`000000oooo0?ooo`3o0?oooaT0oooo000Q0?ooo`030000003oool0oooo0740oooo
00<000000?ooo`3oool0o`3ooolI0?ooo`008@3oool00`000000oooo0?ooo`1`0?ooo`030000003o
ool0oooo0?l0oooo6P3oool00240oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`3o
0?oooaX0oooo000Q0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0o`3ooolK0?oo
o`008@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0?l0oooo6`3oool00240oooo
00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`3o0?oooa/0oooo000Q0?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`008@3oool00`000000oooo0?ooo`1^
0?ooo`030000003oool0oooo0?l0oooo703oool00240oooo00<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`3o0?oooad0oooo000Q0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3o
ool0o`3ooolM0?ooo`008@3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0?l0oooo
7P3oool00240oooo0P00001]0?ooo`030000003oool0oooo0?l0oooo7P3oool00240oooo00<00000
0?ooo`3oool0J`3oool00`000000oooo0?ooo`3o0?oooal0oooo000Q0?ooo`030000003oool0oooo
06/0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`008@3oool00`000000oooo0?ooo`1Z0?ooo`03
0000003oool0oooo0?l0oooo803oool00240oooo00<000000?ooo`3oool0JP3oool00`000000oooo
0?ooo`3o0?ooob00oooo000Q0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0o`3o
oolQ0?ooo`008@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0?l0oooo8@3oool0
0240oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`3o0?ooob80oooo000Q0?ooo`03
0000003oool0oooo06P0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`008@3oool00`000000oooo
0?ooo`1W0?ooo`030000003oool0oooo0?l0oooo8`3oool00240oooo00<000000?ooo`3oool0I`3o
ool00`000000oooo0?ooo`3o0?ooob<0oooo000Q0?ooo`030000003oool0oooo06H0oooo00<00000
0?ooo`3oool0o`3ooolT0?ooo`008@3oool2000006L0oooo00<000000?ooo`3oool0o`3ooolT0?oo
o`008@3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0?l0oooo903oool00240oooo
00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3o0?ooobD0oooo000Q0?ooo`030000003o
ool0oooo06D0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`008@3oool00`000000oooo0?ooo`1T
0?ooo`030000003oool0oooo0?l0oooo9P3oool00240oooo00<000000?ooo`3oool0I03oool00`00
0000oooo0?ooo`3o0?ooobH0oooo000Q0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool0o`3ooolW0?ooo`008@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0?l0oooo
9`3oool000<0oooo00D0okmd000000000000000007Boo`050?ooo`030;md0000000007Bo00D0oooo
00D0_g@00000000000000000001d_`070?ooo`030000003oool0oooo0680oooo00<000000?ooo`3o
ool0o`3ooolX0?ooo`000`3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@00000
0000M;l0103oool00`3o_g@007Bo0?ooo`020?ooo`030;mdB02Lgol0oooo00D0oooo00<000000?oo
o`3oool0HP3oool00`000000oooo0?ooo`3o0?ooobP0oooo00020?ooo`030?noM000M;l0oooo0080
oooo00<0gia804RLg`3oool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`030;md001d_ol0oooo00D0
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`3o0?ooobT0oooo00020?ooo`030=nL
B018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool00`3o_g@004RL0?ooo`020?ooo`0309a8
B02Lgol0oooo00D0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`3o0?ooobT0oooo
00020?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02`3oool01@3OW4P000000000
00000000B9cO00L0oooo0`00001P0?ooo`030000003oool0oooo0?l0oooo:P3oool00080oooo00<0
gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`030?oo_`1dB9`0oooo0080oooo00<0
W4Qd0;ooo`3oool01@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0?l0oooo:P3o
ool00080oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030?noM018W=l0
oooo0080oooo00<0_g@007Boo`3oool01@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0
oooo0?l0oooo:`3oool000<0oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`070?oOW018
07@0_ooo0?ooo`3ogi`0B01d0;ooo`060?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3o
ool0o`3oool[0?ooo`000`3oool01@3ookl0M0000000000004P0W=oo00d0oooo00D0okmd00000000
0000001809cOo`070?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0o`3oool/0?oo
o`008@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0?l0oooo;03oool00240oooo
00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`3o0?ooobd0oooo000Q0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0o`3oool]0?ooo`008@3oool00`000000oooo0?ooo`1L
0?ooo`030000003oool0oooo0?l0oooo;P3oool00240oooo00<000000?ooo`3oool0G03oool00`00
0000oooo0?ooo`3o0?ooobh0oooo000Q0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3o
ool0o`3oool_0?ooo`008@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0?l0oooo
<03oool00240oooo0P00001K0?ooo`030000003oool0oooo0?l0oooo<03oool00240oooo00<00000
0?ooo`3oool0F@3oool00`000000oooo0?ooo`3o0?oooc40oooo000Q0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`008@3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo0?l0oooo<P3oool00240oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`3o0?oooc<0oooo000Q0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0o`3o
oolc0?ooo`008@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0?l0oooo=03oool0
0240oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`3o0?ooocD0oooo000Q0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`008@3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo0?l0oooo=`3oool00240oooo00<000000?ooo`3oool0DP3o
ool00`000000oooo0?ooo`3o0?ooocP0oooo000Q0?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool0o`3ooolh0?ooo`008@3oool200000580oooo00<000000?ooo`3oool0o`3oooli0?oo
o`008@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0?l0oooo>P3oool00240oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`3o0?oooc/0oooo000Q0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool0o`3oooll0?ooo`008@3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo0?l0oooo?@3oool00240oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`3o0?oooch0oooo000Q0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3o
ool0o`3ooolo0?ooo`008@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0?l0oooo
@03oool00240oooo00<000000?ooo`3oool0B03oool200000?l0oooo@`3oool00240oooo00<00000
0?ooo`3oool0AP3oool200000?l0ooooA@3oool00240oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`3o0?ooodD0oooo000Q0?ooo`030000003oool0oooo04<0oooo0P00003o0?ooodP0
oooo000Q0?ooo`800000@`3oool00`000000oooo0?ooo`3o0?ooodP0oooo000Q0?ooo`030000003o
ool0oooo0400oooo0P00003o0?oood/0oooo000Q0?ooo`030000003oool0oooo03h0oooo0P00003o
0?ooodd0oooo000Q0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0o`3ooom=0?oo
o`008@3oool00`000000oooo0?ooo`0k0?ooo`800000o`3ooom@0?ooo`008@3oool00`000000oooo
0?ooo`0h0?ooo`<00000o`3ooomB0?ooo`008@3oool00`000000oooo0?ooo`0e0?ooo`<00000o`3o
oomE0?ooo`008@3oool00`000000oooo0?ooo`0a0?ooo`@00000o`3ooomH0?ooo`00503oool00`3o
_g@000000000000300000003001d_`3oool0oooo00@0oooo00<000000?ooo`3oool0:@3oool80000
0?l0ooooG03oool001L0oooo00<0W4Q809cOo`3oool01`3oool00`000000oooo0?ooo`0<0?oooad0
0000o`3ooomT0?ooo`005`3oool00`2LB4P0W=oo0?ooo`070?ooo`l00000o`3ooon10?ooo`005`3o
ool00`2LB4P0W=oo0?ooo`070?ooo`030000003oool0oooo0?l0ooooS@3oool001L0oooo00<0W4Q8
09cOo`3oool01`3oool300000?l0ooooS@3oool001L0oooo00<0W4Q809cOo`3oool01`3oool00`00
0000oooo0?ooo`3o0?ooohd0oooo000G0?ooo`0309a8B02Lgol0oooo00L0oooo00<000000?ooo`3o
ool0o`3ooon=0?ooo`00503oool01@3OW4P000000018W02LB4P0W=oo00P0oooo00<000000?ooo`3o
ool0o`3ooon=0?ooo`005P3oool00`3OW4P0001809cOo`080?ooo`030000003oool0oooo0?l0oooo
S@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.69104, -0.0772123, \
0.0310384, 0.00623565}}]
}, Closed]],

Cell["\<\
When analyzing measurements of such a density distribution, one commonly \
employs a Fourier-Bessel transform\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`fbe[
        r]\  = \ \(\(\[Sum]\+\(n = 1\)\%nmax\( 
                a\_n\) \[ScriptJ]\_0[\(n\ \[Pi]\ r\)\/R]\ \ for\ r\)\(\
\[LessEqual]\)\(R\)\(\ \)\)\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
within a limited volume whose radius is several times the root-mean-square \
radius of the distribution.  Using known properties of the spherical Bessel \
functions, one can show that the expansion coefficients are given by the \
integral\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`a\_n = \(2\/\(\(R\^3\) \[ScriptJ]\_1[\(n\ \[Pi]\ \
r\)\/R]\^2\)\) \(\[Integral]\_0\%R \[Rho][
              r] \[ScriptJ]\_0[\(n\ \[Pi]\ r\)\/R] \(r\^2\) \[DifferentialD]r\
\)\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Thus, we wish to construct a function which evaluates the expansion \
coefficients by numerical integration.  We also test this function by \
comparing the expansion with the original function.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[sbessj, fbeCoeff];\)\), "\n", 
    \(\(sbessj[n_, z_\  /; z \[NotEqual] 0]\  := 
        Sqrt[\ Pi/\((2  z)\)]\ BesselJ[n + 1\/2, z];\)\), "\n", 
    \(\(sbessj[0, 0]\  := \ 1;\)\), "\n", 
    \(sbessj[n_ /; n > 0, 0\ ]\  := \ 0\)}], "Input"],

Cell[BoxData[
    \(fbeCoeff[\[Rho]_, params_, n_, 
        R_] := \ \ \(2\/\(\(R\^3\) sbessj[1, n\ \[Pi]\ ]\^2\)\) 
        NIntegrate[
          Evaluate[
            r\^2\ \[Rho]\ sbessj[0, \(n\ \[Pi]\ r\)\/R] /. params], {r, 0, 
            R}]\)], "Input"],

Cell[BoxData[
    \(fbe[r_, coeffs_, R_] := \ 
      coeffs . Table[
          sbessj[0, \(n\ \[Pi]\ r\)\/R], {n, 1, Length[coeffs]}]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(coeffs = 
      Table[fbeCoeff[\[Rho], {c \[Rule] 2.5, a \[Rule] 0.5, w \[Rule] 0.2}, 
          n, 8. ], {n, 1, 10}]\)], "Input"],

Cell[BoxData[
    \({0.28031302399221425`, 0.5937994230911209`, 
      0.4051151033867951`, \(-0.001773251181958961`\), \
\(-0.19859179891209575`\), \(-0.1430966453367851`\), \(-0.018939958911222538`\
\), 0.042663391666979376`, 0.03625523672851818`, 
      0.00864849374475225`}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
        Evaluate[\((\[Rho] - fbe[r, coeffs, 8. ])\) /. {c \[Rule] 2.5, 
              a \[Rule] 0.5, w \[Rule] 0.2}], {r, 0, 8}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.307753 91.3479 [
[.2619 .29525 -3 -9 ]
[.2619 .29525 3 0 ]
[.5 .29525 -3 -9 ]
[.5 .29525 3 0 ]
[.7381 .29525 -3 -9 ]
[.7381 .29525 3 0 ]
[.97619 .29525 -3 -9 ]
[.97619 .29525 3 0 ]
[.01131 .03371 -36 -4.5 ]
[.01131 .03371 0 4.5 ]
[.01131 .12506 -36 -4.5 ]
[.01131 .12506 0 4.5 ]
[.01131 .21641 -36 -4.5 ]
[.01131 .21641 0 4.5 ]
[.01131 .3991 -30 -4.5 ]
[.01131 .3991 0 4.5 ]
[.01131 .49045 -30 -4.5 ]
[.01131 .49045 0 4.5 ]
[.01131 .5818 -30 -4.5 ]
[.01131 .5818 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30775 m
.2619 .314 L
s
[(2)] .2619 .29525 0 1 Mshowa
.5 .30775 m
.5 .314 L
s
[(4)] .5 .29525 0 1 Mshowa
.7381 .30775 m
.7381 .314 L
s
[(6)] .7381 .29525 0 1 Mshowa
.97619 .30775 m
.97619 .314 L
s
[(8)] .97619 .29525 0 1 Mshowa
.125 Mabswid
.08333 .30775 m
.08333 .3115 L
s
.14286 .30775 m
.14286 .3115 L
s
.20238 .30775 m
.20238 .3115 L
s
.32143 .30775 m
.32143 .3115 L
s
.38095 .30775 m
.38095 .3115 L
s
.44048 .30775 m
.44048 .3115 L
s
.55952 .30775 m
.55952 .3115 L
s
.61905 .30775 m
.61905 .3115 L
s
.67857 .30775 m
.67857 .3115 L
s
.79762 .30775 m
.79762 .3115 L
s
.85714 .30775 m
.85714 .3115 L
s
.91667 .30775 m
.91667 .3115 L
s
.25 Mabswid
0 .30775 m
1 .30775 L
s
.02381 .03371 m
.03006 .03371 L
s
[(-0.003)] .01131 .03371 1 0 Mshowa
.02381 .12506 m
.03006 .12506 L
s
[(-0.002)] .01131 .12506 1 0 Mshowa
.02381 .21641 m
.03006 .21641 L
s
[(-0.001)] .01131 .21641 1 0 Mshowa
.02381 .3991 m
.03006 .3991 L
s
[(0.001)] .01131 .3991 1 0 Mshowa
.02381 .49045 m
.03006 .49045 L
s
[(0.002)] .01131 .49045 1 0 Mshowa
.02381 .5818 m
.03006 .5818 L
s
[(0.003)] .01131 .5818 1 0 Mshowa
.125 Mabswid
.02381 .05198 m
.02756 .05198 L
s
.02381 .07025 m
.02756 .07025 L
s
.02381 .08852 m
.02756 .08852 L
s
.02381 .10679 m
.02756 .10679 L
s
.02381 .14333 m
.02756 .14333 L
s
.02381 .1616 m
.02756 .1616 L
s
.02381 .17987 m
.02756 .17987 L
s
.02381 .19814 m
.02756 .19814 L
s
.02381 .23467 m
.02756 .23467 L
s
.02381 .25294 m
.02756 .25294 L
s
.02381 .27121 m
.02756 .27121 L
s
.02381 .28948 m
.02756 .28948 L
s
.02381 .32602 m
.02756 .32602 L
s
.02381 .34429 m
.02756 .34429 L
s
.02381 .36256 m
.02756 .36256 L
s
.02381 .38083 m
.02756 .38083 L
s
.02381 .41737 m
.02756 .41737 L
s
.02381 .43564 m
.02756 .43564 L
s
.02381 .45391 m
.02756 .45391 L
s
.02381 .47218 m
.02756 .47218 L
s
.02381 .50872 m
.02756 .50872 L
s
.02381 .52699 m
.02756 .52699 L
s
.02381 .54526 m
.02756 .54526 L
s
.02381 .56353 m
.02756 .56353 L
s
.02381 .01544 m
.02756 .01544 L
s
.02381 .60007 m
.02756 .60007 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.09213 0 m
.10458 .23806 L
.11427 .38858 L
.12333 .49622 L
.12788 .53675 L
.13277 .56953 L
.13555 .58324 L
.13692 .58867 L
.13819 .59292 L
.13931 .59608 L
.14056 .59889 L
.1418 .60103 L
.14249 .6019 L
.14313 .60254 L
.14431 .60323 L
.14556 .60332 L
.14675 .60279 L
.14783 .60179 L
.14909 .60002 L
.15047 .59737 L
.15296 .5907 L
.15558 .58126 L
.15835 .5687 L
.16331 .54029 L
.18182 .39021 L
.19197 .29904 L
.20162 .22178 L
.21027 .16777 L
.21517 .14559 L
.21735 .13785 L
.21971 .13105 L
.22103 .12793 L
.22225 .12553 L
.2234 .12367 L
.22465 .12209 L
.22578 .12106 L
.22683 .12043 L
.22794 .12013 L
.22912 .1202 L
.23042 .12073 L
.23115 .12125 L
.23182 .12186 L
.23306 .12331 L
.23437 .12531 L
.23665 .12986 L
.23915 .13642 L
.24435 .15475 L
.24994 .18064 L
.26005 .23882 L
.27973 .35948 L
Mistroke
.28512 .38659 L
.29088 .41011 L
.29367 .41922 L
.29631 .42632 L
.29868 .43142 L
.29991 .4336 L
.30124 .43556 L
.30253 .4371 L
.30371 .43817 L
.3049 .43895 L
.30602 .4394 L
.30733 .43957 L
.30854 .4394 L
.30917 .43919 L
.30987 .43886 L
.31059 .4384 L
.31128 .43787 L
.31257 .43661 L
.31394 .43491 L
.31638 .43097 L
.31901 .4255 L
.32189 .41817 L
.33174 .38443 L
.34091 .34553 L
.35 .30575 L
.35963 .26815 L
.36465 .25206 L
.37018 .23797 L
.37261 .23311 L
.37522 .22882 L
.37768 .22567 L
.37993 .22355 L
.38124 .22265 L
.38196 .22227 L
.38264 .22197 L
.38396 .22158 L
.38516 .22144 L
.38585 .22145 L
.38658 .22153 L
.3879 .22185 L
.38863 .22213 L
.38931 .22246 L
.39086 .22342 L
.39348 .22572 L
.39587 .22852 L
.40125 .23699 L
.41159 .25987 L
.42139 .28576 L
.43017 .309 L
.43963 .33102 L
Mistroke
.44504 .34127 L
.45 .34882 L
.45475 .35424 L
.45713 .35627 L
.45848 .35722 L
.45974 .35797 L
.46099 .35859 L
.46234 .35911 L
.46357 .35947 L
.4647 .35969 L
.46593 .35981 L
.46662 .35983 L
.46727 .35982 L
.46859 .35969 L
.46932 .35956 L
.47 .35941 L
.47121 .35906 L
.47234 .35864 L
.47489 .35737 L
.47714 .35591 L
.47953 .35402 L
.49056 .34167 L
.50054 .32717 L
.51073 .31159 L
.52147 .29668 L
.53064 .28666 L
.53584 .28243 L
.54068 .27953 L
.54309 .27848 L
.54436 .27802 L
.5457 .27762 L
.54688 .27733 L
.54817 .27708 L
.54935 .27692 L
.55045 .27682 L
.5516 .27678 L
.55269 .27678 L
.55366 .27683 L
.55473 .27692 L
.55589 .27708 L
.55712 .2773 L
.55934 .27784 L
.56193 .2787 L
.56473 .27989 L
.56981 .28265 L
.5793 .28947 L
.59884 .30648 L
.6092 .31479 L
.61489 .31864 L
.6203 .32167 L
Mistroke
.62541 .32392 L
.6283 .32491 L
.63097 .32565 L
.63321 .32612 L
.63451 .32634 L
.63569 .3265 L
.63694 .32663 L
.63759 .32669 L
.63828 .32673 L
.63944 .32678 L
.64071 .3268 L
.64199 .32678 L
.64321 .32673 L
.6443 .32665 L
.64548 .32654 L
.64677 .32637 L
.64813 .32617 L
.65058 .32569 L
.65496 .32455 L
.65977 .32291 L
.67921 .31356 L
.7001 .30286 L
.71022 .29896 L
.71595 .29735 L
.71869 .29675 L
.72126 .29628 L
.72372 .29593 L
.72501 .29579 L
.72637 .29566 L
.72752 .29557 L
.72878 .2955 L
.72993 .29546 L
.731 .29543 L
.73164 .29543 L
.73234 .29543 L
.73362 .29545 L
.73486 .29549 L
.736 .29554 L
.73724 .29562 L
.7386 .29574 L
.74136 .29604 L
.74372 .29638 L
.74629 .29682 L
.75148 .29793 L
.76074 .30051 L
.78161 .30762 L
.79171 .31088 L
.80125 .31342 L
.80652 .31451 L
.8093 .31498 L
Mistroke
.81223 .31541 L
.81471 .3157 L
.81742 .31595 L
.81862 .31604 L
.8199 .31612 L
.82109 .31618 L
.82221 .31622 L
.82342 .31625 L
.82406 .31626 L
.82476 .31627 L
.82545 .31627 L
.82618 .31627 L
.82748 .31625 L
.82868 .31623 L
.82981 .31619 L
.83104 .31613 L
.83236 .31605 L
.83533 .31582 L
.83815 .31554 L
.84341 .31484 L
.85306 .31308 L
.86352 .31069 L
.88298 .30595 L
.8933 .30382 L
.89899 .30288 L
.9044 .30218 L
.90685 .30193 L
.90947 .30172 L
.91098 .30162 L
.91235 .30154 L
.91373 .30148 L
.91501 .30144 L
.91618 .30141 L
.91741 .30139 L
.91865 .30138 L
.91935 .30139 L
.92001 .30139 L
.9212 .30141 L
.92228 .30144 L
.92354 .30148 L
.92472 .30154 L
.92702 .30167 L
.92946 .30186 L
.93384 .30231 L
.93855 .30297 L
.94376 .30386 L
.95937 .3075 L
.97619 .3124 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00>P3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0ooooFP3oool003X0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`3o0?oooeX0oooo000j0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`00>P3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo0?l0ooooFP3oool003X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`3o0?oooeX0oooo000j0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0o`3ooomJ
0?ooo`00>P3oool3000001L0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`00>P3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0ooooFP3oool003X0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`3o0?oooeX0oooo000;0?ooo`050?noM000000000000000001d_ol0
1@3oool00`2oM0000000001d_`050?ooo`050?noM000000000000000001d_ol0103oool01@3o_g@0
0000000000000000M;oo00@0oooo00D0_g@0000000000000000004RLg`060?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`002`3oool01P2LB7@0_ooo0?ooo`3ookl0
M01d0;ooo`@0oooo00<0_g@000000000M;l01@3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`<0
oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool20?ooo`070;md0000M;l0oooo0?ooo`3ookl0M000
04RLg`050?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooomI0?ooo`002P3o
ool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0okmd001d_`3oool00P3o
ool01P3OW4P0B9cO0?ooo`3oool0okmd001d_`<0oooo00<0gia804RLg`3oool01P3oool00`3o_g@0
07Bo0?ooo`040?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooomI0?ooo`00
2P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0gia804RLg`3oool0
0P3oool01P3o_g@007Bo0?ooo`3oool0gia804RLg`<0oooo00<0okmd001d_`3oool01@3oool00`3o
gi`0B01809cOo`050?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooomI0?oo
o`0000<0oooo09a800000000100000001@00B9`0oooo0?ooo`3OW4P0B9cO00<0oooo00<0okmd001d
_`3oool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`060?noM000M;l0oooo0?ooo`3OW4P0B9cO0`3o
ool00`3o_g@007Bo0?ooo`030?ooo`040=nLB0000000001809cOo`H0oooo1000000G0?ooo`030000
003oool0oooo0?l0ooooF@3oool000X0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?oo
o`0:0?ooo`030=nLB018W=l0oooo0080oooo00H0okmd001d_`3oool0oooo0=nLB018W=l30?ooo`03
0?noM000M;l0oooo00D0oooo00<0omnL04P0B02Lgol01@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo0?l0ooooF@3oool000X0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO
0?ooo`0:0?ooo`030?noM018W=l0oooo0080oooo00H0gia804RLg`3oool0oooo0?noM018W=l30?oo
o`030=nLB018W=l0oooo00H0oooo00<0_g@007Boo`3oool0103oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo0?l0ooooF@3oool000/0oooo00H0W4P007Boo`3oool0omnL04P0M02oool<
0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo0`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;oo
o`80oooo00L0okmd0000B02Lgol0oooo0?oOW01804P0W=oo00D0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`3o0?oooeT0oooo000;0?ooo`050?oo_`1d000000000000B02Lgol03@3o
ool01@3ookl0M0000000000004P0W=oo00@0oooo00D0oono07@000000000001809cOo`040?ooo`05
0?oOW018000000000000001d_ol01P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
0?l0ooooF@3oool003X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3o0?oooeT0
oooo000j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooomI0?ooo`00>P3o
ool3000001P0oooo00<000000?ooo`3oool0o`3ooomI0?ooo`00>P3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo0?l0ooooF@3oool003X0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`3o0?oooeT0oooo000j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0o`3ooomI0?ooo`00>P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0?l0oooo
F@3oool003X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3o0?oooeT0oooo000j
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooomI0?ooo`00>P3oool30000
01P0oooo00<000000?ooo`3oool0o`3ooomI0?ooo`00>P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo0?l0ooooF03oool003X0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`3o0?oooeP0oooo000j0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3o
oomH0?ooo`00>P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0ooooF03oool0
03X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?oooeP0oooo000j0?ooo`<0
00006@3oool00`000000oooo0?ooo`3o0?oooeP0oooo000j0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0o`3ooomH0?ooo`00>P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo0?l0ooooF03oool003X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o
0?oooeP0oooo000j0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3ooomH0?oo
o`00>P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0ooooF03oool003X0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?oooeP0oooo000j0?ooo`<000006@3o
ool00`000000oooo0?ooo`3o0?oooeP0oooo000j0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0o`3ooomH0?ooo`00>P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0?l0ooooF03oool003X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?oooeP0
oooo000;0?ooo`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`050?ooo`05
0?noM000000000000000001d_ol0103oool01@3o_g@00000000000000000M;oo0080oooo00<0oono
07@000000000100000000`1d_ol0oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0o`3ooomH0?ooo`002`3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0
_g@000000000M;l01@3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`<0oooo00H0W4Qd0;ooo`3o
ool0oono07@0M02oool20?ooo`030;md000007@0_ooo0080oooo00<0giad09cOo`3oool0103oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0ooooF03oool000X0oooo00<0okmd001d
_`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030?noM000M;l0oooo0080oooo00H0gia804RL
g`3oool0oooo0?noM000M;l30?ooo`030=nLB018W=l0oooo0080oooo00<0okmd0000B02Lgol0203o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02d0oooo1000003o0?ooobH0oooo000:
0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool00`3OW4P0B9cO0?ooo`02
0?ooo`060?noM000M;l0oooo0?ooo`3OW4P0B9cO0`3oool00`3o_g@007Bo0?ooo`030?ooo`030?oO
W0180000B9cO00L0oooo1000000I0?ooo`030000003oool0oooo02`0oooo00D000000?ooo`3oool0
oooo0000003o0?ooobH0oooo00000`3oool0W4P000000004000000050018W03oool0oooo0=nLB018
W=l00`3oool00`3o_g@007Bo0?ooo`0:0?ooo`030=nLB018W=l0oooo0080oooo00H0okmd001d_`3o
ool0oooo0=nLB018W=l30?ooo`030?noM000M;l0oooo00D0oooo00<0W4P004RLg`3oool01@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3o0?ooob<0oooo000:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d
_`3oool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`060?noM000M;l0oooo0?ooo`3OW4P0B9cO0`3o
ool00`3o_g@007Bo0?ooo`060?ooo`0309a8M02oool0oooo00@0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3o
oolS0?ooo`002P3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0okmd
04RLg`3oool00P3oool01P3OW4P0B9cO0?ooo`3oool0okmd04RLg`<0oooo00H0gia804RLg`3oool0
oooo0=nLB01d_ol30?ooo`030;md001d_ol0oooo00@0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooolS0?oo
o`002`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo``0oooo00H0W4P007Boo`3oool0omnL04P0
M02oool30?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo0P3oool01`3o_g@0001d0;ooo`3oool0
okmd0000B02Lgol01@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooob80oooo000;0?ooo`050?oo_`1d0000
00000000B02Lgol03@3oool01@3ookl0M0000000000004P0W=oo00@0oooo00D0oono07@000000000
001809cOo`040?ooo`050?noM000000000000000B02Lgol01P3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oo
ob80oooo000j0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo8P3oool003X0oooo0`00000J0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooob40oooo
000j0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0?l0oooo8@3oool003X0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolQ
0?ooo`00>P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`3o0?ooob40oooo000j0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0
oooo803oool003X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooolP0?ooo`00>P3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`3o0?ooob00oooo000j0?ooo`<000006P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0o`3ooolP0?ooo`00>P3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oo
oal0oooo000j0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo7`3oool003X0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
o`3ooolO0?ooo`00>P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oooal0oooo000j0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0?l0oooo7`3oool003X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`00>P3oool3000001/0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0
oooo7P3oool003X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`00>P3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`3o0?oooah0oooo000j0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo7P3oool003X0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0o`3ooolM0?ooo`00>P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?oooad0oooo000j0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0?l0oooo7@3oool003X0oooo0`00000K0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?oooad0oooo000j0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0?l0oooo7@3oool003X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooolM0?ooo`00>P3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`3o0?oooa`0oooo000;0?ooo`050?noM000000000000000001d_ol01@3oool00`2oM000
0000001d_`050?ooo`050?noM000000000000000001d_ol0103oool01@3o_g@00000000000000000
M;oo00<0oooo00<0okmd0000000000000`0000000`00M;l0oooo0?ooo`030?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0?l0oooo703oool000/0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000
000007Bo00D0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool30?ooo`0609a8M02oool0oooo0?oo
_`1d07@0_ooo1@3oool00`2LB4P0W=oo0?ooo`060?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0oooo703oool0
00X0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030?noM000M;l0oooo
0080oooo00H0gia804RLg`3oool0oooo0?noM000M;l30?ooo`030=nLB018W=l0oooo00@0oooo00<0
W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?oooa`0oooo000:0?ooo`030=nLB018W=l0
oooo0080oooo00<0okmd001d_`3oool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`060?noM000M;l0
oooo0?ooo`3OW4P0B9cO0`3oool00`3o_g@007Bo0?ooo`040?ooo`0309a8B02Lgol0oooo00H0oooo
1000000K0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`3o0?oooa`0oooo00000`3oool0W4P000000004000000050018W03oool0oooo0=nLB018W=l0
0`3oool00`3o_g@007Bo0?ooo`0:0?ooo`030=nLB018W=l0oooo0080oooo00H0okmd001d_`3oool0
oooo0=nLB018W=l30?ooo`030?noM000M;l0oooo00@0oooo00<0W4Q809cOo`3oool01P3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`3o0?oooa/0oooo000:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3o
ool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`060?noM000M;l0oooo0?ooo`3OW4P0B9cO0`3oool0
0`3o_g@007Bo0?ooo`040?ooo`0309a8B02Lgol0oooo00H0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0;@3oool3
00000>X0oooo000:0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool02P3oool00`3o
_g@0B9cO0?ooo`020?ooo`060=nLB018W=l0oooo0?ooo`3o_g@0B9cO0`3oool00`3OW4P0B9cO0?oo
o`040?ooo`0309a8B02Lgol0oooo00H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0;03oool200000080oooo00<0
00000?ooo`3oool0i`3oool000/0oooo00H0W4P007Boo`3oool0omnL04P0M02oool<0?ooo`0609a8
001d_ol0oooo0?oOW01807@0_ooo0`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`80oooo00D0
gia800000000B9`0W4Q809cOo`070?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`3V0?ooo`002`3oool01@3ookl0M0000000000004P0W=oo00d0oooo
00D0oono07@000000000001809cOo`040?ooo`050?oo_`1d000000000000B02Lgol01@3oool00`3O
W4P0001809cOo`070?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`3U0?ooo`00>P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0i03oool003X0oooo0`00000L0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0i03oool003X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0><0oooo000j0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`3S0?ooo`00>P3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0hP3oool003X0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0>80oooo000j0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3Q0?ooo`00>P3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0h@3o
ool003X0oooo0`00000L0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0h03oool0
03X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0>00oooo000j0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`3O0?ooo`00>P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0g`3oool003X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0180oooo00<0oono07@000000000100000000`1d_ol0oooo0?oo
o`0P0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool07@3oool01@3ogi`0B0000000
00000000M;oo05H0oooo00D0_g@0000000000000001d0;ooo`1E0?ooo`050;md0000000000000000
0000M;l0203oool003X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo01<0oooo00L0_g@00000M02oool0oooo0000003OW7@0W=oo0240oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0N0?ooo`030;md001d_ol0oooo05D0oooo00H0gia8
001d_`3oool0oooo0?noM000M;mD0?ooo`030?noM000M;l0oooo0080oooo00<0_gA809cOo`3oool0
1P3oool003X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo01@0oooo00@0okmd0000B02Lgol000008`3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo01h0oooo00<0_g@007Boo`3oool0E03oool00`3ookl0M00007Boo`020?ooo`030?oo
_`1dB9`0oooo05<0oooo00<0gia804RLg`3oool00P3oool00`2oM000M;oo0?ooo`060?ooo`00>P3o
ool3000001d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0F0?ooo`030?oOW018
0000000002<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0I0?ooo`030=nLB000
0000000000<0000000<0M;oo0?ooo`3oool0DP3oool01`3o_g@004Q807@0M02oool0oooo0=nLB000
M;l0E03oool00`3o_g@004RL0?ooo`020?ooo`0309a8B02Lgol0oooo00H0oooo000j0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0H0?ooo`030000
0018W=l0oooo0240oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0I0?ooo`060?no
M00007@0_ooo0?ooo`2oM000M;ooE@3oool00`3ogi`0B4RL0?noM002000000030018W03oool0oooo
05@0oooo00D0gia8000000000000000004RLg`080?ooo`00>P3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0603oool00`000000W4Qd0;ooo`0P0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool01@3OW4P007Bo0?ooo`2oM000
M;oo0100oooo1@0000100?ooo`030?oo_`1d07@0_ooo05P0oooo00<0oono07A8W03oool00P3oool0
0`2LB7@0_ooo0?ooo`060?ooo`00>P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0503oool00`3OW4P0M;oo0?ooo`020?ooo`030000001d_ol0oooo
01l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0J0?ooo`0409a80018W=l0_g@0
07Boo`d0oooo0`0000040?ooo`@00000?P3oool00`2oM000B9cO0?ooo`1G0?ooo`030?noM018W=l0
oooo0080oooo00<0_g@007Boo`3oool01P3oool003X0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo01@0oooo00L0okmd0000M02oool0oooo0?noM000
0000W=oo0200oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0J0?ooo`040?oOW018
04P0B4P007Boo``0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0l0?ooo`030?oo
_`1d000007Bo05L0oooo00L0omnL04P0M02oool0oooo0?oOW01807@0_ooo00L0oooo000j0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0E0?ooo`05
0?noM000000000000000B00000008@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01X0oooo00<0okmd0000001d_ol02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
03d0oooo00@0_g@000000000000004RLE@3oool01@3o_g@000000000000004P0W=oo00P0oooo000j
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo00`0oooo0P00002S0?ooo`00>P3oool3000001d0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00l0oooo0P00002Q0?oo
o`00>P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo09h0oooo000j0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0<`3oool6000006@0oooo000j0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0;P3oool5000000D0oooo1P00001N0?ooo`00>P3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0H0?ooo`800000:`3oool300000100oooo0`00001K0?ooo`00>P3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo02D0oooo0`00000F0?ooo`800000<@3oool@0000
01P0oooo000j0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool08P3oool2000001/0
oooo0`00000W0?ooo`L00000403oool4000001@0oooo000a0?ooool00000P000000003X0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool0000001H0oooo00D000000?ooo`3oool0
oooo0000000B0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000005P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01@0oooo00@000000?ooo`00000000004`3oool00`000000oooo0?ooo`0?
0?ooo`D000005P3oool500000180oooo00<000000?ooo`3oool03`3oool3000000030?ooo`000000
oooo00T0oooo000j0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo0000000F
0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0000001H0oooo
00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0D0?ooo`8000005@3oool00`000000oooo0?ooo`0C0?ooo`<0
00004@3oool4000001H0oooo00<000000?ooo`3oool04P3oool2000000X0oooo000j0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo02<0oooo0P00000G0?ooo`800000<03ooolA000003/0oooo000j0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo02H0oooo0P00000C0?ooo`800000OP3oool003X0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0:03oool2
000000l0oooo0P0000200?ooo`00>P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0[0?ooo`8000002P3oool30000
0880oooo000j0?ooo`<000007P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0;P3oool:000008D0oooo000j0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0;h0oooo
000j0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo0;h0oooo000j0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0;l0oooo000j0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0<00oooo000j0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0<00oooo000j0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0<40oooo000j0?ooo`<000007`3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0`P3oool003X0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0``3oool0
03X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0``3oool003X0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0a03oool003X0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00D0oooo
0P0000370?ooo`00>P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02X0oooo0`00
00030?ooo`800000b@3oool003X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0/
0?ooo`D00000bP3oool003X0oooo0`00000O0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?/0oooo000j0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0o03oool003X0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`3l0?ooo`00>P3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0?`0oooo000j0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0o03oool0
03X0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3l0?ooo`00>P3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0?d0oooo000j0?ooo`<00000803oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`3m0?ooo`00>P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?d0oooo000j
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o@3oool000/0oooo00D0okmd0000
00000000000007Boo`050?ooo`030;md0000000007Bo00D0oooo00D0okmd000000000000000007Bo
o`040?ooo`050?noM000000000000000001d_ol00`3oool00`3o_g@000000000000300000003001d
_`3oool0oooo00<0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3n0?ooo`002`3o
ool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l01@3oool01P2LB7@0
_ooo0?ooo`3ookl0M01d0;ooo`<0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool50?ooo`0309a8
B02Lgol0oooo00H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3n0?ooo`002P3o
ool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0okmd001d_`3oool00P3o
ool01P3OW4P0B9cO0?ooo`3oool0okmd001d_`<0oooo00<0gia804RLg`3oool0103oool00`2LB4P0
W=oo0?ooo`060?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0oP3oool000X0oooo
00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`030=nLB018W=l0oooo0080oooo
00H0okmd001d_`3oool0oooo0=nLB018W=l30?ooo`030?noM000M;l0oooo00@0oooo00<0W4Q809cO
o`3oool01P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo000:0?ooo`03
0=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`06
0?noM000M;l0oooo0?ooo`3OW4P0B9cO0`3oool00`3o_g@007Bo0?ooo`040?ooo`0309a8B02Lgol0
oooo00H0oooo1000000O0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo000:0?ooo`030=nLB018W=l0oooo
0080oooo00<0okmd001d_`3oool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`060?noM000M;l0oooo
0?ooo`3OW4P0B9cO0`3oool00`3o_g@007Bo0?ooo`040?ooo`0309a8B02Lgol0oooo00H0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooo`002P3oool00`3o_g@0B9cO0?ooo`02
0?ooo`030=nLB018W=l0oooo00X0oooo00<0okmd04RLg`3oool00P3oool01P3OW4P0B9cO0?ooo`3o
ool0okmd04RLg`<0oooo00<0gia804RLg`3oool0103oool00`2LB4P0W=oo0?ooo`060?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0o`3oool000/0oooo00H0W4P007Boo`3oool0omnL
04P0M02oool<0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo0`3oool01P2LB000M;oo0?ooo`3o
gi`0B01d0;ooo`80oooo00D0gia800000000B9`0W4Q809cOo`070?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0o`3oool10?ooo`002`3oool01@3ookl0M0000000000004P0W=oo00d0
oooo00D0oono07@000000000001809cOo`040?ooo`050?oo_`1d000000000000B02Lgol01@3oool0
0`3OW4P0001809cOo`070?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3oool1
0?ooo`00>P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo0@3oool003X0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooo`80oooo000j0?ooo`<00000
8@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`3o0?ooo`80oooo000j0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0o`3oool20?ooo`00>P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0?l0oooo0`3oool003X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?oo
o`<0oooo000j0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool40?ooo`00
>P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo103oool003X0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`D0oooo000j0?ooo`<000008@3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02`0oooo0P0000020?ooo`800000o`3oool7
0?ooo`00>P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0;P3oool400000?l0oooo203oool003X0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0oooo>P3oool003X0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0oooo>P3oool003X0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0oooo>P3o
ool003X0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0?l0oooo>P3oool003X0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0?l0oooo>P3oool003X0oooo0`00000R0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0o`3ooolj0?ooo`00>P3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooolk0?ooo`00>P3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooolk0?ooo`00>P3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooolk
0?ooo`00>P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0o`3ooolk0?ooo`00>P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0o`3ooolk0?ooo`00>P3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooolk0?ooo`00>P3oool300000280oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?oooc/0oooo000j0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?oooc/0oooo000j0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?oo
oc`0oooo000;0?ooo`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`050?oo
o`050?noM000000000000000001d_ol0103oool01@3o_g@00000000000000000M;oo0080oooo00<0
oono07@000000000100000000`1d_ol0oooo0?ooo`030?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?oooc`0oooo000;0?ooo`0609a8M02oool0
oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`050?ooo`0609a8M02oool0oooo0?oo_`1d
07@0_ooo0`3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`80oooo00<0_g@00000M02oool00P3o
ool00`3OW7@0W=oo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`3o0?oooc`0oooo000:0?ooo`030?noM000M;l0oooo0080oooo00<0gia8
04RLg`3oool02P3oool00`3o_g@007Bo0?ooo`020?ooo`060=nLB018W=l0oooo0?ooo`3o_g@007Bo
0`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM00004P0W=oo00P0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo?03oool000X0oooo00<0
gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`030=nLB018W=l0oooo0080oooo00H0
okmd001d_`3oool0oooo0=nLB018W=l30?ooo`030?noM000M;l0oooo00<0oooo00<0omnL04P00018
W=l01`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0o`3oooll0?ooo`002P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo
00<0gia804RLg`3oool00P3oool01P3o_g@007Bo0?ooo`3oool0gia804RLg`<0oooo00<0okmd001d
_`3oool01@3oool00`2LB000B9cO0?ooo`050?ooo`@000008P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0?l0oooo?03oool000X0oooo00<0gia804RLg`3oool00P3oool00`3o_g@0
07Bo0?ooo`0:0?ooo`030=nLB018W=l0oooo0080oooo00H0okmd001d_`3oool0oooo0=nLB018W=l3
0?ooo`030?noM000M;l0oooo00H0oooo00<0W4Qd0;ooo`3oool0103oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3oooll0?ooo`002P3oool00`3o
_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0okmd04RLg`3oool00P3oool01P3O
W4P0B9cO0?ooo`3oool0okmd04RLg`<0oooo00H0gia804RLg`3oool0oooo0=nLB01d_ol30?ooo`03
0;md001d_ol0oooo00@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0?l0oooo?@3oool000/0oooo00H0W4P007Boo`3oool0omnL04P0M02oool<0?oo
o`0609a8001d_ol0oooo0?oOW01807@0_ooo0`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`80
oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo00D0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo?@3oool000/0oooo00D0oono07@0
00000000001809cOo`0=0?ooo`050?oo_`1d000000000000B02Lgol0103oool01@3ookl0M0000000
000004P0W=oo00@0oooo00D0okmd000000000000001809cOo`060?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooocd0oooo000j0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooocd0oooo
000j0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`3o0?ooocd0oooo000j0?ooo`<00000903oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0?l0oooo?@3oool003X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0?l0oooo?@3oool003X0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo?P3oool003X0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo?P3oool003X0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo?P3o
ool003X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0?l0oooo?P3oool003X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0?l0oooo?P3oool003X0oooo0`00000U0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0o`3oooln0?ooo`00>P3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0o`3oooln0?ooo`00>P3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`00>P3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooolo
0?ooo`00>P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0o`3ooolo0?ooo`00>P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0o`3ooolo0?ooo`00>P3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`00>P3oool3000002H0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooocl0oooo000j0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooocl0oooo000j0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oo
ocl0oooo000j0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`3o0?ooocl0oooo000j0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`3o0?oood00oooo000j0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oood00oooo000j0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oood00oooo000j0?oo
o`<000009`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo@03oool003X0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0
oooo@03oool003X0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0?l0oooo@03oool000/0oooo00D0okmd000000000000000007Boo`050?ooo`030;md
0000000007Bo00D0oooo00D0okmd000000000000000007Boo`040?ooo`050?noM000000000000000
001d_ol0103oool01@2oM0000000000000000000B9cO00H0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo@03oool000/0oooo00H0W4Qd0;oo
o`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00D0oooo00H0W4Qd0;ooo`3oool0oono
07@0M02oool30?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo0P3oool01`2oM00007Bo0?ooo`3o
ool0oono07@00018W=l01@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0o`3ooom10?ooo`002P3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018
W=l0oooo00X0oooo00<0okmd001d_`3oool00P3oool01P3OW4P0B9cO0?ooo`3oool0okmd001d_`<0
oooo00<0gia804RLg`3oool01P3oool00`3o_g@007Bo0?ooo`040?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oood40oooo000:0?ooo`030=nL
B018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`060?no
M000M;l0oooo0?ooo`3OW4P0B9cO0`3oool00`3o_g@007Bo0?ooo`050?ooo`030?oOW01804P0W=oo
00D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0?l0oooo@@3oool000X0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`03
0=nLB018W=l0oooo0080oooo00H0okmd001d_`3oool0oooo0=nLB018W=l30?ooo`030?noM000M;l0
oooo00<0oooo00@0gia80000000004P0W=oo1P3oool4000002L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`3o0?oood40oooo000:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd
001d_`3oool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`060?noM000M;l0oooo0?ooo`3OW4P0B9cO
0`3oool00`3o_g@007Bo0?ooo`050?ooo`030?oOW01804P0W=oo00D0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo@P3oool000X0oooo00<0
okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030?noM018W=l0oooo0080oooo00H0
gia804RLg`3oool0oooo0?noM018W=l30?ooo`030=nLB018W=l0oooo00H0oooo00<0_g@007Boo`3o
ool0103oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0o`3ooom20?ooo`002`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo``0oooo00H0W4P007Bo
o`3oool0omnL04P0M02oool30?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo0P3oool01`3o_g@0
001809cOo`3oool0omnL04P0B02Lgol01@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0o`3ooom20?ooo`002`3oool01@3ookl0M0000000000004P0
W=oo00d0oooo00D0oono07@000000000001809cOo`040?ooo`050?oo_`1d000000000000B02Lgol0
103oool01@3ogi`0B000000000000000M;oo00H0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo@P3oool003X0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo@`3oool003X0oooo00<0
00000?ooo`3oool0:P3oool01@000000oooo0?ooo`3oool000000?l0ooooA@3oool003X0oooo0`00
000Z0?ooo`80000000<0oooo0000003oool0o`3ooom50?ooo`00>P3oool00`000000oooo0?ooo`0[
0?ooo`800000o`3ooom70?ooo`00>P3oool00`000000oooo0?ooo`3o0?ooog@0oooo000j0?ooo`03
0000003oool0oooo0?l0ooooM03oool003X0oooo00<000000?ooo`3oool0o`3ooomd0?ooo`00>P3o
ool00`000000oooo0?ooo`3o0?ooog@0oooo000j0?ooo`030000003oool0oooo0?l0ooooM03oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-1.29462, -0.00380274, \
0.033044, 4.30641*^-05}}]
}, Closed]],

Cell["\<\
For this choice of cut-off radius we achieve better than 1% accuracy with 10 \
terms of the Fourier-Bessel expansion.\
\>", "Text"],

Cell["rms radius for spherical distribution (numerical)", "Exercise"],

Cell["\<\
The root-mean-square (rms) radius for a spherically symmetric radial \
distribution function \[Rho](r) is defined as\
\>", "ExerciseText"],

Cell[BoxData[
    \(TraditionalForm\`rms = \@\(\(\[Integral]\_0\%\[Infinity] \[Rho]\ \(r\^4\
\) \[DifferentialD]r\)\/\(\[Integral]\_0\%\[Infinity] \[Rho]\ \(r\^2\) \
\[DifferentialD]r\)\)\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Write a function which evaluates the rms radius for an arbitrary \
distribution numerically.  Test using a uniform distribution for ",
  Cell[BoxData[
      \(TraditionalForm\`r \[LessEqual] R\)]],
  ".  Then evaluate the rms radius for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = \ \(1 + w\ \((r/c)\)\^2\)\/\(1 + Exp[\((r - \
c)\)/a]\)\)]],
  " and compare with the Fourier-Bessel expansion of same."
}], "ExerciseText",
  CellDingbat->None]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Numerical contour integration", "Subsection"],

Cell[TextData[{
  "Contour integration along a path defined as a series of connected line \
segments can be performed using the syntax ",
  StyleBox["NIntegrate", "InlineInput",
    FontWeight->"Bold"],
  "[",
  Cell[BoxData[
      \(TraditionalForm\`f, {\(z, z\_1, z\_2, \[CenterEllipsis]\), z\_n}\)]],
  "]",
  StyleBox[" ",
    FontWeight->"Bold"],
  "where the ",
  Cell[BoxData[
      \(TraditionalForm\`z\_i\)]],
  " are complex numbers that plot the contour.  For example, the following \
integral is performed along a square contour centered on the origin with \
edges parallel to the real and imaginary axis."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NIntegrate[
      Exp[z]\/z, {z, \(-1\) - \[ImaginaryI], 1 - \[ImaginaryI], 
        1 + \[ImaginaryI], \(-1\) + \[ImaginaryI], \(-1\) - \
\[ImaginaryI]}]\)], "Input"],

Cell[BoxData[
    \(\(\(0.`\)\(\[InvisibleSpace]\)\) + 
      6.2831853071795685`\ \[ImaginaryI]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Because we chose a function exhibiting only one simple pole with unit \
residue inside the contour, the result is just ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\ \[ImaginaryI]\)]],
  ".  Complex analysis tells us that the same result should be obtained for \
any other contour which encompasses the same poles and which can be deformed \
continuously into the first without crossing singularities or branch cuts.  \
Thus, the diamond-shaped contour"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NIntegrate[
      Exp[z]\/z, {z, \(-1\), \(-\[ImaginaryI]\), 
        1, \[ImaginaryI], \(-1\)}]\)], "Input"],

Cell[BoxData[
    \(\(\(0.`\)\(\[InvisibleSpace]\)\) + 
      6.2831853071795685`\ \[ImaginaryI]\)], "Output"]
}, Closed]],

Cell["does indeed give the same result.", "Text"],

Cell["\<\
More general contours can be defined in terms of the same type of replacement \
rules we employed above for symbolic contour integration.\
\>", "Text"],

Cell[BoxData[
    \(contourNIntegrate[f_, 
        contour : \((z_ \[Rule] \[Zeta]_)\), {t_, tmin_, tmax_}] := 
      NIntegrate[
        Evaluate[f\ D[\[Zeta], t] /. contour], {t, tmin, tmax}]\)], "Input"],

Cell["Applying this over a circle, ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(contourNIntegrate[Exp[z]\/z, 
        z \[Rule] Cos[t] + \[ImaginaryI]\ Sin[t], {t, 0, 2  \[Pi]}] // 
      Chop\)], "Input"],

Cell[BoxData[
    \(6.283185307179588`\ \[ImaginaryI]\)], "Output"]
}, Closed]],

Cell["\<\
we again obtain the same result when the contour encloses a single pole.  \
Returning to our earlier example in which the pole is circled twice, we now \
obtain the correct answer because numerical integration counts both loops.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(contourNIntegrate[1\/\(z - 1\/2\), 
        z \[Rule] Exp[\[ImaginaryI]\ t] \((2  Cos[t] + 1)\), {t, 0, 
          2  \[Pi]}] // Chop\)], "Input"],

Cell[BoxData[
    \(12.56637061435209`\ \[ImaginaryI]\)], "Output"]
}, Closed]],

Cell["\<\
Nor is the spurious real part produced by the symbolic integral present in \
the numerical integral.  \
\>", "Text"],

Cell["\<\
Numerical integration is often more reliable than symbolic integration and \
should be used to check suspicious symbolic results.\
\>", "Advice"],

Cell[TextData[{
  "Numerically integrate ",
  Cell[BoxData[
      \(TraditionalForm\`1\/\(z - 1\/2\) - 2\/\(z - \[ImaginaryI] - 1\)\)]],
  " on both of the following contours for {t,0,2\[Pi]}: \na) z\[Rule]Cos[t]+\
\[ImaginaryI] Sin[t]  \t\t\n[Hint: do not separate the integrand.]\nb) z\
\[Rule]Exp[\[ImaginaryI] t](2Cos[t]+1)\t\n[Hint: you may need to handle the \
two terms separately for the two-loop contour because nearby poles tend to \
cause problems with numerical stability.]  \nComment on your results.  "
}], "Exercise"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises", "ExerciseMain"],

Cell[CellGroupData[{

Cell["Chain and cyclic rules", "ExerciseTitle"],

Cell[TextData[{
  "In thermodynamics, one frequently wishes to connect the dependencies of \
three variables ",
  Cell[BoxData[
      \(TraditionalForm\`{x, y, z}\)]],
  " for which there exists a single state function that reduces the number of \
degrees freedom to two.  Thus, we can express ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`x[y, z]\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`y[x, z]\)]],
  " and deduce relationships among the partial derivatives ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[PartialD]x\/\[PartialD]y)\)\_z\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[PartialD]y\/\[PartialD]z)\)\_x\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[PartialD]z\/\[PartialD]x)\)\_y\)]],
  " where the subscript indicates the constrained variable."
}], "ExerciseText"],

Cell[TextData[{
  "a) Evaluate ",
  StyleBox["Dt[x]\[Equal]Dt[x[y,z]]", "InlineInput"],
  " and ",
  StyleBox["Dt[y]\[Equal]Dt[y[x,z]]", "InlineInput"],
  " symbolically.  Then eliminate ",
  StyleBox["Dt[y]", "InlineInput",
    FontWeight->"Bold"],
  " and find the coefficients of ",
  StyleBox["Dt[x]", "InlineInput",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Dt[z]", "InlineInput",
    FontWeight->"Bold"],
  " for an equation of the form ",
  StyleBox["Dt[x]\[Equal]0", "InlineInput"],
  "."
}], "ExerciseText"],

Cell[TextData[{
  "b) Because we are free to vary any two variables independently, the \
coefficients of ",
  StyleBox["Dt[x]", "InlineInput",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Dt[z]", "InlineInput",
    FontWeight->"Bold"],
  " must each vanish separately.  Obtain thereby two relationships among the \
partial derivatives \[LongDash] one will be the familiar chain rule and the \
second will be a less familiar ",
  StyleBox["cyclic rule",
    FontSlant->"Italic"],
  " that is very important in thermodynamic analysis."
}], "ExerciseText"],

Cell[TextData[{
  "c) The equation of state for a simple compressible system can be expressed \
in the form ",
  Cell[BoxData[
      \(TraditionalForm\`V = V[T, p]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " is pressure, ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " is temperature, and ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  " is volume.  Use the cyclic rule to express ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[PartialD]p\/\[PartialD]T)\)\_V\)]],
  " in terms of the isobaric expansivity, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \(1\/V\) \((\[PartialD]V\/\[PartialD]T)\)\
\_p\)]],
  ", and the isothermal compressibility, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\_T = \(-\(1\/V\)\) \((\[PartialD]V\/\
\[PartialD]p)\)\_T\)]],
  "."
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Interference maxima", "ExerciseTitle"],

Cell[TextData[{
  "If ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "equally spaced identical antennas radiate in phase, the angular \
distribution is described by an interference pattern of the form"
}], "ExerciseText"],

Cell[BoxData[
    \(TraditionalForm\`f[n, \[Alpha]] = 
      Sin[n\ \[Alpha]]\^2\/Sin[\[Alpha]]\^2\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell["where", "ExerciseText"],

Cell[BoxData[
    \(TraditionalForm\`\[Alpha]\  = \ \(d\/\[Lambda]\) 
        Sin[\[Theta]]\)], "DisplayFormula",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "and where ",
  StyleBox["d",
    FontSlant->"Italic"],
  " is the spacing between sources and \[Lambda] is the wave length."
}], "ExerciseText"],

Cell[TextData[{
  "a) Plot the distribution in \[Alpha] for several values of ",
  StyleBox["n",
    FontSlant->"Italic"],
  " and determine the locations of the principal maxima.  How many minor \
maxima are found between principal maxima?"
}], "ExerciseText"],

Cell[TextData[{
  "b) Write a function which produces a numerical list of positions for the \
minor maxima. with ",
  Cell[BoxData[
      \(TraditionalForm\`0 < \[Alpha] < \[Pi]\)]],
  "."
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Small amplitude oscillations", "ExerciseTitle"],

Cell[TextData[{
  "Consider a particle of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " is the presence of a potential ",
  Cell[BoxData[
      \(TraditionalForm\`V[r]\)]],
  ".  The equation of motion is then"
}], "ExerciseText"],

Cell[BoxData[
    \(TraditionalForm\`m\ \[PartialD]\^2 r\/\[PartialD]t\^2 \[Equal] \(-\(\
\[PartialD]V\/\[PartialD]r\)\)\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "Furthermore, suppose the potential exhibits a minimum at ",
  Cell[BoxData[
      \(TraditionalForm\`r = r\_0\)]],
  " such that a Taylor series expansion near the minimum takes the form"
}], "ExerciseText"],

Cell[BoxData[
    \(TraditionalForm\`V[r] \[TildeTilde] 
      V\_0 + \(1\/2\) 
          k\ \((r - r\_0)\)\^2 + \[CenterEllipsis]\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0 = V[r\_0]\)]],
  "."
}], "ExerciseText"],

Cell[TextData[{
  "a) Show that for small amplitude oscillations, ",
  Cell[BoxData[
      \(TraditionalForm\`r[t]\)]],
  " has sinusoidal solutions and deduce the relationship between the \
frequency \[Omega] and the parameters ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ".  Then deduce the relationship between ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " and the original potential."
}], "ExerciseText"],

Cell["\<\
b) Determine the position and depth of the minimum in the generalized Morse \
potential \
\>", "ExerciseText"],

Cell[BoxData[
    \(TraditionalForm\`V[
        r] = \(-\(\(\(\ \)\(d\)\)\/\(1 - 
                2  c\^2\)\)\) \((Exp[\(-2\) \(a(r - b)\)/c]\  - 
            2 \( c\^2\) Exp[\(-\(a(r - b)\)\)/c])\)\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
symbolically and deduce the frequency for small amplitude oscillations.  \
\>", "ExerciseText"],

Cell[TextData[{
  "c) Choose units of energy and length for which ",
  Cell[BoxData[
      \(TraditionalForm\`d = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b = 1\)]],
  ".  For copper atoms in a face-centered-cubic lattice, one finds that \
experimental data for specific heats are fit well using ",
  Cell[BoxData[
      \(TraditionalForm\`a = 3.02\)]],
  " in these units.  Plot the potential for ",
  Cell[BoxData[
      \(TraditionalForm\`c = {1, 2, 0.5}\)]],
  " on the same figure and interpret the parameters.  Note that the usual \
Morse potential corresponds to ",
  Cell[BoxData[
      \(TraditionalForm\`c \[Rule] 1\)]],
  "."
}], "ExerciseText"],

Cell[TextData[{
  "d) Compare graphically the quadratic approximation with the original \
potential using ",
  Cell[BoxData[
      \(TraditionalForm\`c = 1.5\)]],
  " and the parameters of the preceding part."
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Fourier-sine series for periodic functions with step-discontinuities\
\>", "ExerciseTitle"],

Cell[TextData[{
  "An odd periodic function, for which ",
  Cell[BoxData[
      \(TraditionalForm\`f[\(-x\)] \[Equal] \(-f[x]\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f[x + b] \[Equal] f[x]\)]],
  ", can be represented as a Fourier-Sine series of the form ",
  Cell[BoxData[
      \(TraditionalForm\`f[
          x]\  = \ \[Sum]\+\(n = 1\)\%\[Infinity]\( a\_n\) 
            Sin[2  \[Pi]\ n\ x\/b]\)]],
  " where the coefficients are given by ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n = \(2\/b\) \(\[Integral]\_0\%b f[x]\ Sin[
                2  \[Pi]\ n\ x\/b]\ \[DifferentialD]x\)\)]],
  ".  "
}], "ExerciseText"],

Cell[TextData[{
  "a) Determine the expansion coefficients for a sawtooth function which \
varies between ",
  Cell[BoxData[
      \(TraditionalForm\`\(+1\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  " in a unit interval, and verify graphically that the sawtooth function is \
obtained by summation of the Fourier-Sine series for finite ",
  Cell[BoxData[
      \(TraditionalForm\`n \[LessEqual] n\_max\)]],
  "."
}], "ExerciseText"],

Cell[TextData[{
  "b) ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does not produce a closed-form summation of this Fourier-Sine series \
without some coaching.  Let us assume, without formal proof, that the sine \
functions can be converted to exponentials, such that the series is separated \
into two series with exponentials whose arguments differ in time, and that \
these two series can be summed separately and then combined.   Show that \
these series can be summed and obtain a result for the Fourier-Sine series.  \
How does this function produce step discontinuities?"
}], "ExerciseText"],

Cell["c) Repeat parts a) and b) for a square wave.", "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Potential for conservative vector field", "ExerciseTitle"],

Cell[TextData[{
  "A conservative vector field ",
  Cell[BoxData[
      \(TraditionalForm\`f\&\[RightVector]\)]],
  " can be expressed in terms of a potential as ",
  Cell[BoxData[
      \(TraditionalForm
      \`f\&\[RightVector] = \(-\[Del]\&\[RightVector] \[Phi]\)\)]],
  ".  Hence, given an expression for such a field we can construct the \
corresponding potential using the path integral"
}], "ExerciseText"],

Cell[BoxData[
    \(TraditionalForm\`\[Phi][r\&\[RightVector]] - \[Phi][
          r\&\[RightVector]\_0] = \
\(-\(\[Integral]\_\(r\&\[RightVector]\_0\)\%\(r\&\[RightVector]\)f\&\
\[RightVector] . \[DifferentialD]r\&\[RightVector]\)\)\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`r\&\[RightVector]\_0\)]],
  " is a reference point and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi][r\&\[RightVector]\_0]\)]],
  " is an arbitrary value assigned to the reference point.  One can show that \
for a conservative field the integral is independent of the path between \
these points.  Hence, one way to construct the potential function is to use a \
path consisting of three segments in which only one variable changes over the \
segment.  Write a function which implements this algorithm.  Test by \
constructing the potential for the vector field ",
  Cell[BoxData[
      \(TraditionalForm\`{y, x, 0}\)]],
  " and then evaluating the gradient of the potential."
}], "ExerciseText",
  CellDingbat->None]
}, Closed]],

Cell[CellGroupData[{

Cell["angle between curves", "ExerciseTitle"],

Cell[TextData[{
  "The angle, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  ", between two curves, ",
  Cell[BoxData[
      \(TraditionalForm\`y\_1[x]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\_2[x]\)]],
  ", at a point of intersection is defined as the angle between the tangents \
at that point."
}], "ExerciseText"],

Cell[TextData[{
  "a) Derive a formula for ",
  Cell[BoxData[
      \(TraditionalForm\`Tan[\[Theta]]\)]],
  " in terms of the slopes ",
  Cell[BoxData[
      \(TraditionalForm\`m\_i = \[DifferentialD]y\_i/\[DifferentialD]x\)]],
  "."
}], "ExerciseText"],

Cell[TextData[{
  "b) Recall the \"cylinder in a trough\" problem from the algebra notebook.  \
A cylinder of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " is dropped into a parabolic trough and becomes wedged when its center is \
at height ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  ".  Another way to determine ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " is to evaluate the angle between the curves ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 + \((y - h)\)\^2 = R\^2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y = a\ x\^2\)]],
  " at their points of intersection.  Clearly, this angle should be zero at \
the proper value of ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  "."
}], "ExerciseText"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 952}},
WindowToolbars->"EditBar",
WindowSize->{1392, 912},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Visible->True,
ShowCellLabel->False,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->PaperWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}, {
        Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {0, 0}},
    CellGroupingRules->"TitleGrouping",
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    ShowCellBracket->True,
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{9, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->0.5,
    CellMargins->{{25, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.700008, 0.4]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{25, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{25, 0}, {6, 6}}],
  
  Cell[StyleData["Input", "Printout"],
    CellFrame->0.5,
    CellMargins->{{25, 0}, {6, 6}},
    Background->None]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->True,
    CellMargins->{{25, 10}, {8, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{25, Inherited}, {12, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{10, 4}, {2, 10}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{12, 10}, {2, 12}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {1, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->9],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{9, 0}, {4, 12}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    CellMargins->{{10, 10}, {40, 2}},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{12, 10}, {50, 2}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Example",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Definition",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Definition", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Theorem",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Theorem", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.4]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caution"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Caution",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.996109, 0, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Caution", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Caution", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Caution", "Printout"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Advice"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Advice",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0, 1, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Advice", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Advice", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Advice", "Printout"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->"NormalGrouping",
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseMain"],
    CellFrame->{{6, 0}, {0, 1}},
    CellMargins->{{12, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseMain", "Presentation"],
    CellMargins->{{18, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["ExerciseMain", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["ExerciseMain", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseTitle"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseTitle", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["ExerciseTitle", "Condensed"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["ExerciseTitle", "Printout"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{32, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExcersiceText",
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{32, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{32, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{32, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Problem"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Problem", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Problem", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Problem", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{12, 10}, {Inherited, 6}},
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{13, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{62, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{74, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    CellMargins->{{52, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"]],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"]],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation package. These \
styles serve to make visible otherwise invisible tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "S3.6.8"->{
    Cell[1082550, 19420, 78, 1, 72, "Input",
      CellTags->"S3.6.8"],
    Cell[1082631, 19423, 103, 2, 75, "Output",
      CellTags->"S3.6.8"]},
  "Integrate"->{
    Cell[1099653, 19996, 113, 2, 93, "Input",
      CellTags->"Integrate"],
    Cell[1099769, 20000, 207, 4, 75, "Output",
      CellTags->"Integrate"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"S3.6.8", 1348964, 26261},
  {"Integrate", 1349128, 26266}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 74, 2, 81, "Title"],
Cell[1853, 57, 455, 15, 85, "Author"],

Cell[CellGroupData[{
Cell[2333, 76, 31, 0, 83, "Section"],
Cell[2367, 78, 319, 5, 67, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2723, 88, 33, 0, 51, "Section"],
Cell[2759, 90, 119, 2, 99, "Input"],
Cell[2881, 94, 65, 1, 73, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2983, 100, 34, 0, 51, "Section"],

Cell[CellGroupData[{
Cell[3042, 104, 41, 0, 68, "Subsection"],
Cell[3086, 106, 1045, 28, 95, "Text"],
Cell[4134, 136, 884, 17, 130, "Text"],
Cell[5021, 155, 207, 5, 58, "InlineInput",
  Evaluatable->False],
Cell[5231, 162, 155, 4, 60, "InlineInput",
  Evaluatable->False],
Cell[5389, 168, 184, 4, 66, "InlineInput",
  Evaluatable->False],
Cell[5576, 174, 226, 5, 63, "InlineInput",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[5827, 183, 43, 1, 73, "Input"],
Cell[5873, 186, 126, 3, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[6036, 194, 59, 1, 73, "Input"],
Cell[6098, 197, 170, 5, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[6305, 207, 71, 1, 74, "Input"],
Cell[6379, 210, 170, 5, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[6586, 220, 58, 1, 73, "Input"],
Cell[6647, 223, 134, 3, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[6818, 231, 56, 1, 74, "Input"],
Cell[6877, 234, 162, 5, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[7076, 244, 57, 1, 73, "Input"],
Cell[7136, 247, 162, 5, 61, "Output"]
}, Closed]],
Cell[7313, 255, 35, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[7373, 259, 50, 1, 74, "Input"],
Cell[7426, 262, 45, 1, 61, "Output"]
}, Closed]],
Cell[7486, 266, 374, 10, 67, "Text"],
Cell[7863, 278, 197, 7, 41, "Text"],
Cell[8063, 287, 44, 1, 73, "Input"],

Cell[CellGroupData[{
Cell[8132, 292, 49, 1, 73, "Input"],
Cell[8184, 295, 337, 9, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[8558, 309, 46, 1, 73, "Input"],
Cell[8607, 312, 162, 4, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[8806, 321, 46, 1, 73, "Input"],
Cell[8855, 324, 266, 7, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[9158, 336, 79, 1, 93, "Input"],
Cell[9240, 339, 38, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[9315, 345, 87, 1, 94, "Input"],
Cell[9405, 348, 56, 1, 59, "Output"]
}, Closed]],
Cell[9476, 352, 1005, 34, 95, "Text"],

Cell[CellGroupData[{
Cell[10506, 390, 46, 1, 73, "Input"],
Cell[10555, 393, 170, 5, 61, "Output"]
}, Closed]],
Cell[10740, 401, 207, 8, 41, "Text"],

Cell[CellGroupData[{
Cell[10972, 413, 70, 1, 73, "Input"],
Cell[11045, 416, 428, 12, 61, "Output"]
}, Closed]],
Cell[11488, 431, 292, 9, 41, "Text"],

Cell[CellGroupData[{
Cell[11805, 444, 49, 1, 73, "Input"],
Cell[11857, 447, 510, 15, 61, "Output"]
}, Closed]],
Cell[12382, 465, 138, 5, 58, "Exercise"],
Cell[12523, 472, 381, 10, 97, "Exercise"],
Cell[12907, 484, 59, 0, 58, "Exercise"],
Cell[12969, 486, 830, 24, 67, "ExerciseText"],
Cell[13802, 512, 585, 12, 125, "Text"],
Cell[14390, 526, 711, 20, 68, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[15138, 551, 39, 0, 68, "Subsection"],
Cell[15180, 553, 874, 31, 72, "Text"],

Cell[CellGroupData[{
Cell[16079, 588, 47, 1, 73, "Input"],
Cell[16129, 591, 403, 12, 61, "Output"]
}, Closed]],
Cell[16547, 606, 376, 12, 67, "Text"],

Cell[CellGroupData[{
Cell[16948, 622, 53, 1, 73, "Input"],
Cell[17004, 625, 2618, 72, 87, "Output"]
}, Closed]],
Cell[19637, 700, 69, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[19731, 704, 50, 1, 73, "Input"],
Cell[19784, 707, 912, 26, 61, "Output"]
}, Closed]],
Cell[20711, 736, 341, 7, 68, "Text"],

Cell[CellGroupData[{
Cell[21077, 747, 76, 1, 73, "Input"],
Cell[21156, 750, 530, 14, 61, "Output"]
}, Closed]],
Cell[21701, 767, 70, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[21796, 771, 88, 1, 73, "Input"],
Cell[21887, 774, 478, 14, 61, "Output"]
}, Closed]],
Cell[22380, 791, 159, 3, 41, "Text"],
Cell[22542, 796, 204, 4, 41, "Text"],
Cell[22749, 802, 70, 1, 73, "Input"],

Cell[CellGroupData[{
Cell[22844, 807, 108, 2, 101, "Input"],
Cell[22955, 811, 643, 17, 81, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[23635, 833, 61, 0, 55, "Subsubsection"],
Cell[23699, 835, 73, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[23797, 839, 237, 5, 125, "Input"],
Cell[24037, 846, 673, 17, 75, "Output"]
}, Closed]],
Cell[24725, 866, 90, 2, 41, "Text"],

Cell[CellGroupData[{
Cell[24840, 872, 46, 1, 73, "Input"],
Cell[24889, 875, 1924, 46, 102, "Output"]
}, Closed]],
Cell[26828, 924, 422, 13, 68, "Text"],

Cell[CellGroupData[{
Cell[27275, 941, 72, 1, 73, "Input"],
Cell[27350, 944, 1244, 30, 75, "Output"]
}, Closed]],
Cell[28609, 977, 92, 2, 41, "Text"],

Cell[CellGroupData[{
Cell[28726, 983, 220, 4, 73, "Input"],
Cell[28949, 989, 35, 1, 59, "Output"]
}, Closed]],
Cell[28999, 993, 125, 3, 41, "Text"],
Cell[29127, 998, 862, 25, 126, "Exercise"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[30038, 1029, 46, 0, 68, "Subsection"],
Cell[30087, 1031, 1218, 41, 95, "Text"],

Cell[CellGroupData[{
Cell[31330, 1076, 114, 2, 100, "Input"],
Cell[31447, 1080, 105, 2, 59, "Output"]
}, Closed]],
Cell[31567, 1085, 156, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[31748, 1092, 143, 2, 73, "Input"],
Cell[31894, 1096, 74, 1, 78, "Output"]
}, Closed]],
Cell[31983, 1100, 146, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[32154, 1107, 165, 3, 73, "Input"],
Cell[32322, 1112, 88, 1, 82, "Output"]
}, Closed]],
Cell[32425, 1116, 242, 4, 67, "Text"],
Cell[32670, 1122, 346, 9, 84, "Exercise"],
Cell[33019, 1133, 299, 5, 83, "Exercise"]
}, Closed]],

Cell[CellGroupData[{
Cell[33355, 1143, 48, 0, 68, "Subsection"],
Cell[33406, 1145, 490, 15, 42, "Text"],

Cell[CellGroupData[{
Cell[33921, 1164, 75, 1, 74, "Input"],
Cell[33999, 1167, 170, 5, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[34206, 1177, 44, 1, 73, "Input"],
Cell[34253, 1180, 171, 5, 59, "Output"]
}, Closed]],
Cell[34439, 1188, 238, 8, 42, "Text"],

Cell[CellGroupData[{
Cell[34702, 1200, 52, 1, 73, "Input"],
Cell[34757, 1203, 161, 5, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[34955, 1213, 56, 1, 73, "Input"],
Cell[35014, 1216, 158, 5, 59, "Output"]
}, Closed]],
Cell[35187, 1224, 501, 16, 41, "Text"],
Cell[35691, 1242, 208, 6, 62, "DisplayFormula",
  Evaluatable->False],
Cell[35902, 1250, 834, 20, 119, "Text"],

Cell[CellGroupData[{
Cell[36761, 1274, 40, 1, 73, "Input"],
Cell[36804, 1277, 127, 4, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[36968, 1286, 46, 1, 73, "Input"],
Cell[37017, 1289, 50, 1, 59, "Output"]
}, Closed]],
Cell[37082, 1293, 136, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[37243, 1300, 50, 1, 73, "Input"],
Cell[37296, 1303, 43, 1, 59, "Output"]
}, Closed]],
Cell[37354, 1307, 91, 2, 41, "Text"],

Cell[CellGroupData[{
Cell[37470, 1313, 52, 1, 92, "Input"],
Cell[37525, 1316, 45, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[37607, 1322, 51, 1, 73, "Input"],
Cell[37661, 1325, 40, 1, 59, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[37762, 1333, 34, 0, 51, "Section"],

Cell[CellGroupData[{
Cell[37821, 1337, 39, 0, 68, "Subsection"],
Cell[37863, 1339, 1325, 23, 199, "Text"],

Cell[CellGroupData[{
Cell[39213, 1366, 60, 0, 55, "Subsubsection"],
Cell[39276, 1368, 927, 36, 68, "Text"],
Cell[40206, 1406, 110, 2, 99, "Input"],

Cell[CellGroupData[{
Cell[40341, 1412, 61, 1, 73, "Input"],
Cell[40405, 1415, 33932, 708, 280, 4771, 344, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[74352, 2126, 336, 7, 67, "Text"],

Cell[CellGroupData[{
Cell[74713, 2137, 55, 1, 73, "Input"],
Cell[74771, 2140, 93, 1, 59, "Output"]
}, Closed]],
Cell[74879, 2144, 174, 5, 42, "Text"],

Cell[CellGroupData[{
Cell[75078, 2153, 92, 1, 73, "Input"],
Cell[75173, 2156, 162, 2, 59, "Output"]
}, Closed]],
Cell[75350, 2161, 140, 5, 58, "Exercise"],
Cell[75493, 2168, 63, 0, 58, "Exercise"],
Cell[75559, 2170, 1119, 31, 94, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[76715, 2206, 61, 0, 55, "Subsubsection"],
Cell[76779, 2208, 928, 30, 68, "Text"],
Cell[77710, 2240, 108, 2, 99, "Input"],

Cell[CellGroupData[{
Cell[77843, 2246, 123, 2, 73, "Input"],
Cell[77969, 2250, 185808, 3069, 444, 12892, 930, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[263792, 5322, 557, 13, 69, "Text"],

Cell[CellGroupData[{
Cell[264374, 5339, 68, 1, 73, "Input"],
Cell[264445, 5342, 139, 2, 59, "Output"]
}, Closed]],
Cell[264599, 5347, 115, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[264739, 5354, 152, 2, 73, "Input"],
Cell[264894, 5358, 391787, 6385, 444, 27177, 1879, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[656742, 11750, 49, 0, 68, "Subsection"],
Cell[656794, 11752, 113, 3, 41, "Text"],
Cell[656910, 11757, 275, 8, 59, "InlineInput",
  Evaluatable->False],
Cell[657188, 11767, 21, 0, 41, "Text"],
Cell[657212, 11769, 240, 7, 61, "InlineInput",
  Evaluatable->False],
Cell[657455, 11778, 129, 5, 41, "Text"],
Cell[657587, 11785, 292, 7, 69, "InlineInput",
  Evaluatable->False],
Cell[657882, 11794, 1143, 32, 122, "Text"],
Cell[659028, 11828, 1111, 22, 146, "Text"],

Cell[CellGroupData[{
Cell[660164, 11854, 139, 2, 74, "Input"],
Cell[660306, 11858, 213968, 3621, 400, 52994, 1629, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[874311, 15484, 214, 3, 74, "Input"],
Cell[874528, 15489, 190572, 3386, 325, 53644, 1691, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1065115, 18878, 1384, 39, 94, "Text"],
Cell[1066502, 18919, 246, 7, 68, "InlineInput",
  Evaluatable->False],
Cell[1066751, 18928, 441, 7, 93, "Text"],
Cell[1067195, 18937, 490, 8, 93, "Text"],
Cell[1067688, 18947, 122, 3, 58, "Exercise"],
Cell[1067813, 18952, 125, 3, 58, "Exercise"],
Cell[1067941, 18957, 584, 13, 183, "Exercise"],
Cell[1068528, 18972, 356, 6, 108, "Exercise"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1068933, 18984, 32, 0, 51, "Section"],

Cell[CellGroupData[{
Cell[1068990, 18988, 50, 0, 68, "Subsection"],
Cell[1069043, 18990, 1014, 31, 68, "Text"],
Cell[1070060, 19023, 55, 0, 41, "Text"],
Cell[1070118, 19025, 285, 9, 73, "Input"],
Cell[1070406, 19036, 99, 2, 94, "Input"],
Cell[1070508, 19040, 344, 7, 67, "Text"],

Cell[CellGroupData[{
Cell[1070877, 19051, 66, 1, 73, "Input"],
Cell[1070946, 19054, 1015, 20, 86, "Output"]
}, Closed]],
Cell[1071976, 19077, 680, 15, 94, "Text"],

Cell[CellGroupData[{
Cell[1072681, 19096, 50, 1, 73, "Input"],
Cell[1072734, 19099, 754, 15, 109, "Output"]
}, Closed]],
Cell[1073503, 19117, 414, 14, 42, "Text"],

Cell[CellGroupData[{
Cell[1073942, 19135, 48, 1, 73, "Input"],
Cell[1073993, 19138, 179, 3, 86, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1074209, 19146, 58, 1, 73, "Input"],
Cell[1074270, 19149, 993, 21, 134, "Output"]
}, Closed]],
Cell[1075278, 19173, 497, 17, 42, "Text"],

Cell[CellGroupData[{
Cell[1075800, 19194, 62, 1, 73, "Input"],
Cell[1075865, 19197, 65, 1, 81, "Output"]
}, Closed]],
Cell[1075945, 19201, 261, 4, 83, "Exercise"],
Cell[1076209, 19207, 572, 16, 99, "Exercise"]
}, Closed]],

Cell[CellGroupData[{
Cell[1076818, 19228, 35, 0, 68, "Subsection"],
Cell[1076856, 19230, 300, 8, 41, "Text"],

Cell[CellGroupData[{
Cell[1077181, 19242, 46, 1, 73, "Input"],
Cell[1077230, 19245, 49, 1, 59, "Output"]
}, Closed]],
Cell[1077294, 19249, 219, 8, 41, "Text"],
Cell[1077516, 19259, 203, 5, 64, "DisplayFormula"],
Cell[1077722, 19266, 260, 11, 41, "Text"],

Cell[CellGroupData[{
Cell[1078007, 19281, 65, 1, 73, "Input"],
Cell[1078075, 19284, 1856, 51, 194, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1079968, 19340, 63, 1, 73, "Input"],
Cell[1080034, 19343, 49, 1, 75, "Output"]
}, Closed]],
Cell[1080098, 19347, 178, 5, 42, "Text"],

Cell[CellGroupData[{
Cell[1080301, 19356, 60, 1, 80, "Input"],
Cell[1080364, 19359, 310, 8, 80, "Output"]
}, Closed]],
Cell[1080689, 19370, 63, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[1080777, 19374, 91, 1, 73, "Input"],
Cell[1080871, 19377, 297, 5, 76, "Output"]
}, Closed]],
Cell[1081183, 19385, 102, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[1081310, 19392, 73, 1, 73, "Input"],
Cell[1081386, 19395, 564, 8, 66, "Message"],
Cell[1081953, 19405, 500, 7, 51, "Message"],
Cell[1082456, 19414, 57, 1, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1082550, 19420, 78, 1, 72, "Input",
  CellTags->"S3.6.8"],
Cell[1082631, 19423, 103, 2, 75, "Output",
  CellTags->"S3.6.8"]
}, Closed]],
Cell[1082749, 19428, 186, 4, 41, "Text"],
Cell[1082938, 19434, 70, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[1083033, 19438, 83, 1, 96, "Input"],
Cell[1083119, 19441, 45, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1083201, 19447, 83, 1, 96, "Input"],
Cell[1083287, 19450, 50, 1, 59, "Output"]
}, Closed]],
Cell[1083352, 19454, 188, 8, 65, "Exercise"],
Cell[1083543, 19464, 179, 5, 66, "Exercise"],
Cell[1083725, 19471, 108, 3, 58, "Exercise"]
}, Closed]],

Cell[CellGroupData[{
Cell[1083870, 19479, 47, 0, 68, "Subsection"],
Cell[1083920, 19481, 2640, 83, 67, "Text"],

Cell[CellGroupData[{
Cell[1086585, 19568, 65, 1, 73, "Input"],
Cell[1086653, 19571, 865, 27, 83, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1087555, 19603, 53, 1, 73, "Input"],
Cell[1087611, 19606, 2155, 54, 82, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1089803, 19665, 89, 1, 73, "Input"],
Cell[1089895, 19668, 2155, 54, 82, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1092087, 19727, 87, 1, 73, "Input"],
Cell[1092177, 19730, 1919, 49, 75, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1094133, 19784, 80, 1, 73, "Input"],
Cell[1094216, 19787, 35, 1, 59, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1094312, 19795, 39, 0, 51, "Section"],

Cell[CellGroupData[{
Cell[1094376, 19799, 59, 0, 68, "Subsection"],
Cell[1094438, 19801, 786, 24, 69, "Text"],
Cell[1095227, 19827, 163, 5, 62, "DisplayFormula",
  Evaluatable->False],
Cell[1095393, 19834, 34, 0, 41, "Text"],
Cell[1095430, 19836, 179, 5, 64, "DisplayFormula",
  Evaluatable->False],
Cell[1095612, 19843, 457, 11, 67, "Text"],

Cell[CellGroupData[{
Cell[1096094, 19858, 45, 0, 55, "Subsubsection"],
Cell[1096142, 19860, 48, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[1096215, 19864, 79, 1, 92, "Input"],
Cell[1096297, 19867, 141, 3, 61, "Output"]
}, Closed]],
Cell[1096453, 19873, 116, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[1096594, 19880, 52, 1, 73, "Input"],
Cell[1096649, 19883, 44, 1, 59, "Output"]
}, Closed]],
Cell[1096708, 19887, 311, 9, 67, "Text"],

Cell[CellGroupData[{
Cell[1097044, 19900, 107, 2, 92, "Input"],
Cell[1097154, 19904, 127, 2, 77, "Output"]
}, Closed]],
Cell[1097296, 19909, 173, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[1097494, 19916, 74, 1, 92, "Input"],
Cell[1097571, 19919, 65, 1, 83, "Output"]
}, Closed]],
Cell[1097651, 19923, 402, 14, 41, "Text"],
Cell[1098056, 19939, 612, 17, 150, "Exercise"],
Cell[1098671, 19958, 272, 6, 119, "Exercise"]
}, Closed]],

Cell[CellGroupData[{
Cell[1098980, 19969, 43, 0, 55, "Subsubsection"],
Cell[1099026, 19971, 159, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[1099210, 19978, 77, 1, 94, "Input"],
Cell[1099290, 19981, 157, 3, 75, "Output"]
}, Closed]],
Cell[1099462, 19987, 166, 5, 41, "Text"],

Cell[CellGroupData[{
Cell[1099653, 19996, 113, 2, 93, "Input",
  CellTags->"Integrate"],
Cell[1099769, 20000, 207, 4, 75, "Output",
  CellTags->"Integrate"]
}, Closed]],
Cell[1099991, 20007, 396, 10, 68, "Text"],

Cell[CellGroupData[{
Cell[1100412, 20021, 112, 2, 73, "Input"],
Cell[1100527, 20025, 47, 1, 75, "Output"]
}, Closed]],
Cell[1100589, 20029, 550, 15, 68, "Text"],

Cell[CellGroupData[{
Cell[1101164, 20048, 129, 3, 93, "Input"],
Cell[1101296, 20053, 47, 1, 75, "Output"]
}, Closed]],
Cell[1101358, 20057, 96, 2, 41, "Text"],

Cell[CellGroupData[{
Cell[1101479, 20063, 115, 2, 73, "Input"],
Cell[1101597, 20067, 47, 1, 75, "Output"]
}, Closed]],
Cell[1101659, 20071, 184, 4, 41, "Text"],
Cell[1101846, 20077, 122, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[1101993, 20084, 121, 3, 95, "Input"],
Cell[1102117, 20089, 697, 13, 189, "Output"]
}, Closed]],
Cell[1102829, 20105, 208, 6, 42, "Text"],

Cell[CellGroupData[{
Cell[1103062, 20115, 81, 1, 73, "Input"],
Cell[1103146, 20118, 243, 4, 104, "Output"]
}, Closed]],
Cell[1103404, 20125, 361, 6, 67, "Text"],

Cell[CellGroupData[{
Cell[1103790, 20135, 77, 1, 94, "Input"],
Cell[1103870, 20138, 543, 9, 125, "Output"]
}, Closed]],
Cell[1104428, 20150, 249, 6, 41, "Text"],
Cell[1104680, 20158, 655, 23, 148, "Exercise"],
Cell[1105338, 20183, 286, 8, 125, "Exercise"],
Cell[1105627, 20193, 371, 12, 141, "Exercise"],
Cell[1106001, 20207, 263, 6, 80, "Exercise"],
Cell[1106267, 20215, 197, 6, 71, "Exercise"],
Cell[1106467, 20223, 68, 0, 58, "Exercise"],
Cell[1106538, 20225, 148, 3, 41, "ExerciseText"],
Cell[1106689, 20230, 278, 6, 93, "DisplayFormula",
  Evaluatable->False],
Cell[1106970, 20238, 384, 10, 67, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1107391, 20253, 40, 0, 55, "Subsubsection"],
Cell[1107434, 20255, 423, 8, 67, "Text"],

Cell[CellGroupData[{
Cell[1107882, 20267, 164, 4, 98, "Input"],
Cell[1108049, 20273, 112, 2, 76, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1108198, 20280, 40, 1, 73, "Input"],
Cell[1108241, 20283, 55, 1, 59, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1108357, 20291, 36, 0, 68, "Subsection"],
Cell[1108396, 20293, 313, 5, 67, "Text"],
Cell[1108712, 20300, 179, 5, 63, "DisplayFormula",
  Evaluatable->False],
Cell[1108894, 20307, 1088, 28, 122, "Text"],
Cell[1109985, 20337, 116, 3, 41, "Text"],
Cell[1110104, 20342, 213, 5, 63, "DisplayFormula",
  Evaluatable->False],
Cell[1110320, 20349, 2083, 49, 243, "Text"],
Cell[1112406, 20400, 56, 1, 73, "Input"],
Cell[1112465, 20403, 956, 18, 366, "Input"],

Cell[CellGroupData[{
Cell[1113446, 20425, 33, 0, 55, "Subsubsection"],

Cell[CellGroupData[{
Cell[1113504, 20429, 127, 2, 99, "Input"],
Cell[1113634, 20433, 42, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1113713, 20439, 110, 2, 99, "Input"],
Cell[1113826, 20443, 47, 1, 82, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1113910, 20449, 192, 3, 99, "Input"],
Cell[1114105, 20454, 681, 13, 161, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1114823, 20472, 101, 2, 74, "Input"],
Cell[1114927, 20476, 39, 1, 75, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1115003, 20482, 124, 2, 92, "Input"],
Cell[1115130, 20486, 39, 1, 75, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1115206, 20492, 110, 2, 73, "Input"],
Cell[1115319, 20496, 183, 3, 61, "Output"]
}, Closed]],
Cell[1115517, 20502, 100, 2, 58, "Exercise"],
Cell[1115620, 20506, 31, 0, 58, "Exercise"],
Cell[1115654, 20508, 1176, 21, 146, "ExerciseText"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1116879, 20535, 40, 0, 68, "Subsection"],
Cell[1116922, 20537, 377, 6, 67, "Text"],

Cell[CellGroupData[{
Cell[1117324, 20547, 166, 2, 99, "Input"],
Cell[1117493, 20551, 141, 2, 82, "Output"]
}, Closed]],
Cell[1117649, 20556, 55, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[1117729, 20560, 57, 1, 74, "Input"],
Cell[1117789, 20563, 51, 1, 80, "Output"]
}, Closed]],
Cell[1117855, 20567, 75, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[1117955, 20571, 85, 1, 74, "Input"],
Cell[1118043, 20574, 88, 1, 75, "Output"]
}, Closed]],
Cell[1118146, 20578, 285, 8, 41, "Text"],

Cell[CellGroupData[{
Cell[1118456, 20590, 73, 1, 74, "Input"],
Cell[1118532, 20593, 39, 1, 75, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1118608, 20599, 132, 2, 94, "Input"],
Cell[1118743, 20603, 39, 1, 75, "Output"]
}, Closed]],
Cell[1118797, 20607, 256, 6, 42, "Text"],
Cell[1119056, 20615, 261, 5, 73, "Input"],

Cell[CellGroupData[{
Cell[1119342, 20624, 144, 4, 73, "Input"],
Cell[1119489, 20630, 49, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1119575, 20636, 135, 3, 74, "Input"],
Cell[1119713, 20641, 119, 2, 91, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1119869, 20648, 116, 2, 73, "Input"],
Cell[1119988, 20652, 152, 2, 92, "Output"]
}, Closed]],
Cell[1120155, 20657, 50, 0, 58, "Exercise"],
Cell[1120208, 20659, 2074, 54, 298, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1122319, 20718, 41, 0, 68, "Subsection"],
Cell[1122363, 20720, 914, 27, 93, "Text"],
Cell[1123280, 20749, 185, 3, 73, "Input"],
Cell[1123468, 20754, 566, 12, 93, "Text"],

Cell[CellGroupData[{
Cell[1124059, 20770, 133, 2, 112, "Input"],
Cell[1124195, 20774, 57, 1, 59, "Output"]
}, Closed]],
Cell[1124267, 20778, 301, 6, 41, "Text"],
Cell[1124571, 20786, 164, 3, 73, "Input"],

Cell[CellGroupData[{
Cell[1124760, 20793, 299, 4, 127, "Input"],
Cell[1125062, 20799, 53178, 1104, 444, 7800, 539, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[1178277, 21908, 169, 3, 112, "Input"],
Cell[1178449, 21913, 67, 1, 59, "Output"]
}, Closed]],
Cell[1178531, 21917, 259, 5, 67, "Text"],
Cell[1178793, 21924, 35, 0, 71, "Advice"],
Cell[1178831, 21926, 220, 4, 83, "Exercise"],
Cell[1179054, 21932, 308, 7, 76, "Exercise"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1179411, 21945, 40, 0, 51, "Section"],

Cell[CellGroupData[{
Cell[1179476, 21949, 34, 0, 68, "Subsection"],
Cell[1179513, 21951, 965, 21, 147, "Text"],

Cell[CellGroupData[{
Cell[1180503, 21976, 78, 1, 74, "Input"],
Cell[1180584, 21979, 79, 1, 75, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1180700, 21985, 39, 1, 73, "Input"],
Cell[1180742, 21988, 53, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1180832, 21994, 79, 1, 74, "Input"],
Cell[1180914, 21997, 53, 1, 59, "Output"]
}, Closed]],
Cell[1180982, 22001, 215, 9, 41, "Text"],

Cell[CellGroupData[{
Cell[1181222, 22014, 132, 3, 100, "Input"],
Cell[1181357, 22019, 106, 2, 94, "Output"]
}, Closed]],
Cell[1181478, 22024, 165, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[1181668, 22031, 68, 1, 73, "Input"],
Cell[1181739, 22034, 85, 1, 59, "Output"]
}, Closed]],
Cell[1181839, 22038, 75, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[1181939, 22042, 148, 3, 100, "Input"],
Cell[1182090, 22047, 69, 1, 59, "Output"]
}, Closed]],
Cell[1182174, 22051, 58, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[1182257, 22055, 44, 1, 73, "Input"],
Cell[1182304, 22058, 62, 1, 61, "Output"]
}, Closed]],
Cell[1182381, 22062, 230, 4, 67, "Text"],
Cell[1182614, 22068, 247, 4, 67, "Text"],

Cell[CellGroupData[{
Cell[1182886, 22076, 93, 1, 100, "Input"],
Cell[1182982, 22079, 32182, 623, 279, 3790, 268, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1215179, 22705, 560, 10, 94, "Text"],

Cell[CellGroupData[{
Cell[1215764, 22719, 52, 1, 73, "Input"],
Cell[1215819, 22722, 396, 6, 109, "Output"]
}, Closed]],
Cell[1216230, 22731, 258, 5, 67, "Text"],
Cell[1216491, 22738, 224, 6, 71, "Exercise"],
Cell[1216718, 22746, 256, 6, 71, "Exercise"],

Cell[CellGroupData[{
Cell[1216999, 22756, 65, 0, 55, "Subsubsection"],
Cell[1217067, 22758, 323, 5, 67, "Text"],
Cell[1217393, 22765, 139, 3, 132, "Input"],
Cell[1217535, 22770, 364, 10, 67, "Text"],
Cell[1217902, 22782, 107, 2, 73, "Input"],

Cell[CellGroupData[{
Cell[1218034, 22788, 81, 1, 73, "Input"],
Cell[1218118, 22791, 26020, 525, 279, 3538, 243, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1244153, 23319, 133, 3, 41, "Text"],
Cell[1244289, 23324, 280, 7, 77, "DisplayFormula",
  Evaluatable->False],
Cell[1244572, 23333, 262, 5, 67, "Text"],
Cell[1244837, 23340, 303, 7, 75, "DisplayFormula",
  Evaluatable->False],
Cell[1245143, 23349, 217, 4, 67, "Text"],
Cell[1245363, 23355, 271, 5, 180, "Input"],
Cell[1245637, 23362, 261, 6, 99, "Input"],
Cell[1245901, 23370, 146, 3, 92, "Input"],

Cell[CellGroupData[{
Cell[1246072, 23377, 150, 3, 73, "Input"],
Cell[1246225, 23382, 292, 5, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1246554, 23392, 172, 3, 73, "Input"],
Cell[1246729, 23397, 47904, 986, 279, 7073, 477, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1294648, 24386, 141, 3, 41, "Text"],
Cell[1294792, 24391, 69, 0, 58, "Exercise"],
Cell[1294864, 24393, 148, 3, 41, "ExerciseText"],
Cell[1295015, 24398, 280, 6, 93, "DisplayFormula",
  Evaluatable->False],
Cell[1295298, 24406, 470, 11, 81, "ExerciseText"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1295817, 24423, 51, 0, 68, "Subsection"],
Cell[1295871, 24425, 630, 17, 68, "Text"],

Cell[CellGroupData[{
Cell[1296526, 24446, 187, 4, 95, "Input"],
Cell[1296716, 24452, 110, 2, 59, "Output"]
}, Closed]],
Cell[1296841, 24457, 491, 9, 93, "Text"],

Cell[CellGroupData[{
Cell[1297357, 24470, 129, 3, 95, "Input"],
Cell[1297489, 24475, 110, 2, 59, "Output"]
}, Closed]],
Cell[1297614, 24480, 49, 0, 41, "Text"],
Cell[1297666, 24482, 161, 3, 41, "Text"],
Cell[1297830, 24487, 206, 4, 99, "Input"],
Cell[1298039, 24493, 45, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[1298109, 24497, 145, 3, 95, "Input"],
Cell[1298257, 24502, 67, 1, 59, "Output"]
}, Closed]],
Cell[1298339, 24506, 252, 4, 67, "Text"],

Cell[CellGroupData[{
Cell[1298616, 24514, 166, 3, 112, "Input"],
Cell[1298785, 24519, 67, 1, 59, "Output"]
}, Closed]],
Cell[1298867, 24523, 126, 3, 41, "Text"],
Cell[1298996, 24528, 155, 3, 71, "Advice"],
Cell[1299154, 24533, 532, 9, 201, "Exercise"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1299735, 24548, 33, 0, 54, "ExerciseMain"],

Cell[CellGroupData[{
Cell[1299793, 24552, 47, 0, 58, "ExerciseTitle"],
Cell[1299843, 24554, 939, 28, 102, "ExerciseText"],
Cell[1300785, 24584, 522, 17, 69, "ExerciseText"],
Cell[1301310, 24603, 556, 14, 68, "ExerciseText"],
Cell[1301869, 24619, 836, 26, 76, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1302742, 24650, 44, 0, 58, "ExerciseTitle"],
Cell[1302789, 24652, 222, 6, 41, "ExerciseText"],
Cell[1303014, 24660, 189, 5, 68, "DisplayFormula",
  Evaluatable->False],
Cell[1303206, 24667, 29, 0, 41, "ExerciseText"],
Cell[1303238, 24669, 160, 4, 61, "DisplayFormula"],
Cell[1303401, 24675, 163, 5, 41, "ExerciseText"],
Cell[1303567, 24682, 261, 6, 41, "ExerciseText"],
Cell[1303831, 24690, 208, 6, 41, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1304076, 24701, 53, 0, 58, "ExerciseTitle"],
Cell[1304132, 24703, 244, 8, 41, "ExerciseText"],
Cell[1304379, 24713, 211, 5, 64, "DisplayFormula",
  Evaluatable->False],
Cell[1304593, 24720, 226, 5, 41, "ExerciseText"],
Cell[1304822, 24727, 221, 6, 60, "DisplayFormula",
  Evaluatable->False],
Cell[1305046, 24735, 114, 5, 41, "ExerciseText"],
Cell[1305163, 24742, 485, 15, 67, "ExerciseText"],
Cell[1305651, 24759, 120, 3, 41, "ExerciseText"],
Cell[1305774, 24764, 289, 7, 62, "DisplayFormula",
  Evaluatable->False],
Cell[1306066, 24773, 105, 2, 41, "ExerciseText"],
Cell[1306174, 24777, 674, 19, 67, "ExerciseText"],
Cell[1306851, 24798, 229, 6, 41, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1307117, 24809, 101, 2, 58, "ExerciseTitle"],
Cell[1307221, 24813, 640, 17, 77, "ExerciseText"],
Cell[1307864, 24832, 461, 13, 67, "ExerciseText"],
Cell[1308328, 24847, 613, 11, 93, "ExerciseText"],
Cell[1308944, 24860, 68, 0, 41, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1309049, 24865, 64, 0, 58, "ExerciseTitle"],
Cell[1309116, 24867, 414, 10, 67, "ExerciseText"],
Cell[1309533, 24879, 324, 7, 71, "DisplayFormula",
  Evaluatable->False],
Cell[1309860, 24888, 791, 17, 93, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[1310688, 24910, 45, 0, 58, "ExerciseTitle"],
Cell[1310736, 24912, 349, 12, 41, "ExerciseText"],
Cell[1311088, 24926, 253, 8, 41, "ExerciseText"],
Cell[1311344, 24936, 759, 23, 93, "ExerciseText"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

