(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    665826,      22389]*)
(*NotebookOutlinePosition[    702714,      23693]*)
(*  CellTagsIndexPosition[    702670,      23689]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Differential Equations", "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "from ",
  StyleBox[ButtonBox["Essential Mathematica for Students of Science",
    Active->False,
    ButtonData:>{
      URL[ 
      "http://www.physics.umd.edu/courses/CourseWare/EssentialMathematica/"], 
      None},
    Active->False,
    ButtonStyle->"Hyperlink"],
    Active->False],
  "\n\[Copyright] James J. Kelly, 1998\nLast revised: January, 2006"
}], "Author",
  Active->True,
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
  "In this notebook we introduce the techniques available for solving \
differential equations.  The function ",
  StyleBox["DSolve", "InlineInput",
    FontWeight->"Bold"],
  " seeks symbolic solutions while ",
  StyleBox["NDSolve", "InlineInput",
    FontWeight->"Bold"],
  " produces numerical solutions.  The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " book provides good descriptions and insightful examples of both functions \
and is a valuable resource but not quite a textbook.  Here we provide an \
introduction from the point of view of someone who has had to learn to use \
these functions in a more practical setting.  Although ",
  StyleBox["NDSolve", "InlineInput",
    FontWeight->"Bold"],
  " is, in my experience, much more useful than ",
  StyleBox["DSolve", "InlineInput",
    FontWeight->"Bold"],
  ", we begin with ",
  StyleBox["DSolve", "InlineInput",
    FontWeight->"Bold"],
  " because it is simpler to use and many of its features carry over to ",
  StyleBox["NDSolve", "InlineInput",
    FontWeight->"Bold"],
  ".  Then we discuss the unique features of ",
  StyleBox["NDSolve", "InlineInput",
    FontWeight->"Bold"],
  " and some practical problems encountered in numerical work."
}], "Text"],

Cell[TextData[{
  "More information about ",
  StyleBox["DSolve", "InlineInput",
    FontWeight->"Bold"],
  " can be found in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " book,\[NonBreakingSpace]",
  ButtonBox["Section 3.5.10",
    ButtonData:>{"3.5.10", "10.2"},
    ButtonStyle->"MainBookLink"],
  ", or in the reference guide,  ",
  ButtonBox["DSolve",
    ButtonStyle->"RefGuideLink"],
  ".  More information about ",
  StyleBox["NDSolve", "InlineInput",
    FontWeight->"Bold"],
  " can be found in\[NonBreakingSpace]",
  ButtonBox["Section 3.9.7",
    ButtonData:>{"3.9.7", "7.1"},
    ButtonStyle->"MainBookLink"],
  " or ",
  ButtonBox["NDSolve",
    ButtonStyle->"RefGuideLink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[BoxData[{
    \(\(ClearAll["\<Global`*\>"];\)\), "\n", 
    \(Off[General::spell, \ General::spell1]\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Utilities`Notation`\>"];\)\), "\n", 
    \(Needs["\<Graphics`\>"]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Symbolic solution", "Section"],

Cell[CellGroupData[{

Cell["Basic syntax", "Subsection"],

Cell[TextData[{
  "The basic command for symbolic solution of a differential equation is ",
  ButtonBox["DSolve",
    ButtonStyle->"RefGuideLink"],
  ".  The syntax for an ordinary differential equation with one variable is \
",
  StyleBox["DSolve[", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["eqn,fn,var", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["]", "InlineInput",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "where ",
  StyleBox["eqn", "InlineInput"],
  " is a well-posed differential equation involving derivatives of the \
function ",
  StyleBox["fn", "InlineInput"],
  " with respect to the independent variable ",
  StyleBox["var", "InlineInput"],
  ".  The derivatives must be based upon ",
  StyleBox["D", "InlineInput",
    FontWeight->"Bold"],
  ", not ",
  StyleBox["Dt", "InlineInput",
    FontWeight->"Bold"],
  ".  The solution is returned in the form of a list of replacement rules for \
",
  StyleBox["fn", "InlineInput"],
  StyleBox[", ",
    FontSlant->"Italic"],
  "with the detailed form depending on the specificity of ",
  StyleBox["fn", "InlineInput"],
  ".  For example, consider the equation of motion for a simple-harmonic \
oscillator:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol1\  = \ 
      DSolve[\(x\^\[DoublePrime]\)[t] \[Equal] \ \(-\[Omega]\_0\%2\) x[t], \ 
        x, \ t]\)], "Input"],

Cell[BoxData[
    \({{x \[Rule] 
          Function[{t}, 
            C[2]\ Cos[t\ \[Omega]\_0] + 
              C[1]\ Sin[t\ \[Omega]\_0]]}}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Because there exist two independent solutions to this second-order \
differential equation, the solution is returned in the form of a replacement \
rule that includes two undetermined constants, ",
  StyleBox["C[1]", "InlineInput",
    FontWeight->"Bold"],
  " and ",
  StyleBox["C[2]", "InlineInput",
    FontWeight->"Bold"],
  ".  A more explicit solution is obtained if we specify a sufficient number \
of initial or boundary conditions, in the form of additional equations, that \
determine these constants.  In the example below, we specify the initial \
displacement and velocity"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[{\(x\^\[DoublePrime]\)[t] \[Equal] \ \(-\[Omega]\_0\%2\) x[t], \ 
        x[0] \[Equal] x0, \ \(x\^\[Prime]\)[0] \[Equal] v0}, \ x, \ 
      t]\)], "Input"],

Cell[BoxData[
    \({{x \[Rule] 
          Function[{t}, \(v0\ Sin[t\ \[Omega]\_0] + x0\ Cos[t\ \[Omega]\_0]\ \
\[Omega]\_0\)\/\[Omega]\_0]}}\)], "Output"]
}, Closed]],

Cell["\<\
and obtain a complete solution free of undetermined constants.\
\>", "Text"],

Cell[TextData[{
  "Notice that although we must employ a dummy argument in the statement of \
the differential equation, we chose to specify ",
  StyleBox["fn", "InlineInput"],
  " simply as ",
  StyleBox["x", "InlineInput",
    FontWeight->"Bold"],
  " rather than ",
  StyleBox["x[t]", "InlineInput",
    FontWeight->"Bold"],
  ".  The solution is then returned as a replacement rule for a ",
  StyleBox["pure function",
    FontSlant->"Italic"],
  " that can be used with either symbolic or numerical arguments.  \
Furthermore, it is not necessary for the symbolic argument to be the same as \
the dummy argument, labelled ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", used to represent the independent variable.  Thus, we obtain functions \
for the displacement and velocity "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({x[\[Tau]], \(x\^\[Prime]\)[\[Tau]]}\  /. 
      sol1\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \({C[2]\ Cos[\[Tau]\ \[Omega]\_0] + C[1]\ Sin[\[Tau]\ \[Omega]\_0], 
      C[1]\ Cos[\[Tau]\ \[Omega]\_0]\ \[Omega]\_0 - 
        C[2]\ Sin[\[Tau]\ \[Omega]\_0]\ \[Omega]\_0}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "as expressions in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)]],
  " or"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({x[1.5/\[Omega]\_0], \(x\^\[Prime]\)[1.5/\[Omega]\_0]} /. 
      sol1\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \({0.9974949866040544`\ C[1] + 0.0707372016677029`\ C[2], 
      0.0707372016677029`\ C[1]\ \[Omega]\_0 - 
        0.9974949866040544`\ C[2]\ \[Omega]\_0}\)], "Output"]
}, Closed]],

Cell["as numerical results quite easily.", "Text"],

Cell[TextData[{
  "Often one sees ",
  StyleBox["DSolve", "InlineInput",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "used to obtain a solution for ",
  StyleBox["x[t]", "InlineInput",
    FontWeight->"Bold"],
  " as follows."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol2\  = \ 
      DSolve[\(x\^\[DoublePrime]\)[t] \[Equal] \ \(-\[Omega]\_0\%2\) x[t], \ 
        x[t], \ t]\)], "Input"],

Cell[BoxData[
    \({{x[t] \[Rule] 
          C[2]\ Cos[t\ \[Omega]\_0] + C[1]\ Sin[t\ \[Omega]\_0]}}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "In this example we specified ",
  StyleBox["fn", "InlineInput"],
  " as ",
  StyleBox["x[t]", "InlineInput"],
  " and hence obtained a replacement rule for ",
  StyleBox["x[t]", "InlineInput"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x[t]\  /. sol2\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \(C[2]\ Cos[t\ \[Omega]\_0] + C[1]\ Sin[t\ \[Omega]\_0]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "However, ",
  Cell[BoxData[
      \(TraditionalForm\`x[1.5/\[Omega]\_0]\)]],
  " is not recognized as being related to ",
  Cell[BoxData[
      \(TraditionalForm\`x[t]\)]],
  " and hence cannot be evaluated by using the replacement rule directly."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x[1.5/\[Omega]\_0]\  /. 
      sol2\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \(x[1.5`\/\[Omega]\_0]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "To evaluate this quantity using the replacement for ",
  StyleBox["x[t]", "InlineInput"],
  " would require a couple of steps."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(x[t]\  /. sol2\[LeftDoubleBracket]1\[RightDoubleBracket]\)\  /. 
      t \[Rule] 1.5/\[Omega]\_0\)], "Input"],

Cell[BoxData[
    \(0.9974949866040544`\ C[1] + 0.0707372016677029`\ C[2]\)], "Output"]
}, Closed]],

Cell["Nor can we obtain the velocity", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(x\^\[Prime]\)[t] /. 
      sol2\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["x", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]], "Output"]
}, Closed]],

Cell[TextData[{
  "with substitution for ",
  StyleBox["x[t]", "InlineInput",
    FontWeight->"Bold"],
  " before differentiation."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[x[t] /. sol2\[LeftDoubleBracket]1\[RightDoubleBracket], t]\)], "Input"],

Cell[BoxData[
    \(C[1]\ Cos[t\ \[Omega]\_0]\ \[Omega]\_0 - 
      C[2]\ Sin[t\ \[Omega]\_0]\ \[Omega]\_0\)], "Output"]
}, Closed]],

Cell["\<\
It is usually easier to express solutions as pure functions rather than in \
terms of explicit arguments.\
\>", "Text"],

Cell["\<\
Use DSolve and NDSolve to produce pure functions \[LongDash] avoid naming \
dummy arguments!\
\>", "Advice"]
}, Closed]],

Cell[CellGroupData[{

Cell["Undetermined constants", "Subsection"],

Cell[TextData[{
  "If the equations do not completely determine the solution, ",
  StyleBox["DSolve", "InlineInput",
    FontWeight->"Bold"],
  " produces constants of integration indexed sequentially.  By default, the \
constants are represented by ",
  StyleBox["C[1]", "InlineInput"],
  ", ",
  StyleBox["C[2]", "InlineInput"],
  ", ..., ",
  StyleBox["C[n]", "InlineInput"],
  ", but the function applied to each index can be changed using the option \
",
  StyleBox["GeneratedParameters", "InlineInput",
    FontWeight->"Bold"],
  ". (It was ",
  StyleBox["DSolveConstants", "InlineInput",
    FontWeight->"Bold"],
  " before version 5.)  By default, ",
  StyleBox["GeneratedParameters\[Rule]C", "InlineInput",
    FontWeight->"Bold"],
  StyleBox[" ", "InlineInput"],
  "but ",
  StyleBox["C", "InlineInput",
    FontWeight->"Bold"],
  " remains a reserved symbol even if the option is changed. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"sol3", " ", "=", " ", 
      RowBox[{"DSolve", "[", 
        RowBox[{\(\(x\^\[DoublePrime]\)[t] \[Equal] \ \(-\[Omega]\_0\%2\) 
              x[t]\), ",", " ", "x", ",", " ", "t", ",", " ", 
          RowBox[{
            StyleBox["GeneratedParameters",
              FontWeight->"Bold"], "\[Rule]", "a"}]}], "]"}]}]], "Input"],

Cell[BoxData[
    \({{x \[Rule] 
          Function[{t}, 
            a[2]\ Cos[t\ \[Omega]\_0] + 
              a[1]\ Sin[t\ \[Omega]\_0]]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(C = 1\)], "Input"],

Cell[BoxData[
    RowBox[{\(Set::"wrsym"\), \(\(:\)\(\ \)\), "\<\"Symbol \\!\\(C\\) is \
Protected. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::wrsym\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(1\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(C[1]\  = \ 0\)], "Input"],

Cell[BoxData[
    RowBox[{\(Set::"write"\), \(\(:\)\(\ \)\), "\<\"Tag \\!\\(C\\) in \
\\!\\(C[1]\\) is Protected. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::write\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(0\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(a[1]\  = \ 0\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(x[t]\  /. sol3\)], "Input"],

Cell[BoxData[
    \({a[2]\ Cos[t\ \[Omega]\_0]}\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Initial or boundary conditions", "Subsection"],

Cell[TextData[{
  "Initial conditions or boundary conditions should be specified in the form \
of equations also.  ",
  StyleBox["DSolve[", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["eqns,fn,var", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["]", "InlineInput",
    FontWeight->"Bold"],
  " can then be used to solve a list of differential equations, ",
  StyleBox["eqns", "InlineInput"],
  ".  If ",
  StyleBox["eqns", "InlineInput"],
  " is sufficiently complete, there will be no undetermined constants left.  \
For example, if we specify that the system is released from initial \
displacement ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  " with zero initial velocity, we obtain a complete solution."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol4\  = \ 
      DSolve[{\(x\^\[DoublePrime]\)[t] \[Equal] \ \(-\[Omega]\_0\%2\) x[t], \ 
          x[0] \[Equal] a, \(x\^\[Prime]\)[0] \[Equal] 0}, \ x, \ 
        t]\)], "Input"],

Cell[BoxData[
    \({{x \[Rule] Function[{t}, a\ Cos[t\ \[Omega]\_0]]}}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Ordinarily, we would prefer to specify the initial displacement as ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  ", but since confusion can arise between ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  ", ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " simple echoes the input without producing a solution."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[{\(x\^\[DoublePrime]\)[t] \[Equal] \ \(-\[Omega]\_0\%2\) x[t], \ 
        x[0] \[Equal] x\_0, \(x\^\[Prime]\)[0] \[Equal] 0}, \ x, \ 
      t]\)], "Input"],

Cell[BoxData[
    RowBox[{\(DSolve::"dvnoarg"\), \(\(:\)\(\ \)\), "\<\"The function \\!\\(x\
\\) appears with no arguments. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"DSolve::dvnoarg\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{"DSolve", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["x", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-\[Omega]\_0\%2\)\ x[t]\)}], 
            ",", \(x[0] \[Equal] x\_0\), ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
              "0"}]}], "}"}], ",", "x", ",", "t"}], "]"}]], "Output"]
}, Closed]],

Cell[TextData[{
  "This problem is solved by using the ",
  StyleBox["Symbolize", "InlineInput",
    FontWeight->"Bold"],
  " command provided by the ",
  StyleBox["Notation", "InlineInput",
    FontWeight->"Bold"],
  " package to identify ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  " as a symbol that is distinct from ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ".  We then obtain a solution of the desired form.  (However, you must \
remember that ",
  StyleBox["Symbolize", "InlineInput",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "can only be invoked from the ",
  StyleBox["Notation", "InlineInput",
    FontWeight->"Bold"],
  " palette and will not work properly if typed directly into an input cell.) \
"
}], "Text"],

Cell[BoxData[
    RowBox[{"Symbolize", "[", 
      TagBox[\(x\_0\),
        NotationBoxTag,
        Editable->True], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[{\(x\^\[DoublePrime]\)[t] \[Equal] \ \(-\[Omega]\_0\%2\) x[t], \ 
        x[0] \[Equal] x\_0, \(x\^\[Prime]\)[0] \[Equal] 0}, \ x, \ 
      t]\)], "Input"],

Cell[BoxData[
    \({{x \[Rule] Function[{t}, x\_0\ Cos[t\ \[Omega]\_0]]}}\)], "Output"]
}, Closed]],

Cell["\<\
More generally, if we symbolize the initial velocity also, we can produce a \
general solution for arbitrary initial conditions.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Symbolize", "[", 
      TagBox[\(v\_0\),
        NotationBoxTag,
        Editable->True], "]"}]], "Input"],

Cell[BoxData[
    \(Symbolize::"bsymbexs" \(\(:\)\(\ \)\) 
      "Warning: The box structure attempting to be symbolized has a similar \
or identical symbol already defined, possibly overriding previously \
symbolized box structure."\)], "Message"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(shm\  = 
      DSolve[{\(x\^\[DoublePrime]\)[t] \[Equal] \ \(-\[Omega]\_0\%2\) x[t], \ 
          x[0] \[Equal] x\_0, \(x\^\[Prime]\)[0] \[Equal] v\_0}, \ x, \ 
        t]\)], "Input"],

Cell[BoxData[
    \({{x \[Rule] 
          Function[{t}, \(v\_0\ Sin[t\ \[Omega]\_0] + x\_0\ Cos[t\ \
\[Omega]\_0]\ \[Omega]\_0\)\/\[Omega]\_0]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \({x[t], \(x\^\[Prime]\)[t]} /. 
      shm\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \({\(v\_0\ Sin[t\ \[Omega]\_0] + x\_0\ Cos[t\ \[Omega]\_0]\ \[Omega]\_0\)\
\/\[Omega]\_0, \(v\_0\ Cos[t\ \[Omega]\_0]\ \[Omega]\_0 - x\_0\ Sin[t\ \
\[Omega]\_0]\ \[Omega]\_0\%2\)\/\[Omega]\_0}\)], "Output"]
}, Closed]],

Cell["\<\
Alternatively, we can present boundary conditions in terms of the solutions \
for several independent values of the independent variable.  For example, in \
the case of simple harmonic motion, specification of the displacements at two \
times is sufficient to determine both constants of integration.\
\>", "Text"],

Cell[BoxData[
    RowBox[{"Symbolize", "[", 
      TagBox[\(x\_1\),
        NotationBoxTag,
        Editable->True], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[{\(x\^\[DoublePrime]\)[t] \[Equal] \ \(-\[Omega]\_0\%2\) x[t], \ 
        x[0] \[Equal] x\_0, \ x[1/\[Omega]\_0] \[Equal] x\_1}, \ x, \ 
      t]\)], "Input"],

Cell[BoxData[
    \({{x \[Rule] 
          Function[{t}, 
            x\_0\ Cos[t\ \[Omega]\_0] - x\_0\ Cot[1]\ Sin[t\ \[Omega]\_0] + 
              x\_1\ Csc[1]\ Sin[t\ \[Omega]\_0]]}}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Although the initial conditions are usually specified in terms of simple \
equations like ",
  Cell[BoxData[
      \(TraditionalForm\`x[0] \[Equal] x\_0\)]],
  ", it is also possible to use more complicated equations whose solutions \
may include several sets of  initial conditions, in which case ",
  StyleBox["DSolve", "InlineInput",
    FontWeight->"Bold"],
  " produces several solutions to the differential equation.  The following \
variation of the shm problem appears contrived, but illustrates the idea."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[{\(x\^\[DoublePrime]\)[t] \[Equal] \ \(-\[Omega]\_0\%2\) 
            x[t], \ \((\(\[Omega]\_0\) x[0] - \(x\^\[Prime]\)[0])\)\^2 \
\[Equal] v\_0\^2, \ \(\[Omega]\_0\) x[0] + \(x\^\[Prime]\)[0] \[Equal] 0}, \ 
      x, \ t]\)], "Input"],

Cell[BoxData[
    \({{x \[Rule] 
          Function[{t}, \(v\_0\ Cos[t\ \[Omega]\_0] - v\_0\ Sin[t\ \
\[Omega]\_0]\)\/\(2\ \[Omega]\_0\)]}, {x \[Rule] 
          Function[{t}, \(\(-v\_0\)\ Cos[t\ \[Omega]\_0] + v\_0\ Sin[t\ \
\[Omega]\_0]\)\/\(2\ \[Omega]\_0\)]}}\)], "Output"]
}, Closed]],

Cell["\<\
Of course, you will probably need some subsidiary condition to choose between \
the solutions produced.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["What can it do?", "Subsection"],

Cell[TextData[{
  StyleBox["DSolve", "InlineInput",
    FontWeight->"Bold"],
  " claims to be able to solve any linear differential equation with constant \
coefficients, regardless of order, and many linear equations with nonconstant \
coefficients up to second order.  Many common special functions were \
originally defined as solutions to differential equations arising in diverse \
problems in physics, and hence those equations will usually be recognized.  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[\(y\^\[DoublePrime]\)[x]\  - \ x\ y[x] \[Equal] 0, y[x], 
      x]\)], "Input"],

Cell[BoxData[
    \({{y[x] \[Rule] AiryAi[x]\ C[1] + AiryBi[x]\ C[2]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DSolve", "[", 
      RowBox[{
        RowBox[{
          RowBox[{\(z\^2\ \(y\^\[Prime]\[Prime]\)[z]\), "+", 
            RowBox[{"z", " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "z", "]"}]}], 
            "+", \(\((z\^2 - n\^2)\)\ y[z]\)}], "\[Equal]", "0"}], ",", "y", 
        ",", "z"}], "]"}]], "Input"],

Cell[BoxData[
    \({{y \[Rule] 
          Function[{z}, 
            BesselJ[n, z]\ C[1] + BesselY[n, z]\ C[2]]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[\ \(y\^\[Prime]\[Prime]\)[z] + \((1 - n\/z\^2)\)\ y[z] \[Equal] 
        0, y, z]\)], "Input"],

Cell[BoxData[
    \({{y \[Rule] 
          Function[{z}, \@z\ BesselJ[1\/2\ \@\(1 + 4\ n\), z]\ C[
                  1] + \@z\ BesselY[1\/2\ \@\(1 + 4\ n\), z]\ C[
                  2]]}}\)], "Output"]
}, Closed]],

Cell["\<\
However, many relatively simple differential equations cannot be solved in \
terms of named functions.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[\ \(y\^\[Prime]\[Prime]\)[z] + Sin[z]\ y[z] \[Equal] 0, y, 
      z]\)], "Input"],

Cell[BoxData[
    RowBox[{"DSolve", "[", 
      RowBox[{
        RowBox[{
          RowBox[{\(Sin[z]\ y[z]\), "+", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "z", "]"}]}], "\[Equal]", 
          "0"}], ",", "y", ",", "z"}], "]"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[\ \(y\^\[Prime]\[Prime]\)[z] + \((1 - n\/z\^n)\)\ y[z] \[Equal] 
        0, y, z]\)], "Input"],

Cell[BoxData[
    RowBox[{"DSolve", "[", 
      RowBox[{
        RowBox[{
          RowBox[{\(\((1 - n\ z\^\(-n\))\)\ y[z]\), "+", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "z", "]"}]}], "\[Equal]", 
          "0"}], ",", "y", ",", "z"}], "]"}]], "Output"]
}, Closed]],

Cell[TextData[{
  "Solve ",
  Cell[BoxData[
      \(TraditionalForm\`y\^\[Prime]\  + \ y\ \(tan(x)\)\  = \ sin(2  x)\)]],
  " given ",
  Cell[BoxData[
      \(TraditionalForm\`y = 2\)]],
  " when ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " and verify the solution."
}], "Exercise"],

Cell[TextData[{
  "Obtain the symbolic solution to a second-order linear differential \
equation with constant coefficients in the general form ",
  Cell[BoxData[
      \(TraditionalForm\`a\ y\^\[DoublePrime]\  + \ b\ y\^\[Prime]\  + \ 
          c\ y\  = \ 0\)]],
  " and interpret the solution."
}], "Exercise"],

Cell[TextData[{
  "Solve ",
  Cell[BoxData[
      \(TraditionalForm\`\((y\^\[Prime])\)\^2 + \ y = a\)]],
  " and verify the solution."
}], "Exercise"],

Cell[TextData[{
  "Solve ",
  Cell[BoxData[
      \(TraditionalForm\`y\^\[Prime] + \ y\^2 = a\)]],
  " and verify the solution."
}], "Exercise"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Numerical solution", "Section"],

Cell[CellGroupData[{

Cell["Basic syntax", "Subsection"],

Cell[TextData[{
  "The command for numerical solution of differential equations is ",
  ButtonBox["NDSolve",
    ButtonStyle->"RefGuideLink"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "with the basic syntax  ",
  StyleBox["NDSolve[", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["eqns,fn,{var,min,max}", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["]", "InlineInput",
    FontWeight->"Bold"],
  ", where ",
  StyleBox["eqns", "InlineInput"],
  " must now be complete enough for a proper numerical solution and ",
  StyleBox["var", "InlineInput"],
  " must be given a definite range between ",
  StyleBox["min", "InlineInput"],
  " and ",
  StyleBox["max", "InlineInput"],
  ".  Hence, ",
  StyleBox["eqns", "InlineInput"],
  " must specify a sufficient number of initial conditions and all symbols \
must evaluate to numbers.  Although the initial conditions usually specify \
values and derivatives directly, more complicated relationships can be \
employed provided that the number of conditions is sufficient.  These \
conditions may be expressed in terms of points outside the range of the \
solution sought.  If the equations for the initial conditions admit multiple \
solutions, ",
  StyleBox["NDSolve", "InlineInput",
    FontWeight->"Bold"],
  " will produce multiple solutions also.   "
}], "Text"],

Cell[TextData[{
  StyleBox["NDSolve", "InlineInput",
    FontWeight->"Bold"],
  " returns its results in the form of interpolating functions.  For example, \
consider the equation of motion for an ordinary pendulum without making the \
simplifying assumption of small-amplitude oscillations."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ndsol1\  = 
      NDSolve[{\(\[Theta]\^\[DoublePrime]\)[
              t] \[Equal] \ \(-Sin[\[Theta][t]]\), \[Theta][
              0] \[Equal] \(3  \[Pi]\)\/4, \(\[Theta]\^\[Prime]\)[0] \[Equal] 
            0}, \ \[Theta], \ {t, 0, 10}]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{"\[Theta]", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{0.`, 10.`}}, "<>"]\),
            False,
            Editable->False]}], "}"}], "}"}]], "Output"]
}, Closed]],

Cell[TextData[{
  "An ",
  ButtonBox["InterpolatingFunction",
    ButtonStyle->"RefGuideLink"],
  " is used to represent an approximate function whose values are obtained by \
interpolation within a table.  It has the form of a pure function.  Thus, ",
  StyleBox["InterpolatingFunction[domain,table][x]", "InlineInput",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "computes the function at argument ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " using an interpolating function defined within a specified ",
  StyleBox["domain", "InlineInput"],
  " based upon values contained in a ",
  StyleBox["table", "InlineInput"],
  ".  In standard output only the domain is printed, with the table indicated \
schematically by",
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["<>", "InlineInput",
    FontWeight->"Bold"],
  ".  Note that if the argument is outside the domain, a warning message is \
issued and an extrapolated value returned; however, extrapolation tends to go \
bad very quickly outside the domain of the interpolating function and should \
be avoided."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Theta][t] /. 
      ndsol1\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    RowBox[{
      TagBox[\(InterpolatingFunction[{{0.`, 10.`}}, "<>"]\),
        False,
        Editable->False], "[", "t", "]"}]], "Output"]
}, Closed]],

Cell[TextData[{
  "An interpolating function can be used like any other function.  In \
particular, its derivative can be evaluated using ",
  StyleBox["D", "InlineInput",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Derivative", "InlineInput",
    FontWeight->"Bold"],
  ".  Thus, it is a simple matter to construct the phase plot for the \
large-amplitude pendulum using ",
  StyleBox["ParametricPlot", "InlineInput",
    FontWeight->"Bold"],
  " to plot the angular velocity against the angular displacement.  Instead \
of the simple circle characteristic of the simple harmonic oscillator, we now \
obtain a flattened curve that resembles an American football."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ParametricPlot[
        Evaluate[{\[Theta][t], \(\[Theta]\^\[Prime]\)[t]} /. 
            ndsol1\[LeftDoubleBracket]1\[RightDoubleBracket]], {t, 0, 10}, 
        AspectRatio \[Rule] Automatic];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .78421 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.202102 0.392106 0.202102 [
[.0958 .37961 -6 -9 ]
[.0958 .37961 6 0 ]
[.2979 .37961 -6 -9 ]
[.2979 .37961 6 0 ]
[.7021 .37961 -3 -9 ]
[.7021 .37961 3 0 ]
[.9042 .37961 -3 -9 ]
[.9042 .37961 3 0 ]
[.4875 .08895 -24 -4.5 ]
[.4875 .08895 0 4.5 ]
[.4875 .19 -12 -4.5 ]
[.4875 .19 0 4.5 ]
[.4875 .29106 -24 -4.5 ]
[.4875 .29106 0 4.5 ]
[.4875 .49316 -18 -4.5 ]
[.4875 .49316 0 4.5 ]
[.4875 .59421 -6 -4.5 ]
[.4875 .59421 0 4.5 ]
[.4875 .69526 -18 -4.5 ]
[.4875 .69526 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .78421 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0958 .39211 m
.0958 .39836 L
s
[(-2)] .0958 .37961 0 1 Mshowa
.2979 .39211 m
.2979 .39836 L
s
[(-1)] .2979 .37961 0 1 Mshowa
.7021 .39211 m
.7021 .39836 L
s
[(1)] .7021 .37961 0 1 Mshowa
.9042 .39211 m
.9042 .39836 L
s
[(2)] .9042 .37961 0 1 Mshowa
.125 Mabswid
.13622 .39211 m
.13622 .39586 L
s
.17664 .39211 m
.17664 .39586 L
s
.21706 .39211 m
.21706 .39586 L
s
.25748 .39211 m
.25748 .39586 L
s
.33832 .39211 m
.33832 .39586 L
s
.37874 .39211 m
.37874 .39586 L
s
.41916 .39211 m
.41916 .39586 L
s
.45958 .39211 m
.45958 .39586 L
s
.54042 .39211 m
.54042 .39586 L
s
.58084 .39211 m
.58084 .39586 L
s
.62126 .39211 m
.62126 .39586 L
s
.66168 .39211 m
.66168 .39586 L
s
.74252 .39211 m
.74252 .39586 L
s
.78294 .39211 m
.78294 .39586 L
s
.82336 .39211 m
.82336 .39586 L
s
.86378 .39211 m
.86378 .39586 L
s
.05538 .39211 m
.05538 .39586 L
s
.01496 .39211 m
.01496 .39586 L
s
.94462 .39211 m
.94462 .39586 L
s
.98504 .39211 m
.98504 .39586 L
s
.25 Mabswid
0 .39211 m
1 .39211 L
s
.5 .08895 m
.50625 .08895 L
s
[(-1.5)] .4875 .08895 1 0 Mshowa
.5 .19 m
.50625 .19 L
s
[(-1)] .4875 .19 1 0 Mshowa
.5 .29106 m
.50625 .29106 L
s
[(-0.5)] .4875 .29106 1 0 Mshowa
.5 .49316 m
.50625 .49316 L
s
[(0.5)] .4875 .49316 1 0 Mshowa
.5 .59421 m
.50625 .59421 L
s
[(1)] .4875 .59421 1 0 Mshowa
.5 .69526 m
.50625 .69526 L
s
[(1.5)] .4875 .69526 1 0 Mshowa
.125 Mabswid
.5 .10916 m
.50375 .10916 L
s
.5 .12937 m
.50375 .12937 L
s
.5 .14958 m
.50375 .14958 L
s
.5 .16979 m
.50375 .16979 L
s
.5 .21022 m
.50375 .21022 L
s
.5 .23043 m
.50375 .23043 L
s
.5 .25064 m
.50375 .25064 L
s
.5 .27085 m
.50375 .27085 L
s
.5 .31127 m
.50375 .31127 L
s
.5 .33148 m
.50375 .33148 L
s
.5 .35169 m
.50375 .35169 L
s
.5 .3719 m
.50375 .3719 L
s
.5 .41232 m
.50375 .41232 L
s
.5 .43253 m
.50375 .43253 L
s
.5 .45274 m
.50375 .45274 L
s
.5 .47295 m
.50375 .47295 L
s
.5 .51337 m
.50375 .51337 L
s
.5 .53358 m
.50375 .53358 L
s
.5 .55379 m
.50375 .55379 L
s
.5 .574 m
.50375 .574 L
s
.5 .61442 m
.50375 .61442 L
s
.5 .63463 m
.50375 .63463 L
s
.5 .65484 m
.50375 .65484 L
s
.5 .67505 m
.50375 .67505 L
s
.5 .06874 m
.50375 .06874 L
s
.5 .04853 m
.50375 .04853 L
s
.5 .02832 m
.50375 .02832 L
s
.5 .00811 m
.50375 .00811 L
s
.5 .71547 m
.50375 .71547 L
s
.5 .73568 m
.50375 .73568 L
s
.5 .75589 m
.50375 .75589 L
s
.5 .7761 m
.50375 .7761 L
s
.25 Mabswid
.5 0 m
.5 .78421 L
s
0 0 m
1 0 L
1 .78421 L
0 .78421 L
closepath
clip
newpath
.5 Mabswid
.97619 .39211 m
.97618 .39034 L
.97615 .38874 L
.9761 .38688 L
.97602 .38513 L
.97583 .38201 L
.97556 .37862 L
.97516 .37488 L
.97462 .37091 L
.9734 .36376 L
.96987 .34929 L
.96432 .33302 L
.95689 .31614 L
.94679 .29733 L
.9227 .26126 L
.84879 .17962 L
.79814 .13606 L
.74275 .09668 L
.68202 .06271 L
.64538 .04683 L
.61081 .03506 L
.5924 .03008 L
.5727 .02574 L
.55572 .02283 L
.54609 .02151 L
.53694 .0205 L
.53186 .02003 L
.52632 .0196 L
.52172 .0193 L
.51662 .01904 L
.51398 .01893 L
.51113 .01884 L
.50811 .01876 L
.50528 .01871 L
.50261 .01868 L
.49981 .01867 L
.49479 .01871 L
.49007 .0188 L
.48504 .01897 L
.48029 .01919 L
.47598 .01944 L
.46542 .02027 L
.45548 .02132 L
.43751 .02389 L
.41792 .02768 L
.37907 .03818 L
.34426 .05097 L
.31296 .06515 L
.24725 .10318 L
.19474 .14172 L
Mistroke
.10764 .22425 L
.07635 .26254 L
.05473 .29475 L
.03799 .32736 L
.03161 .34443 L
.02938 .35194 L
.02736 .3601 L
.02586 .36781 L
.02484 .37495 L
.02442 .37888 L
.02413 .38246 L
.02402 .38443 L
.02396 .38548 L
.02392 .38658 L
.02388 .38754 L
.02385 .38861 L
.02382 .39048 L
.02381 .39223 L
.02382 .39407 L
.02385 .39565 L
.02391 .39737 L
.02399 .39923 L
.0241 .40122 L
.02437 .4048 L
.02474 .40844 L
.02517 .41187 L
.0262 .41832 L
.02765 .42539 L
.02964 .43323 L
.03496 .44932 L
.04893 .47933 L
.0702 .51318 L
.10103 .55242 L
.13843 .5923 L
.18883 .63768 L
.24156 .6772 L
.27502 .69846 L
.30858 .71687 L
.34462 .73339 L
.37913 .74605 L
.41726 .75639 L
.43767 .76034 L
.44881 .76204 L
.45938 .76333 L
.46872 .76423 L
.47365 .76461 L
.47888 .76494 L
.48328 .76517 L
.48813 .76535 L
.49253 .76547 L
Mistroke
.49666 .76553 L
.50182 .76554 L
.50672 .76548 L
.51112 .76538 L
.51591 .7652 L
.5211 .76495 L
.52663 .76459 L
.53655 .76375 L
.54584 .76273 L
.55585 .76137 L
.57389 .75824 L
.6071 .75023 L
.64232 .73855 L
.67945 .72273 L
.74843 .68387 L
.85447 .5992 L
.92309 .52243 L
.94793 .48492 L
.95661 .46865 L
.96402 .45194 L
.96923 .43708 L
.9714 .42931 L
.97328 .42103 L
.97459 .4135 L
.97505 .41022 L
.97545 .40664 L
.97576 .40326 L
.97597 .40011 L
.97605 .39837 L
.97611 .39679 L
.97616 .39496 L
.97619 .39324 L
.97619 .39151 L
.97617 .38965 L
.97613 .38789 L
.97607 .38629 L
.97598 .38441 L
.97586 .38236 L
.97556 .37863 L
.97514 .37473 L
.97457 .37056 L
.97326 .36305 L
.97153 .35542 L
.96955 .34818 L
.96487 .33446 L
.96467 .33394 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 225.813},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001DR000`400?l00000o`00003oe`3oool0
0`000000oooo0?ooo`3F0?ooo`00e`3oool00`000000oooo0?ooo`3F0?ooo`00e`3oool00`000000
oooo0?ooo`3F0?ooo`00e`3oool300000=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo003G
0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`03
0000003oool0oooo0=H0oooo003;0?oooa/00000bP3oool00<40oooo2P00000<0?ooo`030000003o
ool0oooo00`0oooo1`0000330?ooo`00^`3oool6000001H0oooo00<000000?ooo`3oool04`3oool6
00000;d0oooo002g0?ooo`@00000703oool00`000000oooo0?ooo`0I0?ooo`H00000]`3oool00;80
oooo1@00000P0?ooo`<000007`3oool400000;<0oooo002^0?ooo`@000009@3oool00`000000oooo
0?ooo`0S0?ooo`@00000[`3oool00:X0oooo1000000Y0?ooo`030000003oool0oooo02L0oooo1000
002[0?ooo`00YP3oool4000002d0oooo00<000000?ooo`3oool0:`3oool400000:L0oooo002R0?oo
o`@00000<@3oool00`000000oooo0?ooo`0_0?ooo`<00000Y03oool00:00oooo0P00000e0?ooo`03
0000003oool0oooo0380oooo0`00002Q0?ooo`00W@3oool3000003L0oooo00<000000?ooo`3oool0
=@3oool3000009h0oooo002K0?ooo`800000>P3oool00`000000oooo0?ooo`0h0?ooo`<00000V`3o
ool009P0oooo0`00000l0?ooo`030000003oool0oooo03/0oooo0`00002H0?ooo`00UP3oool20000
03l0oooo0`00000n0?ooo`800000UP3oool009<0oooo0`0000110?ooo`030000003oool0oooo0400
oooo0P00002D0?ooo`00T@3oool2000004@0oooo00<000000?ooo`3oool0@P3oool200000980oooo
002?0?ooo`800000AP3oool00`000000oooo0?ooo`140?ooo`800000T03oool008`0oooo0`000018
0?ooo`030000003oool0oooo04H0oooo0P00002>0?ooo`00RP3oool2000004/0oooo00<000000?oo
o`3oool0B03oool2000008`0oooo00280?ooo`800000C@3oool00`000000oooo0?ooo`1:0?ooo`80
0000RP3oool008H0oooo0P00001?0?ooo`030000003oool0oooo04`0oooo0P0000280?ooo`00Q03o
ool200000540oooo0`00001>0?ooo`800000QP3oool00880oooo0P00001C0?ooo`030000003oool0
oooo0500oooo0P0000240?ooo`00P03oool2000005D0oooo00<000000?ooo`3oool0DP3oool20000
0880oooo001o0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E03oool200000800
oooo001m0?ooo`800000F03oool00`000000oooo0?ooo`1F0?ooo`800000OP3oool007/0oooo0P00
001J0?ooo`030000003oool0oooo05P0oooo0P00001l0?ooo`00N@3oool2000003d0oooo00<0okmd
0000000000000`0000000`00M;l0oooo0?ooo`020?ooo`030;md0000000007Bo00D0oooo00D0_g@0
000000000000000007Boo`070?ooo`030000003oool0oooo05X0oooo0P00001j0?ooo`00N03oool0
0`000000oooo0?ooo`100?ooo`0309a8B02Lgol0oooo00D0oooo00<0_g@000000000M;l0103oool0
1`2oM00007Bo0?ooo`3oool0omnL04P0001d_ol01P3oool00`000000oooo0?ooo`1L0?ooo`800000
N03oool007H0oooo0P0000130?ooo`0309a8B02Lgol0oooo0140oooo00<0okmd001d_`3oool01@3o
ool00`000000oooo0?ooo`1N0?ooo`800000MP3oool007@0oooo0P0000150?ooo`0309a8B02Lgol0
oooo0140oooo00<0okmd001d_`3oool01@3oool4000005l0oooo0P00001d0?ooo`00LP3oool20000
03/0oooo00<0W4P00000000000000`0000000`00B9`0oooo0?ooo`030?ooo`0309a8B02Lgol0oooo
0140oooo00<0W4P007Boo`3oool01@3oool00`000000oooo0?ooo`1R0?ooo`800000LP3oool00740
oooo00<000000?ooo`3oool0A`3oool00`2LB4P0W=oo0?ooo`0<0?ooo`030?oo_`1d000000000080
000000<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`1T0?ooo`800000L03oool006l0oooo
0P00001:0?ooo`0309a8B02Lgol0oooo00`0oooo00<0oono07@0M02oool02P3oool00`000000oooo
0?ooo`1V0?ooo`030000003oool0oooo06d0oooo001]0?ooo`800000B@3oool01@3OW4P000000018
W02LB4P0W=oo00d0oooo00<0oono07@0M02oool02P3oool00`000000oooo0?ooo`1W0?ooo`800000
K@3oool006/0oooo0P00001=0?ooo`030=nLB00004P0W=oo00d0oooo00<0oono07@0000000000P00
00000`0007@0_ooo0?ooo`050?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0JP3o
ool006X0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0
oooo06T0oooo001Y0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0J`3oool20000
06T0oooo001W0?ooo`800000KP3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo06H0
oooo001V0?ooo`030000003oool0oooo06h0oooo0`00001^0?ooo`030000003oool0oooo06D0oooo
001U0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0K`3oool2000006D0oooo001S
0?ooo`800000LP3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0680oooo001R0?oo
o`030000003oool0oooo0780oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1Q0?oo
o`00H@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo07<0oooo0P00001Q0?ooo`00
H03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0
GP3oool005h0oooo0P00001g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0G@3o
ool005d0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1g0?ooo`800000G@3oool0
05`0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
05X0oooo001J0?ooo`800000N`3oool3000007X0oooo00<000000?ooo`3oool0F@3oool005T0oooo
00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`1k0?ooo`800000F@3oool005P0oooo00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo05H0oooo001F
0?ooo`800000O`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo05D0oooo001E0?oo
o`030000003oool0oooo07l0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`1D0?oo
o`00E03oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0800oooo0P00001D0?ooo`00
D`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0
D@3oool00580oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`230?ooo`030000003o
ool0oooo0500oooo001A0?ooo`030000003oool0oooo08<0oooo0`0000240?ooo`030000003oool0
oooo04l0oooo001@0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0Q@3oool00`00
0000oooo0?ooo`1>0?ooo`00C`3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool0C@3oool004d0oooo0P0000280?ooo`030000003oool0oooo08L0oooo
00<000000?ooo`3oool0C03oool004`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?oo
o`280?ooo`800000C03oool004/0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2:
0?ooo`030000003oool0oooo04T0oooo001:0?ooo`030000003oool0oooo08X0oooo00<000000?oo
o`3oool0R`3oool00`000000oooo0?ooo`180?ooo`00B@3oool00`000000oooo0?ooo`2;0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool0A`3oool004P0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04H0oooo00170?ooo`030000003o
ool0oooo08d0oooo0`00002>0?ooo`030000003oool0oooo04D0oooo00160?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0S`3oool2000004D0oooo00150?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`120?ooo`00A03oool00`000000
oooo0?ooo`2@0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0@@3oool004<0oooo
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0400oooo
00120?ooo`030000003oool0oooo08D0oooo00<0okmd0000000000000`0000000`00M;l0oooo0?oo
o`040?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0?`3oool00400oooo0P00002;
0?ooo`0309a8B02Lgol0oooo00L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0n
0?ooo`00?`3oool00`000000oooo0?ooo`2;0?ooo`0309a8B02Lgol0oooo00L0oooo00<000000?oo
o`3oool0UP3oool00`000000oooo0?ooo`0m0?ooo`00?P3oool00`000000oooo0?ooo`2<0?ooo`03
09a8B02Lgol0oooo00L0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0l0?ooo`00
?@3oool00`000000oooo0?ooo`210?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool0
0`3oool00`2LB4P0W=oo0?ooo`070?ooo`@00000U`3oool00`000000oooo0?ooo`0k0?ooo`00?03o
ool00`000000oooo0?ooo`2>0?ooo`0309a8B02Lgol0oooo00L0oooo00<000000?ooo`3oool0V03o
ool00`000000oooo0?ooo`0k0?ooo`00>`3oool00`000000oooo0?ooo`2?0?ooo`0309a8B02Lgol0
oooo00L0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0j0?ooo`00>P3oool00`00
0000oooo0?ooo`2=0?ooo`050=nLB000000004RL09a8B02Lgol0203oool00`000000oooo0?ooo`2J
0?ooo`030000003oool0oooo03T0oooo000i0?ooo`030000003oool0oooo0900oooo00<0gia80000
B02Lgol0203oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo03P0oooo000h0?ooo`03
0000003oool0oooo09`0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0g0?ooo`00
=`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0
=P3oool003H0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`2N0?ooo`030000003o
ool0oooo03D0oooo000d0?ooo`800000X@3oool3000009l0oooo00<000000?ooo`3oool0=03oool0
03<0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo
03<0oooo000b0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0X@3oool00`000000
oooo0?ooo`0b0?ooo`00<@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo0:80oooo
00<000000?ooo`3oool0<@3oool00300oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?oo
o`2S0?ooo`030000003oool0oooo0300oooo000_0?ooo`030000003oool0oooo0:D0oooo00<00000
0?ooo`3oool0X`3oool00`000000oooo0?ooo`0`0?ooo`00;P3oool00`000000oooo0?ooo`2V0?oo
o`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0;`3oool002d0oooo00<000000?ooo`3o
ool0Y`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02h0oooo000/0?ooo`030000
003oool0oooo0:P0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0]0?ooo`00;03o
ool00`000000oooo0?ooo`2X0?ooo`<00000Y`3oool00`000000oooo0?ooo`0/0?ooo`00:`3oool0
0`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0:`3oool0
02X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo
02X0oooo000Y0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0ZP3oool00`000000
oooo0?ooo`0Y0?ooo`00:@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0:/0oooo
00<000000?ooo`3oool0:03oool002P0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?oo
o`2/0?ooo`030000003oool0oooo02L0oooo000W0?ooo`030000003oool0oooo0:d0oooo00<00000
0?ooo`3oool0[@3oool00`000000oooo0?ooo`0V0?ooo`009P3oool00`000000oooo0?ooo`2^0?oo
o`030000003oool0oooo0:h0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3o
ool0[P3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo02D0oooo000U0?ooo`030000
003oool0oooo0:l0oooo0`00002_0?ooo`030000003oool0oooo02@0oooo000T0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0S0?ooo`008`3oool0
0`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool08P3oool0
02<0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo
0240oooo000R0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool0/`3oool00`000000
oooo0?ooo`0P0?ooo`008@3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo0;@0oooo
00<000000?ooo`3oool07`3oool00200oooo00<000000?ooo`3oool0]03oool00`000000oooo0?oo
o`2d0?ooo`030000003oool0oooo01l0oooo000P0?ooo`030000003oool0oooo0;@0oooo00<00000
0?ooo`3oool0]@3oool00`000000oooo0?ooo`0N0?ooo`007`3oool00`000000oooo0?ooo`2e0?oo
o`<00000]@3oool00`000000oooo0?ooo`0N0?ooo`007P3oool00`000000oooo0?ooo`2f0?ooo`03
0000003oool0oooo0;H0oooo00<000000?ooo`3oool07@3oool001d0oooo00<000000?ooo`3oool0
]`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01`0oooo000M0?ooo`030000003o
ool0oooo0;L0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0L0?ooo`00703oool0
0`000000oooo0?ooo`2h0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06`3oool0
01/0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo
01X0oooo000K0?ooo`030000003oool0oooo09/0oooo00D0okmd000000000000000007Boo`050?oo
o`030;md0000000007Bo00D0oooo00D0_g@0000000000000000007Boo`070?ooo`030000003oool0
oooo0;T0oooo00<000000?ooo`3oool06P3oool001X0oooo00<000000?ooo`3oool0W03oool01P2L
B7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l0103oool01`2oM00007Bo0?oo
o`3oool0omnL04P0001d_ol01P3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01T0
oooo000I0?ooo`030000003oool0oooo09`0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO
0?ooo`0?0?ooo`030?noM000M;l0oooo00D0oooo00<000000?ooo`3oool0^P3oool00`000000oooo
0?ooo`0I0?ooo`00603oool00`000000oooo0?ooo`2M0?ooo`030=nLB018W=l0oooo0080oooo00<0
okmd001d_`3oool03`3oool00`3o_g@007Bo0?ooo`050?ooo`@00000^P3oool00`000000oooo0?oo
o`0H0?ooo`00603oool00`000000oooo0?ooo`2D0?ooo`0309a800000000000000<0000000D004RL
0?ooo`3oool0gia804RLg`030?ooo`030?noM000M;l0oooo00l0oooo00<0W4P007Boo`3oool01@3o
ool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01L0oooo000G0?ooo`030000003oool0
oooo09h0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`030?oo_`1d0000
00000080000000<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0
oooo01L0oooo000F0?ooo`030000003oool0oooo09l0oooo00<0okmd04RLg`3oool00P3oool00`3O
W4P0B9cO0?ooo`0:0?ooo`030?oo_`1d07@0_ooo00X0oooo00<000000?ooo`3oool0_@3oool00`00
0000oooo0?ooo`0F0?ooo`005P3oool00`000000oooo0?ooo`2P0?ooo`0609a8001d_ol0oooo0?oO
W01807@0_ooo2`3oool00`3ookl0M01d0;ooo`0:0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool05@3oool001D0oooo00<000000?ooo`3oool0X@3oool01@3ookl0M0000000000004P0
W=oo00`0oooo00<0oono07@0000000000P0000000`0007@0_ooo0?ooo`050?ooo`030000003oool0
oooo0;h0oooo00<000000?ooo`3oool05@3oool001D0oooo00<000000?ooo`3oool0_`3oool00`00
0000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo000D0?ooo`030000003oool0oooo0<00
oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`00503oool00`000000oooo
0?ooo`300?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool001<0oooo00<0
00000?ooo`3oool0`@3oool300000<40oooo00<000000?ooo`3oool04P3oool001<0oooo00<00000
0?ooo`3oool0`@3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo000B0?oo
o`030000003oool0oooo0<80oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?oo
o`004P3oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3o
ool04@3oool00140oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`330?ooo`030000
003oool0oooo0100oooo000A0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0``3o
ool00`000000oooo0?ooo`0@0?ooo`00403oool00`000000oooo0?ooo`340?ooo`030000003oool0
oooo0<@0oooo00<000000?ooo`3oool03`3oool00100oooo00<000000?ooo`3oool0a03oool00`00
0000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo000@0?ooo`030000003oool0oooo0<@0
oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo
0?ooo`350?ooo`<00000a@3oool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?oo
o`350?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool000h0oooo00<00000
0?ooo`3oool0aP3oool00`000000oooo0?ooo`350?ooo`8000003`3oool000h0oooo00<000000?oo
o`3oool0aP3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00d0oooo000=0?ooo`03
0000003oool0oooo0<L0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0=0?ooo`00
3@3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool0
3@3oool000d0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`370?ooo`030000003o
ool0oooo00`0oooo000<0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0a`3oool0
0`000000oooo0?ooo`0<0?ooo`00303oool00`000000oooo0?ooo`0J0?ooo`030?oo_`1d00000000
00@0000000<0M;oo0?ooo`3oool0CP3oool00`3o_g@000000000000300000003001d_`3oool0oooo
04d0oooo0`00001A0?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool0C@3oool00`3o
okl0M000000000040000000307Boo`3oool0oooo01H0oooo00<000000?ooo`3oool0303oool000`0
oooo00<000000?ooo`3oool06`3oool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo0580
oooo00<0W4Q809cOo`3oool0D03oool00`000000oooo0?ooo`1D0?ooo`0309a8B02Lgol0oooo0540
oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?ooo`0H0?ooo`030000003oool0oooo00/0
oooo000;0?ooo`030000003oool0oooo01d0oooo00<0okmd0000B02Lgol0EP3oool00`2LB4P0W=oo
0?ooo`1@0?ooo`030000003oool0oooo05@0oooo00<0W4Q809cOo`3oool0DP3oool00`3o_g@00018
09cOo`0L0?ooo`030000003oool0oooo00/0oooo000;0?ooo`030000003oool0oooo01h0oooo00<0
omnL04P00018W=l0E@3oool00`2LB4P0W=oo0?ooo`1@0?ooo`030000003oool0oooo05@0oooo00<0
W4Q809cOo`3oool0D`3oool00`3ogi`0B00004RLg`0K0?ooo`030000003oool0oooo00/0oooo000;
0?ooo`030000003oool0oooo01<0oooo00<0W4P00000000000000`0000000`00B9`0oooo0?ooo`04
0?ooo`0309a80018W=l0oooo04L0oooo00<0W4P00000000000000`0000000`00B9`0oooo0?ooo`03
0?ooo`0309a8B02Lgol0oooo0500oooo00<000000?ooo`3oool0E03oool00`2LB4P0W=oo0?ooo`1E
0?ooo`0309a80018W=l0oooo01X0oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?oo
o`3oool08@3oool00`2LB7@0_ooo0?ooo`1B0?ooo`0309a8B02Lgol0oooo0500oooo00<000000?oo
o`3oool0E03oool00`2LB4P0W=oo0?ooo`1F0?ooo`0309a8M02oool0oooo01T0oooo00<000000?oo
o`3oool02P3oool000/0oooo00<000000?ooo`3oool0703oool00`3OW4P0M;oo0?ooo`020?ooo`03
0;md001d_ol0oooo0580oooo00<0W4Q809cOo`3oool0D03oool00`000000oooo0?ooo`1D0?ooo`03
09a8B02Lgol0oooo0540oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`0I0?ooo`03
0000003oool0oooo00X0oooo000;0?ooo`030000003oool0oooo01`0oooo00L0okmd0000M02oool0
oooo0?noM00004P0W=oo0500oooo00D0gia800000000B9`0W4Q809cOo`1A0?ooo`030000003oool0
oooo0540oooo00D0gia800000000B9`0W4Q809cOo`1B0?ooo`070?noM00007@0_ooo0?ooo`3o_g@0
001809cOo`0J0?ooo`030000003oool0oooo00X0oooo000;0?ooo`030000003oool0oooo01d0oooo
00D0okmd000000000000001809cOo`1C0?ooo`030=nLB00004P0W=oo0540oooo00<000000?ooo`3o
ool0D`3oool00`3OW4P0001809cOo`1C0?ooo`050?noM000000000000000B02Lgol06`3oool00`00
0000oooo0?ooo`0:0?ooo`002P3oool00`000000oooo0?ooo`3:0?ooo`<00000b@3oool00`000000
oooo0?ooo`0:0?ooo`002P3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo0<X0oooo
00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?oo
o`3:0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0<X0oooo00<00000
0?ooo`3oool0bP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`3:0?oo
o`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3o
ool0bP3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000
003oool0oooo0<X0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`090?ooo`002P3o
ool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02@3o
ool000X0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0
oooo00T0oooo003o00000;0000000@3oool000H0oooo00D000000?ooo`3oool0oooo0000000=0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool0
000000L0oooo000:0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0<X0
oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo
0?ooo`3:0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02@3oool000X0oooo00<0
00000?ooo`3oool0bP3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00T0oooo000:
0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`09
0?ooo`002P3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo0<X0oooo00<000000?oo
o`3oool02@3oool000/0oooo00<000000?ooo`3oool0b@3oool300000<T0oooo00<000000?ooo`3o
ool02P3oool000/0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`390?ooo`030000
003oool0oooo00X0oooo000;0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool0b@3o
ool00`000000oooo0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`390?ooo`030000003oool0
oooo0<T0oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`3oool0b@3oool00`00
0000oooo0?ooo`390?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo0<P0
oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0:0?ooo`00303oool00`000000oooo
0?ooo`380?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool02`3oool000`0oooo00<0
00000?ooo`3oool0b03oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00/0oooo000<
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0;
0?ooo`00303oool00`000000oooo0?ooo`380?ooo`<00000b03oool00`000000oooo0?ooo`0;0?oo
o`00303oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3o
ool0303oool000d0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`370?ooo`030000
003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool0a`3o
ool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?ooo`360?ooo`030000003oool0
oooo0<H0oooo00<000000?ooo`3oool03@3oool000h0oooo00<000000?ooo`3oool0aP3oool00`00
0000oooo0?ooo`360?ooo`030000003oool0oooo00d0oooo000?0?ooo`030000003oool0oooo0<D0
oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo
0?ooo`350?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool000l0oooo00<0
00000?ooo`3oool0a@3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo000@
0?ooo`030000003oool0oooo0<@0oooo0`0000350?ooo`030000003oool0oooo00h0oooo000@0?oo
o`030000003oool0oooo0<@0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?oo
o`004@3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3o
ool03`3oool00140oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`330?ooo`030000
003oool0oooo0100oooo000B0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0``3o
ool00`000000oooo0?ooo`0@0?ooo`004P3oool00`000000oooo0?ooo`320?ooo`030000003oool0
oooo0<<0oooo00<000000?ooo`3oool0403oool001<0oooo00<000000?ooo`3oool0`@3oool00`00
0000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo000C0?ooo`030000003oool0oooo0<40
oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`00503oool00`000000oooo
0?ooo`300?ooo`<00000`@3oool00`000000oooo0?ooo`0B0?ooo`00503oool00`000000oooo0?oo
o`300?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool001D0oooo00<00000
0?ooo`3oool0_`3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo000E0?oo
o`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?oo
o`005P3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3o
ool0503oool001H0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`2o0?ooo`030000
003oool0oooo01@0oooo000G0?ooo`030000003oool0oooo09l0oooo00D0okmd0000000000000000
07Boo`050?ooo`030;md0000000007Bo00D0oooo00D0_g@0000000000000000007Boo`070?ooo`03
0000003oool0oooo0;h0oooo00<000000?ooo`3oool05@3oool001L0oooo00<000000?ooo`3oool0
W`3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l0103oool01`2o
M00007Bo0?ooo`3oool0omnL04P0001d_ol01P3oool00`000000oooo0?ooo`2m0?ooo`030000003o
ool0oooo01H0oooo000H0?ooo`030000003oool0oooo09d0oooo00<0okmd001d_`3oool00P3oool0
0`3OW4P0B9cO0?ooo`0?0?ooo`030?noM000M;l0oooo00D0oooo00<000000?ooo`3oool0_@3oool0
0`000000oooo0?ooo`0F0?ooo`006@3oool00`000000oooo0?ooo`2L0?ooo`030=nLB018W=l0oooo
0080oooo00<0okmd001d_`3oool03`3oool00`3o_g@007Bo0?ooo`050?ooo`@00000^`3oool00`00
0000oooo0?ooo`0G0?ooo`006@3oool00`000000oooo0?ooo`2L0?ooo`030=nLB018W=l0oooo0080
oooo00<0okmd001d_`3oool03`3oool00`2LB000M;oo0?ooo`050?ooo`030000003oool0oooo0;/0
oooo00<000000?ooo`3oool0603oool001X0oooo00<000000?ooo`3oool0V`3oool00`3OW4P0B9cO
0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0oono07@0000000000P0000000`18W=l0oooo
0?ooo`050?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0603oool001X0oooo00<0
00000?ooo`3oool0V`3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0
oono07@0M02oool02P3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01T0oooo000K
0?ooo`030000003oool0oooo09/0oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`030?oo
_`1d07@0_ooo00X0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0J0?ooo`00703o
ool00`000000oooo0?ooo`2J0?ooo`050?oo_`1d000000000000B02Lgol0303oool00`3ookl0M000
00000002000000030000M02oool0oooo00D0oooo00<000000?ooo`3oool0^03oool00`000000oooo
0?ooo`0K0?ooo`00703oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo0;P0oooo00<0
00000?ooo`3oool06`3oool001d0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`2g
0?ooo`030000003oool0oooo01`0oooo000M0?ooo`030000003oool0oooo0;L0oooo00<000000?oo
o`3oool0]P3oool00`000000oooo0?ooo`0M0?ooo`007P3oool00`000000oooo0?ooo`2f0?ooo`<0
0000]P3oool00`000000oooo0?ooo`0M0?ooo`007`3oool00`000000oooo0?ooo`2e0?ooo`030000
003oool0oooo0;D0oooo00<000000?ooo`3oool07P3oool00200oooo00<000000?ooo`3oool0]03o
ool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01l0oooo000P0?ooo`030000003oool0
oooo0;@0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0O0?ooo`008@3oool00`00
0000oooo0?ooo`2c0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool0803oool00280
oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo0240
oooo000S0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0/@3oool00`000000oooo
0?ooo`0R0?ooo`008`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool08`3oool002@0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`2_
0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo0:l0oooo0`00002_0?oo
o`030000003oool0oooo02@0oooo000V0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3o
ool0[P3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`2^0?ooo`030000
003oool0oooo0:d0oooo00<000000?ooo`3oool09P3oool002L0oooo00<000000?ooo`3oool0[@3o
ool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo02L0oooo000X0?ooo`030000003oool0
oooo0:`0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0X0?ooo`00:@3oool00`00
0000oooo0?ooo`2[0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0:@3oool002T0
oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02X0
oooo000Z0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0Z03oool00`000000oooo
0?ooo`0[0?ooo`00:`3oool00`000000oooo0?ooo`2Y0?ooo`<00000Z03oool00`000000oooo0?oo
o`0[0?ooo`00;03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0:L0oooo00<00000
0?ooo`3oool0;03oool002d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`2V0?oo
o`030000003oool0oooo02d0oooo000^0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3o
ool0Y@3oool00`000000oooo0?ooo`0^0?ooo`00;`3oool00`000000oooo0?ooo`2U0?ooo`030000
003oool0oooo0:@0oooo00<000000?ooo`3oool0;`3oool00300oooo00<000000?ooo`3oool0Y03o
ool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo0300oooo000a0?ooo`030000003oool0
oooo0:<0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0a0?ooo`00<P3oool00`00
0000oooo0?ooo`2R0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0<P3oool003<0
oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo0380
oooo000c0?ooo`030000003oool0oooo0:40oooo0`00002P0?ooo`030000003oool0oooo03<0oooo
000d0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?oo
o`0d0?ooo`00=@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo09h0oooo00<00000
0?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`2M0?oo
o`030000003oool0oooo03H0oooo000g0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3o
ool0W03oool00`000000oooo0?ooo`0g0?ooo`00>03oool00`000000oooo0?ooo`2?0?ooo`030?no
M0000000000000<0000000<007Bo0?ooo`3oool0103oool00`000000oooo0?ooo`2K0?ooo`030000
003oool0oooo03P0oooo000i0?ooo`030000003oool0oooo0940oooo00<0W4Q809cOo`3oool01`3o
ool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo03T0oooo000j0?ooo`030000003oool0
oooo0900oooo00<0W4Q809cOo`3oool01`3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0
oooo03T0oooo000k0?ooo`030000003oool0oooo08l0oooo00<0W4Q809cOo`3oool01`3oool00`00
0000oooo0?ooo`2I0?ooo`030000003oool0oooo03X0oooo000l0?ooo`030000003oool0oooo08h0
oooo00<0W4Q809cOo`3oool01`3oool4000009L0oooo00<000000?ooo`3oool0>`3oool003d0oooo
00<000000?ooo`3oool0S@3oool00`2LB4P0W=oo0?ooo`070?ooo`030000003oool0oooo09L0oooo
00<000000?ooo`3oool0?03oool003h0oooo0P00002=0?ooo`0309a8B02Lgol0oooo00L0oooo00<0
00000?ooo`3oool0UP3oool00`000000oooo0?ooo`0m0?ooo`00@03oool00`000000oooo0?ooo`27
0?ooo`050=nLB000000004RL09a8B02Lgol0203oool00`000000oooo0?ooo`2E0?ooo`030000003o
ool0oooo03h0oooo00110?ooo`030000003oool0oooo08P0oooo00<0gia80000B02Lgol0203oool0
0`000000oooo0?ooo`2C0?ooo`800000@@3oool00480oooo00<000000?ooo`3oool0TP3oool00`00
0000oooo0?ooo`2B0?ooo`030000003oool0oooo0440oooo00130?ooo`030000003oool0oooo0940
oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`120?ooo`00A03oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo08l0oooo0P0000150?ooo`00A@3oool00`000000oooo0?oo
o`2?0?ooo`<00000SP3oool00`000000oooo0?ooo`150?ooo`00AP3oool2000008l0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`160?ooo`00B03oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo08`0oooo00<000000?ooo`3oool0A`3oool004T0oooo00<000000?ooo`3o
ool0R`3oool00`000000oooo0?ooo`2:0?ooo`800000BP3oool004X0oooo00<000000?ooo`3oool0
RP3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo04X0oooo001;0?ooo`030000003o
ool0oooo08T0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`1;0?ooo`00C03oool0
0`000000oooo0?ooo`280?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0C03oool0
04d0oooo0P0000280?ooo`030000003oool0oooo08D0oooo0P00001?0?ooo`00C`3oool00`000000
oooo0?ooo`250?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0C`3oool00500oooo
00<000000?ooo`3oool0Q03oool3000008<0oooo00<000000?ooo`3oool0D03oool00540oooo00<0
00000?ooo`3oool0P`3oool00`000000oooo0?ooo`210?ooo`800000D`3oool00580oooo0P000023
0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0D`3oool005@0oooo00<000000?oo
o`3oool0P03oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo05@0oooo001E0?ooo`03
0000003oool0oooo07l0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`1E0?ooo`00
EP3oool2000007l0oooo00<000000?ooo`3oool0O03oool2000005P0oooo001H0?ooo`030000003o
ool0oooo07`0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`1H0?ooo`00F@3oool0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0F@3oool0
05X0oooo0P00001k0?ooo`030000003oool0oooo07P0oooo0P00001L0?ooo`00G03oool00`000000
oooo0?ooo`1h0?ooo`<00000M`3oool00`000000oooo0?ooo`1L0?ooo`00G@3oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0G@3oool005h0oooo0P00
001g0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0GP3oool00600oooo00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`1c0?ooo`800000H@3oool00640oooo00<000000?oo
o`3oool0L`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0640oooo001R0?ooo`80
0000L`3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0680oooo001T0?ooo`030000
003oool0oooo0700oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1S0?ooo`00I@3o
ool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo06h0oooo0P00001V0?ooo`00IP3oool2
000006l0oooo0`00001]0?ooo`030000003oool0oooo06H0oooo001X0?ooo`030000003oool0oooo
06`0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1W0?ooo`00J@3oool2000006`0
oooo00<000000?ooo`3oool0JP3oool2000006X0oooo001[0?ooo`030000003oool0oooo06T0oooo
00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1Z0?ooo`00K03oool00`000000oooo0?oo
o`1X0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0J`3oool006d0oooo0P00001X
0?ooo`030000003oool0oooo06H0oooo0P00001^0?ooo`00K`3oool00`000000oooo0?ooo`160?oo
o`030?noM0000000000000<0000000<007Bo0?ooo`3oool00P3oool00`2oM0000000001d_`050?oo
o`050;md0000000000000000001d_ol01`3oool00`000000oooo0?ooo`1T0?ooo`800000L03oool0
0700oooo0P0000190?ooo`0309a8B02Lgol0oooo00D0oooo00<0_g@000000000M;l0103oool01`2o
M00007Bo0?ooo`3oool0omnL04P0001d_ol01P3oool00`000000oooo0?ooo`1R0?ooo`800000LP3o
ool00780oooo00<000000?ooo`3oool0AP3oool00`2LB4P0W=oo0?ooo`0A0?ooo`030?noM000M;l0
oooo00D0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1b0?ooo`00L`3oool00`00
0000oooo0?ooo`150?ooo`0309a8B02Lgol0oooo0140oooo00<0okmd001d_`3oool01@3oool40000
05h0oooo0P00001e0?ooo`00M03oool2000004D0oooo00<0W4Q809cOo`3oool04@3oool00`2LB000
M;oo0?ooo`050?ooo`030000003oool0oooo05d0oooo0P00001g0?ooo`00MP3oool2000004<0oooo
00<0W4Q809cOo`3oool0303oool00`3ookl0M000000000020000000304RLg`3oool0oooo00D0oooo
00<000000?ooo`3oool0F`3oool2000007T0oooo001h0?ooo`800000@@3oool00`2LB4P0W=oo0?oo
o`0<0?ooo`030?oo_`1d07@0_ooo00X0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?oo
o`1i0?ooo`00NP3oool2000003`0oooo00D0gia800000000B9`0W4Q809cOo`0=0?ooo`030?oo_`1d
07@0_ooo00X0oooo00<000000?ooo`3oool0F03oool2000007`0oooo001l0?ooo`800000?03oool0
0`3OW4P0001809cOo`0=0?ooo`030?oo_`1d000000000080000000<0001d0;ooo`3oool01@3oool0
0`000000oooo0?ooo`1F0?ooo`800000OP3oool007h0oooo0P00001G0?ooo`030000003oool0oooo
05@0oooo0P0000200?ooo`00P03oool2000005D0oooo00<000000?ooo`3oool0DP3oool200000880
oooo00220?ooo`800000D`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0880oooo
00240?ooo`800000D@3oool3000004l0oooo0P0000250?ooo`00QP3oool2000004l0oooo00<00000
0?ooo`3oool0C@3oool2000008L0oooo00280?ooo`800000C@3oool00`000000oooo0?ooo`1;0?oo
o`800000R@3oool008X0oooo0P00001;0?ooo`030000003oool0oooo04T0oooo0P00002;0?ooo`00
S03oool2000004T0oooo00<000000?ooo`3oool0A`3oool2000008d0oooo002>0?ooo`800000A`3o
ool00`000000oooo0?ooo`150?ooo`800000S`3oool00900oooo0P0000150?ooo`030000003oool0
oooo04<0oooo0P00002A0?ooo`00TP3oool2000004<0oooo00<000000?ooo`3oool0@03oool30000
09<0oooo002D0?ooo`800000@@3oool00`000000oooo0?ooo`0n0?ooo`800000UP3oool009H0oooo
0`00000n0?ooo`<00000?03oool2000009P0oooo002I0?ooo`<00000>`3oool00`000000oooo0?oo
o`0i0?ooo`<00000VP3oool009`0oooo0`00000h0?ooo`030000003oool0oooo03H0oooo0`00002M
0?ooo`00W`3oool3000003D0oooo00<000000?ooo`3oool0<`3oool300000:00oooo002R0?ooo`<0
0000<P3oool00`000000oooo0?ooo`0`0?ooo`<00000X`3oool00:D0oooo0`00000_0?ooo`030000
003oool0oooo02d0oooo0`00002V0?ooo`00Z03oool3000002`0oooo00<000000?ooo`3oool0:@3o
ool400000:T0oooo002[0?ooo`@00000:03oool00`000000oooo0?ooo`0U0?ooo`@00000[@3oool0
0:l0oooo0`00000U0?ooo`<00000803oool500000;40oooo002b0?ooo`H000007`3oool00`000000
oooo0?ooo`0L0?ooo`@00000]P3oool00;P0oooo1`00000H0?ooo`030000003oool0oooo01P0oooo
1000002j0?ooo`00_`3oool5000001<0oooo00<000000?ooo`3oool0403oool800000;h0oooo0034
0?ooobH00000aP3oool00=L0oooo00<000000?ooo`3oool0eP3oool00=L0oooo00<000000?ooo`3o
ool0eP3oool00=L0oooo00<000000?ooo`3oool0eP3oool00=L0oooo00<000000?ooo`3oool0eP3o
ool00=L0oooo0`00003F0?ooo`00e`3oool00`000000oooo0?ooo`3F0?ooo`00e`3oool00`000000
oooo0?ooo`3F0?ooo`00e`3oool00`000000oooo0?ooo`3F0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {337.688, 0}} -> {-2.47627, -1.94016, \
0.0172362, 0.0172362}}]
}, Closed]],

Cell["Driven pendulum", "Exercise"],

Cell["\<\
A driven pendulum with linear damping satisfies an equation of motion of the \
form\
\>", "ExerciseText"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[\(\[PartialD]\^2 \[Theta]\), \(\[PartialD]t\^2\),
            MultilineFunction->None], "+", 
          RowBox[{"\[Gamma]", " ", 
            FractionBox[\(\[PartialD]\[Theta]\), \(\[PartialD]t\),
              MultilineFunction->None]}], "+", 
          " ", \(\(\[Omega]\_0\^2\) \(sin(\[Theta])\)\)}], 
        "\[Equal]", \(f\ \(cos(\[Omega]\ t)\)\)}], 
      TraditionalForm]], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " are the amplitude and frequency of the driving force and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " is the damping coefficient.  The natural frequency for free oscillations \
is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_0 = \@\(g/\[ScriptL]\)\)]],
  ", but it is convenient to express frequency in units of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_0\)]],
  " by setting  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_0 \[Rule] 1\)]],
  " and rescaling the time unit accordingly.  Write functions which solve the \
pendulum equation numerically and which produce phase diagrams.  Examine and \
describe the behavior for the following situations.\na) free undamped \
oscillation (",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f = 0\)]],
  ") versus ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\_0\)]],
  "\nb) modest damping and driving forces (",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] \[TildeTilde] 0.1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f \[TildeTilde] 0.1\)]],
  ") for ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Omega], 0.5, 1, 0.5}\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\_0 = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\& . \_0 = 0\)]],
  "."
}], "ExerciseText",
  CellDingbat->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Systems of equations", "Subsection"],

Cell[TextData[{
  StyleBox["NDSolve", "InlineInput",
    FontWeight->"Bold"],
  " will also solve systems of differential equations.  For example, another \
method for producing a phase plot is to reduce a second-order differential \
equation to a pair of first-order equations and then to solve for the \
displacement and velocity as if these were independent functions."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ndsol3\  = 
      NDSolve[{\[Omega][t]\  \[Equal] \ \(\[Theta]\^\[Prime]\)[
              t], \(\[Omega]\^\[Prime]\)[
              t] \[Equal] \ \(-Sin[\[Theta][t]]\), \[Theta][
              0] \[Equal] \(3  \[Pi]\)\/4, \[Omega][0] \[Equal] 
            0}, \ {\[Theta], \[Omega]}, \ {t, 0, 10}]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Theta]", "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 10.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{"\[Omega]", "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 10.`}}, "<>"]\),
              False,
              Editable->False]}]}], "}"}], "}"}]], "Output"]
}, Closed]],

Cell["\<\
Although there is only one solution, that solution consists of two \
replacement rules.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ParametricPlot[
        Evaluate[{\[Theta][t], \[Omega][t]} /. 
            ndsol3\[LeftDoubleBracket]1\[RightDoubleBracket]], {t, 0, 10}, 
        AspectRatio \[Rule] Automatic];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .78421 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.202102 0.392106 0.202102 [
[.0958 .37961 -6 -9 ]
[.0958 .37961 6 0 ]
[.2979 .37961 -6 -9 ]
[.2979 .37961 6 0 ]
[.7021 .37961 -3 -9 ]
[.7021 .37961 3 0 ]
[.9042 .37961 -3 -9 ]
[.9042 .37961 3 0 ]
[.4875 .08895 -24 -4.5 ]
[.4875 .08895 0 4.5 ]
[.4875 .19 -12 -4.5 ]
[.4875 .19 0 4.5 ]
[.4875 .29106 -24 -4.5 ]
[.4875 .29106 0 4.5 ]
[.4875 .49316 -18 -4.5 ]
[.4875 .49316 0 4.5 ]
[.4875 .59421 -6 -4.5 ]
[.4875 .59421 0 4.5 ]
[.4875 .69526 -18 -4.5 ]
[.4875 .69526 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .78421 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0958 .39211 m
.0958 .39836 L
s
[(-2)] .0958 .37961 0 1 Mshowa
.2979 .39211 m
.2979 .39836 L
s
[(-1)] .2979 .37961 0 1 Mshowa
.7021 .39211 m
.7021 .39836 L
s
[(1)] .7021 .37961 0 1 Mshowa
.9042 .39211 m
.9042 .39836 L
s
[(2)] .9042 .37961 0 1 Mshowa
.125 Mabswid
.13622 .39211 m
.13622 .39586 L
s
.17664 .39211 m
.17664 .39586 L
s
.21706 .39211 m
.21706 .39586 L
s
.25748 .39211 m
.25748 .39586 L
s
.33832 .39211 m
.33832 .39586 L
s
.37874 .39211 m
.37874 .39586 L
s
.41916 .39211 m
.41916 .39586 L
s
.45958 .39211 m
.45958 .39586 L
s
.54042 .39211 m
.54042 .39586 L
s
.58084 .39211 m
.58084 .39586 L
s
.62126 .39211 m
.62126 .39586 L
s
.66168 .39211 m
.66168 .39586 L
s
.74252 .39211 m
.74252 .39586 L
s
.78294 .39211 m
.78294 .39586 L
s
.82336 .39211 m
.82336 .39586 L
s
.86378 .39211 m
.86378 .39586 L
s
.05538 .39211 m
.05538 .39586 L
s
.01496 .39211 m
.01496 .39586 L
s
.94462 .39211 m
.94462 .39586 L
s
.98504 .39211 m
.98504 .39586 L
s
.25 Mabswid
0 .39211 m
1 .39211 L
s
.5 .08895 m
.50625 .08895 L
s
[(-1.5)] .4875 .08895 1 0 Mshowa
.5 .19 m
.50625 .19 L
s
[(-1)] .4875 .19 1 0 Mshowa
.5 .29106 m
.50625 .29106 L
s
[(-0.5)] .4875 .29106 1 0 Mshowa
.5 .49316 m
.50625 .49316 L
s
[(0.5)] .4875 .49316 1 0 Mshowa
.5 .59421 m
.50625 .59421 L
s
[(1)] .4875 .59421 1 0 Mshowa
.5 .69526 m
.50625 .69526 L
s
[(1.5)] .4875 .69526 1 0 Mshowa
.125 Mabswid
.5 .10916 m
.50375 .10916 L
s
.5 .12937 m
.50375 .12937 L
s
.5 .14958 m
.50375 .14958 L
s
.5 .16979 m
.50375 .16979 L
s
.5 .21022 m
.50375 .21022 L
s
.5 .23043 m
.50375 .23043 L
s
.5 .25064 m
.50375 .25064 L
s
.5 .27085 m
.50375 .27085 L
s
.5 .31127 m
.50375 .31127 L
s
.5 .33148 m
.50375 .33148 L
s
.5 .35169 m
.50375 .35169 L
s
.5 .3719 m
.50375 .3719 L
s
.5 .41232 m
.50375 .41232 L
s
.5 .43253 m
.50375 .43253 L
s
.5 .45274 m
.50375 .45274 L
s
.5 .47295 m
.50375 .47295 L
s
.5 .51337 m
.50375 .51337 L
s
.5 .53358 m
.50375 .53358 L
s
.5 .55379 m
.50375 .55379 L
s
.5 .574 m
.50375 .574 L
s
.5 .61442 m
.50375 .61442 L
s
.5 .63463 m
.50375 .63463 L
s
.5 .65484 m
.50375 .65484 L
s
.5 .67505 m
.50375 .67505 L
s
.5 .06874 m
.50375 .06874 L
s
.5 .04853 m
.50375 .04853 L
s
.5 .02832 m
.50375 .02832 L
s
.5 .00811 m
.50375 .00811 L
s
.5 .71547 m
.50375 .71547 L
s
.5 .73568 m
.50375 .73568 L
s
.5 .75589 m
.50375 .75589 L
s
.5 .7761 m
.50375 .7761 L
s
.25 Mabswid
.5 0 m
.5 .78421 L
s
0 0 m
1 0 L
1 .78421 L
0 .78421 L
closepath
clip
newpath
.5 Mabswid
.97619 .39211 m
.97618 .39034 L
.97615 .38874 L
.9761 .38688 L
.97602 .38513 L
.97583 .38201 L
.97556 .37862 L
.97516 .37488 L
.97462 .37091 L
.9734 .36376 L
.96987 .34929 L
.96432 .33302 L
.95689 .31614 L
.94679 .29733 L
.9227 .26126 L
.84879 .17962 L
.79814 .13606 L
.74275 .09668 L
.68202 .06271 L
.64538 .04683 L
.61081 .03506 L
.5924 .03008 L
.5727 .02574 L
.55572 .02283 L
.54609 .02151 L
.53694 .0205 L
.53186 .02003 L
.52632 .0196 L
.52172 .0193 L
.51662 .01904 L
.51398 .01893 L
.51113 .01884 L
.50811 .01876 L
.50528 .01871 L
.50261 .01868 L
.49981 .01867 L
.49479 .01871 L
.49007 .0188 L
.48504 .01897 L
.48029 .01919 L
.47598 .01944 L
.46542 .02027 L
.45548 .02132 L
.43751 .02389 L
.41792 .02768 L
.37907 .03818 L
.34426 .05097 L
.31296 .06515 L
.24725 .10318 L
.19474 .14172 L
Mistroke
.10764 .22425 L
.07635 .26254 L
.05473 .29475 L
.03799 .32736 L
.03161 .34443 L
.02938 .35194 L
.02736 .3601 L
.02586 .36781 L
.02484 .37495 L
.02442 .37888 L
.02413 .38246 L
.02402 .38443 L
.02396 .38548 L
.02392 .38658 L
.02388 .38754 L
.02385 .38861 L
.02382 .39048 L
.02381 .39223 L
.02382 .39407 L
.02385 .39565 L
.02391 .39737 L
.02399 .39923 L
.0241 .40122 L
.02437 .4048 L
.02474 .40844 L
.02517 .41187 L
.0262 .41832 L
.02765 .42539 L
.02964 .43323 L
.03496 .44932 L
.04893 .47933 L
.0702 .51318 L
.10103 .55242 L
.13843 .5923 L
.18883 .63768 L
.24156 .6772 L
.27502 .69846 L
.30858 .71687 L
.34462 .73339 L
.37913 .74605 L
.41726 .75639 L
.43767 .76034 L
.44881 .76204 L
.45938 .76333 L
.46872 .76423 L
.47365 .76461 L
.47888 .76494 L
.48328 .76517 L
.48813 .76535 L
.49253 .76547 L
Mistroke
.49666 .76553 L
.50182 .76554 L
.50672 .76548 L
.51112 .76538 L
.51591 .7652 L
.5211 .76495 L
.52663 .76459 L
.53655 .76375 L
.54584 .76273 L
.55585 .76137 L
.57389 .75824 L
.6071 .75023 L
.64232 .73855 L
.67945 .72273 L
.74843 .68387 L
.85447 .5992 L
.92309 .52243 L
.94793 .48492 L
.95661 .46865 L
.96402 .45194 L
.96923 .43708 L
.9714 .42931 L
.97328 .42103 L
.97459 .4135 L
.97505 .41022 L
.97545 .40664 L
.97576 .40326 L
.97597 .40011 L
.97605 .39837 L
.97611 .39679 L
.97616 .39496 L
.97619 .39324 L
.97619 .39151 L
.97617 .38965 L
.97613 .38789 L
.97607 .38629 L
.97598 .38441 L
.97586 .38236 L
.97556 .37863 L
.97514 .37473 L
.97457 .37056 L
.97326 .36305 L
.97153 .35542 L
.96955 .34818 L
.96487 .33446 L
.96467 .33394 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 225.813},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001DR000`400?l00000o`00003oe`3oool0
0`000000oooo0?ooo`3F0?ooo`00e`3oool00`000000oooo0?ooo`3F0?ooo`00e`3oool00`000000
oooo0?ooo`3F0?ooo`00e`3oool300000=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo003G
0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`030000003oool0oooo0=H0oooo003G0?ooo`03
0000003oool0oooo0=H0oooo003;0?oooa/00000bP3oool00<40oooo2P00000<0?ooo`030000003o
ool0oooo00`0oooo1`0000330?ooo`00^`3oool6000001H0oooo00<000000?ooo`3oool04`3oool6
00000;d0oooo002g0?ooo`@00000703oool00`000000oooo0?ooo`0I0?ooo`H00000]`3oool00;80
oooo1@00000P0?ooo`<000007`3oool400000;<0oooo002^0?ooo`@000009@3oool00`000000oooo
0?ooo`0S0?ooo`@00000[`3oool00:X0oooo1000000Y0?ooo`030000003oool0oooo02L0oooo1000
002[0?ooo`00YP3oool4000002d0oooo00<000000?ooo`3oool0:`3oool400000:L0oooo002R0?oo
o`@00000<@3oool00`000000oooo0?ooo`0_0?ooo`<00000Y03oool00:00oooo0P00000e0?ooo`03
0000003oool0oooo0380oooo0`00002Q0?ooo`00W@3oool3000003L0oooo00<000000?ooo`3oool0
=@3oool3000009h0oooo002K0?ooo`800000>P3oool00`000000oooo0?ooo`0h0?ooo`<00000V`3o
ool009P0oooo0`00000l0?ooo`030000003oool0oooo03/0oooo0`00002H0?ooo`00UP3oool20000
03l0oooo0`00000n0?ooo`800000UP3oool009<0oooo0`0000110?ooo`030000003oool0oooo0400
oooo0P00002D0?ooo`00T@3oool2000004@0oooo00<000000?ooo`3oool0@P3oool200000980oooo
002?0?ooo`800000AP3oool00`000000oooo0?ooo`140?ooo`800000T03oool008`0oooo0`000018
0?ooo`030000003oool0oooo04H0oooo0P00002>0?ooo`00RP3oool2000004/0oooo00<000000?oo
o`3oool0B03oool2000008`0oooo00280?ooo`800000C@3oool00`000000oooo0?ooo`1:0?ooo`80
0000RP3oool008H0oooo0P00001?0?ooo`030000003oool0oooo04`0oooo0P0000280?ooo`00Q03o
ool200000540oooo0`00001>0?ooo`800000QP3oool00880oooo0P00001C0?ooo`030000003oool0
oooo0500oooo0P0000240?ooo`00P03oool2000005D0oooo00<000000?ooo`3oool0DP3oool20000
0880oooo001o0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E03oool200000800
oooo001m0?ooo`800000F03oool00`000000oooo0?ooo`1F0?ooo`800000OP3oool007/0oooo0P00
001J0?ooo`030000003oool0oooo05P0oooo0P00001l0?ooo`00N@3oool2000003d0oooo00<0okmd
0000000000000`0000000`00M;l0oooo0?ooo`020?ooo`030;md0000000007Bo00D0oooo00D0_g@0
000000000000000007Boo`070?ooo`030000003oool0oooo05X0oooo0P00001j0?ooo`00N03oool0
0`000000oooo0?ooo`100?ooo`0309a8B02Lgol0oooo00D0oooo00<0_g@000000000M;l0103oool0
1`2oM00007Bo0?ooo`3oool0omnL04P0001d_ol01P3oool00`000000oooo0?ooo`1L0?ooo`800000
N03oool007H0oooo0P0000130?ooo`0309a8B02Lgol0oooo0140oooo00<0okmd001d_`3oool01@3o
ool00`000000oooo0?ooo`1N0?ooo`800000MP3oool007@0oooo0P0000150?ooo`0309a8B02Lgol0
oooo0140oooo00<0okmd001d_`3oool01@3oool4000005l0oooo0P00001d0?ooo`00LP3oool20000
03/0oooo00<0W4P00000000000000`0000000`00B9`0oooo0?ooo`030?ooo`0309a8B02Lgol0oooo
0140oooo00<0W4P007Boo`3oool01@3oool00`000000oooo0?ooo`1R0?ooo`800000LP3oool00740
oooo00<000000?ooo`3oool0A`3oool00`2LB4P0W=oo0?ooo`0<0?ooo`030?oo_`1d000000000080
000000<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`1T0?ooo`800000L03oool006l0oooo
0P00001:0?ooo`0309a8B02Lgol0oooo00`0oooo00<0oono07@0M02oool02P3oool00`000000oooo
0?ooo`1V0?ooo`030000003oool0oooo06d0oooo001]0?ooo`800000B@3oool01@3OW4P000000018
W02LB4P0W=oo00d0oooo00<0oono07@0M02oool02P3oool00`000000oooo0?ooo`1W0?ooo`800000
K@3oool006/0oooo0P00001=0?ooo`030=nLB00004P0W=oo00d0oooo00<0oono07@0000000000P00
00000`0007@0_ooo0?ooo`050?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0JP3o
ool006X0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0
oooo06T0oooo001Y0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0J`3oool20000
06T0oooo001W0?ooo`800000KP3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo06H0
oooo001V0?ooo`030000003oool0oooo06h0oooo0`00001^0?ooo`030000003oool0oooo06D0oooo
001U0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0K`3oool2000006D0oooo001S
0?ooo`800000LP3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0680oooo001R0?oo
o`030000003oool0oooo0780oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1Q0?oo
o`00H@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo07<0oooo0P00001Q0?ooo`00
H03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0
GP3oool005h0oooo0P00001g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0G@3o
ool005d0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1g0?ooo`800000G@3oool0
05`0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
05X0oooo001J0?ooo`800000N`3oool3000007X0oooo00<000000?ooo`3oool0F@3oool005T0oooo
00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`1k0?ooo`800000F@3oool005P0oooo00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo05H0oooo001F
0?ooo`800000O`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo05D0oooo001E0?oo
o`030000003oool0oooo07l0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`1D0?oo
o`00E03oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0800oooo0P00001D0?ooo`00
D`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0
D@3oool00580oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`230?ooo`030000003o
ool0oooo0500oooo001A0?ooo`030000003oool0oooo08<0oooo0`0000240?ooo`030000003oool0
oooo04l0oooo001@0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0Q@3oool00`00
0000oooo0?ooo`1>0?ooo`00C`3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool0C@3oool004d0oooo0P0000280?ooo`030000003oool0oooo08L0oooo
00<000000?ooo`3oool0C03oool004`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?oo
o`280?ooo`800000C03oool004/0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2:
0?ooo`030000003oool0oooo04T0oooo001:0?ooo`030000003oool0oooo08X0oooo00<000000?oo
o`3oool0R`3oool00`000000oooo0?ooo`180?ooo`00B@3oool00`000000oooo0?ooo`2;0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool0A`3oool004P0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04H0oooo00170?ooo`030000003o
ool0oooo08d0oooo0`00002>0?ooo`030000003oool0oooo04D0oooo00160?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0S`3oool2000004D0oooo00150?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`120?ooo`00A03oool00`000000
oooo0?ooo`2@0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0@@3oool004<0oooo
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0400oooo
00120?ooo`030000003oool0oooo08D0oooo00<0okmd0000000000000`0000000`00M;l0oooo0?oo
o`040?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0?`3oool00400oooo0P00002;
0?ooo`0309a8B02Lgol0oooo00L0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0n
0?ooo`00?`3oool00`000000oooo0?ooo`2;0?ooo`0309a8B02Lgol0oooo00L0oooo00<000000?oo
o`3oool0UP3oool00`000000oooo0?ooo`0m0?ooo`00?P3oool00`000000oooo0?ooo`2<0?ooo`03
09a8B02Lgol0oooo00L0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0l0?ooo`00
?@3oool00`000000oooo0?ooo`210?ooo`0309a800000000000000<0000000<004RL0?ooo`3oool0
0`3oool00`2LB4P0W=oo0?ooo`070?ooo`@00000U`3oool00`000000oooo0?ooo`0k0?ooo`00?03o
ool00`000000oooo0?ooo`2>0?ooo`0309a8B02Lgol0oooo00L0oooo00<000000?ooo`3oool0V03o
ool00`000000oooo0?ooo`0k0?ooo`00>`3oool00`000000oooo0?ooo`2?0?ooo`0309a8B02Lgol0
oooo00L0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0j0?ooo`00>P3oool00`00
0000oooo0?ooo`2=0?ooo`050=nLB000000004RL09a8B02Lgol0203oool00`000000oooo0?ooo`2J
0?ooo`030000003oool0oooo03T0oooo000i0?ooo`030000003oool0oooo0900oooo00<0gia80000
B02Lgol0203oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo03P0oooo000h0?ooo`03
0000003oool0oooo09`0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0g0?ooo`00
=`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0
=P3oool003H0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`2N0?ooo`030000003o
ool0oooo03D0oooo000d0?ooo`800000X@3oool3000009l0oooo00<000000?ooo`3oool0=03oool0
03<0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo
03<0oooo000b0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0X@3oool00`000000
oooo0?ooo`0b0?ooo`00<@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo0:80oooo
00<000000?ooo`3oool0<@3oool00300oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?oo
o`2S0?ooo`030000003oool0oooo0300oooo000_0?ooo`030000003oool0oooo0:D0oooo00<00000
0?ooo`3oool0X`3oool00`000000oooo0?ooo`0`0?ooo`00;P3oool00`000000oooo0?ooo`2V0?oo
o`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0;`3oool002d0oooo00<000000?ooo`3o
ool0Y`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02h0oooo000/0?ooo`030000
003oool0oooo0:P0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0]0?ooo`00;03o
ool00`000000oooo0?ooo`2X0?ooo`<00000Y`3oool00`000000oooo0?ooo`0/0?ooo`00:`3oool0
0`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0:`3oool0
02X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo
02X0oooo000Y0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0ZP3oool00`000000
oooo0?ooo`0Y0?ooo`00:@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0:/0oooo
00<000000?ooo`3oool0:03oool002P0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?oo
o`2/0?ooo`030000003oool0oooo02L0oooo000W0?ooo`030000003oool0oooo0:d0oooo00<00000
0?ooo`3oool0[@3oool00`000000oooo0?ooo`0V0?ooo`009P3oool00`000000oooo0?ooo`2^0?oo
o`030000003oool0oooo0:h0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3o
ool0[P3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo02D0oooo000U0?ooo`030000
003oool0oooo0:l0oooo0`00002_0?ooo`030000003oool0oooo02@0oooo000T0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0S0?ooo`008`3oool0
0`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool08P3oool0
02<0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo
0240oooo000R0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool0/`3oool00`000000
oooo0?ooo`0P0?ooo`008@3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo0;@0oooo
00<000000?ooo`3oool07`3oool00200oooo00<000000?ooo`3oool0]03oool00`000000oooo0?oo
o`2d0?ooo`030000003oool0oooo01l0oooo000P0?ooo`030000003oool0oooo0;@0oooo00<00000
0?ooo`3oool0]@3oool00`000000oooo0?ooo`0N0?ooo`007`3oool00`000000oooo0?ooo`2e0?oo
o`<00000]@3oool00`000000oooo0?ooo`0N0?ooo`007P3oool00`000000oooo0?ooo`2f0?ooo`03
0000003oool0oooo0;H0oooo00<000000?ooo`3oool07@3oool001d0oooo00<000000?ooo`3oool0
]`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01`0oooo000M0?ooo`030000003o
ool0oooo0;L0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0L0?ooo`00703oool0
0`000000oooo0?ooo`2h0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06`3oool0
01/0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo
01X0oooo000K0?ooo`030000003oool0oooo09/0oooo00D0okmd000000000000000007Boo`050?oo
o`030;md0000000007Bo00D0oooo00D0_g@0000000000000000007Boo`070?ooo`030000003oool0
oooo0;T0oooo00<000000?ooo`3oool06P3oool001X0oooo00<000000?ooo`3oool0W03oool01P2L
B7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l0103oool01`2oM00007Bo0?oo
o`3oool0omnL04P0001d_ol01P3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01T0
oooo000I0?ooo`030000003oool0oooo09`0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO
0?ooo`0?0?ooo`030?noM000M;l0oooo00D0oooo00<000000?ooo`3oool0^P3oool00`000000oooo
0?ooo`0I0?ooo`00603oool00`000000oooo0?ooo`2M0?ooo`030=nLB018W=l0oooo0080oooo00<0
okmd001d_`3oool03`3oool00`3o_g@007Bo0?ooo`050?ooo`@00000^P3oool00`000000oooo0?oo
o`0H0?ooo`00603oool00`000000oooo0?ooo`2D0?ooo`0309a800000000000000<0000000D004RL
0?ooo`3oool0gia804RLg`030?ooo`030?noM000M;l0oooo00l0oooo00<0W4P007Boo`3oool01@3o
ool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01L0oooo000G0?ooo`030000003oool0
oooo09h0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`030?oo_`1d0000
00000080000000<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0
oooo01L0oooo000F0?ooo`030000003oool0oooo09l0oooo00<0okmd04RLg`3oool00P3oool00`3O
W4P0B9cO0?ooo`0:0?ooo`030?oo_`1d07@0_ooo00X0oooo00<000000?ooo`3oool0_@3oool00`00
0000oooo0?ooo`0F0?ooo`005P3oool00`000000oooo0?ooo`2P0?ooo`0609a8001d_ol0oooo0?oO
W01807@0_ooo2`3oool00`3ookl0M01d0;ooo`0:0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool05@3oool001D0oooo00<000000?ooo`3oool0X@3oool01@3ookl0M0000000000004P0
W=oo00`0oooo00<0oono07@0000000000P0000000`0007@0_ooo0?ooo`050?ooo`030000003oool0
oooo0;h0oooo00<000000?ooo`3oool05@3oool001D0oooo00<000000?ooo`3oool0_`3oool00`00
0000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo000D0?ooo`030000003oool0oooo0<00
oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`00503oool00`000000oooo
0?ooo`300?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool001<0oooo00<0
00000?ooo`3oool0`@3oool300000<40oooo00<000000?ooo`3oool04P3oool001<0oooo00<00000
0?ooo`3oool0`@3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo000B0?oo
o`030000003oool0oooo0<80oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?oo
o`004P3oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3o
ool04@3oool00140oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`330?ooo`030000
003oool0oooo0100oooo000A0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0``3o
ool00`000000oooo0?ooo`0@0?ooo`00403oool00`000000oooo0?ooo`340?ooo`030000003oool0
oooo0<@0oooo00<000000?ooo`3oool03`3oool00100oooo00<000000?ooo`3oool0a03oool00`00
0000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo000@0?ooo`030000003oool0oooo0<@0
oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo
0?ooo`350?ooo`<00000a@3oool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?oo
o`350?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool000h0oooo00<00000
0?ooo`3oool0aP3oool00`000000oooo0?ooo`350?ooo`8000003`3oool000h0oooo00<000000?oo
o`3oool0aP3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00d0oooo000=0?ooo`03
0000003oool0oooo0<L0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0=0?ooo`00
3@3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool0
3@3oool000d0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`370?ooo`030000003o
ool0oooo00`0oooo000<0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0a`3oool0
0`000000oooo0?ooo`0<0?ooo`00303oool00`000000oooo0?ooo`0J0?ooo`030?oo_`1d00000000
00@0000000<0M;oo0?ooo`3oool0CP3oool00`3o_g@000000000000300000003001d_`3oool0oooo
04d0oooo0`00001A0?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool0C@3oool00`3o
okl0M000000000040000000307Boo`3oool0oooo01H0oooo00<000000?ooo`3oool0303oool000`0
oooo00<000000?ooo`3oool06`3oool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo0580
oooo00<0W4Q809cOo`3oool0D03oool00`000000oooo0?ooo`1D0?ooo`0309a8B02Lgol0oooo0540
oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?ooo`0H0?ooo`030000003oool0oooo00/0
oooo000;0?ooo`030000003oool0oooo01d0oooo00<0okmd0000B02Lgol0EP3oool00`2LB4P0W=oo
0?ooo`1@0?ooo`030000003oool0oooo05@0oooo00<0W4Q809cOo`3oool0DP3oool00`3o_g@00018
09cOo`0L0?ooo`030000003oool0oooo00/0oooo000;0?ooo`030000003oool0oooo01h0oooo00<0
omnL04P00018W=l0E@3oool00`2LB4P0W=oo0?ooo`1@0?ooo`030000003oool0oooo05@0oooo00<0
W4Q809cOo`3oool0D`3oool00`3ogi`0B00004RLg`0K0?ooo`030000003oool0oooo00/0oooo000;
0?ooo`030000003oool0oooo01<0oooo00<0W4P00000000000000`0000000`00B9`0oooo0?ooo`04
0?ooo`0309a80018W=l0oooo04L0oooo00<0W4P00000000000000`0000000`00B9`0oooo0?ooo`03
0?ooo`0309a8B02Lgol0oooo0500oooo00<000000?ooo`3oool0E03oool00`2LB4P0W=oo0?ooo`1E
0?ooo`0309a80018W=l0oooo01X0oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?oo
o`3oool08@3oool00`2LB7@0_ooo0?ooo`1B0?ooo`0309a8B02Lgol0oooo0500oooo00<000000?oo
o`3oool0E03oool00`2LB4P0W=oo0?ooo`1F0?ooo`0309a8M02oool0oooo01T0oooo00<000000?oo
o`3oool02P3oool000/0oooo00<000000?ooo`3oool0703oool00`3OW4P0M;oo0?ooo`020?ooo`03
0;md001d_ol0oooo0580oooo00<0W4Q809cOo`3oool0D03oool00`000000oooo0?ooo`1D0?ooo`03
09a8B02Lgol0oooo0540oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`0I0?ooo`03
0000003oool0oooo00X0oooo000;0?ooo`030000003oool0oooo01`0oooo00L0okmd0000M02oool0
oooo0?noM00004P0W=oo0500oooo00D0gia800000000B9`0W4Q809cOo`1A0?ooo`030000003oool0
oooo0540oooo00D0gia800000000B9`0W4Q809cOo`1B0?ooo`070?noM00007@0_ooo0?ooo`3o_g@0
001809cOo`0J0?ooo`030000003oool0oooo00X0oooo000;0?ooo`030000003oool0oooo01d0oooo
00D0okmd000000000000001809cOo`1C0?ooo`030=nLB00004P0W=oo0540oooo00<000000?ooo`3o
ool0D`3oool00`3OW4P0001809cOo`1C0?ooo`050?noM000000000000000B02Lgol06`3oool00`00
0000oooo0?ooo`0:0?ooo`002P3oool00`000000oooo0?ooo`3:0?ooo`<00000b@3oool00`000000
oooo0?ooo`0:0?ooo`002P3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo0<X0oooo
00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?oo
o`3:0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0<X0oooo00<00000
0?ooo`3oool0bP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`3:0?oo
o`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3o
ool0bP3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000
003oool0oooo0<X0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`090?ooo`002P3o
ool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02@3o
ool000X0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0
oooo00T0oooo003o00000;0000000@3oool000H0oooo00D000000?ooo`3oool0oooo0000000=0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool0
000000L0oooo000:0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0<X0
oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo
0?ooo`3:0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02@3oool000X0oooo00<0
00000?ooo`3oool0bP3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00T0oooo000:
0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`09
0?ooo`002P3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo0<X0oooo00<000000?oo
o`3oool02@3oool000/0oooo00<000000?ooo`3oool0b@3oool300000<T0oooo00<000000?ooo`3o
ool02P3oool000/0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`390?ooo`030000
003oool0oooo00X0oooo000;0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool0b@3o
ool00`000000oooo0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`390?ooo`030000003oool0
oooo0<T0oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`3oool0b@3oool00`00
0000oooo0?ooo`390?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo0<P0
oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0:0?ooo`00303oool00`000000oooo
0?ooo`380?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool02`3oool000`0oooo00<0
00000?ooo`3oool0b03oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00/0oooo000<
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0;
0?ooo`00303oool00`000000oooo0?ooo`380?ooo`<00000b03oool00`000000oooo0?ooo`0;0?oo
o`00303oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3o
ool0303oool000d0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`370?ooo`030000
003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool0a`3o
ool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?ooo`360?ooo`030000003oool0
oooo0<H0oooo00<000000?ooo`3oool03@3oool000h0oooo00<000000?ooo`3oool0aP3oool00`00
0000oooo0?ooo`360?ooo`030000003oool0oooo00d0oooo000?0?ooo`030000003oool0oooo0<D0
oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo
0?ooo`350?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool000l0oooo00<0
00000?ooo`3oool0a@3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo000@
0?ooo`030000003oool0oooo0<@0oooo0`0000350?ooo`030000003oool0oooo00h0oooo000@0?oo
o`030000003oool0oooo0<@0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?oo
o`004@3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3o
ool03`3oool00140oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`330?ooo`030000
003oool0oooo0100oooo000B0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0``3o
ool00`000000oooo0?ooo`0@0?ooo`004P3oool00`000000oooo0?ooo`320?ooo`030000003oool0
oooo0<<0oooo00<000000?ooo`3oool0403oool001<0oooo00<000000?ooo`3oool0`@3oool00`00
0000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo000C0?ooo`030000003oool0oooo0<40
oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`00503oool00`000000oooo
0?ooo`300?ooo`<00000`@3oool00`000000oooo0?ooo`0B0?ooo`00503oool00`000000oooo0?oo
o`300?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool001D0oooo00<00000
0?ooo`3oool0_`3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo000E0?oo
o`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?oo
o`005P3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3o
ool0503oool001H0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`2o0?ooo`030000
003oool0oooo01@0oooo000G0?ooo`030000003oool0oooo09l0oooo00D0okmd0000000000000000
07Boo`050?ooo`030;md0000000007Bo00D0oooo00D0_g@0000000000000000007Boo`070?ooo`03
0000003oool0oooo0;h0oooo00<000000?ooo`3oool05@3oool001L0oooo00<000000?ooo`3oool0
W`3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l0103oool01`2o
M00007Bo0?ooo`3oool0omnL04P0001d_ol01P3oool00`000000oooo0?ooo`2m0?ooo`030000003o
ool0oooo01H0oooo000H0?ooo`030000003oool0oooo09d0oooo00<0okmd001d_`3oool00P3oool0
0`3OW4P0B9cO0?ooo`0?0?ooo`030?noM000M;l0oooo00D0oooo00<000000?ooo`3oool0_@3oool0
0`000000oooo0?ooo`0F0?ooo`006@3oool00`000000oooo0?ooo`2L0?ooo`030=nLB018W=l0oooo
0080oooo00<0okmd001d_`3oool03`3oool00`3o_g@007Bo0?ooo`050?ooo`@00000^`3oool00`00
0000oooo0?ooo`0G0?ooo`006@3oool00`000000oooo0?ooo`2L0?ooo`030=nLB018W=l0oooo0080
oooo00<0okmd001d_`3oool03`3oool00`2LB000M;oo0?ooo`050?ooo`030000003oool0oooo0;/0
oooo00<000000?ooo`3oool0603oool001X0oooo00<000000?ooo`3oool0V`3oool00`3OW4P0B9cO
0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0oono07@0000000000P0000000`18W=l0oooo
0?ooo`050?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0603oool001X0oooo00<0
00000?ooo`3oool0V`3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0
oono07@0M02oool02P3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01T0oooo000K
0?ooo`030000003oool0oooo09/0oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`030?oo
_`1d07@0_ooo00X0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0J0?ooo`00703o
ool00`000000oooo0?ooo`2J0?ooo`050?oo_`1d000000000000B02Lgol0303oool00`3ookl0M000
00000002000000030000M02oool0oooo00D0oooo00<000000?ooo`3oool0^03oool00`000000oooo
0?ooo`0K0?ooo`00703oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo0;P0oooo00<0
00000?ooo`3oool06`3oool001d0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`2g
0?ooo`030000003oool0oooo01`0oooo000M0?ooo`030000003oool0oooo0;L0oooo00<000000?oo
o`3oool0]P3oool00`000000oooo0?ooo`0M0?ooo`007P3oool00`000000oooo0?ooo`2f0?ooo`<0
0000]P3oool00`000000oooo0?ooo`0M0?ooo`007`3oool00`000000oooo0?ooo`2e0?ooo`030000
003oool0oooo0;D0oooo00<000000?ooo`3oool07P3oool00200oooo00<000000?ooo`3oool0]03o
ool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01l0oooo000P0?ooo`030000003oool0
oooo0;@0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0O0?ooo`008@3oool00`00
0000oooo0?ooo`2c0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool0803oool00280
oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo0240
oooo000S0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0/@3oool00`000000oooo
0?ooo`0R0?ooo`008`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool08`3oool002@0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`2_
0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo0:l0oooo0`00002_0?oo
o`030000003oool0oooo02@0oooo000V0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3o
ool0[P3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`2^0?ooo`030000
003oool0oooo0:d0oooo00<000000?ooo`3oool09P3oool002L0oooo00<000000?ooo`3oool0[@3o
ool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo02L0oooo000X0?ooo`030000003oool0
oooo0:`0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0X0?ooo`00:@3oool00`00
0000oooo0?ooo`2[0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0:@3oool002T0
oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02X0
oooo000Z0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0Z03oool00`000000oooo
0?ooo`0[0?ooo`00:`3oool00`000000oooo0?ooo`2Y0?ooo`<00000Z03oool00`000000oooo0?oo
o`0[0?ooo`00;03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0:L0oooo00<00000
0?ooo`3oool0;03oool002d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`2V0?oo
o`030000003oool0oooo02d0oooo000^0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3o
ool0Y@3oool00`000000oooo0?ooo`0^0?ooo`00;`3oool00`000000oooo0?ooo`2U0?ooo`030000
003oool0oooo0:@0oooo00<000000?ooo`3oool0;`3oool00300oooo00<000000?ooo`3oool0Y03o
ool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo0300oooo000a0?ooo`030000003oool0
oooo0:<0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0a0?ooo`00<P3oool00`00
0000oooo0?ooo`2R0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0<P3oool003<0
oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo0380
oooo000c0?ooo`030000003oool0oooo0:40oooo0`00002P0?ooo`030000003oool0oooo03<0oooo
000d0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?oo
o`0d0?ooo`00=@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo09h0oooo00<00000
0?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`2M0?oo
o`030000003oool0oooo03H0oooo000g0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3o
ool0W03oool00`000000oooo0?ooo`0g0?ooo`00>03oool00`000000oooo0?ooo`2?0?ooo`030?no
M0000000000000<0000000<007Bo0?ooo`3oool0103oool00`000000oooo0?ooo`2K0?ooo`030000
003oool0oooo03P0oooo000i0?ooo`030000003oool0oooo0940oooo00<0W4Q809cOo`3oool01`3o
ool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo03T0oooo000j0?ooo`030000003oool0
oooo0900oooo00<0W4Q809cOo`3oool01`3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0
oooo03T0oooo000k0?ooo`030000003oool0oooo08l0oooo00<0W4Q809cOo`3oool01`3oool00`00
0000oooo0?ooo`2I0?ooo`030000003oool0oooo03X0oooo000l0?ooo`030000003oool0oooo08h0
oooo00<0W4Q809cOo`3oool01`3oool4000009L0oooo00<000000?ooo`3oool0>`3oool003d0oooo
00<000000?ooo`3oool0S@3oool00`2LB4P0W=oo0?ooo`070?ooo`030000003oool0oooo09L0oooo
00<000000?ooo`3oool0?03oool003h0oooo0P00002=0?ooo`0309a8B02Lgol0oooo00L0oooo00<0
00000?ooo`3oool0UP3oool00`000000oooo0?ooo`0m0?ooo`00@03oool00`000000oooo0?ooo`27
0?ooo`050=nLB000000004RL09a8B02Lgol0203oool00`000000oooo0?ooo`2E0?ooo`030000003o
ool0oooo03h0oooo00110?ooo`030000003oool0oooo08P0oooo00<0gia80000B02Lgol0203oool0
0`000000oooo0?ooo`2C0?ooo`800000@@3oool00480oooo00<000000?ooo`3oool0TP3oool00`00
0000oooo0?ooo`2B0?ooo`030000003oool0oooo0440oooo00130?ooo`030000003oool0oooo0940
oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`120?ooo`00A03oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo08l0oooo0P0000150?ooo`00A@3oool00`000000oooo0?oo
o`2?0?ooo`<00000SP3oool00`000000oooo0?ooo`150?ooo`00AP3oool2000008l0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`160?ooo`00B03oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo08`0oooo00<000000?ooo`3oool0A`3oool004T0oooo00<000000?ooo`3o
ool0R`3oool00`000000oooo0?ooo`2:0?ooo`800000BP3oool004X0oooo00<000000?ooo`3oool0
RP3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo04X0oooo001;0?ooo`030000003o
ool0oooo08T0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`1;0?ooo`00C03oool0
0`000000oooo0?ooo`280?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0C03oool0
04d0oooo0P0000280?ooo`030000003oool0oooo08D0oooo0P00001?0?ooo`00C`3oool00`000000
oooo0?ooo`250?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0C`3oool00500oooo
00<000000?ooo`3oool0Q03oool3000008<0oooo00<000000?ooo`3oool0D03oool00540oooo00<0
00000?ooo`3oool0P`3oool00`000000oooo0?ooo`210?ooo`800000D`3oool00580oooo0P000023
0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0D`3oool005@0oooo00<000000?oo
o`3oool0P03oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo05@0oooo001E0?ooo`03
0000003oool0oooo07l0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`1E0?ooo`00
EP3oool2000007l0oooo00<000000?ooo`3oool0O03oool2000005P0oooo001H0?ooo`030000003o
ool0oooo07`0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`1H0?ooo`00F@3oool0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0F@3oool0
05X0oooo0P00001k0?ooo`030000003oool0oooo07P0oooo0P00001L0?ooo`00G03oool00`000000
oooo0?ooo`1h0?ooo`<00000M`3oool00`000000oooo0?ooo`1L0?ooo`00G@3oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0G@3oool005h0oooo0P00
001g0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0GP3oool00600oooo00<00000
0?ooo`3oool0M03oool00`000000oooo0?ooo`1c0?ooo`800000H@3oool00640oooo00<000000?oo
o`3oool0L`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0640oooo001R0?ooo`80
0000L`3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0680oooo001T0?ooo`030000
003oool0oooo0700oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1S0?ooo`00I@3o
ool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo06h0oooo0P00001V0?ooo`00IP3oool2
000006l0oooo0`00001]0?ooo`030000003oool0oooo06H0oooo001X0?ooo`030000003oool0oooo
06`0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1W0?ooo`00J@3oool2000006`0
oooo00<000000?ooo`3oool0JP3oool2000006X0oooo001[0?ooo`030000003oool0oooo06T0oooo
00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1Z0?ooo`00K03oool00`000000oooo0?oo
o`1X0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0J`3oool006d0oooo0P00001X
0?ooo`030000003oool0oooo06H0oooo0P00001^0?ooo`00K`3oool00`000000oooo0?ooo`160?oo
o`030?noM0000000000000<0000000<007Bo0?ooo`3oool00P3oool00`2oM0000000001d_`050?oo
o`050;md0000000000000000001d_ol01`3oool00`000000oooo0?ooo`1T0?ooo`800000L03oool0
0700oooo0P0000190?ooo`0309a8B02Lgol0oooo00D0oooo00<0_g@000000000M;l0103oool01`2o
M00007Bo0?ooo`3oool0omnL04P0001d_ol01P3oool00`000000oooo0?ooo`1R0?ooo`800000LP3o
ool00780oooo00<000000?ooo`3oool0AP3oool00`2LB4P0W=oo0?ooo`0A0?ooo`030?noM000M;l0
oooo00D0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1b0?ooo`00L`3oool00`00
0000oooo0?ooo`150?ooo`0309a8B02Lgol0oooo0140oooo00<0okmd001d_`3oool01@3oool40000
05h0oooo0P00001e0?ooo`00M03oool2000004D0oooo00<0W4Q809cOo`3oool04@3oool00`2LB000
M;oo0?ooo`050?ooo`030000003oool0oooo05d0oooo0P00001g0?ooo`00MP3oool2000004<0oooo
00<0W4Q809cOo`3oool0303oool00`3ookl0M000000000020000000304RLg`3oool0oooo00D0oooo
00<000000?ooo`3oool0F`3oool2000007T0oooo001h0?ooo`800000@@3oool00`2LB4P0W=oo0?oo
o`0<0?ooo`030?oo_`1d07@0_ooo00X0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?oo
o`1i0?ooo`00NP3oool2000003`0oooo00D0gia800000000B9`0W4Q809cOo`0=0?ooo`030?oo_`1d
07@0_ooo00X0oooo00<000000?ooo`3oool0F03oool2000007`0oooo001l0?ooo`800000?03oool0
0`3OW4P0001809cOo`0=0?ooo`030?oo_`1d000000000080000000<0001d0;ooo`3oool01@3oool0
0`000000oooo0?ooo`1F0?ooo`800000OP3oool007h0oooo0P00001G0?ooo`030000003oool0oooo
05@0oooo0P0000200?ooo`00P03oool2000005D0oooo00<000000?ooo`3oool0DP3oool200000880
oooo00220?ooo`800000D`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0880oooo
00240?ooo`800000D@3oool3000004l0oooo0P0000250?ooo`00QP3oool2000004l0oooo00<00000
0?ooo`3oool0C@3oool2000008L0oooo00280?ooo`800000C@3oool00`000000oooo0?ooo`1;0?oo
o`800000R@3oool008X0oooo0P00001;0?ooo`030000003oool0oooo04T0oooo0P00002;0?ooo`00
S03oool2000004T0oooo00<000000?ooo`3oool0A`3oool2000008d0oooo002>0?ooo`800000A`3o
ool00`000000oooo0?ooo`150?ooo`800000S`3oool00900oooo0P0000150?ooo`030000003oool0
oooo04<0oooo0P00002A0?ooo`00TP3oool2000004<0oooo00<000000?ooo`3oool0@03oool30000
09<0oooo002D0?ooo`800000@@3oool00`000000oooo0?ooo`0n0?ooo`800000UP3oool009H0oooo
0`00000n0?ooo`<00000?03oool2000009P0oooo002I0?ooo`<00000>`3oool00`000000oooo0?oo
o`0i0?ooo`<00000VP3oool009`0oooo0`00000h0?ooo`030000003oool0oooo03H0oooo0`00002M
0?ooo`00W`3oool3000003D0oooo00<000000?ooo`3oool0<`3oool300000:00oooo002R0?ooo`<0
0000<P3oool00`000000oooo0?ooo`0`0?ooo`<00000X`3oool00:D0oooo0`00000_0?ooo`030000
003oool0oooo02d0oooo0`00002V0?ooo`00Z03oool3000002`0oooo00<000000?ooo`3oool0:@3o
ool400000:T0oooo002[0?ooo`@00000:03oool00`000000oooo0?ooo`0U0?ooo`@00000[@3oool0
0:l0oooo0`00000U0?ooo`<00000803oool500000;40oooo002b0?ooo`H000007`3oool00`000000
oooo0?ooo`0L0?ooo`@00000]P3oool00;P0oooo1`00000H0?ooo`030000003oool0oooo01P0oooo
1000002j0?ooo`00_`3oool5000001<0oooo00<000000?ooo`3oool0403oool800000;h0oooo0034
0?ooobH00000aP3oool00=L0oooo00<000000?ooo`3oool0eP3oool00=L0oooo00<000000?ooo`3o
ool0eP3oool00=L0oooo00<000000?ooo`3oool0eP3oool00=L0oooo00<000000?ooo`3oool0eP3o
ool00=L0oooo0`00003F0?ooo`00e`3oool00`000000oooo0?ooo`3F0?ooo`00e`3oool00`000000
oooo0?ooo`3F0?ooo`00e`3oool00`000000oooo0?ooo`3F0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {337.688, 0}} -> {-2.47627, -1.94016, \
0.0172362, 0.0172362}}]
}, Closed]],

Cell["\<\
Another interesting system of equations are the Lorenz equations, which arise \
in the theory of convection.  With appropriate parameters and initial \
conditions, one obtains the famous butterfly attractor.\
\>", "Text"],

Cell[BoxData[
    \(\(lorenzEqs\  = \ {\n\t\t\(x\^\[Prime]\)[
              t]\  \[Equal] \ \[Alpha] \((\ \(-x[t]\) + 
                  y[t])\), \n\t\t\(y\^\[Prime]\)[
              t]\  \[Equal] \ \(-x[t]\)\ z[t]\  + \ \[Beta]\ x[t]\  - \ 
              y[t], \n\t\t\(z\^\[Prime]\)[t]\  \[Equal] \ 
            x[t]\ y[t]\  - \ \[Gamma]\ z[t]\ };\)\)], "Input"],

Cell[BoxData[
    \(lorenzPlot[values_, ic_, tmax_] := \ 
      ParametricPlot3D[
        Evaluate[{x[t], y[t], 
              z[t]} /. \(NDSolve[
                Join[lorenzEqs /. values, ic], {x, y, z}, {t, 0, tmax}, 
                MaxSteps \[Rule] 
                  10000]\)\[LeftDoubleBracket]1\[RightDoubleBracket]], {t, 0, 
          tmax}, PlotPoints \[Rule] 3000]\)], "Input"],

Cell["\<\
A trajectory using the customary parameters illustrates the complexity of \
this motion.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(lorenzPlot[{\[Alpha] \[Rule] 10, \[Beta] \[Rule] 28, \[Gamma] \[Rule] 
            8\/3}, {x[0] \[Equal] 0, y[0] \[Equal] 1, z[0] \[Equal] \(-1\)}, 
        50];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.23294 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.119764 1.30869 7.49184e-017 1.30869 [
[.18051 .16189 -16.8993 -9 ]
[.18051 .16189 1.10067 0 ]
[.30949 .10761 -5.42647 -9 ]
[.30949 .10761 .57353 0 ]
[.4442 .05094 -10.4397 -9 ]
[.4442 .05094 1.56033 0 ]
[.585 -0.00825 -10.0264 -9 ]
[.585 -0.00825 1.9736 0 ]
[.04375 .92949 -10.0954 0 ]
[.04375 .92949 7.90463 9 ]
[.23779 1.07492 -3.2131 0 ]
[.23779 1.07492 2.7869 9 ]
[.40216 1.19812 -6.18471 0 ]
[.40216 1.19812 5.81529 9 ]
[.07051 .24732 -6 -2.63103 ]
[.07051 .24732 0 6.36897 ]
[.03947 .47661 -12 -2.79873 ]
[.03947 .47661 0 6.20127 ]
[.00387 .7397 -12 -2.99337 ]
[.00387 .7397 0 6.00663 ]
[ 0 0 0 0 ]
[ 1 1.23294 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08883 .21714 m
.60683 0 L
s
.1913 .17418 m
.19669 .18033 L
s
[(-10)] .18051 .16189 .8777 1 Mshowa
.31978 .12033 m
.32492 .12669 L
s
[(0)] .30949 .10761 .80882 1 Mshowa
.45393 .06409 m
.45879 .07067 L
s
[(10)] .4442 .05094 .73995 1 Mshowa
.59412 .00533 m
.59867 .01212 L
s
[(20)] .585 -0.00825 .67107 1 Mshowa
.125 Mabswid
.21656 .16359 m
.21977 .16731 L
s
.24204 .15292 m
.24521 .15665 L
s
.26773 .14214 m
.27088 .14591 L
s
.29364 .13128 m
.29676 .13507 L
s
.34615 .10927 m
.3492 .11312 L
s
.37274 .09813 m
.37576 .10199 L
s
.39956 .08688 m
.40255 .09078 L
s
.42663 .07554 m
.42958 .07946 L
s
.48147 .05255 m
.48435 .05652 L
s
.50925 .0409 m
.5121 .0449 L
s
.53729 .02915 m
.5401 .03317 L
s
.56557 .01729 m
.56835 .02134 L
s
.16625 .18468 m
.16952 .18835 L
s
.14141 .19509 m
.14471 .19873 L
s
.11678 .20542 m
.1201 .20903 L
s
.09235 .21566 m
.0957 .21925 L
s
.25 Mabswid
0 .87886 m
.4707 1.23294 L
s
.04572 .91325 m
.04671 .90513 L
s
[(-20)] .04375 .92949 .12171 -1 Mshowa
.23895 1.05861 m
.23952 1.05045 L
s
[(0)] .23779 1.07492 .07103 -1 Mshowa
.40267 1.18177 m
.40292 1.17359 L
s
[(20)] .40216 1.19812 .03078 -1 Mshowa
.125 Mabswid
.09722 .95199 m
.09775 .94711 L
s
.1465 .98906 m
.14696 .98418 L
s
.1937 1.02457 m
.1941 1.01968 L
s
.28236 1.09127 m
.28266 1.08637 L
s
.32405 1.12263 m
.3243 1.11773 L
s
.36413 1.15277 m
.36432 1.14787 L
s
.43976 1.20967 m
.43987 1.20477 L
s
.25 Mabswid
.08883 .21714 m
0 .87886 L
s
.08562 .24104 m
.09317 .2379 L
s
[(0)] .07051 .24732 1 -0.41533 Mshowa
.05478 .47082 m
.06243 .46793 L
s
[(20)] .03947 .47661 1 -0.37806 Mshowa
.01938 .7345 m
.02713 .73191 L
s
[(40)] .00387 .7397 1 -0.33481 Mshowa
.125 Mabswid
.07829 .29567 m
.08283 .29382 L
s
.07071 .35212 m
.07527 .3503 L
s
.06288 .41047 m
.06745 .40869 L
s
.04639 .53329 m
.051 .53159 L
s
.03771 .59797 m
.04233 .59632 L
s
.02871 .665 m
.03335 .6634 L
s
.0097 .80662 m
.01437 .80511 L
s
.25 Mabswid
.08883 .21714 m
0 .87886 L
s
0 .87886 m
.4707 1.23294 L
s
.4707 1.23294 m
.47951 .63506 L
s
.47951 .63506 m
.08883 .21714 L
s
.60683 0 m
.93119 .48778 L
s
.93119 .48778 m
1 1.11084 L
s
1 1.11084 m
.62278 .68523 L
s
.62278 .68523 m
.60683 0 L
s
.08883 .21714 m
0 .87886 L
s
0 .87886 m
.62278 .68523 L
s
.62278 .68523 m
.60683 0 L
s
.60683 0 m
.08883 .21714 L
s
.47951 .63506 m
.93119 .48778 L
s
.93119 .48778 m
1 1.11084 L
s
1 1.11084 m
.4707 1.23294 L
s
.4707 1.23294 m
.47951 .63506 L
s
0 0 m
1 0 L
1 1.23294 L
0 1.23294 L
closepath
clip
newpath
.5 Mabswid
.71611 .52758 m
.75506 .57069 L
s
.68157 .4931 m
.71611 .52758 L
s
.75506 .57069 m
.79751 .62358 L
s
.65161 .46579 m
.68157 .4931 L
s
.79751 .62358 m
.84147 .68656 L
s
.62605 .44426 m
.65161 .46579 L
s
.60448 .4273 m
.62605 .44426 L
s
.58641 .41392 m
.60448 .4273 L
s
.84147 .68656 m
.88342 .75807 L
s
.57138 .40332 m
.58641 .41392 L
s
.71359 .56168 m
.74728 .59835 L
s
.68304 .53197 m
.71359 .56168 L
s
.55891 .39489 m
.57138 .40332 L
s
.74728 .59835 m
.78321 .64259 L
s
.65598 .50829 m
.68304 .53197 L
s
.54861 .38814 m
.55891 .39489 L
s
.6324 .48964 m
.65598 .50829 L
s
.5401 .38273 m
.54861 .38814 L
s
.78321 .64259 m
.81964 .69425 L
s
.61209 .47511 m
.6324 .48964 L
s
.53309 .37836 m
.5401 .38273 L
s
.52732 .37485 m
.53309 .37836 L
s
.52256 .37203 m
.52732 .37485 L
s
.59473 .46389 m
.61209 .47511 L
s
.51862 .36981 m
.52256 .37203 L
s
.51536 .36812 m
.51862 .36981 L
s
.50823 .36641 m
.51028 .36636 L
s
.51262 .36696 m
.51536 .36812 L
s
.51028 .36636 m
.51262 .36696 L
s
.57999 .45533 m
.59473 .46389 L
s
.81964 .69425 m
.85375 .75178 L
s
.88342 .75807 m
.91793 .83347 L
s
.56751 .44891 m
.57999 .45533 L
s
.69413 .57942 m
.72115 .60623 L
s
.66941 .55769 m
.69413 .57942 L
s
.72115 .60623 m
.74991 .63852 L
s
.55699 .4442 m
.56751 .44891 L
s
.64725 .54045 m
.66941 .55769 L
s
.70032 .58869 m
.72735 .61625 L
s
.67541 .5662 m
.70032 .58869 L
s
.72735 .61625 m
.75581 .64917 L
s
.65292 .54825 m
.67541 .5662 L
s
.74991 .63852 m
.77933 .67627 L
s
.62766 .52705 m
.64725 .54045 L
s
.54813 .44087 m
.55699 .4442 L
s
.63293 .53424 m
.65292 .54825 L
s
.75581 .64917 m
.7845 .68725 L
s
.54067 .43866 m
.54813 .44087 L
s
.6105 .51689 m
.62766 .52705 L
s
.61536 .52357 m
.63293 .53424 L
s
.77933 .67627 m
.80772 .71871 L
s
.70241 .60467 m
.72755 .63049 L
s
.67893 .58343 m
.70241 .60467 L
s
.53441 .43737 m
.54067 .43866 L
s
.65748 .56637 m
.67893 .58343 L
s
.59559 .50943 m
.6105 .51689 L
s
.72755 .63049 m
.75365 .66098 L
s
.60003 .5157 m
.61536 .52357 L
s
.63822 .55304 m
.65748 .56637 L
s
.52914 .43684 m
.53441 .43737 L
s
.85375 .75178 m
.88153 .81156 L
s
.7845 .68725 m
.81162 .7295 L
s
.52471 .43696 m
.52914 .43684 L
s
.5827 .50421 m
.59559 .50943 L
s
.75365 .66098 m
.77954 .6958 L
s
.62111 .54292 m
.63822 .55304 L
s
.58673 .51016 m
.60003 .5157 L
s
.52099 .43761 m
.52471 .43696 L
s
.57158 .50085 m
.5827 .50421 L
s
.60605 .53554 m
.62111 .54292 L
s
.51785 .43874 m
.52099 .43761 L
s
.57524 .50657 m
.58673 .51016 L
s
.69267 .61187 m
.71485 .63336 L
s
.6719 .59424 m
.69267 .61187 L
s
.71485 .63336 m
.73789 .65878 L
s
.65285 .58018 m
.6719 .59424 L
s
.80772 .71871 m
.83268 .76397 L
s
.51522 .44027 m
.51785 .43874 L
s
.69814 .61908 m
.72027 .64122 L
s
.67725 .60076 m
.69814 .61908 L
s
.65797 .58602 m
.67725 .60076 L
s
.69674 .61908 m
.71863 .64077 L
s
.67608 .60116 m
.69674 .61908 L
s
.65701 .58679 m
.67608 .60116 L
s
.59287 .53048 m
.60605 .53554 L
s
.72027 .64122 m
.74301 .66718 L
s
.56203 .49905 m
.57158 .50085 L
s
.63563 .56931 m
.65285 .58018 L
s
.77954 .6958 m
.80354 .73387 L
s
.51299 .44217 m
.51522 .44027 L
s
.71863 .64077 m
.74116 .66624 L
s
.64046 .57453 m
.65797 .58602 L
s
.56533 .50461 m
.57524 .50657 L
s
.73789 .65878 m
.7609 .68791 L
s
.68504 .61122 m
.7059 .63041 L
s
.66558 .59559 m
.68504 .61122 L
s
.7059 .63041 m
.7277 .65329 L
s
.63968 .57562 m
.65701 .58679 L
s
.64776 .58325 m
.66558 .59559 L
s
.51111 .4444 m
.51299 .44217 L
s
.69125 .61886 m
.71213 .63884 L
s
.67161 .60243 m
.69125 .61886 L
s
.62025 .56124 m
.63563 .56931 L
s
.65349 .58931 m
.67161 .60243 L
s
.71213 .63884 m
.7337 .6624 L
s
.62475 .56591 m
.64046 .57453 L
s
.7277 .65329 m
.74971 .67972 L
s
.81162 .7295 m
.83469 .77377 L
s
.74301 .66718 m
.76541 .6966 L
s
.55383 .49855 m
.56203 .49905 L
s
.58139 .52739 m
.59287 .53048 L
s
.68359 .61448 m
.70371 .63276 L
s
.66478 .59961 m
.68359 .61448 L
s
.74116 .66624 m
.76339 .69516 L
s
.70371 .63276 m
.72471 .65453 L
s
.50952 .44694 m
.51111 .4444 L
s
.62412 .56731 m
.63968 .57562 L
s
.63166 .57384 m
.64776 .58325 L
s
.55681 .50403 m
.56533 .50461 L
s
.63705 .5792 m
.65349 .58931 L
s
.64752 .58788 m
.66478 .59961 L
s
.91793 .83347 m
.93791 .90405 L
s
.50817 .44975 m
.50952 .44694 L
s
.7337 .6624 m
.75517 .68929 L
s
.72471 .65453 m
.74591 .67968 L
s
.60662 .5556 m
.62025 .56124 L
s
.61079 .55978 m
.62475 .56591 L
s
.7609 .68791 m
.78262 .71999 L
s
.63191 .57898 m
.64752 .58788 L
s
.61027 .56149 m
.62412 .56731 L
s
.5468 .49916 m
.55383 .49855 L
s
.61728 .56703 m
.63166 .57384 L
s
.57142 .52598 m
.58139 .52739 L
s
.50703 .45284 m
.50817 .44975 L
s
.62229 .57174 m
.63705 .5792 L
s
.74971 .67972 m
.77088 .70915 L
s
.54948 .50461 m
.55681 .50403 L
s
.50606 .45618 m
.50703 .45284 L
s
.59463 .55205 m
.60662 .5556 L
s
.59847 .55582 m
.61079 .55978 L
s
.61792 .57258 m
.63191 .57898 L
s
.76541 .6966 m
.78611 .72856 L
s
.76339 .69516 m
.78401 .72664 L
s
.74591 .67968 m
.7663 .70767 L
s
.54077 .50071 m
.5468 .49916 L
s
.59802 .55783 m
.61027 .56149 L
s
.60453 .56246 m
.61728 .56703 L
s
.60916 .56662 m
.62229 .57174 L
s
.50523 .45977 m
.50606 .45618 L
s
.75517 .68929 m
.77536 .7188 L
s
.56277 .526 m
.57142 .52598 L
s
.68731 .6303 m
.70571 .64733 L
s
.66986 .61625 m
.68731 .6303 L
s
.54318 .5062 m
.54948 .50461 L
s
.70571 .64733 m
.7246 .66735 L
s
.65365 .60506 m
.66986 .61625 L
s
.68521 .62962 m
.70334 .64613 L
s
.66804 .61605 m
.68521 .62962 L
s
.80354 .73387 m
.82347 .77316 L
s
.70334 .64613 m
.72201 .66559 L
s
.50452 .46362 m
.50523 .45977 L
s
.65211 .60527 m
.66804 .61605 L
s
.6055 .56836 m
.61792 .57258 L
s
.68061 .62789 m
.6982 .64332 L
s
.66402 .61531 m
.68061 .62789 L
s
.58413 .5503 m
.59463 .55205 L
s
.58766 .55371 m
.59847 .55582 L
s
.6982 .64332 m
.71642 .66162 L
s
.63881 .59649 m
.65365 .60506 L
s
.5356 .5031 m
.54077 .50071 L
s
.67981 .62907 m
.69723 .64411 L
s
.66336 .61686 m
.67981 .62907 L
s
.59756 .56352 m
.60916 .56662 L
s
.5933 .55983 m
.60453 .56246 L
s
.58724 .55605 m
.59802 .55783 L
s
.69723 .64411 m
.71525 .66201 L
s
.7246 .66735 m
.7433 .69008 L
s
.50392 .46771 m
.50452 .46362 L
s
.64867 .60541 m
.66402 .61531 L
s
.63754 .59707 m
.65211 .60527 L
s
.72201 .66559 m
.74056 .68777 L
s
.83268 .76397 m
.85118 .80877 L
s
.53775 .50868 m
.54318 .5062 L
s
.55528 .52726 m
.56277 .526 L
s
.68452 .63369 m
.70189 .64938 L
s
.66803 .62076 m
.68452 .63369 L
s
.6481 .60735 m
.66336 .61686 L
s
.71642 .66162 m
.73468 .68264 L
s
.77088 .70915 m
.78976 .74045 L
s
.70189 .64938 m
.71972 .66784 L
s
.78262 .71999 m
.80138 .75357 L
s
.65268 .6105 m
.66803 .62076 L
s
.71525 .66201 m
.73331 .68259 L
s
.88153 .81156 m
.89801 .8674 L
s
.6254 .59029 m
.63881 .59649 L
s
.5034 .47204 m
.50392 .46771 L
s
.63466 .59798 m
.64867 .60541 L
s
.59455 .56604 m
.6055 .56836 L
s
.63414 .60032 m
.6481 .60735 L
s
.53117 .50621 m
.5356 .5031 L
s
.62438 .59119 m
.63754 .59707 L
s
.7663 .70767 m
.78455 .73746 L
s
.57497 .55009 m
.58413 .5503 L
s
.6386 .60271 m
.65268 .6105 L
s
.57822 .55321 m
.58766 .55371 L
s
.71972 .66784 m
.7374 .68883 L
s
.58738 .56216 m
.59756 .56352 L
s
.58346 .55889 m
.5933 .55983 L
s
.57777 .55592 m
.58724 .55605 L
s
.53308 .51195 m
.53775 .50868 L
s
.50295 .47663 m
.5034 .47204 L
s
.54878 .52961 m
.55528 .52726 L
s
.73468 .68264 m
.75218 .70593 L
s
.7433 .69008 m
.76089 .71494 L
s
.74056 .68777 m
.75811 .71212 L
s
.62203 .59278 m
.63466 .59798 L
s
.6134 .58621 m
.6254 .59029 L
s
.73331 .68259 m
.75064 .70543 L
s
.77536 .7188 m
.79281 .74964 L
s
.62148 .59557 m
.63414 .60032 L
s
.78401 .72664 m
.80136 .75915 L
s
.78611 .72856 m
.8034 .76148 L
s
.62586 .59714 m
.6386 .60271 L
s
.69196 .64804 m
.70825 .66369 L
s
.67621 .63488 m
.69196 .64804 L
s
.66133 .6242 m
.67621 .63488 L
s
.61261 .58738 m
.62438 .59119 L
s
.50256 .48148 m
.50295 .47663 L
s
.52738 .50998 m
.53117 .50621 L
s
.68759 .64575 m
.70371 .66052 L
s
.67206 .63351 m
.68759 .64575 L
s
.58495 .56538 m
.59455 .56604 L
s
.65741 .62375 m
.67206 .63351 L
s
.83469 .77377 m
.85067 .81657 L
s
.67946 .64059 m
.6951 .65384 L
s
.66456 .62981 m
.67946 .64059 L
s
.70371 .66052 m
.72001 .67769 L
s
.64751 .61588 m
.66133 .6242 L
s
.56702 .55121 m
.57497 .55009 L
s
.70825 .66369 m
.72461 .6817 L
s
.57001 .55408 m
.57822 .55321 L
s
.52905 .51593 m
.53308 .51195 L
s
.6951 .65384 m
.71112 .66952 L
s
.7374 .68883 m
.75409 .71182 L
s
.57848 .56233 m
.58738 .56216 L
s
.56947 .55723 m
.57777 .55592 L
s
.6438 .61636 m
.65741 .62375 L
s
.57488 .55941 m
.58346 .55889 L
s
.6506 .62143 m
.66456 .62981 L
s
.61075 .58955 m
.62203 .59278 L
s
.54315 .53293 m
.54878 .52961 L
s
.50222 .48659 m
.50256 .48148 L
s
.67881 .64086 m
.69403 .65385 L
s
.66432 .63023 m
.67881 .64086 L
s
.61009 .59286 m
.62148 .59557 L
s
.60275 .58398 m
.6134 .58621 L
s
.69403 .65385 m
.70966 .66918 L
s
.61444 .59358 m
.62586 .59714 L
s
.71112 .66952 m
.72701 .68743 L
s
.63487 .60975 m
.64751 .61588 L
s
.6508 .62188 m
.66432 .63023 L
s
.52413 .51433 m
.52738 .50998 L
s
.60218 .58539 m
.61261 .58738 L
s
.63771 .61532 m
.6506 .62143 L
s
.72001 .67769 m
.73587 .69697 L
s
.63132 .61119 m
.6438 .61636 L
s
.72461 .6817 m
.74036 .70169 L
s
.70966 .66918 m
.7252 .68665 L
s
.50194 .49196 m
.50222 .48659 L
s
.57658 .56614 m
.58495 .56538 L
s
.52556 .52057 m
.52905 .51593 L
s
.75218 .70593 m
.76789 .73065 L
s
.46732 .44918 m
.46194 .44315 L
s
.47186 .45519 m
.46732 .44918 L
s
.46194 .44315 m
.45557 .43705 L
s
.47571 .46119 m
.47186 .45519 L
s
.63837 .61566 m
.6508 .62188 L
s
.75064 .70543 m
.76622 .72971 L
s
.56014 .5535 m
.56702 .55121 L
s
.5629 .55616 m
.57001 .55408 L
s
.45557 .43705 m
.44804 .43088 L
s
.75811 .71212 m
.77355 .73767 L
s
.56219 .55984 m
.56947 .55723 L
s
.60076 .58807 m
.61075 .58955 L
s
.47896 .46723 m
.47571 .46119 L
s
.62345 .60561 m
.63487 .60975 L
s
.57076 .56381 m
.57848 .56233 L
s
.5999 .592 m
.61009 .59286 L
s
.53825 .53713 m
.54315 .53293 L
s
.56745 .56119 m
.57488 .55941 L
s
.76089 .71494 m
.7762 .74091 L
s
.62592 .61132 m
.63771 .61532 L
s
.68748 .65487 m
.70208 .66817 L
s
.67328 .64376 m
.68748 .65487 L
s
.65976 .63489 m
.67328 .64376 L
s
.60431 .5918 m
.61444 .59358 L
s
.78976 .74045 m
.80465 .77183 L
s
.59338 .58338 m
.60275 .58398 L
s
.61996 .60807 m
.63132 .61119 L
s
.72701 .68743 m
.74212 .70715 L
s
.48172 .47333 m
.47896 .46723 L
s
.44804 .43088 m
.43911 .42464 L
s
.52135 .51924 m
.52413 .51433 L
s
.50169 .49761 m
.50194 .49196 L
s
.46354 .45 m
.45759 .44377 L
s
.46858 .4562 m
.46354 .45 L
s
.47285 .46239 m
.46858 .4562 L
s
.45759 .44377 m
.45055 .43749 L
s
.70208 .66817 m
.71669 .68353 L
s
.64709 .62819 m
.65976 .63489 L
s
.7252 .68665 m
.74001 .70587 L
s
.593 .585 m
.60218 .58539 L
s
.47647 .4686 m
.47285 .46239 L
s
.78455 .73746 m
.79909 .76741 L
s
.6271 .61139 m
.63837 .61566 L
s
.48404 .47954 m
.48172 .47333 L
s
.45055 .43749 m
.44223 .43115 L
s
.52252 .52583 m
.52556 .52057 L
s
.75409 .71182 m
.76876 .73592 L
s
.68403 .65511 m
.69806 .66741 L
s
.67043 .64492 m
.68403 .65511 L
s
.73587 .69697 m
.75054 .71777 L
s
.65748 .63687 m
.67043 .64492 L
s
.47955 .47486 m
.47647 .4686 L
s
.43911 .42464 m
.42853 .41835 L
s
.82347 .77316 m
.83676 .81057 L
s
.80138 .75357 m
.81521 .78646 L
s
.56932 .56816 m
.57658 .56614 L
s
.61522 .60927 m
.62592 .61132 L
s
.69806 .66741 m
.71215 .68171 L
s
.61324 .60326 m
.62345 .60561 L
s
.63537 .62356 m
.64709 .62819 L
s
.48601 .48588 m
.48404 .47954 L
s
.50148 .50354 m
.50169 .49761 L
s
.74036 .70169 m
.7547 .72303 L
s
.44223 .43115 m
.43239 .42476 L
s
.48216 .48121 m
.47955 .47486 L
s
.55423 .5568 m
.56014 .5535 L
s
.64536 .6309 m
.65748 .63687 L
s
.6097 .60683 m
.61996 .60807 L
s
.5908 .59281 m
.5999 .592 L
s
.53397 .54215 m
.53825 .53713 L
s
.55678 .5593 m
.5629 .55616 L
s
.59199 .58812 m
.60076 .58807 L
s
.5558 .56362 m
.56219 .55984 L
s
.71669 .68353 m
.73076 .70063 L
s
.51899 .52465 m
.52135 .51924 L
s
.56409 .56645 m
.57076 .56381 L
s
.5954 .59158 m
.60431 .5918 L
s
.56103 .56408 m
.56745 .56119 L
s
.58519 .58422 m
.59338 .58338 L
s
.48767 .49239 m
.48601 .48588 L
s
.61699 .6089 m
.6271 .61139 L
s
.42853 .41835 m
.41601 .41209 L
s
.48439 .48767 m
.48216 .48121 L
s
.71215 .68171 m
.7258 .69772 L
s
.51986 .5317 m
.52252 .52583 L
s
.43239 .42476 m
.42075 .4184 L
s
.63414 .62692 m
.64536 .6309 L
s
.62462 .62087 m
.63537 .62356 L
s
.58499 .58602 m
.593 .585 L
s
.79281 .74964 m
.80578 .77984 L
s
.4594 .45792 m
.45302 .45129 L
s
.46482 .46456 m
.4594 .45792 L
s
.50132 .50975 m
.50148 .50354 L
s
.46942 .47122 m
.46482 .46456 L
s
.74212 .70715 m
.75562 .72796 L
s
.45302 .45129 m
.44551 .44464 L
s
.60556 .60901 m
.61522 .60927 L
s
.47334 .47792 m
.46942 .47122 L
s
.48629 .49427 m
.48439 .48767 L
s
.46067 .46188 m
.4546 .45514 L
s
.46583 .46863 m
.46067 .46188 L
s
.48906 .4991 m
.48767 .49239 L
s
.4546 .45514 m
.44745 .44842 L
s
.74001 .70587 m
.75328 .72618 L
s
.60421 .60252 m
.61324 .60326 L
s
.4702 .47544 m
.46583 .46863 L
s
.44551 .44464 m
.43665 .43799 L
s
.60045 .60732 m
.6097 .60683 L
s
.56308 .57127 m
.56932 .56816 L
s
.44745 .44842 m
.43902 .4417 L
s
.80136 .75915 m
.81354 .79044 L
s
.47668 .4847 m
.47334 .47792 L
s
.53021 .54794 m
.53397 .54215 L
s
.47391 .48232 m
.4702 .47544 L
s
.51699 .53053 m
.51899 .52465 L
s
.58269 .59517 m
.5908 .59281 L
s
.76789 .73065 m
.78061 .75555 L
s
.8034 .76148 m
.81536 .79301 L
s
.55016 .56848 m
.5558 .56362 L
s
.54917 .56101 m
.55423 .5568 L
s
.62383 .62483 m
.63414 .62692 L
s
.76622 .72971 m
.77888 .75421 L
s
.58437 .58953 m
.59199 .58812 L
s
.55154 .56337 m
.55678 .5593 L
s
.73076 .70063 m
.74362 .71892 L
s
.41601 .41209 m
.4012 .40599 L
s
.43665 .43799 m
.42621 .43138 L
s
.48793 .50104 m
.48629 .49427 L
s
.58763 .59275 m
.5954 .59158 L
s
.42075 .4184 m
.407 .41216 L
s
.60804 .60799 m
.61699 .6089 L
s
.50119 .51626 m
.50132 .50975 L
s
.61483 .62001 m
.62462 .62087 L
s
.47706 .48932 m
.47391 .48232 L
s
.49022 .50604 m
.48906 .4991 L
s
.43902 .4417 m
.42908 .43501 L
s
.47953 .49159 m
.47668 .4847 L
s
.55837 .5701 m
.56409 .56645 L
s
.55555 .56794 m
.56103 .56408 L
s
.51752 .53816 m
.51986 .5317 L
s
.57812 .58632 m
.58519 .58422 L
s
.75054 .71777 m
.76307 .73922 L
s
.7258 .69772 m
.73842 .71497 L
s
.77355 .73767 m
.78557 .76304 L
s
.59686 .61043 m
.60556 .60901 L
s
.47973 .49646 m
.47706 .48932 L
s
.57808 .58828 m
.58499 .58602 L
s
.48198 .4986 m
.47953 .49159 L
s
.7762 .74091 m
.7879 .7665 L
s
.48933 .508 m
.48793 .50104 L
s
.42908 .43501 m
.41738 .42843 L
s
.42621 .43138 m
.41391 .42487 L
s
.7547 .72303 m
.76665 .74475 L
s
.49117 .51326 m
.49022 .50604 L
s
.59213 .60943 m
.60045 .60732 L
s
.59632 .60319 m
.60421 .60252 L
s
.61443 .62451 m
.62383 .62483 L
s
.51531 .53687 m
.51699 .53053 L
s
.52689 .55449 m
.53021 .54794 L
s
.50111 .52308 m
.50119 .51626 L
s
.48197 .5038 m
.47973 .49646 L
s
.76876 .73592 m
.78022 .75983 L
s
.57542 .59896 m
.58269 .59517 L
s
.55777 .57535 m
.56308 .57127 L
s
.60593 .62086 m
.61483 .62001 L
s
.85118 .80877 m
.8599 .84851 L
s
.48408 .50577 m
.48198 .4986 L
s
.54515 .57437 m
.55016 .56848 L
s
.51542 .54521 m
.51752 .53816 L
s
.5449 .56601 m
.54917 .56101 L
s
.407 .41216 m
.39078 .40624 L
s
.60021 .60851 m
.60804 .60799 L
s
.45263 .46794 m
.44557 .46081 L
s
.45866 .47512 m
.45263 .46794 L
s
.57783 .59213 m
.58437 .58953 L
s
.4638 .48236 m
.45866 .47512 L
s
.54712 .56826 m
.55154 .56337 L
s
.49056 .51517 m
.48933 .508 L
s
.44557 .46081 m
.43728 .45375 L
s
.58096 .59513 m
.58763 .59275 L
s
.4012 .40599 m
.38372 .40032 L
s
.49194 .52078 m
.49117 .51326 L
s
.4682 .48969 m
.4638 .48236 L
s
.55354 .57465 m
.55837 .5701 L
s
.48386 .51136 m
.48197 .5038 L
s
.55091 .57268 m
.55555 .56794 L
s
.41738 .42843 m
.40361 .42206 L
s
.57207 .58954 m
.57812 .58632 L
s
.589 .6134 m
.59686 .61043 L
s
.41391 .42487 m
.39943 .41863 L
s
.43728 .45375 m
.42755 .44678 L
s
.75562 .72796 m
.76653 .74887 L
s
.48589 .51313 m
.48408 .50577 L
s
.60585 .62587 m
.61443 .62451 L
s
.47197 .49711 m
.4682 .48969 L
s
.75328 .72618 m
.7641 .74661 L
s
.50107 .5302 m
.50111 .52308 L
s
.74362 .71892 m
.75449 .73763 L
s
.58462 .61306 m
.59213 .60943 L
s
.5722 .59163 m
.57808 .58828 L
s
.73842 .71497 m
.74928 .73277 L
s
.51394 .54364 m
.51531 .53687 L
s
.5239 .56177 m
.52689 .55449 L
s
.58952 .60512 m
.59632 .60319 L
s
.59785 .62333 m
.60593 .62086 L
s
.48542 .51918 m
.48386 .51136 L
s
.49164 .52257 m
.49056 .51517 L
s
.42755 .44678 m
.41615 .43997 L
s
.47521 .50467 m
.47197 .49711 L
s
.49253 .52864 m
.49194 .52078 L
s
.56889 .60411 m
.57542 .59896 L
s
.51351 .55287 m
.51542 .54521 L
s
.80465 .77183 m
.81368 .80085 L
s
.54065 .58125 m
.54515 .57437 L
s
.79909 .76741 m
.80818 .79528 L
s
.48748 .52069 m
.48589 .51313 L
s
.55332 .58028 m
.55777 .57535 L
s
.59346 .6103 m
.60021 .60851 L
s
.54134 .57174 m
.5449 .56601 L
s
.57229 .59579 m
.57783 .59213 L
s
.54344 .57389 m
.54712 .56826 L
s
.478 .51238 m
.47521 .50467 L
s
.40361 .42206 m
.38744 .41613 L
s
.58187 .61787 m
.589 .6134 L
s
.5753 .5986 m
.58096 .59513 L
s
.4867 .52731 m
.48542 .51918 L
s
.59802 .62884 m
.60585 .62587 L
s
.5011 .53763 m
.50107 .5302 L
s
.39078 .40624 m
.37171 .40099 L
s
.54951 .57999 m
.55354 .57465 L
s
.54706 .57818 m
.55091 .57268 L
s
.39943 .41863 m
.38244 .41289 L
s
.41615 .43997 m
.40279 .43345 L
s
.49261 .53022 m
.49164 .52257 L
s
.76307 .73922 m
.77246 .76012 L
s
.49296 .53689 m
.49253 .52864 L
s
.567 .59373 m
.57207 .58954 L
s
.57779 .61815 m
.58462 .61306 L
s
.51285 .55083 m
.51394 .54364 L
s
.52116 .5698 m
.5239 .56177 L
s
.38372 .40032 m
.36317 .39547 L
s
.59046 .62735 m
.59785 .62333 L
s
.48888 .52846 m
.48748 .52069 L
s
.51172 .56116 m
.51351 .55287 L
s
.48043 .52026 m
.478 .51238 L
s
.85067 .81657 m
.85646 .85325 L
s
.56728 .59596 m
.5722 .59163 L
s
.77888 .75421 m
.78736 .77733 L
s
.78061 .75555 m
.78904 .77898 L
s
.58377 .60818 m
.58952 .60512 L
s
.56294 .61056 m
.56889 .60411 L
s
.4877 .5358 m
.4867 .52731 L
s
.53655 .58912 m
.54065 .58125 L
s
.76665 .74475 m
.77515 .76555 L
s
.81521 .78646 m
.82209 .81577 L
s
.49321 .54556 m
.49296 .53689 L
s
.50122 .54537 m
.5011 .53763 L
s
.49351 .53812 m
.49261 .53022 L
s
.59083 .63336 m
.59802 .62884 L
s
.58776 .61321 m
.59346 .6103 L
s
.54968 .58599 m
.55332 .58028 L
s
.57534 .62379 m
.58187 .61787 L
s
.40279 .43345 m
.38716 .42741 L
s
.48256 .52833 m
.48043 .52026 L
s
.53847 .57811 m
.54134 .57174 L
s
.49015 .53648 m
.48888 .52846 L
s
.54046 .58019 m
.54344 .57389 L
s
.56771 .60038 m
.57229 .59579 L
s
.74928 .73277 m
.7576 .7502 L
s
.57063 .60302 m
.5753 .5986 L
s
.38744 .41613 m
.36852 .41098 L
s
.48845 .54468 m
.4877 .5358 L
s
.5715 .62466 m
.57779 .61815 L
s
.51204 .55842 m
.51285 .55083 L
s
.78557 .76304 m
.79284 .7864 L
s
.5186 .57861 m
.52116 .5698 L
s
.58365 .6329 m
.59046 .62735 L
s
.54626 .58606 m
.54951 .57999 L
s
.50999 .5701 m
.51172 .56116 L
s
.75449 .73763 m
.76253 .75574 L
s
.54396 .58438 m
.54706 .57818 L
s
.56285 .59881 m
.567 .59373 L
s
.38244 .41289 m
.36256 .40805 L
s
.44699 .49365 m
.44012 .48561 L
s
.45285 .50189 m
.44699 .49365 L
s
.44012 .48561 m
.43209 .47779 L
s
.78022 .75983 m
.78725 .78191 L
s
.49328 .5547 m
.49321 .54556 L
s
.7879 .7665 m
.79463 .78984 L
s
.55742 .61832 m
.56294 .61056 L
s
.7641 .74661 m
.7715 .76595 L
s
.76653 .74887 m
.77388 .76857 L
s
.45783 .51035 m
.45285 .50189 L
s
.43209 .47779 m
.42272 .47021 L
s
.48445 .53662 m
.48256 .52833 L
s
.49438 .54628 m
.49351 .53812 L
s
.53271 .59798 m
.53655 .58912 L
s
.37171 .40099 m
.34939 .39692 L
s
.56329 .60115 m
.56728 .59596 L
s
.57903 .61224 m
.58377 .60818 L
s
.93791 .90405 m
.93596 .95754 L
s
.50143 .55342 m
.50122 .54537 L
s
.58413 .63943 m
.59083 .63336 L
s
.49133 .54474 m
.49015 .53648 L
s
.46205 .51906 m
.45783 .51035 L
s
.56924 .63114 m
.57534 .62379 L
s
.48895 .55401 m
.48845 .54468 L
s
.83676 .81057 m
.84088 .84221 L
s
.42272 .47021 m
.4118 .46295 L
s
.81354 .79044 m
.81866 .8177 L
s
.58308 .61713 m
.58776 .61321 L
s
.89801 .8674 m
.89822 .91114 L
s
.54681 .59239 m
.54968 .58599 L
s
.38716 .42741 m
.36896 .42219 L
s
.4656 .52804 m
.46205 .51906 L
s
.57726 .63995 m
.58365 .6329 L
s
.50826 .57975 m
.50999 .5701 L
s
.5161 .58822 m
.5186 .57861 L
s
.36317 .39547 m
.33915 .39208 L
s
.53625 .58508 m
.53847 .57811 L
s
.56558 .63258 m
.5715 .62466 L
s
.81536 .79301 m
.82005 .82026 L
s
.51153 .56638 m
.51204 .55842 L
s
.53816 .5871 m
.54046 .58019 L
s
.49314 .56437 m
.49328 .5547 L
s
.56407 .60582 m
.56771 .60038 L
s
.48618 .54513 m
.48445 .53662 L
s
.56691 .6083 m
.57063 .60302 L
s
.4118 .46295 m
.39911 .45612 L
s
.49526 .55472 m
.49438 .54628 L
s
.54376 .59278 m
.54626 .58606 L
s
.54157 .59121 m
.54396 .58438 L
s
.55218 .62738 m
.55742 .61832 L
s
.46854 .53735 m
.4656 .52804 L
s
.48917 .56385 m
.48895 .55401 L
s
.49247 .55326 m
.49133 .54474 L
s
.55961 .60466 m
.56285 .59881 L
s
.529 .60786 m
.53271 .59798 L
s
.50179 .56179 m
.50143 .55342 L
s
.57777 .64704 m
.58413 .63943 L
s
.36852 .41098 m
.3465 .40714 L
s
.56341 .63994 m
.56924 .63114 L
s
.5753 .61719 m
.57903 .61224 L
s
.56021 .60711 m
.56329 .60115 L
s
.77246 .76012 m
.7777 .77904 L
s
.44019 .50468 m
.43299 .49628 L
s
.44633 .51337 m
.44019 .50468 L
s
.47092 .54703 m
.46854 .53735 L
s
.43299 .49628 m
.42459 .4882 L
s
.50643 .59015 m
.50826 .57975 L
s
.49276 .57462 m
.49314 .56437 L
s
.5711 .64855 m
.57726 .63995 L
s
.51357 .59869 m
.5161 .58822 L
s
.45155 .52235 m
.44633 .51337 L
s
.55987 .64196 m
.56558 .63258 L
s
.4878 .55387 m
.48618 .54513 L
s
.39911 .45612 m
.38438 .44993 L
s
.42459 .4882 m
.41482 .48047 L
s
.36256 .40805 m
.33946 .40473 L
s
.57942 .62195 m
.58308 .61713 L
s
.51133 .57471 m
.51153 .56638 L
s
.48909 .57425 m
.48917 .56385 L
s
.45594 .53165 m
.45155 .52235 L
s
.54473 .59941 m
.54681 .59239 L
s
.4962 .56343 m
.49526 .55472 L
s
.53468 .5926 m
.53625 .58508 L
s
.7576 .7502 m
.76264 .7662 L
s
.49364 .56203 m
.49247 .55326 L
s
.53655 .59457 m
.53816 .5871 L
s
.54701 .6378 m
.55218 .62738 L
s
.41482 .48047 m
.40348 .47319 L
s
.57153 .65623 m
.57777 .64704 L
s
.47277 .55713 m
.47092 .54703 L
s
.52528 .61881 m
.529 .60786 L
s
.56136 .612 m
.56407 .60582 L
s
.36896 .42219 m
.34787 .4183 L
s
.50232 .57046 m
.50179 .56179 L
s
.56414 .61436 m
.56691 .6083 L
s
.4596 .5413 m
.45594 .53165 L
s
.77515 .76555 m
.77923 .78396 L
s
.43383 .50651 m
.42602 .49812 L
s
.44051 .51525 m
.43383 .50651 L
s
.55763 .65024 m
.56341 .63994 L
s
.53992 .59862 m
.54157 .59121 L
s
.34939 .39692 m
.32347 .39486 L
s
.54201 .60009 m
.54376 .59278 L
s
.76253 .75574 m
.76694 .77207 L
s
.44619 .52432 m
.44051 .51525 L
s
.42602 .49812 m
.41692 .4901 L
s
.4921 .58551 m
.49276 .57462 L
s
.55726 .61123 m
.55961 .60466 L
s
.50442 .60136 m
.50643 .59015 L
s
.56498 .65873 m
.5711 .64855 L
s
.45098 .53374 m
.44619 .52432 L
s
.51089 .61007 m
.51357 .59869 L
s
.48939 .56285 m
.4878 .55387 L
s
.78736 .77733 m
.79049 .79723 L
s
.55413 .65284 m
.55987 .64196 L
s
.40348 .47319 m
.39037 .46651 L
s
.41692 .4901 m
.40638 .48253 L
s
.48868 .58528 m
.48909 .57425 L
s
.46257 .55135 m
.4596 .5413 L
s
.78904 .77898 m
.79198 .79905 L
s
.80818 .79528 m
.81025 .81849 L
s
.47412 .56771 m
.47277 .55713 L
s
.38438 .44993 m
.36738 .44467 L
s
.57256 .62295 m
.5753 .61719 L
s
.55805 .61377 m
.56021 .60711 L
s
.45496 .54353 m
.45098 .53374 L
s
.81368 .80085 m
.81519 .82472 L
s
.56521 .66709 m
.57153 .65623 L
s
.49727 .57241 m
.4962 .56343 L
s
.51151 .5834 m
.51133 .57471 L
s
.54172 .64963 m
.54701 .6378 L
s
.49489 .57107 m
.49364 .56203 L
s
.7715 .76595 m
.77462 .7828 L
s
.40638 .48253 m
.39418 .47554 L
s
.33915 .39208 m
.31134 .39113 L
s
.57679 .6276 m
.57942 .62195 L
s
.52136 .63091 m
.52528 .61881 L
s
.4649 .56184 m
.46257 .55135 L
s
.77388 .76857 m
.77676 .78563 L
s
.49107 .59712 m
.4921 .58551 L
s
.45821 .55373 m
.45496 .54353 L
s
.55168 .66211 m
.55763 .65024 L
s
.53381 .60061 m
.53468 .5926 L
s
.54343 .60701 m
.54473 .59941 L
s
.5031 .57942 m
.50232 .57046 L
s
.47494 .57884 m
.47412 .56771 L
s
.5021 .61347 m
.50442 .60136 L
s
.55862 .67059 m
.56498 .65873 L
s
.53565 .60255 m
.53655 .59457 L
s
.39037 .46651 m
.37526 .46066 L
s
.3465 .40714 m
.32108 .40543 L
s
.48786 .59701 m
.48868 .58528 L
s
.50791 .62244 m
.51089 .61007 L
s
.55959 .61888 m
.56136 .612 L
s
.54813 .66532 m
.55413 .65284 L
s
.49102 .57206 m
.48939 .56285 L
s
.56233 .62112 m
.56414 .61436 L
s
.79284 .7864 m
.79419 .80576 L
s
.53903 .60656 m
.53992 .59862 L
s
.46075 .56439 m
.45821 .55373 L
s
.54104 .60795 m
.54201 .60009 L
s
.4666 .57283 m
.4649 .56184 L
s
.78725 .78191 m
.78877 .80032 L
s
.39418 .47554 m
.38014 .46933 L
s
.5585 .67972 m
.56521 .66709 L
s
.42783 .51949 m
.42008 .51081 L
s
.43445 .5286 m
.42783 .51949 L
s
.55584 .61844 m
.55726 .61123 L
s
.42956 .5154 m
.42147 .50712 L
s
.43661 .524 m
.42956 .5154 L
s
.42147 .50712 m
.41218 .49922 L
s
.42008 .51081 m
.41107 .50262 L
s
.44005 .53814 m
.43445 .5286 L
s
.53604 .66297 m
.54172 .64963 L
s
.33946 .40473 m
.31287 .40383 L
s
.44277 .53286 m
.43661 .524 L
s
.4896 .60953 m
.49107 .59712 L
s
.47521 .59058 m
.47494 .57884 L
s
.41218 .49922 m
.4015 .4918 L
s
.51706 .64423 m
.52136 .63091 L
s
.49855 .58166 m
.49727 .57241 L
s
.36738 .44467 m
.34786 .44082 L
s
.54526 .67566 m
.55168 .66211 L
s
.79463 .78984 m
.79522 .80886 L
s
.49631 .58036 m
.49489 .57107 L
s
.44471 .5481 m
.44005 .53814 L
s
.57085 .62945 m
.57256 .62295 L
s
.34787 .4183 m
.32363 .41647 L
s
.41107 .50262 m
.40063 .49498 L
s
.46261 .57556 m
.46075 .56439 L
s
.55683 .62108 m
.55805 .61377 L
s
.55174 .68425 m
.55862 .67059 L
s
.48655 .60951 m
.48786 .59701 L
s
.51211 .59242 m
.51151 .5834 L
s
.49933 .62653 m
.5021 .61347 L
s
.46767 .58438 m
.4666 .57283 L
s
.4482 .54196 m
.44277 .53286 L
s
.50447 .63589 m
.50791 .62244 L
s
.54155 .67948 m
.54813 .66532 L
s
.44852 .55852 m
.44471 .5481 L
s
.4015 .4918 m
.38926 .485 L
s
.57521 .63399 m
.57679 .6276 L
s
.37526 .46066 m
.35795 .456 L
s
.50419 .58868 m
.5031 .57942 L
s
.8599 .84851 m
.85602 .87791 L
s
.40063 .49498 m
.38861 .48803 L
s
.55107 .69424 m
.5585 .67972 L
s
.49278 .58152 m
.49102 .57206 L
s
.38014 .46933 m
.36405 .46418 L
s
.53367 .6091 m
.53381 .60061 L
s
.54298 .61515 m
.54343 .60701 L
s
.82209 .81577 m
.82033 .83837 L
s
.76264 .7662 m
.76375 .77963 L
s
.47488 .60301 m
.47521 .59058 L
s
.46379 .5873 m
.46261 .57556 L
s
.53552 .61101 m
.53565 .60255 L
s
.45151 .56942 m
.44852 .55852 L
s
.45302 .55128 m
.4482 .54196 L
s
.52968 .67792 m
.53604 .66297 L
s
.48755 .6228 m
.4896 .60953 L
s
.7777 .77904 m
.77798 .79447 L
s
.5588 .62639 m
.55959 .61888 L
s
.53804 .69102 m
.54526 .67566 L
s
.46808 .59655 m
.46767 .58438 L
s
.51214 .65885 m
.51706 .64423 L
s
.42047 .5263 m
.41242 .51764 L
s
.42735 .53547 m
.42047 .5263 L
s
.54395 .69983 m
.55174 .68425 L
s
.32347 .39486 m
.29375 .39597 L
s
.56153 .62852 m
.56233 .62112 L
s
.43315 .54514 m
.42735 .53547 L
s
.38926 .485 m
.37527 .47906 L
s
.48464 .62287 m
.48655 .60951 L
s
.53896 .615 m
.53903 .60656 L
s
.41242 .51764 m
.40307 .50956 L
s
.54092 .61632 m
.54104 .60795 L
s
.49595 .64065 m
.49933 .62653 L
s
.43797 .55529 m
.43315 .54514 L
s
.38861 .48803 m
.37484 .48198 L
s
.53405 .69548 m
.54155 .67948 L
s
.50012 .59118 m
.49855 .58166 L
s
.4537 .58086 m
.45151 .56942 L
s
.49799 .58991 m
.49631 .58036 L
s
.5554 .62626 m
.55584 .61844 L
s
.50036 .65048 m
.50447 .63589 L
s
.76694 .77207 m
.76707 .7854 L
s
.54252 .71082 m
.55107 .69424 L
s
.40307 .50956 m
.39229 .50215 L
s
.45738 .5608 m
.45302 .55128 L
s
.46424 .59967 m
.46379 .5873 L
s
.44187 .56594 m
.43797 .55529 L
s
.47385 .61619 m
.47488 .60301 L
s
.57022 .63663 m
.57085 .62945 L
s
.51323 .60178 m
.51211 .59242 L
s
.42153 .53689 m
.41424 .52786 L
s
.42771 .54646 m
.42153 .53689 L
s
.46776 .60943 m
.46808 .59655 L
s
.41424 .52786 m
.40572 .51941 L
s
.55661 .62899 m
.55683 .62108 L
s
.52227 .6946 m
.52968 .67792 L
s
.48479 .63702 m
.48755 .6228 L
s
.43285 .55654 m
.42771 .54646 L
s
.5296 .70831 m
.53804 .69102 L
s
.53482 .7175 m
.54395 .69983 L
s
.50571 .59824 m
.50419 .58868 L
s
.77923 .78396 m
.77813 .79845 L
s
.49479 .59123 m
.49278 .58152 L
s
.45509 .59289 m
.4537 .58086 L
s
.34786 .44082 m
.32565 .43901 L
s
.44487 .57713 m
.44187 .56594 L
s
.40572 .51941 m
.39586 .51162 L
s
.39229 .50215 m
.37992 .49558 L
s
.5063 .67489 m
.51214 .65885 L
s
.36405 .46418 m
.34574 .46051 L
s
.81866 .8177 m
.81525 .83797 L
s
.57473 .64107 m
.57521 .63399 L
s
.35795 .456 m
.33826 .45302 L
s
.48197 .63716 m
.48464 .62287 L
s
.37527 .47906 m
.35936 .47428 L
s
.43702 .56715 m
.43285 .55654 L
s
.41475 .53333 m
.40663 .52469 L
s
.42167 .54254 m
.41475 .53333 L
s
.42749 .55231 m
.42167 .54254 L
s
.49173 .6559 m
.49595 .64065 L
s
.52518 .71343 m
.53405 .69548 L
s
.32108 .40543 m
.29211 .407 L
s
.53236 .72961 m
.54252 .71082 L
s
.31134 .39113 m
.27959 .39402 L
s
.46392 .61274 m
.46424 .59967 L
s
.37484 .48198 m
.35916 .47712 L
s
.40663 .52469 m
.39722 .51671 L
s
.53436 .61805 m
.53367 .6091 L
s
.43229 .56261 m
.42749 .55231 L
s
.46141 .57052 m
.45738 .5608 L
s
.54345 .6238 m
.54298 .61515 L
s
.49533 .66632 m
.50036 .65048 L
s
.39586 .51162 m
.38454 .50461 L
s
.82005 .82026 m
.81602 .84025 L
s
.447 .58888 m
.44487 .57713 L
s
.53624 .61994 m
.53552 .61101 L
s
.44026 .5783 m
.43702 .56715 L
s
.47202 .6302 m
.47385 .61619 L
s
.46664 .62306 m
.46776 .60943 L
s
.45565 .60556 m
.45509 .59289 L
s
.43612 .57346 m
.43229 .56261 L
s
.77462 .7828 m
.77281 .79581 L
s
.39722 .51671 m
.3864 .50949 L
s
.55908 .6345 m
.5588 .62639 L
s
.85646 .85325 m
.84957 .87883 L
s
.52383 .7374 m
.53482 .7175 L
s
.51946 .72766 m
.5296 .70831 L
s
.56181 .63655 m
.56153 .62852 L
s
.51339 .71313 m
.52227 .6946 L
s
.48112 .65226 m
.48479 .63702 L
s
.5021 .60096 m
.50012 .59118 L
s
.50006 .59973 m
.49799 .58991 L
s
.37992 .49558 m
.36584 .49009 L
s
.32363 .41647 m
.29612 .41777 L
s
.5398 .62393 m
.53896 .615 L
s
.54173 .62519 m
.54092 .61632 L
s
.77676 .78563 m
.77452 .79863 L
s
.44257 .59002 m
.44026 .5783 L
s
.79049 .79723 m
.78744 .81208 L
s
.439 .58487 m
.43612 .57346 L
s
.47836 .65244 m
.48197 .63716 L
s
.49921 .69241 m
.5063 .67489 L
s
.51998 .75077 m
.53236 .72961 L
s
.38454 .50461 m
.37162 .49858 L
s
.44824 .60124 m
.447 .58888 L
s
.46271 .62657 m
.46392 .61274 L
s
.51445 .73346 m
.52518 .71343 L
s
.31287 .40383 m
.28267 .40664 L
s
.55603 .63466 m
.5554 .62626 L
s
.79198 .79905 m
.7886 .8139 L
s
.48642 .67235 m
.49173 .6559 L
s
.3864 .50949 m
.37403 .50322 L
s
.51499 .61147 m
.51323 .60178 L
s
.4553 .61892 m
.45565 .60556 L
s
.46527 .58042 m
.46141 .57052 L
s
.57074 .64446 m
.57022 .63663 L
s
.48909 .68347 m
.49533 .66632 L
s
.46924 .6451 m
.47202 .6302 L
s
.49718 .60117 m
.49479 .59123 L
s
.46457 .63751 m
.46664 .62306 L
s
.35936 .47428 m
.34138 .47109 L
s
.44093 .59687 m
.439 .58487 L
s
.50777 .60808 m
.50571 .59824 L
s
.44396 .60235 m
.44257 .59002 L
s
.84088 .84221 m
.83396 .86407 L
s
.55749 .63749 m
.55661 .62899 L
s
.51034 .75964 m
.52383 .7374 L
s
.35916 .47712 m
.34144 .47386 L
s
.50705 .74918 m
.51946 .72766 L
s
.44854 .61426 m
.44824 .60124 L
s
.50253 .73357 m
.51339 .71313 L
s
.57544 .64882 m
.57473 .64107 L
s
.40881 .534 m
.39974 .52618 L
s
.41683 .54233 m
.40881 .534 L
s
.47631 .66858 m
.48112 .65226 L
s
.34574 .46051 m
.32511 .45893 L
s
.39974 .52618 m
.38947 .519 L
s
.5047 .77435 m
.51998 .75077 L
s
.42394 .55106 m
.41683 .54233 L
s
.46051 .6412 m
.46271 .62657 L
s
.36584 .49009 m
.34993 .48599 L
s
.37162 .49858 m
.35698 .49379 L
s
.47359 .66879 m
.47836 .65244 L
s
.50124 .75563 m
.51445 .73346 L
s
.49046 .71149 m
.49921 .69241 L
s
.37403 .50322 m
.36002 .49813 L
s
.4419 .6095 m
.44093 .59687 L
s
.33826 .45302 m
.31609 .45241 L
s
.536 .62745 m
.53436 .61805 L
s
.45396 .63301 m
.4553 .61892 L
s
.44437 .61533 m
.44396 .60235 L
s
.54496 .63296 m
.54345 .6238 L
s
.38947 .519 m
.37787 .51262 L
s
.47972 .69005 m
.48642 .67235 L
s
.76375 .77963 m
.76055 .78946 L
s
.43031 .56014 m
.42394 .55106 L
s
.4072 .55191 m
.39981 .5431 L
s
.41342 .56139 m
.4072 .55191 L
s
.53793 .62934 m
.53624 .61994 L
s
.78877 .80032 m
.78411 .81339 L
s
.41855 .57149 m
.41342 .56139 L
s
.4653 .66094 m
.46924 .6451 L
s
.4614 .65283 m
.46457 .63751 L
s
.81025 .81849 m
.80425 .83457 L
s
.39981 .5431 m
.39119 .53504 L
s
.48127 .70197 m
.48909 .68347 L
s
.44782 .62797 m
.44854 .61426 L
s
.50267 .60981 m
.50006 .59973 L
s
.32565 .43901 m
.30068 .44015 L
s
.50466 .61103 m
.5021 .60096 L
s
.56052 .6432 m
.55908 .6345 L
s
.49361 .7842 m
.51034 .75964 L
s
.42261 .58221 m
.41855 .57149 L
s
.40952 .55905 m
.40284 .54987 L
s
.41507 .56888 m
.40952 .55905 L
s
.40284 .54987 m
.39498 .5414 L
s
.46912 .59051 m
.46527 .58042 L
s
.79419 .80576 m
.78886 .81925 L
s
.56327 .64517 m
.56181 .63655 L
s
.49167 .77284 m
.50705 .74918 L
s
.40302 .53703 m
.39367 .5295 L
s
.41131 .54513 m
.40302 .53703 L
s
.41953 .57933 m
.41507 .56888 L
s
.39119 .53504 m
.38126 .52781 L
s
.4891 .75593 m
.50253 .73357 L
s
.54168 .63334 m
.5398 .62393 L
s
.44183 .62278 m
.4419 .6095 L
s
.4187 .55368 m
.41131 .54513 L
s
.39498 .5414 m
.38585 .53372 L
s
.54359 .63456 m
.54173 .62519 L
s
.47008 .68602 m
.47631 .66858 L
s
.39367 .5295 m
.38312 .52268 L
s
.37787 .51262 m
.36481 .50727 L
s
.4361 .56949 m
.43031 .56014 L
s
.42563 .59353 m
.42261 .58221 L
s
.45713 .65669 m
.46051 .6412 L
s
.44373 .62899 m
.44437 .61533 L
s
.29375 .39597 m
.26026 .40194 L
s
.48571 .80024 m
.5047 .77435 L
s
.42294 .59039 m
.41953 .57933 L
s
.81519 .82472 m
.80808 .84077 L
s
.45149 .64789 m
.45396 .63301 L
s
.46737 .68622 m
.47359 .66879 L
s
.55783 .64363 m
.55603 .63466 L
s
.48486 .77987 m
.50124 .75563 L
s
.42533 .56261 m
.4187 .55368 L
s
.50011 .61139 m
.49718 .60117 L
s
.47958 .7321 m
.49046 .71149 L
s
.38585 .53372 m
.3754 .52697 L
s
.51755 .62152 m
.51499 .61147 L
s
.76707 .7854 m
.7626 .79469 L
s
.38126 .52781 m
.36995 .5216 L
s
.57251 .65292 m
.57074 .64446 L
s
.38312 .52268 m
.37125 .51677 L
s
.77798 .79447 m
.77283 .80509 L
s
.44598 .6424 m
.44782 .62797 L
s
.35698 .49379 m
.34056 .49063 L
s
.36002 .49813 m
.34427 .49457 L
s
.42759 .60546 m
.42563 .59353 L
s
.47124 .70902 m
.47972 .69005 L
s
.79522 .80886 m
.78898 .82171 L
s
.45693 .66904 m
.4614 .65283 L
s
.34138 .47109 m
.32128 .47008 L
s
.51055 .61825 m
.50777 .60808 L
s
.45997 .67774 m
.4653 .66094 L
s
.42529 .60207 m
.42294 .59039 L
s
.34993 .48599 m
.33212 .48375 L
s
.34144 .47386 m
.32164 .47279 L
s
.44065 .63674 m
.44183 .62278 L
s
.55959 .64656 m
.55749 .63749 L
s
.47146 .72181 m
.48127 .70197 L
s
.57744 .65721 m
.57544 .64882 L
s
.44147 .57909 m
.4361 .56949 L
s
.43136 .57184 m
.42533 .56261 L
s
.44193 .64334 m
.44373 .62899 L
s
.4728 .81081 m
.49361 .7842 L
s
.36481 .50727 m
.35019 .50325 L
s
.3754 .52697 m
.36354 .52132 L
s
.47256 .79843 m
.49167 .77284 L
s
.45237 .67303 m
.45713 .65669 L
s
.42847 .618 m
.42759 .60546 L
s
.42656 .61435 m
.42529 .60207 L
s
.46209 .70455 m
.47008 .68602 L
s
.47242 .78006 m
.4891 .75593 L
s
.44771 .66355 m
.45149 .64789 L
s
.37125 .51677 m
.35797 .512 L
s
.36995 .5216 m
.35718 .5166 L
s
.47315 .60077 m
.46912 .59051 L
s
.29211 .407 m
.25972 .41345 L
s
.45938 .70471 m
.46737 .68622 L
s
.39954 .56656 m
.39281 .55779 L
s
.40514 .57604 m
.39954 .56656 L
s
.44287 .65756 m
.44598 .6424 L
s
.53874 .63733 m
.536 .62745 L
s
.40962 .58619 m
.40514 .57604 L
s
.39281 .55779 m
.38489 .54982 L
s
.32511 .45893 m
.30215 .46021 L
s
.54766 .64264 m
.54496 .63296 L
s
.46604 .75414 m
.47958 .7321 L
s
.46206 .82798 m
.48571 .80024 L
s
.43822 .65139 m
.44065 .63674 L
s
.39667 .56531 m
.38964 .5568 L
s
.40254 .57455 m
.39667 .56531 L
s
.45091 .68613 m
.45693 .66904 L
s
.4073 .58449 m
.40254 .57455 L
s
.4645 .80585 m
.48486 .77987 L
s
.506 .6202 m
.50267 .60981 L
s
.54077 .63923 m
.53793 .62934 L
s
.41301 .59697 m
.40962 .58619 L
s
.50798 .62141 m
.50466 .61103 L
s
.45298 .69546 m
.45997 .67774 L
s
.4267 .62724 m
.42656 .61435 L
s
.46058 .72916 m
.47124 .70902 L
s
.4282 .63116 m
.42847 .618 L
s
.43698 .58133 m
.43136 .57184 L
s
.29612 .41777 m
.26546 .42363 L
s
.38964 .5568 m
.38143 .54912 L
s
.38489 .54982 m
.37575 .54275 L
s
.77813 .79845 m
.77149 .80776 L
s
.41095 .59506 m
.4073 .58449 L
s
.43883 .6584 m
.44193 .64334 L
s
.56327 .6525 m
.56052 .6432 L
s
.27959 .39402 m
.24412 .40269 L
s
.56606 .6544 m
.56327 .64517 L
s
.44661 .58889 m
.44147 .57909 L
s
.45919 .74286 m
.47146 .72181 L
s
.36354 .52132 m
.35023 .51703 L
s
.41529 .60837 m
.41301 .59697 L
s
.38143 .54912 m
.37198 .54239 L
s
.4135 .60626 m
.41095 .59506 L
s
.31609 .45241 m
.29152 .4551 L
s
.34427 .49457 m
.32678 .49299 L
s
.44598 .6902 m
.45237 .67303 L
s
.54477 .64327 m
.54168 .63334 L
s
.44242 .67996 m
.44771 .66355 L
s
.54669 .64445 m
.54359 .63456 L
s
.37575 .54275 m
.36533 .53673 L
s
.34056 .49063 m
.32235 .48958 L
s
.35797 .512 m
.34319 .50871 L
s
.45198 .72409 m
.46209 .70455 L
s
.50379 .62189 m
.50011 .61139 L
s
.77281 .79581 m
.76584 .80389 L
s
.43831 .67342 m
.44287 .65756 L
s
.35718 .5166 m
.34292 .51313 L
s
.35019 .50325 m
.33397 .50097 L
s
.42563 .64074 m
.4267 .62724 L
s
.56096 .6532 m
.55783 .64363 L
s
.4267 .64492 m
.4282 .63116 L
s
.41643 .62037 m
.41529 .60837 L
s
.4344 .6667 m
.43822 .65139 L
s
.41491 .61806 m
.4135 .60626 L
s
.5211 .63195 m
.51755 .62152 L
s
.44924 .72414 m
.45938 .70471 L
s
.57567 .66202 m
.57251 .65292 L
s
.28267 .40664 m
.24913 .41492 L
s
.44696 .83875 m
.4728 .81081 L
s
.45173 .8055 m
.47242 .78006 L
s
.44885 .82534 m
.47256 .79843 L
s
.37198 .54239 m
.36126 .53676 L
s
.51425 .62876 m
.51055 .61825 L
s
.44306 .70402 m
.45091 .68613 L
s
.33212 .48375 m
.31244 .48395 L
s
.43426 .67411 m
.43883 .6584 L
s
.77452 .79863 m
.76694 .80646 L
s
.44237 .59103 m
.43698 .58133 L
s
.39288 .57725 m
.38669 .56867 L
s
.39796 .58657 m
.39288 .57725 L
s
.444 .71402 m
.45298 .69546 L
s
.40192 .59657 m
.39796 .58657 L
s
.38669 .56867 m
.37935 .5609 L
s
.44922 .77729 m
.46604 .75414 L
s
.58085 .66625 m
.57744 .65721 L
s
.56307 .65624 m
.55959 .64656 L
s
.36533 .53673 m
.35361 .53195 L
s
.39087 .57654 m
.38449 .56816 L
s
.39612 .58568 m
.39087 .57654 L
s
.32128 .47008 m
.29913 .47201 L
s
.44726 .75028 m
.46058 .72916 L
s
.41639 .63293 m
.41643 .62037 L
s
.40025 .59551 m
.39612 .58568 L
s
.41516 .63042 m
.41491 .61806 L
s
.47759 .61125 m
.47315 .60077 L
s
.30068 .44015 m
.27313 .44543 L
s
.40476 .60719 m
.40192 .59657 L
s
.38449 .56816 m
.37698 .56062 L
s
.32164 .47279 m
.29983 .47462 L
s
.37935 .5609 m
.37085 .55406 L
s
.42323 .65481 m
.42563 .64074 L
s
.40328 .60597 m
.40025 .59551 L
s
.35023 .51703 m
.33547 .51442 L
s
.43537 .69706 m
.44242 .67996 L
s
.42384 .65925 m
.4267 .64492 L
s
.43768 .70809 m
.44598 .6902 L
s
.82033 .83837 m
.80907 .85156 L
s
.45174 .59888 m
.44661 .58889 L
s
.43929 .8328 m
.4645 .80585 L
s
.44393 .76484 m
.45919 .74286 L
s
.43207 .68992 m
.43831 .67342 L
s
.37698 .56062 m
.3683 .55402 L
s
.40647 .61841 m
.40476 .60719 L
s
.36126 .53676 m
.34926 .53246 L
s
.429 .6826 m
.4344 .6667 L
s
.43278 .85649 m
.46206 .82798 L
s
.76055 .78946 m
.753 .79496 L
s
.40517 .61704 m
.40328 .60597 L
s
.37085 .55406 m
.36117 .54829 L
s
.4393 .74439 m
.45198 .72409 L
s
.41415 .64333 m
.41516 .63042 L
s
.41509 .64603 m
.41639 .63293 L
s
.34319 .50871 m
.32693 .5073 L
s
.54279 .64774 m
.53874 .63733 L
s
.78744 .81208 m
.77792 .82048 L
s
.428 .69039 m
.43426 .67411 L
s
.34292 .51313 m
.32718 .51156 L
s
.5103 .63094 m
.506 .6202 L
s
.55173 .6529 m
.54766 .64264 L
s
.51228 .63216 m
.50798 .62141 L
s
.43655 .74428 m
.44924 .72414 L
s
.407 .63018 m
.40647 .61841 L
s
.3683 .55402 m
.35846 .54853 L
s
.43305 .72254 m
.44306 .70402 L
s
.40589 .62865 m
.40517 .61704 L
s
.54495 .64966 m
.54077 .63923 L
s
.35361 .53195 m
.34059 .52869 L
s
.38515 .58251 m
.37903 .57446 L
s
.39017 .59132 m
.38515 .58251 L
s
.39409 .60083 m
.39017 .59132 L
s
.41939 .66938 m
.42323 .65481 L
s
.7886 .8139 m
.77864 .82211 L
s
.56749 .66243 m
.56327 .6525 L
s
.43267 .7332 m
.444 .71402 L
s
.33397 .50097 m
.31619 .50091 L
s
.37903 .57446 m
.37181 .56727 L
s
.38877 .59091 m
.38365 .58224 L
s
.3928 .60028 m
.38877 .59091 L
s
.44775 .60093 m
.44237 .59103 L
s
.38365 .58224 m
.37742 .57435 L
s
.41948 .67408 m
.42384 .65925 L
s
.32678 .49299 m
.30761 .49397 L
s
.39689 .61096 m
.39409 .60083 L
s
.57034 .66428 m
.56606 .6544 L
s
.39572 .61029 m
.3928 .60028 L
s
.37742 .57435 m
.3701 .56733 L
s
.36117 .54829 m
.3503 .54377 L
s
.89822 .91114 m
.87884 .93471 L
s
.41181 .6567 m
.41415 .64333 L
s
.41242 .65959 m
.41509 .64603 L
s
.4263 .71466 m
.43537 .69706 L
s
.37181 .56727 m
.36347 .56105 L
s
.32235 .48958 m
.30243 .49128 L
s
.40629 .64245 m
.407 .63018 L
s
.39856 .62168 m
.39689 .61096 L
s
.42625 .83133 m
.45173 .8055 L
s
.40538 .64076 m
.40589 .62865 L
s
.43078 .77194 m
.44726 .75028 L
s
.54928 .65378 m
.54477 .64327 L
s
.42393 .70689 m
.43207 .68992 L
s
.42716 .72647 m
.43768 .70809 L
s
.55121 .65494 m
.54669 .64445 L
s
.34926 .53246 m
.33599 .52976 L
s
.3975 .62088 m
.39572 .61029 L
s
.4218 .69897 m
.429 .6826 L
s
.50848 .63277 m
.50379 .62189 L
s
.42851 .80091 m
.44922 .77729 L
s
.30215 .46021 m
.2771 .46537 L
s
.3701 .56733 m
.36168 .56131 L
s
.35846 .54853 m
.34744 .54434 L
s
.81525 .83797 m
.8027 .84891 L
s
.56561 .66341 m
.56096 .6532 L
s
.41965 .85234 m
.44885 .82534 L
s
.7626 .79469 m
.75356 .79922 L
s
.58037 .67179 m
.57567 .66202 L
s
.33547 .51442 m
.3193 .51391 L
s
.39905 .6329 m
.39856 .62168 L
s
.41513 .86654 m
.44696 .83875 L
s
.4571 .60906 m
.45174 .59888 L
s
.41984 .70708 m
.428 .69039 L
s
.5259 .64286 m
.5211 .63195 L
s
.39812 .63198 m
.3975 .62088 L
s
.38065 .59012 m
.37506 .58228 L
s
.38516 .59871 m
.38065 .59012 L
s
.36347 .56105 m
.35404 .55597 L
s
.42515 .78717 m
.44393 .76484 L
s
.41394 .68434 m
.41939 .66938 L
s
.3886 .60797 m
.38516 .59871 L
s
.51912 .63972 m
.51425 .62876 L
s
.37506 .58228 m
.3684 .57528 L
s
.37954 .59011 m
.3739 .58239 L
s
.38411 .59859 m
.37954 .59011 L
s
.48269 .62197 m
.47759 .61125 L
s
.38761 .60774 m
.38411 .59859 L
s
.40427 .65513 m
.40629 .64245 L
s
.42364 .76504 m
.4393 .74439 L
s
.40357 .65331 m
.40538 .64076 L
s
.58582 .67597 m
.58085 .66625 L
s
.41347 .68927 m
.41948 .67408 L
s
.39093 .61782 m
.3886 .60797 L
s
.36168 .56131 m
.35217 .55643 L
s
.78411 .81339 m
.77317 .8199 L
s
.3739 .58239 m
.3672 .57551 L
s
.40801 .67046 m
.41181 .6567 L
s
.81602 .84025 m
.80271 .85063 L
s
.39001 .6175 m
.38761 .60774 L
s
.31244 .48395 m
.29106 .48733 L
s
.3503 .54377 m
.33827 .54073 L
s
.40828 .67353 m
.41242 .65959 L
s
.34059 .52869 m
.32632 .52725 L
s
.42054 .74138 m
.43305 .72254 L
s
.56811 .66659 m
.56307 .65624 L
s
.26026 .40194 m
.22357 .41498 L
s
.3684 .57528 m
.3607 .56924 L
s
.42088 .76468 m
.43655 .74428 L
s
.39832 .64458 m
.39905 .6329 L
s
.39752 .64354 m
.39812 .63198 L
s
.39212 .62821 m
.39093 .61782 L
s
.3672 .57551 m
.35946 .56961 L
s
.77283 .80509 m
.7623 .81001 L
s
.32693 .5073 m
.30928 .5083 L
s
.39127 .62779 m
.39001 .6175 L
s
.41863 .7526 m
.43267 .7332 L
s
.29152 .4551 m
.26485 .46226 L
s
.32718 .51156 m
.31009 .51236 L
s
.34744 .54434 m
.3353 .54169 L
s
.40838 .85922 m
.43929 .8328 L
s
.35404 .55597 m
.34353 .55219 L
s
.41491 .73247 m
.4263 .71466 L
s
.41257 .71556 m
.4218 .69897 L
s
.4534 .61103 m
.44775 .60093 L
s
.41362 .72408 m
.42393 .70689 L
s
.37808 .59927 m
.37332 .5914 L
s
.3818 .60783 m
.37808 .59927 L
s
.3607 .56924 m
.35196 .5643 L
s
.37332 .5914 m
.36753 .58432 L
s
.39214 .63906 m
.39212 .62821 L
s
.38444 .617 m
.3818 .60783 L
s
.37726 .59942 m
.37248 .59164 L
s
.381 .6079 m
.37726 .59942 L
s
.40038 .66617 m
.40357 .65331 L
s
.40084 .66814 m
.40427 .65513 L
s
.78886 .81925 m
.7768 .8256 L
s
.33599 .52976 m
.32152 .529 L
s
.41408 .74499 m
.42716 .72647 L
s
.37248 .59164 m
.36668 .58465 L
s
.35217 .55643 m
.3416 .5529 L
s
.39137 .63853 m
.39127 .62779 L
s
.38366 .61699 m
.381 .6079 L
s
.35946 .56961 m
.35069 .56482 L
s
.39628 .6566 m
.39832 .64458 L
s
.36753 .58432 m
.36073 .57813 L
s
.29913 .47201 m
.27519 .47783 L
s
.40672 .69951 m
.41394 .68434 L
s
.39563 .65545 m
.39752 .64354 L
s
.38598 .62671 m
.38444 .617 L
s
.29983 .47462 m
.27628 .48029 L
s
.40264 .68445 m
.40801 .67046 L
s
.36668 .58465 m
.35987 .57856 L
s
.40953 .7239 m
.41984 .70708 L
s
.38524 .62662 m
.38366 .61699 L
s
.85602 .87791 m
.83812 .89249 L
s
.40251 .68768 m
.40828 .67353 L
s
.54839 .65877 m
.54279 .64774 L
s
.51584 .64213 m
.5103 .63094 L
s
.39692 .88372 m
.43278 .85649 L
s
.4056 .70462 m
.41347 .68927 L
s
.41065 .79341 m
.43078 .77194 L
s
.31619 .50091 m
.29702 .50369 L
s
.55742 .66382 m
.55173 .6529 L
s
.51787 .64337 m
.51228 .63216 L
s
.39093 .65026 m
.39214 .63906 L
s
.36073 .57813 m
.35294 .57296 L
s
.25972 .41345 m
.22453 .42687 L
s
.38639 .63687 m
.38598 .62671 L
s
.39025 .64964 m
.39137 .63853 L
s
.33827 .54073 m
.32517 .53947 L
s
.55072 .66073 m
.54495 .64966 L
s
.26546 .42363 m
.23223 .43593 L
s
.57338 .67307 m
.56749 .66243 L
s
.35196 .5643 m
.34223 .56062 L
s
.38568 .6367 m
.38524 .62662 L
s
.35987 .57856 m
.35209 .57348 L
s
.57629 .67486 m
.57034 .66428 L
s
.37201 .60186 m
.36728 .5946 L
s
.37573 .60982 m
.37201 .60186 L
s
.37842 .61839 m
.37573 .60982 L
s
.34353 .55219 m
.332 .54996 L
s
.35069 .56482 m
.34095 .56131 L
s
.36728 .5946 m
.36157 .58814 L
s
.30761 .49397 m
.28701 .49821 L
s
.4033 .82387 m
.42851 .80091 L
s
.39569 .67922 m
.40038 .66617 L
s
.78898 .82171 m
.77593 .82718 L
s
.39287 .66886 m
.39628 .6566 L
s
.3959 .68131 m
.40084 .66814 L
s
.39237 .66759 m
.39563 .65545 L
s
.80425 .83457 m
.79001 .84177 L
s
.3193 .51391 m
.3019 .51601 L
s
.46299 .61947 m
.4571 .60906 L
s
.38005 .62749 m
.37842 .61839 L
s
.40521 .76001 m
.42054 .74138 L
s
.3353 .54169 m
.32212 .54087 L
s
.38562 .64739 m
.38639 .63687 L
s
.77149 .80776 m
.7595 .81117 L
s
.40456 .7853 m
.42364 .76504 L
s
.32632 .52725 m
.31093 .52805 L
s
.3416 .5529 m
.33004 .55094 L
s
.36157 .58814 m
.35491 .58259 L
s
.35294 .57296 m
.34421 .56895 L
s
.38495 .64714 m
.38568 .6367 L
s
.40233 .80888 m
.42515 .78717 L
s
.39525 .85591 m
.42625 .83133 L
s
.38843 .66172 m
.39093 .65026 L
s
.55545 .66497 m
.54928 .65378 L
s
.55741 .6661 m
.55121 .65494 L
s
.51448 .64411 m
.50848 .63277 L
s
.38784 .661 m
.39025 .64964 L
s
.40109 .73204 m
.41257 .71556 L
s
.35209 .57348 m
.34338 .56958 L
s
.58678 .68227 m
.58037 .67179 L
s
.38059 .63702 m
.38005 .62749 L
s
.30243 .49128 m
.2811 .49649 L
s
.76584 .80389 m
.75394 .80646 L
s
.39556 .69847 m
.40264 .68445 L
s
.40183 .7846 m
.42088 .76468 L
s
.40089 .74108 m
.41362 .72408 L
s
.57199 .67433 m
.56561 .66341 L
s
.36804 .60532 m
.36354 .59843 L
s
.37157 .61289 m
.36804 .60532 L
s
.39754 .71461 m
.40672 .69951 L
s
.40152 .77161 m
.41863 .7526 L
s
.40092 .75002 m
.41491 .73247 L
s
.3741 .62106 m
.37157 .61289 L
s
.27313 .44543 m
.24353 .45635 L
s
.395 .70181 m
.40251 .68768 L
s
.36354 .59843 m
.35811 .59232 L
s
.35491 .58259 m
.34735 .57807 L
s
.34223 .56062 m
.33158 .55843 L
s
.4888 .63304 m
.48269 .62197 L
s
.5925 .6864 m
.58582 .67597 L
s
.37559 .62972 m
.3741 .62106 L
s
.38362 .65815 m
.38562 .64739 L
s
.39572 .71982 m
.4056 .70462 L
s
.37999 .64688 m
.38059 .63702 L
s
.383 .65782 m
.38495 .64714 L
s
.53225 .65435 m
.5259 .64286 L
s
.39815 .76306 m
.41408 .74499 L
s
.35811 .59232 m
.35177 .58711 L
s
.34095 .56131 m
.33031 .55929 L
s
.39683 .74041 m
.40953 .7239 L
s
.388 .68118 m
.39287 .66886 L
s
.38767 .67981 m
.39237 .66759 L
s
.753 .79496 m
.74146 .79581 L
s
.52548 .65123 m
.51912 .63972 L
s
.32152 .529 m
.30603 .53058 L
s
.38421 .87726 m
.41965 .85234 L
s
.38941 .69225 m
.39569 .67922 L
s
.37603 .63879 m
.37559 .62972 L
s
.45962 .62137 m
.4534 .61103 L
s
.34421 .56895 m
.3346 .56629 L
s
.24412 .40269 m
.2058 .41967 L
s
.38933 .69445 m
.3959 .68131 L
s
.76694 .80646 m
.75434 .80857 L
s
.30928 .5083 m
.29046 .5123 L
s
.38457 .67327 m
.38843 .66172 L
s
.57493 .67767 m
.56811 .66659 L
s
.36503 .60944 m
.36089 .60279 L
s
.36823 .61673 m
.36503 .60944 L
s
.38408 .67246 m
.38784 .661 L
s
.31009 .51236 m
.29186 .5161 L
s
.37046 .62458 m
.36823 .61673 L
s
.34338 .56958 m
.3338 .56703 L
s
.80808 .84077 m
.79225 .84722 L
s
.332 .54996 m
.31957 .54954 L
s
.36089 .60279 m
.35585 .5969 L
s
.34735 .57807 m
.33893 .57474 L
s
.32517 .53947 m
.31113 .54033 L
s
.35177 .58711 m
.34458 .58292 L
s
.37169 .63289 m
.37046 .62458 L
s
.37821 .65695 m
.37999 .64688 L
s
.24913 .41492 m
.21306 .43094 L
s
.37536 .64815 m
.37603 .63879 L
s
.35585 .5969 m
.34995 .59187 L
s
.37654 .89161 m
.41513 .86654 L
s
.38032 .66901 m
.38362 .65815 L
s
.33004 .55094 m
.31762 .55083 L
s
.37976 .66859 m
.383 .65782 L
s
.93596 .95754 m
.90722 .98176 L
s
.83396 .86407 m
.81545 .87319 L
s
.37189 .64156 m
.37169 .63289 L
s
.36269 .61399 m
.359 .60751 L
s
.36547 .62108 m
.36269 .61399 L
s
.29106 .48733 m
.26837 .49478 L
s
.38664 .71222 m
.39556 .69847 L
s
.359 .60751 m
.35444 .60173 L
s
.3673 .62868 m
.36547 .62108 L
s
.2771 .46537 m
.25046 .47564 L
s
.32212 .54087 m
.30806 .54223 L
s
.34995 .59187 m
.34323 .58782 L
s
.38561 .71562 m
.395 .70181 L
s
.33158 .55843 m
.32012 .55794 L
s
.38646 .81351 m
.41065 .79341 L
s
.38145 .69188 m
.38767 .67981 L
s
.35444 .60173 m
.34904 .59675 L
s
.36816 .63668 m
.3673 .62868 L
s
.38158 .69334 m
.388 .68118 L
s
.34458 .58292 m
.3366 .57988 L
s
.38627 .72925 m
.39754 .71461 L
s
.37356 .65768 m
.37536 .64815 L
s
.37928 .68474 m
.38457 .67327 L
s
.38716 .74787 m
.40109 .73204 L
s
.37891 .68384 m
.38408 .67246 L
s
.84957 .87883 m
.82915 .88947 L
s
.3752 .6671 m
.37821 .65695 L
s
.37101 .65046 m
.37189 .64156 L
s
.3346 .56629 m
.32422 .56517 L
s
.33893 .57474 m
.32974 .57276 L
s
.38678 .77767 m
.40521 .76001 L
s
.33031 .55929 m
.31889 .559 L
s
.36077 .61883 m
.35759 .61244 L
s
.36306 .62576 m
.36077 .61883 L
s
.35945 .57988 m
.35086 .57589 L
s
.36745 .58474 m
.35945 .57988 L
s
.38144 .70498 m
.38941 .69225 L
s
.35759 .61244 m
.35356 .6067 L
s
.37493 .59032 m
.36745 .58474 L
s
.3338 .56703 m
.32347 .56603 L
s
.38554 .75727 m
.40089 .74108 L
s
.36802 .64498 m
.36816 .63668 L
s
.38105 .70725 m
.38933 .69445 L
s
.36443 .63313 m
.36306 .62576 L
s
.34904 .59675 m
.34287 .5927 L
s
.31093 .52805 m
.29467 .53154 L
s
.38367 .73443 m
.39572 .71982 L
s
.55583 .67056 m
.54839 .65877 L
s
.3757 .67979 m
.38032 .66901 L
s
.35356 .6067 m
.34872 .60171 L
s
.37112 .88263 m
.40838 .85922 L
s
.29702 .50369 m
.27679 .51003 L
s
.56497 .67551 m
.55742 .66382 L
s
.52298 .65393 m
.51584 .64213 L
s
.3752 .67928 m
.37976 .66859 L
s
.38412 .76661 m
.40092 .75002 L
s
.58115 .68449 m
.57338 .67307 L
s
.34323 .58782 m
.33578 .58487 L
s
.35086 .57589 m
.34166 .57295 L
s
.58412 .68622 m
.57629 .67486 L
s
.52507 .6552 m
.51787 .64337 L
s
.46977 .6302 m
.46299 .61947 L
s
.75356 .79922 m
.74045 .7988 L
s
.382 .59647 m
.37493 .59032 L
s
.36484 .64085 m
.36443 .63313 L
s
.38173 .80408 m
.40456 .7853 L
s
.3019 .51601 m
.28358 .52128 L
s
.36904 .65948 m
.37101 .65046 L
s
.55835 .67258 m
.55072 .66073 L
s
.35643 .61752 m
.35297 .61178 L
s
.35905 .62384 m
.35643 .61752 L
s
.37058 .66724 m
.37356 .65768 L
s
.34872 .60171 m
.34312 .59757 L
s
.36081 .63063 m
.35905 .62384 L
s
.36683 .65345 m
.36802 .64498 L
s
.38156 .75602 m
.39683 .74041 L
s
.38107 .78928 m
.40152 .77161 L
s
.35297 .61178 m
.34872 .60672 L
s
.3366 .57988 m
.32793 .57816 L
s
.34287 .5927 m
.33598 .58969 L
s
.31957 .54954 m
.30643 .55124 L
s
.36167 .6378 m
.36081 .63063 L
s
.37908 .80292 m
.40183 .7846 L
s
.37094 .67713 m
.3752 .6671 L
s
.36428 .6488 m
.36484 .64085 L
s
.59506 .69352 m
.58678 .68227 L
s
.34872 .60672 m
.34373 .60244 L
s
.37317 .8444 m
.4033 .82387 L
s
.37914 .77984 m
.39815 .76306 L
s
.37509 .82848 m
.40233 .80888 L
s
.34166 .57295 m
.33187 .57126 L
s
.35535 .62268 m
.35249 .61693 L
s
.35739 .62894 m
.35535 .62268 L
s
.35249 .61693 m
.34885 .61178 L
s
.34312 .59757 m
.33684 .59439 L
s
.37252 .69586 m
.37928 .68474 L
s
.37363 .70353 m
.38145 .69188 L
s
.3616 .64524 m
.36167 .6378 L
s
.37228 .69488 m
.37891 .68384 L
s
.37356 .70506 m
.38158 .69334 L
s
.35858 .63559 m
.35739 .62894 L
s
.37579 .72528 m
.38664 .71222 L
s
.3888 .60308 m
.382 .59647 L
s
.32974 .57276 m
.31992 .57232 L
s
.77792 .82048 m
.76239 .82178 L
s
.31762 .55083 m
.30453 .55286 L
s
.30603 .53058 m
.28979 .53498 L
s
.27519 .47783 m
.25005 .48865 L
s
.60106 .69757 m
.5925 .6864 L
s
.33578 .58487 m
.32768 .58317 L
s
.28701 .49821 m
.26542 .50654 L
s
.27628 .48029 m
.25156 .49087 L
s
.34885 .61178 m
.34448 .60733 L
s
.36459 .66197 m
.36683 .65345 L
s
.36594 .66846 m
.36904 .65948 L
s
.31113 .54033 m
.29639 .54367 L
s
.56356 .67696 m
.55545 .66497 L
s
.58032 .68608 m
.57199 .67433 L
s
.56556 .67808 m
.55741 .6661 L
s
.34373 .60244 m
.33806 .59904 L
s
.26485 .46226 m
.2368 .47529 L
s
.36969 .69025 m
.3757 .67979 L
s
.36272 .65684 m
.36428 .6488 L
s
.32422 .56517 m
.31322 .56581 L
s
.3589 .64255 m
.35858 .63559 L
s
.36927 .68966 m
.3752 .67928 L
s
.52216 .65611 m
.51448 .64411 L
s
.32012 .55794 m
.30803 .55942 L
s
.37425 .72866 m
.38561 .71562 L
s
.36641 .67663 m
.37058 .66724 L
s
.35195 .62212 m
.34894 .61688 L
s
.3542 .62787 m
.35195 .62212 L
s
.36058 .65282 m
.3616 .64524 L
s
.35565 .63405 m
.3542 .62787 L
s
.33598 .58969 m
.32848 .58785 L
s
.32347 .56603 m
.31254 .56679 L
s
.34448 .60733 m
.33943 .60368 L
s
.46679 .63206 m
.45962 .62137 L
s
.34894 .61688 m
.3452 .61226 L
s
.37171 .71706 m
.38144 .70498 L
s
.49629 .64462 m
.4888 .63304 L
s
.31889 .559 m
.30687 .56069 L
s
.77864 .82211 m
.76257 .82307 L
s
.35626 .64055 m
.35565 .63405 L
s
.371 .71934 m
.38105 .70725 L
s
.37279 .74288 m
.38627 .72925 L
s
.35831 .64968 m
.3589 .64255 L
s
.33684 .59439 m
.32995 .5923 L
s
.35386 .9063 m
.39692 .88372 L
s
.3452 .61226 m
.34078 .60836 L
s
.32793 .57816 m
.31869 .57793 L
s
.36539 .68684 m
.37094 .67713 L
s
.35126 .62729 m
.34888 .62199 L
s
.35289 .63303 m
.35126 .62729 L
s
.34888 .62199 m
.34577 .61723 L
s
.30806 .54223 m
.2934 .54614 L
s
.33806 .59904 m
.33179 .59663 L
s
.33187 .57126 m
.32157 .57101 L
s
.36014 .66484 m
.36272 .65684 L
s
.35602 .64726 m
.35626 .64055 L
s
.36127 .67036 m
.36459 .66197 L
s
.2811 .49649 m
.25888 .50609 L
s
.35373 .6391 m
.35289 .63303 L
s
.58376 .68959 m
.57493 .67767 L
s
.33943 .60368 m
.33378 .60093 L
s
.54049 .66662 m
.53225 .65435 L
s
.34577 .61723 m
.34199 .61309 L
s
.3586 .66042 m
.36058 .65282 L
s
.37065 .76233 m
.38716 .74787 L
s
.29186 .5161 m
.27292 .5234 L
s
.35828 .87663 m
.39525 .85591 L
s
.3617 .67721 m
.36594 .66846 L
s
.29046 .5123 m
.2709 .51997 L
s
.34078 .60836 m
.33575 .60526 L
s
.53369 .66348 m
.52548 .65123 L
s
.7623 .81001 m
.74699 .80901 L
s
.35681 .65687 m
.35831 .64968 L
s
.36937 .74785 m
.38367 .73443 L
s
.35377 .64541 m
.35373 .6391 L
s
.39554 .61007 m
.3888 .60308 L
s
.34857 .62709 m
.3461 .6222 L
s
.35033 .63242 m
.34857 .62709 L
s
.32768 .58317 m
.31906 .58288 L
s
.34199 .61309 m
.33759 .60966 L
s
.3461 .6222 m
.34295 .61786 L
s
.35134 .63809 m
.35033 .63242 L
s
.35491 .65406 m
.35602 .64726 L
s
.36416 .70527 m
.37228 .69488 L
s
.36425 .70632 m
.37252 .69586 L
s
.36102 .68565 m
.36641 .67663 L
s
.34295 .61786 m
.33918 .61414 L
s
.32848 .58785 m
.32048 .58731 L
s
.36743 .77183 m
.38554 .75727 L
s
.35159 .64401 m
.35134 .63809 L
s
.36421 .71439 m
.37363 .70353 L
s
.31992 .57232 m
.30962 .57361 L
s
.36229 .70012 m
.36969 .69025 L
s
.32995 .5923 m
.32256 .59141 L
s
.35297 .65183 m
.35377 .64541 L
s
.34612 .62716 m
.3436 .62266 L
s
.34796 .63212 m
.34612 .62716 L
s
.36196 .69946 m
.36927 .68966 L
s
.3639 .71595 m
.37356 .70506 L
s
.33179 .59663 m
.325 .59533 L
s
.3491 .63743 m
.34796 .63212 L
s
.33378 .60093 m
.3276 .59919 L
s
.33575 .60526 m
.33019 .60308 L
s
.3436 .62266 m
.34046 .6187 L
s
.33759 .60966 m
.33263 .60705 L
s
.36509 .79323 m
.38678 .77767 L
s
.35564 .66787 m
.3586 .66042 L
s
.35654 .67263 m
.36014 .66484 L
s
.77317 .8199 m
.75655 .81946 L
s
.33918 .61414 m
.33484 .61115 L
s
.35439 .66398 m
.35681 .65687 L
s
.34951 .64299 m
.3491 .63743 L
s
.35105 .65007 m
.35159 .64401 L
s
.35688 .67844 m
.36127 .67036 L
s
.34046 .6187 m
.33673 .61536 L
s
.36438 .78129 m
.38412 .76661 L
s
.35293 .66081 m
.35491 .65406 L
s
.30643 .55124 m
.29284 .55537 L
s
.34389 .62746 m
.34136 .6233 L
s
.34578 .63206 m
.34389 .62746 L
s
.347 .63703 m
.34578 .63206 L
s
.36297 .73714 m
.37579 .72528 L
s
.35856 .69596 m
.36539 .68684 L
s
.36365 .76987 m
.38156 .75602 L
s
.34136 .6233 m
.33825 .61968 L
s
.29467 .53154 m
.27791 .53821 L
s
.34917 .64871 m
.34951 .64299 L
s
.35134 .65824 m
.35297 .65183 L
s
.31322 .56581 m
.30181 .56845 L
s
.34754 .64226 m
.347 .63703 L
s
.35633 .68551 m
.3617 .67721 L
s
.32157 .57101 m
.31089 .57243 L
s
.33484 .61115 m
.33 .60896 L
s
.31869 .57793 m
.30906 .57934 L
s
.33673 .61536 m
.33248 .61274 L
s
.358 .83052 m
.38646 .81351 L
s
.34972 .65615 m
.35105 .65007 L
s
.33263 .60705 m
.32721 .60535 L
s
.34377 .6322 m
.34186 .62791 L
s
.34505 .63685 m
.34377 .6322 L
s
.31254 .56679 m
.30123 .56954 L
s
.34186 .62791 m
.33935 .62406 L
s
.33825 .61968 m
.33459 .61668 L
s
.34736 .64766 m
.34754 .64226 L
s
.36022 .728 m
.37171 .71706 L
s
.3609 .74038 m
.37425 .72866 L
s
.33019 .60308 m
.32418 .60189 L
s
.74146 .79581 m
.72665 .79221 L
s
.34568 .64177 m
.34505 .63685 L
s
.30453 .55286 m
.29106 .55735 L
s
.30803 .55942 m
.29557 .56315 L
s
.33935 .62406 m
.33629 .62075 L
s
.34808 .65446 m
.34917 .64871 L
s
.3276 .59919 m
.32102 .59855 L
s
.35915 .73024 m
.371 .71934 L
s
.35105 .67084 m
.35439 .66398 L
s
.59404 .69845 m
.58412 .68622 L
s
.35173 .67501 m
.35564 .66787 L
s
.59102 .69679 m
.58115 .68449 L
s
.31906 .58288 m
.31008 .58413 L
s
.34193 .63248 m
.34002 .62848 L
s
.34325 .63684 m
.34193 .63248 L
s
.34563 .64686 m
.34568 .64177 L
s
.35007 .66738 m
.35293 .66081 L
s
.325 .59533 m
.31784 .59524 L
s
.34002 .62848 m
.33755 .62492 L
s
.35444 .69403 m
.36102 .68565 L
s
.33459 .61668 m
.33047 .61437 L
s
.34394 .64146 m
.34325 .63684 L
s
.47786 .64141 m
.46977 .6302 L
s
.33629 .62075 m
.33274 .61804 L
s
.35193 .68001 m
.35654 .67263 L
s
.32256 .59141 m
.31481 .59185 L
s
.34647 .6531 m
.34736 .64766 L
s
.80907 .85156 m
.78867 .85392 L
s
.34889 .6645 m
.35134 .65824 L
s
.30687 .56069 m
.29453 .56462 L
s
.32048 .58731 m
.31213 .58822 L
s
.33248 .61274 m
.32779 .61091 L
s
.33755 .62492 m
.33457 .62188 L
s
.57469 .68812 m
.56497 .67551 L
s
.35718 .80428 m
.38107 .78928 L
s
.34217 .89674 m
.38421 .87726 L
s
.22357 .41498 m
.18506 .43782 L
s
.34759 .66211 m
.34972 .65615 L
s
.33 .60896 m
.32475 .60766 L
s
.56543 .68326 m
.55583 .67056 L
s
.75394 .80646 m
.73788 .80357 L
s
.34399 .64626 m
.34394 .64146 L
s
.40248 .61737 m
.39554 .61007 L
s
.34024 .63286 m
.33835 .62913 L
s
.34157 .63695 m
.34024 .63286 L
s
.35503 .81979 m
.38173 .80408 L
s
.35698 .79414 m
.37914 .77984 L
s
.3449 .65201 m
.34563 .64686 L
s
.35142 .686 m
.35688 .67844 L
s
.33835 .62913 m
.33594 .62583 L
s
.60538 .70559 m
.59506 .69352 L
s
.29639 .54367 m
.28132 .54991 L
s
.34231 .6413 m
.34157 .63695 L
s
.34624 .66013 m
.34808 .65446 L
s
.7595 .81117 m
.74291 .80864 L
s
.28358 .52128 m
.26484 .53036 L
s
.32721 .60535 m
.32142 .60463 L
s
.35709 .75479 m
.37279 .74288 L
s
.35458 .71465 m
.36416 .70527 L
s
.33457 .62188 m
.33112 .61943 L
s
.26837 .49478 m
.24506 .50728 L
s
.53211 .66655 m
.52298 .65393 L
s
.33274 .61804 m
.32875 .61602 L
s
.35451 .71574 m
.36425 .70632 L
s
.33594 .62583 m
.33304 .62303 L
s
.34244 .64583 m
.34231 .6413 L
s
.35353 .70906 m
.36229 .70012 L
s
.3533 .70832 m
.36196 .69946 L
s
.61159 .70951 m
.60106 .69757 L
s
.34339 .65113 m
.34399 .64626 L
s
.33869 .63333 m
.33684 .62983 L
s
.34001 .63716 m
.33869 .63333 L
s
.33047 .61437 m
.32594 .61285 L
s
.34486 .65848 m
.34647 .6531 L
s
.56817 .68536 m
.55835 .67258 L
s
.53431 .66788 m
.52507 .6552 L
s
.34078 .64126 m
.34001 .63716 L
s
.27679 .51003 m
.2561 .52068 L
s
.7768 .8256 m
.75869 .82442 L
s
.33684 .62983 m
.33449 .62677 L
s
.32418 .60189 m
.31785 .6018 L
s
.28979 .53498 m
.27323 .54266 L
s
.35256 .81809 m
.37908 .80292 L
s
.34097 .64553 m
.34078 .64126 L
s
.32779 .61091 m
.32274 .60995 L
s
.34349 .65711 m
.3449 .65201 L
s
.34985 .69312 m
.35633 .68551 L
s
.34195 .65044 m
.34244 .64583 L
s
.33304 .62303 m
.32971 .62082 L
s
.30962 .57361 m
.29909 .57682 L
s
.3532 .72401 m
.36421 .71439 L
s
.33449 .62677 m
.33169 .62419 L
s
.34636 .67359 m
.35007 .66738 L
s
.33727 .63384 m
.33546 .63058 L
s
.33857 .63744 m
.33727 .63384 L
s
.33112 .61943 m
.32728 .61766 L
s
.34562 .67047 m
.34889 .6645 L
s
.34683 .67728 m
.35105 .67084 L
s
.33935 .64131 m
.33857 .63744 L
s
.33546 .63058 m
.33318 .62772 L
s
.35265 .72555 m
.3639 .71595 L
s
.23223 .43593 m
.19768 .45686 L
s
.35048 .70417 m
.35856 .69596 L
s
.34469 .66782 m
.34759 .66211 L
s
.32102 .59855 m
.31416 .59912 L
s
.34215 .65597 m
.34339 .65113 L
s
.34689 .68164 m
.35173 .67501 L
s
.32875 .61602 m
.3244 .61476 L
s
.33958 .64534 m
.33935 .64131 L
s
.24353 .45635 m
.21295 .47462 L
s
.34057 .64989 m
.34097 .64553 L
s
.32475 .60766 m
.3192 .60733 L
s
.34365 .66558 m
.34624 .66013 L
s
.33169 .62419 m
.32849 .62218 L
s
.33318 .62772 m
.33048 .62535 L
s
.33596 .6344 m
.3342 .63134 L
s
.33724 .63778 m
.33596 .6344 L
s
.33802 .64142 m
.33724 .63778 L
s
.2934 .54614 m
.27852 .55298 L
s
.35282 .7593 m
.36937 .74785 L
s
.59083 .69875 m
.58032 .68608 L
s
.34084 .65502 m
.34195 .65044 L
s
.34255 .66367 m
.34486 .65848 L
s
.3342 .63134 m
.33201 .62868 L
s
.32971 .62082 m
.32603 .61925 L
s
.34635 .68676 m
.35193 .68001 L
s
.31784 .59524 m
.31045 .59647 L
s
.33925 .64946 m
.33958 .64534 L
s
.33828 .64523 m
.33802 .64142 L
s
.32594 .61285 m
.32111 .61217 L
s
.75434 .80857 m
.73751 .80506 L
s
.31089 .57243 m
.30003 .57574 L
s
.34141 .66205 m
.34349 .65711 L
s
.35158 .77447 m
.37065 .76233 L
s
.33475 .63497 m
.33305 .6321 L
s
.336 .63816 m
.33475 .63497 L
s
.33677 .64159 m
.336 .63816 L
s
.33958 .65423 m
.34057 .64989 L
s
.32728 .61766 m
.32312 .61661 L
s
.32142 .60463 m
.31538 .60499 L
s
.33201 .62868 m
.32942 .62648 L
s
.33048 .62535 m
.32742 .62351 L
s
.30906 .57934 m
.29927 .58257 L
s
.33305 .6321 m
.33094 .62962 L
s
.57595 .69103 m
.56556 .67808 L
s
.33801 .64913 m
.33828 .64523 L
s
.57392 .68993 m
.56356 .67696 L
s
.33705 .64519 m
.33677 .64159 L
s
.22453 .42687 m
.18795 .44974 L
s
.34027 .66067 m
.34215 .65597 L
s
.31481 .59185 m
.30687 .59373 L
s
.32849 .62218 m
.32496 .6208 L
s
.34671 .70149 m
.35444 .69403 L
s
.33091 .90998 m
.37654 .89161 L
s
.47536 .64327 m
.46679 .63206 L
s
.33837 .65357 m
.33925 .64946 L
s
.32274 .60995 m
.31745 .60993 L
s
.33364 .63556 m
.33201 .63287 L
s
.33485 .63856 m
.33364 .63556 L
s
.33561 .6418 m
.33485 .63856 L
s
.34496 .69278 m
.35142 .686 L
s
.33094 .62962 m
.32846 .62758 L
s
.33913 .65948 m
.34084 .65502 L
s
.31213 .58822 m
.30363 .59069 L
s
.33683 .64887 m
.33705 .64519 L
s
.8027 .84891 m
.7816 .84945 L
s
.3244 .61476 m
.31979 .61432 L
s
.31008 .58413 m
.30097 .58708 L
s
.32942 .62648 m
.32648 .6248 L
s
.34337 .84383 m
.37509 .82848 L
s
.3359 .6452 m
.33561 .6418 L
s
.33201 .63287 m
.32998 .63054 L
s
.32603 .61925 m
.32205 .61839 L
s
.30181 .56845 m
.2903 .5733 L
s
.33721 .65302 m
.33801 .64913 L
s
.34157 .67597 m
.34562 .67047 L
s
.34105 .67312 m
.34469 .66782 L
s
.31785 .6018 m
.31134 .60289 L
s
.32742 .62351 m
.32405 .62228 L
s
.33378 .63898 m
.33262 .63615 L
s
.33452 .64203 m
.33378 .63898 L
s
.33262 .63615 m
.33105 .63362 L
s
.34036 .67067 m
.34365 .66558 L
s
.33802 .65846 m
.33958 .65423 L
s
.34184 .67927 m
.34636 .67359 L
s
.25046 .47564 m
.22322 .49239 L
s
.33571 .64868 m
.3359 .6452 L
s
.32998 .63054 m
.32761 .62865 L
s
.34825 .74714 m
.36297 .73714 L
s
.33482 .64524 m
.33452 .64203 L
s
.33956 .66854 m
.34255 .66367 L
s
.33105 .63362 m
.32911 .63145 L
s
.53194 .669 m
.52216 .65611 L
s
.32846 .62758 m
.32566 .62605 L
s
.34176 .6831 m
.34683 .67728 L
s
.3361 .65255 m
.33683 .64887 L
s
.30123 .56954 m
.28984 .5745 L
s
.74045 .7988 m
.72413 .79378 L
s
.77593 .82718 m
.75688 .82501 L
s
.33694 .65758 m
.33837 .65357 L
s
.33869 .6667 m
.34141 .66205 L
s
.3192 .60733 m
.31347 .60803 L
s
.34704 .73726 m
.36022 .728 L
s
.59481 .70246 m
.58376 .68959 L
s
.32496 .6208 m
.32117 .62009 L
s
.32312 .61661 m
.31873 .61636 L
s
.32111 .61217 m
.31607 .61241 L
s
.33467 .64854 m
.33482 .64524 L
s
.32648 .6248 m
.32327 .62371 L
s
.50564 .65694 m
.49629 .64462 L
s
.32911 .63145 m
.32685 .62968 L
s
.33777 .66509 m
.34027 .66067 L
s
.34663 .78366 m
.36743 .77183 L
s
.33805 .85996 m
.37317 .8444 L
s
.33505 .65216 m
.33571 .64868 L
s
.32761 .62865 m
.32494 .62724 L
s
.33589 .65681 m
.33721 .65302 L
s
.29284 .55537 m
.27918 .56225 L
s
.34117 .68754 m
.34689 .68164 L
s
.33684 .66369 m
.33913 .65948 L
s
.31416 .59912 m
.30719 .60097 L
s
.34234 .69975 m
.34985 .69312 L
s
.3456 .73935 m
.35915 .73024 L
s
.32566 .62605 m
.32261 .62507 L
s
.33406 .65183 m
.33467 .64854 L
s
.32405 .62228 m
.32045 .6217 L
s
.33488 .65615 m
.3361 .65255 L
s
.34563 .75007 m
.3609 .74038 L
s
.26542 .50654 m
.24359 .51981 L
s
.3359 .66246 m
.33802 .65846 L
s
.32685 .62968 m
.32431 .62838 L
s
.32205 .61839 m
.31788 .61829 L
s
.34336 .71587 m
.3533 .70832 L
s
.34348 .71666 m
.35353 .70906 L
s
.29557 .56315 m
.28309 .56936 L
s
.34361 .72257 m
.35458 .71465 L
s
.31979 .61432 m
.31502 .61474 L
s
.33392 .65557 m
.33505 .65216 L
s
.33498 .66137 m
.33694 .65758 L
s
.31538 .60499 m
.30923 .60648 L
s
.34337 .72367 m
.35451 .71574 L
s
.32494 .62724 m
.32204 .62636 L
s
.31745 .60993 m
.31203 .61091 L
s
.33987 .69266 m
.34635 .68676 L
s
.32327 .62371 m
.31985 .62323 L
s
.3274 .89929 m
.37112 .88263 L
s
.33407 .66041 m
.33589 .65681 L
s
.333 .65505 m
.33406 .65183 L
s
.32117 .62009 m
.31722 .62011 L
s
.40993 .62499 m
.40248 .61737 L
s
.31045 .59647 m
.30302 .59911 L
s
.34123 .71112 m
.35048 .70417 L
s
.33642 .67524 m
.34036 .67067 L
s
.80271 .85063 m
.78081 .85042 L
s
.29106 .55735 m
.2776 .56459 L
s
.33595 .67294 m
.33956 .66854 L
s
.33673 .67785 m
.34105 .67312 L
s
.27292 .5234 m
.2539 .53491 L
s
.55101 .6799 m
.54049 .66662 L
s
.32431 .62838 m
.32155 .62758 L
s
.34318 .7809 m
.36365 .76987 L
s
.33537 .67092 m
.33869 .6667 L
s
.29453 .56462 m
.28221 .57104 L
s
.33319 .65956 m
.33488 .65615 L
s
.32261 .62507 m
.31936 .62468 L
s
.33681 .68083 m
.34157 .67597 L
s
.31873 .61636 m
.31421 .61693 L
s
.33471 .66912 m
.33777 .66509 L
s
.3418 .7928 m
.36438 .78129 L
s
.2709 .51997 m
.25126 .53201 L
s
.334 .66754 m
.33684 .66369 L
s
.33233 .6588 m
.33392 .65557 L
s
.32045 .6217 m
.31671 .62182 L
s
.54418 .67674 m
.53369 .66348 L
s
.33658 .68423 m
.34184 .67927 L
s
.31607 .61241 m
.31096 .61359 L
s
.34024 .80526 m
.36509 .79323 L
s
.32204 .62636 m
.31896 .62604 L
s
.33327 .66612 m
.3359 .66246 L
s
.33153 .65811 m
.333 .65505 L
s
.29909 .57682 m
.28862 .58212 L
s
.31134 .60289 m
.30481 .60522 L
s
.34072 .73187 m
.3532 .72401 L
s
.33253 .66486 m
.33498 .66137 L
s
.33758 .69851 m
.34496 .69278 L
s
.31347 .60803 m
.3077 .60983 L
s
.30687 .59373 m
.29897 .59714 L
s
.31788 .61829 m
.31362 .61898 L
s
.31985 .62323 m
.31631 .62342 L
s
.33592 .6881 m
.34176 .6831 L
s
.32155 .62758 m
.31864 .62733 L
s
.33179 .66372 m
.33407 .66041 L
s
.33794 .7077 m
.34671 .70149 L
s
.33992 .73334 m
.35265 .72555 L
s
.33105 .6627 m
.33319 .65956 L
s
.27791 .53821 m
.26122 .54853 L
s
.31936 .62468 m
.31602 .62492 L
s
.31502 .61474 m
.31021 .61608 L
s
.31722 .62011 m
.3132 .62088 L
s
.33033 .66177 m
.33233 .6588 L
s
.25156 .49087 m
.22662 .5075 L
s
.30363 .59069 m
.29521 .59482 L
s
.30003 .57574 m
.28928 .5811 L
s
.33931 .76411 m
.35709 .75479 L
s
.33466 .69249 m
.34117 .68754 L
s
.32965 .66092 m
.33153 .65811 L
s
.25005 .48865 m
.22469 .50567 L
s
.31896 .62604 m
.3158 .62632 L
s
.29927 .58257 m
.2896 .58774 L
s
.3315 .67457 m
.33537 .67092 L
s
.33113 .67264 m
.33471 .66912 L
s
.31203 .61091 m
.30662 .61292 L
s
.33177 .67673 m
.33595 .67294 L
s
.31671 .62182 m
.31291 .62264 L
s
.30097 .58708 m
.29197 .59182 L
s
.33068 .6709 m
.334 .66754 L
s
.25888 .50609 m
.23662 .52097 L
s
.33189 .67914 m
.33642 .67524 L
s
.31864 .62733 m
.31565 .62764 L
s
.30719 .60097 m
.30029 .60418 L
s
.33017 .66934 m
.33327 .66612 L
s
.31421 .61693 m
.3097 .61837 L
s
.60621 .71161 m
.59404 .69845 L
s
.32964 .66792 m
.33253 .66486 L
s
.33179 .68184 m
.33673 .67785 L
s
.30923 .60648 m
.30315 .60915 L
s
.61783 .71846 m
.60538 .70559 L
s
.62417 .72217 m
.61159 .70951 L
s
.79001 .84177 m
.76842 .83962 L
s
.32908 .66664 m
.33179 .66372 L
s
.60318 .71004 m
.59102 .69679 L
s
.31631 .62342 m
.31274 .62428 L
s
.28132 .54991 m
.26643 .55938 L
s
.32852 .66546 m
.33105 .6627 L
s
.33142 .68487 m
.33681 .68083 L
s
.33391 .7051 m
.34234 .69975 L
s
.32796 .66439 m
.33033 .66177 L
s
.31362 .61898 m
.30938 .62048 L
s
.31602 .62492 m
.31265 .6258 L
s
.3326 .69743 m
.33987 .69266 L
s
.32742 .66341 m
.32965 .66092 L
s
.31096 .61359 m
.30592 .61576 L
s
.3158 .62632 m
.31263 .62721 L
s
.33068 .68827 m
.33658 .68423 L
s
.3132 .62088 m
.30922 .62242 L
s
.31565 .62764 m
.31266 .62852 L
s
.30302 .59911 m
.29577 .60321 L
s
.3077 .60983 m
.30206 .61274 L
s
.31021 .61608 m
.3055 .61834 L
s
.33422 .76787 m
.35282 .7593 L
s
.31291 .62264 m
.30918 .6242 L
s
.2903 .5733 m
.27905 .58054 L
s
.32668 .67199 m
.33017 .66934 L
s
.32694 .67367 m
.33068 .6709 L
s
.32637 .67046 m
.32964 .66792 L
s
.58683 .70182 m
.57469 .68812 L
s
.32712 .67551 m
.33113 .67264 L
s
.32943 .69205 m
.33592 .6881 L
s
.32602 .66906 m
.32908 .66664 L
s
.33185 .80446 m
.35698 .79414 L
s
.33231 .72168 m
.34336 .71587 L
s
.30481 .60522 m
.29846 .60883 L
s
.32565 .66777 m
.32852 .66546 L
s
.32719 .67753 m
.3315 .67457 L
s
.3323 .7225 m
.34348 .71666 L
s
.21306 .43094 m
.17617 .45727 L
s
.32526 .66658 m
.32796 .66439 L
s
.31274 .62428 m
.30923 .62583 L
s
.72665 .79221 m
.70956 .78478 L
s
.48779 .65337 m
.47786 .64141 L
s
.32489 .66548 m
.32742 .66341 L
s
.32712 .67976 m
.33177 .67673 L
s
.28984 .5745 m
.27874 .58182 L
s
.33004 .81494 m
.35718 .80428 L
s
.3097 .61837 m
.3053 .62068 L
s
.33099 .71643 m
.34123 .71112 L
s
.31265 .6258 m
.30936 .62733 L
s
.33235 .74418 m
.34704 .73726 L
s
.32687 .68222 m
.33189 .67914 L
s
.32943 .70292 m
.33758 .69851 L
s
.27323 .54266 m
.25697 .55406 L
s
.2368 .47529 m
.20859 .49568 L
s
.5775 .6971 m
.56543 .68326 L
s
.27852 .55298 m
.26396 .56308 L
s
.33145 .72854 m
.34361 .72257 L
s
.2058 .41967 m
.16649 .4479 L
s
.30662 .61292 m
.3014 .61599 L
s
.31263 .62721 m
.30954 .62871 L
s
.33102 .7296 m
.34337 .72367 L
s
.33182 .7545 m
.34825 .74714 L
s
.32548 .84213 m
.358 .83052 L
s
.30938 .62048 m
.30528 .62281 L
s
.32636 .68493 m
.33179 .68184 L
s
.31266 .62852 m
.30976 .62997 L
s
.29897 .59714 m
.29134 .60214 L
s
.32751 .69625 m
.33466 .69249 L
s
.33017 .78313 m
.35158 .77447 L
s
.33055 .74602 m
.3456 .73935 L
s
.30922 .62242 m
.30539 .62473 L
s
.58049 .69929 m
.56817 .68536 L
s
.31553 .88983 m
.35828 .87663 L
s
.32829 .7123 m
.33794 .7077 L
s
.32553 .68791 m
.33142 .68487 L
s
.26484 .53036 m
.24642 .54382 L
s
.30315 .60915 m
.29733 .61302 L
s
.74699 .80901 m
.728 .8026 L
s
.30592 .61576 m
.30109 .6189 L
s
.60373 .71243 m
.59083 .69875 L
s
.32231 .66827 m
.32526 .66658 L
s
.32251 .66954 m
.32565 .66777 L
s
.32268 .67091 m
.32602 .66906 L
s
.32212 .66708 m
.32489 .66548 L
s
.30918 .6242 m
.30561 .62647 L
s
.3228 .67239 m
.32637 .67046 L
s
.32488 .62791 m
.32132 .62791 L
s
.32854 .62836 m
.32488 .62791 L
s
.32288 .67399 m
.32668 .67199 L
s
.30029 .60418 m
.2937 .60875 L
s
.3247 .83039 m
.35503 .81979 L
s
.32287 .67573 m
.32694 .67367 L
s
.33229 .62922 m
.32854 .62836 L
s
.30923 .62583 m
.3059 .62805 L
s
.32132 .62791 m
.31786 .62841 L
s
.5437 .68031 m
.53211 .66655 L
s
.32276 .67762 m
.32712 .67551 L
s
.32868 .75695 m
.34563 .75007 L
s
.30936 .62733 m
.30624 .62949 L
s
.29521 .59482 m
.28716 .60066 L
s
.32427 .69119 m
.33068 .68827 L
s
.3055 .61834 m
.30103 .62151 L
s
.28309 .56936 m
.27105 .57827 L
s
.76239 .82178 m
.74194 .81629 L
s
.32252 .67967 m
.32719 .67753 L
s
.30954 .62871 m
.30662 .63079 L
s
.54602 .68171 m
.53431 .66788 L
s
.27918 .56225 m
.26598 .57213 L
s
.30976 .62997 m
.30703 .63198 L
s
.31786 .62841 m
.31456 .6294 L
s
.28862 .58212 m
.27857 .58962 L
s
.3247 .70084 m
.3326 .69743 L
s
.33616 .63045 m
.33229 .62922 L
s
.32211 .6819 m
.32712 .67976 L
s
.32699 .7374 m
.34072 .73187 L
s
.30206 .61274 m
.29673 .61677 L
s
.3053 .62068 m
.30117 .62384 L
s
.32474 .70886 m
.33391 .7051 L
s
.32254 .82806 m
.35256 .81809 L
s
.28221 .57104 m
.27038 .58013 L
s
.29197 .59182 m
.28342 .59843 L
s
.31919 .66813 m
.32212 .66708 L
s
.32148 .68432 m
.32687 .68222 L
s
.4183 .63302 m
.40993 .62499 L
s
.31918 .66937 m
.32231 .66827 L
s
.30528 .62281 m
.30146 .62592 L
s
.32594 .73873 m
.33992 .73334 L
s
.31918 .67069 m
.32251 .66954 L
s
.32244 .69476 m
.32943 .69205 L
s
.58887 .70514 m
.57595 .69103 L
s
.28928 .5811 m
.27898 .58866 L
s
.2896 .58774 m
.2804 .59494 L
s
.31456 .6294 m
.31145 .63091 L
s
.31914 .6721 m
.32268 .67091 L
s
.58682 .70407 m
.57392 .68993 L
s
.2561 .52068 m
.23582 .53636 L
s
.30539 .62473 m
.30185 .62777 L
s
.30384 .91937 m
.35386 .9063 L
s
.31904 .67361 m
.3228 .67239 L
s
.60826 .71633 m
.59481 .70246 L
s
.29846 .60883 m
.2925 .6137 L
s
.3014 .61599 m
.29653 .62008 L
s
.32056 .68695 m
.32636 .68493 L
s
.29577 .60321 m
.28894 .60879 L
s
.30561 .62647 m
.30232 .62943 L
s
.31886 .67524 m
.32288 .67399 L
s
.2776 .56459 m
.26469 .57482 L
s
.79225 .84722 m
.76877 .84371 L
s
.3059 .62805 m
.30285 .63091 L
s
.34022 .632 m
.33616 .63045 L
s
.30624 .62949 m
.3034 .63223 L
s
.31859 .67698 m
.32287 .67573 L
s
.32343 .79143 m
.34663 .78366 L
s
.30662 .63079 m
.30398 .63343 L
s
.30703 .63198 m
.30457 .6345 L
s
.76257 .82307 m
.74158 .81712 L
s
.31819 .67886 m
.32276 .67762 L
s
.48589 .65531 m
.47536 .64327 L
s
.73788 .80357 m
.7188 .79588 L
s
.31145 .63091 m
.30859 .6329 L
s
.30109 .6189 m
.29664 .623 L
s
.31928 .68979 m
.32553 .68791 L
s
.31618 .6686 m
.31919 .66813 L
s
.32068 .70573 m
.32943 .70292 L
s
.31989 .6986 m
.32751 .69625 L
s
.31764 .68087 m
.32252 .67967 L
s
.31597 .66984 m
.31918 .66937 L
s
.30103 .62151 m
.29696 .62556 L
s
.31577 .67117 m
.31918 .67069 L
s
.29733 .61302 m
.29196 .61806 L
s
.31551 .67257 m
.31914 .6721 L
s
.31689 .68303 m
.32211 .6819 L
s
.24506 .50728 m
.22223 .52576 L
s
.30117 .62384 m
.29745 .6278 L
s
.31518 .67407 m
.31904 .67361 L
s
.32048 .78784 m
.34318 .7809 L
s
.3204 .72529 m
.33231 .72168 L
s
.63874 .73541 m
.62417 .72217 L
s
.31752 .69283 m
.32427 .69119 L
s
.31998 .7197 m
.33099 .71643 L
s
.30859 .6329 m
.30606 .63535 L
s
.30146 .62592 m
.29805 .62977 L
s
.29134 .60214 m
.28428 .60871 L
s
.32025 .72611 m
.3323 .7225 L
s
.30457 .6345 m
.30245 .63747 L
s
.72413 .79378 m
.7057 .78495 L
s
.30185 .62777 m
.29872 .63149 L
s
.31475 .67567 m
.31886 .67524 L
s
.30398 .63343 m
.3017 .63655 L
s
.30232 .62943 m
.29944 .63301 L
s
.3034 .63223 m
.30095 .63551 L
s
.2937 .60875 m
.28765 .61468 L
s
.30285 .63091 m
.30019 .63434 L
s
.31588 .68534 m
.32148 .68432 L
s
.34456 .63382 m
.34022 .632 L
s
.29673 .61677 m
.29191 .62185 L
s
.31319 .66844 m
.31618 .6686 L
s
.31978 .76986 m
.33931 .76411 L
s
.75655 .81946 m
.73549 .81259 L
s
.54432 .68311 m
.53194 .669 L
s
.31421 .67736 m
.31859 .67698 L
s
.63241 .73203 m
.61783 .71846 L
s
.74291 .80864 m
.72294 .80085 L
s
.31801 .71496 m
.32829 .7123 L
s
.31278 .66965 m
.31597 .66984 L
s
.31637 .70263 m
.3247 .70084 L
s
.31238 .67094 m
.31577 .67117 L
s
.31836 .73204 m
.33145 .72854 L
s
.31353 .67916 m
.31819 .67886 L
s
.51739 .67037 m
.50564 .65694 L
s
.31457 .68779 m
.32056 .68695 L
s
.30606 .63535 m
.30391 .63821 L
s
.29653 .62008 m
.2922 .62514 L
s
.27905 .58054 m
.26852 .59027 L
s
.31515 .69604 m
.32244 .69476 L
s
.31676 .79965 m
.3418 .7928 L
s
.31775 .73303 m
.33102 .7296 L
s
.3119 .67229 m
.31551 .67257 L
s
.62073 .72568 m
.60621 .71161 L
s
.31267 .68107 m
.31764 .68087 L
s
.73751 .80506 m
.7177 .7967 L
s
.30245 .63747 m
.30077 .64082 L
s
.27874 .58182 m
.26839 .59161 L
s
.29664 .623 m
.29274 .62797 L
s
.28716 .60066 m
.2798 .60821 L
s
.31134 .67372 m
.31518 .67407 L
s
.3017 .63655 m
.29988 .64008 L
s
.2925 .6137 m
.28717 .61979 L
s
.3103 .66764 m
.31319 .66844 L
s
.31509 .71072 m
.32474 .70886 L
s
.30095 .63551 m
.29896 .63924 L
s
.29696 .62556 m
.29345 .6304 L
s
.61775 .72426 m
.60318 .71004 L
s
.31285 .69037 m
.31928 .68979 L
s
.31648 .74808 m
.33235 .74418 L
s
.31068 .67523 m
.31475 .67567 L
s
.30019 .63434 m
.29802 .63826 L
s
.3097 .66879 m
.31278 .66965 L
s
.3116 .68307 m
.31689 .68303 L
s
.29745 .6278 m
.29428 .63248 L
s
.29944 .63301 m
.29706 .63712 L
s
.56426 .69448 m
.55101 .6799 L
s
.29805 .62977 m
.29517 .63427 L
s
.29872 .63149 m
.29611 .63581 L
s
.30391 .63821 m
.30221 .6414 L
s
.26122 .54853 m
.24535 .56287 L
s
.26643 .55938 m
.25238 .57236 L
s
.30764 .85219 m
.34337 .84383 L
s
.28894 .60879 m
.28282 .61578 L
s
.30911 .66999 m
.31238 .67094 L
s
.2539 .53491 m
.23569 .55116 L
s
.31267 .81198 m
.34024 .80526 L
s
.30989 .67681 m
.31421 .67736 L
s
.31201 .69935 m
.31989 .6986 L
s
.29196 .61806 m
.28727 .62418 L
s
.30844 .67124 m
.3119 .67229 L
s
.31025 .68517 m
.31588 .68534 L
s
.30077 .64082 m
.29958 .64444 L
s
.28342 .59843 m
.27565 .60688 L
s
.55739 .69132 m
.54418 .67674 L
s
.31436 .74953 m
.33055 .74602 L
s
.30762 .66623 m
.3103 .66764 L
s
.31397 .77252 m
.33422 .76787 L
s
.30894 .67847 m
.31353 .67916 L
s
.34931 .63588 m
.34456 .63382 L
s
.31408 .75841 m
.33182 .7545 L
s
.31063 .69304 m
.31752 .69283 L
s
.29988 .64008 m
.29857 .64392 L
s
.31161 .70669 m
.32068 .70573 L
s
.25126 .53201 m
.23248 .54899 L
s
.30767 .67255 m
.31134 .67372 L
s
.30221 .6414 m
.301 .64484 L
s
.30684 .66727 m
.3097 .66879 L
s
.27857 .58962 m
.26939 .59935 L
s
.70956 .78478 m
.69126 .77443 L
s
.29896 .63924 m
.29752 .6433 L
s
.29191 .62185 m
.28778 .62791 L
s
.2804 .59494 m
.27205 .60416 L
s
.29802 .63826 m
.29643 .64255 L
s
.24359 .51981 m
.22261 .53877 L
s
.3078 .68019 m
.31267 .68107 L
s
.29408 .90617 m
.34217 .89674 L
s
.30607 .66834 m
.30911 .66999 L
s
.30857 .68734 m
.31457 .68779 L
s
.31237 .74001 m
.32699 .7374 L
s
.30678 .67392 m
.31068 .67523 L
s
.27898 .58866 m
.26957 .59845 L
s
.29706 .63712 m
.2953 .64166 L
s
.30525 .66424 m
.30762 .66623 L
s
.2922 .62514 m
.28858 .63106 L
s
.29958 .64444 m
.29894 .64823 L
s
.29611 .63581 m
.29414 .64059 L
s
.28765 .61468 m
.28239 .62185 L
s
.301 .64484 m
.30034 .64841 L
s
.30522 .66945 m
.30844 .67124 L
s
.29274 .62797 m
.28955 .6337 L
s
.29517 .63427 m
.29296 .6393 L
s
.31108 .74111 m
.32594 .73873 L
s
.30429 .66513 m
.30684 .66727 L
s
.26396 .56308 m
.25039 .57667 L
s
.30576 .67533 m
.30989 .67681 L
s
.29428 .63248 m
.29179 .63776 L
s
.29345 .6304 m
.29064 .63591 L
s
.29857 .64392 m
.29785 .64794 L
s
.27105 .57827 m
.25998 .58996 L
s
.30642 .68196 m
.3116 .68307 L
s
.28428 .60871 m
.27807 .61678 L
s
.30779 .69574 m
.31515 .69604 L
s
.31049 .76015 m
.32868 .75695 L
s
.30427 .67059 m
.30767 .67255 L
s
.29752 .6433 m
.2967 .64757 L
s
.60164 .71673 m
.58683 .70182 L
s
.30325 .66173 m
.30525 .66424 L
s
.30789 .70262 m
.31637 .70263 L
s
.30339 .66603 m
.30607 .66834 L
s
.30647 .68954 m
.31285 .69037 L
s
.30034 .64841 m
.30024 .65201 L
s
.29894 .64823 m
.29887 .65205 L
s
.30457 .67677 m
.30894 .67847 L
s
.27038 .58013 m
.25958 .59197 L
s
.30853 .72058 m
.31998 .7197 L
s
.29643 .64255 m
.29549 .64709 L
s
.30216 .66244 m
.30429 .66513 L
s
.61911 .72712 m
.60373 .71243 L
s
.29856 .86729 m
.33805 .85996 L
s
.28717 .61979 m
.28269 .62698 L
s
.30477 .68376 m
.31025 .68517 L
s
.30319 .67175 m
.30678 .67392 L
s
.30172 .65879 m
.30325 .66173 L
s
.29785 .64794 m
.29774 .65202 L
s
.30239 .66695 m
.30522 .66945 L
s
.30024 .65201 m
.3007 .65551 L
s
.26598 .57213 m
.25385 .58514 L
s
.30741 .71537 m
.31801 .71496 L
s
.2953 .64166 m
.29422 .64647 L
s
.30797 .7263 m
.3204 .72529 L
s
.75869 .82442 m
.73597 .81639 L
s
.29887 .65205 m
.2994 .65578 L
s
.25697 .55406 m
.2418 .56949 L
s
.6551 .74891 m
.63874 .73541 L
s
.3007 .65551 m
.30172 .65879 L
s
.30114 .66313 m
.30339 .66603 L
s
.3077 .72709 m
.32025 .72611 L
s
.30051 .65928 m
.30216 .66244 L
s
.30318 .67824 m
.3078 .68019 L
s
.29414 .64059 m
.29289 .64569 L
s
.30695 .78702 m
.33017 .78313 L
s
.2967 .64757 m
.29654 .65191 L
s
.2994 .65578 m
.30051 .65928 L
s
.30128 .66787 m
.30427 .67059 L
s
.30197 .67293 m
.30576 .67533 L
s
.59235 .71225 m
.5775 .6971 L
s
.28727 .62418 m
.28346 .63125 L
s
.29774 .65202 m
.29827 .656 L
s
.29296 .6393 m
.29152 .6447 L
s
.30386 .69172 m
.31063 .69304 L
s
.30433 .80909 m
.33185 .80446 L
s
.29941 .65975 m
.30114 .66313 L
s
.30002 .66382 m
.30239 .66695 L
s
.29549 .64709 m
.29525 .65172 L
s
.30526 .71045 m
.31509 .71072 L
s
.30416 .69835 m
.31201 .69935 L
s
.30277 .68555 m
.30857 .68734 L
s
.29179 .63776 m
.2901 .64347 L
s
.29827 .656 m
.29941 .65975 L
s
.2798 .60821 m
.27346 .61736 L
s
.28778 .62791 m
.28455 .63478 L
s
.28282 .61578 m
.27768 .62407 L
s
.30155 .6797 m
.30642 .68196 L
s
.29654 .65191 m
.29705 .65617 L
s
.29064 .63591 m
.28866 .64193 L
s
.30004 .66879 m
.30319 .67175 L
s
.26469 .57482 m
.25293 .58814 L
s
.28858 .63106 m
.28584 .63767 L
s
.30058 .67411 m
.30457 .67677 L
s
.22322 .49239 m
.19692 .5169 L
s
.28955 .6337 m
.28723 .64002 L
s
.5956 .71452 m
.58049 .69929 L
s
.29422 .64647 m
.29389 .6514 L
s
.35468 .63815 m
.34931 .63588 L
s
.42811 .64163 m
.4183 .63302 L
s
.29822 .66019 m
.30002 .66382 L
s
.2988 .6645 m
.30128 .66787 L
s
.62417 .73117 m
.60826 .71633 L
s
.64897 .74606 m
.63241 .73203 L
s
.29705 .65617 m
.29822 .66019 L
s
.30476 .73262 m
.31836 .73204 L
s
.29525 .65172 m
.29573 .65627 L
s
.21295 .47462 m
.18318 .50195 L
s
.50016 .66649 m
.48779 .65337 L
s
.29289 .64569 m
.29244 .65094 L
s
.83812 .89249 m
.80711 .89031 L
s
.29867 .66969 m
.30197 .67293 L
s
.30252 .70561 m
.31161 .70669 L
s
.23662 .52097 m
.21552 .54188 L
s
.30397 .73346 m
.31775 .73303 L
s
.29693 .66058 m
.2988 .6645 L
s
.29899 .67525 m
.30318 .67824 L
s
.30032 .81926 m
.33004 .81494 L
s
.29964 .68112 m
.30477 .68376 L
s
.30035 .68728 m
.30647 .68954 L
s
.29746 .66513 m
.30004 .66879 L
s
.29573 .65627 m
.29693 .66058 L
s
.29152 .6447 m
.29091 .6503 L
s
.29389 .6514 m
.29432 .65628 L
s
.30062 .69377 m
.30779 .69574 L
s
.28239 .62185 m
.27819 .63012 L
s
.81545 .87319 m
.78664 .86876 L
s
.29713 .67054 m
.30058 .67411 L
s
.26852 .59027 m
.25923 .60245 L
s
.2901 .64347 m
.2893 .64943 L
s
.27565 .60688 m
.26905 .61705 L
s
.60455 .7205 m
.58887 .70514 L
s
.29553 .66091 m
.29746 .66513 L
s
.24642 .54382 m
.22931 .56208 L
s
.29432 .65628 m
.29553 .66091 L
s
.29244 .65094 m
.29281 .65616 L
s
.7057 .78495 m
.68635 .77335 L
s
.29598 .66571 m
.29867 .66969 L
s
.26839 .59161 m
.25931 .60381 L
s
.60251 .71949 m
.58682 .70407 L
s
.29717 .67634 m
.30155 .6797 L
s
.28866 .64193 m
.28762 .64826 L
s
.29956 .70067 m
.30789 .70262 L
s
.28269 .62698 m
.27928 .63507 L
s
.69126 .77443 m
.67282 .76216 L
s
.2974 .68245 m
.30277 .68555 L
s
.75688 .82501 m
.73335 .81602 L
s
.28723 .64002 m
.28588 .64674 L
s
.29091 .6503 m
.29118 .65589 L
s
.27807 .61678 m
.27304 .62619 L
s
.29281 .65616 m
.294 .66115 L
s
.294 .66115 m
.29598 .66571 L
s
.22662 .5075 m
.20293 .53119 L
s
.2954 .67132 m
.29899 .67525 L
s
.29744 .68885 m
.30386 .69172 L
s
.28346 .63125 m
.28073 .63906 L
s
.28584 .63767 m
.28412 .64477 L
s
.55825 .69556 m
.5437 .68031 L
s
.29434 .66621 m
.29713 .67054 L
s
.28455 .63478 m
.28238 .64225 L
s
.63755 .74051 m
.62073 .72568 L
s
.728 .8026 m
.7067 .79183 L
s
.27911 .91639 m
.33091 .90998 L
s
.27205 .60416 m
.26498 .61527 L
s
.67282 .76216 m
.6551 .74891 L
s
.29996 .74829 m
.31648 .74808 L
s
.2985 .79373 m
.32343 .79143 L
s
.5607 .69704 m
.54602 .68171 L
s
.2893 .64943 m
.28943 .65541 L
s
.29508 .67731 m
.29964 .68112 L
s
.22469 .50567 m
.20061 .52991 L
s
.26939 .59935 m
.26153 .61119 L
s
.29912 .77104 m
.31978 .76986 L
s
.29118 .65589 m
.29234 .66126 L
s
.29662 .69553 m
.30416 .69835 L
s
.29234 .66126 m
.29434 .66621 L
s
.7188 .79588 m
.69802 .7845 L
s
.29345 .67197 m
.29717 .67634 L
s
.29475 .6836 m
.30035 .68728 L
s
.63469 .73933 m
.61775 .72426 L
s
.28762 .64826 m
.28757 .65468 L
s
.29254 .66658 m
.2954 .67132 L
s
.26957 .59845 m
.2615 .61038 L
s
.29689 .7133 m
.30741 .71537 L
s
.19768 .45686 m
.16402 .48863 L
s
.29707 .71879 m
.30853 .72058 L
s
.28943 .65541 m
.29052 .66121 L
s
.27768 .62407 m
.27379 .63343 L
s
.29758 .74923 m
.31436 .74953 L
s
.29737 .73918 m
.31237 .74001 L
s
.29625 .78934 m
.32048 .78784 L
s
.28588 .64674 m
.2856 .6536 L
s
.29052 .66121 m
.29254 .66658 L
s
.29562 .70787 m
.30526 .71045 L
s
.29155 .83351 m
.3247 .83039 L
s
.29267 .6781 m
.2974 .68245 L
s
.28975 .84563 m
.32548 .84213 L
s
.29393 .69013 m
.30062 .69377 L
s
.27817 .90437 m
.3274 .89929 L
s
.29054 .66677 m
.29345 .67197 L
s
.29125 .67245 m
.29508 .67731 L
s
.28412 .64477 m
.28353 .6521 L
s
.28757 .65468 m
.28856 .66093 L
s
.27346 .61736 m
.26849 .62789 L
s
.2955 .72437 m
.30797 .7263 L
s
.29589 .73997 m
.31108 .74111 L
s
.27819 .63012 m
.27526 .63924 L
s
.29377 .70238 m
.30252 .70561 L
s
.29562 .75807 m
.31408 .75841 L
s
.2951 .72508 m
.3077 .72709 L
s
.28238 .64225 m
.28139 .65007 L
s
.29164 .68447 m
.29744 .68885 L
s
.28856 .66093 m
.29054 .66677 L
s
.66715 .76007 m
.64897 .74606 L
s
.28987 .83055 m
.32254 .82806 L
s
.49903 .66863 m
.48589 .65531 L
s
.36093 .64068 m
.35468 .63815 L
s
.27928 .63507 m
.27715 .64381 L
s
.18506 .43782 m
.1473 .47328 L
s
.28073 .63906 m
.27924 .64736 L
s
.23582 .53636 m
.21715 .5576 L
s
.2856 .6536 m
.28642 .66035 L
s
.25238 .57236 m
.23996 .58892 L
s
.2899 .67862 m
.29475 .6836 L
s
.25998 .58996 m
.2505 .60434 L
s
.29171 .69675 m
.29956 .70067 L
s
.28833 .66672 m
.29125 .67245 L
s
.28878 .67266 m
.29267 .6781 L
s
.29277 .77223 m
.31397 .77252 L
s
.28642 .66035 m
.28833 .66672 L
s
.28353 .6521 m
.28412 .65939 L
s
.7177 .7967 m
.69628 .78467 L
s
.25958 .59197 m
.25042 .60643 L
s
.28971 .69092 m
.29662 .69553 L
s
.68635 .77335 m
.66715 .76007 L
s
.72294 .80085 m
.70103 .789 L
s
.29008 .80027 m
.31676 .79965 L
s
.27304 .62619 m
.26948 .63667 L
s
.29169 .75891 m
.31049 .76015 L
s
.26905 .61705 m
.264 .62871 L
s
.28139 .65007 m
.28166 .65793 L
s
.78867 .85392 m
.76083 .8458 L
s
.24535 .56287 m
.23125 .58139 L
s
.28589 .66634 m
.28878 .67266 L
s
.29117 .72989 m
.30476 .73262 L
s
.288 .6849 m
.29393 .69013 L
s
.55981 .69886 m
.54432 .68311 L
s
.63694 .74268 m
.61911 .72712 L
s
.28412 .65939 m
.28589 .66634 L
s
.18795 .44974 m
.15246 .48456 L
s
.286 .67251 m
.2899 .67862 L
s
.28672 .67873 m
.29164 .68447 L
s
.29024 .73054 m
.30397 .73346 L
s
.74194 .81629 m
.71822 .80516 L
s
.27924 .64736 m
.27908 .65582 L
s
.25039 .57667 m
.23862 .59374 L
s
.27379 .63343 m
.27139 .64357 L
s
.25385 .58514 m
.2435 .6012 L
s
.27715 .64381 m
.27642 .65287 L
s
.27526 .63924 m
.2738 .64888 L
s
.28166 .65793 m
.28321 .66552 L
s
.53217 .68538 m
.51739 .67037 L
s
.58063 .71068 m
.56426 .69448 L
s
.28321 .66552 m
.286 .67251 L
s
.61926 .73287 m
.60164 .71673 L
s
.64247 .74677 m
.62417 .73117 L
s
.26498 .61527 m
.25962 .628 L
s
.2866 .70294 m
.29562 .70787 L
s
.82915 .88947 m
.79661 .88402 L
s
.28688 .70866 m
.29689 .7133 L
s
.28574 .69703 m
.29377 .70238 L
s
.25923 .60245 m
.25175 .61688 L
s
.25293 .58814 m
.24306 .60442 L
s
.28289 .67185 m
.28672 .67873 L
s
.20859 .49568 m
.18212 .52471 L
s
.27908 .65582 m
.2803 .6641 L
s
.2847 .69092 m
.29171 .69675 L
s
.25931 .60381 m
.25205 .6182 L
s
.23569 .55116 m
.21943 .57244 L
s
.28309 .67826 m
.288 .6849 L
s
.28609 .71416 m
.29707 .71879 L
s
.28375 .68465 m
.28971 .69092 L
s
.65643 .75574 m
.63755 .74051 L
s
.26849 .62789 m
.26519 .63949 L
s
.7816 .84945 m
.75376 .84021 L
s
.57379 .70756 m
.55739 .69132 L
s
.28334 .81157 m
.31267 .81198 L
s
.26153 .61119 m
.25549 .62489 L
s
.74158 .81712 m
.71734 .8055 L
s
.22223 .52576 m
.20136 .55091 L
s
.2803 .6641 m
.28289 .67185 L
s
.27642 .65287 m
.27719 .66189 L
s
.87884 .93471 m
.84014 .93356 L
s
.73549 .81259 m
.71165 .80057 L
s
.2615 .61038 m
.25527 .6242 L
s
.2418 .56949 m
.2287 .58898 L
s
.26948 .63667 m
.26761 .64783 L
s
.23248 .54899 m
.21577 .57123 L
s
.2738 .64888 m
.27393 .65866 L
s
.65381 .75489 m
.63469 .73933 L
s
.28353 .71932 m
.2955 .72437 L
s
.6102 .72882 m
.59235 .71225 L
s
.27944 .67048 m
.28309 .67826 L
s
.26827 .89104 m
.31553 .88983 L
s
.27139 .64357 m
.27065 .65409 L
s
.2828 .78491 m
.30695 .78702 L
s
.28349 .7443 m
.29996 .74829 L
s
.27719 .66189 m
.27944 .67048 L
s
.28302 .7199 m
.2951 .72508 L
s
.69802 .7845 m
.67686 .77072 L
s
.76842 .83962 m
.74132 .82909 L
s
.61367 .73113 m
.5956 .71452 L
s
.27899 .67695 m
.28375 .68465 L
s
.28263 .73454 m
.29737 .73918 L
s
.264 .62871 m
.26083 .64146 L
s
.27885 .68339 m
.2847 .69092 L
s
.62309 .73712 m
.60455 .7205 L
s
.3684 .64356 m
.36093 .64068 L
s
.44 .6512 m
.42811 .64163 L
s
.27881 .6897 m
.28574 .69703 L
s
.27393 .65866 m
.27567 .66816 L
s
.78081 .85042 m
.75222 .84038 L
s
.28102 .73493 m
.29589 .73997 L
s
.28094 .7446 m
.29758 .74923 L
s
.7067 .79183 m
.68454 .77807 L
s
.27861 .69576 m
.2866 .70294 L
s
.6211 .73621 m
.60251 .71949 L
s
.27567 .66816 m
.27899 .67695 L
s
.22261 .53877 m
.20394 .56388 L
s
.27065 .65409 m
.27167 .66455 L
s
.27788 .7015 m
.28688 .70866 L
s
.26519 .63949 m
.2638 .65171 L
s
.26761 .64783 m
.26761 .65923 L
s
.67686 .77072 m
.65643 .75574 L
s
.27823 .72367 m
.29117 .72989 L
s
.27819 .76676 m
.29912 .77104 L
s
.27444 .67447 m
.27885 .68339 L
s
.27553 .80629 m
.30433 .80909 L
s
.69628 .78467 m
.67461 .77032 L
s
.2505 .60434 m
.24326 .62112 L
s
.25962 .628 m
.25634 .64193 L
s
.26923 .85056 m
.30764 .85219 L
s
.2772 .72406 m
.29024 .73054 L
s
.65697 .75872 m
.63694 .74268 L
s
.27727 .75288 m
.29562 .75807 L
s
.27611 .70674 m
.28609 .71416 L
s
.25042 .60643 m
.24353 .6232 L
s
.27167 .66455 m
.27444 .67447 L
s
.27332 .68067 m
.27881 .6897 L
s
.6628 .76267 m
.64247 .74677 L
s
.70103 .789 m
.67863 .77451 L
s
.67461 .77032 m
.65381 .75489 L
s
.22931 .56208 m
.21473 .58522 L
s
.25549 .62489 m
.2517 .63999 L
s
.26761 .65923 m
.26953 .67035 L
s
.27206 .6866 m
.27861 .69576 L
s
.51571 .68134 m
.50016 .66649 L
s
.27292 .78924 m
.2985 .79373 L
s
.25175 .61688 m
.24661 .63314 L
s
.26083 .64146 m
.25981 .65479 L
s
.25205 .6182 m
.24714 .63435 L
s
.25527 .6242 m
.25132 .63944 L
s
.23996 .58892 m
.23005 .60882 L
s
.26953 .67035 m
.27332 .68067 L
s
.2638 .65171 m
.26449 .66403 L
s
.73597 .81639 m
.71045 .803 L
s
.27265 .71115 m
.28353 .71932 L
s
.2732 .75263 m
.29169 .75891 L
s
.26925 .81529 m
.30032 .81926 L
s
.17617 .45727 m
.14136 .49634 L
s
.27158 .78422 m
.29625 .78934 L
s
.27205 .71158 m
.28302 .7199 L
s
.57622 .71269 m
.55825 .69556 L
s
.27033 .69205 m
.27788 .7015 L
s
.2435 .6012 m
.23569 .61998 L
s
.57882 .71424 m
.5607 .69704 L
s
.27161 .76617 m
.29277 .77223 L
s
.68454 .77807 m
.6628 .76267 L
s
.26728 .67585 m
.27206 .6866 L
s
.24306 .60442 m
.23579 .62329 L
s
.21552 .54188 m
.19719 .56919 L
s
.23862 .59374 m
.22951 .61399 L
s
.24863 .91702 m
.30384 .91937 L
s
.63961 .75006 m
.61926 .73287 L
s
.26449 .66403 m
.26728 .67585 L
s
.76877 .84371 m
.73975 .8315 L
s
.25634 .64193 m
.25543 .65647 L
s
.26765 .69674 m
.27611 .70674 L
s
.67863 .77451 m
.65697 .75872 L
s
.26893 .72596 m
.28263 .73454 L
s
.25981 .65479 m
.26108 .66811 L
s
.23125 .58139 m
.21998 .6039 L
s
.2679 .73585 m
.28349 .7443 L
s
.73335 .81602 m
.70725 .80182 L
s
.26463 .68074 m
.27033 .69205 L
s
.26725 .72589 m
.28102 .73493 L
s
.16649 .4479 m
.12943 .49018 L
s
.26663 .71401 m
.27823 .72367 L
s
.25636 .86285 m
.29856 .86729 L
s
.26553 .71411 m
.2772 .72406 L
s
.2517 .63999 m
.2505 .65587 L
s
.26108 .66811 m
.26463 .68074 L
s
.26531 .73543 m
.28094 .7446 L
s
.26306 .79328 m
.29008 .80027 L
s
.26346 .70014 m
.27265 .71115 L
s
.37756 .647 m
.3684 .64356 L
s
.25132 .63944 m
.24999 .65549 L
s
.71822 .80516 m
.69301 .79005 L
s
.51555 .68386 m
.49903 .66863 L
s
.21715 .5576 m
.20157 .58447 L
s
.24326 .62112 m
.23886 .63971 L
s
.64437 .75473 m
.62309 .73712 L
s
.26282 .70038 m
.27205 .71158 L
s
.63107 .74672 m
.6102 .72882 L
s
.60046 .72872 m
.58063 .71068 L
s
.25543 .65647 m
.25705 .67095 L
s
.26119 .68461 m
.26765 .69674 L
s
.24353 .6232 m
.23948 .64169 L
s
.6347 .74901 m
.61367 .73113 L
s
.19692 .5169 m
.17369 .55 L
s
.5789 .71663 m
.55981 .69886 L
s
.24714 .63435 m
.245 .65162 L
s
.24661 .63314 m
.24427 .65058 L
s
.71165 .80057 m
.68675 .78506 L
s
.25717 .82683 m
.29155 .83351 L
s
.64251 .754 m
.6211 .73621 L
s
.20293 .53119 m
.18242 .56245 L
s
.2287 .58898 m
.21871 .61221 L
s
.25613 .82335 m
.28987 .83055 L
s
.71734 .8055 m
.6917 .78995 L
s
.25705 .67095 m
.26119 .68461 L
s
.20061 .52991 m
.1798 .56194 L
s
.242 .90033 m
.29408 .90617 L
s
.59377 .72578 m
.57379 .70756 L
s
.21943 .57244 m
.20648 .59857 L
s
.26004 .74255 m
.27727 .75288 L
s
.25901 .77584 m
.2828 .78491 L
s
.25253 .83834 m
.28975 .84563 L
s
.2505 .65587 m
.25209 .67174 L
s
.55066 .70256 m
.53217 .68538 L
s
.25648 .68677 m
.26346 .70014 L
s
.25817 .75652 m
.27819 .76676 L
s
.25703 .70125 m
.26663 .71401 L
s
.24999 .65549 m
.25149 .67156 L
s
.25584 .6868 m
.26282 .70038 L
s
.25703 .71363 m
.26893 .72596 L
s
.25594 .70104 m
.26553 .71411 L
s
.66235 .76777 m
.63961 .75006 L
s
.23569 .61998 m
.23113 .6408 L
s
.2538 .80243 m
.28334 .81157 L
s
.21577 .57123 m
.20255 .59854 L
s
.18318 .50195 m
.15682 .53952 L
s
.25605 .7411 m
.2732 .75263 L
s
.2554 .71309 m
.26725 .72589 L
s
.23579 .62329 m
.23181 .64403 L
s
.23005 .60882 m
.22354 .63147 L
s
.25209 .67174 m
.25648 .68677 L
s
.245 .65162 m
.24594 .66916 L
s
.24427 .65058 m
.24503 .66835 L
s
.25149 .67156 m
.25584 .6868 L
s
.25412 .72304 m
.2679 .73585 L
s
.45478 .66232 m
.44 .6512 L
s
.22951 .61399 m
.22392 .63674 L
s
.23886 .63971 m
.23775 .65928 L
s
.23948 .64169 m
.23873 .66104 L
s
.25173 .75396 m
.27161 .76617 L
s
.25 .68602 m
.25703 .70125 L
s
.25165 .72187 m
.26531 .73543 L
s
.66796 .77274 m
.64437 .75473 L
s
.68675 .78506 m
.66235 .76777 L
s
.20136 .55091 m
.18434 .58282 L
s
.71045 .803 m
.68405 .78614 L
s
.24897 .6855 m
.25594 .70104 L
s
.69301 .79005 m
.66796 .77274 L
s
.24594 .66916 m
.25 .68602 L
s
.21473 .58522 m
.204 .6128 L
s
.66632 .77227 m
.64251 .754 L
s
.2471 .79473 m
.27553 .80629 L
s
.24503 .66835 m
.24897 .6855 L
s
.2482 .77708 m
.27292 .78924 L
s
.24792 .77171 m
.27158 .78422 L
s
.24769 .6981 m
.25703 .71363 L
s
.6584 .76766 m
.6347 .74901 L
s
.20394 .56388 m
.1893 .59498 L
s
.65473 .76554 m
.63107 .74672 L
s
.21998 .6039 m
.21261 .6297 L
s
.24619 .69709 m
.2554 .71309 L
s
.6917 .78995 m
.66632 .77227 L
s
.70725 .80182 m
.6805 .78438 L
s
.59804 .732 m
.57622 .71269 L
s
.60075 .7336 m
.57882 .71424 L
s
.23873 .66104 m
.24148 .68022 L
s
.23775 .65928 m
.24021 .67879 L
s
.24504 .72725 m
.26004 .74255 L
s
.23113 .6408 m
.23033 .66268 L
s
.23181 .64403 m
.2316 .66564 L
s
.38898 .65137 m
.37756 .647 L
s
.74132 .82909 m
.71113 .81228 L
s
.22386 .9051 m
.27911 .91639 L
s
.18212 .52471 m
.15994 .56298 L
s
.24303 .70641 m
.25412 .72304 L
s
.24148 .68022 m
.24769 .6981 L
s
.22608 .8928 m
.27817 .90437 L
s
.53523 .69864 m
.51571 .68134 L
s
.21871 .61221 m
.21286 .63834 L
s
.24021 .67879 m
.24619 .69709 L
s
.16402 .48863 m
.13454 .53285 L
s
.23876 .80156 m
.26925 .81529 L
s
.24139 .72462 m
.25605 .7411 L
s
.24084 .70452 m
.25165 .72187 L
s
.6239 .74861 m
.60046 .72872 L
s
.22354 .63147 m
.22116 .65584 L
s
.24036 .74033 m
.25817 .75652 L
s
.76083 .8458 m
.72819 .82925 L
s
.68405 .78614 m
.6584 .76766 L
s
.75376 .84021 m
.72176 .82332 L
s
.22392 .63674 m
.2225 .66092 L
s
.23744 .77788 m
.26306 .79328 L
s
.19719 .56919 m
.18346 .60256 L
s
.6805 .78438 m
.65473 .76554 L
s
.23049 .83631 m
.26923 .85056 L
s
.23716 .7595 m
.25901 .77584 L
s
.2316 .66564 m
.23538 .68688 L
s
.23033 .66268 m
.23359 .68436 L
s
.23538 .68688 m
.24303 .70641 L
s
.60198 .73672 m
.5789 .71663 L
s
.20157 .58447 m
.19067 .61637 L
s
.61755 .74608 m
.59377 .72578 L
s
.20648 .59857 m
.1982 .62877 L
s
.23359 .68436 m
.24084 .70452 L
s
.78664 .86876 m
.75042 .85255 L
s
.75222 .84038 m
.71964 .82278 L
s
.23451 .73579 m
.25173 .75396 L
s
.21939 .87591 m
.26827 .89104 L
s
.2333 .70771 m
.24504 .72725 L
s
.53628 .7018 m
.51555 .68386 L
s
.1473 .47328 m
.11426 .52351 L
s
.15246 .48456 m
.12182 .53306 L
s
.20255 .59854 m
.19427 .63006 L
s
.73975 .8315 m
.70782 .813 L
s
.23024 .704 m
.24139 .72462 L
s
.21261 .6297 m
.21008 .6576 L
s
.22116 .65584 m
.22337 .68055 L
s
.2225 .66092 m
.22564 .6851 L
s
.57349 .7225 m
.55066 .70256 L
s
.22392 .80877 m
.25717 .82683 L
s
.22613 .78375 m
.2538 .80243 L
s
.204 .6128 m
.19841 .64372 L
s
.22369 .805 m
.25613 .82335 L
s
.21286 .63834 m
.21195 .66603 L
s
.22701 .75183 m
.24792 .77171 L
s
.22564 .6851 m
.2333 .70771 L
s
.22613 .75714 m
.2482 .77708 L
s
.18242 .56245 m
.16735 .60093 L
s
.22607 .71889 m
.24036 .74033 L
s
.22337 .68055 m
.23024 .704 L
s
.1798 .56194 m
.16463 .60136 L
s
.21439 .84376 m
.25636 .86285 L
s
.17369 .55 m
.15619 .59156 L
s
.22115 .77394 m
.2471 .79473 L
s
.65074 .76998 m
.6239 .74861 L
s
.62662 .75512 m
.60075 .7336 L
s
.2165 .81837 m
.25253 .83834 L
s
.47343 .67588 m
.45478 .66232 L
s
.62385 .75355 m
.59804 .732 L
s
.22125 .71258 m
.23451 .73579 L
s
.80711 .89031 m
.76627 .87292 L
s
.1893 .59498 m
.18045 .63106 L
s
.18434 .58282 m
.17319 .62067 L
s
.40346 .65732 m
.38898 .65137 L
s
.71113 .81228 m
.68027 .79178 L
s
.21894 .73637 m
.23716 .7595 L
s
.21008 .6576 m
.21293 .68588 L
s
.90722 .98176 m
.85279 .97081 L
s
.21195 .66603 m
.21639 .69353 L
s
.21639 .69353 m
.22607 .71889 L
s
.1982 .62877 m
.19576 .66151 L
s
.64502 .76814 m
.61755 .74608 L
s
.21526 .75426 m
.23744 .77788 L
s
.14136 .49634 m
.11278 .54947 L
s
.21293 .68588 m
.22125 .71258 L
s
.21127 .77765 m
.23876 .80156 L
s
.62917 .75909 m
.60198 .73672 L
s
.19067 .61637 m
.18596 .65186 L
s
.19427 .63006 m
.19217 .66415 L
s
.79661 .88402 m
.75548 .86469 L
s
.19841 .64372 m
.19889 .67619 L
s
.18346 .60256 m
.17617 .64067 L
s
.19229 .8938 m
.24863 .91702 L
s
.68027 .79178 m
.65074 .76998 L
s
.55953 .71919 m
.53523 .69864 L
s
.21053 .72551 m
.22701 .75183 L
s
.15682 .53952 m
.13714 .58731 L
s
.72176 .82332 m
.68842 .80172 L
s
.20855 .73031 m
.22613 .75714 L
s
.70782 .813 m
.67556 .79104 L
s
.72819 .82925 m
.69374 .80732 L
s
.20584 .70789 m
.21894 .73637 L
s
.19003 .87481 m
.242 .90033 L
s
.71964 .82278 m
.68591 .80064 L
s
.65615 .77825 m
.62662 .75512 L
s
.12943 .49018 m
.09935 .54802 L
s
.20271 .75591 m
.22613 .78375 L
s
.15994 .56298 m
.14498 .60979 L
s
.65343 .77684 m
.62385 .75355 L
s
.19576 .66151 m
.19987 .6946 L
s
.67556 .79104 m
.64502 .76814 L
s
.19889 .67619 m
.20584 .70789 L
s
.19995 .74469 m
.22115 .77394 L
s
.19987 .6946 m
.21053 .72551 L
s
.19476 .8082 m
.23049 .83631 L
s
.60116 .74561 m
.57349 .7225 L
s
.56208 .72328 m
.53628 .7018 L
s
.19217 .66415 m
.19694 .69847 L
s
.19844 .72371 m
.21526 .75426 L
s
.18045 .63106 m
.17891 .67005 L
s
.19541 .77546 m
.22369 .805 L
s
.19476 .77916 m
.22392 .80877 L
s
.19694 .69847 m
.20855 .73031 L
s
.18596 .65186 m
.18846 .6886 L
s
.16735 .60093 m
.16 .64499 L
s
.66011 .78312 m
.62917 .75909 L
s
.68842 .80172 m
.65615 .77825 L
s
.17319 .62067 m
.16973 .66244 L
s
.16463 .60136 m
.15742 .64646 L
s
.68591 .80064 m
.65343 .77684 L
s
.17617 .64067 m
.17672 .68114 L
s
.422 .66586 m
.40346 .65732 L
s
.13454 .53285 m
.11342 .58943 L
s
.18934 .74461 m
.21127 .77765 L
s
.17578 .86095 m
.22608 .8928 L
s
.69374 .80732 m
.66011 .78312 L
s
.18846 .6886 m
.19844 .72371 L
s
.18506 .78554 m
.2165 .81837 L
s
.15619 .59156 m
.14712 .63991 L
s
.49713 .69313 m
.47343 .67588 L
s
.75042 .85255 m
.71059 .82824 L
s
.17017 .87188 m
.22386 .9051 L
s
.18573 .72072 m
.20271 .75591 L
s
.18547 .70904 m
.19995 .74469 L
s
.17347 .84191 m
.21939 .87591 L
s
.17891 .67005 m
.18547 .70904 L
s
.17669 .80902 m
.21439 .84376 L
s
.58932 .74366 m
.55953 .71919 L
s
.17672 .68114 m
.18573 .72072 L
s
.16973 .66244 m
.1751 .70501 L
s
.12182 .53306 m
.10076 .59498 L
s
.63379 .77182 m
.60116 .74561 L
s
.1751 .70501 m
.18934 .74461 L
s
.17416 .73649 m
.19541 .77546 L
s
.17267 .73974 m
.19476 .77916 L
s
.16 .64499 m
.16207 .69155 L
s
.11426 .52351 m
.09115 .58852 L
s
.84014 .93356 m
.78671 .90942 L
s
.13714 .58731 m
.12758 .64331 L
s
.14498 .60979 m
.14005 .66258 L
s
.15742 .64646 m
.15991 .69402 L
s
.16581 .76723 m
.19476 .8082 L
s
.59365 .74899 m
.56208 .72328 L
s
.1616 .74192 m
.18506 .78554 L
s
.14712 .63991 m
.14865 .69165 L
s
.16207 .69155 m
.17416 .73649 L
s
.76627 .87292 m
.72035 .84489 L
s
.11278 .54947 m
.09541 .61554 L
s
.15991 .69402 m
.17267 .73974 L
s
.71059 .82824 m
.67079 .80013 L
s
.75548 .86469 m
.71043 .8362 L
s
.67079 .80013 m
.63379 .77182 L
s
.44591 .67849 m
.422 .66586 L
s
.14116 .84722 m
.19229 .8938 L
s
.14405 .82824 m
.19003 .87481 L
s
.62491 .77222 m
.58932 .74366 L
s
.14767 .76053 m
.17669 .80902 L
s
.52721 .71558 m
.49713 .69313 L
s
.14865 .69165 m
.1616 .74192 L
s
.14005 .66258 m
.14696 .71692 L
s
.09935 .54802 m
.08188 .62007 L
s
.14696 .71692 m
.16581 .76723 L
s
.11342 .58943 m
.10501 .65555 L
s
.12758 .64331 m
.1308 .70312 L
s
.13614 .78995 m
.17347 .84191 L
s
.13343 .80882 m
.17578 .86095 L
s
.63122 .77895 m
.59365 .74899 L
s
.12485 .8165 m
.17017 .87188 L
s
.10076 .59498 m
.09409 .66678 L
s
.66584 .80392 m
.62491 .77222 L
s
.1308 .70312 m
.14767 .76053 L
s
.71043 .8362 m
.66584 .80392 L
s
.72035 .84489 m
.67413 .81194 L
s
.09115 .58852 m
.08336 .66471 L
s
.67413 .81194 m
.63122 .77895 L
s
.09541 .61554 m
.09383 .6898 L
s
.47684 .69729 m
.44591 .67849 L
s
.10501 .65555 m
.11242 .72515 L
s
.11044 .76395 m
.14405 .82824 L
s
.11242 .72515 m
.13614 .78995 L
s
.56496 .74473 m
.52721 .71558 L
s
.10253 .78006 m
.14116 .84722 L
s
.10499 .74122 m
.13343 .80882 L
s
.08188 .62007 m
.08215 .70066 L
s
.09409 .66678 m
.10499 .74122 L
s
.09456 .74422 m
.12485 .8165 L
s
.09383 .6898 m
.11044 .76395 L
s
.78671 .90942 m
.72606 .86983 L
s
.08336 .66471 m
.09456 .74422 L
s
.85279 .97081 m
.78078 .92976 L
s
.08215 .70066 m
.10253 .78006 L
s
.61126 .78139 m
.56496 .74473 L
s
.51672 .72478 m
.47684 .69729 L
s
.72606 .86983 m
.6658 .82452 L
s
.6658 .82452 m
.61126 .78139 L
s
.56745 .76336 m
.51672 .72478 L
s
.78078 .92976 m
.70309 .87243 L
s
.63006 .81372 m
.56745 .76336 L
s
.70309 .87243 m
.63006 .81372 L
s
.25 Mabswid
.60683 0 m
.93119 .48778 L
s
.93119 .48778 m
1 1.11084 L
s
1 1.11084 m
.62278 .68523 L
s
.62278 .68523 m
.60683 0 L
s
.08883 .21714 m
0 .87886 L
s
0 .87886 m
.62278 .68523 L
s
.62278 .68523 m
.60683 0 L
s
.60683 0 m
.08883 .21714 L
s
.08883 .21714 m
.60683 0 L
s
.1913 .17418 m
.19669 .18033 L
s
[(-10)] .18051 .16189 .8777 1 Mshowa
.31978 .12033 m
.32492 .12669 L
s
[(0)] .30949 .10761 .80882 1 Mshowa
.45393 .06409 m
.45879 .07067 L
s
[(10)] .4442 .05094 .73995 1 Mshowa
.59412 .00533 m
.59867 .01212 L
s
[(20)] .585 -0.00825 .67107 1 Mshowa
.125 Mabswid
.21656 .16359 m
.21977 .16731 L
s
.24204 .15292 m
.24521 .15665 L
s
.26773 .14214 m
.27088 .14591 L
s
.29364 .13128 m
.29676 .13507 L
s
.34615 .10927 m
.3492 .11312 L
s
.37274 .09813 m
.37576 .10199 L
s
.39956 .08688 m
.40255 .09078 L
s
.42663 .07554 m
.42958 .07946 L
s
.48147 .05255 m
.48435 .05652 L
s
.50925 .0409 m
.5121 .0449 L
s
.53729 .02915 m
.5401 .03317 L
s
.56557 .01729 m
.56835 .02134 L
s
.16625 .18468 m
.16952 .18835 L
s
.14141 .19509 m
.14471 .19873 L
s
.11678 .20542 m
.1201 .20903 L
s
.09235 .21566 m
.0957 .21925 L
s
.25 Mabswid
0 .87886 m
.4707 1.23294 L
s
.04572 .91325 m
.04671 .90513 L
s
[(-20)] .04375 .92949 .12171 -1 Mshowa
.23895 1.05861 m
.23952 1.05045 L
s
[(0)] .23779 1.07492 .07103 -1 Mshowa
.40267 1.18177 m
.40292 1.17359 L
s
[(20)] .40216 1.19812 .03078 -1 Mshowa
.125 Mabswid
.09722 .95199 m
.09775 .94711 L
s
.1465 .98906 m
.14696 .98418 L
s
.1937 1.02457 m
.1941 1.01968 L
s
.28236 1.09127 m
.28266 1.08637 L
s
.32405 1.12263 m
.3243 1.11773 L
s
.36413 1.15277 m
.36432 1.14787 L
s
.43976 1.20967 m
.43987 1.20477 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235.375, 290.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0001/b000`400?l00000o`00003oo`3ooomR
0?ooo`00o`3ooomR0?ooo`00o`3ooomR0?ooo`00a@3oool00`3ookl0M000000000040000000507Bo
o`3oool0oooo0?ooo`3o_g@00`0000000`1d_ol0oooo0?ooo`2:0?ooo`00aP3oool00`2oM000001d
0;ooo`020?ooo`030=nLM02Lgol0oooo0080oooo00H0W4Qd0;ooo`3oool0oono07@0M02ooon;0?oo
o`00a`3oool00`3o_g@0001809cOo`050?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3o
ool0RP3oool00<P0oooo00<0omnL04P00018W=l0103oool00`3OW4P0B9cO0?ooo`020?ooo`030?no
M000M;l0oooo08X0oooo003:0?ooo`0309a80018W=l0oooo0080oooo00<0gia804RLg`3oool00P3o
ool00`3o_g@007Bo0?ooo`2:0?ooo`00b`3oool01P2LB7@0_ooo0?ooo`3oool0gia804RLg`<0oooo
00<0okmd001d_`3oool0RP3oool00<H0oooo00<0gia807Boo`3oool00P3oool01P2oM000M;oo0?oo
o`3oool0okmd04RLg`<0oooo00<0gia804RLg`3oool0RP3oool00<H0oooo00L0okmd0000M02oool0
oooo0?noM00004P0W=oo00<0oooo00H0W4P007Boo`3oool0omnL04P0M02ooon;0?ooo`00a`3oool0
1@3o_g@000000000000004P0W=oo00@0oooo00D0oono07@000000000001809cOo`2<0?ooo`00o`3o
oomR0?ooo`00o`3ooomR0?ooo`00o`3ooomR0?ooo`00o`3ooomR0?ooo`00o`3ooomR0?ooo`00o`3o
oomR0?ooo`00f`3oool2000008@0oooo003I0?ooo`80000000<0oooo000000000000P`3oool00=L0
oooo0P0000030?ooo`800000P`3oool00=@0oooo0`0000000`3oool000000?ooo`020?ooo`030000
003oool000000880oooo003B0?ooo`8000001@3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo07l0oooo002F0?ooo`030?n?=@000000000000<0000000D003F?0?ooo`3oool0oooo
0?n?=@030000000303F?o`3oool0oooo02P0oooo0`00000:0?ooo`040000003oool0oooo00000840
oooo002I0?ooo`0305lD501Oa?l0oooo00@0oooo00H0Ga@e08ooo`3oool0oon?03D0=@2?oolW0?oo
o`8000003@3oool01@000000oooo0?ooo`3oool000000800oooo002I0?ooo`0305lD501Oa?l0oooo
00<0oooo00<0ohle000eS`3oool00P3oool00`34Ga@055o40?ooo`0T0?ooo`8000000P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0O@3oool009T0
oooo00<0Ga@D05o4o`3oool00`3oool00`34Ga@055o40?ooo`020?ooo`030?n?=@00=Hl0oooo0240
oooo0`00000A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0O@3oool009T0oooo
00<0Ga@D05o4o`3oool00`3oool00`34Ga@055o40?ooo`020?ooo`030?n?=@00=Hl0oooo01l0oooo
0P00000D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0O03oool009T0oooo00<0
Ga@D05o4o`3oool00`3oool00`34Ga@055o40?ooo`020?ooo`030?n?=@00=Hl0oooo01`0oooo0`00
000F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0N`3oool009T0oooo00<0Ga@D
05o4o`3oool00`3oool00`3oScD055o40?ooo`020?ooo`030<AO500DGl@0oooo01X0oooo0P000002
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1k
0?ooo`00UP3oool01@34Ga@00000000DG`1O51@0GlCo00D0oooo00H0Ga@003F?o`3oool0olAO01@0
=@2?oolI0?ooo`8000006`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07X0oooo
002H0?ooo`030<AO500001@0GlCo00D0oooo00D0oon?03D000000000000D05o4o`0G0?ooo`<00000
7@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo07T0oooo002j0?ooo`800000803o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo07T0oooo002h0?ooo`8000000P3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0N03oool0
0;D0oooo0`00000T0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0M`3oool00;80
oooo0`00000W0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0M`3oool00;00oooo
0`00000Y0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0MP3oool00:h0oooo0P00
00030?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`1e0?ooo`00[03oool2000002h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1e
0?ooo`00Z03oool400000300oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1d0?oo
o`00Y`3oool300000380oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1c0?ooo`00
Y03oool300000080oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo07<0oooo001b0?ooo`050?n?=@00000000000000000eSol0:`3oool2000000H0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0780oooo
001b0?ooo`0605lD=@2?ool0oooo0?ooS`0e03D0Sooo9`3oool3000003/0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`1a0?ooo`00L@3oool00`3oScD003F?0?ooo`020?ooo`030<AO
500DGl@0oooo02@0oooo0`00000m0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
L@3oool00740oooo00<0a5lD01AOa03oool00P3oool00`3oScD003F?0?ooo`0R0?ooo`8000000`3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0L03o
ool00740oooo00<0a5lD01AOa03oool00P3oool00`3oScD003F?0?ooo`0P0?ooo`800000@P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo06l0oooo001a0?ooo`030<AO500DGl@0oooo
0080oooo00<0ohle000eS`3oool07@3oool3000004@0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`1_0?ooo`00L@3oool00`3oScD055o40?ooo`020?ooo`030<AO500DGl@0oooo01/0
oooo0P0000000`3oool000000?ooo`140?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0KP3oool00780oooo00H0Ga@003F?o`3oool0olAO01@0=@2?oolI0?ooo`<00000B@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo06d0oooo001b0?ooo`050?ooS`0e000000000000
501Oa?l0603oool2000004`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1]0?oo
o`00S@3oool2000004h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1/0?ooo`00
RP3oool3000000030?ooo`000000oooo04d0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`1[0?ooo`00R03oool2000005<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`1[0?ooo`00QP3oool2000005D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Z
0?ooo`00P`3oool3000005L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1Y0?oo
o`00P@3oool200000080oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo06T0oooo001n0?ooo`<00000G03oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo06P0oooo001k0?ooo`<00000G`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo06L0oooo001j0?ooo`<00000H03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo06L0oooo000m0?ooo`030?n?=@000000000000<0000000D003F?0?ooo`3oool0oooo0?n?=@03
0000000303F?o`3oool0oooo02T0oooo0`0000030?ooo`030000003oool0oooo05d0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`1V0?ooo`00@03oool00`1O51@0GlCo0?ooo`040?oo
o`0605lD=@2?ool0oooo0?ooS`0e03D0Sooo:03oool2000006H0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`1V0?ooo`00@03oool00`1O51@0GlCo0?ooo`030?ooo`030?n?=@00=Hl0
oooo0080oooo00<0a5lD01AOa03oool0903oool3000006P0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`1U0?ooo`00@03oool00`1O51@0GlCo0?ooo`030?ooo`030<AO500DGl@0oooo
0080oooo00<0ohle000eS`3oool08P3oool200000080oooo00<000000?ooo`3oool0IP3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo06@0oooo000d0?ooo`0305lD00000000000000<0
000000<001AO0?ooo`3oool00`3oool00`1O51@0GlCo0?ooo`030?ooo`030<AO500DGl@0oooo0080
oooo00<0ohle000eS`3oool0803oool2000006d0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`1T0?ooo`00@03oool00`1O51@0GlCo0?ooo`030?ooo`030<AO500DGl@0oooo0080oooo
00<0ohle000eS`3oool07@3oool3000006l0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`1S0?ooo`00@03oool00`1O51@0GlCo0?ooo`030?ooo`030?n?=@0DGl@0oooo0080oooo00<0
a5lD01AOa03oool06`3oool200000780oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`1R0?ooo`00?@3oool01@34Ga@00000000DG`1O51@0GlCo00D0oooo00H0Ga@003F?o`3oool0olAO
01@0=@2?oolJ0?ooo`8000000P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0HP3oool003l0oooo00<0a5lD0000501Oa?l01@3oool01@3oohl0=@00
0000000001@0GlCo01P0oooo0`00001f0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0H@3oool00640oooo0`00001i0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
H03oool005l0oooo1000001j0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0H03o
ool005d0oooo0P00001n0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0G`3oool0
05/0oooo0P0000200?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0GP3oool005P0
oooo0`0000220?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0GP3oool005H0oooo
0P0000020?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`1M0?ooo`00D`3oool3000008L0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`1L0?ooo`00D03oool3000008X0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1L
0?ooo`00C`3oool3000008/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1K0?oo
o`00C03oool3000000<0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo05X0oooo001:0?ooo`800000T@3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo05X0oooo00180?ooo`800000T`3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo05T0oooo00150?ooo`<0000000<0oooo0000003oool0TP3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo05P0oooo00130?ooo`800000V03oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo05P0oooo00100?ooo`<00000VP3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo05L0oooo000n0?ooo`<00000W03oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo05H0oooo000l0?ooo`8000000`3oool00`000000oooo0?ooo`2I0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0EP3oool003T0oooo0`00002Q0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0E@3oool003L0oooo0P00002T0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0E03oool003@0oooo0`0000000`3oool000000?ooo`2T0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0E03oool00380oooo0P00002Z0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0D`3oool002l0oooo0`00002/0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0DP3oool002h0oooo0`00002]0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool0DP3oool002h0oooo0P00002^0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool0D@3oool002h0oooo00<000000?ooo`000000[@3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo0500oooo000^0?ooo`040000003oool0oooo00000:`0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1@0?ooo`00;@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`1?0?ooo`00;@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0:P0oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`1>0?ooo`00;@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1>
0?ooo`00;@3oool00`000000oooo000000050?ooo`030000003oool0oooo0:H0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`1=0?ooo`00;@3oool2000000H0oooo00<000000?ooo`3o
ool0YP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo04`0oooo000]0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo04`0oooo000Q0?ooo`050?noM000000000000000001d_ol01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`1;0?ooo`008@3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`H0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool0BP3oool00200oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`040?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo04X0oooo000P0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0103o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`190?ooo`00803oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0
oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2P0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool0B03oool00200oooo00<0gia804RLg`3oool00P3oool00`3o
_g@007Bo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0W`3oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo04P0oooo000P0?ooo`030?noM018W=l0oooo0080
oooo00<0gia804RLg`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo09h0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`170?ooo`008@3oool01P2LB000M;oo
0?ooo`3ogi`0B01d0;ooo`D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2M0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0AP3oool00240oooo00D0oono07@00000
0000001809cOo`060?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0W03oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo04H0oooo000[0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo04D0
oooo000[0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0VP3oool00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo04@0oooo000[0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0V@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo04@0oooo000[
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo04<0oooo000[0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0U`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0480oooo000[0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo0480oooo000[0?ooo`800000603oool00`000000oooo0?ooo`2F0?ooo`030000
003oool0oooo03`0oooo00<000000?ooo`3oool0@@3oool002X0oooo0P00000J0?ooo`030000003o
ool0oooo09D0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`100?ooo`00:P3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`100?ooo`00:P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
09<0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0o0?ooo`00:P3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0?`3oool00`000000
oooo0?ooo`0n0?ooo`00:P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0940oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0n0?ooo`00:P3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`0m0?ooo`00:P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0l0?ooo`00:P3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0l0?oo
o`00:@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0k0?ooo`00:@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0j0?ooo`00:@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`0j0?ooo`00:@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0i0?ooo`00:@3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0h0?ooo`00:@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo08T0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0h0?ooo`00:@3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`0g0?ooo`00:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo08L0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`0f0?ooo`00:03oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0f
0?ooo`00:03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`0e0?ooo`00:03oool2000002d0oooo00<000000?ooo`3o
ool0Q@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03@0oooo000X0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo03@0oooo000X0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0P`3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo03<0oooo000X0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo0380oooo000X0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0P@3oool00`00
0000oooo0?ooo`1:0?ooo`030000003oool0oooo0380oooo000W0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0340
oooo000W0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0F`3oool300000240oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0a0?ooo`009`3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`1<0?ooo`030000003oool0oooo0300oooo000W0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool0G@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool0;`3oool002L0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1M0?oo
o`8000007@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo02l0oooo000W0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0GP3oool2000001/0oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`0^0?ooo`009`3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo0600oooo0P00000I0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
;@3oool002H0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`1Q0?ooo`8000005`3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo02d0oooo000V0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0500oooo00<000000?ooo`3oool0;03oool002H0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0=0?oooa800000@`3oool2000001@0oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`0[0?ooo`009P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00D0
oooo1`0000050?ooo`P000001@3oool6000003l0oooo0P00000B0?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool0:`3oool002H0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`04000000@0oooo200000080?ooo`P000000`3oool4000003d0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo02X0oooo000V0?ooo`030000003o
ool0oooo03`0oooo100000020?ooo`H00000603oool6000000040?ooo`0000000000000003/0oooo
0P00000?0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0:@3oool002H0oooo00<0
00000?ooo`3oool0>03oool4000000030?ooo`000000000000<000002P3oool900000140oooo0`00
0000103oool0000000000000000j0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
D`3oool00`000000oooo0?ooo`0Y0?ooo`009@3oool00`000000oooo0?ooo`0g0?ooo`8000000P3o
ool3000000<0oooo00<000000?ooo`3oool00P3ooolH000000`0oooo0`000000103oool000000000
0000000h0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`0X0?ooo`009@3oool00`000000oooo0000000e0?ooo`80000000@0oooo0000000000000000
1`3oool7000001D0oooo1`0000080?ooo`<0000000<0oooo000000000000=`3oool2000000/0oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0W0?ooo`009@3oool2000003@0oooo1@00
00060?ooo`L000007@3oool8000000H0oooo0P0000000`3oool000000000000g0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0W0?ooo`009@3oool0
0`000000oooo0?ooo`0a0?ooo`@000001P3oool6000000<0oooo00<000000?ooo`3oool0803oool6
000000D0oooo0P0000000`3oool000000000000f0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0V0?ooo`009@3oool00`000000oooo0?ooo`0_0?oo
o`@000001P3oool5000000L0oooo00<000000?ooo`3oool00P3ooolG000000/0oooo100000040?oo
o`80000000<0oooo000000000000=@3oool2000000L0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0U0?ooo`009@3oool00`000000oooo0?ooo`0]0?ooo`@000001P3oool4000000T0
oooo1P00000G0?ooo`D000002@3oool3000000@0oooo0P0000000`3oool000000000000e0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0U0?ooo`00
9@3oool00`000000oooo0?ooo`0[0?ooo`80000000<0oooo0000003oool0103oool5000000L0oooo
100000030?ooo`030000003oool0oooo01`0oooo0`0000080?ooo`<00000103oool2000000030?oo
o`000000oooo03@0oooo0P0000040?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
903oool002D0oooo00<000000?ooo`3oool0:P3oool010000000oooo0000000000040?ooo`@00000
1`3oool3000000L0oooo00<000000?ooo`3oool07`3oool3000000H0oooo0`0000050?ooo`@00000
=@3oool01@000000oooo0?ooo`3oool0000005/0oooo00<000000?ooo`3oool08`3oool002@0oooo
00<000000?ooo`3oool0:@3oool2000000030?ooo`000000oooo00<0oooo100000070?ooo`800000
2`3oool00`000000oooo0?ooo`0Q0?ooo`8000001P3oool3000000D0oooo0`00000e0?ooo`040000
003oool0oooo000005/0oooo00<000000?ooo`3oool08`3oool002@0oooo00<000000?ooo`3oool0
:03oool010000000oooo0000000000030?ooo`@000001P3oool3000000h0oooo00<000000?ooo`3o
ool08P3oool3000000@0oooo0`0000060?ooo`<00000=03oool00`000000oooo0000001L0?ooo`03
0000003oool0oooo0280oooo000T0?ooo`030000003oool0oooo02L0oooo0`0000040?ooo`030000
003oool0000000H0oooo0P00000B0?ooo`030000003oool0oooo02@0oooo0P0000040?ooo`<00000
103oool010000000oooo0?ooo`00000F0?ooo`<000006`3oool2000005d0oooo00<000000?ooo`3o
ool08@3oool002@0oooo00<000000?ooo`3oool09@3oool3000000@0oooo100000050?ooo`800000
5@3oool>000001X0oooo0P0000040?ooo`<000000`3oool010000000oooo0?ooo`00000C0?ooo`80
00000`3oool4000001P0oooo0P00001L0?ooo`030000003oool0oooo0240oooo000T0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`000000103oool00`000000oooo000000050?ooo`800000
4`3oool4000000030?ooo`000000oooo00/0oooo1`00000E0?ooo`030000003oool0oooo00<0oooo
0`0000020?ooo`80000000<0oooo0000003oool03`3oool2000000T0oooo0`00000E0?ooo`030000
003oool0000005`0oooo00<000000?ooo`3oool0803oool002@0oooo00<000000?ooo`3oool08P3o
ool2000000030?ooo`000000oooo00<0oooo0`0000050?ooo`030000003oool0oooo00l0oooo1000
00060?ooo`030000003oool0oooo0100oooo1@00000A0?ooo`800000103oool3000000<0oooo00<0
00000?ooo`0000003`3oool00`000000oooo0?ooo`0;0?ooo`<000004P3oool010000000oooo0?oo
o`00001L0?ooo`030000003oool0oooo01l0oooo000T0?ooo`030000003oool0oooo0240oooo00@0
00000?ooo`3oool000000`3oool3000000D0oooo0P00000@0?ooo`8000002`3oool00`000000oooo
0?ooo`0D0?ooo`<00000403oool00`000000oooo0?ooo`030?ooo`8000000`3oool00`000000oooo
0000000=0?ooo`030000003oool0oooo00l0oooo0`00000?0?ooo`050000003oool0oooo0?ooo`00
0000F`3oool00`000000oooo0?ooo`0O0?ooo`008`3oool00`000000oooo0?ooo`0Q0?ooo`040000
003oool0oooo000000<0oooo0P0000050?ooo`8000003`3oool3000000h0oooo00<000000?ooo`3o
ool05P3oool3000000h0oooo0P0000040?ooo`8000000`3oool2000000d0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo0P00001J0?ooo`03
0000003oool0oooo01h0oooo000S0?ooo`030000003oool0oooo0200oooo00@000000?ooo`3oool0
00000P3oool3000000@0oooo0P00000?0?ooo`8000002`3ooolD000000h0oooo0P00000>0?ooo`03
0000003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`00000;0?ooo`030000003oool0
oooo01@0oooo0P00000<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0M0?ooo`008`3oool00`000000oooo0?ooo`0O0?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0=0?ooo`8000002P3oool3
000000P0oooo00<000000?ooo`3oool02@3oool6000000X0oooo0P00000=0?ooo`800000103oool0
0`000000oooo0?ooo`02000000/0oooo00<000000?ooo`3oool05P3oool2000000X0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01d0oooo000S0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`0000000P3oool00`000000oooo000000040?oo
o`030000003oool0oooo00`0oooo0P0000090?ooo`<000001P3ooolB000000D0oooo1@0000070?oo
o`8000003@3oool010000000oooo0?ooo`3oool200000080oooo0P00000:0?ooo`030000003oool0
oooo01P0oooo0P0000080?ooo`030000003oool0oooo00H0oooo0P00001H0?ooo`030000003oool0
oooo01`0oooo000S0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`0000000P3oool00`00
0000oooo000000040?ooo`030000003oool0oooo00/0oooo0P0000080?ooo`<000001@3oool40000
00L0oooo00<000000?ooo`3oool0203oool3000000L0oooo0P0000070?ooo`800000303oool01@00
0000oooo0?ooo`3oool0000000<0oooo0P0000080?ooo`030000003oool0oooo01/0oooo0P000006
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0K
0?ooo`008`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool000000080oooo00<000000?oo
o`000000103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo0P0000040?oo
o`@00000303oool00`000000oooo0?ooo`0:0?ooo`@000001@3oool2000000L0oooo00<000000?oo
o`3oool02@3oool010000000oooo0?ooo`3oool200000080oooo0P0000080?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool06`3oool002<0oooo00<000000?ooo`000000703oool00`00
0000oooo000000030?ooo`800000103oool00`000000oooo0?ooo`0:0?ooo`8000001`3oool20000
00<0oooo0`00000A0?ooo`030000003oool0oooo00d0oooo100000030?ooo`8000001P3oool20000
00X0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`8000001`3oool00`000000oooo0?ooo`0N
0?ooo`8000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool06P3oool002<0oooo0P00000L0?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`090?ooo`8000001`3oool200000080oooo0`00000:0?oo
oa<000002`3oool2000000<0oooo0P0000060?ooo`030000003oool0oooo00P0oooo00@000000?oo
o`3oool0oooo0P0000000`3oool00000000000070?ooo`030000003oool0oooo0200oooo00@00000
0?ooo`3oool000003@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01T0oooo000;
0?ooo`030?oo_`1d0000000000@0000000D0M;oo0?ooo`3oool0oooo0?noM0030000000307Boo`3o
ool0oooo00D0oooo00<000000?ooo`3oool06`3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`8000000P3o
ool2000000T0oooo100000000`3oool0000000000003000000D0oooo00<000000?ooo`0000002P00
00080?ooo`8000000`3oool00`000000oooo0?ooo`040?ooo`8000002@3oool01@000000oooo0?oo
o`3oool000000080oooo0P0000060?ooo`030000003oool0oooo0240oooo00<000000?ooo`000000
3P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo01T0oooo000<0?ooo`030;md0000
07@0_ooo0080oooo00<0giad09cOo`3oool00P3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`H0
oooo00<000000?ooo`3oool06P3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`8000000P3oool2000000P0
oooo0`0000000`3oool0000000000002000000/0oooo00<000000?ooo`3oool0103oool7000000P0
oooo00@000000?ooo`3oool0oooo0P0000060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00P0000000`3oool00000000000060?ooo`030000003oool0oooo0280oooo0P00000?0?oo
o`030000003oool0oooo05@0oooo00<000000?ooo`3oool0603oool000d0oooo00<0okmd0000B02L
gol01@3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo00D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000203oool60000
0100oooo00<000000?ooo`3oool02@3oool4000000H0oooo0P0000030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo0P000005
0?ooo`030000003oool0oooo02<0oooo0P00000?0?ooo`800000E@3oool00`000000oooo0?ooo`0G
0?ooo`003P3oool00`3ogi`0B00004RLg`040?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d
_`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool000000080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P0000070?ooo`@000002P3oool=000000`0oooo0`0000060?ooo`050000003oool0oooo
0?ooo`0000001P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080000000<0oooo
0000000000001@3oool00`000000oooo0?ooo`0T0?ooo`800000403oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo01L0oooo000@0?ooo`0309a80018W=l0oooo0080oooo00<0gia804RL
g`3oool00P3oool00`3o_g@007Bo0?ooo`050?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`0000000P3oool2000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?oo
o`8000000P3oool00`000000oooo0?ooo`050?ooo`@000001`3oool5000000`0oooo1`0000080?oo
o`<000001@3oool200000080oooo0P0000050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0903oool01000
0000oooo00000000000?0?ooo`030000003oool0oooo0540oooo0P00000H0?ooo`004@3oool01P2L
B7@0_ooo0?ooo`3oool0gia804RLg`<0oooo00<0okmd001d_`3oool01@3oool00`000000oooo0?oo
o`0G0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`080?ooo`8000001@3oool00`000000oooo0?ooo`02000000H0oooo0`0000080?ooo`800000
2@3oool;000000@0oooo100000060?ooo`<000001@3oool200000080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080000000<0oooo0000003oool0
103oool00`000000oooo0?ooo`0T0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000
oooo0?ooo`1=0?ooo`<0000000<0oooo0000003oool05`3oool000`0oooo00<0gia807Boo`3oool0
0P3oool01P2oM000M;oo0?ooo`3oool0okmd04RLg`<0oooo00<0gia804RLg`3oool01@3oool00`00
0000oooo0?ooo`0F0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`030000003oool0
oooo00@0oooo0`0000070?ooo`<00000103oool7000000030?ooo`000000000000@000000`3oool6
000000<0oooo0P0000050?ooo`@000001@3oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P0000000`3oool00000000000040?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo04T0oooo0`0000040?ooo`030000003oool0oooo01H0oooo000<0?ooo`070?noM00007@0
_ooo0?ooo`3o_g@0001809cOo`030?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo1@3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool000000080oooo0P0000040?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000H0oooo0P000007
0?ooo`8000000P3oool5000000030?ooo`000000000000D000001P3oool6000000<0oooo0P000003
0?ooo`8000001@3oool4000000@0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`040?ooo`050000003oool0oooo0000003oool00P0000030?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool00`3oool2000000h0oooo00<000000?ooo`3oool0A@3oool3000000L0oooo
00<000000?ooo`3oool05P3oool000d0oooo00D0okmd000000000000001809cOo`040?ooo`050?oo
_`1d000000000000B02Lgol01P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool000000080
oooo0P0000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool01@000000
oooo0?ooo`3oool0000000D0oooo0`0000060?ooo`8000000P3oool2000000030?ooo`0000000000
00<000004P3oool5000000030?ooo`000000000000<0oooo0P0000050?ooo`<00000103oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool010000003
0?ooo`030000003oool0oooo00d0oooo1`00000A0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`<000002P3oool00`000000oooo0?ooo`0F
0?ooo`008@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool000000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000040?ooo`<000001P3oool200000080oooo0P0000000`3oool0000000000009
0?ooo`/00000103oool010000000oooo0?ooo`3oool2000000030?ooo`000000000000<0oooo0P00
00050?ooo`800000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00/0oooo0P0000070?oo
o`<000003P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0?@3oool3000000h0oooo00<000000?ooo`3oool05@3oool00240oooo00<000000?ooo`3o
ool05@3oool00`000000oooo000000020?ooo`800000103oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P0000040?ooo`<000001@3oool200000080
oooo0P0000000`3oool00000000000060?ooo`D000002`3oool6000000@0oooo0P0000000`3oool0
0000000000030?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000300000080oooo00<000000?oo
o`3oool02@3oool200000080oooo200000020?ooo`<000002`3oool00`000000oooo0?ooo`070?oo
o`8000003@3oool00`000000oooo0?ooo`0i0?ooo`<000004@3oool00`000000oooo0?ooo`0E0?oo
o`008@3oool00`000000oooo0?ooo`0E0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?oo
o`8000001@3oool2000000<0oooo00@000000?ooo`0000000000103oool4000000@0oooo3P000004
0?ooo`<000000`3oool2000000030?ooo`00000000000080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo000000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0000000300000080oooo00<000000?ooo`3oool01`3oool2000000040?ooo`00
00000000000000P0oooo0`0000020?ooo`8000002@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0=@3oool3000001@0oooo00<000000?ooo`3oool0
5@3oool00240oooo00<000000?ooo`3oool0503oool00`000000oooo000000020?ooo`8000000`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
1@3oool2000000D0oooo00@000000?ooo`3oool0oooo100000030?ooo`<000001@3oool3000000D0
oooo1@0000040?ooo`8000000`3oool010000000oooo0000000000030?ooo`80000000D0oooo0000
00000000oooo000000050?ooo`030000003oool0000000<0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`040?ooo`D000000P3oool00`000000oooo0?ooo`060?ooo`040000003oool0
oooo000000h0oooo0`000000103oool000000000000000060?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0b0?ooo`<000005`3oool00`000000oooo
0?ooo`0E0?ooo`008@3oool00`000000oooo0?ooo`0D0?ooo`8000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
00050?ooo`8000001@3oool010000000oooo0?ooo`3oool3000000<0oooo0P0000050?ooo`<00000
0P3oool@000000030?ooo`000000000000<000000P3oool2000000<0oooo0P0000000`3oool00000
0?ooo`02000000@0oooo0P0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool0103oool3000000050?ooo`000000oooo0?ooo`0000001`3oool010000000oooo0?ooo`00000B
0?ooo`8000000P3oool2000000@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo02h0oooo0`00000J0?ooo`030000003oool0oooo01D0oooo000P0?oo
o`030000003oool0oooo01@0oooo0P0000030?ooo`8000000`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000001@3oool2000000@0oooo0P0000030?oo
o`8000000`3oool2000000<0oooo3000000;0?ooo`D000000P3oool300000080oooo0P0000030?oo
o`030000003oool000000080oooo0P0000030?ooo`8000000`3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool000005@3oool3000000030?ooo`00000000000080oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02X0oooo
0`00000M0?ooo`030000003oool0oooo01D0oooo000P0?ooo`030000003oool0oooo01@0oooo0P00
00030?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000D0oooo0P0000040?ooo`040000003oool0oooo0?ooo`8000000`3oool2000000<0
oooo0P0000000`3oool0000000000004000001<0oooo100000020?ooo`<000000P3oool200000080
oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool00000008000000P3oool00`00
0000oooo0?ooo`040?ooo`<000006@3oool6000000l0oooo0P00000;0?ooo`030000003oool0oooo
02H0oooo0`00000P0?ooo`030000003oool0oooo01D0oooo000P0?ooo`030000003oool0oooo01<0
oooo0P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0P0000040?ooo`040000003oool0oooo
0?ooo`8000000`3oool010000000oooo0?ooo`3oool2000000040?ooo`00000000000?ooo`800000
603oool500000080oooo0P0000020?ooo`80000000@0oooo00000000000000000P3oool00`000000
oooo0?ooo`020?ooo`8000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000000P0000020?ooo`030000003oool0oooo00<0oooo0P00000N0?oo
o`<000004@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0280oooo0`00000S0?oo
o`030000003oool0oooo01D0oooo000P0?ooo`030000003oool0oooo01<0oooo0P0000020?ooo`80
00000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000103oool2000000@0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0
oooo0080000000@0oooo000000000000oooo0P00000L0?ooo`@000000`3oool200000080oooo00<0
00000?ooo`3oool00P0000020?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool00`3oool400000080oooo00<000000?ooo`3o
ool00`3oool2000000`0oooo1P00000>0?ooo`<00000403oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo01h0oooo0`00000V0?ooo`030000003oool0oooo01D0oooo000P0?ooo`030000
003oool0oooo0180oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000002@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool2000000@0oooo00@000000?oo
o`3oool0oooo0P0000020?ooo`80000000@0oooo000000000000oooo0P0000000`3oool000000000
00090?ooo`l00000203oool4000000<0oooo00@000000?ooo`3oool000000P3oool200000080oooo
00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool010000000oooo0?ooo`00
00050?ooo`@000000P3oool00`000000oooo0?ooo`030?ooo`800000203oool4000000H0oooo0`00
000;0?ooo`@00000403oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01X0oooo0`00
000Z0?ooo`030000003oool0oooo01@0oooo000P0?ooo`8000004`3oool200000080oooo0P000003
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000004
0?ooo`800000103oool010000000oooo0?ooo`3oool200000080oooo00D000000?ooo`3oool00000
0?ooo`02000000030?ooo`000000000000L0oooo200000050?ooo`T000001`3oool400000080oooo
00P000000?ooo`3oool000000?ooo`000000oooo00000080oooo00@000000?ooo`3oool0oooo0P00
00020?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool400000080oooo00<0
00000?ooo`3oool00`3oool2000000L0oooo00<000000?ooo`3oool02`3oool4000000L0oooo00<0
00000?ooo`3oool00`00000?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05P3o
ool3000002d0oooo00<000000?ooo`3oool0503oool00200oooo00<000000?ooo`3oool04@3oool0
0`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000<0oooo0P0000050?ooo`030000003oool0000000800000
0P3oool01`000000oooo0?ooo`000000oooo0000003oool00P0000060?ooo`H000004@3oool40000
00L0oooo0`0000020?ooo`080000003oool0oooo0000003oool000000?ooo`0000020?ooo`0:0000
003oool0oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00`3o
ool4000000030?ooo`000000oooo00<0oooo0P0000070?ooo`030000003oool0oooo0100oooo0`00
00040?ooo`070000003oool0oooo0?ooo`000000oooo0000000?0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool04P3oool300000300oooo00<000000?ooo`3oool0503oool00200oooo
00<000000?ooo`3oool04@3oool200000080oooo0P0000030?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`800000103oool01@000000oooo
0000003oool000000080oooo00P000000?ooo`3oool000000?ooo`000000oooo000000H0oooo1000
000G0?ooo`@000001P3oool300000080oooo00X000000?ooo`3oool000000?ooo`000000oooo0000
003oool000000`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`@0000000<0oooo0000003oool00`3oool2000000H0oooo00<000000?ooo`3oool0
503oool200000080oooo00<000000?ooo`3oool00P3oool4000000h0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0>0?ooo`<00000<`3oool00`000000oooo0?ooo`0D0?ooo`007`3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo
000000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool2000000@0oooo
00D000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0000003oool00`0000060?oo
o`<00000203oool=000000H0oooo100000050?ooo`030000003oool000000080oooo00L000000?oo
o`3oool000000?ooo`000000oooo008000000`3oool01`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`030?ooo`@0000000<0oooo0000003oool00`3oool2000000D0
oooo00<000000?ooo`3oool05`3oool3000000H0oooo00<000000?ooo`0000003P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo0`00000f0?ooo`030000003oool0oooo01@0
oooo000O0?ooo`030000003oool0oooo0140oooo0P0000020?ooo`8000000`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo0P0000050?ooo`030000003oool0oooo0080oooo
00D000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0000003oool00P0000060?oo
o`<000001P3oool8000000@0oooo200000050?ooo`<000001@3oool00`000000oooo000000020?oo
o`050000003oool0oooo0000003oool00P0000001@3oool000000?ooo`3oool000000080oooo00@0
00000?ooo`00000000000`3oool00`000000oooo0?ooo`020?ooo`@0000000<0oooo0000003oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0000000>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
1P3oool3000003T0oooo00<000000?ooo`3oool0503oool001l0oooo00<000000?ooo`3oool0403o
ool00`000000oooo000000020?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`80000000D0
oooo0000003oool0oooo000000020?ooo`040000003oool00000000000H0oooo0`0000050?ooo`D0
0000403oool3000000D0oooo0`0000040?ooo`<000000P3oool01@000000oooo0?ooo`000000oooo
00<000000`3oool010000000oooo0000003oool2000000<0oooo00<000000?ooo`3oool00P3oool4
000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0K
0?ooo`<000001P3oool4000000d0oooo0P00000:0?ooo`030000003oool0oooo0080oooo0`00000l
0?ooo`030000003oool0oooo01@0oooo000O0?ooo`030000003oool0oooo0100oooo00@000000?oo
o`000000oooo0P0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool2
000000@0oooo0P0000040?ooo`050000003oool000000?ooo`0000000P3oool010000000oooo0000
003oool2000000H0oooo0P0000050?ooo`<00000203oool8000000H0oooo0P0000060?ooo`800000
103oool300000080oooo00@000000?ooo`000000oooo0P0000001@3oool000000?ooo`3oool00000
0080oooo0P0000001@3oool000000?ooo`3oool0000000@0oooo100000000`3oool000000?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool6000000X0oooo00<00000
0?ooo`3oool00P0000060?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo00000002000003l0oooo00<000000?ooo`3oool0503oool001l0oooo00<000000?oo
o`3oool0403oool200000080oooo0P0000030?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?oo
o`000000oooo000000020?ooo`040000003oool000000?ooo`8000001P3oool2000000@0oooo0`00
00050?oooa000000103oool3000000D0oooo0P0000040?ooo`<000000P3oool010000000oooo0000
003oool3000000<0oooo00@000000?ooo`000000oooo0P0000020?ooo`030000003oool0oooo00<0
oooo0`0000000`3oool000000?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0203oool4000000040?ooo`000000000000000080oooo100000060?ooo`030000003oool0oooo
0080oooo0P0000050?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool01@3oool30000
04<0oooo00<000000?ooo`3oool04`3oool001l0oooo00<000000?ooo`3oool03`3oool01`000000
oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo0P0000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo0000
00020?ooo`030000003oool0oooo00<000001P3oool00`000000oooo0?ooo`020?ooo`<00000103o
ool4000000l0oooo0`0000030?ooo`<00000103oool2000000@0oooo0`0000020?ooo`030000003o
ool000000080000000D0oooo0000003oool0oooo000000020?ooo`<000000`3oool00`000000oooo
0?ooo`020?ooo`<0000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`0000003`0000030?ooo`030000003oool0oooo00@0oooo
0P0000040?ooo`@000003@3oool010000000oooo0?ooo`3oool3000000<0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`0C0?ooo`007`3oool00`000000oooo0?ooo`0?0?ooo`040000
003oool000000?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`040000003oool000000000
0080oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`800000103oool3000000<0oooo1000
00030?ooo`X000001P3oool3000000<0oooo0P0000040?ooo`800000103oool2000000<0oooo00H0
00000?ooo`00000000000?ooo`0000030?ooo`060000003oool000000000003oool000000P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000T0oooo0`0000020?ooo`L0000000<0oooo0000000000000`0000001@3oool00000
0000003oool0000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000=0?ooo`<0
00001`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01<0oooo000N0?ooo`030000
003oool0oooo0100oooo0P0000020?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000D0oooo0P0000040?oo
o`8000000`3oool3000000@0oooo1@0000070?ooo`@00000103oool2000000@0oooo00<000000?oo
o`3oool00P3oool2000000@0oooo0P0000020?ooo`030000003oool0oooo00<000000`3oool00`00
0000oooo0?ooo`0300000080oooo00<000000?ooo`3oool00P3oool00`000000oooo000000020000
00<0oooo00D000000?ooo`3oool0oooo000000070?ooo`<000000P3oool4000000030?ooo`000000
000000d000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000P0oooo10000000
0`3oool000000?ooo`080?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04`3oool0
01h0oooo00<000000?ooo`3oool0403oool200000080oooo00D000000?ooo`3oool0oooo00000007
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`02
0?ooo`80000000T0oooo0000003oool0oooo0000003oool000000?ooo`0000001@3oool2000000@0
oooo0P0000030?ooo`800000103oool3000000H0oooo0`0000060?ooo`8000000`3oool3000000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`8000000`3oool01P000000
oooo000000000000oooo00000080oooo00<000000?ooo`3oool00`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000000P0000030?ooo`050000003oool0oooo0?ooo`0000001P3o
ool010000000oooo0000003oool3000000040?ooo`000000000000000080oooo0P0000000`3oool0
000000000002000000040?ooo`00000000000?ooo`@00000203oool2000000@0oooo0`0000040?oo
o`<000001P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool04`3oool001h0oooo00<000000?ooo`3oool03`3oool010000000oooo0000003oool20000
00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0000000000020?ooo`030000003oool0
oooo00<00000103oool2000000@0oooo0P0000020?ooo`800000103oool200000080oooo3@000005
0?ooo`8000000`3oool2000000<0oooo00@000000?ooo`3oool0oooo0P0000040?ooo`8000000`3o
ool5000000<0oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo0080oooo00L0
00000?ooo`00000000000?ooo`000000oooo008000000P3oool00`000000oooo0?ooo`050?ooo`80
000000@0oooo000000000000oooo1`0000020?ooo`l00000203oool00`000000oooo0?ooo`030?oo
o`D000002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool04`3oool001h0oooo00<000000?ooo`3oool03`3oool200000080oooo0P0000030?ooo`03
0000003oool0oooo00D0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00T00000
0?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool00000
00D0oooo00<000000?ooo`3oool00P3oool200000080oooo0P0000030?ooo`8000000P3oool50000
00<0oooo2`0000030?ooo`040000003oool0oooo0?ooo`8000000`3oool010000000oooo0?ooo`3o
ool2000000<0oooo0P0000030?ooo`030000003oool00000008000000`3oool020000000oooo0?oo
o`000000oooo0000003oool00000103oool4000000030?ooo`000000oooo008000000P3oool00`00
0000oooo0?ooo`040?ooo`80000000<0oooo0000000000001000000=0?ooo`X00000203oool01000
0000oooo0?ooo`3oool5000000`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo01<0oooo000N0?ooo`030000003oool0oooo00l0oooo0P0000020?oo
o`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0000000000020?ooo`050000003o
ool000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`80
00000`3oool010000000oooo0?ooo`3oool300000080oooo2P0000000`3oool00000000000040000
0080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000040?ooo`8000000`3oool30000
00050?ooo`000000oooo0?ooo`0000000P3oool01@000000oooo0000003oool0000000@0oooo1000
00000`3oool000000?ooo`0200000080oooo00<000000?ooo`3oool0103oool5000000030?ooo`00
0000oooo0100oooo2P0000070?ooo`<000000`3oool00`000000oooo0000000;0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0C0?ooo`007P3oool0
0`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000800000103oool20000
00<0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`8000000`3oool200000080oooo0P00000:
0?ooo`<0000000<0oooo0000000000000P0000020?ooo`8000000P3oool200000080oooo0P000002
0?ooo`8000000`3oool3000000<0oooo100000020?ooo`080000003oool0oooo0000003oool00000
0?ooo`0000040?ooo`80000000D0oooo0000003oool000000?ooo`02000000030?ooo`000000oooo
00D0oooo00D000000?ooo`00000000000?ooo`02000001@0oooo2P0000020?ooo`<0000000<0oooo
000000000000103oool00`000000oooo0000000;0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`0C0?ooo`007P3oool00`000000oooo0?ooo`0>0?oo
o`8000000P3oool200000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000<0oooo0P0000030?ooo`040000003oool0000000000080oooo00D00000
0?ooo`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000000`3oool200000080oooo
00@000000?ooo`3oool0oooo0P0000020?ooo`8000000P3oool<000000030?ooo`00000000000080
oooo0P0000020?ooo`8000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo0P0000030?oo
o`<000000P3oool010000000oooo0000000000020?ooo`030000003oool0oooo00<0000000<0oooo
0000003oool00`3oool2000000050?ooo`000000oooo0000003oool00P0000000`3oool000000?oo
o`050?ooo`80000000@0oooo00000000000000005@3oool00`000000oooo0?ooo`09000000H0oooo
00<000000?ooo`3oool00P3oool3000000/0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo0180oooo000N0?ooo`030000003oool0oooo00h0oooo0P00
00020?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000P3oool00`000000
oooo00000002000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0200000080
oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000P3oool2000000<0oooo1P0000030?oo
o`80000000<0oooo0000000000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P0000020?ooo`8000000`3oool2000000040?ooo`000000oooo0?ooo`<000000P3o
ool00`000000oooo0?ooo`03000000030?ooo`000000oooo00<0oooo0P0000001@3oool000000?oo
o`000000oooo0080000000<0oooo0000003oool0103oool4000000030?ooo`000000oooo00/0oooo
0`0000070?ooo`030000003oool0oooo0080oooo2@0000050?ooo`030000003oool0oooo00<0oooo
0P00000;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0B0?ooo`007@3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000
0`3oool01P000000oooo0?ooo`3oool000000?ooo`8000000P3oool01@000000oooo0000003oool0
000000@0oooo0P0000030?ooo`030000003oool0oooo008000000P3oool01P000000oooo0?ooo`3o
ool000000?ooo`8000000P3oool200000080oooo0`0000060?ooo`8000000`3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo008000000P3oool010000000oooo0?ooo`0000030?oo
o`8000000P3oool200000080oooo00<000000?ooo`0000000`0000000`3oool000000?ooo`020?oo
o`80000000<0oooo0000003oool00`3oool2000000030?ooo`000000oooo0080000000<0oooo0000
000000001P3oool2000000040?ooo`000000oooo000000P0oooo3@000000103oool000000?ooo`3o
ool3000000030?ooo`000000000000H000001@3oool00`000000oooo0?ooo`030?ooo`8000002`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool04P3o
ool001d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0200000080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo0P000002
0?ooo`030000003oool0oooo008000000P3oool00`000000oooo00000002000000@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`8000000P3oool00`000000oooo0?ooo`02000000040?ooo`00
000000000?ooo`80000000D0oooo00000000000000000?ooo`0800000080oooo0`0000001@3oool0
00000?ooo`3oool000000080oooo0P0000001@3oool000000?ooo`3oool000000080oooo0P000002
0?ooo`8000000`3oool010000000oooo0?ooo`3oool5000000030?ooo`000000oooo0080oooo0P00
00020?ooo`040000003oool0oooo0?ooo`L0000000<0oooo0000000000001P3oool4000000030?oo
o`000000oooo00H0oooo0`0000020?ooo`d000001P3oool010000000oooo0000003oool3000000D0
oooo00<000000?ooo`3oool00`3oool2000000/0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo0180oooo000M0?ooo`030000003oool0oooo00h0oooo
0P0000020?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000<0oooo00H000000?ooo`3oool0oooo0000003oool200000080oooo00D00000
0?ooo`000000oooo000000040?ooo`8000000P3oool200000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`04000000040?ooo`00000000000?ooo`<0000000<0oooo00000000
00001`0000030?ooo`@0000000@0oooo0000003oool0oooo100000020?ooo`040000003oool00000
000000<0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`040000003oool0000000000080oooo
00<000000?ooo`3oool00`0000000`3oool000000?ooo`020?ooo`L0000000<0oooo000000000000
1P3oool00`000000oooo00000002000000L0oooo1P0000000`3oool000000000000:000000L0oooo
200000040?ooo`030000003oool0oooo00<0oooo0P00000:0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0B0?ooo`007@3oool00`000000oooo0?oo
o`0>0?ooo`8000000P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000020?ooo`8000000`3oool010000000oooo0000000000020?ooo`03
0000003oool0000000800000103oool01@000000oooo0?ooo`3oool000000080oooo0P0000001@3o
ool000000?ooo`3oool000000080oooo0`0000020?ooo`050000003oool000000000003oool00`00
00000`3oool00000000000040?ooo`@000000`3oool01@000000oooo0000003oool000000080oooo
0`0000020?ooo`030000003oool0oooo008000000P3oool200000080oooo0P0000040?ooo`@00000
00@0oooo0000003oool0oooo0`0000000`3oool000000?ooo`020?ooo`D0000000@0oooo0000003o
ool000001P3oool2000000040?ooo`0000000000000000D0oooo0P0000000`3oool000000?ooo`05
00000080oooo2`0000070?ooo`<0000000@0oooo0000000000000000103oool00`000000oooo0?oo
o`030?ooo`8000002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool04P3oool001d0oooo0P00000?0?ooo`8000000P3oool01@000000oooo0?ooo`3o
ool0000000L0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool00P0000020?ooo`80000000<0oooo0000000000000`3oool200000080
oooo0P0000020?ooo`060000003oool0oooo0000003oool000000`3oool200000080oooo00@00000
0?ooo`000000oooo0P0000020?ooo`8000000P3oool5000000030?ooo`0000000000008000000P3o
ool200000080oooo00@000000?ooo`000000oooo0P0000020?ooo`040000003oool0000000000080
oooo0P0000020?ooo`800000103oool4000000040?ooo`000000oooo0?ooo`80000000<0oooo0000
003oool00`3oool2000000030?ooo`00000000000080000000<0oooo0000003oool01@3oool50000
00D0oooo0P0000000`3oool000000?ooo`02000000<0oooo0`0000050?ooo`P000001P3oool30000
00040?ooo`0000000000000000@0oooo0P0000040?ooo`8000002P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool04P3oool001d0oooo00<000000?oo
o`3oool03P3oool2000000030?ooo`000000000000<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000003oool000000080oooo0P0000030?ooo`040000003oool00000
00000080oooo00<000000?ooo`0000000P0000040?ooo`050000003oool0oooo0?ooo`0000000P3o
ool2000000050?ooo`000000oooo0?ooo`0000000P3oool200000080oooo00H000000?ooo`000000
oooo0000003oool>0000000:0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080
oooo00L000000?ooo`00000000000?ooo`000000oooo008000000P3oool2000000<0oooo00<00000
0?ooo`3oool00P3oool600000080oooo0P0000000`3oool000000?ooo`030?ooo`80000000<0oooo
0000000000000P0000000`3oool000000?ooo`050?ooo`D000001@3oool01@000000oooo0000003o
ool000000080oooo0`0000090?ooo`030000003oool0oooo00H000001P3oool3000000030?ooo`00
0000000000D0oooo00<000000?ooo`3oool00P3oool2000000X0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0180oooo000M0?ooo`030000003oool0
oooo00d0oooo0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000000P3oool2000000<0oooo00@000000?ooo`00000000000P3o
ool00`000000oooo00000002000000<0oooo0P0000020?ooo`8000000P3oool01P000000oooo0?oo
o`000000oooo00000080oooo0P0000020?ooo`040000003oool000000?ooo`D0000000<0oooo0000
000000001P0000004@3oool00000000000000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo00@000000P3oool200000080oooo00@000000?ooo`3oool0oooo
0P0000030?ooo`H000000P3oool2000000030?ooo`000000oooo0080oooo0P0000020?ooo`@00000
00<0oooo0000003oool0103oool5000000D0oooo00<000000?ooo`0000001@0000040?ooo`T00000
103oool6000000D0oooo0`0000000`3oool00000000000050?ooo`070000003oool0oooo0?ooo`00
0000oooo0000000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0B0?ooo`00703oool00`000000oooo0?ooo`0>0?ooo`8000000P3oool200000080
oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool00P0000030?ooo`090000003oool000000000003oool000000?ooo`000000oooo00800000
0`3oool200000080oooo00<000000?ooo`3oool00P0000001P3oool000000?ooo`3oool000000?oo
o`8000000P3oool010000000oooo0000003oool2000000030?ooo`000000oooo00`0000000<0oooo
000000000000100000000`3oool000000?ooo`0200000080oooo00D000000?ooo`000000oooo0000
00020?ooo`8000000P3oool010000000oooo0?ooo`3oool2000000<0oooo0P000000103oool00000
0000000000020?ooo`80000000<0oooo0000003oool00P3oool200000080oooo00H000000?ooo`00
000000000?ooo`0000050?ooo`D000001@3oool5000000D0oooo0P0000040?ooo`<0000000@0oooo
0000000000000000103oool5000000D0oooo0`0000000`3oool00000000000050?ooo`070000003o
ool0oooo0?ooo`000000oooo0000000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0A0?ooo`00703oool00`000000oooo0?ooo`0>0?ooo`800000
0P3oool200000080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo0080000000<0oooo0000003o
ool00`0000040?ooo`030000003oool0oooo008000000P3oool01P000000oooo0?ooo`000000oooo
00000080oooo0P0000001@3oool000000?ooo`000000oooo0080000000<0oooo0000000000002`00
00001P3oool000000000003oool000000?ooo`80000000<0oooo0000003oool00P0000001@3oool0
00000?ooo`000000oooo0080000000<0oooo0000003oool00P0000020?ooo`040000003oool0oooo
0?ooo`8000000`3oool2000000040?ooo`000000oooo00000080oooo0P0000000`3oool000000000
00020?ooo`8000000`3oool3000000030?ooo`000000000000@0oooo1@0000040?ooo`@000001@3o
ool>000000040?ooo`0000000000000000<0oooo1@0000040?ooo`H000001@3oool01`000000oooo
0?ooo`3oool000000?ooo`0000002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool04@3oool001`0oooo00<000000?ooo`3oool03P3oool200000003
0?ooo`000000000000<0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000`3oool010000000oooo0000000000020?ooo`030000003o
ool00000008000000`3oool200000080oooo00<000000?ooo`3oool00P0000001P3oool000000?oo
o`3oool000000?ooo`80000000D0oooo0000003oool000000?ooo`02000000030?ooo`0000000000
00d0000000<0oooo0000000000000P0000001`3oool00000000000000000oooo0000003oool00P00
00000`3oool000000?ooo`02000000030?ooo`0000000000008000000P3oool010000000oooo0?oo
o`3oool2000000<0oooo0P0000000`3oool0000000000002000000040?ooo`00000000000?ooo`80
00000P3oool2000000<0oooo0`0000000`3oool00000000000030?ooo`030000003oool0000000<0
000000<0oooo000000000000100000040?ooo`@0000000@0oooo00000000000000001P3oool50000
00030?ooo`000000000000<0oooo1@0000040?ooo`<0000000<0oooo0000003oool0103oool01`00
0000oooo0?ooo`3oool000000?ooo`0000002@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool04@3oool001`0oooo00<000000?ooo`3oool03@3oool0
10000000oooo0000003oool2000000<0oooo00<000000?ooo`3oool01@3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000P3oool2000000<0oooo00T000000?ooo`00000000000?ooo`000000
oooo0000003oool00P0000030?ooo`80000000<0oooo0000000000000P3oool03@000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool00`0000001@3oool000000000
00000000oooo00/0000000<0oooo0000000000000`0000001P3oool000000000003oool000000?oo
o`80000000L0oooo0000003oool000000?ooo`000000oooo0080000000D0oooo000000000000oooo
000000030?ooo`8000000`3oool2000000030?ooo`000000oooo0080000000P0oooo000000000000
oooo0000003oool000000?ooo`8000000`3oool6000000<0oooo00<000000?ooo`00000010000003
0?ooo`<000000`3oool010000000oooo0000003oool3000000P0oooo00@000000?ooo`3oool0oooo
0`0000000`3oool00000000000020?ooo`D00000103oool3000000030?ooo`000000oooo00@0oooo
00L000000?ooo`3oool0oooo0000003oool0000000T0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo0140oooo000L0?ooo`030000003oool0oooo00d0
oooo00@000000?ooo`000000oooo0P0000030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000020?ooo`8000000P3oool00`000000oooo0?ooo`020000
00050?ooo`000000oooo0000003oool00P0000030?ooo`80000000@0oooo000000000000oooo0P00
00001P3oool000000000003oool000000?ooo`80000000<0oooo0000003oool00`0000001@3oool0
0000000000000000oooo00d0000000<0oooo0000000000000`0000001`3oool00000000000000000
oooo0000003oool00P000000103oool000000?ooo`0000020?ooo`@0000000<0oooo000000000000
0P3oool2000000<0oooo0P0000000`3oool000000?ooo`05000000050?ooo`000000oooo0000003o
ool00P0000040?ooo`<000000P3oool010000000oooo0000003oool5000000@0oooo0`0000030?oo
o`@000002`3oool00`000000oooo0?ooo`040?ooo`D000000P3oool4000000@0oooo00D000000?oo
o`000000oooo000000050?ooo`070000003oool0oooo0?ooo`000000oooo000000090?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0A0?ooo`00703o
ool00`000000oooo0?ooo`0=0?ooo`040000003oool000000?ooo`8000000`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000P3oool200000080oooo
00<000000?ooo`3oool00P0000001P3oool000000?ooo`000000oooo000000@0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`80000000<0oooo0000003oool00P00
00001@3oool00000000000000000oooo01<0000000@0oooo000000000000oooo0P000000103oool0
00000000003oool2000000040?ooo`000000oooo00000080oooo00D000000?ooo`00000000000?oo
o`0200000080oooo0P0000030?ooo`<000000P3oool5000000040?ooo`000000oooo0?ooo`<00000
0`3oool400000080oooo100000000`3oool0000000000002000000<0oooo100000020?ooo`@00000
1`3oool9000000D0oooo1@0000020?ooo`@000000`3oool00`000000oooo00000002000000D0oooo
00L000000?ooo`3oool0oooo0000003oool0000000T0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo000L0?ooo`030000003oool0oooo00d0
oooo00@000000?ooo`000000oooo0P0000020?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo008000000P3oool010000000oooo00000000
00020?ooo`030000003oool00000008000000`3oool200000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0000003oool2000000030?ooo`000000oooo00@0000000@0oooo00000000
0000oooo5@0000000`3oool0000000000002000000030?ooo`000000oooo00@000000P3oool00`00
0000oooo0000000400000080oooo0P0000030?ooo`<000000P3oool00`000000oooo000000020000
00040?ooo`000000oooo0?ooo`<000000`3oool8000000@0oooo0`0000030?ooo`@000000P3oool3
000000D0oooo0`0000020?ooo`H0000000<0oooo0000000000001@3oool400000080oooo10000003
0?ooo`H00000103oool010000000oooo0?ooo`3oool2000000X0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo000K0?ooo`030000003oool0
oooo00h0oooo0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`050?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0200000080oooo00@000000?ooo`0000000000
0P3oool2000000030?ooo`000000000000<0oooo0P0000000`3oool00000000000020?ooo`070000
003oool000000000003oool000000?ooo`02000000040?ooo`00000000000?oooaH0000000<0oooo
0000000000000`0000000`3oool0000000000002000000030?ooo`000000oooo00D0000000<0oooo
0000003oool00P0000000`3oool00000000000020?ooo`8000000`3oool3000000060?ooo`000000
oooo0?ooo`000000oooo0`0000030?ooo`8000000`3oool5000000030?ooo`000000000000@0oooo
0`0000020?ooo`D0000000D0oooo000000000000oooo000000030?ooo`8000000`3oool2000000@0
oooo00<000000?ooo`000000100000050?ooo`<000000`3oool4000000<0oooo1@0000040?ooo`04
0000003oool0oooo0?ooo`8000002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool04@3oool001/0oooo00<000000?ooo`3oool03P3oool200000080
oooo0P0000020?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo008000000P3oool010000000oooo0000000000020?ooo`80000000<0oooo
0000000000000`3oool2000000030?ooo`00000000000080oooo00<000000?ooo`0000001P000000
103oool000000000003oool2000000050?ooo`00000000000000003oool00P0000000`3oool00000
00000004000000030?ooo`000000000000d0000000@0oooo000000000000oooo1@0000000`3oool0
00000?ooo`02000000030?ooo`00000000000080oooo0P0000030?ooo`<0000000@0oooo0000003o
ool0oooo1@0000030?ooo`030000003oool0oooo00<0000000<0oooo0000000000000P0000000`3o
ool000000?ooo`030?ooo`@0000000<0oooo0000000000000`000000103oool00000000000000003
0?ooo`030000003oool0oooo00<000001P3oool00`000000oooo0?ooo`030?ooo`<000001@3oool3
00000080oooo100000030?ooo`D00000103oool010000000oooo0?ooo`3oool2000000X0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0100oooo000K
0?ooo`030000003oool0oooo00h0oooo0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`05
0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`8000000P3oool010000000oooo
0000000000020?ooo`80000000<0oooo0000000000000`3oool010000000oooo0?ooo`0000020?oo
o`80000000/0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0>000000H0
oooo3@0000001P3oool000000000003oool000000?ooo`<0000000<0oooo0000003oool00P000000
0`3oool00000000000020?ooo`8000000`3oool3000000040?ooo`000000oooo0?ooo`H0000000<0
oooo0000000000000P0000020?ooo`80000000H0oooo00000000000000000?ooo`0000040?ooo`D0
00000P3oool5000000060?ooo`000000oooo0?ooo`000000oooo0P0000090?ooo`030000003oool0
oooo00H0oooo0P0000040?ooo`030000003oool000000080oooo100000030?ooo`D00000103oool0
10000000oooo0?ooo`3oool2000000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo0100oooo000K0?ooo`030000003oool0oooo00h0oooo0P000002
0?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000`3oool010000000oooo0?ooo`3oool2000000070?ooo`000000oooo0000003oool0
00000?ooo`02000000<0oooo00@000000?ooo`3oool000000P3oool01@000000oooo000000000000
oooo00@0000000@0oooo000000000000oooo100000000`3oool0000000000006000000P0oooo2`00
00001`3oool00000000000000000oooo0000003oool00`000000103oool000000?ooo`0000020?oo
o`<0000000<0oooo0000000000000`3oool3000000040?ooo`000000oooo0?ooo`80000000@0oooo
000000000000oooo0`0000001`3oool000000?ooo`000000oooo0000003oool00P000000103oool0
00000000000000040?ooo`@000000P3oool5000000060?ooo`000000oooo0000003oool000002`3o
ool00`000000oooo0?ooo`080?ooo`8000000`3oool300000080oooo100000030?ooo`D00000103o
ool01P000000oooo0?ooo`000000oooo000000T0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo0100oooo000K0?ooo`030000003oool0oooo00h0oooo
0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000000P3oool2000000<0oooo0P000000203oool000000?ooo`000000oooo0000
003oool00000103oool010000000oooo0?ooo`0000020?ooo`050000003oool000000000003oool0
100000001P3oool000000000003oool000000?ooo`X000002@3oool:000000030?ooo`0000000000
0080000000<0oooo0000003oool00`000000103oool000000?ooo`0000020?ooo`80000000<0oooo
000000000000103oool01@000000oooo0000003oool000000080oooo0P000000103oool000000000
003oool3000000060?ooo`000000oooo0000003oool000000P3oool3000000030?ooo`000000oooo
00<0oooo100000020?ooo`<0000000<0oooo0000003oool00P0000000`3oool000000?ooo`0;0?oo
o`030000003oool0oooo00X0oooo0P0000030?ooo`<0000000<0oooo0000000000000P0000030?oo
o`D000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000002@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0403oool001/0oooo00<00000
0?ooo`3oool03P3oool200000080oooo0P0000020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000020?ooo`8000000P3oool02`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000@0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo00000006000000030?ooo`00000000000080000000D0oooo00000000000000000?oo
o`06000000T0oooo3`0000000`3oool0000000000003000000040?ooo`000000oooo00000080oooo
00@000000?ooo`3oool0oooo0P0000030?ooo`050000003oool000000?ooo`0000000P3oool20000
00030?ooo`000000000000@000000P3oool2000000040?ooo`000000oooo0?ooo`<000000P3oool0
10000000oooo0?ooo`3oool400000080oooo0`0000020?ooo`80000000<0oooo0000003oool0303o
ool00`000000oooo0?ooo`0;0?ooo`<000000P3oool300000080oooo0`0000030?ooo`D000000`3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000002@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0403oool001/0oooo00<000000?ooo`3oool0
3P3oool200000080oooo0P0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000020?ooo`8000000P3oool02`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000000<0oooo0P0000000`3oool00000000000020?ooo`030000003o
ool000000080000000D0oooo00000000000000000?ooo`0>000000X0oooo3`0000000`3oool00000
0000000200000080oooo00<000000?ooo`0000000P3oool020000000oooo0?ooo`3oool000000?oo
o`000000oooo0P000000103oool000000?ooo`0000020?ooo`80000000<0oooo0000003oool00`00
00040?ooo`800000103oool3000000030?ooo`000000oooo00<0oooo0`0000020?ooo`<000000P3o
ool2000000030?ooo`000000oooo00`0oooo00<000000?ooo`3oool03@3oool200000080oooo00<0
00000?ooo`0000000P3oool3000000<0oooo1@0000030?ooo`070000003oool0oooo0?ooo`000000
oooo000000090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`0@0?ooo`006`3oool00`000000oooo0?ooo`0>0?ooo`8000000P3oool010000000oooo
0?ooo`0000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000P3oool200000080
oooo00P000000?ooo`000000oooo0000003oool000000?ooo`<000000`3oool2000000030?ooo`00
000000000080oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`02000000030?ooo`00
0000000000/000002P3oool;000000030?ooo`000000000000H000000P3oool00`000000oooo0000
00020?ooo`030000003oool0oooo008000000P3oool3000000040?ooo`000000oooo00000080oooo
00@000000?ooo`3oool000000P3oool2000000<0oooo00<000000?ooo`000000103oool300000080
oooo00@000000?ooo`3oool0oooo0`0000020?ooo`<000000P3oool3000000h0oooo00<000000?oo
o`3oool03P3oool3000000040?ooo`000000000000000080oooo0`0000030?ooo`@00000103oool0
10000000oooo0?ooo`3oool2000000T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo0100oooo000J0?ooo`030000003oool0oooo00l0oooo0P000002
0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo008000000P3oool010000000oooo0000000000020?ooo`030000003oool000000080
00000`3oool2000000030?ooo`00000000000080oooo00<000000?ooo`0000000P0000000`3oool0
00000?ooo`02000000030?ooo`000000000000/000002P3oool<000000040?ooo`00000000000?oo
o`H000000P3oool010000000oooo0000000000020?ooo`8000000`3oool300000080oooo00H00000
0?ooo`00000000000?ooo`0000030?ooo`<000000P3oool00`000000oooo000000040?ooo`@00000
00<0oooo0000003oool00P3oool<000000l0oooo00<000000?ooo`3oool03`3oool4000000030?oo
o`00000000000080oooo0`0000030?ooo`@00000103oool010000000oooo0?ooo`3oool2000000T0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0100
oooo000J0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
008000000P3oool010000000oooo0000000000020?ooo`030000003oool00000008000000`3oool0
0`000000oooo0?ooo`020000000:0?ooo`00000000000?ooo`000000oooo0000003oool000000?oo
o`80000000<0oooo0000000000002`00000:0?ooo`H0000000<0oooo0000000000000`0000002@3o
ool000000?ooo`000000oooo0000003oool000000?ooo`02000000030?ooo`000000oooo00800000
0P3oool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000P3oool200000003
0?ooo`000000oooo0080oooo0P0000000`3oool00000000000020?ooo`8000000`3oool500000005
0?ooo`000000oooo0000003oool0100000000`3oool0000000000005000000h0oooo00<000000?oo
o`3oool04@3oool010000000oooo0000003oool200000080oooo0`0000030?ooo`@00000103oool0
10000000oooo0?ooo`3oool2000000T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo0100oooo000J0?ooo`030000003oool0oooo00l0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo008000000P3oool010000000oooo0000000000020?ooo`03
0000003oool00000008000000`3oool00`000000oooo0?ooo`020000000:0?ooo`00000000000?oo
o`000000oooo0000003oool000000?ooo`80000000<0oooo0000000000002`00000:0?ooo`T00000
00<0oooo0000000000000P0000000`3oool000000?ooo`0200000080oooo00D000000?ooo`000000
00000?ooo`0200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000200000080
oooo0P0000000`3oool000000?ooo`020?ooo`<0000000@0oooo0000003oool000000P3oool00`00
0000oooo000000020?ooo`<0000000D0oooo0000003oool000000?ooo`0400000080oooo0P000000
103oool000000?ooo`00000>0?ooo`030000003oool0oooo0180oooo00@000000?ooo`000000oooo
0`000000103oool000000000000000030?ooo`@000000`3oool01`000000oooo0?ooo`3oool00000
0?ooo`000000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P0000020?ooo`040000003oool0000000000080oooo00<000000?ooo`000000
0P0000030?ooo`030000003oool0oooo0080000000X0oooo000000000000oooo0000003oool00000
0?ooo`000000oooo0P0000000`3oool000000000000;000000T0oooo2P0000000`3oool000000?oo
o`02000000030?ooo`000000oooo008000000P3oool00`000000oooo0000000400000080oooo00@0
00000?ooo`3oool0oooo0P0000002@3oool000000000003oool000000?ooo`000000oooo00000003
0?ooo`8000000P3oool4000000<0oooo0P0000030?ooo`<0000000<0oooo0000003oool00P3oool3
00000080oooo0`0000000`3oool000000000000>0?ooo`030000003oool0oooo01<0oooo00@00000
0?ooo`000000oooo0`0000000`3oool00000000000040?ooo`@000000`3oool010000000oooo0?oo
o`3oool2000000T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo00l0oooo000J0?ooo`800000403oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00P0000020?ooo`040000003oool0000000000080oooo00<000000?ooo`0000000P0000030?oo
o`030000003oool0oooo0080000000H0oooo000000000000oooo0000003oool3000000030?ooo`00
0000oooo00l000001`3oool2000000070?ooo`000000oooo0000003oool000000?ooo`0400000005
0?ooo`000000oooo0000003oool00`0000000`3oool000000?ooo`0200000080oooo1@0000030?oo
o`<0000000@0oooo0000003oool0oooo0P0000000`3oool000000?ooo`020?ooo`8000000P3oool4
000000@0oooo00<000000?ooo`3oool00P3oool4000000<0oooo10000000203oool0000000000000
0000oooo0000003oool000003@3oool00`000000oooo0?ooo`0D0?ooo`040000003oool000000?oo
o`<0000000<0oooo0000000000000`3oool5000000<0oooo00@000000?ooo`3oool0oooo0P000009
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0?
0?ooo`006P3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0200000080oooo00@000000?ooo`00000000000P3oool00`000000oooo00000002000000<0oooo
00<000000?ooo`3oool00P0000001P3oool000000000003oool000000?ooo`80000000@0oooo0000
00000000oooo100000000`3oool0000000000009000000D0oooo2`0000000`3oool0000000000002
000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000<0oooo00000000
00000P3oool2000000<0oooo0`000000103oool000000?ooo`3oool2000000040?ooo`000000oooo
0?ooo`<000000P3oool00`000000oooo0000000200000080oooo0P0000050?ooo`@000000P3oool8
00000080oooo0P00000=0?ooo`030000003oool0oooo01D0oooo00@000000?ooo`000000oooo0`00
00000`3oool00000000000030?ooo`@00000103oool010000000oooo0?ooo`3oool2000000P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00l0oooo
000J0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080
00000P3oool010000000oooo0000000000020?ooo`030000003oool00000008000000`3oool00`00
0000oooo0?ooo`0200000080oooo00@000000?ooo`000000oooo0P000000103oool000000000003o
ool2000000030?ooo`000000oooo01H0000000<0oooo0000003oool0100000001P3oool000000000
003oool000000?ooo`8000000P3oool01@000000oooo000000000000oooo008000000P3oool02P00
0000oooo000000000000oooo0000003oool000000?ooo`0000020?ooo`030000003oool0000000<0
oooo0`0000001P3oool000000?ooo`3oool000000?ooo`80000000@0oooo0000003oool000001@3o
ool4000000030?ooo`000000oooo00<0000000D0oooo00000000000000000?ooo`02000000d0oooo
00<000000?ooo`3oool05P3oool010000000oooo0000003oool3000000030?ooo`000000000000<0
oooo100000040?ooo`060000003oool0oooo0000003oool00000203oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool03`3oool001T0oooo00<000000?oo
o`3oool0403oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool0
1@000000oooo0?ooo`3oool000000080oooo00T000000?ooo`3oool000000?ooo`000000oooo0000
003oool00P0000020?ooo`030000003oool00000008000000`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`0000000`000000103oool000000000003oool2000000030?ooo`00
0000000000P0000000<0oooo000000000000200000000`3oool0000000000004000000040?ooo`00
000000000?ooo`80000000L0oooo000000000000oooo0000003oool000000080oooo00@000000?oo
o`3oool000000`3oool010000000oooo0?ooo`3oool3000000040?ooo`000000oooo0?ooo`800000
00D0oooo00000000000000000?ooo`03000000040?ooo`000000oooo000000<0oooo0P0000030?oo
o`030000003oool0oooo0080oooo0`0000000`3oool000000?ooo`020?ooo`<0000000<0oooo0000
000000000P3oool2000000`0oooo00<000000?ooo`3oool05`3oool010000000oooo0000003oool2
00000080oooo0P0000030?ooo`@000000`3oool010000000oooo0?ooo`3oool2000000T0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00l0oooo000I
0?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0?ooo`80
00000P3oool300000080oooo00<000000?ooo`0000000P0000040?ooo`040000003oool0oooo0000
0080oooo00L000000?ooo`3oool000000?ooo`000000oooo0080000000<0oooo0000003oool00`00
00000`3oool000000000000B000000030?ooo`000000000000@0000000H0oooo000000000000oooo
0000003oool3000000030?ooo`000000oooo0080000000<0oooo0000000000000P3oool2000000<0
oooo1@0000020?ooo`030000003oool0000000<0oooo0P0000001P3oool000000?ooo`000000oooo
000000@0oooo0P0000030?ooo`040000003oool0oooo00000080oooo0`0000030?ooo`@0000000@0
oooo000000000000oooo0P00000<0?ooo`030000003oool0oooo01P0oooo0`000000103oool00000
0000003oool300000080oooo100000040?ooo`040000003oool0oooo0?ooo`800000203oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool03`3oool001T0
oooo00<000000?ooo`3oool0403oool200000080oooo00D000000?ooo`3oool0oooo000000070?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`8000000P3oool300000080oooo00<0
00000?ooo`0000000P0000040?ooo`030000003oool0oooo0080000000`0oooo000000000000oooo
0000003oool000000?ooo`000000oooo0000003oool2000000030?ooo`000000000001H0000000<0
oooo0000003oool00P000000103oool000000000003oool2000000040?ooo`000000oooo00000080
oooo00@000000?ooo`3oool000000`3oool2000000<0oooo0`0000001`3oool000000000003oool0
00000?ooo`0000000`3oool2000000030?ooo`00000000000080oooo00<000000?ooo`3oool00P3o
ool3000000<0oooo00<000000?ooo`0000000P3oool4000000030?ooo`000000oooo00@0000000@0
oooo000000000000oooo0P00000;0?ooo`030000003oool0oooo01X0oooo1@000000103oool00000
0000000000020?ooo`@00000103oool010000000oooo0?ooo`3oool2000000P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00l0oooo000I0?ooo`03
0000003oool0oooo0100oooo0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`050?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`8000000P3oool300000080oooo00D00000
0?ooo`000000oooo000000040?ooo`030000003oool0oooo008000000P3oool010000000oooo0000
003oool2000000040?ooo`00000000000?ooo`80000000D0oooo00000000000000000?ooo`060000
00030?ooo`000000000000H0000000<0oooo0000000000001P0000001P3oool000000000003oool0
00000?ooo`<0000000H0oooo0000003oool0oooo0000003oool200000080oooo0P0000030?ooo`<0
00000P3oool01P000000oooo000000000000oooo000000<0oooo1@0000000`3oool000000?ooo`03
0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`020?ooo`D0000000<0oooo
0000000000000P0000001`3oool000000000003oool000000?ooo`0000002P3oool00`000000oooo
0?ooo`0K0?ooo`D0000000<0oooo0000000000000`3oool4000000@0oooo00H000000?ooo`3oool0
00000?ooo`0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0?0?ooo`006@3oool00`000000oooo0?ooo`0@0?ooo`8000000P3oool200000080
oooo00<000000?ooo`3oool01@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool2
00000080oooo0P000000103oool000000?ooo`0000020?ooo`800000103oool00`000000oooo0?oo
o`0200000080oooo00T000000?ooo`00000000000?ooo`000000oooo0000003oool00P0000000`3o
ool000000?ooo`04000000050?ooo`00000000000000003oool0400000000`3oool000000?ooo`02
000000070?ooo`00000000000?ooo`000000oooo000000020?ooo`80000000<0oooo0000003oool0
0P3oool2000000<0oooo0`0000001`3oool000000?ooo`3oool000000?ooo`0000000`3oool20000
0080oooo0P0000000`3oool000000?ooo`030?ooo`040000003oool0oooo0?ooo`8000000P3oool2
00000080oooo1`0000020?ooo`<0000000@0oooo000000000000oooo0P00000:0?ooo`030000003o
ool0oooo01`0oooo1@0000000`3oool00000000000030?ooo`040000003oool00000000000@0oooo
00<000000?ooo`3oool00P0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0>0?ooo`006@3oool00`000000oooo0?ooo`0@0?ooo`8000000P3o
ool200000080oooo00<000000?ooo`3oool01@3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000`3oool200000080oooo0P000000103oool000000?ooo`0000020?ooo`<000000`3oool20000
00030?ooo`00000000000080oooo00/000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`02000000030?ooo`000000oooo00<0000000<0oooo000000000000300000001`3oool0
0000000000000000oooo0000003oool00P0000000`3oool000000?ooo`0200000080oooo00@00000
0?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo0P0000020?ooo`050000
003oool000000000003oool00P0000020?ooo`8000000P3oool010000000oooo0000000000040?oo
o`030000003oool0oooo0080oooo0`0000020?ooo`050000003oool000000000003oool00P000000
0`3oool000000?ooo`020?ooo`8000000P3oool2000000030?ooo`000000000000P0oooo0P00000O
0?ooo`@0000000@0oooo00000000000000000`3oool3000000D0oooo00<000000?ooo`3oool00P00
00080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0>0?ooo`006@3oool00`000000oooo0?ooo`0@0?ooo`8000000P3oool200000080oooo00<00000
0?ooo`3oool01@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool200000080oooo
00H000000?ooo`00000000000?ooo`0000020?ooo`<000000`3oool200000080oooo00<000000?oo
o`3oool00P0000001@3oool000000?ooo`000000oooo0080000000H0oooo000000000000oooo0000
003oool3000000050?ooo`00000000000000003oool02P0000001`3oool00000000000000000oooo
0000003oool00P000000203oool000000?ooo`000000oooo0000003oool000000P3oool200000003
0?ooo`00000000000080oooo0P0000030?ooo`<0000000@0oooo0000003oool0oooo0P0000000`3o
ool000000?ooo`03000000<0oooo00@000000?ooo`000000oooo0P0000000`3oool000000?ooo`05
0?ooo`<000000P3oool200000080oooo100000040?ooo`8000000P3oool2000000030?ooo`000000
000000@0oooo0`0000020?ooo`030000003oool0oooo01`0oooo0P000000103oool000000000003o
ool300000080oooo100000040?ooo`040000003oool0oooo0?ooo`800000203oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03P3oool001T0oooo00<0
00000?ooo`3oool0403oool200000080oooo0P0000030?ooo`030000003oool0oooo00@0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000<0oooo0P0000020?ooo`060000003oool000000000
003oool000000P3oool3000000<0oooo0P0000020?ooo`8000000P3oool00`000000oooo00000002
0?ooo`0:0000003oool000000?ooo`000000oooo0000003oool000000?ooo`@0000000<0oooo0000
000000002`0000001`3oool000000?ooo`000000oooo0000003oool00P000000103oool000000?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000040?oo
o`8000000P3oool01P000000oooo000000000000oooo000000<0oooo0P0000030?ooo`030000003o
ool0000000<0oooo0P0000060?ooo`@0000000<0oooo0000000000000P3oool00`000000oooo0000
0002000000<0oooo0`0000000`3oool00000000000020?ooo`D000001P3oool00`000000oooo0?oo
o`0L0?ooo`D0000000@0oooo00000000000000000P3oool4000000@0oooo00<000000?ooo`3oool0
0P0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0>0?ooo`00603oool00`000000oooo0?ooo`0A0?ooo`040000003oool000000?ooo`800000
0`3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000030?oo
o`8000000`3oool300000080oooo00<000000?ooo`0000000P0000040?ooo`030000003oool0oooo
008000000P3oool01`000000oooo0?ooo`000000oooo0000003oool00P0000001@3oool000000?oo
o`000000oooo0080000000<0oooo0000003oool03@0000001`3oool00000000000000000oooo0000
003oool00P0000020?ooo`050000003oool000000?ooo`0000000P3oool2000000030?ooo`000000
00000080oooo0P0000030?ooo`<0000000@0oooo0000003oool0oooo0P000000103oool000000?oo
o`3oool2000000030?ooo`00000000000080000000<0oooo0000003oool00P3oool2000000H0oooo
00<000000?ooo`3oool00`0000000`3oool0000000000002000000040?ooo`0000000000000000<0
oooo0`0000000`3oool0000000000003000000X0oooo00<000000?ooo`3oool0703oool8000000<0
oooo100000040?ooo`030000003oool0oooo00800000203oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool03P3oool001P0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000020?ooo`<000000P3oool0
0`000000oooo00000002000000@0oooo0P0000000`3oool00000000000020?ooo`80000000/0oooo
0000003oool0oooo0000003oool000000?ooo`000000oooo000000020?ooo`D0000000<0oooo0000
000000001P0000020?ooo`<000000P3oool400000080oooo00@000000?ooo`000000oooo0P000000
0`3oool00000000000020?ooo`050000003oool0oooo0?ooo`000000103oool200000080oooo00@0
00000?ooo`000000oooo0P0000030?ooo`8000000`3oool3000000@0oooo00@000000?ooo`000000
00000`3oool010000000oooo0?ooo`3oool300000080oooo0P0000030?ooo`<000000`3oool60000
00030?ooo`000000000000X0oooo00<000000?ooo`3oool0703oool01@000000oooo000000000000
oooo00<000000`3oool4000000@0oooo00@000000?ooo`00000000002@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool03P3oool001P0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`80
000000L0oooo0000003oool000000?ooo`000000oooo008000000`3oool200000080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool000000?ooo`80000000H0oooo0000003oool0
00000?ooo`0000020?ooo`d0000000<0oooo0000003oool00`0000020?ooo`030000003oool00000
008000000P3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool2000000<0oooo0`000000
103oool000000?ooo`3oool2000000040?ooo`000000oooo0?ooo`8000000`3oool010000000oooo
0000000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool40000
00040?ooo`0000000000000000<0oooo2@000000103oool000000000003oool2000000T0oooo00<0
00000?ooo`3oool07@3oool01@000000oooo000000000000oooo00<000000P3oool4000000@0oooo
00<000000?ooo`3oool00P0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0>0?ooo`00603oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool000000080oooo0P0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000030?ooo`8000000P3oool010000000oooo0000000000020?ooo`030000
003oool00000008000000`3oool200000080oooo0P0000020?ooo`80000000H0oooo0000003oool0
oooo0000003oool2000000050?ooo`000000oooo0000003oool00P0000030?ooo`<000001P3oool4
000000060?ooo`000000oooo0?ooo`000000oooo10000000103oool000000000003oool200000080
oooo00D000000?ooo`3oool0oooo000000040?ooo`8000000P3oool010000000oooo0000003oool2
000000<0oooo0P0000030?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?oo
o`030?ooo`8000000`3oool010000000oooo0000003oool300000080oooo00<000000?ooo`3oool0
1@0000020?ooo`<0000000D0oooo000000000000oooo0000000:0?ooo`030000003oool0oooo01`0
oooo1@0000000`3oool00000000000030?ooo`040000003oool00000000000@0oooo00<000000?oo
o`3oool00P0000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0>0?ooo`00603oool00`000000oooo0?ooo`0B0?ooo`8000000P3oool200000080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0
oooo0P0000020?ooo`040000003oool0000000000080oooo00D000000?ooo`000000oooo00000004
0?ooo`8000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`0000000000
0?ooo`02000000040?ooo`000000oooo00000080oooo0`0000030?ooo`P000000P3oool01@000000
oooo000000000000oooo00@0000000@0oooo000000000000oooo0P0000020?ooo`8000000P3oool0
0`000000oooo0?ooo`020?ooo`<0000000@0oooo0000003oool0oooo0P0000000`3oool000000?oo
o`020?ooo`8000000P3oool010000000oooo0?ooo`0000020?ooo`8000001`3oool010000000oooo
0?ooo`3oool2000000<0oooo0P0000000`3oool000000000000200000080oooo100000020?ooo`<0
000000D0oooo000000000000oooo0000000:0?ooo`030000003oool0oooo01`0oooo10000000103o
ool000000000000000030?ooo`@000000`3oool00`000000oooo0?ooo`02000000T0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00h0oooo000H0?oo
o`030000003oool0oooo0180oooo0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`050?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo0`00
00020?ooo`050000003oool000000?ooo`000000103oool200000080oooo0P0000020?ooo`800000
00@0oooo0000003oool0oooo0P000000103oool000000000003oool4000000<0oooo2@0000020?oo
o`80000000@0oooo0000003oool0oooo10000000103oool000000000003oool2000000<0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`8000000P3oool010000000oooo0000003oool2000000<0
oooo0P0000030?ooo`040000003oool00000000000<0oooo0P0000050?ooo`030000003oool00000
00<000000`3oool500000080oooo00@000000?ooo`3oool0oooo100000020?ooo`<0000000D0oooo
000000000000oooo0000000:0?ooo`030000003oool0oooo01`0oooo00D000000?ooo`0000000000
0?ooo`03000000<0oooo100000030?ooo`030000003oool0oooo00800000203oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool03@3oool001P0oooo00<0
00000?ooo`3oool04P3oool2000000<0oooo00@000000?ooo`3oool000001`3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`<000000`3oool00`00
0000oooo00000002000000<0oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`02000000030?ooo`00000000000080oooo00<000000?ooo`0000000`000007
0?ooo`<0000000@0oooo000000000000oooo0`0000000`3oool000000?ooo`0200000080oooo00@0
00000?ooo`3oool0oooo0P0000020?ooo`030000003oool0oooo0080oooo0`000000103oool00000
0?ooo`3oool2000000030?ooo`000000oooo0080oooo0P0000020?ooo`030000003oool0oooo0080
00000P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0?ooo`80000000<0oooo
0000000000000P0000020?ooo`8000000P3oool200000080oooo100000020?ooo`<0000000<0oooo
0000000000000P00000:0?ooo`030000003oool0oooo01/0oooo0P000000103oool000000000003o
ool2000000<0oooo100000040?ooo`050000003oool000000?ooo`000000203oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool03@3oool001L0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000
1P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo0P0000020?oo
o`040000003oool0000000000080oooo00D000000?ooo`000000oooo000000040?ooo`8000000P3o
ool2000000<0oooo00@000000?ooo`3oool000000P3oool2000000030?ooo`00000000000080oooo
0P0000030?ooo`L0000000@0oooo00000000000000000P3oool200000080oooo00@000000?ooo`00
000000000P3oool200000080oooo0P0000030?ooo`030000003oool0oooo0080oooo0P0000020?oo
o`060000003oool000000000003oool000000`3oool2000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`040000003oool0oooo0?ooo`8000000P3oool010000000oooo0?ooo`3oool30000
00030?ooo`000000000000@0oooo0P0000030?ooo`030000003oool0oooo00@000000P3oool30000
00030?ooo`000000000000<000002@3oool00`000000oooo0?ooo`0K0?ooo`D0000000<0oooo0000
000000000`3oool4000000<0oooo00<000000?ooo`3oool00P0000080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0=0?ooo`005`3oool00`000000
oooo0?ooo`0D0?ooo`8000000P3oool01@000000oooo0?ooo`3oool0000000L0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`3oool2000000<0oooo0`0000020?ooo`030000003o
ool0oooo00<000000`3oool2000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo008000000P3oool010000000oooo0?ooo`3oool3000000D0oooo0`0000030?ooo`80
00000P3oool2000000030?ooo`00000000000080oooo0P0000020?ooo`8000000`3oool00`000000
oooo0?ooo`020?ooo`<0000000P0oooo0000003oool000000?ooo`000000oooo000000<0oooo0P00
00020?ooo`080000003oool0oooo0000003oool000000?ooo`0000060?ooo`80000000<0oooo0000
000000000P0000001@3oool000000000003oool0000000H0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`D0000000D0oooo00000000000000000?ooo`03000000030?ooo`000000oooo00P0oooo
00<000000?ooo`3oool06P3oool00`000000oooo00000002000000040?ooo`000000000000000080
oooo1@0000030?ooo`030000003oool0oooo00800000203oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool03@3oool001L0oooo00<000000?ooo`3oool0
503oool200000080oooo00D000000?ooo`3oool0oooo000000070?ooo`070000003oool0oooo0?oo
o`000000oooo000000030?ooo`030000003oool000000080oooo0P0000002@3oool000000?ooo`3o
ool000000?ooo`000000oooo000000040?ooo`8000000P3oool2000000<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`8000000P3oool2000000@0oooo1@0000040?ooo`8000000P3oool30000
00030?ooo`00000000000080oooo0P0000020?ooo`8000000`3oool00`000000oooo0?ooo`020?oo
o`<0000000@0oooo0000003oool0oooo0P0000000`3oool000000?ooo`020?ooo`8000000`3oool0
0`000000oooo000000020?ooo`030000003oool0000000D0oooo100000020?ooo`040000003oool0
oooo0?ooo`800000203oool01@000000oooo0?ooo`3oool000000080oooo0`0000000`3oool00000
0?ooo`03000000060?ooo`00000000000000003oool000002@3oool00`000000oooo0?ooo`0J0?oo
o`80000000@0oooo000000000000oooo0P0000030?ooo`@00000103oool01@000000oooo0000003o
ool0000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00d0oooo000G0?ooo`030000003oool0oooo01@0oooo0P0000020?ooo`050000003oool0
oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
oooo0P0000020?ooo`040000003oool0000000000080oooo00@000000?ooo`000000oooo0P000003
0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3o
ool2000000<0oooo3@0000020?ooo`<000000P3oool200000080oooo0P0000020?ooo`8000000`3o
ool00`000000oooo0?ooo`030?ooo`<0000000<0oooo0000003oool00P0000020?ooo`040000003o
ool0oooo0?ooo`8000000P3oool00`000000oooo000000030?ooo`8000000`3oool3000000040?oo
o`000000oooo0?ooo`<000000P3oool010000000oooo0000000000080?ooo`8000000P3oool00`00
0000oooo0?ooo`03000000040?ooo`000000oooo0?ooo`80000000<0oooo0000000000000`000009
0?ooo`030000003oool0oooo01T0oooo00H000000?ooo`000000oooo0000003oool3000000<0oooo
100000030?ooo`030000003oool0oooo00800000203oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool03@3oool001L0oooo00<000000?ooo`3oool0503o
ool2000000<0oooo00@000000?ooo`3oool00000203oool01`000000oooo0?ooo`3oool000000?oo
o`0000000`3oool2000000<0oooo0`0000020?ooo`060000003oool0oooo0000003oool00000103o
ool2000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool200000080oooo
0P0000040?ooo`D00000103oool5000000030?ooo`000000000000<0oooo0P0000020?ooo`800000
0`3oool2000000@0oooo0`000000203oool000000?ooo`000000oooo0000003oool000000`3oool2
000000<0oooo00<000000?ooo`0000000`3oool5000000@0oooo00@000000?ooo`3oool0oooo0P00
00020?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`8000000P3oool00`000000oooo0?oo
o`03000000040?ooo`000000oooo0?ooo`80000000@0oooo000000000000oooo0P0000090?ooo`03
0000003oool0oooo01T0oooo0P000000103oool000000000003oool300000080oooo100000040?oo
o`050000003oool000000?ooo`000000203oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool03@3oool001L0oooo00<000000?ooo`0000005@3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01@3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool2000000<0oooo00@000000?ooo`00000000000P3oool010000000
oooo0000003oool2000000@0oooo0P0000030?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool0oooo0`0000020?ooo`<000001@3oool8000000040?ooo`0000000000000000<0oooo0P00
00020?ooo`8000000`3oool2000000@0oooo0`000000103oool000000?ooo`3oool200000080oooo
00@000000?ooo`3oool0oooo0P0000020?ooo`030000003oool0000000<0oooo0`0000060?ooo`05
0000003oool0oooo0?ooo`0000000P3oool2000000030?ooo`000000oooo0080oooo0P0000070?oo
o`8000000P3oool010000000oooo0?ooo`3oool2000000040?ooo`000000oooo0?ooo`80000000@0
oooo000000000000oooo0P0000080?ooo`030000003oool0oooo01T0oooo00D000000?ooo`000000
oooo000000020?ooo`<000000P3oool4000000<0oooo00<000000?ooo`3oool00P0000090?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?ooo`00
5`3oool2000001H0oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000001`3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`<000000P3oool0
1P000000oooo0?ooo`000000oooo000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo0`0000030?ooo`X000000P3oool3000000<0oooo
0`0000020?ooo`8000000`3oool2000000@0oooo0P0000000`3oool00000000000020?ooo`800000
0P3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`0000001@0000070?ooo`05
0000003oool0oooo0?ooo`0000000`3oool2000000H0oooo00<000000?ooo`3oool01@3oool20000
0080oooo0P0000020?ooo`80000000@0oooo0000003oool0oooo0P0000000`3oool0000000000003
000000P0oooo00<000000?ooo`3oool06@3oool2000000040?ooo`00000000000?ooo`<000000P3o
ool4000000@0oooo00<000000?ooo`3oool00P0000080?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0<0?ooo`000`3oool01@3ogi`0B00000000000
0000M;oo00<0oooo00D0okmd000000000000000007Boo`060?ooo`030000003oool0oooo01H0oooo
0P0000020?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000<0oooo0P0000030?ooo`040000003oool0000000000080oooo00@000000?oo
o`000000oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`020?ooo`800000103oool3
000000T0oooo1P0000020?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`800000103oool2
000000040?ooo`000000oooo00000080oooo0P0000000`3oool000000?ooo`020?ooo`8000000`3o
ool3000000@0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000<0oooo
00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`050?ooo`<000000P3oool00`000000
oooo0?ooo`0400000080oooo200000080?ooo`030000003oool0oooo01T0oooo0P000000103oool0
00000?ooo`3oool300000080oooo100000030?ooo`030000003oool0oooo008000002@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0303oool000D0
oooo00<0_g@007Boo`3oool00`3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`D0oooo00<00000
0?ooo`3oool05P3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`05
0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool000000080oooo
00@000000?ooo`00000000000P3oool01@000000oooo0?ooo`000000oooo00800000103oool20000
00@0oooo00<000000?ooo`3oool00P3oool3000000@0oooo3P0000020?ooo`<000000`3oool20000
00@0oooo0P0000040?ooo`80000000@0oooo0000003oool000000P3oool200000080oooo00@00000
0?ooo`3oool0oooo1@0000020?ooo`040000003oool0oooo0?ooo`8000001`3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`80
00001`3oool200000080oooo00<000000?ooo`3oool0100000020?ooo`<0000000<0oooo00000000
00000P0000080?ooo`030000003oool0oooo01P0oooo0P000000103oool000000000003oool40000
00030?ooo`000000000000800000103oool00`000000oooo0?ooo`02000000P0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00`0oooo00050?ooo`03
0;md001d_ol0oooo0080oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`040?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool2000000@0oooo0P0000030?ooo`040000003oool000000000
0080oooo00<000000?ooo`3oool00`0000050?ooo`800000103oool2000000@0oooo1000000>0?oo
o`@000000`3oool3000000@0oooo0P0000050?ooo`050000003oool000000?ooo`0000000`3oool0
10000000oooo0?ooo`0000030?ooo`<0000000D0oooo0000003oool0oooo000000030?ooo`030000
003oool0000000H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`8000000P3oool00`000000
oooo0?ooo`0400000080oooo0`000000103oool000000000003oool2000000L0oooo00<000000?oo
o`3oool0603oool2000000040?ooo`000000oooo0?ooo`<000000P3oool4000000<0oooo00<00000
0?ooo`3oool00P0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0<0?ooo`0000<0oooo0=nLB0000000100000001@1d_ol0oooo0?ooo`3OW4P0
B9cO00<0oooo00<0okmd001d_`3oool0103oool00`000000oooo0?ooo`0G0?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`040000003oool0000000000080oooo
00D000000?ooo`3oool000000?ooo`02000000D0oooo0P0000040?ooo`800000103oool6000000P0
oooo1@0000040?ooo`8000001@3oool2000000D0oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`02000000030?ooo`000000oooo00@000000`3oool00`000000oooo000000040?ooo`03
0000003oool0000000D0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`030000003oool00000
00D0oooo0P0000060?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`040000003oool0oooo
0?ooo`<000000`3oool5000000030?ooo`000000000000L0oooo00<000000?ooo`3oool05`3oool2
000000040?ooo`00000000000?ooo`@0000000<0oooo0000000000000P0000040?ooo`030000003o
ool0oooo008000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0303oool000070?ooo`3o_g@0001d0;ooo`3oool0_g@007Boo`030?ooo`030=nL
B018W=l0oooo0080oooo00<0okmd001d_`3oool0103oool00`000000oooo0?ooo`0G0?ooo`800000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool2000000@0oooo0P0000030?ooo`040000003oool0000000000080oooo00<000000?ooo`3o
ool00P0000000`3oool000000?ooo`040?ooo`8000001@3oool2000000D0oooo300000060?ooo`80
00001@3oool3000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0600000003
0?ooo`000000000000<0oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`000004
0?ooo`040000003oool0oooo0?ooo`8000000P3oool010000000oooo0?ooo`0000070?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool200000080oooo00@000000?ooo`3oool0
oooo0`0000030?ooo`P000001`3oool00`000000oooo0?ooo`0G0?ooo`@000000P3oool300000080
oooo100000030?ooo`030000003oool0oooo008000002@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0303oool00080oooo00D0gia8001d_`3oool0
_g@007Boo`030?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0103oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`80000000<0oooo0000003oool0103oool2
000000H0oooo0`00000B0?ooo`<000001@3oool3000000D0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`03000000040?ooo`000000oooo0?ooo`8000000`3oool010000000oooo0?oo
o`0000040?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0000000T0oooo0P0000050?ooo`8000001P3oool3000000030?ooo`0000000000
0080oooo0`0000030?ooo`<0000000<0oooo0000000000000`0000060?ooo`030000003oool0oooo
01H0oooo0P000000103oool000000000003oool300000080oooo100000040?ooo`030000003oool0
oooo008000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0303oool000<0oooo00@0W4P004RLg`2oM000M;oo0`3oool00`3o_g@0B9cO0?ooo`02
0?ooo`030=nLB018W=l0oooo00@0oooo00<000000?ooo`3oool0603oool2000000030?ooo`000000
000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000@0oooo0P0000030?ooo`040000003oool0000000000080oooo00D000000?ooo`3oool00000
0?ooo`02000000H0oooo0P0000070?ooo`@000002`3oool5000000H0oooo0P0000060?ooo`030000
003oool000000080oooo1@0000020?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000
oooo000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`3oool2
00000080oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo0`0000020?ooo`030000003oool0oooo00@000000P3oool3000000030?ooo`000000
000000<000001P3oool00`000000oooo0?ooo`0F0?ooo`@000000P3oool300000080oooo10000003
0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0303oool000<0oooo00@0omnL04P0B018B000M;oo103o
ool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`D0oooo00<000000?ooo`3oool0603oool200000080
oooo0P0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000040?ooo`8000000`3oool010000000oooo0000000000020?ooo`050000003oool0oooo
0000003oool00P0000060?ooo`8000002@3oool?000000H0oooo0P0000070?ooo`040000003oool0
00000?ooo`<000000P3oool2000000030?ooo`000000oooo0080oooo0P0000030?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`800000
0`3oool2000000h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`800000
0P3oool00`000000oooo0?ooo`0400000080oooo2P0000040?ooo`030000003oool0oooo01H0oooo
0P000000103oool000000000003oool300000080oooo100000040?ooo`030000003oool0oooo0080
00002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0303oool000@0oooo00<0okmd0000001d_ol0103oool01@3ookl0M0000000000004P0W=oo00D0
oooo00<000000?ooo`3oool06@3oool200000080oooo0P0000030?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`8000000`3oool00`000000
oooo0?ooo`0200000080oooo00D000000?ooo`3oool000000?ooo`02000000L0oooo0P00000;0?oo
o`L00000203oool2000000P0oooo00<000000?ooo`0000000`0000030?ooo`80000000<0oooo0000
003oool00P3oool2000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000l0
oooo0P0000050?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`040000003oool0oooo0?oo
o`<000000`3oool7000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool05@3oool20000
00030?ooo`00000000000080oooo0`0000020?ooo`@000000`3oool01@000000oooo0?ooo`3oool0
000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00/0oooo000E0?ooo`030000003oool0oooo01X0oooo0P0000000`3oool00000000000040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?oo
o`8000000`3oool01@000000oooo0000003oool000000080oooo00D000000?ooo`3oool000000?oo
o`03000000H0oooo0`00000E0?ooo`<00000203oool400000080oooo00@000000?ooo`3oool0oooo
0P0000020?ooo`030000003oool0oooo00800000103oool00`000000oooo000000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`0000000`3oool200000080oooo00<000000?ooo`000000
4P3oool00`000000oooo0?ooo`030?ooo`8000001P3oool200000080oooo00@000000?ooo`3oool0
oooo100000020?ooo`T00000103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080
000000@0oooo00000000000000000P3oool4000000@0oooo00<000000?ooo`3oool00P0000090?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?oo
o`005@3oool00`000000oooo0?ooo`0J0?ooo`8000000P3oool2000000<0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`8000000`3oool00`000000oooo0?ooo`03000000030?ooo`000000
oooo00H0oooo1P00000<0?ooo`D000001`3oool600000080oooo00<000000?ooo`3oool00`000002
0?ooo`030000003oool0oooo00800000103oool00`000000oooo000000040?ooo`030000003oool0
oooo00@0oooo0P0000030?ooo`8000000`3oool2000001@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`80000000<0oooo0000000000000P3oool2000000040?ooo`000000
oooo0?ooo`T00000103oool00`000000oooo0?ooo`0D0?ooo`80000000@0oooo000000000000oooo
0`0000030?ooo`@000000`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0oooo000E0?ooo`030000
003oool0oooo01X0oooo00@000000?ooo`000000oooo0P0000030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`8000000`3oool00`000000
oooo0?ooo`02000000<0oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`070?oo
oa8000001`3oool5000000040?ooo`000000oooo0?ooo`8000000P3oool00`000000oooo00000002
0?ooo`030000003oool0oooo008000001@3oool2000000D0oooo00<000000?ooo`3oool0103oool2
000000<0oooo0P0000020?ooo`8000005P3oool2000000D0oooo00<000000?ooo`3oool01@3oool2
00000080oooo00@000000?ooo`3oool0oooo0`0000020?ooo`X000000`3oool00`000000oooo0?oo
o`0C0?ooo`80000000<0oooo0000000000000P3oool2000000<0oooo100000040?ooo`030000003o
ool0oooo008000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool02`3oool001D0oooo00<000000?ooo`3oool06P3oool00`000000oooo00000002
0?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo008000000`3o
ool010000000oooo0?ooo`3oool2000000030?ooo`000000000000X0oooo2P0000080?ooo`<00000
00H0oooo00000000000000000?ooo`0000020?ooo`070000003oool0oooo0?ooo`000000oooo0000
00020?ooo`030000003oool0oooo008000001@3oool00`000000oooo000000040?ooo`030000003o
ool0oooo00D0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`030000003oool0000001P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`8000000P3oool010000000oooo
0?ooo`3oool4000000030?ooo`000000000000P000000`3oool00`000000oooo0?ooo`0B0?ooo`80
000000D0oooo00000000000000000?ooo`03000000<0oooo100000030?ooo`050000003oool0oooo
0?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool02`3oool001D0oooo00<000000?ooo`3oool06`3oool200000080oooo0P0000030?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?oo
o`8000000`3oool010000000oooo0?ooo`3oool2000000<0oooo00@000000?ooo`3oool0oooo0`00
00000`3oool000000000000F0?ooo`@000000P3oool3000000030?ooo`00000000000080oooo00<0
00000?ooo`3oool00P0000001@3oool000000?ooo`3oool0000000<0oooo0P0000040?ooo`030000
003oool0000000D0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000<0
oooo0P00000J0?ooo`030000003oool0oooo00<0oooo0P0000070?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`0000000P3oool9000000<0oooo00<000000?ooo`3oool04@3oool20000
0080oooo0P000000103oool000000000000000030?ooo`@000000`3oool010000000oooo0?ooo`3o
ool2000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo00/0oooo000E0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`0000000P3oool2
000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000@0oooo0P0000030?ooo`050000003oool0oooo0000003oool00P0000020?ooo`040000003o
ool0oooo0?ooo`@0000000<0oooo0000000000004@3oool300000080oooo1@0000000`3oool00000
000000020?ooo`8000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0?oo
o`800000103oool00`000000oooo000000050?ooo`030000003oool0oooo00D0oooo0P0000020?oo
o`8000000P3oool2000001`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`80000000<0oooo0000000000000`3oool300000080oooo1`0000000`3oool00000000000020?oo
o`030000003oool0oooo0100oooo0P0000020?ooo`8000000P3oool2000000<0oooo1@0000030?oo
o`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool02`3oool001@0oooo00<000000?ooo`3oool07@3oool20000
0080oooo0P0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool20000
00D0oooo0P0000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P000003
0?ooo`@0000000@0oooo00000000000000002`3oool300000080oooo0`000000103oool000000000
003oool2000000<0oooo00<000000?ooo`3oool00P000000103oool000000000003oool2000000<0
oooo0P0000040?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool01@3oool010000000
oooo0000003oool2000000<0oooo00<000000?ooo`3oool0703oool2000000D0oooo00<000000?oo
o`3oool01@3oool200000080oooo00@000000?ooo`3oool0oooo100000000`3oool0000000000006
000000050?ooo`00000000000?ooo`0000004@3oool200000080oooo0`000000103oool000000000
000000020?ooo`030000003oool00000008000000`3oool010000000oooo0?ooo`3oool2000000P0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0
oooo000D0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`0000000P3oool200000080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000D0oooo
0P0000030?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000040?oo
o`/000000`3oool3000000030?ooo`000000000000H0000000<0oooo0000000000000`3oool20000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`800000103oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`00
00030?ooo`800000803oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0P00
00020?ooo`030000003oool0oooo0080oooo0`0000020?ooo`@0000000<0oooo0000000000000P3o
ool3000000l0oooo00<000000?ooo`0000000P3oool3000000040?ooo`0000000000000000<0oooo
1@0000030?ooo`030000003oool0oooo008000002@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool02`3oool001@0oooo00<000000?ooo`3oool07P3o
ool200000080oooo0P0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000050?ooo`8000000`3oool00`000000oooo0?ooo`02000000030?ooo`00
000000000080oooo0P0000040?ooo`8000000P3oool4000000030?ooo`000000000000T0000000<0
oooo0000000000000P0000030?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0080oooo0P0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0300000080oooo0P00000R0?ooo`030000003oool0oooo00<0
oooo0P0000070?ooo`80000000<0oooo0000000000000`3oool4000000030?ooo`000000000000<0
000000@0oooo000000000000oooo0`00000>0?ooo`030000003oool000000080oooo0`0000000`3o
ool000000000000200000080oooo00<000000?ooo`0000000P0000030?ooo`040000003oool0oooo
0?ooo`800000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool02P3oool001@0oooo00<000000?ooo`3oool07P3oool2000000<0oooo00D000000?oo
o`3oool0oooo000000090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001@3oool0
0`000000oooo0?ooo`020?ooo`8000000P3oool010000000oooo0?ooo`0000030?ooo`800000103o
oolC000000D0oooo0P0000030?ooo`80000000<0oooo0000000000000P3oool010000000oooo0?oo
o`3oool3000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`060?ooo`04
0000003oool0oooo0?ooo`8000000P3oool2000002@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`8000000P3oool010000000oooo0?ooo`3oool400000080oooo10000000
1@3oool00000000000000000oooo00<00000303oool200000080oooo00D000000?ooo`0000000000
0?ooo`0400000080oooo00<000000?ooo`0000000P0000030?ooo`040000003oool0oooo0?ooo`80
00002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool02P3oool001@0oooo00<000000?ooo`3oool07`3oool200000080oooo0P0000030?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`80
00001@3oool00`000000oooo0?ooo`02000000030?ooo`000000000000<0oooo0`0000001@3oool0
0000000000000000oooo00T00000203oool3000000<0oooo0P0000000`3oool00000000000020?oo
o`8000000`3oool00`000000oooo000000040?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool01P3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`030000003o
ool0oooo0080oooo100000000`3oool0000000000003000000030?ooo`000000000000L000001@3o
ool3000000040?ooo`000000oooo0?ooo`<000000`3oool3000000<0oooo100000040?ooo`060000
003oool0oooo0000003oool00000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool02P3oool001@0oooo00<000000?ooo`3oool07`3oool2000000<0
oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00<0oooo00@000000?oo
o`3oool00000103oool2000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000P3o
ool6000000h0oooo100000040?ooo`80000000<0oooo0000000000000`3oool00`000000oooo0?oo
o`020?ooo`<00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00H0oooo
00L000000?ooo`3oool0oooo0000003oool000000080oooo0P00000W0?ooo`8000001@3oool20000
00H0oooo0`0000000`3oool00000000000030?ooo`@000000P3oool5000000040?ooo`0000000000
00000080oooo1`0000020?ooo`8000000`3oool3000000<0oooo0`0000030?ooo`030000003oool0
0000008000000`3oool010000000oooo0?ooo`3oool2000000T0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo000D0?ooo`030000003oool0
oooo0200oooo0P0000030?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo000000@0oooo0P0000050?ooo`040000003oool0oooo0?ooo`80
000000<0oooo0000000000000P0000050?ooo`h000001P3oool2000000030?ooo`000000000000<0
oooo0P0000030?ooo`<000001@3oool010000000oooo0000000000040?ooo`030000003oool0oooo
00L0oooo00@000000?ooo`3oool0oooo0`0000000`3oool000000000000Z0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool200000080oooo00@000000?ooo`3oool0oooo1@00
00000`3oool000000000000300000080oooo1@0000000`3oool0000000000004000000@0oooo00@0
00000?ooo`00000000000`3oool3000000<0oooo00<000000?ooo`0000000P0000030?ooo`070000
003oool0oooo0?ooo`000000oooo000000080?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0:0?ooo`00503oool00`000000oooo0?ooo`0Q0?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool00000103oool2000000D0oooo1`0000030?ooo`8000005@3oool2
000000030?ooo`000000000000<0oooo0P0000040?ooo`030000003oool0000000D0oooo00<00000
0?ooo`0000001@3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0?ooo`80000000@0
oooo0000000000000000;03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
0P0000020?ooo`8000000P3oool6000000030?ooo`000000000000<000000P3oool7000000D0oooo
1@0000040?ooo`<000000`3oool00`000000oooo00000002000000@0oooo00H000000?ooo`3oool0
00000?ooo`0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0:0?ooo`004`3oool300000280oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool01@000000
oooo0?ooo`3oool0000000@0oooo0P0000030?ooo`H000000P3oool300000080oooo1P0000090?oo
o`T000000`3oool2000000@0oooo0P0000000`3oool000000?ooo`030?ooo`80000000<0oooo0000
003oool0103oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0?ooo`8000000P3oool2
000002h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`<000000P3oool0
10000000oooo0?ooo`3oool3000000030?ooo`000000oooo00H0000000<0oooo0000000000003P00
00030?ooo`040000003oool00000000000<0oooo00<000000?ooo`0000000P0000040?ooo`070000
003oool0oooo0?ooo`000000oooo000000080?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`004`3oool00`000000oooo0?ooo`0S0?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`@000001P3oool2000000<0oooo10000004
0?ooo`T0000000<0oooo0000000000000P0000040?ooo`<00000103oool2000000030?ooo`000000
000000@0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`070?ooo`040000003o
ool0oooo0?ooo`8000000`3oool2000002l0oooo0P0000050?ooo`8000001`3oool200000080oooo
00@000000?ooo`3oool0oooo0`000000103oool000000000003oool7000000030?ooo`0000000000
00X00000103oool2000000030?ooo`000000oooo00<0oooo1@0000040?ooo`060000003oool0oooo
0000003oool000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool02P3oool001<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`04
0?ooo`060000003oool0oooo0?ooo`000000oooo1`0000070?ooo`<00000103oool>000000D0oooo
0`0000050?ooo`80000000<0oooo0000000000001@3oool010000000oooo0?ooo`0000040?ooo`80
00002@3oool010000000oooo0?ooo`3oool2000000<0oooo0P00000b0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool200000080oooo0P0000020?ooo`@0000000@0oooo0000
003oool0oooo1`0000030?ooo`H000001@3oool4000000D0oooo0P0000000`3oool0000000000004
0?ooo`060000003oool0oooo0000003oool000002@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool02@3oool001<0oooo00<000000?ooo`3oool0903o
ool010000000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`040?ooo`D000001@3oool4000000P0oooo1000000?0?ooo`@000001P3oool2000000030?oo
o`000000000000H0oooo00@000000?ooo`0000000000103oool00`000000oooo0?ooo`080?ooo`07
0000003oool0oooo0?ooo`000000oooo000000020?ooo`<00000<`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo0`0000020?ooo`040000003oool0oooo0?ooo`<0000000<0
oooo0000000000000P3oool4000000030?ooo`000000000000`0oooo00@000000?ooo`0000000000
1@3oool00`000000oooo00000002000000@0oooo00@000000?ooo`3oool0oooo0P0000090?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`00
4`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0?ooo`D000000P3oool00`000000
oooo0?ooo`040?ooo`@000002P3oool5000000D0oooo1@0000080?ooo`80000000<0oooo00000000
00001P3oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool0203oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool2000000030?ooo`000000oooo03<0oooo00<00000
0?ooo`3oool0103oool2000000L0oooo0P0000020?ooo`8000000P3oool4000000030?ooo`000000
00000080oooo1`0000080?ooo`80000000<0oooo0000000000001P3oool00`000000oooo00000002
000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000T0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo000C0?ooo`030000003o
ool0oooo02D0oooo00@000000?ooo`3oool0oooo0P0000040?ooo`030000003oool0oooo00L0oooo
0`0000050?ooo`030000003oool0oooo008000001P3oool4000000d0oooo1@00000;0?ooo`800000
00<0oooo0000000000001P3oool200000080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0080oooo0P0000020?ooo`8000000P3oool00`000000oooo
0?ooo`0c0?ooo`8000001P3oool00`000000oooo0?ooo`050?ooo`8000000`3oool010000000oooo
0?ooo`3oool4000000030?ooo`000000oooo0080oooo4P0000060?ooo`030000003oool000000080
0000103oool01`000000oooo0?ooo`3oool000000?ooo`0000002@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02@3oool001<0oooo00<000000?oo
o`3oool09@3oool2000000<0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0`0000000`3o
ool000000?ooo`060?ooo`8000000P3oool2000000H0oooo1@00000G0?ooo`H000001P3oool20000
0080oooo0P0000050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool20000
0080oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01P3oool200000080oooo00<000000?ooo`3oool00P3oool30000
00030?ooo`000000000000<0oooo3`0000060?ooo`030000003oool0oooo00<00000103oool01`00
0000oooo0?ooo`3oool000000?ooo`0000002@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool02@3oool00180oooo00<000000?ooo`3oool09`3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`03000000D0oooo
0P0000070?ooo`050000003oool0oooo0?ooo`0000001`3oool9000000l0oooo1@0000070?ooo`80
00000`3oool00`000000oooo0?ooo`030?ooo`8000002P3oool00`000000oooo0?ooo`020?ooo`80
00000P3oool00`000000oooo000000030?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`060?ooo`8000000P3oool2000000<0oooo100000000`3oool0
0000000000020?ooo`030000003oool0000000T00000203oool01@000000oooo0000003oool00000
00D0oooo00L000000?ooo`3oool0oooo0000003oool0000000T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo000B0?ooo`030000003oool0
oooo02P0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`<000002P3oool00`000000oooo0?oo
o`050?ooo`040000003oool0oooo0?ooo`800000203ooolF000000P0oooo0`0000030?ooo`800000
1@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000
003oool0000000@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`040?ooo`800000
1`3oool2000000<0oooo00<000000?ooo`3oool00P3oool4000000050?ooo`00000000000?ooo`00
00004P3oool00`000000oooo00000002000000H0oooo00L000000?ooo`3oool0oooo0000003oool0
000000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00T0oooo000B0?ooo`030000003oool0oooo02P0oooo0P0000030?ooo`@000000P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo0P0000030?ooo`800000303oool90000
00`0oooo0`0000040?ooo`8000001P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0080oooo0P0000020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0>03oool20000
00H0oooo00<000000?ooo`3oool01P3oool200000080oooo0P0000030?ooo`D0000000@0oooo0000
000000000000403oool010000000oooo0000003oool2000000H0oooo00L000000?ooo`3oool0oooo
0000003oool0000000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00T0oooo000B0?ooo`030000003oool0oooo02T0oooo100000000`3oool00000
000000040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool2000000<0oooo
0P00000M0?ooo`8000001@3oool2000000H0oooo0P00000;0?ooo`030000003oool0oooo0080oooo
0P0000020?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00H0oooo0P0000030?ooo`8000000`3oool500000080oooo
0`00000<0?ooo`80000000<0oooo0000003oool00P0000060?ooo`070000003oool0oooo0?ooo`00
0000oooo000000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`090?ooo`004P3oool00`000000oooo0?ooo`0W0?ooo`<0000000<0oooo0000003o
ool00P3oool2000000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`80
00000`3oool3000001L0oooo0`0000050?ooo`8000001`3oool00`000000oooo0?ooo`090?ooo`80
00000`3oool300000080oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo00@0oooo0P0000080?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`L0
000000<0oooo0000000000000`0000050?ooo`8000000P3oool00`000000oooo0?ooo`02000000H0
oooo00L000000?ooo`3oool0oooo0000003oool0000000T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo000B0?ooo`030000003oool0oooo
02@0oooo0`0000030?ooo`030000003oool0000000<0oooo0P0000030?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0203oool2000000@0oooo1P00000:0?ooo`L000001P3oool20000
00L0oooo0P00000;0?ooo`030000003oool0oooo0080oooo0`0000020?ooo`030000003oool00000
00P0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo0P0000030?ooo`800000103oool6000000D0oooo1@0000030?ooo`80000000<0oooo0000
000000001`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool0
0180oooo00<000000?ooo`3oool0803oool4000000H0oooo00<000000?ooo`000000103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo0P00000:0?ooo`<000001`3oool:0000
00X0oooo0`0000070?ooo`800000303oool00`000000oooo0?ooo`020?ooo`8000000P3oool40000
00T0oooo00<000000?ooo`3oool0?@3oool2000000H0oooo00<000000?ooo`3oool01`3oool20000
00<0oooo00<000000?ooo`3oool00`3oool9000000H0oooo0P000000103oool00000000000000008
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`004@3oool0
0`000000oooo0?ooo`0N0?ooo`<000002`3oool00`000000oooo000000040?ooo`030000003oool0
oooo0080oooo0P00000<0?ooo`8000002`3oool2000001D0oooo100000080?ooo`8000003@3oool0
0`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo0000000;0?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool0103oool2000000P0oooo0`0000020?ooo`8000001@3oool6
000000030?ooo`000000000000@000000P3oool2000000030?ooo`000000oooo00H0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000090?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`004@3oool00`000000oooo0?ooo`0K0?oo
o`<000003`3oool00`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool02`3oool2000000/0oooo200000090?ooo`@000002P3oool2000000d0oooo0P0000040?oo
o`8000000P3oool00`000000oooo0000000<0?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`070?ooo`8000000`3oool2000000H0oooo3`0000080?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00140oooo00<000000?ooo`3o
ool0603oool3000001<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00`0oooo0`00000@0?ooo`T00000303oool2000000h0oooo00<000000?ooo`3o
ool00P3oool300000080oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`110?ooo`80
00001P3oool00`000000oooo0?ooo`070?ooo`<000000`3oool2000000D0oooo00@000000?ooo`3o
ool0oooo1P00000<0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000002P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00140
oooo00<000000?ooo`3oool05@3oool3000001L0oooo00<000000?ooo`0000000`3oool2000000D0
oooo0P00000?0?ooo`8000008@3oool2000000l0oooo00<000000?ooo`3oool00P3oool300000080
oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00@0
oooo0P0000090?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`030?ooo`8000002`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0203oool00140oooo00<000000?ooo`3oool04@3oool4000001/0oooo
00<000000?ooo`0000000`3oool2000000H0oooo00<000000?ooo`3oool03P3oool2000001/0oooo
1000000?0?ooo`800000103oool200000080oooo0P0000000`3oool000000?ooo`0>0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`<00000
103oool2000000<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`800000
2`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
203oool00140oooo00<000000?ooo`3oool03P3oool300000200oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`0?0?ooo`D000004P3oool400000140oooo0P0000040?ooo`<000000P3o
ool010000000oooo00000000000@0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`080?ooo`<00000103oool3000000030?ooo`000000oooo0100oooo
00<000000?ooo`3oool00`3oool00`000000oooo0000000;0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`004@3oool00`000000oooo0?oo
o`0;0?ooo`<00000903oool2000000@0oooo0P0000060?ooo`800000503oool7000000H0oooo1@00
000C0?ooo`8000001@3oool2000000<0oooo00<000000?ooo`0000004P3oool00`000000oooo0?oo
o`160?ooo`8000001P3oool2000000T0oooo100000050?ooo`<00000403oool00`000000oooo0?oo
o`030?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00L0oooo000A0?ooo`030000003oool0oooo00P0oooo0`00000X
0?ooo`8000001@3oool2000000H0oooo00<000000?ooo`3oool0603oool6000001H0oooo0P000005
0?ooo`<000000P3oool2000000030?ooo`000000oooo0180oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00@000000?ooo`00000000001@3o
ool4000000/0oooo0P0000060?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo000@0?ooo`030000003oool0
oooo00H0oooo0`00000/0?ooo`8000001@3oool2000000H0oooo00<000000?ooo`3oool0<@3oool2
000000H0oooo0P0000030?ooo`040000003oool00000000001@0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000000
00040?ooo`030000003oool0oooo00D00000103oool2000000P0oooo0P00000=0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`00403oool0
0`000000oooo0?ooo`020?ooo`@00000<@3oool2000000@0oooo0`0000050?ooo`800000;`3oool2
000000H0oooo0`0000020?ooo`80000000<0oooo0000003oool05@3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo00D0oooo0P00000:0?ooo`80000000<0oooo0000000000000`3oool0
0`000000oooo0?ooo`040?ooo`@000002@3oool00`000000oooo0000000=0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`00403oool00`00
0000oooo00000002000003H0oooo0`0000030?ooo`@000001@3oool2000002/0oooo0P0000070?oo
o`8000000`3oool010000000oooo0?ooo`00000G0?ooo`030000003oool0oooo04/0oooo0P000007
0?ooo`030000003oool0oooo00T0oooo1@0000020?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`0000003@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool01`3oool00100oooo0P00000j0?ooo`030000003oool0000000@0oooo100000050?oo
o`<00000903oool4000000L0oooo0`0000030?ooo`040000003oool00000000001P0oooo00<00000
0?ooo`3oool0C@3oool00`000000oooo0?ooo`050?ooo`800000303oool4000000030?ooo`000000
oooo00l0oooo0`00000>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`070?ooo`004@3oool2000003X0oooo00@000000?ooo`0000000000103oool3
000000L0oooo0`00000N0?ooo`<000002@3oool3000000<0oooo0P0000000`3oool000000?ooo`0I
0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;
0?ooo`H00000303oool2000000030?ooo`000000oooo00h0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo000C0?ooo`030000003oool0oooo
03P0oooo00@000000?ooo`3oool000001@3oool3000000P0oooo1000000F0?ooo`@000002@3oool4
000000@0oooo00@000000?ooo`00000000006`3oool00`000000oooo0?ooo`1?0?ooo`8000001`3o
ool2000000h0oooo2@0000040?ooo`80000000<0oooo000000000000403oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool001@0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`02000000D0oooo0`00000:0?ooo`<000002P3oool9
000000X0oooo1@0000040?ooo`@000007@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool03P3oool:00000080oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool0
01D0oooo0P00000i0?ooo`040000003oool0oooo0?ooo`8000001@3oool4000000X0oooo2P00000@
0?ooo`<0000000<0oooo000000000000103oool4000001l0oooo00<000000?ooo`3oool0DP3oool0
0`000000oooo0?ooo`060?ooo`8000003`3oool00`000000oooo0?ooo`020?ooo`H000004`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool0
01L0oooo00<000000?ooo`3oool0=`3oool2000000<0oooo00<000000?ooo`3oool0103oool60000
01d0oooo0`0000020?ooo`800000103oool2000000030?ooo`000000oooo0200oooo00<000000?oo
o`3oool0D`3oool2000000P0oooo0P00000>0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo000H0?ooo`03
0000003oool0oooo03P0oooo0`0000000`3oool00000000000060?ooo`8000000P3oool4000001<0
oooo1P0000000`3oool0000000000002000000<0oooo0`0000000`3oool000000000000R0?ooo`03
0000003oool0oooo05D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00H0oooo000I0?ooo`800000>`3oool2000000030?ooo`000000000000H0oooo
1@0000000`3oool0000000000002000000L0oooo200000020?ooo`D000001@3oool200000080oooo
0P00000T0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool01`3oool2000000`0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0e0?ooo`H00000203oool<000000@0oooo1P0000070?ooo`<000000P3oool2000002H0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01P3oool001`0oooo00D000000?ooo`3oool0oooo0000000j0?ooo`P00000303o
ool7000000/0oooo0P0000020?ooo`<00000:03oool00`000000oooo0?ooo`1H0?ooo`8000002@3o
ool2000000/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool01P3oool001d0oooo0P0000000`3oool000000?ooo`0l
0?ooo`8000000`3oool4000001@0oooo2P00000[0?ooo`030000003oool0oooo05X0oooo00<00000
0?ooo`3oool0203oool2000000X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool001l0oooo0P00000o0?oo
o`<00000103oool5000000L0oooo200000020?ooo`@00000;`3oool00`000000oooo0?ooo`1K0?oo
o`030000003oool0oooo00T0oooo0P0000090?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo000P0?ooo`03
0000003oool0oooo0400oooo400000060?ooo`@00000<`3oool00`000000oooo0?ooo`1L0?ooo`80
00002`3oool2000000P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool00240oooo0P00001:0?ooo``00000
=`3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00X0oooo0P0000070?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00D0oooo000S0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0G`3o
ool00`000000oooo0?ooo`0;0?ooo`<000001@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`00903oool0
0`000000oooo0?ooo`290?ooo`030000003oool0oooo0600oooo0P00000>0?ooo`800000103oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`050?ooo`009@3oool2000008T0oooo00<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`0=0?ooo`8000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`009`3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool03P3oool200000003
0?ooo`000000oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0
I@3oool200000100oooo3`00000B0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
1@3oool002T0oooo0P0000240?ooo`030000003oool0oooo06L0oooo0P00000A0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`00:`3oool0
0`000000oooo0?ooo`210?ooo`030000003oool0oooo06T0oooo0P00000@0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`00;03oool00`00
0000oooo0?ooo`200?ooo`030000003oool0oooo06/0oooo0P00000?0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`006@3oool00`3oohl0
=@00000000040000000503F?o`3oool0oooo0?ooo`3oScD00`0000000`0eSol0oooo0?ooo`020?oo
o`8000000P3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo06d0oooo0P00000>0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?oo
o`006P3oool00`2?=@00000e08ooo`020?ooo`030<AO=@1Oa?l0oooo0080oooo00H0Ga@e08ooo`3o
ool0oon?03D0=@2?ool50?ooo`030000003oool0000007d0oooo00<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`040?ooo`006`3oool00`3oScD0000D05o4o`050?ooo`030?n?=@00=Hl0oooo
0080oooo00<0a5lD01AOa03oool01@3oool2000007d0oooo00<000000?ooo`3oool0L03oool20000
00d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00@0oooo000L0?ooo`030?o4G`0D000055o400@0oooo00<0a5lD01AOa03oool00P3oool00`3oScD0
03F?0?ooo`060?ooo`800000O03oool00`000000oooo0?ooo`1b0?ooo`8000002`3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool00140oooo
00<0Ga@00000000000000`0000000`0055l0oooo0?ooo`040?ooo`0305lD000DGl@0oooo0080oooo
00<0a5lD01AOa03oool00P3oool00`3oScD003F?0?ooo`080?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool0M03oool2000000X0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00@0oooo000O0?ooo`0605lD=@2?ool0oooo0?ooo`34Ga@0
55o40`3oool00`3oScD003F?0?ooo`090?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool0MP3oool2000000T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00@0oooo000J0?ooo`030<AO500eSol0oooo0080oooo00H0ScD003F?o`3oool0
oooo0?n?=@0DGl@30?ooo`030<AO500DGl@0oooo00X0oooo0P00001h0?ooo`030000003oool0oooo
07P0oooo0P0000080?ooo`030000003oool0oooo0100oooo0P00000A0?ooo`030000003oool0oooo
00@0oooo000J0?ooo`070?n?=@0003D0Sooo0?ooo`3oScD0000D05o4o`030?ooo`0605lD000eSol0
oooo0?o4G`0D03D0Sooo3@3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo07X0oooo
0P0000070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`040?ooo`006`3oool01@3oScD000000000000001@0GlCo00@0oooo00D0oon?03D000000000
000D05o4o`0?0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0O03oool3000000D0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0
oooo000i0?ooo`800000M03oool00`000000oooo0?ooo`1o0?ooo`@000000P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00`3oool003/0oooo00<0
00000?ooo`3oool0L@3oool00`000000oooo0?ooo`230?ooo`D00000203oool2000001L0oooo00<0
00000?ooo`3oool00`3oool003`0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`27
0?ooo`D000000`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo000m0?oo
o`800000L03oool00`000000oooo0?ooo`280?ooo`040000003oool0oooo0?ooo`<000006P3oool0
0`000000oooo0?ooo`030?ooo`00?`3oool00`000000oooo0000001]0?ooo`030000003oool0oooo
08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`030?ooo`00@03oool2000006d0
oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00<0
oooo00110?ooo`800000K03oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool00`3oool004<0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?oo
o`2;0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool004@0oooo00<00000
0?ooo`3oool0J03oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool00P3oool004D0oooo0P00001X0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`020?ooo`00A`3oool00`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`00
B03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`020?ooo`00B@3oool2000006@0oooo00<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0080oooo001;0?ooo`030000003oool0
oooo0640oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo0080oooo001<0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo001=0?ooo`800000H03oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool004l0oooo
00<000000?ooo`000000G@3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool00@3oool00500oooo0P00001M0?ooo`030000003oool0oooo09@0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`010?ooo`00D@3oool2000005`0oooo00<00000
0?ooo`3oool0U@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0040oooo001C0?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0040oooo001D0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0U`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0040oooo001E0?ooo`800000
F03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0@3oool005L0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`2I0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00@3oool005P0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`2I0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00@3oool0
05T0oooo0P00001D0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`010?ooo`00F`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo09/0
oooo00<000000?ooo`3oool03P3oool100000040oooo0@3oool005`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0
3@3oool100000040oooo0@3oool005d0oooo0P0000020?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0W@3oool00`000000oooo0?ooo`0<0?ooo`4000000@3oool10?ooo`00G`3oool2
000004h0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0;0?ooo`4000000@3oool1
0?ooo`00H03oool2000004d0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0:0?oo
o`4000000@3oool10?ooo`00HP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0:00
oooo00<000000?ooo`3oool02@3oool100000040oooo0@3oool006<0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo00P0oooo0@0000010?ooo`40oooo
001T0?ooo`800000B@3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo00P0oooo0@00
00010?ooo`40oooo001V0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0XP3oool0
0`000000oooo0?ooo`080?ooo`4000000@3oool006L0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`2S0?ooo`030000003oool0oooo00L0oooo0@0000010?ooo`00J03oool2000004D0
oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`060?ooo`4000000@3oool006X0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00D0oooo
0@0000010?ooo`00J`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0:H0oooo00<0
00000?ooo`3oool0103oool100000040oooo001/0?ooo`80000000<0oooo0000003oool0?P3oool0
0`000000oooo0?ooo`2W0?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`00G@3oool01@3o
ScD00000000000000000=Hoo00`0oooo0P00000o0?ooo`030000003oool0oooo0:P0oooo00<00000
0?ooo`3oool00P3oool100000040oooo001M0?ooo`0605lD=@2?ool0oooo0?ooS`0e03D0Sooo303o
ool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0:T0oooo00D000000?ooo`3oool0oooo
000000010?ooo`00G03oool00`3oScD003F?0?ooo`020?ooo`030<AO500DGl@0oooo00`0oooo0P00
000m0?ooo`030000003oool0oooo0:X0oooo00@000000?ooo`3oool000000@3oool005`0oooo00<0
a5lD01AOa03oool00P3oool00`3oScD003F?0?ooo`0>0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0ZP3oool010000000oooo0?ooo`3oool100000000G03oool00`34Ga@055o40?oo
o`020?ooo`030?n?=@00=Hl0oooo00l0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`2[0?ooo`030000003oool0oooo00400000001L0?ooo`030<AO500DGl@0oooo0080oooo00<0ohle
000eS`3oool0403oool2000003T0oooo00<000000?ooo`3oool0[03oool100000040oooo0@000000
05`0oooo00<0ohle01AOa03oool00P3oool00`34Ga@055o40?ooo`0B0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[@3oool200000000G@3oool01P1O5000=Hoo0?ooo`3oa5l0500e
08oooa@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`2/0?ooo`<00000001M0?oo
o`050?ooS`0e000000000000501Oa?l05P3oool2000003D0oooo00<000000?ooo`3oool0Z03oool4
000000<0oooo001j0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0Y03oool40000
00L0oooo001k0?ooo`030000003oool000000340oooo00<000000?ooo`3oool0W`3oool5000000/0
oooo001l0?ooo`800000<@3oool00`000000oooo0?ooo`2K0?ooo`@00000403oool007h0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`2G0?ooo`@00000503oool007l0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`2B0?ooo`D00000603oool00800oooo0P00000]0?oo
o`030000003oool0oooo08h0oooo1000000M0?ooo`00PP3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo08/0oooo1000000Q0?ooo`00P`3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo08H0oooo1@00000U0?ooo`00Q03oool2000002P0oooo00<000000?ooo`3oool0PP3o
ool4000002X0oooo00260?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0OP3oool4
000002h0oooo00270?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0N@3oool50000
0380oooo00280?ooo`<000008`3oool00`000000oooo0?ooo`1e0?ooo`@00000=`3oool008X0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1a0?ooo`@00000>`3oool008/0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1/0?ooo`D00000?`3oool008`0oooo0P00000P
0?ooo`030000003oool0oooo06P0oooo100000140?ooo`00SP3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo06@0oooo100000180?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo05l0oooo1@00001<0?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0
F`3oool400000540oooo002B0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0E`3o
ool4000005D0oooo002C0?ooo`050000003oool0oooo0?ooo`0000005P3oool00`000000oooo0?oo
o`1B0?ooo`D00000F@3oool009@0oooo0P0000000`3oool000000?ooo`0E0?ooo`030000003oool0
oooo04h0oooo1000001N0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0B@3oool50000
0680oooo002G0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0A@3oool4000006L0
oooo002H0?ooo`800000503oool00`000000oooo0?ooo`110?ooo`@00000J`3oool009X0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0l0?ooo`D00000K`3oool009/0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0h0?ooo`@00000M03oool009`0oooo0P00000@0?oo
o`030000003oool0oooo03@0oooo1000001h0?ooo`00WP3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo02l0oooo1@00001l0?ooo`00W`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo02/0oooo100000210?ooo`00X03oool2000000`0oooo00<000000?ooo`3oool09`3o
ool4000008D0oooo002R0?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool08P3oool5
000008T0oooo002S0?ooo`8000002@3oool00`000000oooo0?ooo`0N0?ooo`@00000SP3oool00:@0
oooo0P0000080?ooo`030000003oool0oooo01X0oooo1000002B0?ooo`00SP3oool00`3oohl0=@00
000000040000000503F?o`3oool0oooo0?ooo`3oScD00`0000000`0eSol0oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool5000009H0oooo002?0?ooo`0308le
000003D0Sooo0080oooo00<0a5le05o4o`3oool00P3oool01P1O53D0Sooo0?ooo`3oohl0=@0e08oo
o`P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0A0?ooo`@00000V`3oool00900
oooo00<0ohle0000501Oa?l01@3oool00`3oScD003F?0?ooo`020?ooo`030<AO500DGl@0oooo00P0
oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000002O0?ooo`00T@3oool00`3oa5l05000
01AOa0040?ooo`030<AO500DGl@0oooo0080oooo00<0ohle000eS`3oool02P3oool01@000000oooo
0?ooo`3oool0000000X0oooo1@00002S0?ooo`00T`3oool00`1O500055o40?ooo`020?ooo`030<AO
500DGl@0oooo0080oooo00<0ohle000eS`3oool02`3oool010000000oooo0?ooo`0000060?ooo`@0
0000Z03oool009@0oooo00H0Ga@e08ooo`3oool0oooo0<AO500DGl@30?ooo`030?n?=@00=Hl0oooo
00`0oooo0`0000020?ooo`@00000[03oool008l0oooo00<0a5lD03F?o`3oool00P3oool01P2?=@00
=Hoo0?ooo`3oool0ohle01AOa0<0oooo00<0a5lD01AOa03oool03P3oool300000;00oooo002?0?oo
o`070?noM00007@0_ooo0?ooo`3o_g@0001809cOo`030?ooo`0609a8001d_ol0oooo0?oOW01807@0
_ooo`P3oool00900oooo00D0okmd000000000000001809cOo`040?ooo`050?oo_`1d000000000000
B02Lgol0``3oool00?l0ooooHP3oool00001\
\>"],
  ImageRangeCache->{{{0, 352.063}, {434.25, 0}} -> {0.0534541, -0.0401236, \
0.0034178, 0.0034178}}]
}, Closed]],

Cell["Sensitivity to initial conditions", "Exercise"],

Cell[TextData[{
  "Define ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta][
          t] = \@\(\((x\_1[t] - x\_2[t])\)\^2 + \((y\_1[t] - y\_2[t])\)\^2 + \
\((z\_1[t] - z\_2[t])\)\^2\)\)]],
  " to be the Cartesian distance between two orbits.  Write a function which \
constructs ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta][t]\)]],
  " for two orbits that represent solutions to the Lorenz equations with \
slightly different initial conditions.  For example, use ",
  StyleBox["LogPlot", "InlineInput",
    FontWeight->"Bold"],
  " to display ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta][t]\)]],
  " for initial conditions {0,1,1} and {0.01,1,1} and determine how long it \
takes for these orbits to diverge from each other."
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Accuracy issues", "Subsection"],

Cell[TextData[{
  StyleBox["NDSolve", "InlineInput",
    FontWeight->"Bold"],
  " employs several sophisticated adaptive algorithms which attempt to \
optimize both speed and accuracy without user intervention, but no algorithm \
can succeed for every conceivable set of differential equations.  \
Consequently, a vast literature has accumulated over the last 100 years or so \
discussing a large variety of numerical methods and comparing their \
strengths, weaknesses, and realms of applicability.  Although it is certainly \
beyond the scope of this course to review the literature on the subject or to \
implement many of these competing algorithms, one must be aware of the \
options available for regulating the accuracy of the standard algorithm, for \
Murphy's law decrees that your first interesting problem will challenge the \
default algorithm.  At that time you may be motivated to produce a custom \
integrator suitable to your application or may seek an alternative package.  \
In either case, one must have some insight into the nature of the equation at \
hand and the special challenges it might present.  Nevertheless, after all of \
these obligatory caveats, one should recognize that the default algorithm is \
already as good or better than most of the alternatives and that if your \
problem looks intractable in its present form the best approach is often to \
seek a better representation of the problem than a better numerical algorithm \
\[LongDash] brute computation is a poor substitute for insight."
}], "Text"],

Cell[TextData[{
  "A very good discussion of the accuracy options available to ",
  StyleBox["NDSolve", "InlineInput",
    FontWeight->"Bold"],
  " can be found in ",
  ButtonBox["Section 3.9.7",
    ButtonData:>{"3.9.7", "7.1"},
    ButtonStyle->"MainBookLink"],
  " of the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " book.  First, we list those options."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[NDSolve]\)], "Input"],

Cell[BoxData[
    \({AccuracyGoal \[Rule] Automatic, Compiled \[Rule] True, 
      DependentVariables \[Rule] Automatic, EvaluationMonitor \[Rule] None, 
      MaxStepFraction \[Rule] 1\/10, MaxSteps \[Rule] Automatic, 
      MaxStepSize \[Rule] Automatic, Method \[Rule] Automatic, 
      NormFunction \[Rule] Automatic, PrecisionGoal \[Rule] Automatic, 
      SolveDelayed \[Rule] False, StartingStepSize \[Rule] Automatic, 
      StepMonitor \[Rule] None, 
      WorkingPrecision \[Rule] MachinePrecision}\)], "Output"]
}, Closed]],

Cell[TextData[{
  StyleBox["AccuracyGoal", "InlineInput",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "specifies the number of decimal digits for the solution itself, while ",
  StyleBox["PrecisionGoal", "InlineInput",
    FontWeight->"Bold"],
  " governs the relative precision of the solution.  If the solution varies \
strongly in magnitude, the relative precision may be most important, \
particularly if small errors in small values tend to grow into large errors \
elsewhere, which is a property of unstable systems.  Setting ",
  StyleBox["AccuracyGoal\[Rule]Infinity", "InlineInput",
    FontWeight->"Bold"],
  " instructs the program to test ",
  StyleBox["PrecisionGoal", "InlineInput",
    FontWeight->"Bold"],
  " only.  With automatic settings, ",
  StyleBox["AccuracyGoal", "InlineInput",
    FontWeight->"Bold"],
  " and ",
  StyleBox["PrecisionGoal", "InlineInput",
    FontWeight->"Bold"],
  " are about half the ",
  StyleBox["WorkingPrecision", "InlineInput",
    FontWeight->"Bold"],
  "; hence, increasing either goal generally requires increasing ",
  StyleBox["WorkingPrecision", "InlineInput",
    FontWeight->"Bold"],
  " also.  If necessary, ",
  StyleBox["NDSolve", "InlineInput",
    FontWeight->"Bold"],
  " adjusts its step sizes to meet these goals provided that ",
  StyleBox["MaxSteps", "InlineInput",
    FontWeight->"Bold"],
  " is not exceeded.  ",
  StyleBox["MaxSteps", "InlineInput",
    FontWeight->"Bold"],
  " may be exceeded either when there are accuracy problems or when the range \
of integration is very large, in which case one can increase it, perhaps to \
",
  StyleBox["Infinity", "InlineInput",
    FontWeight->"Bold"],
  " if you are patient and brave.  Occasionally it is necessary to reduce ",
  StyleBox["StartingStepSize", "InlineInput",
    FontWeight->"Bold"],
  " if the solution varies rapidly near its starting point."
}], "Text"],

Cell["Consider, for example, the following simple equation.  ", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(y\^\[DoublePrime]\)[x]\  - \ \(\[Lambda]\^2\) 
          y[x]\  \[Equal] \ 0, \ 
    y[0] \[Equal] 
      1, \ \(y\^\[Prime]\)[
          0] \[Equal] \(-\[Lambda]\ \ \ \[DoubleLongRightArrow]\ \ y[
              x]\)\  = \ \[ExponentialE]\^\(\(-\[Lambda]\)\ x\)\)], \
"DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "Although the symbolic solution is trivial, numerical algorithms may \
encounter considerable difficulty if ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " happens to be large.  The reason for this behavior is easy to explain for \
such a simple equation.  Consider the original equation without the initial \
conditions."
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(y\^\[DoublePrime]\)[x]\  - \ \(\[Lambda]\^2\) 
            y[x]\  \[Equal] \ 0\ \ \ \[DoubleLongRightArrow]\ \ y[x]\  = \ 
      A\ \[ExponentialE]\^\(\(-\[Lambda]\)\ x\)\  + \ 
        B\ \[ExponentialE]\^\(\[Lambda]\ x\)\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "The second-order differential equation has two linearly independent \
solutions whose mixing is determined by the initial conditions.  Although we \
chose initial conditions which selected the exponentially decaying solution \
and eliminated the growing solution, numerical methods find it much more \
difficult to suppress the divergent solution.  Any numerical error in the \
initial conditions or the integration procedure will introduce a small \
admixture of the spurious solution, which then grows uncontrollably until it \
overwhelms the correct solution.  The present equation is described as ",
  StyleBox["stiff",
    FontSlant->"Italic"],
  " because the coefficient that multiplies errors is large, here ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^2\)]],
  ", so that small errors are quickly amplified."
}], "Text"],

Cell["\<\
The following functions can be used to compare numerical solution with \
suitable acccuracy option with the true solution.\
\>", "Text"],

Cell[BoxData[{
    \(\(stiffEq[\[Lambda]_] := {\(y\^\[DoublePrime]\)[
                x] - \[Lambda]\^2\ y[x] \[Equal] 0, 
          y[0] \[Equal] 
            1, \(y\^\[Prime]\)[
              0] \[Equal] \(-\[Lambda]\)};\)\), "\[IndentingNewLine]", 
    \(\(stiffSol[\[Lambda]_, xmax_, opts___Rule] := 
        y[x] /. \(NDSolve[stiffEq[\[Lambda]], y, {x, 0, xmax}, 
              opts]\)\[LeftDoubleBracket]1\[RightDoubleBracket];\)\), "\
\[IndentingNewLine]", 
    \(trueSol[\[Lambda]_] := 
      y[x] /. DSolve[stiffEq[\[Lambda]], y, x]\)}], "Input"],

Cell[TextData[{
  "Consider the two plots show below.  Both solve the same equation with the \
same large ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  ", but the first uses a larger range of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " than the second even though  both are plotted for the same range.  The \
first solution appears to start plausibly, but a spurious divergence occurs \
for large ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " that is absent in the second solution with a more restricted range.  \
Evidently, a larger step size is used for the larger range and numerical \
errors near the starting point produce an intolerably large admixture of the \
spurious divergent solution."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Plot[Evaluate[stiffSol[20, 30]], {x, 0, 10}, 
        PlotRange \[Rule] {Automatic, {0, 1}}];\)\), "\[IndentingNewLine]", 
    \(\(Plot[Evaluate[stiffSol[20, 10]], {x, 0, 10}, 
        PlotRange \[Rule] {Automatic, {0, 1}}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0 0.618034 [
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.01131 .12361 -18 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -18 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -18 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(0.2)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.4)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.6)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.8)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .61803 m
.02499 .48283 L
.02605 .38569 L
.02729 .29761 L
.02846 .23292 L
.03053 .15062 L
.0317 .11777 L
.03279 .09384 L
.03388 .07457 L
.03506 .05824 L
.03635 .04441 L
.03756 .03444 L
.03891 .02592 L
.0402 .01978 L
.04136 .01552 L
.04262 .0119 L
.04396 .00898 L
.04523 .00688 L
.04636 .00542 L
.04759 .00419 L
.04894 .00316 L
.05036 .00234 L
.05157 .00182 L
.0529 .00137 L
.05415 .00106 L
.05528 .00083 L
.05659 .00063 L
.05784 .00049 L
.05898 .00038 L
.06004 .00031 L
.06121 .00024 L
.06244 .00019 L
.06371 .00014 L
.06504 .00011 L
.06617 8e-005 L
.06742 7e-005 L
.06876 5e-005 L
.07019 4e-005 L
.07155 3e-005 L
.07277 2e-005 L
.07402 2e-005 L
.07517 1e-005 L
.07643 1e-005 L
.07776 1e-005 L
.07892 1e-005 L
.08001 0 L
.0812 0 L
.08247 0 L
.08394 0 L
.08531 0 L
Mistroke
.08681 0 L
.0884 0 L
.08992 0 L
.09135 0 L
.09264 0 L
.09402 0 L
.0953 0 L
.0967 0 L
.09816 0 L
.09953 0 L
.1008 0 L
.10197 0 L
.10331 0 L
.10458 0 L
.10572 0 L
.10696 0 L
.10812 0 L
.10918 0 L
.11037 0 L
.11166 0 L
.11231 0 L
.11301 0 L
.11426 0 L
.11495 0 L
.11559 0 L
.11629 0 L
.11703 0 L
.11828 0 L
.11898 0 L
.11964 0 L
.12088 0 L
.122 0 L
.1233 0 L
.12453 0 L
.12558 0 L
.12675 0 L
.12797 0 L
.12911 0 L
.13115 0 L
.1323 0 L
.13335 0 L
.13451 0 L
.13559 0 L
.13677 0 L
.13803 0 L
.13936 0 L
.14061 0 L
.14174 0 L
.14296 0 L
.14419 0 L
Mistroke
.14531 0 L
.14661 0 L
.14784 0 L
.14897 0 L
.15003 1e-005 L
.15118 1e-005 L
.15241 1e-005 L
.15376 1e-005 L
.15522 2e-005 L
.1566 2e-005 L
.15787 3e-005 L
.15902 3e-005 L
.16027 4e-005 L
.16159 6e-005 L
.16281 7e-005 L
.16412 .0001 L
.16554 .00013 L
.16688 .00018 L
.16813 .00023 L
.16924 .00029 L
.17047 .00037 L
.17176 .00049 L
.17297 .00063 L
.1743 .00083 L
.1757 .00112 L
.1769 .00144 L
.17821 .00189 L
.17962 .00254 L
.18113 .00349 L
.18255 .00471 L
.18385 .00618 L
.18504 .00795 L
.18616 .01005 L
.18739 .013 L
.1887 .01714 L
.19008 .02289 L
.19139 .03012 L
.19256 .03854 L
.19384 .05041 L
.19506 .06506 L
.19616 .08197 L
.19742 .10702 L
.19862 .13752 L
.19973 .17362 L
.20075 .21507 L
.20187 .27204 L
.20305 .34856 L
.20435 .45792 L
.20553 .58701 L
Mfstroke
.20553 .58701 m
.20575 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00K`3oool00`3ookl0M000000000040000000307Boo`3oool0oooo04<0oooo00D0omnL04P0
00000000000007Boo`150?ooo`050;md0000000000000000M02oool0A03oool01@2oM00000000000
0000000007Bo0400oooo00<0okmd0000000000000`0000001@00M;l0oooo0?ooo`3oool0okmd00<0
000000<0M;oo0?ooo`3oool02`3oool00700oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo
0?ooo`160?ooo`030;md001d_ol0oooo04@0oooo00H0gia8001d_`3oool0oooo0?noM000M;m30?oo
o`030?noM000M;l0oooo0080oooo00<0_gA809cOo`3oool0@@3oool00`2LB4P0W=oo0?ooo`040?oo
o`0609a8M02oool0oooo0?oo_`1d07@0_ooo303oool00740oooo00<0okmd0000B02Lgol0BP3oool0
0`2oM000M;oo0?ooo`130?ooo`030?oo_`1d0000M;oo0080oooo00<0oono07A8W03oool0@P3oool0
0`3OW4P0B9cO0?ooo`020?ooo`030;md001d_ol0oooo0440oooo00<0W4Q809cOo`3oool00`3oool0
0`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo00/0oooo001b0?ooo`030?oOW0180000B9cO
04D0oooo00<0gia80000000000000`0000000`1d_ol0oooo0?ooo`110?ooo`070?noM000B4P0M01d
0;ooo`3oool0gia8001d_`130?ooo`030?noM000B9`0oooo0080oooo00<0W4Q809cOo`3oool0@@3o
ool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02`3o
ool007@0oooo00<0W4P004RLg`3oool0@`3oool01P3o_g@0001d0;ooo`3oool0_g@007Bood@0oooo
00<0omnL04Q8W03o_g@00P0000000`00B9`0oooo0?ooo`130?ooo`050=nLB0000000000000000018
W=l0@`3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3o
ool02`3oool007D0oooo00<0W4Qd0;ooo`3oool0@`3oool01@3OW4P007Bo0?ooo`2oM000M;oo04@0
oooo00<0oono07@0M02oool0A`3oool00`3ookl0M4RL0?ooo`020?ooo`0309a8M02oool0oooo0440
oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00/0
oooo001`0?ooo`030=nLB01d_ol0oooo0080oooo00<0_g@007Boo`3oool0A03oool0102LB000B9cO
0;md001d_om50?ooo`030;md0018W=l0oooo04H0oooo00<0okmd04RLg`3oool00P3oool00`2oM000
M;oo0?ooo`110?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0
B9cO0?ooo`0;0?ooo`00L03oool01`3o_g@0001d0;ooo`3oool0okmd0000B02Lgol0A@3oool0103o
gi`0B01804Q8001d_om50?ooo`030?oo_`1d000007Bo04H0oooo00L0omnL04P0M02oool0oooo0?oO
W01807@0_ooo03l0oooo00D0gia800000000B9`0W4Q809cOo`050?ooo`0609a8001d_ol0oooo0?oO
W01807@0_ooo303oool00740oooo00D0okmd000000000000001809cOo`170?ooo`030?noM0000000
M;oo04L0oooo00@0_g@000000000000004RLA03oool01@3o_g@000000000000004P0W=oo0480oooo
00<0gia80000B02Lgol01@3oool01@3ookl0M0000000000004P0W=oo00d0oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo000P0?ooool00000Q`00000:0?ooo`00:@3oool00`000000
oooo0?ooo`070?ooo`8000001P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0
oooo00@000000?ooo`3oool0oooo0`00000<0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool04@3oool002T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0A0?ooo`00
:@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
o`3ooom60?ooo`00:@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool0o`3ooom60?ooo`00:@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0o`3ooom50?ooo`00:@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0o`3ooom50?ooo`00:@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0o`3ooom50?ooo`00
:@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
o`3ooom50?ooo`00:@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool0o`3ooom40?ooo`00:@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool0o`3ooom40?ooo`00:@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0o`3ooom40?ooo`00:@3oool2000000<0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`3o0?oood@0oooo000Y0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`3o0?oood@0oooo
000Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`3o0?oood<0oooo000Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`3o0?oood<0oooo000Y0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`3o0?oood<0oooo000Y0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`3o0?oood<0oooo000Y0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`3o0?oood<0oooo
000Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`3o0?oood<0oooo000Y0?ooo`050000003oool0oooo0?ooo`000000?@3oool00`000000oooo0?oo
o`3o0?oood<0oooo000Y0?ooo`050000003oool0oooo0?ooo`000000?@3oool00`000000oooo0?oo
o`3o0?oood<0oooo000Y0?ooo`050000003oool0oooo0?ooo`000000?@3oool00`000000oooo0?oo
o`3o0?oood<0oooo000Y0?ooo`050000003oool0oooo0?ooo`000000?P3oool00`000000oooo0?oo
o`3o0?oood80oooo000Y0?ooo`8000000P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo0?l0oooo@P3oool002T0oooo00D000000?ooo`3oool0oooo0000000n0?ooo`030000003oool0
oooo0?l0oooo@P3oool002T0oooo00D000000?ooo`3oool0oooo0000000n0?ooo`030000003oool0
oooo0?l0oooo@P3oool002T0oooo00D000000?ooo`3oool0oooo0000000n0?ooo`030000003oool0
oooo0?l0oooo@P3oool002T0oooo00D000000?ooo`3oool0oooo0000000n0?ooo`030000003oool0
oooo0?l0oooo@P3oool002T0oooo00D000000?ooo`3oool0oooo0000000n0?ooo`030000003oool0
oooo0?l0oooo@P3oool002T0oooo00D000000?ooo`3oool0oooo0000000n0?ooo`030000003oool0
oooo0?l0oooo@P3oool002T0oooo00D000000?ooo`3oool0oooo0000000n0?ooo`030000003oool0
oooo0?l0oooo@P3oool002T0oooo00D000000?ooo`3oool0oooo0000000n0?ooo`030000003oool0
oooo0?l0oooo@P3oool002T0oooo00@000000?ooo`3oool00000?`3oool00`000000oooo0?ooo`3o
0?oood80oooo000Y0?ooo`040000003oool0oooo000003l0oooo00<000000?ooo`3oool0o`3ooom2
0?ooo`00:@3oool010000000oooo0?ooo`00000o0?ooo`030000003oool0oooo0?l0oooo@P3oool0
02T0oooo0P0000000`3oool000000?ooo`0n0?ooo`030000003oool0oooo0?l0oooo@P3oool002T0
oooo00@000000?ooo`3oool00000?`3oool00`000000oooo0?ooo`3o0?oood80oooo000Y0?ooo`04
0000003oool0oooo000003l0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00:@3oool010000000
oooo0?ooo`00000o0?ooo`030000003oool0oooo0?l0oooo@P3oool002T0oooo00@000000?ooo`3o
ool00000?`3oool00`000000oooo0?ooo`3o0?oood80oooo000Y0?ooo`040000003oool0oooo0000
03l0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00:@3oool010000000oooo0?ooo`00000o0?oo
o`030000003oool0oooo0?l0oooo@P3oool002T0oooo00@000000?ooo`3oool00000?`3oool00`00
0000oooo0?ooo`3o0?oood80oooo000Y0?ooo`040000003oool0oooo000003l0oooo00<000000?oo
o`3oool0o`3ooom20?ooo`002`3oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@00000
0000M;l00`3oool00`3ookl0M000000000040000000307Boo`3oool0oooo00@0oooo00@000000?oo
o`3oool00000?`3oool00`000000oooo0?ooo`3o0?oood80oooo000;0?ooo`0609a8M02oool0oooo
0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`040?ooo`030;md000007@0_ooo0080oooo00<0
giad09cOo`3oool01@3oool010000000oooo0?ooo`00000o0?ooo`030000003oool0oooo0?l0oooo
@P3oool000X0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0;0?ooo`030?noM000
04P0W=oo00T0oooo00@000000?ooo`3oool00000?`3oool00`000000oooo0?ooo`3o0?oood80oooo
000:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0303oool00`3ogi`0B00004RL
g`080?ooo`@00000?`3oool00`000000oooo0?ooo`3o0?oood80oooo000:0?ooo`030=nLB018W=l0
oooo0080oooo00<0okmd001d_`3oool03P3oool00`2LB000B9cO0?ooo`060?ooo`040000003oool0
oooo00000400oooo00<000000?ooo`3oool0o`3ooom10?ooo`002P3oool00`3OW4P0B9cO0?ooo`02
0?ooo`030?noM000M;l0oooo00l0oooo00<0W4Qd0;ooo`3oool01@3oool010000000oooo0?ooo`00
00100?ooo`030000003oool0oooo0?l0oooo@@3oool000X0oooo00<0okmd04RLg`3oool00P3oool0
0`3OW4P0B9cO0?ooo`0:0?ooo`030=nLB01d_ol0oooo0080oooo00<0_g@007Boo`3oool01@3oool0
10000000oooo0?ooo`0000100?ooo`030000003oool0oooo0?l0oooo@@3oool000/0oooo00H0W4P0
07Boo`3oool0omnL04P0M02oool;0?ooo`070?noM00007@0_ooo0?ooo`3o_g@0001809cOo`060?oo
o`040000003oool0oooo00000400oooo00<000000?ooo`3oool0o`3ooom10?ooo`002`3oool01@3o
okl0M0000000000004P0W=oo00d0oooo00D0okmd000000000000001809cOo`070?ooo`030000003o
ool000000440oooo00<000000?ooo`3oool0o`3ooom10?ooo`00:@3oool00`000000oooo00000011
0?ooo`030000003oool0oooo0?l0oooo@@3oool002T0oooo00<000000?ooo`000000@@3oool00`00
0000oooo0?ooo`3o0?oood40oooo000Y0?ooo`030000003oool000000440oooo00<000000?ooo`3o
ool0o`3ooom10?ooo`00:@3oool00`000000oooo000000110?ooo`030000003oool0oooo0?l0oooo
@@3oool002T0oooo00<000000?ooo`000000@@3oool00`000000oooo0?ooo`3o0?oood40oooo000Y
0?ooo`030000003oool000000440oooo00<000000?ooo`3oool0o`3ooom10?ooo`00:@3oool30000
0440oooo00<000000?ooo`3oool0o`3ooom10?ooo`00:@3oool00`000000oooo000000110?ooo`03
0000003oool0oooo0?l0oooo@@3oool002T0oooo00<000000?ooo`000000@@3oool00`000000oooo
0?ooo`3o0?oood40oooo000Y0?ooo`030000003oool000000440oooo00<000000?ooo`3oool0o`3o
oom10?ooo`00:@3oool00`000000oooo000000110?ooo`030000003oool0oooo0?l0oooo@@3oool0
02T0oooo00<000000?ooo`000000@@3oool00`000000oooo0?ooo`3o0?oood40oooo000Y0?ooo`03
0000003oool000000440oooo00<000000?ooo`3oool0o`3ooom10?ooo`00:@3oool00`000000oooo
000000110?ooo`030000003oool0oooo0?l0oooo@@3oool002T0oooo00<000000?ooo`000000@@3o
ool00`000000oooo0?ooo`3o0?oood40oooo000Y0?ooo`030000003oool000000440oooo00<00000
0?ooo`3oool0o`3ooom10?ooo`00:@3oool00`000000oooo000000110?ooo`030000003oool0oooo
0?l0oooo@@3oool002T0oooo00<000000?ooo`000000@@3oool00`000000oooo0?ooo`3o0?oood40
oooo000Y0?ooo`<00000@@3oool00`000000oooo0?ooo`3o0?oood40oooo000Y0?ooo`030000003o
ool000000440oooo00<000000?ooo`3oool0o`3ooom10?ooo`00:@3oool00`000000oooo00000011
0?ooo`030000003oool0oooo0?l0oooo@@3oool002T0oooo00<000000?ooo`000000@@3oool00`00
0000oooo0?ooo`3o0?oood40oooo000Y0?ooo`030000003oool000000440oooo00<000000?ooo`3o
ool0o`3ooom10?ooo`00:@3oool00`000000oooo000000120?ooo`030000003oool0oooo0?l0oooo
@03oool002T0oooo00<000000?ooo`000000@P3oool00`000000oooo0?ooo`3o0?oood00oooo000Y
0?ooo`030000003oool000000480oooo00<000000?ooo`3oool0o`3ooom00?ooo`00:@3oool00`00
0000oooo000000120?ooo`030000003oool0oooo0?l0oooo@03oool002T0oooo00<000000?ooo`00
0000@P3oool00`000000oooo0?ooo`3o0?oood00oooo000Y0?ooo`030000003oool000000480oooo
00<000000?ooo`3oool0o`3ooom00?ooo`00:@3oool00`000000oooo000000120?ooo`030000003o
ool0oooo0?l0oooo@03oool002T0oooo0`0000120?ooo`030000003oool0oooo0?l0oooo@03oool0
02T0oooo00<000000?ooo`000000@P3oool00`000000oooo0?ooo`3o0?oood00oooo000Y0?ooo`03
0000003oool000000480oooo00<000000?ooo`3oool0o`3ooom00?ooo`00:@3oool00`000000oooo
000000120?ooo`030000003oool0oooo0?l0oooo@03oool002T0oooo00<000000?ooo`000000@P3o
ool00`000000oooo0?ooo`3o0?oood00oooo000Y0?ooo`030000003oool000000480oooo00<00000
0?ooo`3oool0o`3ooom00?ooo`00:@3oool00`000000oooo000000120?ooo`030000003oool0oooo
0?l0oooo@03oool002T0oooo00<000000?ooo`000000@P3oool00`000000oooo0?ooo`3o0?oood00
oooo000Y0?ooo`030000003oool000000480oooo00<000000?ooo`3oool0o`3ooom00?ooo`002`3o
ool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l01P3oool01@3ogi`0B000
000000000000M;oo00H0oooo00<000000?ooo`000000@P3oool00`000000oooo0?ooo`3o0?oood00
oooo000;0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`080?oo
o`030;md001d_ol0oooo00H0oooo00<000000?ooo`000000@P3oool00`000000oooo0?ooo`3o0?oo
od00oooo000:0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool03P3oool00`2oM000
M;oo0?ooo`060?ooo`030000003oool000000480oooo00<000000?ooo`3oool0o`3ooom00?ooo`00
2P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0gia8000000000000
0`0000000`1d_ol0oooo0?ooo`040?ooo`<00000@P3oool00`000000oooo0?ooo`3o0?oood00oooo
000:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool01P3o_g@0001d0;oo
o`3oool0_g@007Boo`L0oooo00<000000?ooo`000000@P3oool00`000000oooo0?ooo`3o0?oood00
oooo000:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02`3oool01@3OW4P007Bo
0?ooo`2oM000M;oo00L0oooo00<000000?ooo`000000@P3oool00`000000oooo0?ooo`3o0?oood00
oooo000:0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool0303oool0102LB000B9cO
0;md001d_ol70?ooo`030000003oool000000480oooo00<000000?ooo`3oool0o`3ooom00?ooo`00
2`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`d0oooo00@0omnL04P0B018B000M;oo1`3oool0
0`000000oooo000000120?ooo`030000003oool0oooo0?l0oooo@03oool000/0oooo00D0oono07@0
00000000001809cOo`0?0?ooo`030?noM0000000M;oo00L0oooo00<000000?ooo`000000@P3oool0
0`000000oooo0?ooo`3o0?oood00oooo000Y0?ooo`030000003oool000000480oooo00<000000?oo
o`3oool0o`3ooom00?ooo`00:@3oool00`000000oooo000000120?ooo`030000003oool0oooo0?l0
oooo@03oool002T0oooo0P0000130?ooo`030000003oool0oooo0?l0oooo@03oool002T0oooo0P00
00130?ooo`030000003oool0oooo0?l0oooo@03oool002T0oooo0P0000130?ooo`030000003oool0
oooo0?l0oooo@03oool002T0oooo0P0000130?ooo`030000003oool0oooo0?l0oooo@03oool002T0
oooo0P0000130?ooo`030000003oool0oooo0?l0oooo@03oool002T0oooo0P0000130?ooo`030000
003oool0oooo0?l0oooo@03oool002T0oooo0P0000130?ooo`030000003oool0oooo0?l0oooo@03o
ool002T0oooo0P0000130?ooo`030000003oool0oooo0?l0oooo@03oool002T0oooo0P0000130?oo
o`030000003oool0oooo0?l0oooo@03oool002T0oooo0P0000130?ooo`030000003oool0oooo0?l0
oooo@03oool002T0oooo0P0000130?ooo`030000003oool0oooo0?l0oooo@03oool002T0oooo0P00
00130?ooo`030000003oool0oooo0?l0oooo@03oool002T0oooo0P0000130?ooo`030000003oool0
oooo0?l0oooo@03oool002T0oooo0P0000130?ooo`030000003oool0oooo0?l0oooo@03oool002T0
oooo0P0000130?ooo`030000003oool0oooo0?l0oooo@03oool002T0oooo0P0000130?ooo`030000
003oool0oooo0?l0oooo@03oool002T0oooo0P0000130?ooo`030000003oool0oooo0?l0oooo@03o
ool002T0oooo0P0000130?ooo`030000003oool0oooo0?l0oooo@03oool002T0oooo0P0000140?oo
o`030000003oool0oooo0?l0oooo?`3oool002T0oooo0P0000140?ooo`030000003oool0oooo0?l0
oooo?`3oool002T0oooo0P0000140?ooo`030000003oool0oooo0?l0oooo?`3oool002T0oooo0P00
00140?ooo`030000003oool0oooo0?l0oooo?`3oool002T0oooo0P0000140?ooo`030000003oool0
oooo0?l0oooo?`3oool002T0oooo0P0000140?ooo`030000003oool0oooo0?l0oooo?`3oool002T0
oooo0P0000140?ooo`030000003oool0oooo0?l0oooo?`3oool002T0oooo0P0000140?ooo`030000
003oool0oooo0?l0oooo?`3oool002T0oooo0P0000140?ooo`030000003oool0oooo0?l0oooo?`3o
ool002T0oooo0P0000140?ooo`030000003oool0oooo0?l0oooo?`3oool002T0oooo0P0000140?oo
o`030000003oool0oooo0?l0oooo?`3oool002T0oooo0P0000140?ooo`030000003oool0oooo0?l0
oooo?`3oool002T0oooo0P0000140?ooo`030000003oool0oooo0?l0oooo?`3oool002T0oooo0P00
00140?ooo`030000003oool0oooo0?l0oooo?`3oool002T0oooo0P0000140?ooo`030000003oool0
oooo0?l0oooo?`3oool002T0oooo0P0000140?ooo`030000003oool0oooo0?l0oooo?`3oool002T0
oooo0P0000140?ooo`030000003oool0oooo0?l0oooo?`3oool002T0oooo0P0000140?ooo`030000
003oool0oooo0?l0oooo?`3oool002T0oooo0P0000140?ooo`030000003oool0oooo0?l0oooo?`3o
ool000/0oooo00D0okmd000000000000000007Boo`050?ooo`030;md0000000007Bo00H0oooo00D0
_g@0000000000000001d0;ooo`060?ooo`800000A03oool00`000000oooo0?ooo`3o0?ooocl0oooo
000;0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`050?ooo`06
0=nLB000M;l0oooo0?ooo`3o_g@007Bo1P3oool2000004@0oooo00<000000?ooo`3oool0o`3ooolo
0?ooo`002P3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0oono07@0
001d_ol00P3oool00`3ookl0M4RL0?ooo`050?ooo`800000A03oool00`000000oooo0?ooo`3o0?oo
ocl0oooo000:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool01`3o_g@0
04Q807@0M02oool0oooo0=nLB000M;l01P3oool3000004<0oooo00<000000?ooo`3oool0o`3ooolo
0?ooo`002P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0omnL04Q8
W03o_g@00P0000000`00B9`0oooo0?ooo`050?ooo`800000A03oool00`000000oooo0?ooo`3o0?oo
ocl0oooo000:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool00`3ookl0
M01d0;ooo`0:0?ooo`800000A03oool00`000000oooo0?ooo`3o0?ooocl0oooo000:0?ooo`030?no
M018W=l0oooo0080oooo00<0gia804RLg`3oool02`3oool00`2oM000B9cO0?ooo`090?ooo`800000
A03oool00`000000oooo0?ooo`3o0?ooocl0oooo000;0?ooo`0609a8001d_ol0oooo0?oOW01807@0
_ooo303oool00`3ookl0M000001d_`090?ooo`800000A03oool00`000000oooo0?ooo`3o0?ooocl0
oooo000;0?ooo`050?oo_`1d000000000000B02Lgol03`3oool0102oM000000000000000B9`60?oo
o`800000A03oool00`000000oooo0?ooo`3o0?ooocl0oooo000Y0?ooo`800000A03oool00`000000
oooo0?ooo`3o0?ooocl0oooo000Y0?ooo`800000A03oool00`000000oooo0?ooo`3o0?ooocl0oooo
000Y0?ooo`800000A03oool00`000000oooo0?ooo`3o0?ooocl0oooo000Y0?ooo`800000A03oool0
0`000000oooo0?ooo`3o0?ooocl0oooo000Y0?ooo`800000A03oool00`000000oooo0?ooo`3o0?oo
ocl0oooo000Y0?ooo`800000A03oool00`000000oooo0?ooo`3o0?ooocl0oooo000Y0?ooo`800000
A03oool00`000000oooo0?ooo`3o0?ooocl0oooo000Y0?ooo`800000A03oool00`000000oooo0?oo
o`3o0?ooocl0oooo000Y0?ooo`800000A03oool00`000000oooo0?ooo`3o0?ooocl0oooo000Y0?oo
o`800000A03oool00`000000oooo0?ooo`3o0?ooocl0oooo000Y0?ooo`800000A03oool00`000000
oooo0?ooo`3o0?ooocl0oooo000Y0?ooo`800000A03oool00`000000oooo0?ooo`3o0?ooocl0oooo
000Y0?ooo`800000A03oool00`000000oooo0?ooo`3o0?ooocl0oooo000Y0?ooo`800000A03oool0
0`000000oooo0?ooo`3o0?ooocl0oooo000Y0?ooo`800000A03oool00`000000oooo0?ooo`3o0?oo
ocl0oooo000Y0?ooo`800000A03oool00`000000oooo0?ooo`3o0?ooocl0oooo000Y0?ooo`800000
A03oool00`000000oooo0?ooo`3o0?ooocl0oooo000Y0?ooo`800000A03oool00`000000oooo0?oo
o`3o0?ooocl0oooo000Y0?ooo`800000A03oool00`000000oooo0?ooo`3o0?ooocl0oooo000Y0?oo
o`800000A03oool00`000000oooo0?ooo`3o0?ooocl0oooo000Y0?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool0o`3ooolo0?ooo`00:@3oool00`000000oooo0?ooo`130?ooo`030000
003oool0oooo0?l0oooo?`3oool002T0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`3o0?ooocl0oooo000Y0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0o`3ooolo
0?ooo`00:@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0oooo?`3oool002T0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`3o0?ooocl0oooo000Y0?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`00:@3oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo0?l0oooo?`3oool002T0oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`3o0?ooocl0oooo000Y0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool0o`3ooolo0?ooo`00:@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0
oooo?`3oool002T0oooo0P0000140?ooo`030000003oool0oooo0?l0oooo?`3oool002T0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`3o0?ooocl0oooo000Y0?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`00:@3oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo0?l0oooo?`3oool002T0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`3o0?ooocl0oooo000Y0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
o`3ooolo0?ooo`00:@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0oooo?`3o
ool002T0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`3o0?ooocl0oooo000;0?oo
o`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`050?ooo`050;md00000000
000000000000M;l01`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0oooo?`3o
ool000/0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00@0oooo
00<0okmd001d_`3oool00P3oool00`2oM4P0W=oo0?ooo`050?ooo`030000003oool0oooo04<0oooo
00<000000?ooo`3oool0o`3ooolo0?ooo`002P3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018
W=l0oooo00X0oooo00<0gia804RLg`3oool00P3oool00`2oM000M;oo0?ooo`050?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`002P3oool00`3OW4P0B9cO0?ooo`02
0?ooo`030?noM000M;l0oooo00X0oooo00<0okmd0018W03oool00P3oool00`2LB4P0W=oo0?ooo`05
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`002P3oool00`3O
W4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00/0oooo00D0gia8000000000000000004RLg`07
0?ooo`<00000@`3oool00`000000oooo0?ooo`3o0?ooocl0oooo000:0?ooo`030=nLB018W=l0oooo
0080oooo00<0okmd001d_`3oool02P3oool00`3ookl0M4RL0?ooo`020?ooo`0309a8M02oool0oooo
00D0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`3o0?ooocl0oooo000:0?ooo`03
0?noM018W=l0oooo0080oooo00<0gia804RLg`3oool02P3oool00`3o_g@0B9cO0?ooo`020?ooo`03
0;md001d_ol0oooo00D0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`3o0?ooocl0
oooo000;0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2`3oool01`3ogi`0B01d0;ooo`3oool0
omnL04P0M02oool01P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0oooo?`3o
ool000/0oooo00D0oono07@000000000001809cOo`0=0?ooo`050?noM000000000000000B02Lgol0
1`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0oooo?`3oool002T0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`3o0?ooocl0oooo000Y0?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`00:@3oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo0?l0oooo?`3oool002T0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`3o0?ooocl0oooo000Y0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
o`3ooolo0?ooo`00:@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0oooo?`3o
ool002T0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?oooch0oooo000Y0?oo
o`800000A@3oool00`000000oooo0?ooo`3o0?oooch0oooo000Y0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool0o`3oooln0?ooo`00:@3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo0?l0oooo?P3oool002T0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?oo
o`3o0?oooch0oooo000Y0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0o`3oooln
0?ooo`00:@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo?P3oool002T0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?oooch0oooo000Y0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0o`3oooln0?ooo`00:@3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo0?l0oooo?P3oool002T0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`3o0?oooch0oooo000Y0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0o`3oooln0?ooo`00:@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0
oooo?P3oool002T0oooo0P0000150?ooo`030000003oool0oooo0?l0oooo?P3oool002T0oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?oooch0oooo000Y0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool0o`3oooln0?ooo`00:@3oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo0?l0oooo?P3oool002T0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`3o0?oooch0oooo000Y0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
o`3oooln0?ooo`00:@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo?P3o
ool002T0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?oooch0oooo000Y0?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool0o`3oooln0?ooo`00:@3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo?P3oool002T0oooo00<000000?ooo`3oool0
A03oool00`000000oooo0?ooo`3o0?oooch0oooo000Y0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool0o`3oooln0?ooo`00:@3oool2000004D0oooo00<000000?ooo`3oool0o`3oooln
0?ooo`00:@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo?P3oool002T0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?oooch0oooo000Y0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0o`3oooln0?ooo`00:@3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo0?l0oooo?P3oool002T0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`3o0?oooch0oooo000Y0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0o`3oooln0?ooo`00:@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0
oooo?P3oool001`0oooo00<0okmd0000000000000`0000000`00M;l0oooo0?ooo`040?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0o`3oooln0?ooo`007`3oool00`2LB4P0W=oo0?oo
o`070?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0o`3oooln0?ooo`007`3oool0
0`2LB4P0W=oo0?ooo`070?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0o`3oooln
0?ooo`007`3oool00`2LB4P0W=oo0?ooo`070?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0o`3oooln0?ooo`007`3oool00`2LB4P0W=oo0?ooo`070?ooo`<00000A03oool00`000000
oooo0?ooo`3o0?oooch0oooo000O0?ooo`0309a8B02Lgol0oooo0?l0ooooS`3oool001l0oooo00<0
W4Q809cOo`3oool0o`3ooon?0?ooo`00703oool01@3OW4P000000018W02LB4P0W=oo0?l0ooooT03o
ool001h0oooo00<0gia80000B02Lgol0o`3ooon@0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-1.11314, -0.0763042, \
0.0404313, 0.00623041}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0 0.618034 [
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.01131 .12361 -18 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -18 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -18 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .12361 m
.03006 .12361 L
s
[(0.2)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.4)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.6)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.8)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .61803 m
.02499 .48283 L
.02605 .38569 L
.02729 .29761 L
.02846 .23292 L
.03053 .15062 L
.0317 .11777 L
.03279 .09384 L
.03388 .07457 L
.03506 .05824 L
.03635 .04441 L
.03756 .03444 L
.03891 .02592 L
.0402 .01978 L
.04136 .01552 L
.04262 .0119 L
.04396 .00898 L
.04523 .00688 L
.04636 .00542 L
.04759 .00419 L
.04894 .00316 L
.05036 .00234 L
.05157 .00182 L
.0529 .00137 L
.05415 .00106 L
.05528 .00083 L
.05659 .00063 L
.05784 .00049 L
.05898 .00038 L
.06004 .00031 L
.06121 .00024 L
.06244 .00019 L
.06371 .00014 L
.06504 .00011 L
.06617 8e-005 L
.06742 7e-005 L
.06876 5e-005 L
.07019 4e-005 L
.07155 3e-005 L
.07277 2e-005 L
.07402 2e-005 L
.07517 1e-005 L
.07643 1e-005 L
.07776 1e-005 L
.07892 1e-005 L
.08001 0 L
.0812 0 L
.08247 0 L
.08394 0 L
.08531 0 L
Mistroke
.08681 0 L
.0884 0 L
.08992 0 L
.09135 0 L
.09264 0 L
.09402 0 L
.0953 0 L
.0967 0 L
.09816 0 L
.09953 0 L
.1008 0 L
.10197 0 L
.10331 0 L
.10458 0 L
.10572 0 L
.10696 0 L
.10918 0 L
.11048 0 L
.11183 0 L
.11426 0 L
Mfstroke
.11426 0 m
.11456 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00K`3oool00`3ookl0M000000000040000000307Boo`3oool0oooo04<0oooo00D0omnL04P0
00000000000007Boo`150?ooo`050;md0000000000000000M02oool0A03oool01@2oM00000000000
0000000007Bo0400oooo00<0okmd0000000000000`0000001@00M;l0oooo0?ooo`3oool0okmd00<0
000000<0M;oo0?ooo`3oool02`3oool00700oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo
0?ooo`160?ooo`030;md001d_ol0oooo04@0oooo00H0gia8001d_`3oool0oooo0?noM000M;m30?oo
o`030?noM000M;l0oooo0080oooo00<0_gA809cOo`3oool0@@3oool00`2LB4P0W=oo0?ooo`040?oo
o`0609a8M02oool0oooo0?oo_`1d07@0_ooo303oool00740oooo00<0okmd0000B02Lgol0BP3oool0
0`2oM000M;oo0?ooo`130?ooo`030?oo_`1d0000M;oo0080oooo00<0oono07A8W03oool0@P3oool0
0`3OW4P0B9cO0?ooo`020?ooo`030;md001d_ol0oooo0440oooo00<0W4Q809cOo`3oool00`3oool0
0`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo00/0oooo001b0?ooo`030?oOW0180000B9cO
04D0oooo00<0gia80000000000000`0000000`1d_ol0oooo0?ooo`110?ooo`070?noM000B4P0M01d
0;ooo`3oool0gia8001d_`130?ooo`030?noM000B9`0oooo0080oooo00<0W4Q809cOo`3oool0@@3o
ool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02`3o
ool007@0oooo00<0W4P004RLg`3oool0@`3oool01P3o_g@0001d0;ooo`3oool0_g@007Bood@0oooo
00<0omnL04Q8W03o_g@00P0000000`00B9`0oooo0?ooo`130?ooo`050=nLB0000000000000000018
W=l0@`3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3o
ool02`3oool007D0oooo00<0W4Qd0;ooo`3oool0@`3oool01@3OW4P007Bo0?ooo`2oM000M;oo04@0
oooo00<0oono07@0M02oool0A`3oool00`3ookl0M4RL0?ooo`020?ooo`0309a8M02oool0oooo0440
oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00/0
oooo001`0?ooo`030=nLB01d_ol0oooo0080oooo00<0_g@007Boo`3oool0A03oool0102LB000B9cO
0;md001d_om50?ooo`030;md0018W=l0oooo04H0oooo00<0okmd04RLg`3oool00P3oool00`2oM000
M;oo0?ooo`110?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0
B9cO0?ooo`0;0?ooo`00L03oool01`3o_g@0001d0;ooo`3oool0okmd0000B02Lgol0A@3oool0103o
gi`0B01804Q8001d_om50?ooo`030?oo_`1d000007Bo04H0oooo00L0omnL04P0M02oool0oooo0?oO
W01807@0_ooo03l0oooo00D0gia800000000B9`0W4Q809cOo`050?ooo`0609a8001d_ol0oooo0?oO
W01807@0_ooo303oool00740oooo00D0okmd000000000000001809cOo`170?ooo`030?noM0000000
M;oo04L0oooo00@0_g@000000000000004RLA03oool01@3o_g@000000000000004P0W=oo0480oooo
00<0gia80000B02Lgol01@3oool01@3ookl0M0000000000004P0W=oo00d0oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo000P0?ooool00000Q`00000:0?ooo`00:@3oool00`000000
oooo0?ooo`070?ooo`8000001P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140
oooo000Y0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo0140oooo000Y0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0o`3ooomm0?ooo`00:@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0?l0ooooOP3oool002T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oo
ogh0oooo000Y0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooomn0?ooo`00
:@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooO`3oool002T0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooogl0oooo000Y0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00:@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0?l0ooooO`3oool002T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`3o0?ooogl0oooo000Y0?ooo`8000000`3oool00`000000oooo0?ooo`3o0?oooh00oooo
000Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooon00?ooo`00:@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooP03oool002T0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`3o0?oooh00oooo000Y0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0o`3ooon00?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0?l0ooooP03oool002T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3o0?oooh00oooo000Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooon0
0?ooo`00:@3oool01@000000oooo0?ooo`3oool000000?l0ooooP`3oool002T0oooo00D000000?oo
o`3oool0oooo0000003o0?oooh<0oooo000Y0?ooo`050000003oool0oooo0?ooo`000000o`3ooon3
0?ooo`00:@3oool01@000000oooo0?ooo`3oool000000?l0ooooP`3oool002T0oooo0P0000020?oo
o`030000003oool0oooo0?l0ooooP@3oool002T0oooo00D000000?ooo`3oool0oooo0000003o0?oo
oh<0oooo000Y0?ooo`050000003oool0oooo0?ooo`000000o`3ooon30?ooo`00:@3oool01@000000
oooo0?ooo`3oool000000?l0ooooP`3oool002T0oooo00D000000?ooo`3oool0oooo0000003o0?oo
oh<0oooo000Y0?ooo`050000003oool0oooo0?ooo`000000o`3ooon30?ooo`00:@3oool01@000000
oooo0?ooo`3oool000000?l0ooooP`3oool002T0oooo00D000000?ooo`3oool0oooo0000003o0?oo
oh<0oooo000Y0?ooo`050000003oool0oooo0?ooo`000000o`3ooon30?ooo`00:@3oool010000000
oooo0?ooo`00003o0?oooh@0oooo000Y0?ooo`040000003oool0oooo00000?l0ooooQ03oool002T0
oooo00@000000?ooo`3oool00000o`3ooon40?ooo`00:@3oool2000000030?ooo`000000oooo0?l0
ooooP`3oool002T0oooo00@000000?ooo`3oool00000o`3ooon40?ooo`00:@3oool010000000oooo
0?ooo`00003o0?oooh@0oooo000Y0?ooo`040000003oool0oooo00000?l0ooooQ03oool002T0oooo
00@000000?ooo`3oool00000o`3ooon40?ooo`00:@3oool010000000oooo0?ooo`00003o0?oooh@0
oooo000Y0?ooo`040000003oool0oooo00000?l0ooooQ03oool002T0oooo00@000000?ooo`3oool0
0000o`3ooon40?ooo`00:@3oool010000000oooo0?ooo`00003o0?oooh@0oooo000;0?ooo`050?no
M000000000000000001d_ol01@3oool00`2oM0000000001d_`030?ooo`030?oo_`1d0000000000@0
000000<0M;oo0?ooo`3oool0103oool010000000oooo0?ooo`00003o0?oooh@0oooo000;0?ooo`06
09a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`040?ooo`030;md000007@0
_ooo0080oooo00<0giad09cOo`3oool01@3oool010000000oooo0?ooo`00003o0?oooh@0oooo000:
0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool02`3oool00`3o_g@0001809cOo`09
0?ooo`040000003oool0oooo00000?l0ooooQ03oool000X0oooo00<0gia804RLg`3oool00P3oool0
0`3o_g@007Bo0?ooo`0<0?ooo`030?oOW0180000B9cO00P0oooo1000003o0?oooh@0oooo000:0?oo
o`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool03P3oool00`2LB000B9cO0?ooo`060?oo
o`040000003oool0oooo00000?l0ooooQ03oool000X0oooo00<0gia804RLg`3oool00P3oool00`3o
_g@007Bo0?ooo`0?0?ooo`0309a8M02oool0oooo00D0oooo00@000000?ooo`3oool00000o`3ooon4
0?ooo`002P3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0gia807Bo
o`3oool00P3oool00`2oM000M;oo0?ooo`050?ooo`040000003oool0oooo00000?l0ooooQ03oool0
00/0oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`070?noM00007@0_ooo0?ooo`3o_g@0
001809cOo`060?ooo`040000003oool0oooo00000?l0ooooQ03oool000/0oooo00D0oono07@00000
0000001809cOo`0=0?ooo`050?noM000000000000000B02Lgol01`3oool00`000000oooo0000003o
0?ooohD0oooo000Y0?ooo`030000003oool000000?l0ooooQ@3oool002T0oooo00<000000?ooo`00
0000o`3ooon50?ooo`00:@3oool00`000000oooo0000003o0?ooohD0oooo000Y0?ooo`030000003o
ool000000?l0ooooQ@3oool002T0oooo00<000000?ooo`000000o`3ooon50?ooo`00:@3oool00`00
0000oooo0000003o0?ooohD0oooo000Y0?ooo`<00000o`3ooon50?ooo`00:@3oool00`000000oooo
0000003o0?ooohD0oooo000Y0?ooo`030000003oool000000?l0ooooQ@3oool002T0oooo00<00000
0?ooo`000000o`3ooon50?ooo`00:@3oool00`000000oooo0000003o0?ooohD0oooo000Y0?ooo`03
0000003oool000000?l0ooooQ@3oool002T0oooo00<000000?ooo`000000o`3ooon50?ooo`00:@3o
ool00`000000oooo0000003o0?ooohD0oooo000Y0?ooo`030000003oool000000?l0ooooQ@3oool0
02T0oooo00<000000?ooo`000000o`3ooon50?ooo`00:@3oool00`000000oooo0000003o0?ooohD0
oooo000Y0?ooo`030000003oool000000?l0ooooQ@3oool002T0oooo0`00003o0?ooohD0oooo000Y
0?ooo`030000003oool000000?l0ooooQ@3oool002T0oooo00<000000?ooo`000000o`3ooon50?oo
o`00:@3oool00`000000oooo0000003o0?ooohD0oooo000Y0?ooo`030000003oool000000?l0oooo
Q@3oool002T0oooo00<000000?ooo`000000o`3ooon50?ooo`00:@3oool00`000000oooo0000003o
0?ooohD0oooo000Y0?ooo`030000003oool000000?l0ooooQ@3oool002T0oooo00<000000?ooo`00
0000o`3ooon50?ooo`00:@3oool00`000000oooo0000003o0?ooohD0oooo000Y0?ooo`030000003o
ool000000?l0ooooQ@3oool002T0oooo00<000000?ooo`000000o`3ooon50?ooo`00:@3oool30000
0?l0ooooQ@3oool002T0oooo00<000000?ooo`000000o`3ooon50?ooo`00:@3oool00`000000oooo
0000003o0?ooohD0oooo000Y0?ooo`030000003oool000000?l0ooooQ@3oool002T0oooo00<00000
0?ooo`000000o`3ooon50?ooo`00:@3oool00`000000oooo0000003o0?ooohD0oooo000Y0?ooo`03
0000003oool000000?l0ooooQ@3oool002T0oooo00<000000?ooo`000000o`3ooon50?ooo`00:@3o
ool00`000000oooo0000003o0?ooohD0oooo000;0?ooo`050?noM000000000000000001d_ol01@3o
ool00`2oM0000000001d_`060?ooo`050?oOW018000000000000001d_ol01P3oool00`000000oooo
0000003o0?ooohD0oooo000;0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM000
0000001d_`080?ooo`030;md001d_ol0oooo00H0oooo00<000000?ooo`000000o`3ooon50?ooo`00
2P3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo00h0oooo00<0_g@007Boo`3oool0
1P3oool00`000000oooo0000003o0?ooohD0oooo000:0?ooo`030=nLB018W=l0oooo0080oooo00<0
okmd001d_`3oool02P3oool00`3OW4P00000000000030000000307Boo`3oool0oooo00@0oooo0`00
003o0?ooohD0oooo000:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool0
1P3o_g@0001d0;ooo`3oool0_g@007Boo`L0oooo00<000000?ooo`000000o`3ooon50?ooo`002P3o
ool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00/0oooo00D0gia8001d_`3oool0_g@0
07Boo`070?ooo`030000003oool000000?l0ooooQ@3oool000X0oooo00<0okmd04RLg`3oool00P3o
ool00`3OW4P0B9cO0?ooo`0<0?ooo`0409a80018W=l0_g@007Boo`L0oooo00<000000?ooo`000000
o`3ooon50?ooo`002`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`d0oooo00@0omnL04P0B018
B000M;oo1`3oool00`000000oooo0000003o0?ooohD0oooo000;0?ooo`050?oo_`1d000000000000
B02Lgol03`3oool00`3o_g@0000007Boo`070?ooo`030000003oool000000?l0ooooQ@3oool002T0
oooo00<000000?ooo`000000o`3ooon50?ooo`00:@3oool00`000000oooo0000003o0?ooohD0oooo
000Y0?ooo`800000o`3ooon60?ooo`00:@3oool200000?l0ooooQP3oool002T0oooo0P00003o0?oo
ohH0oooo000Y0?ooo`800000o`3ooon60?ooo`00:@3oool200000?l0ooooQP3oool002T0oooo0P00
003o0?ooohH0oooo000Y0?ooo`800000o`3ooon60?ooo`00:@3oool200000?l0ooooQP3oool002T0
oooo0P00003o0?ooohH0oooo000Y0?ooo`800000o`3ooon60?ooo`00:@3oool200000?l0ooooQP3o
ool002T0oooo0P00003o0?ooohH0oooo000Y0?ooo`800000o`3ooon60?ooo`00:@3oool200000?l0
ooooQP3oool002T0oooo0P00003o0?ooohH0oooo000Y0?ooo`800000o`3ooon60?ooo`00:@3oool2
00000?l0ooooQP3oool002T0oooo0P00003o0?ooohH0oooo000Y0?ooo`800000o`3ooon60?ooo`00
:@3oool200000?l0ooooQP3oool002T0oooo0P00003o0?ooohH0oooo000Y0?ooo`800000o`3ooon6
0?ooo`00:@3oool200000?l0ooooQP3oool002T0oooo0P00003o0?ooohH0oooo000Y0?ooo`800000
o`3ooon60?ooo`00:@3oool200000?l0ooooQP3oool002T0oooo0P00003o0?ooohH0oooo000Y0?oo
o`800000o`3ooon60?ooo`00:@3oool200000?l0ooooQP3oool002T0oooo0P00003o0?ooohH0oooo
000Y0?ooo`800000o`3ooon60?ooo`00:@3oool200000?l0ooooQP3oool002T0oooo0P00003o0?oo
ohH0oooo000Y0?ooo`800000o`3ooon60?ooo`00:@3oool200000?l0ooooQP3oool002T0oooo0P00
003o0?ooohH0oooo000Y0?ooo`800000o`3ooon60?ooo`002`3oool01@3o_g@00000000000000000
M;oo00D0oooo00<0_g@000000000M;l01P3oool01@2oM00000000000000007@0_ooo00H0oooo0P00
003o0?ooohH0oooo000;0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000
001d_`050?ooo`060=nLB000M;l0oooo0?ooo`3o_g@007Bo1P3oool200000?l0ooooQP3oool000X0
oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030?oo_`1d0000M;oo0080
oooo00<0oono07A8W03oool01@3oool200000?l0ooooQP3oool000X0oooo00<0gia804RLg`3oool0
0P3oool00`3o_g@007Bo0?ooo`0:0?ooo`070?noM000B4P0M01d0;ooo`3oool0gia8001d_`060?oo
o`<00000o`3ooon50?ooo`002P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0
oooo00<0omnL04Q8W03o_g@00P0000000`00B9`0oooo0?ooo`050?ooo`800000o`3ooon60?ooo`00
2P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0oono07@0M02oool0
2P3oool200000?l0ooooQP3oool000X0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?oo
o`0;0?ooo`030;md0018W=l0oooo00T0oooo0P00003o0?ooohH0oooo000;0?ooo`0609a8001d_ol0
oooo0?oOW01807@0_ooo303oool00`3ookl0M000001d_`090?ooo`800000o`3ooon60?ooo`002`3o
ool01@3ookl0M0000000000004P0W=oo00l0oooo00@0_g@000000000000004RL1P3oool200000?l0
ooooQP3oool002T0oooo0P00003o0?ooohH0oooo000Y0?ooo`800000o`3ooon60?ooo`00:@3oool2
00000?l0ooooQP3oool002T0oooo0P00003o0?ooohH0oooo000Y0?ooo`800000o`3ooon60?ooo`00
:@3oool200000?l0ooooQP3oool002T0oooo0P00003o0?ooohH0oooo000Y0?ooo`800000o`3ooon6
0?ooo`00:@3oool200000?l0ooooQP3oool002T0oooo0P00003o0?ooohH0oooo000Y0?ooo`800000
o`3ooon60?ooo`00:@3oool200000?l0ooooQP3oool002T0oooo0P00003o0?ooohH0oooo000Y0?oo
o`800000o`3ooon60?ooo`00:@3oool200000?l0ooooQP3oool002T0oooo0P00003o0?ooohH0oooo
000Y0?ooo`800000o`3ooon60?ooo`00:@3oool200000?l0ooooQP3oool002T0oooo0P00003o0?oo
ohH0oooo000Y0?ooo`800000o`3ooon60?ooo`00:@3oool00`000000oooo0?ooo`3o0?ooohD0oooo
000Y0?ooo`030000003oool0oooo0?l0ooooQ@3oool002T0oooo00<000000?ooo`3oool0o`3ooon5
0?ooo`00:@3oool00`000000oooo0?ooo`3o0?ooohD0oooo000Y0?ooo`030000003oool0oooo0?l0
ooooQ@3oool002T0oooo00<000000?ooo`3oool0o`3ooon50?ooo`00:@3oool00`000000oooo0?oo
o`3o0?ooohD0oooo000Y0?ooo`030000003oool0oooo0?l0ooooQ@3oool002T0oooo00<000000?oo
o`3oool0o`3ooon50?ooo`00:@3oool00`000000oooo0?ooo`3o0?ooohD0oooo000Y0?ooo`030000
003oool0oooo0?l0ooooQ@3oool002T0oooo0P00003o0?ooohH0oooo000Y0?ooo`030000003oool0
oooo0?l0ooooQ@3oool002T0oooo00<000000?ooo`3oool0o`3ooon50?ooo`00:@3oool00`000000
oooo0?ooo`3o0?ooohD0oooo000Y0?ooo`030000003oool0oooo0?l0ooooQ@3oool002T0oooo00<0
00000?ooo`3oool0o`3ooon50?ooo`00:@3oool00`000000oooo0?ooo`3o0?ooohD0oooo000Y0?oo
o`030000003oool0oooo0?l0ooooQ@3oool000/0oooo00D0okmd000000000000000007Boo`050?oo
o`030;md0000000007Bo00D0oooo00D0_g@00000000000000000001d_`070?ooo`030000003oool0
oooo0?l0ooooQ@3oool000/0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000
000007Bo00@0oooo00<0okmd001d_`3oool00P3oool00`2oM4P0W=oo0?ooo`050?ooo`030000003o
ool0oooo0?l0ooooQ@3oool000X0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0:
0?ooo`030=nLB018W=l0oooo0080oooo00<0_g@007Boo`3oool01@3oool00`000000oooo0?ooo`3o
0?ooohD0oooo000:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool00`3o
_g@004RL0?ooo`020?ooo`0309a8B02Lgol0oooo00D0oooo00<000000?ooo`3oool0o`3ooon50?oo
o`002P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00/0oooo00D0gia800000000
0000000004RLg`070?ooo`<00000o`3ooon50?ooo`002P3oool00`3OW4P0B9cO0?ooo`020?ooo`03
0?noM000M;l0oooo00X0oooo00<0oono07A8W03oool00P3oool00`2LB7@0_ooo0?ooo`050?ooo`03
0000003oool0oooo0?l0ooooQ@3oool000X0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO
0?ooo`0:0?ooo`030?noM018W=l0oooo0080oooo00<0_g@007Boo`3oool01@3oool00`000000oooo
0?ooo`3o0?ooohD0oooo000;0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2`3oool01`3ogi`0
B01d0;ooo`3oool0omnL04P0M02oool01P3oool00`000000oooo0?ooo`3o0?ooohD0oooo000;0?oo
o`050?oo_`1d000000000000B02Lgol03@3oool01@3o_g@000000000000004P0W=oo00L0oooo00<0
00000?ooo`3oool0o`3ooon50?ooo`00:@3oool00`000000oooo0?ooo`3o0?ooohD0oooo000Y0?oo
o`030000003oool0oooo0?l0ooooQ@3oool002T0oooo00<000000?ooo`3oool0o`3ooon50?ooo`00
:@3oool00`000000oooo0?ooo`3o0?ooohD0oooo000Y0?ooo`030000003oool0oooo0?l0ooooQ@3o
ool002T0oooo00<000000?ooo`3oool0o`3ooon50?ooo`00:@3oool00`000000oooo0?ooo`3o0?oo
ohD0oooo000Y0?ooo`800000o`3ooon60?ooo`00:@3oool00`000000oooo0?ooo`3o0?ooohD0oooo
000Y0?ooo`030000003oool0oooo0?l0ooooQ@3oool002T0oooo00<000000?ooo`3oool0o`3ooon5
0?ooo`00:@3oool00`000000oooo0?ooo`3o0?ooohD0oooo000Y0?ooo`030000003oool0oooo0?l0
ooooQ@3oool002T0oooo00<000000?ooo`3oool0o`3ooon50?ooo`00:@3oool00`000000oooo0?oo
o`3o0?ooohD0oooo000Y0?ooo`030000003oool0oooo0?l0ooooQ@3oool002T0oooo00<000000?oo
o`3oool0o`3ooon50?ooo`00:@3oool00`000000oooo0?ooo`3o0?ooohD0oooo000Y0?ooo`030000
003oool0oooo0?l0ooooQ@3oool002T0oooo0P00003o0?ooohH0oooo000Y0?ooo`030000003oool0
oooo0?l0ooooQ@3oool002T0oooo00<000000?ooo`3oool0o`3ooon50?ooo`00:@3oool00`000000
oooo0?ooo`3o0?ooohD0oooo000Y0?ooo`030000003oool0oooo0?l0ooooQ@3oool002T0oooo00<0
00000?ooo`3oool0o`3ooon50?ooo`00:@3oool00`000000oooo0?ooo`3o0?ooohD0oooo000Y0?oo
o`030000003oool0oooo0?l0ooooQ@3oool002T0oooo00<000000?ooo`3oool0o`3ooon50?ooo`00
:@3oool00`000000oooo0?ooo`3o0?ooohD0oooo000Y0?ooo`030000003oool0oooo0?l0ooooQ@3o
ool002T0oooo00<000000?ooo`3oool0o`3ooon50?ooo`00:@3oool200000?l0ooooQP3oool002T0
oooo00<000000?ooo`3oool0o`3ooon50?ooo`00:@3oool00`000000oooo0?ooo`3o0?ooohD0oooo
000Y0?ooo`030000003oool0oooo0?l0ooooQ@3oool002T0oooo00<000000?ooo`3oool0o`3ooon5
0?ooo`00:@3oool00`000000oooo0?ooo`3o0?ooohD0oooo000Y0?ooo`030000003oool0oooo0?l0
ooooQ@3oool002T0oooo00<000000?ooo`3oool0o`3ooon50?ooo`00703oool00`3o_g@000000000
000300000003001d_`3oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooon50?ooo`007`3oool0
0`2LB4P0W=oo0?ooo`070?ooo`030000003oool0oooo0?l0ooooQ@3oool001l0oooo00<0W4Q809cO
o`3oool01`3oool00`000000oooo0?ooo`3o0?ooohD0oooo000O0?ooo`0309a8B02Lgol0oooo00L0
oooo00<000000?ooo`3oool0o`3ooon50?ooo`007`3oool00`2LB4P0W=oo0?ooo`070?ooo`<00000
o`3ooon50?ooo`007`3oool00`2LB4P0W=oo0?ooo`3o0?ooohl0oooo000O0?ooo`0309a8B02Lgol0
oooo0?l0ooooS`3oool001`0oooo00D0gia800000000B9`0W4Q809cOo`3o0?oooi00oooo000N0?oo
o`030=nLB00004P0W=oo0?l0ooooT03oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-1.11314, -0.0763042, \
0.0404313, 0.00623041}}]
}, Closed]]
}, Closed]],

Cell["\<\
A small improvement in the range of validity can be obtained by reducing the \
initial step size\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DisplayTogether[
        LogPlot[Evaluate[
            Abs[stiffSol[20, 10, StartingStepSize \[Rule] 10\^\(-6\)]]], {x, 
            0, 2}, PlotRange \[Rule] {Automatic, {10\^\(-9\), 10\^1}}], 
        LogPlot[Evaluate[trueSol[20]], {x, 0, 2}, 
          PlotStyle \[Rule] {{RGBColor[1, 0, 0], 
                Dashing[{0.02, 0.02}]}}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.556231 0.0618034 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[-0.0125 0 -46.5 -6.6875 ]
[-0.0125 0 0 6.6875 ]
[-0.0125 .12361 -46.5 -6.625 ]
[-0.0125 .12361 0 6.625 ]
[-0.0125 .24721 -46 -6.28125 ]
[-0.0125 .24721 0 6.28125 ]
[-0.0125 .37082 -34 -6.28125 ]
[-0.0125 .37082 0 6.28125 ]
[-0.0125 .49443 -22 -6.28125 ]
[-0.0125 .49443 0 6.28125 ]
[-0.0125 .61803 -16 -6.28125 ]
[-0.0125 .61803 0 6.28125 ]
[ -0.0005 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
.00625 0 L
s
gsave
-0.0125 0 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
gsave
-0.0125 .12361 -107.5 -10.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.500 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.313 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
105.000 9.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .24721 m
.00625 .24721 L
s
gsave
-0.0125 .24721 -107 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00001) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .37082 m
.00625 .37082 L
s
gsave
-0.0125 .37082 -95 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .49443 m
.00625 .49443 L
s
gsave
-0.0125 .49443 -83 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -77 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .0667 m
.00375 .0667 L
s
0 .08416 m
.00375 .08416 L
s
0 .09465 m
.00375 .09465 L
s
0 .10217 m
.00375 .10217 L
s
0 .10804 m
.00375 .10804 L
s
0 .11286 m
.00375 .11286 L
s
0 .11694 m
.00375 .11694 L
s
0 .12048 m
.00375 .12048 L
s
0 .1903 m
.00375 .1903 L
s
0 .20777 m
.00375 .20777 L
s
0 .21826 m
.00375 .21826 L
s
0 .22578 m
.00375 .22578 L
s
0 .23165 m
.00375 .23165 L
s
0 .23646 m
.00375 .23646 L
s
0 .24054 m
.00375 .24054 L
s
0 .24409 m
.00375 .24409 L
s
0 .31391 m
.00375 .31391 L
s
0 .33137 m
.00375 .33137 L
s
0 .34186 m
.00375 .34186 L
s
0 .34939 m
.00375 .34939 L
s
0 .35526 m
.00375 .35526 L
s
0 .36007 m
.00375 .36007 L
s
0 .36415 m
.00375 .36415 L
s
0 .36769 m
.00375 .36769 L
s
0 .43752 m
.00375 .43752 L
s
0 .45498 m
.00375 .45498 L
s
0 .46547 m
.00375 .46547 L
s
0 .47299 m
.00375 .47299 L
s
0 .47886 m
.00375 .47886 L
s
0 .48368 m
.00375 .48368 L
s
0 .48776 m
.00375 .48776 L
s
0 .4913 m
.00375 .4913 L
s
0 .56112 m
.00375 .56112 L
s
0 .57859 m
.00375 .57859 L
s
0 .58908 m
.00375 .58908 L
s
0 .5966 m
.00375 .5966 L
s
0 .60247 m
.00375 .60247 L
s
0 .60728 m
.00375 .60728 L
s
0 .61137 m
.00375 .61137 L
s
0 .61491 m
.00375 .61491 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .55623 m
.06244 .51268 L
.10458 .46518 L
.14415 .42057 L
.18221 .37767 L
.22272 .332 L
.26171 .28804 L
.30316 .24132 L
.34309 .1963 L
.3815 .15297 L
.40095 .1309 L
.42237 .1059 L
.43215 .09352 L
.43755 .08597 L
.44268 .07788 L
.44744 .06884 L
.44995 .063 L
.45262 .0554 L
.4539 .05101 L
.4551 .04619 L
.45626 .04057 L
.45734 .03418 L
.45836 .0263 L
.45944 .01435 L
s
.45944 .01435 m
.46014 0 L
s
.46271 0 m
.46302 .01009 L
.46423 .02486 L
.46486 .03023 L
.46555 .03513 L
.46696 .043 L
.46952 .05342 L
.47192 .06087 L
.4764 .07148 L
.48123 .08019 L
.50214 .1089 L
.54328 .15617 L
.5829 .20091 L
.62101 .24389 L
.66157 .28961 L
.70062 .33363 L
.74212 .38041 L
.7821 .42548 L
.82057 .46885 L
.86148 .51498 L
.90089 .5594 L
.93877 .60211 L
s
.93877 .60211 m
.9529 .61803 L
s
1 0 0 r
[ .02 .02 ] 0 setdash
.02381 .55623 m
.06244 .51268 L
.10458 .46518 L
.14415 .42057 L
.18221 .37767 L
.22272 .332 L
.26171 .28804 L
.30316 .24132 L
.34309 .19631 L
.3815 .153 L
.42237 .10693 L
.46172 .06257 L
.49955 .01992 L
s
.49955 .01992 m
.51722 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00D03oool0
1@3o_g@00000000000000000M;oo04L0oooo00D0okmd000000000000000007Boo`050?ooo`030;md
0000000007Bo00D0oooo00D0_g@0000000000000000007Boo`160?ooo`030?noM0000000000000<0
000000<007Bo0?ooo`3oool0@`3oool00`3o_g@000000000000300000003001d_`3oool0oooo0080
oooo00<0_g@000000000M;l01@3oool01@2oM0000000000000000000M;oo04D0oooo00<0oono07@0
00000000100000000`1d_ol0oooo0?ooo`040?ooo`00D03oool01P2LB7@0_ooo0?ooo`3ookl0M01d
0;ooodH0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00@0oooo
00L0_g@0001d_`3oool0oooo0?oOW0180000M;oo04P0oooo00<0W4Q809cOo`3oool0B@3oool00`2L
B4P0W=oo0?ooo`050?ooo`030;md0000000007Bo00@0oooo00L0_g@0001d_`3oool0oooo0?oOW018
0000M;oo04D0oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?ooo`050?ooo`00C`3oool0
0`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo04@0oooo00<0okmd001d_`3oool00P3oool0
0`3OW4P0B9cO0?ooo`0?0?ooo`030?noM000M;l0oooo04L0oooo00<0W4Q809cOo`3oool0B@3oool0
0`2LB4P0W=oo0?ooo`0A0?ooo`030?noM000M;l0oooo04D0oooo00<0okmd0000B02Lgol02@3oool0
04l0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`140?ooo`030=nLB018W=l0oooo
0080oooo00<0okmd001d_`3oool03`3oool00`3o_g@007Bo0?ooo`170?ooo`0309a8B02Lgol0oooo
04T0oooo00<0W4Q809cOo`3oool04@3oool00`3o_g@007Bo0?ooo`160?ooo`030?oOW0180000B9cO
00P0oooo001?0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0A03oool00`3OW4P0
B9cO0?ooo`020?ooo`030?noM000M;l0oooo00l0oooo00<0W4P007Boo`3oool0A`3oool00`2LB4P0
W=oo0?ooo`190?ooo`0309a8B02Lgol0oooo0140oooo00<0W4P007Boo`3oool0B03oool00`2LB000
B9cO0?ooo`060?ooo`00C`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo04@0oooo
00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`030?oo_`1d0000000000800000
00<0B9cO0?ooo`3oool0A`3oool00`2LB4P0W=oo0?ooo`190?ooo`0309a8B02Lgol0oooo00`0oooo
00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`190?ooo`0309a8M02oool0oooo00D0oooo
001?0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool0A03oool00`3o_g@0B9cO0?oo
o`020?ooo`030=nLB018W=l0oooo00X0oooo00<0oono07@0M02oool0C03oool00`2LB4P0W=oo0?oo
o`190?ooo`0309a8B02Lgol0oooo00`0oooo00<0oono07@0M02oool0B@3oool00`3OW4P0M;oo0?oo
o`020?ooo`030;md001d_ol0oooo00D0oooo001@0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo
AP3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00<0oono07@0M02oool0B@3oool01@3O
W4P000000018W02LB4P0W=oo04L0oooo00D0gia800000000B9`0W4Q809cOo`0=0?ooo`030?oo_`1d
07@0_ooo04T0oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo00H0oooo001@0?ooo`050?oo
_`1d000000000000B02Lgol0A`3oool01@3ookl0M0000000000004P0W=oo00`0oooo00<0oono07@0
000000000P0000000`0007@0_ooo0?ooo`160?ooo`030=nLB00004P0W=oo04T0oooo00<0gia80000
B02Lgol03@3oool00`3ookl0M00000000002000000030000M02oool0oooo04D0oooo00D0okmd0000
00000000001809cOo`070?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00103oool00`3o_g@000000000000300000003001d_`3oool0oooo0080oooo00<0_g@0
00000000M;l01P3oool00`2oM4P0W=oo0?ooo`020?ooo`030?oo_`1dB9`0gooo00@0oooo00<0okmd
0000000000000`0000001@00M;l0oooo0?ooo`3oool0okmd00<0000000<0M;oo0?ooo`3oool0o`3o
ooml0?ooo`001`3oool00`2LB4P0W=oo0?ooo`050?ooo`030;md0000000007Bo00H0oooo00L0oooO
09a8B02Lgol0oooo0?oo_`1d07@0_ooo00P0oooo00<0W4Q809cOo`3oool0103oool01P2LB7@0_ooo
0?ooo`3ookl0M01d0;ooool0ooooO@3oool000L0oooo00<0W4Q809cOo`3oool03`3oool01@3ooml0
W4Qd0;oog`2LB7@0_ooo00T0oooo00<0W4Q809cOo`3oool00`3oool00`3o_g@007Bo0?ooo`020?oo
o`030=nLB018W=l0oooo0?l0ooooO03oool000L0oooo00<0W4Q809cOo`3oool0403oool00`3ookl0
M01809cOo`0:0?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@0
07Bo0?ooo`3o0?ooog`0oooo00070?ooo`0309a8B02Lgol0oooo00l0oooo00D0oono07@0M02ooml0
W4Q809cOo`090?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@0
07Bo0?ooo`0E0?ooool00000I`00000000L0oooo00<0W4Q809cOo`3oool03P3oool01`3ookl0M01d
0;ooo`3oool0oooO09a8B02Lgol0203oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo
0080oooo00<0okmd001d_`3oool05@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00800000303oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo00T0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool01`3oool000L0oooo00<0W4Q809cOo`3oool03P3oool00`2oM7@0_ooo0?ooo`020?ooo`03
0?oog`2LM9`0gooo00L0oooo00<0W4Q809cOo`3oool00`3oool00`3o_g@0B9cO0?ooo`020?ooo`03
0=nLB018W=l0oooo00L0oooo00@0_g@000000000000004RL2P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0580oooo00<000000?ooo`3oool0A03oool2000000`0oooo00D000000?oo
o`3oool0oooo0?l0001@0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool01`3oool0
00@0oooo00D0gia800000000B9`0W4Q809cOo`0K0?ooo`050=nLB000000004RL09a8B02Lgol01@3o
ool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00<0gia8001d_`3oool0203oool00`000000
oooo0?ooo`2Q0?ooo`8000003`3oool00`3o0000oooo0?ooo`2^0?ooo`001P3oool00`3OW4P00018
09cOo`0M0?ooo`030=nLB00004P0W=oo00D0oooo00D0oono07@000000000001809cOo`020?ooo`03
0?oog`2LB00000000080000000<0B9cO0?ooo`3oool00`3oool00`2LB7@0_ooo0?ooo`070?ooo`03
0000003oool0oooo0:40oooo0P00000>0?ooo`030?l0003oool0oooo0:l0oooo000l0?ooo`060?oo
_`1d000000000000000004P0W=oo203oool00`000000oooo0?ooo`2Q0?ooo`8000003P3oool00`3o
0000oooo0?ooo`2_0?ooo`00?03oool01P2oM000M;oo0?ooo`3oool0W4Qd0;ooo`P0oooo00<00000
0?ooo`3oool0X@3oool2000000d0oooo00<0o`000?ooo`3oool0/03oool003`0oooo00D0_g@007Bo
o`3oool0okmd001d_`090?ooo`030000003oool0oooo0:00oooo00<000000?ooo`000000303oool0
0`3o0000oooo0?ooo`2a0?ooo`00?03oool01@3ookl0M0000000000007@0_ooo00T0oooo00<00000
0?ooo`3oool0X03oool00`000000oooo000000300?ooo`00BP3oool00`000000oooo0?ooo`2P0?oo
o`030000003oool000000<00oooo001:0?ooo`030000003oool0oooo0:00oooo00@000000?ooo`3o
ool00000_`3oool004X0oooo00<000000?ooo`3oool0X03oool010000000oooo0?ooo`0000070?oo
o`030?l0003oool0oooo0;D0oooo001:0?ooo`030000003oool0oooo0:00oooo00@000000?ooo`3o
ool000001P3oool00`3o0000oooo0?ooo`2f0?ooo`00BP3oool00`000000oooo0?ooo`2P0?ooo`04
0000003oool0oooo000000D0oooo00<0o`000?ooo`3oool0]`3oool004X0oooo00<000000?ooo`3o
ool0X03oool010000000oooo0?ooo`0000040?ooo`030?l0003oool0oooo0;P0oooo001:0?ooo`03
0000003oool0oooo09l0oooo00D000000?ooo`3oool0oooo000000040?ooo`030?l0003oool0oooo
0;P0oooo001:0?ooo`030000003oool0oooo09l0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030?l0003oool0oooo0;T0oooo001:0?ooo`030000003oool0oooo09l0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030?l0003oool0oooo0;X0oooo001:0?ooo`030000003oool0oooo09l0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2l0?ooo`00BP3oool00`000000oooo
0?ooo`2N0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0_03oool004X0oooo00<0
00000?ooo`3oool0WP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0;`0oooo001:
0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2k
0?ooo`00BP3oool00`000000oooo0?ooo`2M0?ooo`040000003oool0oooo0?ooo`80o`000P3oool0
0`000000oooo0?ooo`2k0?ooo`00BP3oool2000009d0oooo00D000000?ooo`3oool0oooo0?l00005
0?ooo`030000003oool0oooo0;X0oooo001:0?ooo`030000003oool0oooo09`0oooo00@000000?oo
o`3oool0o`001P3oool00`000000oooo0?ooo`2j0?ooo`00BP3oool00`000000oooo0?ooo`2L0?oo
o`040000003oool0oooo0?l000L0oooo00<000000?ooo`3oool0^@3oool004X0oooo00<000000?oo
o`3oool0V`3oool010000000oooo0?ooo`3o00080?ooo`030000003oool0oooo0;T0oooo001:0?oo
o`030000003oool0oooo09/0oooo00<000000?ooo`3o00002P3oool00`000000oooo0?ooo`2h0?oo
o`00BP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0^03oool004X0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0;L0oooo001:0?ooo`800000VP3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0;H0oooo001:0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`2f0?ooo`00BP3oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0]@3oool004X0oooo0P00002H0?ooo`030000003o0000oooo0180
oooo00<000000?ooo`3oool0]03oool004X0oooo00<000000?ooo`3oool0UP3oool00`000000o`00
0?ooo`0D0?ooo`030000003oool0oooo0;<0oooo001:0?ooo`030000003oool0oooo09D0oooo00<0
00000?l0003oool05P3oool00`000000oooo0?ooo`2b0?ooo`00BP3oool2000009D0oooo00<00000
0?l0003oool05`3oool00`000000oooo0?ooo`2b0?ooo`00BP3oool00`000000oooo0?ooo`2C0?oo
o`030000003o0000oooo01T0oooo00<000000?ooo`3oool0/@3oool004X0oooo0P00002C0?ooo`03
0000003o0000oooo01/0oooo00<000000?ooo`3oool0/03oool004X0oooo00<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0:l0oooo00040?ooo`030?noM000
0000000000<0000000<007Bo0?ooo`3oool00P3oool00`2oM0000000001d_`060?ooo`030;mdB02L
gol0oooo0080oooo00<0oono07A8W03Oool0103oool00`3o_g@000000000000300000005001d_`3o
ool0oooo0?ooo`3o_g@00`0000000`1d_ol0oooo0?ooo`0E0?ooo`800000TP3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo0:h0oooo00070?ooo`0309a8B02Lgol0oooo00D0oooo00<0
_g@000000000M;l01P3oool01`3ooml0W4Q809cOo`3oool0oono07@0M02oool0203oool00`2LB4P0
W=oo0?ooo`040?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo5P3oool200000940oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`2]0?ooo`001`3oool00`2LB4P0W=oo0?ooo`0?0?oo
o`050?oog`2LB7@0_ooO09a8M02oool02@3oool00`2LB4P0W=oo0?ooo`030?ooo`030?noM000M;l0
oooo0080oooo00<0gia804RLg`3oool05@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0[03oool000L0oooo00<0W4Q809cOo`3oool0403oool00`3o
okl0M01809cOo`0:0?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o
_g@007Bo0?ooo`0E0?ooo`800000S`3oool00`000000o`000?ooo`0S0?ooo`030000003oool0oooo
0:`0oooo00070?ooo`0309a8B02Lgol0oooo00l0oooo00D0oono07@0M02ooml0W4Q809cOo`090?oo
o`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0E0?oo
o`<00000SP3oool00`3o0000oooo0?ooo`0T0?ooo`030000003oool0oooo0:/0oooo00070?ooo`03
09a8B02Lgol0oooo00h0oooo00L0oono07@0M02oool0oooo0?oog`2LB4P0W=oo00P0oooo00<0W4Q8
09cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo01D0oooo00<00000
0?ooo`3oool0S@3oool00`3o0000oooo0?ooo`0V0?ooo`030000003oool0oooo0:X0oooo00070?oo
o`0309a8B02Lgol0oooo00h0oooo00<0_gAd0;ooo`3oool00P3oool00`3ooml0W7BL0=ooo`070?oo
o`0309a8B02Lgol0oooo00<0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0E0?oo
o`030000003oool0oooo08`0oooo00<0o`000?ooo`3oool0:03oool00`000000oooo0?ooo`2Y0?oo
o`00103oool01@3OW4P000000018W02LB4P0W=oo01/0oooo00D0gia800000000B9`0W4Q809cOo`05
0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2@3oool00`3ookl0M4RL0?ooo`0:0?ooo`030000
003oool0oooo08/0oooo00<000000?l0003oool0:P3oool00`000000oooo0?ooo`2X0?ooo`001P3o
ool00`3OW4P0001809cOo`0M0?ooo`030=nLB00004P0W=oo00D0oooo00D0oono07@0000000000018
09cOo`0;0?ooo`030;mdB02Lgol0oooo00T0oooo00<000000?ooo`3oool0RP3oool00`000000o`00
0?ooo`0/0?ooo`030000003oool0oooo0:L0oooo000e0?ooo`030?oog`2LB00000000080000000H0
B9cO0?ooo`3oool0oooo0?noM018W=l:0?ooo`030000003oool0oooo08T0oooo00<000000?l0003o
ool0;P3oool00`000000oooo0?ooo`2V0?ooo`00?P3oool00`3ookl0M4RL0?ooo`090?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`2U0?ooo`00?`3o
ool00`3OW4P0M;oo0?ooo`080?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`2U0?ooo`00>`3oool01P3ookl0M4RL0?ooo`3oool0omnL04Qd_`T0oooo
00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0:@0oooo
000k0?ooo`030?oo_`1d000000000080000000<007Bo0?ooo`3oool01`3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0X`3oool004X0oooo00<00000
0?ooo`3oool0Q@3oool00`3o0000oooo0?ooo`0f0?ooo`030000003oool0oooo0:80oooo001:0?oo
o`030000003oool0oooo08@0oooo00<0o`000?ooo`3oool0>03oool00`000000oooo0?ooo`2Q0?oo
o`00BP3oool00`000000oooo0?ooo`230?ooo`030?l0003oool0oooo03X0oooo00<000000?ooo`3o
ool0X03oool004X0oooo00<000000?ooo`3oool0PP3oool00`3o0000oooo0?ooo`0l0?ooo`030000
003oool0oooo09l0oooo001:0?ooo`030000003oool0oooo0840oooo00<0o`000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`2N0?ooo`00BP3oool00`000000oooo0?ooo`200?ooo`030?l000000000
oooo03l0oooo00<000000?ooo`3oool0WP3oool004X0oooo00<000000?ooo`3oool0P03oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo09d0oooo001:0?ooo`030000003oool0oooo07l0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`2L0?ooo`00BP3oool00`000000oooo
0?ooo`1n0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0V`3oool004X0oooo00<0
00000?ooo`3oool0O@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo09X0oooo001:
0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2I
0?ooo`00BP3oool00`000000oooo0?ooo`1k0?ooo`030000003o0000oooo04X0oooo00<000000?oo
o`3oool0V03oool004X0oooo00<000000?ooo`3oool0NP3oool00`000000o`000?ooo`1<0?ooo`03
0000003oool0oooo09L0oooo001:0?ooo`800000N`3oool00`3o0000oooo0?ooo`1<0?ooo`030000
003oool0oooo09L0oooo001:0?ooo`030000003oool0oooo07T0oooo00<0o`000?ooo`3oool0CP3o
ool00`000000oooo0?ooo`2F0?ooo`00BP3oool00`000000oooo0?ooo`1h0?ooo`030?l0003oool0
oooo0500oooo00<000000?ooo`3oool0U@3oool004X0oooo00<000000?ooo`3oool0M`3oool00`3o
0000oooo0?ooo`1B0?ooo`030000003oool0oooo09@0oooo001:0?ooo`030000003oool0oooo07H0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2C0?ooo`00BP3oool00`000000oooo
0?ooo`1e0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0TP3oool004X0oooo00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0940oooo001:
0?ooo`800000M03oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0940oooo001:0?oo
o`030000003oool0oooo0780oooo00<0o`000000003oool0F`3oool00`000000oooo0?ooo`2@0?oo
o`00BP3oool00`000000oooo0?ooo`1a0?ooo`030?l000000000oooo05d0oooo00<000000?ooo`3o
ool0S`3oool004X0oooo0P00001a0?ooo`030?l000000000oooo05l0oooo00<000000?ooo`3oool0
SP3oool004X0oooo00<000000?ooo`3oool0K`3oool00`3o000000000?ooo`1Q0?ooo`030000003o
ool0oooo08d0oooo001:0?ooo`030000003oool0oooo06l0oooo00<0o`000?ooo`3oool0H@3oool0
0`000000oooo0?ooo`2=0?ooo`00BP3oool2000006l0oooo00<0o`000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`2<0?ooo`00BP3oool00`000000oooo0?ooo`1]0?ooo`030?l0003oool0oooo06D0
oooo00<000000?ooo`3oool0R`3oool004X0oooo0P00001]0?ooo`030000003oool0oooo06L0oooo
00<000000?ooo`3oool0RP3oool004X0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?oo
o`1X0?ooo`030000003oool0oooo08T0oooo001:0?ooo`800000K03oool00`000000oooo0?ooo`1Z
0?ooo`030000003oool0oooo08P0oooo00050?ooo`050?noM000000000000000001d_ol01@3oool0
0`2oM0000000001d_`050?ooo`050?noM000000000000000001d_ol0103oool01@3o_g@000000000
00000000M;oo00@0oooo00D0okmd000000000000000007Boo`040?ooo`050?noM000000000000000
001d_ol00`3oool00`3o_g@000000000000300000003001d_`3oool0oooo00L0oooo0P00001[0?oo
o`030000003oool0oooo06/0oooo00<000000?ooo`3oool0R03oool000D0oooo00H0W4Qd0;ooo`3o
ool0oono07@0M02oool40?ooo`030;md0000000007Bo00D0oooo00H0W4Qd0;ooo`3oool0oono07@0
M02oool30?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo0`3oool01P2LB7@0_ooo0?ooo`3ookl0
M01d0;ooo`<0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool50?ooo`0309a8B02Lgol0oooo00X0
oooo00<000000?ooo`3oool0J@3oool00`3o0000oooo0?ooo`1]0?ooo`030000003oool0oooo08L0
oooo00040?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool02P3oool00`3o_g@007Bo
0?ooo`020?ooo`060=nLB018W=l0oooo0?ooo`3o_g@007Bo0`3oool01P3OW4P0B9cO0?ooo`3oool0
okmd001d_`<0oooo00H0gia804RLg`3oool0oooo0?noM000M;l30?ooo`030=nLB018W=l0oooo00@0
oooo00<0W4Q809cOo`3oool02P3oool2000006T0oooo00<0o`000?ooo`3oool0K`3oool00`000000
oooo0?ooo`260?ooo`00103oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo
00<0gia804RLg`3oool00P3oool01P3o_g@007Bo0?ooo`3oool0gia804RLg`<0oooo00H0okmd001d
_`3oool0oooo0=nLB018W=l30?ooo`060?noM000M;l0oooo0?ooo`3OW4P0B9cO0`3oool00`3o_g@0
07Bo0?ooo`040?ooo`0309a8B02Lgol0oooo00X0oooo0`00001W0?ooo`030?l0003oool0oooo0740
oooo00<000000?ooo`3oool0Q@3oool000@0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo
0?ooo`0:0?ooo`030=nLB018W=l0oooo0080oooo00H0okmd001d_`3oool0oooo0=nLB018W=l30?oo
o`060?noM000M;l0oooo0?ooo`3OW4P0B9cO0`3oool01P3o_g@007Bo0?ooo`3oool0gia804RLg`<0
oooo00<0okmd001d_`3oool0103oool00`2LB4P0W=oo0?ooo`0:0?ooo`030000003oool0oooo06H0
oooo00<0o`000?ooo`3oool0L`3oool00`000000oooo0?ooo`240?ooo`00103oool00`3OW4P0B9cO
0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0gia804RLg`3oool00P3oool01P3o_g@007Bo
0?ooo`3oool0gia804RLg`<0oooo00H0okmd001d_`3oool0oooo0=nLB018W=l30?ooo`060?noM000
M;l0oooo0?ooo`3OW4P0B9cO0`3oool00`3o_g@007Bo0?ooo`040?ooo`0309a8B02Lgol0oooo00X0
oooo00<000000?ooo`3oool0I@3oool00`3o0000oooo0?ooo`1e0?ooo`030000003oool0oooo08<0
oooo00040?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool02P3oool00`3o_g@0B9cO
0?ooo`020?ooo`060=nLB018W=l0oooo0?ooo`3o_g@0B9cO0`3oool01P3OW4P0B9cO0?ooo`3oool0
okmd04RLg`<0oooo00H0gia804RLg`3oool0oooo0?noM018W=l30?ooo`030=nLB018W=l0oooo00@0
oooo00<0W4Q809cOo`3oool02P3oool00`000000oooo0?ooo`1T0?ooo`030?l0003oool0oooo07L0
oooo00<000000?ooo`3oool0PP3oool000D0oooo00H0W4P007Boo`3oool0omnL04P0M02oool<0?oo
o`0609a8001d_ol0oooo0?oOW01807@0_ooo0`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`<0
oooo00H0W4P007Boo`3oool0omnL04P0M02oool30?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo
0P3oool01@3OW4P000000018W02LB4P0W=oo00/0oooo00<000000?ooo`3oool0H`3oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo0840oooo00050?ooo`050?oo_`1d000000000000B02L
gol03@3oool01@3ookl0M0000000000004P0W=oo00@0oooo00D0oono07@000000000001809cOo`04
0?ooo`050?oo_`1d000000000000B02Lgol0103oool01@3ookl0M0000000000004P0W=oo00D0oooo
00<0gia80000B02Lgol02`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo07/0oooo
00<000000?ooo`3oool0P03oool004X0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?oo
o`1m0?ooo`030000003oool0oooo07l0oooo001:0?ooo`030000003oool0oooo0640oooo00<00000
0?ooo`3oool0O@3oool00`000000oooo0?ooo`1o0?ooo`00BP3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo07l0oooo00<000000?ooo`3oool0OP3oool004X0oooo00<000000?ooo`3o
ool0G`3oool00`3o0000oooo0?ooo`210?ooo`030000003oool0oooo07d0oooo001:0?ooo`030000
003oool0oooo05h0oooo00<0o`000?ooo`3oool0P`3oool00`000000oooo0?ooo`1l0?ooo`00BP3o
ool00`000000oooo0?ooo`1M0?ooo`030?l0003oool0oooo08D0oooo00<000000?ooo`3oool0N`3o
ool004X0oooo00<000000?ooo`3oool0G03oool00`3o0000oooo0?ooo`270?ooo`030000003oool0
oooo07X0oooo001:0?ooo`030000003oool0oooo05/0oooo00<0o`000?ooo`3oool0R@3oool00`00
0000oooo0?ooo`1i0?ooo`00BP3oool00`000000oooo0?ooo`1J0?ooo`030?l0003oool0oooo08/0
oooo00<000000?ooo`3oool0N03oool004X0oooo00<000000?ooo`3oool0F@3oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo07L0oooo001:0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`1f0?ooo`00BP3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0M@3oool004X0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo07@0oooo001:0?ooo`03
0000003oool0oooo05H0oooo00<0o`000?ooo`3oool0T`3oool00`000000oooo0?ooo`1d0?ooo`00
BP3oool00`000000oooo0?ooo`1E0?ooo`030?l0003oool0oooo09D0oooo00<000000?ooo`3oool0
L`3oool004X0oooo00<000000?ooo`3oool0E03oool00`3o0000oooo0?ooo`2G0?ooo`030000003o
ool0oooo0780oooo001:0?ooo`030000003oool0oooo05<0oooo00<0o`000?ooo`3oool0V@3oool0
0`000000oooo0?ooo`1a0?ooo`00BP3oool00`000000oooo0?ooo`1B0?ooo`030000003o0000oooo
09/0oooo00<000000?ooo`3oool0L03oool004X0oooo0P00001B0?ooo`030000003o0000oooo09d0
oooo00<000000?ooo`3oool0K`3oool004X0oooo00<000000?ooo`3oool0D03oool00`000000o`00
0?ooo`2O0?ooo`030000003oool0oooo06h0oooo001:0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0X@3oool00`000000oooo0?ooo`1]0?ooo`00BP3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0K@3oool004X0oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo06`0oooo001:0?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`1[0?ooo`00
BP3oool2000004d0oooo00<0o`000?ooo`3oool0Y`3oool00`000000oooo0?ooo`1Z0?ooo`00BP3o
ool00`000000oooo0?ooo`1;0?ooo`030?l0003oool0oooo0:T0oooo00<000000?ooo`3oool0J@3o
ool004X0oooo00<000000?ooo`3oool0BP3oool00`3o0000oooo0?ooo`2[0?ooo`030000003oool0
oooo06P0oooo001:0?ooo`030000003oool0oooo04T0oooo00<0o`000?ooo`3oool0[@3oool00`00
0000oooo0?ooo`1W0?ooo`00BP3oool2000004T0oooo00<0o`000?ooo`3oool0[`3oool00`000000
oooo0?ooo`1V0?ooo`00BP3oool00`000000oooo0?ooo`170?ooo`030?l000000000oooo0;00oooo
00<000000?ooo`3oool0IP3oool004X0oooo0P0000180?ooo`030000003oool0oooo0;40oooo00<0
00000?ooo`3oool0I@3oool004X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`2c
0?ooo`030000003oool0oooo06@0oooo001:0?ooo`800000AP3oool00`000000oooo0?ooo`2e0?oo
o`030000003oool0oooo06<0oooo001:0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool0]`3oool00`000000oooo0?ooo`1R0?ooo`00BP3oool2000004@0oooo00<000000?ooo`3oool0
^@3oool00`000000oooo0?ooo`1Q0?ooo`005`3oool01@3o_g@00000000000000000M;oo00D0oooo
00<0_g@000000000M;l01@3oool01@3o_g@00000000000000000M;oo00@0oooo00D0okmd00000000
0000000007Boo`030?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool01`3oool00`00
0000oooo0?ooo`120?ooo`030000003o0000oooo0;/0oooo00<000000?ooo`3oool0H03oool001L0
oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00D0oooo00H0W4Qd
0;ooo`3oool0oono07@0M02oool30?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo1@3oool00`2L
B4P0W=oo0?ooo`0:0?ooo`800000@P3oool00`000000o`000?ooo`2m0?ooo`030000003oool0oooo
05l0oooo000F0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool02P3oool00`3o_g@0
07Bo0?ooo`020?ooo`060=nLB018W=l0oooo0?ooo`3o_g@007Bo0`3oool00`3OW4P0B9cO0?ooo`04
0?ooo`0309a8B02Lgol0oooo00X0oooo0P0000120?ooo`030?l0003oool0oooo0;d0oooo00<00000
0?ooo`3oool0G`3oool001H0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?oo
o`030=nLB018W=l0oooo0080oooo00H0okmd001d_`3oool0oooo0=nLB018W=l30?ooo`030?noM000
M;l0oooo00@0oooo00<0W4Q809cOo`3oool02P3oool300000400oooo00<0o`000?ooo`3oool0_`3o
ool00`000000oooo0?ooo`1N0?ooo`005P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0
oooo00X0oooo00<0gia804RLg`3oool00P3oool01P3o_g@007Bo0?ooo`3oool0gia804RLg`<0oooo
00<0okmd001d_`3oool0103oool00`2LB4P0W=oo0?ooo`0:0?ooo`030000003oool0oooo03l0oooo
00<0o`000?ooo`3oool0`@3oool00`000000oooo0?ooo`1M0?ooo`005P3oool00`3OW4P0B9cO0?oo
o`020?ooo`030?noM000M;l0oooo00X0oooo00<0gia804RLg`3oool00P3oool01P3o_g@007Bo0?oo
o`3oool0gia804RLg`<0oooo00<0okmd001d_`3oool0103oool00`2LB4P0W=oo0?ooo`0:0?ooo`03
0000003oool0oooo03h0oooo00<0o`000?ooo`3oool0``3oool00`000000oooo0?ooo`1L0?ooo`00
5P3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0okmd04RLg`3oool0
0P3oool01P3OW4P0B9cO0?ooo`3oool0okmd04RLg`<0oooo00<0gia804RLg`3oool0103oool00`2L
B4P0W=oo0?ooo`0:0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0a@3oool00`00
0000oooo0?ooo`1K0?ooo`005`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo``0oooo00H0W4P0
07Boo`3oool0omnL04P0M02oool30?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo0P3oool01@3O
W4P000000018W02LB4P0W=oo00/0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`37
0?ooo`030000003oool0oooo05X0oooo000G0?ooo`050?oo_`1d000000000000B02Lgol03@3oool0
1@3ookl0M0000000000004P0W=oo00@0oooo00D0oono07@000000000001809cOo`050?ooo`030=nL
B00004P0W=oo00/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`390?ooo`030000
003oool0oooo05T0oooo001:0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0b`3o
ool00`000000oooo0?ooo`1H0?ooo`00BP3oool00`000000oooo0?ooo`0i0?ooo`030?l000000000
oooo0<d0oooo00<000000?ooo`3oool0E`3oool004X0oooo00<000000?ooo`3oool0>03oool00`3o
000000000?ooo`3?0?ooo`030000003oool0oooo05H0oooo001:0?ooo`030000003oool0oooo03P0
oooo00<0o`000?ooo`3oool0d03oool00`000000oooo0?ooo`1E0?ooo`00BP3oool00`000000oooo
0?ooo`0g0?ooo`030?l0003oool0oooo0=80oooo00<000000?ooo`3oool0E03oool004X0oooo00<0
00000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`3C0?ooo`030000003oool0oooo05@0oooo001:
0?ooo`030000003oool0oooo03D0oooo00<000000?l0003oool0e@3oool00`000000oooo0?ooo`1C
0?ooo`00BP3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000oooo0=L0oooo00<000000?oo
o`3oool0DP3oool004X0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`3I0?ooo`03
0000003oool0oooo0540oooo001:0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
fP3oool00`000000oooo0?ooo`1@0?ooo`00BP3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo0=`0oooo00<000000?ooo`3oool0C`3oool004X0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`3N0?ooo`030000003oool0oooo04h0oooo001:0?ooo`030000003oool0oooo
0300oooo00<0o`000?ooo`3oool0h03oool00`000000oooo0?ooo`1=0?ooo`00BP3oool00`000000
oooo0?ooo`0_0?ooo`030?l0003oool0oooo0>80oooo00<000000?ooo`3oool0C03oool004X0oooo
00<000000?ooo`3oool0;P3oool00`3o0000oooo0?ooo`3T0?ooo`030000003oool0oooo04/0oooo
001:0?ooo`030000003oool0oooo02d0oooo00<0o`000?ooo`3oool0iP3oool00`000000oooo0?oo
o`1:0?ooo`00BP3oool00`000000oooo0?ooo`0/0?ooo`030?l0003oool0oooo0>L0oooo00<00000
0?ooo`3oool0BP3oool004X0oooo00<000000?ooo`3oool0:`3oool00`3o000000000?ooo`3Y0?oo
o`030000003oool0oooo04T0oooo001:0?ooo`800000;03oool00`000000oooo0?ooo`3Z0?ooo`03
0000003oool0oooo04P0oooo001:0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
k03oool00`000000oooo0?ooo`170?ooo`00BP3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0>h0oooo00<000000?ooo`3oool0AP3oool004X0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`3_0?ooo`030000003oool0oooo04H0oooo001:0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`150?ooo`00BP3oool00`000000
oooo0?ooo`0V0?ooo`030?l0003oool0oooo0?<0oooo00<000000?ooo`3oool0A03oool004X0oooo
0P00000V0?ooo`030?l0003oool0oooo0?D0oooo00<000000?ooo`3oool0@`3oool004X0oooo00<0
00000?ooo`3oool0903oool00`3o000000000?ooo`3g0?ooo`030000003oool0oooo0480oooo001:
0?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3oool0n03oool00`000000oooo0?ooo`11
0?ooo`00BP3oool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo0?T0oooo00<000000?oo
o`3oool0@@3oool004X0oooo0P00000S0?ooo`030?l0003oool0oooo0?/0oooo00<000000?ooo`3o
ool0@03oool004X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3m0?ooo`030000
003oool0oooo03l0oooo001:0?ooo`8000008@3oool00`000000oooo0?ooo`3o0?ooo`030000003o
ool0oooo03h0oooo001:0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0o`3oool2
0?ooo`030000003oool0oooo03d0oooo001:0?ooo`8000007`3oool00`000000oooo0?ooo`3o0?oo
o`@0oooo00<000000?ooo`3oool0?03oool004X0oooo00<000000?ooo`3oool07@3oool00`3o0000
oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool0>`3oool004X0oooo0P00000M0?ooo`030?l0
003oool0oooo0?l0oooo203oool00`000000oooo0?ooo`0j0?ooo`00:@3oool01@3o_g@000000000
00000000M;oo00D0oooo00<0_g@000000000M;l0103oool00`3o_g@000000000000300000003001d
_`3oool0oooo00L0oooo00<000000?ooo`3oool06`3oool00`3o0000oooo0?ooo`3o0?ooo`X0oooo
00<000000?ooo`3oool0>@3oool002T0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`03
0;md0000000007Bo00L0oooo00<0W4Q809cOo`3oool02P3oool2000001/0oooo00<0o`000?ooo`3o
ool0o`3oool<0?ooo`030000003oool0oooo03P0oooo000X0?ooo`030?noM000M;l0oooo0080oooo
00<0gia804RLg`3oool03@3oool00`2LB4P0W=oo0?ooo`0:0?ooo`8000006`3oool00`3o0000oooo
0?ooo`3o0?ooo``0oooo00<000000?ooo`3oool0>03oool002P0oooo00<0gia804RLg`3oool00P3o
ool00`3o_g@007Bo0?ooo`0=0?ooo`0309a8B02Lgol0oooo00X0oooo0`00000I0?ooo`030?l0003o
ool0oooo0?l0oooo3P3oool00`000000oooo0?ooo`0g0?ooo`00:03oool00`3OW4P0B9cO0?ooo`02
0?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool02P3oool00`000000oooo0?ooo`0H
0?ooo`030?l0003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`0f0?ooo`00:03oool00`3O
W4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00d0oooo00<0W4Q809cOo`3oool02P3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0oooo4P3oool00`000000oooo0?ooo`0e0?oo
o`00:03oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00d0oooo00<0W4Q809cOo`3o
ool02P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0oooo503oool00`000000
oooo0?ooo`0d0?ooo`00:@3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00D0gia80000
0000B9`0W4Q809cOo`0;0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooolF
0?ooo`030000003oool0oooo03<0oooo000Y0?ooo`050?oo_`1d000000000000B02Lgol03P3oool0
0`3OW4P0001809cOo`0;0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3ooolH
0?ooo`030000003oool0oooo0380oooo001:0?ooo`030000003oool0oooo01<0oooo00<0o`000?oo
o`3oool0o`3ooolJ0?ooo`030000003oool0oooo0340oooo001:0?ooo`030000003oool0oooo0180
oooo00<0o`000?ooo`3oool0o`3ooolL0?ooo`030000003oool0oooo0300oooo001:0?ooo`030000
003oool0oooo0140oooo00<0o`000?ooo`3oool0o`3ooolN0?ooo`030000003oool0oooo02l0oooo
001:0?ooo`030000003oool0oooo0100oooo00<000000?l0003oool0o`3ooolP0?ooo`030000003o
ool0oooo02h0oooo001:0?ooo`030000003oool0oooo00l0oooo00<000000?l0003oool0o`3ooolR
0?ooo`030000003oool0oooo02d0oooo001:0?ooo`030000003oool0oooo00l0oooo00<0o`000?oo
o`3oool0o`3ooolR0?ooo`030000003oool0oooo02d0oooo001:0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo02`0oooo001:0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`030000003oool0oooo02/0oooo
001:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`030000003o
ool0oooo02X0oooo001:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooolZ
0?ooo`030000003oool0oooo02T0oooo001:0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0o`3oool/0?ooo`030000003oool0oooo02P0oooo001:0?ooo`030000003oool0oooo00T0
oooo00<000000?l0003oool0o`3oool^0?ooo`030000003oool0oooo02L0oooo001:0?ooo`030000
003oool0oooo00P0oooo00<000000?l0003oool0o`3oool`0?ooo`030000003oool0oooo02H0oooo
001:0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool0o`3oool`0?ooo`030000003o
ool0oooo02H0oooo001:0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool0o`3ooolb
0?ooo`030000003oool0oooo02D0oooo001:0?ooo`030000003oool0oooo00H0oooo00<0o`000?oo
o`3oool0o`3ooold0?ooo`030000003oool0oooo02@0oooo001:0?ooo`030000003oool0oooo00D0
oooo00<0o`000?ooo`3oool0o`3ooolf0?ooo`030000003oool0oooo02<0oooo001:0?ooo`030000
003oool0oooo0?l0oooo?`3oool00`000000oooo0?ooo`0R0?ooo`00BP3oool200000?l0oooo@@3o
ool00`000000oooo0?ooo`0Q0?ooo`00BP3oool00`000000oooo0?ooo`3o0?oood40oooo00<00000
0?ooo`3oool0803oool004X0oooo00<000000?ooo`3oool0o`3ooom20?ooo`030000003oool0oooo
01l0oooo001:0?ooo`030000003oool0oooo0?l0oooo@`3oool00`000000oooo0?ooo`0N0?ooo`00
BP3oool00`000000oooo0?ooo`3o0?oood@0oooo00<000000?ooo`3oool07@3oool004X0oooo00<0
00000?ooo`3oool0o`3ooom50?ooo`030000003oool0oooo01`0oooo001:0?ooo`800000o`3ooom7
0?ooo`030000003oool0oooo01/0oooo001:0?ooo`030000003oool0oooo0?l0ooooAP3oool00`00
0000oooo0?ooo`0K0?ooo`00BP3oool00`000000oooo0?ooo`3o0?ooodL0oooo00<000000?ooo`3o
ool06P3oool004X0oooo00<000000?ooo`3oool0o`3ooom80?ooo`030000003oool0oooo01T0oooo
001:0?ooo`800000o`3ooom:0?ooo`030000003oool0oooo01P0oooo001:0?ooo`030000003oool0
oooo0?l0ooooBP3oool00`000000oooo0?ooo`0G0?ooo`00BP3oool200000?l0ooooC03oool00`00
0000oooo0?ooo`0F0?ooo`00BP3oool00`000000oooo0?ooo`3o0?oood`0oooo00<000000?ooo`3o
ool05@3oool004X0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`030000003oool0oooo01@0oooo
001:0?ooo`800000o`3ooom?0?ooo`030000003oool0oooo01<0oooo001:0?ooo`800000o`3ooom@
0?ooo`030000003oool0oooo0180oooo000a0?ooo`030?noM0000000000000<0000000D007Bo0?oo
o`3oool0oooo0?noM0030000000307Boo`3oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooom?
0?ooo`030000003oool0oooo0180oooo000d0?ooo`0309a8B02Lgol0oooo00@0oooo00H0W4Qd0;oo
o`3oool0oono07@0M02oool90?ooo`800000o`3ooomA0?ooo`030000003oool0oooo0140oooo000d
0?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`08
0?ooo`800000o`3ooomB0?ooo`030000003oool0oooo0100oooo000d0?ooo`0309a8B02Lgol0oooo
00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`080?ooo`<00000o`3ooomB0?oo
o`030000003oool0oooo00l0oooo000d0?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3o
ool00P3oool00`3o_g@007Bo0?ooo`3o0?ooofl0oooo000d0?ooo`0309a8B02Lgol0oooo00<0oooo
00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`3o0?ooofl0oooo000d0?ooo`0309a8B02L
gol0oooo00<0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`3o0?ooofl0oooo000a
0?ooo`050=nLB000000004RL09a8B02Lgol01@3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooool0
ooooL03oool003<0oooo00<0gia80000B02Lgol01@3oool01@3ookl0M0000000000004P0W=oo0?l0
ooooL@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.486801, -10.2224, \
0.00882882, 0.0680253}}]
}, Closed]],

Cell["or by increasing the accuracy goal", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DisplayTogether[
        LogPlot[Evaluate[
            Abs[stiffSol[20, 10, AccuracyGoal \[Rule] 10, 
                WorkingPrecision \[Rule] 20]]], {x, 0, 10}, 
          PlotRange \[Rule] {Automatic, {10\^\(-30\), 10\^1}}], 
        LogPlot[Evaluate[trueSol[20]], {x, 0, 10}, 
          PlotStyle \[Rule] {{RGBColor[1, 0, 0], 
                Dashing[{0.02, 0.02}]}}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.598097 0.0199366 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[-0.0125 0 -50.6875 -6.6875 ]
[-0.0125 0 0 6.6875 ]
[-0.0125 .11962 -50.6875 -6.6875 ]
[-0.0125 .11962 0 6.6875 ]
[-0.0125 .23924 -50.6875 -6.6875 ]
[-0.0125 .23924 0 6.6875 ]
[-0.0125 .35886 -50.6875 -6.6875 ]
[-0.0125 .35886 0 6.6875 ]
[-0.0125 .47848 -46.5 -6.6875 ]
[-0.0125 .47848 0 6.6875 ]
[-0.0125 .5981 -10 -6.28125 ]
[-0.0125 .5981 0 6.28125 ]
[ -0.0005 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
.00625 0 L
s
gsave
-0.0125 0 -111.688 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
109.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11962 m
.00625 .11962 L
s
gsave
-0.0125 .11962 -111.688 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
109.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .23924 m
.00625 .23924 L
s
gsave
-0.0125 .23924 -111.688 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18) show
109.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .35886 m
.00625 .35886 L
s
gsave
-0.0125 .35886 -111.688 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
109.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .47848 m
.00625 .47848 L
s
gsave
-0.0125 .47848 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .5981 m
.00625 .5981 L
s
gsave
-0.0125 .5981 -71 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .1006 m
.00375 .1006 L
s
0 .1066 m
.00375 .1066 L
s
0 .11011 m
.00375 .11011 L
s
0 .1126 m
.00375 .1126 L
s
0 .11453 m
.00375 .11453 L
s
0 .11611 m
.00375 .11611 L
s
0 .11744 m
.00375 .11744 L
s
0 .1186 m
.00375 .1186 L
s
0 .22021 m
.00375 .22021 L
s
0 .22622 m
.00375 .22622 L
s
0 .22973 m
.00375 .22973 L
s
0 .23222 m
.00375 .23222 L
s
0 .23415 m
.00375 .23415 L
s
0 .23573 m
.00375 .23573 L
s
0 .23706 m
.00375 .23706 L
s
0 .23822 m
.00375 .23822 L
s
0 .33983 m
.00375 .33983 L
s
0 .34584 m
.00375 .34584 L
s
0 .34935 m
.00375 .34935 L
s
0 .35184 m
.00375 .35184 L
s
0 .35377 m
.00375 .35377 L
s
0 .35535 m
.00375 .35535 L
s
0 .35668 m
.00375 .35668 L
s
0 .35784 m
.00375 .35784 L
s
0 .45945 m
.00375 .45945 L
s
0 .46546 m
.00375 .46546 L
s
0 .46897 m
.00375 .46897 L
s
0 .47146 m
.00375 .47146 L
s
0 .47339 m
.00375 .47339 L
s
0 .47497 m
.00375 .47497 L
s
0 .4763 m
.00375 .4763 L
s
0 .47746 m
.00375 .47746 L
s
0 .57907 m
.00375 .57907 L
s
0 .58507 m
.00375 .58507 L
s
0 .58859 m
.00375 .58859 L
s
0 .59108 m
.00375 .59108 L
s
0 .59301 m
.00375 .59301 L
s
0 .59459 m
.00375 .59459 L
s
0 .59592 m
.00375 .59592 L
s
0 .59708 m
.00375 .59708 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .5981 m
.06244 .52785 L
.10458 .45124 L
.12507 .41399 L
.14415 .37923 L
.1536 .36219 L
.16254 .3465 L
.16748 .3357 L
.16818 .33202 L
.16883 .32559 L
.16951 .31158 L
.17026 .32936 L
.1715 .33696 L
.1722 .33924 L
.17284 .34074 L
.17403 .34254 L
.17513 .34331 L
.17635 .34333 L
.17764 .34243 L
.17887 .34073 L
.18004 .33866 L
.18117 .33677 L
.18221 .33555 L
.18337 .33509 L
.18462 .33563 L
.18577 .33667 L
.18686 .33775 L
.18813 .33878 L
.18931 .33934 L
.1906 .3394 L
.19125 .33918 L
.19197 .33871 L
.19262 .33809 L
.19331 .33723 L
.19453 .33521 L
.19596 .33265 L
.19729 .33053 L
.19844 .32913 L
.19968 .32823 L
.20038 .32799 L
.20104 .3279 L
.20229 .32796 L
.20335 .32806 L
.20453 .32803 L
.20575 .32766 L
.2069 .3269 L
.20797 .32573 L
.20895 .32427 L
.21115 .32031 L
.21229 .31837 L
Mistroke
.21351 .31664 L
.21421 .3159 L
.21484 .31543 L
.21608 .31517 L
.21724 .31565 L
.21849 .31676 L
.22076 .31949 L
.22536 .32487 L
.23029 .32902 L
.23312 .33076 L
.2357 .33202 L
.23814 .33298 L
.24074 .33378 L
.24343 .3344 L
.24593 .33481 L
.24731 .33498 L
.24861 .33509 L
.24935 .33514 L
.25003 .33518 L
.25078 .33521 L
.25157 .33522 L
.2528 .33522 L
.25411 .33519 L
.25534 .33513 L
.25646 .33505 L
.25779 .33493 L
.25922 .33476 L
.26181 .33434 L
.26418 .33386 L
.26672 .33321 L
.2713 .3317 L
.27675 .32928 L
.28173 .32634 L
.2869 .32235 L
.29254 .31654 L
.29786 .30914 L
.30279 .30056 L
.30504 .29646 L
.30741 .29236 L
.30865 .29063 L
.30935 .28991 L
.31001 .28945 L
.31116 .2892 L
.3124 .28968 L
.31356 .29068 L
.31483 .2921 L
.31713 .29494 L
.32143 .29962 L
.32663 .30362 L
.32925 .30508 L
Mistroke
.33214 .30635 L
.3346 .3072 L
.33724 .30791 L
.33852 .30818 L
.33974 .3084 L
.34202 .30872 L
.34327 .30884 L
.34392 .30889 L
.34461 .30894 L
.34588 .30899 L
.34705 .30901 L
.34818 .30901 L
.34923 .30898 L
.35038 .30893 L
.35162 .30884 L
.35293 .30871 L
.35436 .30854 L
.35696 .30813 L
.3595 .3076 L
.36184 .307 L
.36608 .30563 L
.37076 .30364 L
.37565 .30093 L
.38023 .29767 L
.38483 .2935 L
.38917 .28848 L
.39418 .28103 L
.39872 .27289 L
.40117 .26841 L
.4025 .26607 L
.40375 .26419 L
.4044 .26342 L
.4051 .26281 L
.40588 .26245 L
.40659 .26241 L
.40723 .2626 L
.40793 .26303 L
.4092 .26424 L
.41431 .27048 L
.41894 .27492 L
.42154 .27679 L
.42398 .27822 L
.42678 .27953 L
.42935 .28048 L
.43161 .28114 L
.43399 .28168 L
.43638 .28207 L
.43773 .28223 L
.43899 .28235 L
.44031 .28243 L
Mistroke
.44105 .28246 L
.44174 .28248 L
.443 .28249 L
.44363 .28248 L
.44433 .28247 L
.44554 .28241 L
.44684 .28233 L
.44807 .28221 L
.44919 .28209 L
.45186 .28169 L
.45478 .28109 L
.4601 .27958 L
.46541 .27744 L
.47041 .27476 L
.4749 .27166 L
.47976 .26738 L
.48507 .2612 L
.49068 .25249 L
.49594 .24298 L
.49715 .24086 L
.49843 .23884 L
.49952 .2375 L
.50073 .23665 L
.50193 .23657 L
.50306 .23714 L
.50428 .23826 L
.5056 .23978 L
.5102 .24524 L
.51278 .24773 L
.5155 .24987 L
.51785 .25137 L
.52036 .25269 L
.52274 .2537 L
.52489 .25445 L
.52709 .25506 L
.52911 .2555 L
.53148 .25589 L
.53272 .25604 L
.53404 .25616 L
.53518 .25624 L
.53625 .25629 L
.53743 .25631 L
.53869 .2563 L
.53938 .25629 L
.54003 .25626 L
.54124 .2562 L
.54254 .2561 L
.54394 .25595 L
.54648 .25559 L
.54882 .25515 L
Mistroke
.55419 .25374 L
.55689 .2528 L
.55986 .25157 L
.56488 .24898 L
.57026 .24531 L
.57533 .24076 L
.57996 .23537 L
.58923 .22011 L
.59148 .21597 L
.59267 .21386 L
.59391 .21188 L
.59457 .211 L
.5953 .21026 L
.59657 .20963 L
.59787 .2099 L
.59907 .21083 L
.60429 .21714 L
.60716 .22018 L
.60986 .22251 L
.61238 .22427 L
.61509 .2258 L
.61984 .22774 L
.62221 .22843 L
.62474 .22899 L
.62597 .2292 L
.62714 .22937 L
.62818 .22949 L
.62933 .2296 L
.63058 .22968 L
.63127 .22971 L
.63192 .22973 L
.63307 .22975 L
.63431 .22974 L
.63497 .22972 L
.63569 .22969 L
.63645 .22965 L
.63715 .2296 L
.6384 .22949 L
.63975 .22934 L
.64246 .22893 L
.64541 .22832 L
.65077 .22677 L
.65599 .22466 L
.6608 .22208 L
.66582 .21859 L
.67059 .21429 L
.67609 .20773 L
.68112 .19983 L
.68553 .19186 L
.68795 .18761 L
Mistroke
.68913 .18583 L
.69023 .18461 L
.69152 .18389 L
.69221 .18387 L
.69293 .18411 L
.69409 .18495 L
.69538 .18629 L
.70016 .192 L
.7027 .19454 L
.7051 .19654 L
.70961 .19939 L
.71213 .20057 L
.71446 .20146 L
.71701 .20222 L
.71973 .20283 L
.72189 .20318 L
.7231 .20333 L
.72421 .20344 L
.72519 .20351 L
.72626 .20357 L
.72738 .2036 L
.72842 .20361 L
.72967 .20359 L
.73084 .20355 L
.7319 .20348 L
.73305 .20339 L
.7343 .20326 L
.73563 .20309 L
.738 .2027 L
.74053 .20217 L
.74293 .20155 L
.74744 .20006 L
.75229 .19793 L
.75758 .19488 L
.76218 .19143 L
.76709 .18669 L
.77171 .1809 L
.7759 .17429 L
.78079 .16538 L
.78346 .16057 L
.78476 .1586 L
.78595 .15735 L
.78704 .15685 L
.78808 .15699 L
.78917 .15769 L
.79036 .15889 L
.79519 .16485 L
.80044 .16983 L
.80309 .17166 L
.80602 .17326 L
Mistroke
.8085 .17434 L
.81118 .17526 L
.81371 .17593 L
.81602 .17638 L
.81731 .17658 L
.81852 .17673 L
.8196 .17683 L
.82078 .17692 L
.82206 .17698 L
.82271 .177 L
.82342 .17701 L
.82468 .177 L
.82586 .17696 L
.82704 .1769 L
.82816 .17681 L
.83026 .17659 L
.83253 .17626 L
.83499 .17578 L
.8402 .17438 L
.84284 .17346 L
.84575 .17225 L
.85088 .16958 L
.85571 .16631 L
.89437 .13613 L
.89551 .13661 L
.89671 .13702 L
.89803 .13736 L
.89925 .13758 L
.90038 .1377 L
.90144 .13774 L
.90261 .13772 L
.90386 .1376 L
.90454 .1375 L
.90528 .13736 L
.90663 .13703 L
.90795 .1366 L
.90917 .13611 L
.91151 .13492 L
.914 .13325 L
.91701 .13063 L
.91984 .12744 L
.92513 .11929 L
.92755 .11484 L
.9301 .11051 L
.93075 .10963 L
.93144 .10884 L
.9322 .10818 L
.93291 .10779 L
.9336 .10762 L
.93426 .10764 L
Mistroke
.93548 .10807 L
.94023 .11165 L
.94256 .11329 L
.94469 .11446 L
.94692 .11534 L
.9481 .11567 L
.94933 .11591 L
.9506 .11607 L
.95178 .11612 L
.95308 .11609 L
.9538 .11602 L
.95446 .11594 L
.95513 .11583 L
.95584 .11569 L
.95711 .11536 L
.95847 .11489 L
.95997 .11426 L
.96266 .11276 L
.96518 .1109 L
.96995 .10594 L
.97264 .10217 L
.97508 .0981 L
.97619 .09613 L
Mfstroke
1 0 0 r
[ .02 .02 ] 0 setdash
.02381 .5981 m
.06244 .52785 L
.10458 .45124 L
.14415 .37928 L
.18221 .31009 L
.22272 .23643 L
.26171 .16553 L
.30316 .09018 L
.34309 .01757 L
s
.34309 .01757 m
.35275 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00EP3oool01@3o_g@00000000000000000M;oo03/0oooo00<0oono07@00000000010000000
0`1d_ol0oooo0?ooo`0l0?ooo`050?oOW018000000000000001d_ol0?P3oool01@2oM00000000000
000007@0_ooo03`0oooo00D0_g@00000000000000000001d_`0i0?ooo`030?noM0000000000000<0
000000D007Bo0?ooo`3oool0oooo0?noM0030000000307Boo`3oool0oooo0040oooo001F0?ooo`06
09a8M02oool0oooo0?oo_`1d07@0_ooo>`3oool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0
oooo03l0oooo00<0_g@007Boo`3oool0?@3oool01P3OW4P007Bo0?ooo`3oool0okmd001d_c/0oooo
00<0okmd001d_`3oool00P3oool00`2oM4P0W=oo0?ooo`0j0?ooo`0309a8B02Lgol0oooo00@0oooo
00H0W4Qd0;ooo`3oool0oono07@0M02oool20?ooo`00E@3oool00`3o_g@007Bo0?ooo`020?ooo`03
0=nLB018W=l0oooo03/0oooo00<0okmd0000B02Lgol0@`3oool00`2oM000M;oo0?ooo`0l0?ooo`03
0?oo_`1d0000M;oo0080oooo00<0oono07A8W03oool0>P3oool00`3OW4P0B9cO0?ooo`020?ooo`03
0;md001d_ol0oooo03X0oooo00<0W4Q809cOo`3oool00`3oool00`3o_g@007Bo0?ooo`020?ooo`03
0=nLB018W=l0oooo0040oooo001E0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0
?03oool00`3ogi`0B00004RLg`0n0?ooo`030=nLB0000000000000<0000000<0M;oo0?ooo`3oool0
>P3oool01`3o_g@004Q807@0M02oool0oooo0=nLB000M;l0>`3oool00`3o_g@004RL0?ooo`020?oo
o`0309a8B02Lgol0oooo03X0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`020?oo
o`030?noM000M;l0oooo0040oooo001E0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3o
ool0?P3oool00`2LB000B9cO0?ooo`0l0?ooo`060?noM00007@0_ooo0?ooo`2oM000M;oo?@3oool0
0`3ogi`0B4RL0?noM002000000030018W03oool0oooo03/0oooo00D0gia8000000000000000004RL
g`0l0?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?oo
o`010?ooo`00E@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo03l0oooo00<0W4Qd
0;ooo`3oool0?03oool01@3OW4P007Bo0?ooo`2oM000M;oo03d0oooo00<0oono07@0M02oool0?`3o
ool00`3ookl0M4RL0?ooo`020?ooo`0309a8M02oool0oooo03X0oooo00<0W4Q809cOo`3oool00`3o
ool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo0040oooo001E0?ooo`030?noM018W=l0
oooo0080oooo00<0gia804RLg`3oool0>P3oool00`3OW4P0M;oo0?ooo`020?ooo`030;md001d_ol0
oooo03d0oooo00@0W4P004RLg`2oM000M;oo?P3oool00`2oM000B9cO0?ooo`0n0?ooo`030?noM018
W=l0oooo0080oooo00<0_g@007Boo`3oool0>P3oool00`2LB4P0W=oo0?ooo`030?ooo`030?noM018
W=l0oooo0080oooo00<0gia804RLg`3oool00@3oool005H0oooo00H0W4P007Boo`3oool0omnL04P0
M02ooolk0?ooo`070?noM00007@0_ooo0?ooo`3o_g@0001809cOo`0n0?ooo`040?oOW01804P0B4P0
07Booch0oooo00<0oono07@00000M;l0?P3oool01`3ogi`0B01d0;ooo`3oool0omnL04P0M02oool0
>03oool01@3OW4P000000018W02LB4P0W=oo00D0oooo00H0W4P007Boo`3oool0omnL04P0M02oool2
0?ooo`00EP3oool01@3ookl0M0000000000004P0W=oo03d0oooo00D0okmd000000000000001809cO
o`100?ooo`030?noM0000000M;oo0400oooo00@0_g@000000000000004RL?03oool01@3o_g@00000
0000000004P0W=oo03/0oooo00<0gia80000B02Lgol01@3oool01@3ookl0M0000000000004P0W=oo
00<0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo00040?oo
o`030?noM0000000000000<0000000<007Bo0?ooo`3oool00P3oool00`2oM0000000001d_`060?oo
o`030;mdB02Lgol0oooo0080oooo00<0oono07A8W03Oool0103oool00`3o_g@00000000000030000
0005001d_`3oool0oooo0?ooo`3o_g@00`0000000`1d_ol0oooo0?ooo`3o0?ooog`0oooo00070?oo
o`0309a8B02Lgol0oooo00D0oooo00<0_g@000000000M;l01P3oool01`3ooml0W4Q809cOo`3oool0
oono07@0M02oool0203oool00`2LB4P0W=oo0?ooo`040?ooo`0609a8M02oool0oooo0?oo_`1d07@0
_oooo`3ooomm0?ooo`001`3oool00`2LB4P0W=oo0?ooo`0?0?ooo`050?oog`2LB7@0_ooO09a8M02o
ool02@3oool00`2LB4P0W=oo0?ooo`030?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3o
ool0o`3oooml0?ooo`001`3oool00`2LB4P0W=oo0?ooo`0@0?ooo`030?oo_`1d04P0W=oo00X0oooo
00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo01/0oooo
N`0000000`3o000000000000003Q00000040oooo00070?ooo`0309a8B02Lgol0oooo00l0oooo00D0
oono07@0M02ooml0W4Q809cOo`090?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool0
0P3oool00`3o_g@007Bo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
2`3oool0103o0000oooo0?ooo`00000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00070?ooo`0309a8
B02Lgol0oooo00h0oooo00L0oono07@0M02oool0oooo0?oog`2LB4P0W=oo00P0oooo00<0W4Q809cO
o`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo01/0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo02`0oooo00<0o`000?oo
o`3oool04@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`070?ooo`001`3oool00`2LB4P0W=oo0?ooo`0>0?ooo`03
0;mdM02oool0oooo0080oooo00<0oooO09adW03Oool01`3oool00`2LB4P0W=oo0?ooo`030?ooo`03
0?noM018W=l0oooo0080oooo00<0gia804RLg`3oool01`3oool01@3o_g@000000000000004P0W=oo
0080oooo00D0omnL04P000000000001809cOo`080?ooo`030000003oool0oooo07H0oooo00<0o`00
0?ooo`3oool0i03oool000@0oooo00D0gia800000000B9`0W4Q809cOo`0K0?ooo`050=nLB0000000
04RL09a8B02Lgol01@3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`L0oooo00d0omnL04P0M02o
ool0oooo0?oOW01807@0_ooo0?ooo`3OW7@0W=oo0?ooo`3ogi`0B7Bo00P0oooo00<000000?ooo`3o
ool0MP3oool00`3o0000oooo0?ooo`3T0?ooo`001P3oool00`3OW4P0001809cOo`0M0?ooo`030=nL
B00004P0W=oo00D0oooo00D0oono07@000000000001809cOo`020?ooo`030?oog`2LB00000000080
000000<0B9cO0?ooo`3oool00P3oool02@3o_g@004RL0?ooo`3oool0W4Qd0;ooo`3oool0oono07A8
W0080?ooo`030000003oool0oooo07D0oooo00<0o`000?ooo`3oool0i@3oool003d0oooo00@0gia8
0000000007@0_ooo0P3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`L0oooo00<000000?ooo`3o
ool0M@3oool00`3o0000oooo0?ooo`3U0?ooo`00?`3oool02@3o_g@007Bo0?ooo`3oool0W4Qd0;oo
o`3oool0oono07A8W0080?ooo`030000003oool0oooo07D0oooo00<0o`000?ooo`3oool0i@3oool0
03`0oooo00D0W4P004RLg`3oool0okmd001d_`020?ooo`050=nLB018W=l0oooo0?noM000M;l0203o
ool00`000000oooo0?ooo`1d0?ooo`030?l0003oool0oooo0>H0oooo000m0?ooo`0409a800000000
001d0;ooo`<0oooo00@0W4P00000000007@0_ooo203oool00`000000oooo0?ooo`1d0?ooo`030?l0
003oool0oooo0>H0oooo001@0?ooo`030000003oool0oooo07<0oooo00<0o`000?ooo`3oool0i`3o
ool00500oooo00<000000?ooo`3oool0LP3oool00`3o0000oooo0?ooo`3X0?ooo`00D03oool00`00
0000oooo0?ooo`1b0?ooo`030?l0003oool0oooo0>P0oooo001@0?ooo`030000003oool0oooo0740
oooo00<0o`000?ooo`3oool0j@3oool00500oooo00<000000?ooo`3oool0o`3ooomN0?ooo`00D03o
ool00`000000oooo0?ooo`3o0?oooeh0oooo001@0?ooo`030000003oool0oooo0?l0ooooGP3oool0
0500oooo00<000000?ooo`3oool0o`3ooomN0?ooo`00D03oool00`000000oooo0?ooo`3o0?oooeh0
oooo001@0?ooo`030000003oool0oooo06h0oooo00<0o`000?ooo`3oool0k03oool00500oooo00<0
00000?ooo`3oool0K@3oool00`3o0000oooo0?ooo`3]0?ooo`00D03oool00`000000oooo0?ooo`1]
0?ooo`030?l0003oool0oooo0>d0oooo001@0?ooo`030000003oool0oooo06`0oooo00<0o`000?oo
o`3oool0kP3oool00500oooo00<000000?ooo`3oool0J`3oool00`3o0000oooo0?ooo`3_0?ooo`00
D03oool00`000000oooo0?ooo`1[0?ooo`030?l0003oool0oooo0>l0oooo001@0?ooo`030000003o
ool0oooo06X0oooo00<0o`000?ooo`3oool0l03oool00500oooo00<000000?ooo`3oool0o`3ooomN
0?ooo`00D03oool00`000000oooo0?ooo`3o0?oooeh0oooo001@0?ooo`030000003oool0oooo0?l0
ooooGP3oool00500oooo00<000000?ooo`3oool0o`3ooomN0?ooo`00D03oool00`000000oooo0?oo
o`3o0?oooeh0oooo001@0?ooo`030000003oool0oooo0?l0ooooGP3oool00500oooo00<000000?oo
o`3oool0I`3oool00`3o0000oooo0?ooo`3c0?ooo`00D03oool00`000000oooo0?ooo`1V0?ooo`03
0?l0003oool0oooo0?@0oooo001@0?ooo`030000003oool0oooo06H0oooo00<0o`000?ooo`3oool0
j@3oool2000000T0oooo001@0?ooo`800000IP3oool00`3o0000oooo0?ooo`3Y0?ooo`030000003o
ool0oooo00T0oooo001@0?ooo`030000003oool0oooo06D0oooo00<0o`000?ooo`3oool0j@3oool0
0`000000oooo0?ooo`090?ooo`00D03oool2000006D0oooo00<0o`000?ooo`3oool0j@3oool00`00
0000oooo0?ooo`0:0?ooo`00D03oool00`000000oooo0?ooo`1T0?ooo`030?l0003oool0oooo0=`0
oooo0P00000:0?ooo`030000003oool0oooo00/0oooo00040?ooo`030?noM0000000000000<00000
00<007Bo0?ooo`3oool00P3oool00`2oM0000000001d_`060?ooo`030;mdB02Lgol0oooo0080oooo
00<0oono07A8W03Oool0103oool00`3o_g@000000000000300000005001d_`3oool0oooo0?ooo`3o
_g@00`0000000`1d_ol0oooo0?ooo`0K0?ooo`800000o`3ooom40?ooo`80000000<0oooo00000000
0000203oool00`000000oooo0?ooo`0;0?ooo`001`3oool00`2LB4P0W=oo0?ooo`050?ooo`030;md
0000000007Bo00H0oooo00L0oooO09a8B02Lgol0oooo0?oo_`1d07@0_ooo00P0oooo00<0W4Q809cO
o`3oool0103oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;oooa`0oooo0P00003o0?oood<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000003P3oool000L0oooo00<0W4Q8
09cOo`3oool03`3oool01@3ooml0W4Qd0;oog`2LB7@0_ooo00T0oooo00<0W4Q809cOo`3oool00`3o
ool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo01/0oooo0P00003o0?oood<0oooo00<0
00000?ooo`3oool0103oool500000100oooo00070?ooo`0309a8B02Lgol0oooo0100oooo00<0oono
07@0B02Lgol02P3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0okmd
001d_`3oool06`3oool300000?l0oooo@P3oool00`000000oooo0?ooo`0I0?ooo`001`3oool00`2L
B4P0W=oo0?ooo`0?0?ooo`050?oo_`1d07@0_ooO09a8B02Lgol02@3oool00`2LB4P0W=oo0?ooo`03
0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool06`3oool00`000000oooo0?ooo`3o
0?oood40oooo00<000000?ooo`3oool06P3oool000L0oooo00<0W4Q809cOo`3oool03P3oool01`3o
okl0M01d0;ooo`3oool0oooO09a8B02Lgol0203oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018
W=l0oooo0080oooo00<0okmd001d_`3oool06`3oool00`000000oooo0?ooo`1P0?ooo`030?l0003o
ool0oooo0=d0oooo00<000000?ooo`3oool06P3oool000L0oooo00<0W4Q809cOo`3oool03P3oool0
0`2oM7@0_ooo0?ooo`020?ooo`030?oog`2LM9`0gooo00L0oooo00<0W4Q809cOo`3oool00`3oool0
0`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00H0oooo00<0omnL04P0000000000P000000
2018W=l0oooo0?ooo`3oool0oono07@00000000004RL203oool00`000000oooo0?ooo`1O0?ooo`03
0?l0003oool0oooo0=d0oooo00<000000?ooo`3oool06`3oool000@0oooo00D0gia800000000B9`0
W4Q809cOo`0K0?ooo`050=nLB000000004RL09a8B02Lgol01@3oool01P2LB000M;oo0?ooo`3ogi`0
B01d0;ooo`P0oooo00<0W4P00018W03oool01`3oool00`2LB7@0_ooo0?ooo`070?ooo`030000003o
ool0oooo05l0oooo00<0o`000?ooo`3oool0g03oool00`000000oooo0?ooo`0L0?ooo`001P3oool0
0`3OW4P0001809cOo`0M0?ooo`030=nLB00004P0W=oo00D0oooo00D0oono07@000000000001809cO
o`020?ooo`030?oog`2LB00000000080000000H0B9cO0?ooo`3oool0gia80000M02oool30?ooo`05
09a800000000000000000000M;l0203oool00`000000oooo0?ooo`1N0?ooo`030?l0003oool0oooo
0=/0oooo0P00000O0?ooo`00?P3oool00`3o_g@0001d0;ooo`020?ooo`050;md001d_ol0oooo09a8
M02oool0203oool00`000000oooo0?ooo`1N0?ooo`030?l0003oool0oooo0=D0oooo1P00000Q0?oo
o`00?`3oool02@3o_kl0_ooo0?ooo`3oool0oono07@0M02oool0W4Qd0;ooo`080?ooo`030000003o
ool0oooo05d0oooo00<0o`000?ooo`3oool0e03oool2000002L0oooo000k0?ooo`060?oo_`1d07@0
_ooo0?ooo`2oM000B9cO0`3oool0103o_g@004RL09a8M02oool80?ooo`030000003oool0oooo05d0
oooo00<0o`000?ooo`3oool0d`3oool00`000000oooo0?ooo`0W0?ooo`00?03oool0103o_g@00000
00000000B9`50?ooo`030=nLB00007@0_ooo00P0oooo00<000000?ooo`3oool0o`3ooolc0?ooo`03
0000003oool0oooo02P0oooo001@0?ooo`030000003oool0oooo0?l0oooo<@3oool2000002/0oooo
001@0?ooo`030000003oool0oooo0?l0oooo<03oool00`000000oooo0?ooo`0[0?ooo`00D03oool0
0`000000oooo0?ooo`3o0?ooobh0oooo0P00000^0?ooo`00D03oool00`000000oooo0?ooo`3o0?oo
oa40oooo0P00000J0?ooo`030000003oool0oooo02h0oooo001@0?ooo`030000003oool0oooo05X0
oooo00<0o`000?ooo`3oool0/P3oool3000001T0oooo00<000000?ooo`3oool0;`3oool00500oooo
00<000000?ooo`3oool0F@3oool00`3o0000oooo0?ooo`2b0?ooo`050000003oool0oooo0?ooo`00
00005P3oool200000380oooo001@0?ooo`030000003oool0oooo05P0oooo00<0o`000?ooo`3oool0
/`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
<P3oool00500oooo00<000000?ooo`3oool0E`3oool00`3o0000oooo0?ooo`2c0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0c0?ooo`00D03oool0
0`000000oooo0?ooo`1G0?ooo`030?l0003oool0oooo0;<0oooo00<000000?ooo`3oool01@3oool2
000000h0oooo0P00000f0?ooo`00D03oool00`000000oooo0?ooo`1F0?ooo`030?l0003oool0oooo
0;<0oooo00<000000?ooo`3oool0203oool3000000T0oooo0P00000h0?ooo`00D03oool00`000000
oooo0?ooo`1F0?ooo`030?l0003oool0oooo0;80oooo00<000000?ooo`3oool0303oool9000003X0
oooo001@0?ooo`030000003oool0oooo0?l0oooo303oool00`000000oooo0?ooo`1?0?ooo`00D03o
ool00`000000oooo0?ooo`3_0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0D03o
ool00500oooo00<000000?ooo`3oool0kP3oool3000001P0oooo00<000000?ooo`3oool0D@3oool0
0500oooo00<000000?ooo`3oool0kP3oool010000000oooo0?ooo`00000F0?ooo`030000003oool0
oooo0580oooo001@0?ooo`030000003oool0oooo0>d0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo0580oooo001@0?ooo`030000003oool0oooo05<0
oooo00<0o`000?ooo`3oool0UP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0100
oooo0P00001E0?ooo`00D03oool00`000000oooo0?ooo`1B0?ooo`030?l0003oool0oooo09L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`800000E`3oool00500oooo00<0
00000?ooo`3oool0DP3oool00`3o0000oooo0?ooo`2F0?ooo`030000003oool0oooo00L0oooo0P00
000;0?ooo`800000F@3oool00500oooo00<000000?ooo`3oool0D@3oool00`3o0000oooo0?ooo`2F
0?ooo`030000003oool0oooo00X0oooo2`00001K0?ooo`00D03oool00`000000oooo0?ooo`1A0?oo
o`030?l0003oool0oooo09H0oooo00<000000?ooo`3oool0L03oool00500oooo00<000000?ooo`3o
ool0D03oool00`3o0000oooo0?ooo`1k0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0L@3oool00500oooo00<000000?ooo`3oool0D03oool00`3o0000oooo0?ooo`1j0?ooo`<00000
603oool00`000000oooo0?ooo`1b0?ooo`00D03oool00`000000oooo0?ooo`1?0?ooo`030?l0003o
ool0oooo07X0oooo00@000000?ooo`3oool00000603oool00`000000oooo0?ooo`1b0?ooo`00D03o
ool00`000000oooo0?ooo`3<0?ooo`050000003oool0oooo0?ooo`0000005P3oool00`000000oooo
0?ooo`1c0?ooo`00D03oool200000<`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo07@0oooo001@0?ooo`030000003oool0oooo0<X0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`800000M`3oool00500oooo0P00003;0?oo
o`030000003oool0oooo00H0oooo0P00000<0?ooo`<00000N@3oool000@0oooo00<0okmd00000000
00000`0000000`00M;l0oooo0?ooo`020?ooo`030;md0000000007Bo00H0oooo00<0_gA809cOo`3o
ool00P3oool00`3ookl0M4RL0=ooo`040?ooo`030?noM0000000000000<0000000D007Bo0?ooo`3o
ool0oooo0?noM0030000000307Boo`3oool0oooo01/0oooo00<000000?ooo`3oool0b@3oool00`00
0000oooo0?ooo`090?ooo`D000000P3oool5000007`0oooo00070?ooo`0309a8B02Lgol0oooo00D0
oooo00<0_g@000000000M;l01P3oool01`3ooml0W4Q809cOo`3oool0oono07@0M02oool0203oool0
0`2LB4P0W=oo0?ooo`040?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo703oool2000004d0oooo
00<0o`000?ooo`3oool0NP3oool00`000000oooo0?ooo`0>0?ooo`<00000P03oool000L0oooo00<0
W4Q809cOo`3oool03`3oool01@3ooml0W4Qd0;oog`2LB7@0_ooo00T0oooo00<0W4Q809cOo`3oool0
0`3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo01/0oooo0P00001<0?ooo`030?l0
003oool0oooo07X0oooo00<000000?ooo`3oool0TP3oool000L0oooo00<0W4Q809cOo`3oool0403o
ool00`3ookl0M01809cOo`0:0?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool00P3o
ool00`3o_g@007Bo0?ooo`0K0?ooo`800000C03oool00`3o0000oooo0?ooo`1N0?ooo`8000006P3o
ool00`000000oooo0?ooo`2B0?ooo`001`3oool00`2LB4P0W=oo0?ooo`0?0?ooo`050?oo_`1d07@0
_ooO09a8B02Lgol02@3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0
okmd001d_`3oool06`3oool3000004X0oooo00<0o`000?ooo`3oool0GP3oool010000000oooo0000
0000000G0?ooo`800000U@3oool000L0oooo00<0W4Q809cOo`3oool03P3oool01`3ookl0M01d0;oo
o`3oool0oooO09a8B02Lgol0203oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080
oooo00<0okmd001d_`3oool06`3oool00`000000oooo0?ooo`1:0?ooo`030?l0003oool0oooo05d0
oooo00D000000?ooo`3oool0oooo0000000F0?ooo`030000003oool0oooo09D0oooo00070?ooo`03
09a8B02Lgol0oooo00h0oooo00<0_gAd0;ooo`3oool00P3oool00`3ooml0W7BL0=ooo`070?ooo`03
09a8B02Lgol0oooo00<0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0K0?ooo`03
0000003oool0oooo04T0oooo00<0o`000?ooo`3oool0GP3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0UP3oool000@0oooo00D0gia800000000B9`0
W4Q809cOo`0K0?ooo`050=nLB000000004RL09a8B02Lgol01@3oool01P2LB000M;oo0?ooo`3ogi`0
B01d0;ooo`P0oooo00P0W4P000000000000000000000M02oool0oooo0=nLB0<0000000<0M;oo0?oo
o`3oool01P3oool00`000000oooo0?ooo`190?ooo`030?l0003oool0oooo05d0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo09L0oooo00060?ooo`03
0=nLB00004P0W=oo01d0oooo00<0gia80000B02Lgol01@3oool01@3ookl0M0000000000004P0W=oo
00/0oooo00<0W4Qd0;ooo`3oool00P3oool01@2LM9`0oooo0?ooo`3ookl0M7Bo00P0oooo00<00000
0?ooo`3oool0Z@3oool00`000000oooo0?ooo`050?ooo`8000003P3oool2000009X0oooo000e0?oo
o`030?oog`2LB00000000080000000H0B9cO0?ooo`3oool0oooo09a8M02oool30?ooo`0509a8M02o
ool0oooo0?oOW018M;l0203oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo00P0oooo
0`0000070?ooo`@00000W03oool003h0oooo00<0W4Qd0;ooo`3oool00P3oool01@3o_g@000000000
000004P0W=oo00P0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0;0?ooo`L00000
X03oool003h0oooo00<0W4Qd0;ooo`3oool00P3oool01@2oM7@0_ooo0?ooo`3ogi`0B7Bo00P0oooo
00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`2c0?ooo`00?03oool0102oM000M;oo09a8
M02oool30?ooo`050;mdB02Lgol0oooo0?noM000M;l0203oool00`000000oooo0?ooo`2:0?ooo`<0
00006P3oool00`000000oooo0?ooo`2c0?ooo`00?03oool0103ookl0M0000000M02oool30?ooo`05
0?oOW018000000000000M02oool0203oool00`000000oooo0?ooo`150?ooo`030?l0003oool0oooo
0480oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`2d0?ooo`00D03oool00`000000
oooo0?ooo`140?ooo`030?l0003oool0oooo0480oooo00D000000?ooo`3oool0oooo0000000G0?oo
o`030000003oool0oooo0;D0oooo001@0?ooo`030000003oool0oooo04@0oooo00<0o`000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0180oooo0P00002h0?ooo`00
D03oool00`000000oooo0?ooo`130?ooo`030?l0003oool0oooo0480oooo00<000000?ooo`3oool0
103oool200000140oooo00<000000?ooo`3oool0^03oool00500oooo00<000000?ooo`3oool0@`3o
ool00`3o0000oooo0?ooo`110?ooo`030000003oool0oooo00H0oooo0P00000>0?ooo`800000^`3o
ool00500oooo00<000000?ooo`3oool0@P3oool00`3o0000oooo0?ooo`120?ooo`030000003oool0
oooo00P0oooo0P00000:0?ooo`800000_@3oool00500oooo00<000000?ooo`3oool0@P3oool00`3o
0000oooo0?ooo`110?ooo`030000003oool0oooo00/0oooo2P00002o0?ooo`00D03oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo0=@0oooo001@0?ooo`030000003oool0oooo06T0oooo
0P00000J0?ooo`030000003oool0oooo0=D0oooo001@0?ooo`030000003oool0oooo06P0oooo1000
000H0?ooo`030000003oool0oooo0=H0oooo001@0?ooo`030000003oool0oooo06P0oooo00D00000
0?ooo`3oool0oooo0000000G0?ooo`030000003oool0oooo0=H0oooo001@0?ooo`030000003oool0
oooo06P0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`800000f@3oool00500oooo00<00000
0?ooo`3oool0?`3oool00`3o0000oooo0?ooo`0U0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0403oool200000=/0oooo001@0?ooo`030000003oool0oooo03h0oooo00<0o`000?oo
o`3oool09@3oool00`000000oooo0?ooo`050?ooo`8000003`3oool00`000000oooo0?ooo`3K0?oo
o`00D03oool00`000000oooo0?ooo`0n0?ooo`030?l0003oool0oooo02D0oooo00<000000?ooo`3o
ool01`3oool2000000/0oooo0P00003N0?ooo`00D03oool00`000000oooo0?ooo`0m0?ooo`030?l0
003oool0oooo02D0oooo00<000000?ooo`3oool02P3oool;00000>00oooo001@0?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0T0?ooo`030000003o
ool0oooo0?H0oooo001@0?ooo`030000003oool0oooo03P0oooo00D000000?ooo`3oool0oooo0?l0
000<0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0mP3oool00500oooo00<00000
0?ooo`3oool0>03oool010000000oooo0?ooo`3o000<0?ooo`8000006@3oool00`000000oooo0?oo
o`3g0?ooo`00D03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo00@00000
0?ooo`3oool000005`3oool00`000000oooo0?ooo`3h0?ooo`00D03oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0?T0oooo001@0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo0P00003l0?oo
o`00D03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00L0oooo100000070?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0o03oool00500oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo0P00000<0?ooo`800000
o`3oool00500oooo00<000000?ooo`3oool0>03oool00`3o000000000?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000003P3oool<00000?l0oooo0P3oool00500oooo00<000000?ooo`3oool0=`3o
ool00`3o00000000000000020?ooo`<0000000<0oooo000000000000o`3ooolL0?ooo`00D03oool2
000003P0oooo00@0o`000?ooo`000000oooo0P0000020?ooo`800000o`3ooolM0?ooo`00D03oool0
0`000000oooo0?ooo`0f0?ooo`040?l000000000oooo0?ooo`800000o`3ooolR0?ooo`00D03oool2
000003L0oooo00<0o`000?ooo`3oool0o`3ooolU0?ooo`00103oool00`3o_g@00000000000030000
0003001d_`3oool0oooo0080oooo00<0_g@000000000M;l01P3oool00`2oM4P0W=oo0?ooo`020?oo
o`030?oo_`1dB9`0gooo00@0oooo00<0okmd0000000000000`0000001@00M;l0oooo0?ooo`3oool0
okmd00<0000000<0M;oo0?ooo`3oool06`3oool2000003H0oooo00<0o`000?ooo`3oool0o`3ooolV
0?ooo`001`3oool00`2LB4P0W=oo0?ooo`050?ooo`030;md0000000007Bo00H0oooo00L0oooO09a8
B02Lgol0oooo0?oo_`1d07@0_ooo00P0oooo00<0W4Q809cOo`3oool0103oool01P2LB7@0_ooo0?oo
o`3ookl0M01d0;oooa`0oooo0P00000f0?ooo`030?l0003oool0oooo0?l0oooo9P3oool000L0oooo
00<0W4Q809cOo`3oool03`3oool01@3ooml0W4Qd0;oog`2LB7@0_ooo00T0oooo00<0W4Q809cOo`3o
ool00`3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo01/0oooo0P00000e0?ooo`03
0?l0003oool0oooo0?l0oooo9`3oool000L0oooo00<0W4Q809cOo`3oool0403oool00`3ookl0M018
09cOo`0:0?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo
0?ooo`0K0?ooo`800000=@3oool00`000000oooo0?ooo`3o0?ooobL0oooo00070?ooo`0309a8B02L
gol0oooo00l0oooo00D0oono07@0M02ooml0W4Q809cOo`090?ooo`0309a8B02Lgol0oooo00<0oooo
00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0K0?ooo`<00000<`3oool00`000000oooo
0?ooo`3o0?ooobP0oooo00070?ooo`0309a8B02Lgol0oooo00h0oooo00L0oono07@0M02oool0oooo
0?oog`2LB4P0W=oo00P0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`03
0?noM000M;l0oooo01/0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`3o0?ooobP0
oooo00070?ooo`0309a8B02Lgol0oooo00h0oooo00<0_gAd0;ooo`3oool00P3oool00`3ooml0W7BL
0=ooo`070?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO
0?ooo`0K0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0o`3ooolY0?ooo`00103o
ool01@3OW4P000000018W02LB4P0W=oo01/0oooo00D0gia800000000B9`0W4Q809cOo`050?ooo`06
09a8001d_ol0oooo0?oOW01807@0_ooo203oool0202LB0000000000000000000001d0;ooo`3ogi`0
B0000`0000000`18W=l0oooo0?ooo`060?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0o`3ooolY0?ooo`001P3oool00`3OW4P0001809cOo`0M0?ooo`030=nLB00004P0W=oo00D0oooo
00D0oono07@000000000001809cOo`0;0?ooo`0309a8M02oool0oooo0080oooo00<0W4P00018W03o
ool02P3oool00`000000oooo0?ooo`0a0?ooo`030?l0003oool0oooo0?l0oooo:P3oool003D0oooo
00<0oooO09a8000000000P0000001P18W=l0oooo0?ooo`3oool0W4Qd0;ooo`@0oooo00<0gia80000
M02oool02@3oool00`000000oooo0?ooo`0`0?ooo`030?l0003oool0oooo0?l0oooo:`3oool003h0
oooo00<0W4Qd0;ooo`3oool0103oool00`3o_g@0001d0;ooo`080?ooo`030000003oool0oooo0300
oooo00<0o`000?ooo`3oool0o`3oool[0?ooo`00?P3oool00`2LB7@0_ooo0?ooo`050?ooo`030?no
_`2oool0oooo00L0oooo00<000000?ooo`3oool0;`3oool00`3o0000oooo0?ooo`3o0?ooob`0oooo
000l0?ooo`040;md001d_ol0W4Qd0;ooo`80oooo00H0oono07@0M02oool0oooo0;md0018W=l80?oo
o`030000003oool0oooo02h0oooo00<000000?l0003oool0o`3oool]0?ooo`00?03oool0103ookl0
M0000000M02oool30?ooo`040?noM000000000000018W0T0oooo00<000000?ooo`3oool0;P3oool0
0`3o0000oooo0?ooo`3o0?ooobd0oooo001@0?ooo`030000003oool0oooo02d0oooo00<000000?l0
003oool0o`3oool^0?ooo`00D03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0
oooo;P3oool00500oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`3o0?ooobl0oooo
001@0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0o`3oool_0?ooo`00D03oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0oooo<03oool00500oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`3o0?oooc00oooo001@0?ooo`030000003oool0oooo02X0
oooo00<0o`000?ooo`3oool0o`3ooola0?ooo`00D03oool00`000000oooo0?ooo`0Y0?ooo`030?l0
00000000oooo0?l0oooo<P3oool00500oooo00<000000?ooo`3oool0:@3oool00`3o0000oooo0?oo
o`3o0?oooc80oooo001@0?ooo`030000003oool0oooo02P0oooo00<0o`000000003oool0o`3ooolc
0?ooo`00D03oool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0oooo0?l0oooo<`3oool00500
oooo00<000000?ooo`3oool09`3oool00`3o000000000?ooo`3o0?oooc@0oooo001@0?ooo`030000
003oool0oooo02L0oooo00<0o`000?ooo`3oool0o`3ooold0?ooo`00D03oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo0?l0oooo=03oool00500oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`3o0?ooocD0oooo001@0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0o`3ooole0?ooo`00D03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0?l0
oooo=P3oool00500oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?ooocH0oooo
001@0?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3oool0o`3ooolg0?ooo`00D03oool0
0`000000oooo0?ooo`0S0?ooo`030?l000000000oooo0?l0oooo>03oool00500oooo00<000000?oo
o`3oool08`3oool00`3o0000oooo0?ooo`3o0?ooocP0oooo001@0?ooo`030000003oool0oooo0280
oooo00<0o`000000003oool0o`3oooli0?ooo`00D03oool00`000000oooo0?ooo`0R0?ooo`030?l0
003oool0oooo0?l0oooo>@3oool00500oooo00<000000?ooo`3oool08@3oool00`3o0000oooo0?oo
o`3o0?ooocX0oooo001@0?ooo`030000003oool0oooo0200oooo00<0o`000000003oool0o`3ooolk
0?ooo`00D03oool200000240oooo00<000000?ooo`3oool0o`3ooolk0?ooo`00D03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0oooo>`3oool00500oooo0P00000P0?ooo`030000
003oool0oooo0?l0oooo?03oool000X0oooo00<0okmd0000000000000`0000000`00M;l0oooo0?oo
o`020?ooo`030;md0000000007Bo00L0oooo00<0_gA809cOo`3oool00P3oool00`3ookl0M4RL0=oo
o`030?ooo`030?noM0000000000000<0000000D007Bo0?ooo`3oool0oooo0?noM0030000000307Bo
o`3oool0oooo01D0oooo0P00000P0?ooo`030000003oool0oooo0?l0oooo?03oool000d0oooo00<0
W4Q809cOo`3oool01@3oool00`2oM0000000001d_`070?ooo`070?oog`2LB4P0W=oo0?ooo`3ookl0
M01d0;ooo`070?ooo`0309a8B02Lgol0oooo00@0oooo00H0W4Qd0;ooo`3oool0oono07@0M02ooolF
0?ooo`8000007`3oool00`000000oooo0?ooo`3o0?ooocd0oooo000=0?ooo`0309a8B02Lgol0oooo
0100oooo00D0oooO09a8M02ooml0W4Qd0;ooo`080?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd
001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0E0?ooo`8000007`3oool00`000000oooo0?ooo`3o
0?ooocd0oooo000=0?ooo`0309a8B02Lgol0oooo0140oooo00<0oono07@0B02Lgol02@3oool00`2L
B4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool05@3oool20000
01h0oooo00<0o`000?ooo`3oool0o`3oooln0?ooo`003@3oool00`2LB4P0W=oo0?ooo`0@0?ooo`05
0?oo_`1d07@0_ooO09a8B02Lgol0203oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo
0080oooo00<0okmd001d_`3oool05@3oool3000001`0oooo00<0o`000?ooo`3oool0o`3ooolo0?oo
o`003@3oool00`2LB4P0W=oo0?ooo`0?0?ooo`070?oo_`1d07@0_ooo0?ooo`3ooml0W4Q809cOo`07
0?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0E
0?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool0o`3ooolo0?ooo`003@3oool00`2L
B4P0W=oo0?ooo`0?0?ooo`030;mdM02oool0oooo0080oooo00<0oooO09adW03Oool01P3oool00`2L
B4P0W=oo0?ooo`030?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool02@3oool0103O
W4P0000000000000B9`80?ooo`030000003oool0oooo01/0oooo00<0o`000?ooo`3oool0o`3ooom0
0?ooo`002P3oool01@3OW4P000000018W02LB4P0W=oo01/0oooo00D0gia800000000B9`0W4Q809cO
o`050?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2@3oool01P3ogi`0B4RL0?ooo`3oool0giad
09cOo`L0oooo00<000000?ooo`3oool06P3oool00`3o000000000?ooo`3o0?oood40oooo000<0?oo
o`030=nLB00004P0W=oo01d0oooo00<0gia80000B02Lgol01@3oool01@3ookl0M0000000000004P0
W=oo0080oooo00<0oooO09a8000000000P0000001@18W=l0oooo0?ooo`2oM00004RL0080oooo00<0
W4Q809cOo`3oool01P3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo0?l0oooo@@3o
ool004<0oooo00D0giad07AdB0000000000004RLg`080?ooo`030000003oool0oooo01T0oooo00<0
o`000000003oool0o`3ooom20?ooo`00@`3oool00`3OW4P0M;oo0?ooo`0:0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00@`3oool00`3ookl0M00004RLg`0:0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00A@3oool0102LB000
00000000001d_ol70?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooom30?oo
o`00D03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0ooooA03oool00500oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?oood@0oooo001@0?ooo`030000003o
ool0oooo01H0oooo00<0o`000?ooo`3oool0o`3ooom50?ooo`00D03oool00`000000oooo0?ooo`0E
0?ooo`030?l000000000oooo0?l0ooooAP3oool00500oooo00<000000?ooo`3oool05@3oool00`3o
0000oooo0?ooo`3o0?ooodH0oooo001@0?ooo`030000003oool0oooo01@0oooo00<0o`000000003o
ool0o`3ooom70?ooo`00D03oool00`000000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0?l0oooo
A`3oool00500oooo00<000000?ooo`3oool04`3oool00`3o000000000?ooo`3o0?ooodP0oooo001@
0?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3oool0o`3ooom80?ooo`00D03oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0ooooB@3oool00500oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`3o0?ooodT0oooo001@0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0o`3ooom:0?ooo`00D03oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0?l0ooooBP3oool00500oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o
0?oood/0oooo001@0?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool0o`3ooom<0?oo
o`00D03oool00`000000oooo0?ooo`0>0?ooo`030?l000000000oooo0?l0ooooC@3oool00500oooo
00<000000?ooo`3oool03P3oool00`3o0000oooo0?ooo`3o0?ooodd0oooo001@0?ooo`030000003o
ool0oooo00d0oooo00<0o`000000003oool0o`3ooom>0?ooo`00D03oool00`000000oooo0?ooo`0=
0?ooo`030?l0003oool0oooo0?l0ooooCP3oool00500oooo00<000000?ooo`3oool0303oool00`3o
000000000?ooo`3o0?ooodl0oooo001@0?ooo`030000003oool0oooo00`0oooo00<0o`000?ooo`3o
ool0o`3ooom?0?ooo`00D03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo
D03oool00500oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oooe00oooo001@
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00D03oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooD@3oool00500oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`3o0?oooe80oooo001@0?ooo`8000002@3oool00`000000o`00
0?ooo`3o0?oooe<0oooo001@0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool0o`3o
oomC0?ooo`00D03oool2000000P0oooo00<000000?l0003oool0o`3ooomD0?ooo`00D03oool20000
00P0oooo00<0o`000?ooo`3oool0o`3ooomD0?ooo`00@@3oool00`3o_g@000000000000300000003
001d_`3oool0oooo00H0oooo0P0000070?ooo`030?l0003oool0oooo0?l0ooooE@3oool004@0oooo
00<0W4Q809cOo`3oool02@3oool2000000L0oooo00<0o`000?ooo`3oool0o`3ooomE0?ooo`00A03o
ool00`2LB4P0W=oo0?ooo`090?ooo`<000001@3oool00`3o0000oooo0?ooo`3o0?oooeH0oooo0014
0?ooo`0309a8B02Lgol0oooo00T0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`00A03oool00`2L
B4P0W=oo0?ooo`090?ooo`030000003oool0oooo0?l0ooooGP3oool004@0oooo00<0W4Q809cOo`3o
ool02@3oool00`000000oooo0?ooo`3o0?oooeh0oooo00140?ooo`0309a8B02Lgol0oooo00T0oooo
00<000000?ooo`3oool0o`3ooomN0?ooo`00@@3oool01@3OW4P000000018W02LB4P0W=oo00X0oooo
00<000000?ooo`3oool0o`3ooomN0?ooo`00@`3oool00`3OW4P0001809cOo`0:0?ooo`030000003o
ool0oooo0?l0ooooGP3oool00500oooo00<000000?ooo`3oool0o`3ooomN0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.66274, -34.6613, \
0.0450099, 0.215015}}]
}, Closed]],

Cell["or by increasing the precision goal", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DisplayTogether[\[IndentingNewLine]LogPlot[
          Evaluate[
            Abs[stiffSol[20, 10, PrecisionGoal \[Rule] 10, 
                WorkingPrecision \[Rule] 20]]], {x, 0, 10}, 
          PlotRange \[Rule] {Automatic, {10\^\(-25\), 
                10\^1}}], \[IndentingNewLine]LogPlot[
          Evaluate[
            Abs[stiffSol[20, 10, PrecisionGoal \[Rule] 15, 
                WorkingPrecision \[Rule] 30]]], {x, 0, 10}, 
          PlotRange \[Rule] {Automatic, {10\^\(-25\), 10\^1}}, 
          PlotStyle \[Rule] {{RGBColor[0, 0, 
                  1]}}], \[IndentingNewLine]LogPlot[
          Evaluate[trueSol[20]], {x, 0, 10}, 
          PlotStyle \[Rule] {{RGBColor[1, 0, 0], 
                Dashing[{0.02, 0.02}]}}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.594263 0.0237705 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[-0.0125 .11885 -50.6875 -6.6875 ]
[-0.0125 .11885 0 6.6875 ]
[-0.0125 .23771 -50.6875 -6.6875 ]
[-0.0125 .23771 0 6.6875 ]
[-0.0125 .35656 -50.6875 -6.6875 ]
[-0.0125 .35656 0 6.6875 ]
[-0.0125 .47541 -46 -6.28125 ]
[-0.0125 .47541 0 6.28125 ]
[-0.0125 .59426 -10 -6.28125 ]
[-0.0125 .59426 0 6.28125 ]
[ -0.0005 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11885 m
.00625 .11885 L
s
gsave
-0.0125 .11885 -111.688 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
109.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .23771 m
.00625 .23771 L
s
gsave
-0.0125 .23771 -111.688 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
109.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .35656 m
.00625 .35656 L
s
gsave
-0.0125 .35656 -111.688 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
109.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .47541 m
.00625 .47541 L
s
gsave
-0.0125 .47541 -107 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00001) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .59426 m
.00625 .59426 L
s
gsave
-0.0125 .59426 -71 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .09617 m
.00375 .09617 L
s
0 .10333 m
.00375 .10333 L
s
0 .10751 m
.00375 .10751 L
s
0 .11048 m
.00375 .11048 L
s
0 .11278 m
.00375 .11278 L
s
0 .11467 m
.00375 .11467 L
s
0 .11626 m
.00375 .11626 L
s
0 .11764 m
.00375 .11764 L
s
0 .21502 m
.00375 .21502 L
s
0 .22218 m
.00375 .22218 L
s
0 .22636 m
.00375 .22636 L
s
0 .22933 m
.00375 .22933 L
s
0 .23164 m
.00375 .23164 L
s
0 .23352 m
.00375 .23352 L
s
0 .23511 m
.00375 .23511 L
s
0 .23649 m
.00375 .23649 L
s
0 .33388 m
.00375 .33388 L
s
0 .34103 m
.00375 .34103 L
s
0 .34522 m
.00375 .34522 L
s
0 .34819 m
.00375 .34819 L
s
0 .35049 m
.00375 .35049 L
s
0 .35237 m
.00375 .35237 L
s
0 .35396 m
.00375 .35396 L
s
0 .35534 m
.00375 .35534 L
s
0 .45273 m
.00375 .45273 L
s
0 .45988 m
.00375 .45988 L
s
0 .46407 m
.00375 .46407 L
s
0 .46704 m
.00375 .46704 L
s
0 .46934 m
.00375 .46934 L
s
0 .47123 m
.00375 .47123 L
s
0 .47282 m
.00375 .47282 L
s
0 .47419 m
.00375 .47419 L
s
0 .57158 m
.00375 .57158 L
s
0 .57874 m
.00375 .57874 L
s
0 .58292 m
.00375 .58292 L
s
0 .58589 m
.00375 .58589 L
s
0 .5882 m
.00375 .5882 L
s
0 .59008 m
.00375 .59008 L
s
0 .59167 m
.00375 .59167 L
s
0 .59305 m
.00375 .59305 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .59426 m
.06244 .51051 L
.10458 .41916 L
.12507 .37475 L
.14415 .33331 L
.1536 .31299 L
.16254 .29429 L
.16748 .28141 L
.16818 .27702 L
.16883 .26935 L
.16951 .25264 L
.17026 .27385 L
.1715 .28291 L
.1722 .28563 L
.17284 .28742 L
.17403 .28956 L
.17513 .29048 L
.17635 .2905 L
.17764 .28943 L
.17887 .2874 L
.18004 .28493 L
.18117 .28268 L
.18221 .28123 L
.18337 .28068 L
.18462 .28132 L
.18577 .28256 L
.18686 .28385 L
.18813 .28508 L
.18931 .28575 L
.1906 .28582 L
.19125 .28555 L
.19197 .285 L
.19262 .28426 L
.19331 .28322 L
.19453 .28082 L
.19596 .27776 L
.19729 .27524 L
.19844 .27357 L
.19968 .2725 L
.20038 .27221 L
.20104 .27211 L
.20229 .27218 L
.20335 .2723 L
.20453 .27226 L
.20575 .27182 L
.2069 .27091 L
.20797 .26952 L
.20895 .26778 L
.21115 .26306 L
.21229 .26074 L
Mistroke
.21351 .25868 L
.21421 .25779 L
.21484 .25724 L
.21608 .25692 L
.21724 .2575 L
.21849 .25882 L
.22076 .26208 L
.22536 .26849 L
.23029 .27344 L
.23312 .27551 L
.2357 .27701 L
.23814 .27816 L
.24074 .27911 L
.24343 .27986 L
.24593 .28035 L
.24731 .28054 L
.24861 .28068 L
.24935 .28074 L
.25003 .28078 L
.25078 .28082 L
.25157 .28084 L
.2528 .28084 L
.25411 .2808 L
.25534 .28073 L
.25646 .28063 L
.25779 .28049 L
.25922 .28028 L
.26181 .27979 L
.26418 .27921 L
.26672 .27844 L
.2713 .27664 L
.27675 .27375 L
.28173 .27024 L
.2869 .26548 L
.29254 .25856 L
.29786 .24974 L
.30279 .23951 L
.30504 .23462 L
.30741 .22973 L
.30865 .22767 L
.30935 .2268 L
.31001 .22626 L
.31116 .22596 L
.3124 .22654 L
.31356 .22773 L
.31483 .22942 L
.31713 .23281 L
.32143 .23838 L
.32663 .24315 L
.32925 .2449 L
Mistroke
.33214 .24641 L
.3346 .24743 L
.33724 .24827 L
.33852 .24859 L
.33974 .24886 L
.34202 .24924 L
.34327 .24938 L
.34392 .24944 L
.34461 .2495 L
.34588 .24956 L
.34705 .24959 L
.34818 .24958 L
.34923 .24955 L
.35038 .24948 L
.35162 .24938 L
.35293 .24923 L
.35436 .24902 L
.35696 .24853 L
.3595 .2479 L
.36184 .24719 L
.36608 .24555 L
.37076 .24317 L
.37565 .23995 L
.38023 .23606 L
.38483 .23109 L
.38917 .22511 L
.39418 .21623 L
.39872 .20651 L
.40117 .20117 L
.4025 .19838 L
.40375 .19614 L
.4044 .19523 L
.4051 .1945 L
.40588 .19406 L
.40659 .19402 L
.40723 .19425 L
.40793 .19476 L
.4092 .1962 L
.41431 .20364 L
.41894 .20893 L
.42154 .21117 L
.42398 .21287 L
.42678 .21444 L
.42935 .21557 L
.43161 .21635 L
.43399 .21699 L
.43638 .21746 L
.43773 .21766 L
.43899 .21779 L
.44031 .21789 L
Mistroke
.44105 .21793 L
.44174 .21795 L
.443 .21796 L
.44363 .21795 L
.44433 .21793 L
.44554 .21787 L
.44684 .21777 L
.44807 .21763 L
.44919 .21748 L
.45186 .217 L
.45478 .2163 L
.4601 .21449 L
.46541 .21194 L
.47041 .20874 L
.4749 .20505 L
.47976 .19994 L
.48507 .19258 L
.49068 .18219 L
.49594 .17085 L
.49715 .16833 L
.49843 .16592 L
.49952 .16432 L
.50073 .16331 L
.50193 .16322 L
.50306 .16389 L
.50428 .16523 L
.5056 .16704 L
.5102 .17355 L
.51278 .17651 L
.5155 .17906 L
.51785 .18086 L
.52036 .18243 L
.52274 .18364 L
.52489 .18453 L
.52709 .18526 L
.52911 .18579 L
.53148 .18625 L
.53272 .18643 L
.53404 .18657 L
.53518 .18666 L
.53625 .18672 L
.53743 .18675 L
.53869 .18674 L
.53938 .18672 L
.54003 .18669 L
.54124 .18661 L
.54254 .18649 L
.54394 .18632 L
.54648 .18589 L
.54882 .18537 L
Mistroke
.55419 .18368 L
.55689 .18256 L
.55986 .1811 L
.56488 .178 L
.57026 .17364 L
.57533 .16821 L
.57996 .16178 L
.58923 .14358 L
.59148 .13864 L
.59267 .13613 L
.59391 .13377 L
.59457 .13273 L
.5953 .13185 L
.59657 .13109 L
.59787 .13142 L
.59907 .13252 L
.60429 .14004 L
.60716 .14368 L
.60986 .14645 L
.61238 .14854 L
.61509 .15037 L
.61984 .15269 L
.62221 .1535 L
.62474 .15417 L
.62597 .15442 L
.62714 .15462 L
.62818 .15477 L
.62933 .1549 L
.63058 .155 L
.63127 .15503 L
.63192 .15506 L
.63307 .15508 L
.63431 .15507 L
.63497 .15504 L
.63569 .15501 L
.63645 .15496 L
.63715 .1549 L
.6384 .15477 L
.63975 .15459 L
.64246 .1541 L
.64541 .15337 L
.65077 .15153 L
.65599 .14901 L
.6608 .14593 L
.66582 .14177 L
.67059 .13665 L
.67609 .12883 L
.68112 .11941 L
.68553 .10991 L
.68795 .10484 L
Mistroke
.68913 .10272 L
.69023 .10125 L
.69152 .1004 L
.69221 .10037 L
.69293 .10066 L
.69409 .10166 L
.69538 .10327 L
.70016 .11007 L
.7027 .1131 L
.7051 .11548 L
.70961 .11888 L
.71213 .12029 L
.71446 .12135 L
.71701 .12226 L
.71973 .12299 L
.72189 .1234 L
.7231 .12358 L
.72421 .12371 L
.72519 .1238 L
.72626 .12386 L
.72738 .1239 L
.72842 .12391 L
.72967 .12389 L
.73084 .12384 L
.7319 .12376 L
.73305 .12365 L
.7343 .1235 L
.73563 .12329 L
.738 .12283 L
.74053 .1222 L
.74293 .12146 L
.74744 .11968 L
.75229 .11715 L
.75758 .1135 L
.76218 .10939 L
.76709 .10375 L
.77171 .09684 L
.7759 .08895 L
.78079 .07833 L
.78346 .0726 L
.78476 .07025 L
.78595 .06876 L
.78704 .06816 L
.78808 .06832 L
.78917 .06916 L
.79036 .0706 L
.79519 .07769 L
.80044 .08364 L
.80309 .08582 L
.80602 .08773 L
Mistroke
.8085 .08902 L
.81118 .09011 L
.81371 .0909 L
.81602 .09145 L
.81731 .09168 L
.81852 .09186 L
.8196 .09199 L
.82078 .09209 L
.82206 .09216 L
.82271 .09218 L
.82342 .09219 L
.82468 .09218 L
.82586 .09214 L
.82704 .09206 L
.82816 .09196 L
.83026 .0917 L
.83253 .0913 L
.83499 .09073 L
.8402 .08906 L
.84284 .08796 L
.84575 .08652 L
.85088 .08334 L
.85571 .07944 L
.89437 .04345 L
.89551 .04402 L
.89671 .04451 L
.89803 .04492 L
.89925 .04518 L
.90038 .04533 L
.90144 .04538 L
.90261 .04535 L
.90386 .04521 L
.90454 .04509 L
.90528 .04492 L
.90663 .04452 L
.90795 .04401 L
.90917 .04343 L
.91151 .04201 L
.914 .04003 L
.91701 .0369 L
.91984 .03309 L
.92513 .02337 L
.92755 .01807 L
.9301 .01291 L
.93075 .01186 L
.93144 .01091 L
.9322 .01013 L
.93291 .00967 L
.9336 .00947 L
.93426 .00949 L
Mistroke
.93548 .01 L
.94023 .01427 L
.94256 .01622 L
.94469 .01762 L
.94692 .01867 L
.9481 .01906 L
.94933 .01935 L
.9506 .01953 L
.95178 .0196 L
.95308 .01956 L
.9538 .01948 L
.95446 .01938 L
.95513 .01925 L
.95584 .01908 L
.95711 .01869 L
.95847 .01814 L
.95997 .01738 L
.96266 .01559 L
.96518 .01338 L
.96995 .00746 L
.97264 .00297 L
Mfstroke
.97264 .00297 m
.97413 0 L
s
0 0 1 r
.02381 .59426 m
.06244 .51051 L
.10458 .41916 L
.14415 .33337 L
.18221 .25086 L
.20342 .20462 L
.21345 .18382 L
.21786 .17454 L
.22037 .16933 L
.22159 .16641 L
.22272 .16274 L
.22387 .15605 L
.22496 .12466 L
.22612 .15619 L
.22738 .164 L
.22862 .16795 L
.22932 .16937 L
.22995 .1703 L
.23117 .17132 L
.23233 .17141 L
.2336 .17058 L
.23424 .1698 L
.23494 .16866 L
.23734 .16368 L
.23803 .16244 L
.23869 .16154 L
.23945 .16092 L
.24014 .16079 L
.2414 .16146 L
.24211 .16217 L
.24276 .16292 L
.24385 .16415 L
.24501 .16524 L
.24612 .16589 L
.24713 .16609 L
.24825 .16581 L
.24948 .16481 L
.25076 .16295 L
.25195 .16055 L
.25311 .15807 L
.25438 .15558 L
.25557 .15367 L
.25667 .15244 L
.25795 .15171 L
.2586 .15158 L
.25931 .15155 L
.26055 .15166 L
.26171 .15171 L
.26296 .1515 L
.26366 .15119 L
Mistroke
.26429 .15076 L
.26553 .14947 L
.26669 .14762 L
.26952 .14146 L
.27076 .13882 L
.27141 .13758 L
.27212 .13644 L
.27331 .13513 L
.27443 .13481 L
.2757 .13547 L
.27687 .13678 L
.282 .14456 L
.28656 .15002 L
.28914 .15233 L
.29152 .15407 L
.29589 .15647 L
.2981 .15736 L
.30053 .15814 L
.30289 .1587 L
.30423 .15895 L
.30547 .15914 L
.30678 .15929 L
.30798 .15938 L
.30864 .15942 L
.30935 .15945 L
.31065 .15947 L
.31177 .15946 L
.313 .15941 L
.31428 .15932 L
.31548 .15921 L
.31762 .15892 L
.31992 .15849 L
.3226 .15784 L
.32552 .15694 L
.33083 .15476 L
.336 .15185 L
.34079 .14834 L
.34553 .14387 L
.35052 .13776 L
.35599 .12884 L
.36102 .11854 L
.36329 .11372 L
.36454 .11118 L
.36572 .10901 L
.36681 .10738 L
.36801 .10628 L
.36909 .10601 L
.37009 .10636 L
.37128 .10738 L
.37239 .10872 L
Mistroke
.37491 .11226 L
.37736 .11555 L
.38002 .11862 L
.38255 .12102 L
.38489 .12286 L
.38732 .12443 L
.38952 .1256 L
.39372 .12727 L
.39603 .12793 L
.3982 .12839 L
.39933 .12858 L
.40058 .12875 L
.40188 .12888 L
.40309 .12896 L
.40423 .12901 L
.40526 .12902 L
.40646 .12901 L
.40759 .12896 L
.40881 .12888 L
.41012 .12876 L
.41123 .12862 L
.41245 .12844 L
.41518 .12791 L
.41774 .12727 L
.42244 .12567 L
.42758 .12327 L
.43295 .1199 L
.43794 .11579 L
.44263 .1108 L
.44689 .10503 L
.45181 .09645 L
.45645 .08653 L
.45868 .0815 L
.46108 .07614 L
.46179 .07474 L
.46246 .07357 L
.46372 .07205 L
.4649 .0716 L
.46618 .07223 L
.46688 .07296 L
.46754 .07381 L
.46877 .07567 L
.47152 .08003 L
.47394 .08341 L
.47648 .08638 L
.47869 .0885 L
.4811 .09042 L
.48535 .09298 L
.48775 .09405 L
.49031 .09494 L
Mistroke
.49273 .09558 L
.49494 .09601 L
.49612 .09618 L
.49723 .09631 L
.49845 .09641 L
.49976 .09648 L
.50042 .0965 L
.50113 .09651 L
.50244 .09649 L
.50371 .09644 L
.50488 .09635 L
.50608 .09623 L
.50722 .09609 L
.50933 .09575 L
.51161 .09527 L
.51407 .09461 L
.51933 .09271 L
.52489 .0899 L
.52964 .0867 L
.53485 .08215 L
.54009 .0761 L
.54505 .06852 L
.54956 .05981 L
.55435 .0497 L
.55554 .04739 L
.55683 .04529 L
.55756 .04438 L
.55823 .04379 L
.55955 .04341 L
.56067 .04386 L
.5619 .04498 L
.56318 .04658 L
.56437 .04823 L
.5696 .055 L
.57254 .05793 L
.57526 .06009 L
.58037 .06306 L
.58295 .06412 L
.58578 .06501 L
.58825 .06557 L
.58964 .06581 L
.59091 .06599 L
.59209 .06611 L
.59337 .0662 L
.59459 .06625 L
.59571 .06627 L
.59688 .06626 L
.59815 .0662 L
.59934 .06612 L
.60043 .06602 L
Mistroke
.60252 .06574 L
.60471 .06535 L
.60708 .06481 L
.60928 .06418 L
.6143 .06232 L
.61932 .05978 L
.62477 .05611 L
.62992 .05153 L
.63468 .04601 L
.63896 .03966 L
.64369 .03075 L
.64825 .02064 L
.65084 .01472 L
.6521 .01201 L
.65325 .00998 L
.65447 .00862 L
.65563 .00834 L
.65685 .00907 L
.65754 .00984 L
.65817 .01071 L
.66336 .01881 L
.66786 .02418 L
.67013 .02623 L
.67262 .02807 L
.67529 .02966 L
.67782 .03085 L
.68074 .03191 L
.68203 .03228 L
.68341 .03261 L
.6846 .03286 L
.68591 .03308 L
.68712 .03324 L
.68823 .03336 L
.68954 .03345 L
.69022 .03348 L
.69094 .0335 L
.69216 .03351 L
.69285 .0335 L
.69349 .03348 L
.69476 .03341 L
.6954 .03336 L
.69611 .0333 L
.69852 .03299 L
.69988 .03276 L
.70135 .03246 L
.70399 .0318 L
.70917 .03002 L
.71391 .02777 L
.71847 .02496 L
.72344 .02101 L
Mistroke
.72813 .0162 L
.73249 .0105 L
.73757 .00191 L
Mfstroke
.73757 .00191 m
.73849 0 L
s
.77013 0 m
.77163 .00072 L
.77415 .00167 L
.7768 .00244 L
.77907 .00292 L
.78035 .00313 L
.78154 .00329 L
.78274 .0034 L
.78387 .00348 L
.78488 .00352 L
.78598 .00354 L
.78718 .00353 L
.78844 .00348 L
.78953 .00341 L
.79072 .0033 L
.7921 .00313 L
.79342 .00294 L
.79589 .00246 L
.79855 .00179 L
.80145 .00087 L
s
.80145 .00087 m
.80354 0 L
s
1 0 0 r
[ .02 .02 ] 0 setdash
.02381 .59426 m
.06244 .51051 L
.10458 .41916 L
.14415 .33337 L
.18221 .25087 L
.22272 .16305 L
.26171 .07852 L
s
.26171 .07852 m
.29793 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00EP3oool01@3o_g@00000000000000000M;oo03/0oooo00<0oono07@00000000010000000
0`1d_ol0oooo0?ooo`0l0?ooo`050?oOW018000000000000001d_ol0?P3oool01@2oM00000000000
000007@0_ooo03`0oooo00D0_g@00000000000000000001d_`0i0?ooo`030?noM0000000000000<0
000000D007Bo0?ooo`3oool0oooo0?noM0030000000307Boo`3oool0oooo0040oooo001F0?ooo`06
09a8M02oool0oooo0?oo_`1d07@0_ooo>`3oool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0
oooo03l0oooo00<0_g@007Boo`3oool0?@3oool01P3OW4P007Bo0?ooo`3oool0okmd001d_c/0oooo
00<0okmd001d_`3oool00P3oool00`2oM4P0W=oo0?ooo`0j0?ooo`0309a8B02Lgol0oooo00@0oooo
00H0W4Qd0;ooo`3oool0oono07@0M02oool20?ooo`00E@3oool00`3o_g@007Bo0?ooo`020?ooo`03
0=nLB018W=l0oooo03/0oooo00<0okmd0000B02Lgol0@`3oool00`2oM000M;oo0?ooo`0l0?ooo`03
0?oo_`1d0000M;oo0080oooo00<0oono07A8W03oool0>P3oool00`3OW4P0B9cO0?ooo`020?ooo`03
0;md001d_ol0oooo03X0oooo00<0W4Q809cOo`3oool00`3oool00`3o_g@007Bo0?ooo`020?ooo`03
0=nLB018W=l0oooo0040oooo001E0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0
?03oool00`3ogi`0B00004RLg`0n0?ooo`030=nLB0000000000000<0000000<0M;oo0?ooo`3oool0
>P3oool01`3o_g@004Q807@0M02oool0oooo0=nLB000M;l0>`3oool00`3o_g@004RL0?ooo`020?oo
o`0309a8B02Lgol0oooo03X0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`020?oo
o`030?noM000M;l0oooo0040oooo001E0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3o
ool0?P3oool00`2LB000B9cO0?ooo`0l0?ooo`060?noM00007@0_ooo0?ooo`2oM000M;oo?@3oool0
0`3ogi`0B4RL0?noM002000000030018W03oool0oooo03/0oooo00D0gia8000000000000000004RL
g`0l0?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?oo
o`010?ooo`00E@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo03l0oooo00<0W4Qd
0;ooo`3oool0?03oool01@3OW4P007Bo0?ooo`2oM000M;oo03d0oooo00<0oono07@0M02oool0?`3o
ool00`3ookl0M4RL0?ooo`020?ooo`0309a8M02oool0oooo03X0oooo00<0W4Q809cOo`3oool00`3o
ool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo0040oooo001E0?ooo`030?noM018W=l0
oooo0080oooo00<0gia804RLg`3oool0>P3oool00`3OW4P0M;oo0?ooo`020?ooo`030;md001d_ol0
oooo03d0oooo00@0W4P004RLg`2oM000M;oo?P3oool00`2oM000B9cO0?ooo`0n0?ooo`030?noM018
W=l0oooo0080oooo00<0_g@007Boo`3oool0>P3oool00`2LB4P0W=oo0?ooo`030?ooo`030?noM018
W=l0oooo0080oooo00<0gia804RLg`3oool00@3oool005H0oooo00H0W4P007Boo`3oool0omnL04P0
M02ooolk0?ooo`070?noM00007@0_ooo0?ooo`3o_g@0001809cOo`0n0?ooo`040?oOW01804P0B4P0
07Booch0oooo00<0oono07@00000M;l0?P3oool01`3ogi`0B01d0;ooo`3oool0omnL04P0M02oool0
>03oool01@3OW4P000000018W02LB4P0W=oo00D0oooo00H0W4P007Boo`3oool0omnL04P0M02oool2
0?ooo`00EP3oool01@3ookl0M0000000000004P0W=oo03d0oooo00D0okmd000000000000001809cO
o`100?ooo`030?noM0000000M;oo0400oooo00@0_g@000000000000004RL?03oool01@3o_g@00000
0000000004P0W=oo03/0oooo00<0gia80000B02Lgol01@3oool01@3ookl0M0000000000004P0W=oo
00<0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo001@0?ooofP0000000<0o`00
000000000000U`0000000`000?l0000000000008000000<0003o1`0000030000odD000000@3oool0
0500oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000o`000000oooo
00`0oooo1`000?l=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0000000T0oooo001@0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0oooo02@0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0oooo00l0
oooo00<000000?ooo`3oool0?@3oool010000000oooo0?ooo`0000090?ooo`00D03oool00`000000
oooo0?ooo`3Q0?ooo`<0003o6@3oool00`000?l0oooo0?ooo`130?ooo`8000002P3oool00`000000
oooo0?ooo`0;0?ooo`00D03oool00`000000oooo0?ooo`3Q0?ooo`030000o`3oool0003o01P0oooo
00<0003o0?ooo`3oool0@`3oool2000000030?ooo`000000oooo00P0oooo00<000000?ooo`3oool0
2`3oool00500oooo00<000000?ooo`3oool0h@3oool010000?l0oooo0?ooo`000?lG0?ooo`030000
o`3oool0oooo0480oooo00<000000?ooo`3oool00P3oool2000000H0oooo00<000000?ooo`3oool0
303oool00500oooo00<000000?ooo`3oool0h03oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo01<0oooo00<0003o0?ooo`3oool0@`3oool00`000000oooo0?ooo`030?ooo`<0000000@0
oooo00000000000000003`3oool00500oooo00<000000?ooo`3oool0h03oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool0A03oool00`000000oooo0?oo
o`050?ooo`<000004@3oool00500oooo00<000000?ooo`3oool0H@3oool00`3o0000oooo0?ooo`1k
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`15
0?ooo`030000003oool0oooo01T0oooo001@0?ooo`030000003oool0oooo0640oooo00<0o`000?oo
o`3oool0N`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00h0oooo00<0003o0?oo
o`3oool0A@3oool00`000000oooo0?ooo`0J0?ooo`00D03oool00`000000oooo0?ooo`1P0?ooo`03
0?l0003oool0oooo07/0oooo00<0003o0?ooo`3oool01`3oool20000o`/0oooo0`000?m80?ooo`03
0000003oool0oooo01X0oooo001@0?ooo`030000003oool0oooo0600oooo00<0o`000?ooo`3oool0
N`3oool00`000?l0oooo0?ooo`090?ooo`D0003o00<0oooo0000o`000?l00`000?m:0?ooo`030000
003oool0oooo01/0oooo001@0?ooo`030000003oool0oooo05l0oooo00<0o`000?ooo`3oool0N`3o
ool00`000?l0oooo0?ooo`0>0?ooo`<0003oC@3oool00`000000oooo0?ooo`0L0?ooo`00D03oool0
0`000000oooo0?ooo`1O0?ooo`030?l0003oool0oooo07/0oooo00<0003o0?ooo`3oool0GP3oool0
0`000000oooo0?ooo`0L0?ooo`00D03oool00`000000oooo0?ooo`1N0?ooo`030?l0003oool0oooo
07/0oooo00<0003o0?ooo`3oool0GP3oool00`000000oooo0?ooo`0M0?ooo`00D03oool00`000000
oooo0?ooo`1N0?ooo`030?l0003oool0oooo05l0oooo0P000?lI0?ooo`030000o`3oool0oooo05P0
oooo0P0000020?ooo`<00000803oool00500oooo00<000000?ooo`3oool0_`3oool20000o`030?oo
o`000?l0oooo01L0oooo00<0003o0?ooo`3oool0E`3oool00`000000oooo0000000300000280oooo
001@0?ooo`030000003oool0oooo0;l0oooo00@0003o0?ooo`3oool0003o5`3oool00`000?l0oooo
0?ooo`1G0?ooo`030000003oool0oooo02H0oooo001@0?ooo`030000003oool0oooo0;h0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo05L0oooo00<0
00000?ooo`3oool09`3oool00500oooo00<000000?ooo`3oool0_P3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool0E`3oool00`000000oooo0?ooo`0X
0?ooo`00D03oool00`000000oooo0?ooo`2m0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?oo
o`3oool03`3oool00`000?l0oooo0?ooo`1G0?ooo`030000003oool0oooo02T0oooo001@0?ooo`03
0000003oool0oooo05/0oooo00<0o`000?ooo`3oool0G`3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0E`3oool00`000000oooo0?ooo`0Z0?ooo`00
D03oool00`000000oooo0?ooo`1J0?ooo`030?l0003oool0oooo0600oooo00<0003o0?ooo`3oool0
1`3oool30000o`L0oooo1@000?mH0?ooo`800000;@3oool00500oooo00<000000?ooo`3oool0FP3o
ool00`3o0000oooo0?ooo`1O0?ooo`030000o`3oool0oooo00/0oooo20000?mK0?ooo`030000003o
ool0oooo02d0oooo001@0?ooo`030000003oool0oooo05T0oooo00<0o`000?ooo`3oool0H03oool0
0`000?l0oooo0?ooo`1A0?ooo`8000006P3oool00`000000oooo0?ooo`0^0?ooo`00D03oool00`00
0000oooo0?ooo`1I0?ooo`030?l0003oool0oooo04<0oooo0P000?lJ0?ooo`030000o`3oool0oooo
0540oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`0_0?ooo`00D03oool00`000000
oooo0?ooo`1H0?ooo`030?l0003oool0oooo04<0oooo0P000?l00`3oool0003o0?ooo`0G0?ooo`03
0000o`3oool0oooo0540oooo00D000000?ooo`3oool0oooo0000000G0?ooo`030000003oool0oooo
0300oooo001@0?ooo`030000003oool0oooo05P0oooo00<0o`000?ooo`3oool0@P3oool01@000?l0
oooo0?ooo`3oool0003o01L0oooo00<0003o0?ooo`3oool0DP3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0<@3oool00500oooo00<000000?ooo`3o
ool0F03oool00`3o0000oooo0?ooo`120?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool0503oool00`000?l0oooo0?ooo`1A0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0b0?ooo`00D03oool00`000000oooo0?ooo`1G0?ooo`030?l0
003oool0oooo04<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0B0?ooo`030000
o`3oool0oooo0580oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo03<0oooo001@0?ooo`030000003oool0oooo05L0oooo00<0o`000?ooo`3oool0@`3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00l0oooo0P000?mD0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0303oool2000003H0oooo001@0?ooo`030000003oool0
oooo09`0oooo00<0003o0?ooo`3oool01@3oool20000o`l0oooo00<0003o0?ooo`3oool0E03oool0
0`000000oooo0?ooo`080?ooo`<000002@3oool2000003P0oooo001@0?ooo`030000003oool0oooo
09`0oooo00<0003o0?ooo`3oool01`3oool20000o`/0oooo0P000?mG0?ooo`030000003oool0oooo
00/0oooo2@00000j0?ooo`00D03oool2000009`0oooo00<0003o0?ooo`3oool02P3oool40000o`80
oooo1@000?mH0?ooo`030000003oool0oooo04l0oooo001@0?ooo`030000003oool0oooo09/0oooo
00<0003o0?ooo`3oool03@3oool40000oe`0oooo00<000000?ooo`3oool0C`3oool00500oooo00<0
00000?ooo`3oool0VP3oool00`000?l0oooo0?ooo`1A0?ooo`<000006@3oool00`000000oooo0?oo
o`1@0?ooo`00D03oool2000005D0oooo00<0o`000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`1A
0?ooo`030000003oool0000001P0oooo00<000000?ooo`3oool0D@3oool00500oooo0P00001E0?oo
o`030?l0003oool0oooo02H0oooo0`000?lI0?ooo`030000o`3oool0oooo0540oooo00D000000?oo
o`3oool0oooo0000000F0?ooo`030000003oool0oooo0580oooo00040?ooo`030?noM00000000000
00<0000000<007Bo0?ooo`3oool00P3oool00`2oM0000000001d_`060?ooo`030;mdB02Lgol0oooo
0080oooo00<0oono07A8W03Oool0103oool00`3o_g@000000000000300000005001d_`3oool0oooo
0?ooo`3o_g@00`0000000`1d_ol0oooo0?ooo`0K0?ooo`800000E03oool00`3o0000oooo0?ooo`0W
0?ooo`030000o`3oool0003o01P0oooo00<0003o0?ooo`3oool0DP3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0DP3oool000L0oooo00<0W4Q809cO
o`3oool01@3oool00`2oM0000000001d_`060?ooo`070?oog`2LB4P0W=oo0?ooo`3ookl0M01d0;oo
o`080?ooo`0309a8B02Lgol0oooo00@0oooo00H0W4Qd0;ooo`3oool0oono07@0M02ooolL0?ooo`80
0000E03oool00`3o0000oooo0?ooo`0V0?ooo`050000o`3oool0oooo0?ooo`000?l05`3oool00`00
0?l0oooo0?ooo`1A0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`1C0?ooo`001`3oool00`2LB4P0W=oo0?ooo`0?0?ooo`050?oog`2LB7@0_ooO09a8
M02oool02@3oool00`2LB4P0W=oo0?ooo`030?ooo`030?noM000M;l0oooo0080oooo00<0gia804RL
g`3oool06`3oool2000005<0oooo00<0o`000?ooo`3oool09`3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo0180oooo0P000?mD0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`1D0?ooo`001`3oool00`2LB4P0W=oo0?ooo`0@0?ooo`03
0?oo_`1d04P0W=oo00X0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`03
0?noM000M;l0oooo01/0oooo0`00001B0?ooo`030?l0003oool0oooo02H0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0<0?ooo`800000E`3oool000L0oooo00<0W4Q809cOo`3oool0
3`3oool01@3ookl0M01d0;oog`2LB4P0W=oo00T0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0
B9cO0?ooo`020?ooo`030?noM000M;l0oooo01/0oooo00<000000?ooo`3oool0D@3oool00`3o0000
oooo0?ooo`0V0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool03P3oool00`000?l0
oooo0?ooo`1D0?ooo`030000003oool0oooo00P0oooo0P0000090?ooo`<00000F@3oool000L0oooo
00<0W4Q809cOo`3oool03P3oool01`3ookl0M01d0;ooo`3oool0oooO09a8B02Lgol0203oool00`2L
B4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool06`3oool00`00
0000oooo0?ooo`1<0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool09P3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0E03oool00`00
0000oooo0?ooo`0;0?ooo`T00000G03oool000L0oooo00<0W4Q809cOo`3oool03P3oool00`2oM7@0
_ooo0?ooo`020?ooo`030?oog`2LM9`0gooo00L0oooo00<0W4Q809cOo`3oool00`3oool00`3o_g@0
B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00H0oooo00<0omnL04P0000000000P0000002018W=l0
oooo0?ooo`3ogi`0B0000000000004P0W=oo203oool00`000000oooo0?ooo`1<0?ooo`030000o`3o
ool0oooo02X0oooo00<0003o0?ooo`3oool02@3oool30000o`L0oooo10000?mG0?ooo`030000003o
ool0oooo0700oooo00040?ooo`050=nLB000000004RL09a8B02Lgol06`3oool01@3OW4P000000018
W02LB4P0W=oo00D0oooo00H0W4P007Boo`3oool0omnL04P0M02oool80?ooo`0309a80000B9`0oooo
00@0oooo00D0giad09cOo`3oool0omnL04Qd_`080?ooo`030000003oool0oooo04`0oooo00<0003o
0?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0;0?ooo`P0003oFP3oool00`000000oooo0?ooo`1a
0?ooo`001P3oool00`3OW4P0001809cOo`0M0?ooo`030=nLB00004P0W=oo00D0oooo00D0oono07@0
00000000001809cOo`020?ooo`030?oog`2LB00000000080000000H0B9cO0?ooo`3oool0gia80000
M02oool30?ooo`0509a8M02oool0oooo0?oo_`1dB9`0203oool00`000000oooo0?ooo`1<0?ooo`03
0000o`3oool0oooo02X0oooo00<0003o0?ooo`3oool0D@3oool3000001T0oooo00<000000?ooo`3o
ool0L@3oool003h0oooo00<0okmd0000M02oool00P3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;oo
o`L0oooo00<000000?ooo`3oool0C03oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo
01P0oooo00<0003o0?ooo`3oool0D@3oool2000000030?ooo`000000oooo01L0oooo00<000000?oo
o`3oool0LP3oool003l0oooo00T0okno0;ooo`3oool0oooo09a8M02oool0oooo0?oo_`1dB9`0203o
ool00`000000oooo0?ooo`1<0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`000?l06@3o
ool00`000?l0oooo0?ooo`1A0?ooo`050000003oool0oooo0?ooo`0000005`3oool00`000000oooo
0?ooo`1b0?ooo`00>`3oool01P3ookl0M01d0;ooo`3oool0_g@004RLg`80oooo00D0gia804RLg`3o
ool0okmd001d_`080?ooo`030000003oool0oooo04/0oooo0P000?l00`3oool0o`000?ooo`0;0?oo
o`050000o`3oool0oooo0?ooo`000?l05`3oool00`000?l0oooo0?ooo`1A0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool04`3oool2000007D0oooo000l0?ooo`040?noM00000000000
0018W0@0oooo00@0W4P00000000007@0_ooo203oool00`000000oooo0?ooo`1;0?ooo`80003o00<0
oooo0?l0003oool02P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01<0oooo00<0
003o0?ooo`3oool0DP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0M@3oool00500oooo00<000000?ooo`3oool0B`3oool20000o`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0
oooo0580oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo07H0oooo001@0?ooo`030000003oool0oooo04/0oooo0P000?l00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`1C0?oo
o`030000003oool0oooo00H0oooo0P00000=0?ooo`800000N@3oool00500oooo00<000000?ooo`3o
ool0B`3oool20000o`030?l0003oool0oooo00L0oooo0`000?l80?ooo`030000o`3oool0oooo00d0
oooo0P000?mE0?ooo`030000003oool0oooo00T0oooo0P0000080?ooo`<00000N`3oool00500oooo
00<000000?ooo`3oool0B`3oool00`000?l0o`000?ooo`080?ooo`030000o`3oool0oooo00X0oooo
00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`1E0?ooo`030000003oool0oooo00/0oooo
2000001n0?ooo`00D03oool00`000000oooo0?ooo`1;0?ooo`030000o`3o0000oooo00L0oooo00<0
003o0?ooo`3oool0303oool40000o`@0oooo1@000?mG0?ooo`030000003oool0oooo0980oooo001@
0?ooo`030000003oool0oooo04/0oooo0P000?l30?ooo`80003o0`3oool00`000?l0oooo0?ooo`0@
0?ooo`@0003oG03oool00`000000oooo0?ooo`2B0?ooo`00D03oool00`000000oooo0?ooo`1;0?oo
o`80003o0`3oool010000?l0oooo0000o`3oool20000oeH0oooo0P00000I0?ooo`030000003oool0
oooo09<0oooo001@0?ooo`030000003oool0oooo04X0oooo00<0003o0?ooo`000?l00P3oool01000
0?l0oooo0?ooo`3oool20000oeH0oooo00@000000?ooo`0000000000603oool00`000000oooo0?oo
o`2C0?ooo`00D03oool00`000000oooo0?ooo`1:0?ooo`060000o`3oool0oooo0000o`3oool0003o
F`3oool010000000oooo0?ooo`00000G0?ooo`030000003oool0oooo09@0oooo001@0?ooo`030000
003oool0oooo04T0oooo00<0003o0?ooo`3oool00P3oool20000oeX0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo09D0oooo001@0?ooo`030000003o
ool0oooo04T0oooo00<0003o0?ooo`3oool0GP3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0UP3oool00500oooo00<000000?ooo`3oool0B@3oool0
0`3o0000oooo0?ooo`1M0?ooo`030000003oool0oooo00@0oooo0P00000A0?ooo`030000003oool0
oooo09L0oooo001@0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo0P00002J0?ooo`00D03oool00`000000
oooo0?ooo`180?ooo`030?l0003oool0oooo05h0oooo00<000000?ooo`3oool01`3oool3000000T0
oooo0P00002L0?ooo`00D03oool00`000000oooo0?ooo`170?ooo`030?l0003oool0oooo05h0oooo
00<000000?ooo`3oool02P3oool:000009h0oooo001@0?ooo`030000003oool0oooo04L0oooo00<0
o`000?ooo`3oool0GP3oool00`000000oooo0?ooo`2b0?ooo`00D03oool00`000000oooo0?ooo`16
0?ooo`030?l0003oool0oooo05h0oooo00<000000?ooo`3oool0/`3oool00500oooo00<000000?oo
o`3oool0AP3oool00`3o0000oooo0?ooo`110?ooo`<000006@3oool00`000000oooo0?ooo`2d0?oo
o`00D03oool00`000000oooo0?ooo`150?ooo`030000o`3oool0oooo0480oooo00@000000?ooo`3o
ool00000603oool00`000000oooo0?ooo`2d0?ooo`00D03oool00`000000oooo0?ooo`150?ooo`03
0000o`3oool0oooo0440oooo00D000000?ooo`3oool0oooo0000000G0?ooo`030000003oool0oooo
0;D0oooo001@0?ooo`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool0@@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0]P3oool00500oooo
00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`2g0?ooo`00D03oool00`000000oooo0?oo
o`130?ooo`030000o`3oool0oooo0480oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0;P0oooo001@0?ooo`030000003oool0oooo04<0oooo00<0o`00
0?ooo`3oool0@@3oool00`000000oooo0?ooo`060?ooo`8000003P3oool200000;/0oooo001@0?oo
o`800000@`3oool00`000?l0o`000?ooo`120?ooo`030000003oool0oooo00P0oooo0P00000:0?oo
o`800000_@3oool00500oooo00<000000?ooo`3oool0@P3oool00`3o0000oooo0?ooo`110?ooo`03
0000003oool0oooo00/0oooo2P00002o0?ooo`00D03oool00`000000oooo0?ooo`120?ooo`030?l0
003oool0oooo0440oooo00<000000?ooo`3oool0e03oool00500oooo0P0000120?ooo`030?l0003o
ool0oooo0440oooo00<000000?ooo`3oool0e@3oool00500oooo0P0000120?ooo`030?l0003oool0
oooo02D0oooo0P00000J0?ooo`030000003oool0oooo0=D0oooo00040?ooo`030?noM00000000000
00<0000000<007Bo0?ooo`3oool00P3oool00`2oM0000000001d_`060?ooo`030;mdB02Lgol0oooo
0080oooo00<0oono07A8W03Oool0103oool00`3o_g@000000000000300000005001d_`3oool0oooo
0?ooo`3o_g@00`0000000`1d_ol0oooo0?ooo`0K0?ooo`800000@@3oool00`3o0000oooo0?ooo`0U
0?ooo`040000003oool0oooo000001P0oooo00<000000?ooo`3oool0eP3oool000L0oooo00<0W4Q8
09cOo`3oool01@3oool00`2oM0000000001d_`060?ooo`070?oog`2LB4P0W=oo0?ooo`3ookl0M01d
0;ooo`080?ooo`0309a8B02Lgol0oooo00@0oooo00H0W4Qd0;ooo`3oool0oono07@0M02ooolL0?oo
o`800000@@3oool00`3o0000oooo0?ooo`0U0?ooo`050000003oool0oooo0?ooo`0000005`3oool0
0`000000oooo0?ooo`3F0?ooo`001`3oool00`2LB4P0W=oo0?ooo`0?0?ooo`050?oog`2LB7@0_ooO
09a8M02oool02@3oool00`2LB4P0W=oo0?ooo`030?ooo`030?noM000M;l0oooo0080oooo00<0gia8
04RLg`3oool06`3oool200000400oooo00<0003o0?ooo`3oool09P3oool01@000000oooo0?ooo`3o
ool0000001D0oooo0P00003I0?ooo`001`3oool00`2LB4P0W=oo0?ooo`0@0?ooo`030?oo_`1d04P0
W=oo00X0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0
oooo01/0oooo0`00000o0?ooo`030000o`3oool0oooo02D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0=T0oooo00070?ooo`0309a8B02Lgol0oooo
00l0oooo00D0oono07@0M02ooml0W4Q809cOo`090?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia8
04RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0K0?ooo`030000003oool0oooo03l0oooo00<0003o
0?ooo`3oool09@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0fP3oool000L0oooo00<0W4Q809cOo`3oool03P3oool01`3ookl0M01d0;ooo`3oool0
oooO09a8B02Lgol0203oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0
okmd001d_`3oool06`3oool00`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo02D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0=/0oooo0007
0?ooo`0309a8B02Lgol0oooo00h0oooo00<0_gAd0;ooo`3oool00P3oool00`3ooml0W7BL0=ooo`07
0?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`07
0?ooo`0909a80000000000000000000007@0_ooo0?ooo`3ogi`0B0000080000000<0M;oo0?ooo`3o
ool01P3oool00`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo02D0oooo00<000000?ooo`3o
ool01`3oool3000000T0oooo0`00003N0?ooo`00103oool01@3OW4P000000018W02LB4P0W=oo01/0
oooo00D0gia800000000B9`0W4Q809cOo`050?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2P3o
ool02`2LB7@0_ooo0?ooo`3oool0oono07@0B02Lgol0oooo0?oo_`1d07@0_ooo00L0oooo00<00000
0?ooo`3oool0?@3oool00`3o0000oooo0?ooo`0U0?ooo`030000003oool0oooo00/0oooo2@00003Q
0?ooo`001P3oool00`3OW4P0001809cOo`0M0?ooo`030=nLB00004P0W=oo00D0oooo00D0oono07@0
00000000001809cOo`020?ooo`030?oog`2LB00000000080000000H0B9cO0?ooo`3oool0oooo09a8
M02oool70?ooo`0309a8M02oool0oooo00H0oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`020?ooo`030?l0003oool0oooo02@0oooo00<000000?ooo`3oool0mP3oool003h0oooo00<0
W4Qd0;ooo`3oool00P3oool01@3OW4P00000000000000000B9cO00P0oooo00<000000?ooo`3oool0
>03oool01@000000oooo0?ooo`3oool0o`0002L0oooo00<000000?ooo`3oool0mP3oool003h0oooo
00<0W4Qd0;ooo`3oool00P3oool00`3OW4P0M;oo0?ooo`0:0?ooo`030000003oool0oooo03P0oooo
00D000000?ooo`3oool0oooo0?l0000;0?ooo`8000006@3oool00`000000oooo0?ooo`3g0?ooo`00
?03oool0102oM000M;oo09a8M02oool30?ooo`030=nLB01d_ol0oooo00X0oooo00<000000?ooo`3o
ool0>03oool010000000oooo0?ooo`3o000;0?ooo`030000003oool0000001P0oooo00<000000?oo
o`3oool0n03oool003`0oooo00@0oono07@0000007@0_ooo0`3oool01@3OW4P000000000000004P0
W=oo00P0oooo00<000000?ooo`3oool0>03oool010000000oooo0?ooo`3o000;0?ooo`040000003o
ool0oooo000001L0oooo00<000000?ooo`3oool0n03oool00500oooo00<000000?ooo`3oool0>03o
ool00`000000oooo0?l0000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`3i0?ooo`00D03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0
003o00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`800000o03oool0
0500oooo00<000000?ooo`3oool0>03oool00`000000003o0?ooo`080?ooo`<000001`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0?`0oooo001@0?ooo`030000003oool0oooo03P0
oooo00<000000000o`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0o03oool00500oooo00<000000?ooo`3oool0>03oool00`000?l0oooo
0?ooo`060?ooo`030000003oool0oooo00/0oooo0`0000080?ooo`@00000o`3oool00500oooo00<0
00000?ooo`3oool0>03oool00`000?l000000?ooo`020?ooo`8000000P3oool00`000000oooo0?oo
o`0>0?ooo`P00000o`3oool40?ooo`00D03oool00`000000oooo0?ooo`0g0?ooo`030000o`000000
00000080oooo00@000000?ooo`000000oooo0P00003o0?oooa`0oooo001@0?ooo`030000003oool0
oooo03L0oooo00@0o`000?ooo`000000oooo0P0000020?ooo`800000o`3ooolM0?ooo`00D03oool0
0`000000oooo0?ooo`0f0?ooo`040?l000000000oooo0?ooo`800000o`3ooolR0?ooo`00D03oool0
0`000000oooo0?ooo`0f0?ooo`030?l0003oool0oooo0?l0oooo9@3oool00500oooo00<000000?oo
o`3oool0=@3oool00`3o000000000?ooo`3o0?ooobH0oooo001@0?ooo`030000003oool0oooo03D0
oooo00<0o`000?ooo`3oool0o`3ooolV0?ooo`00D03oool00`000000oooo0?ooo`0d0?ooo`030?l0
00000000oooo0?l0oooo9`3oool00500oooo00<000000?ooo`3oool0=03oool00`3o0000oooo0?oo
o`3o0?ooobL0oooo001@0?ooo`030000003oool0oooo03<0oooo00<0003o0000003oool0o`3ooolX
0?ooo`00D03oool00`000000oooo0?ooo`0c0?ooo`030000o`3oool0oooo0?l0oooo:03oool00500
oooo00<000000?ooo`3oool0<P3oool00`000?l000000?ooo`3o0?ooobT0oooo001@0?ooo`030000
003oool0oooo0380oooo00<0003o0?ooo`3oool0o`3ooolY0?ooo`00D03oool00`000000oooo0?oo
o`0a0?ooo`030000o`000000oooo0?l0oooo:P3oool00500oooo00<000000?ooo`3oool0<@3oool0
0`3o0000oooo0?ooo`3o0?ooobX0oooo001@0?ooo`030000003oool0oooo0300oooo00<0o`000000
003oool0o`3oool[0?ooo`00D03oool00`000000oooo0?ooo`0`0?ooo`030?l0003oool0oooo0?l0
oooo:`3oool00500oooo00<000000?ooo`3oool0;`3oool00`3o000000000?ooo`3o0?ooob`0oooo
001@0?ooo`030000003oool0oooo02l0oooo00<0o`000?ooo`3oool0o`3oool/0?ooo`00D03oool2
00000300oooo00<0o`000?ooo`3oool0o`3oool/0?ooo`00D03oool00`000000oooo0?ooo`0^0?oo
o`030?l0003oool0oooo0?l0oooo;@3oool00500oooo0P00000_0?ooo`030?l0003oool0oooo0?l0
oooo;@3oool00500oooo00<000000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`3o0?ooobh0oooo
00040?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool00P3oool00`2oM0000000001d
_`060?ooo`030;mdB02Lgol0oooo0080oooo00<0oono07A8W03Oool0103oool00`3o_g@000000000
000300000005001d_`3oool0oooo0?ooo`3o_g@00`0000000`1d_ol0oooo0?ooo`0K0?ooo`800000
;P3oool00`000?l0oooo0?ooo`3o0?ooobh0oooo00070?ooo`0309a8B02Lgol0oooo00D0oooo00<0
_g@000000000M;l01P3oool01`3ooml0W4Q809cOo`3oool0oono07@0M02oool0203oool00`2LB4P0
W=oo0?ooo`040?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo703oool2000002d0oooo00<0003o
0000003oool0o`3oool_0?ooo`001`3oool00`2LB4P0W=oo0?ooo`0?0?ooo`050?oog`2LB7@0_ooO
09a8M02oool02@3oool00`2LB4P0W=oo0?ooo`030?ooo`030?noM000M;l0oooo0080oooo00<0gia8
04RLg`3oool06`3oool2000002d0oooo00<0003o0?ooo`3oool0o`3oool_0?ooo`001`3oool00`2L
B4P0W=oo0?ooo`0@0?ooo`030?oo_`1d04P0W=oo00X0oooo00<0W4Q809cOo`3oool00`3oool00`3O
W4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo01/0oooo0P00000]0?ooo`030000o`3oool0oooo
0?l0oooo;`3oool000L0oooo00<0W4Q809cOo`3oool03`3oool01@3ookl0M01d0;oog`2LB4P0W=oo
00T0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo
01/0oooo0`00000[0?ooo`030?l0003oool0oooo0?l0oooo<03oool000L0oooo00<0W4Q809cOo`3o
ool03P3oool01`3ookl0M01d0;ooo`3oool0oooO09a8B02Lgol0203oool00`2LB4P0W=oo0?ooo`03
0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool06`3oool00`000000oooo0?ooo`0[
0?ooo`030?l0003oool0oooo0?l0oooo<03oool000L0oooo00<0W4Q809cOo`3oool03P3oool00`2o
M7@0_ooo0?ooo`020?ooo`030?oog`2LM9`0gooo00L0oooo00<0W4Q809cOo`3oool00`3oool00`3o
_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00L0oooo00`0W4P000000000000000000000M02o
ool0oooo0?oOW018000000000000B02Lgol80?ooo`030000003oool0oooo02X0oooo00<0o`000000
003oool0o`3ooola0?ooo`00103oool01@3OW4P000000018W02LB4P0W=oo01/0oooo00D0gia80000
0000B9`0W4Q809cOo`050?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo2P3oool00`2LB7@0_ooo
0?ooo`020?ooo`050=nLM02Lgol0oooo0?oOW018M;l0203oool00`000000oooo0?ooo`0Z0?ooo`03
0?l0003oool0oooo0?l0oooo<@3oool000H0oooo00<0gia80000B02Lgol07@3oool00`3OW4P00018
09cOo`050?ooo`050?oo_`1d000000000000B02Lgol00P3oool00`3ooml0W4P00000000200000006
04RLg`3oool0oooo0?ooo`2LB7@0_ooo0`3oool01@2LB7@0_ooo0?ooo`3ookl0M4RL00P0oooo00<0
00000?ooo`3oool0:@3oool00`3o000000000?ooo`3o0?oooc80oooo000n0?ooo`0309a8M02oool0
oooo0080oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool70?ooo`030000003oool0oooo02T0oooo
00<0o`000?ooo`3oool0o`3ooolb0?ooo`00?P3oool00`2LB7@0_ooo0?ooo`020?ooo`0509a8M02o
ool0oooo0?oo_`1dB9`0203oool00`000000oooo0?ooo`0X0?ooo`030?l000000000oooo0?l0oooo
<`3oool003`0oooo00@0_g@007Boo`2LB7@0_ooo0`3oool01@3OW4P0B9cO0?ooo`3o_g@007Bo00P0
oooo00<000000?ooo`3oool0:03oool00`3o000000000?ooo`3o0?oooc<0oooo000l0?ooo`040?oo
_`1d0000001d0;ooo`@0oooo00@0W4P00000000007@0_ooo203oool00`000000oooo0?ooo`0X0?oo
o`030000o`3oool0oooo0?l0oooo<`3oool00500oooo00<000000?ooo`3oool09`3oool00`000?l0
00000?ooo`3o0?oooc@0oooo001@0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0
o`3ooold0?ooo`00D03oool00`000000oooo0?ooo`0V0?ooo`030000o`000000oooo0?l0oooo=@3o
ool00500oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0?ooo`3o0?ooocD0oooo001@0?oo
o`030000003oool0oooo02D0oooo00<0o`000000003oool0o`3ooolf0?ooo`00D03oool00`000000
oooo0?ooo`0U0?ooo`030?l0003oool0oooo0?l0oooo=P3oool00500oooo00<000000?ooo`3oool0
903oool00`3o0000003o0?ooo`3o0?ooocL0oooo001@0?ooo`030000003oool0oooo02@0oooo00<0
o`000?ooo`3oool0o`3ooolg0?ooo`00D03oool00`000000oooo0?ooo`0T0?ooo`030?l0003oool0
oooo0?l0oooo=`3oool00500oooo00<000000?ooo`3oool08`3oool00`3o0000oooo0?ooo`3o0?oo
ocP0oooo001@0?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool0o`3ooolh0?ooo`00
D03oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0?l0oooo>@3oool00500oooo00<0
00000?ooo`3oool08P3oool00`000?l0oooo0?ooo`3o0?ooocT0oooo001@0?ooo`030000003oool0
oooo0280oooo00<0003o0?ooo`3oool0o`3oooli0?ooo`00D03oool00`000000oooo0?ooo`0Q0?oo
o`030000o`3oool0oooo0?l0oooo>P3oool00500oooo00<000000?ooo`3oool08@3oool00`000?l0
oooo0?ooo`3o0?ooocX0oooo001@0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0
o`3ooolk0?ooo`00D03oool00`000000oooo0?ooo`0P0?ooo`030?l0003oool0oooo0?l0oooo>`3o
ool00500oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`3o0?oooc`0oooo001@0?oo
o`030000003oool0oooo01l0oooo00<0o`000?ooo`3oool0o`3oooll0?ooo`00D03oool00`000000
oooo0?ooo`0N0?ooo`030?l0003oool0oooo0?l0oooo?@3oool00500oooo00<000000?ooo`3oool0
7P3oool00`3o0000oooo0?ooo`3o0?ooocd0oooo001@0?ooo`030000003oool0oooo01d0oooo00<0
o`000?ooo`3oool0o`3oooln0?ooo`00D03oool00`000000oooo0?ooo`0M0?ooo`030?l0003oool0
oooo0?l0oooo?P3oool00500oooo0P00000M0?ooo`030000o`3oool0oooo0?l0oooo?`3oool00500
oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`3o0?ooocl0oooo001@0?ooo`030000
003oool0oooo01/0oooo00<0003o0?ooo`3oool0o`3ooom00?ooo`00D03oool2000001`0oooo00<0
003o0?ooo`3oool0o`3ooom00?ooo`00D03oool2000001/0oooo00<0003o0?ooo`3oool0o`3ooom1
0?ooo`00303oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l01@3oool0
1@3o_g@00000000000000000M;oo00@0oooo00D0okmd000000000000000007Boo`040?ooo`050?no
M000000000000000001d_ol0103oool01@3o_g@00000000000000000M;oo00<0oooo00<0okmd0000
000000000`0000000`00M;l0oooo0?ooo`060?ooo`8000006`3oool00`3o0000oooo0?ooo`3o0?oo
od40oooo000<0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2oM0000000001d_`05
0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo0`3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;oo
o`<0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool30?ooo`0609a8M02oool0oooo0?oo_`1d07@0
_ooo1@3oool00`2LB4P0W=oo0?ooo`090?ooo`8000006`3oool00`3o0000oooo0?ooo`3o0?oood40
oooo000;0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool02P3oool00`3o_g@007Bo
0?ooo`020?ooo`060=nLB018W=l0oooo0?ooo`3o_g@007Bo0`3oool01P3OW4P0B9cO0?ooo`3oool0
okmd001d_`<0oooo00H0gia804RLg`3oool0oooo0?noM000M;l30?ooo`030=nLB018W=l0oooo00@0
oooo00<0W4Q809cOo`3oool02@3oool2000001X0oooo00<0o`000?ooo`3oool0o`3ooom20?ooo`00
2`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0gia804RLg`3oool0
0P3oool01P3o_g@007Bo0?ooo`3oool0gia804RLg`<0oooo00H0okmd001d_`3oool0oooo0=nLB018
W=l30?ooo`060?noM000M;l0oooo0?ooo`3OW4P0B9cO0`3oool00`3o_g@007Bo0?ooo`040?ooo`03
09a8B02Lgol0oooo00T0oooo0`00000I0?ooo`030?l0003oool0oooo0?l0oooo@P3oool000/0oooo
00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`030=nLB018W=l0oooo0080oooo
00H0okmd001d_`3oool0oooo0=nLB018W=l30?ooo`060?noM000M;l0oooo0?ooo`3OW4P0B9cO0`3o
ool01P3o_g@007Bo0?ooo`3oool0gia804RLg`<0oooo00<0okmd001d_`3oool0103oool00`2LB4P0
W=oo0?ooo`090?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0o`3ooom30?ooo`00
2`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00X0oooo00<0gia804RLg`3oool0
0P3oool01P3o_g@007Bo0?ooo`3oool0gia804RLg`<0oooo00H0okmd001d_`3oool0oooo0=nLB018
W=l30?ooo`060?noM000M;l0oooo0?ooo`3OW4P0B9cO0`3oool00`3o_g@007Bo0?ooo`040?ooo`03
09a8B02Lgol0oooo00T0oooo00<000000?ooo`3oool0603oool00`3o0000oooo0?ooo`3o0?oood<0
oooo000;0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool02P3oool00`3o_g@0B9cO
0?ooo`020?ooo`060=nLB018W=l0oooo0?ooo`3o_g@0B9cO0`3oool01P3OW4P0B9cO0?ooo`3oool0
okmd04RLg`<0oooo00H0gia804RLg`3oool0oooo0?noM018W=l30?ooo`030=nLB018W=l0oooo00@0
oooo00<0W4Q809cOo`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0oooo0?l0
ooooA03oool000`0oooo00H0W4P007Boo`3oool0omnL04P0M02oool<0?ooo`0609a8001d_ol0oooo
0?oOW01807@0_ooo0`3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`<0oooo00H0W4P007Boo`3o
ool0omnL04P0M02oool30?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo0P3oool01@3OW4P00000
0018W02LB4P0W=oo00X0oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`3o0?oood@0
oooo000<0?ooo`050?oo_`1d000000000000B02Lgol03@3oool01@3ookl0M0000000000004P0W=oo
00@0oooo00D0oono07@000000000001809cOo`040?ooo`050?oo_`1d000000000000B02Lgol0103o
ool01@3ookl0M0000000000004P0W=oo00D0oooo00<0gia80000B02Lgol02P3oool00`000000oooo
0?ooo`0F0?ooo`030000o`3oool0oooo0?l0ooooA@3oool00500oooo00<000000?ooo`3oool05P3o
ool00`000?l0oooo0?ooo`3o0?ooodD0oooo001@0?ooo`030000003oool0oooo01D0oooo00<0003o
0?ooo`3oool0o`3ooom60?ooo`00D03oool00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo
0?l0ooooAP3oool00500oooo00<000000?ooo`3oool0503oool00`000?l0oooo0?ooo`3o0?ooodL0
oooo001@0?ooo`030000003oool0oooo01@0oooo00<0o`000?ooo`3oool0o`3ooom70?ooo`00D03o
ool00`000000oooo0?ooo`0C0?ooo`030?l0003oool0oooo0?l0ooooB03oool00500oooo00<00000
0?ooo`3oool04`3oool00`3o0000oooo0?ooo`3o0?ooodP0oooo001@0?ooo`030000003oool0oooo
0180oooo00<0o`000000o`3oool0o`3ooom90?ooo`00D03oool00`000000oooo0?ooo`0B0?ooo`03
0?l0003oool0oooo0?l0ooooB@3oool00500oooo00<000000?ooo`3oool04@3oool00`3o0000003o
0?ooo`3o0?ooodX0oooo001@0?ooo`030000003oool0oooo0140oooo00<0o`000?ooo`3oool0o`3o
oom:0?ooo`00D03oool00`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0?l0ooooBP3oool0
0500oooo00<000000?ooo`3oool0403oool00`000?l0oooo0?ooo`3o0?oood/0oooo001@0?ooo`03
0000003oool0oooo0100oooo00<0003o0?ooo`3oool0o`3ooom;0?ooo`00D03oool00`000000oooo
0?ooo`0?0?ooo`030000o`3oool0oooo0?l0ooooC03oool00500oooo00<000000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`3o0?oood`0oooo001@0?ooo`030000003oool0oooo00h0oooo00<0003o
0?ooo`3oool0o`3ooom=0?ooo`00D03oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo
0?l0ooooC@3oool00500oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`3o0?ooodh0
oooo001@0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool0o`3ooom>0?ooo`00D03o
ool00`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo0?l0ooooC`3oool00500oooo00<00000
0?ooo`3oool0303oool00`3o0000oooo0?ooo`3o0?ooodl0oooo001@0?ooo`030000003oool0oooo
00/0oooo00<0o`000000o`3oool0o`3ooom@0?ooo`00D03oool00`000000oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo0?l0ooooD03oool00500oooo00<000000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`3o0?oooe00oooo001@0?ooo`030000003oool0oooo00X0oooo00<0003o0?ooo`3oool0o`3o
oomA0?ooo`00D03oool00`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo0?l0ooooD@3oool0
0500oooo00<000000?ooo`3oool02@3oool00`000?l0oooo0?ooo`3o0?oooe80oooo001@0?ooo`80
00002P3oool00`000?l0oooo0?ooo`3o0?oooe80oooo001@0?ooo`030000003oool0oooo00P0oooo
00<0o`000?ooo`3oool0o`3ooomC0?ooo`00D03oool2000000T0oooo00<0o`000?ooo`3oool0o`3o
oomC0?ooo`00D03oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo0?l0ooooE03oool0
0500oooo0P0000080?ooo`030?l0003oool0oooo0?l0ooooE03oool00440oooo00<0okmd00000000
00000`0000000`00M;l0oooo0?ooo`060?ooo`8000001`3oool00`3o0000oooo0?ooo`3o0?oooeD0
oooo00140?ooo`0309a8B02Lgol0oooo00T0oooo0P0000070?ooo`030?l0003oool0oooo0?l0oooo
E@3oool004@0oooo00<0W4Q809cOo`3oool02@3oool2000000H0oooo00<0o`000?ooo`3oool0o`3o
oomF0?ooo`00A03oool00`2LB4P0W=oo0?ooo`090?ooo`<000001@3oool00`3o0000oooo0?ooo`3o
0?oooeH0oooo00140?ooo`0309a8B02Lgol0oooo00T0oooo00<000000?ooo`3oool0o`3ooomN0?oo
o`00A03oool00`2LB4P0W=oo0?ooo`090?ooo`030000003oool0oooo0?l0ooooGP3oool004@0oooo
00<0W4Q809cOo`3oool02@3oool00`000000oooo0?ooo`3o0?oooeh0oooo00110?ooo`050=nLB000
000004RL09a8B02Lgol02P3oool00`000000oooo0?ooo`3o0?oooeh0oooo00130?ooo`030=nLB000
04P0W=oo00X0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`00D03oool00`000000oooo0?ooo`3o
0?oooeh0oooo001@0?ooo`030000003oool0oooo0?l0ooooGP3oool00500oooo00<000000?ooo`3o
ool0o`3ooomN0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.66274, -28.9904, \
0.0450099, 0.180335}}]
}, Closed]],

Cell["\<\
Notice that the working precision must be about twice the accuracy or \
precision goal for these to be completely effective.  When a symbolic \
solution is not available, one can compare results for two values of the \
accuracy or precision goals to evaluate the probable range of validity for a \
numerical solution.  However, if one really needs to push the limits of \
numerical methods, it is probably better to reformulate the problem!\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DisplayTogether[\[IndentingNewLine]LogPlot[
          Evaluate[
            Abs[1 - stiffSol[20, 10, PrecisionGoal \[Rule] 10, 
                    WorkingPrecision \[Rule] 20]/
                  stiffSol[20, 10, PrecisionGoal \[Rule] 20, 
                    WorkingPrecision \[Rule] 40]]], {x, 0, 2}, 
          PlotRange \[Rule] {Automatic, {10\^\(-10\), 
                10\^1}}], \[IndentingNewLine]LogPlot[
          Evaluate[
            Abs[1 - stiffSol[20, 10]/
                  stiffSol[20, 10, PrecisionGoal \[Rule] 20, 
                    WorkingPrecision \[Rule] 40]]], {x, 0, 2}, 
          PlotRange \[Rule] {Automatic, {10\^\(-10\), 10\^1}}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.561849 0.0561849 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[-0.0125 .11237 -46.5 -6.6875 ]
[-0.0125 .11237 0 6.6875 ]
[-0.0125 .22474 -46.5 -6.6875 ]
[-0.0125 .22474 0 6.6875 ]
[-0.0125 .33711 -40 -6.28125 ]
[-0.0125 .33711 0 6.28125 ]
[-0.0125 .44948 -28 -6.28125 ]
[-0.0125 .44948 0 6.28125 ]
[-0.0125 .56185 -10 -6.28125 ]
[-0.0125 .56185 0 6.28125 ]
[ -0.0005 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11237 m
.00625 .11237 L
s
gsave
-0.0125 .11237 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .22474 m
.00625 .22474 L
s
gsave
-0.0125 .22474 -107.5 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .33711 m
.00625 .33711 L
s
gsave
-0.0125 .33711 -101 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .44948 m
.00625 .44948 L
s
gsave
-0.0125 .44948 -89 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .56185 m
.00625 .56185 L
s
gsave
-0.0125 .56185 -71 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .06063 m
.00375 .06063 L
s
0 .07651 m
.00375 .07651 L
s
0 .08605 m
.00375 .08605 L
s
0 .09289 m
.00375 .09289 L
s
0 .09822 m
.00375 .09822 L
s
0 .1026 m
.00375 .1026 L
s
0 .10631 m
.00375 .10631 L
s
0 .10953 m
.00375 .10953 L
s
0 .173 m
.00375 .173 L
s
0 .18888 m
.00375 .18888 L
s
0 .19842 m
.00375 .19842 L
s
0 .20526 m
.00375 .20526 L
s
0 .21059 m
.00375 .21059 L
s
0 .21497 m
.00375 .21497 L
s
0 .21868 m
.00375 .21868 L
s
0 .2219 m
.00375 .2219 L
s
0 .28537 m
.00375 .28537 L
s
0 .30125 m
.00375 .30125 L
s
0 .31079 m
.00375 .31079 L
s
0 .31763 m
.00375 .31763 L
s
0 .32296 m
.00375 .32296 L
s
0 .32734 m
.00375 .32734 L
s
0 .33105 m
.00375 .33105 L
s
0 .33427 m
.00375 .33427 L
s
0 .39774 m
.00375 .39774 L
s
0 .41362 m
.00375 .41362 L
s
0 .42316 m
.00375 .42316 L
s
0 .43 m
.00375 .43 L
s
0 .43533 m
.00375 .43533 L
s
0 .43971 m
.00375 .43971 L
s
0 .44342 m
.00375 .44342 L
s
0 .44664 m
.00375 .44664 L
s
0 .51011 m
.00375 .51011 L
s
0 .52599 m
.00375 .52599 L
s
0 .53553 m
.00375 .53553 L
s
0 .54236 m
.00375 .54236 L
s
0 .5477 m
.00375 .5477 L
s
0 .55208 m
.00375 .55208 L
s
0 .55579 m
.00375 .55579 L
s
0 .55901 m
.00375 .55901 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02633 0 m
.02729 .0064 L
.02846 .00028 L
s
.02846 .00028 m
.02848 0 L
s
.08108 0 m
.08131 .00136 L
.08257 .00114 L
s
.08257 .00114 m
.08301 0 L
s
.08334 0 m
.08394 .00659 L
.08519 .00564 L
.08589 .00462 L
.08654 .01053 L
.08725 .01193 L
.088 .0084 L
.08925 .0145 L
.09041 .01272 L
.09169 .01669 L
.09241 .01785 L
.09307 .01546 L
.09374 .01588 L
.09446 .02003 L
.09575 .01786 L
.09654 .01983 L
.09729 .02266 L
.09796 .02164 L
.09868 .02025 L
.09939 .02357 L
.10017 .02463 L
.10099 .02248 L
.10175 .02448 L
.10246 .02662 L
.10312 .02576 L
.10387 .02463 L
.10458 .0275 L
.10572 .02754 L
.10694 .02829 L
.1081 .02971 L
.10916 .02859 L
.11033 .03157 L
.11162 .02997 L
.11227 .03212 L
.11297 .03301 L
.11422 .03154 L
.11491 .0337 L
.11554 .03438 L
.11624 .03329 L
.11698 .03337 L
.11822 .03563 L
.11892 .0341 L
.11958 .03467 L
.12446 .04051 L
.1256 .04164 L
.12684 .04403 L
.12801 .04259 L
.1291 .04593 L
.13018 .04515 L
.13115 .04534 L
Mistroke
.13228 .04785 L
.13334 .04657 L
.1345 .04907 L
.13573 .04926 L
.13677 .04895 L
.13792 .05127 L
.13916 .05008 L
.13985 .05129 L
.14048 .05279 L
.14171 .05199 L
.14288 .05331 L
.14402 .05417 L
.14525 .05357 L
.14641 .05566 L
.14747 .05479 L
.14865 .05628 L
.14994 .05661 L
.15059 .05601 L
.15129 .05703 L
.15254 .05805 L
.1628 .06735 L
.18123 .07931 L
.20115 .09406 L
.20661 .09734 L
.21239 .10017 L
.22274 .10388 L
.24342 .11032 L
.25352 .11327 L
.26275 .11589 L
.26387 .11596 L
.26492 .11582 L
.26614 .11658 L
.26724 .1168 L
.26846 .11779 L
.26977 .12175 L
.271 .12348 L
.27213 .12346 L
.2732 .12443 L
.27419 .12625 L
.27529 .12693 L
.27646 .12472 L
.27769 .11763 L
.27885 .11331 L
.27989 .11254 L
.28103 .10011 L
.28216 .01836 L
.28338 .0723 L
.28408 .0754 L
.28472 .08853 L
.28598 .11084 L
Mistroke
.28727 .1176 L
.28799 .11782 L
.28867 .11978 L
.28991 .12744 L
.29123 .13176 L
.29245 .13227 L
.29377 .13628 L
.29502 .13957 L
.29617 .14002 L
.29721 .14133 L
.29835 .14451 L
.29954 .14629 L
.30065 .14671 L
.30191 .15348 L
.3026 .15872 L
.30325 .1626 L
.30439 .16564 L
.30566 .16596 L
.30632 .16671 L
.30702 .1679 L
.30827 .16973 L
.30897 .17013 L
.30962 .17019 L
.31034 .17035 L
.3111 .17127 L
.31619 .17693 L
.321 .18084 L
.32326 .18191 L
.3245 .182 L
.32566 .18317 L
.32691 .18521 L
.32758 .18594 L
.32829 .18624 L
.33072 .18714 L
.33955 .19099 L
.34076 .19223 L
.34208 .19321 L
.34331 .19333 L
.34445 .19362 L
.34509 .19395 L
.34579 .1943 L
.34651 .19455 L
.34719 .19464 L
.34839 .1947 L
.34967 .19548 L
.35041 .19614 L
.35121 .19669 L
.35197 .19692 L
.35267 .19694 L
.3533 .19734 L
Mistroke
.354 .19907 L
.35472 .2021 L
.3554 .20521 L
.35605 .20772 L
.35674 .20944 L
.35796 .2102 L
.35928 .20994 L
.36002 .20941 L
.36071 .20867 L
.36197 .20732 L
.36268 .20694 L
.36334 .20688 L
.36454 .2044 L
.36581 .18939 L
.36687 .1384 L
.36802 .16622 L
.36927 .16957 L
.37044 .18262 L
.37108 .19165 L
.37177 .1994 L
.37252 .20497 L
.37322 .20748 L
.37448 .20811 L
.37519 .20905 L
.37586 .21107 L
.37702 .21576 L
.37824 .21927 L
.37888 .21991 L
.37958 .21999 L
.38081 .22101 L
.42133 .25781 L
.46033 .30241 L
.47055 .30573 L
.472 .30652 L
.4727 .30688 L
.47335 .30713 L
.47403 .30728 L
.47476 .30734 L
.47556 .30733 L
.47632 .30756 L
.47764 .3097 L
.47886 .31352 L
.4802 .31801 L
.4809 .31995 L
.48164 .32147 L
.4823 .3223 L
.48301 .32271 L
.48428 .32276 L
.48556 .32232 L
.48676 .32088 L
Mistroke
.48793 .31844 L
.48899 .31568 L
.49023 .31282 L
.49139 .31143 L
.49265 .31127 L
.49328 .31103 L
.49398 .31015 L
.49521 .30632 L
.49637 .29943 L
.50178 .26811 L
.50295 .26657 L
.50406 .26191 L
.50533 .25081 L
.50648 .23198 L
.50776 .18537 L
.50848 .14042 L
.50914 .15153 L
.51035 .23221 L
.51162 .27175 L
.51285 .29232 L
.51417 .305 L
.51541 .31108 L
.51655 .31296 L
.52197 .32107 L
.54048 .36001 L
.54159 .37307 L
.54276 .38222 L
.54405 .38838 L
.54523 .39124 L
.54633 .39207 L
.54736 .3921 L
.54849 .39217 L
.5497 .39245 L
.55036 .39269 L
.55108 .39302 L
.55239 .39372 L
.55358 .39431 L
.55485 .39476 L
.556 .39493 L
.55727 .39492 L
.55842 .39485 L
.55951 .39392 L
.56017 .39251 L
.56089 .38998 L
.56221 .38163 L
.5635 .36502 L
.56469 .31142 L
.56542 .33888 L
.56611 .35528 L
.56739 .36466 L
Mistroke
.56811 .36549 L
.56877 .36547 L
.5695 .36558 L
.57027 .3663 L
.57146 .36908 L
.57273 .37378 L
.57383 .37823 L
.57503 .38251 L
.57575 .38459 L
.57643 .38608 L
.57707 .38709 L
.57776 .38775 L
.57894 .38807 L
.58025 .38852 L
.58156 .39161 L
.5828 .39734 L
.58423 .40542 L
.58553 .41243 L
.58668 .41764 L
.58789 .4219 L
.58853 .4236 L
.58922 .42504 L
.59045 .42657 L
.59173 .42703 L
.59245 .42705 L
.5931 .42713 L
.59438 .4281 L
.59558 .43041 L
.59626 .43222 L
.59698 .43444 L
.59827 .43871 L
.5998 .4434 L
.60047 .44514 L
.6012 .44674 L
.60242 .44865 L
.6037 .44965 L
.60437 .44983 L
.60509 .44986 L
.6064 .44979 L
.60771 .44914 L
.60896 .44756 L
.61007 .4451 L
.61129 .44113 L
.61356 .42963 L
.61475 .42178 L
.616 .41366 L
.61711 .4089 L
.61831 .40759 L
.61941 .40718 L
.62043 .40331 L
Mistroke
.6216 .385 L
.62267 .37873 L
.6239 .41658 L
.62506 .43221 L
.62634 .4428 L
.62751 .44907 L
.6288 .45319 L
.62945 .45437 L
.63017 .4551 L
.63149 .4554 L
.63275 .45561 L
.63344 .45615 L
.6342 .45724 L
.63552 .46039 L
.63814 .46905 L
.63938 .47288 L
.64052 .47578 L
.64167 .47796 L
.64292 .47938 L
.64402 .47989 L
.64519 .47996 L
.64641 .47994 L
.64756 .4798 L
.64881 .4794 L
.64952 .47904 L
.65016 .47864 L
.65441 .47458 L
.65557 .47351 L
.65682 .47268 L
.65801 .47231 L
.65909 .47226 L
.66027 .47209 L
.66157 .4709 L
.66279 .46809 L
.66392 .46335 L
.66458 .4592 L
.6653 .45305 L
.66661 .43293 L
.66787 .39497 L
.66904 .43614 L
.67007 .44618 L
.6712 .45056 L
.67239 .4515 L
.67349 .45154 L
.67469 .45268 L
.67578 .45546 L
.67704 .46046 L
.67823 .46597 L
.68074 .47643 L
.682 .4802 L
Mistroke
.68273 .4818 L
.6834 .48293 L
.6846 .48412 L
.6857 .48445 L
.68691 .48446 L
.68819 .48458 L
.68948 .48506 L
.69021 .48553 L
.69086 .48608 L
.69336 .48883 L
.69475 .49044 L
.69549 .49119 L
.69627 .49187 L
.69695 .49233 L
.6977 .49271 L
.69901 .49302 L
.70022 .49304 L
.70151 .49308 L
.70225 .49318 L
.70292 .49335 L
.70423 .49391 L
.70545 .49469 L
.70677 .49571 L
.70792 .49664 L
.70917 .49757 L
.71039 .49828 L
.71153 .4987 L
.71273 .49889 L
.71401 .49891 L
.71521 .49896 L
.71634 .49917 L
.71735 .49956 L
.71846 .50021 L
.72118 .50243 L
.72251 .50353 L
.72373 .50435 L
.72501 .50492 L
.72568 .50508 L
.72638 .50517 L
.72711 .50519 L
.72779 .50518 L
.72853 .50513 L
.72932 .50499 L
.73062 .50447 L
.73135 .50394 L
.73202 .50325 L
.73326 .50128 L
.73458 .49773 L
.73575 .49231 L
.73685 .48337 L
Mistroke
.73804 .46011 L
.73935 .46568 L
.74061 .4938 L
.74129 .5027 L
.74194 .50946 L
.74434 .52784 L
.74696 .54218 L
.74978 .55445 L
.7546 .57114 L
.75967 .58517 L
.76934 .60552 L
Mfstroke
.76934 .60552 m
.77769 .61803 L
s
.02444 0 m
.02499 .13078 L
.02605 .13016 L
.02729 .1297 L
.02846 .12218 L
.02954 .11558 L
.03053 .13137 L
.03163 .13377 L
.03279 .13562 L
.03395 .13704 L
.0352 .13851 L
.03638 .13936 L
.03746 .14028 L
.03873 .14638 L
.03944 .14879 L
.04011 .14856 L
.04132 .14002 L
.04262 .13717 L
.04327 .14014 L
.04396 .142 L
.04519 .14003 L
.04588 .13858 L
.04652 .13861 L
.04722 .13901 L
.04797 .13923 L
.04862 .13919 L
.04933 .13905 L
.05061 .1389 L
.05186 .13847 L
.05302 .13835 L
.05414 .13826 L
.05519 .13796 L
.05634 .1377 L
.05759 .13472 L
.05882 .13349 L
.06012 .13093 L
.06244 .12742 L
.06509 .12179 L
.06633 .11668 L
.06748 .11548 L
.06813 .1121 L
.06881 .10787 L
.0695 .10664 L
.07025 .10494 L
.07091 .09911 L
.07161 .09133 L
.07287 .08707 L
.07411 .04475 L
s
.07411 .04475 m
.07473 0 L
s
.07499 0 m
.07547 .01704 L
.07676 .07767 L
.07794 .08806 L
.07909 .06686 L
.08018 .0879 L
.08133 .09521 L
.08257 .10612 L
.08323 .11186 L
.08395 .11379 L
.08523 .11486 L
.08815 .11754 L
.08891 .11828 L
.08973 .11868 L
.09051 .11871 L
.09123 .11891 L
.09188 .11913 L
.09259 .11916 L
.09334 .11914 L
.09404 .11942 L
.09533 .12094 L
.09598 .12125 L
.09669 .1213 L
.09795 .12225 L
.09912 .12279 L
.09983 .12292 L
.1005 .12419 L
.10176 .12814 L
.10246 .12917 L
.10311 .12929 L
.10383 .12967 L
.10458 .13084 L
.1058 .1324 L
.10648 .13255 L
.10712 .13266 L
.10829 .13429 L
.10953 .13577 L
.11063 .13594 L
.11167 .13709 L
.11281 .13858 L
.11404 .13887 L
.11527 .13978 L
.11662 .14097 L
.11934 .14269 L
.12419 .14554 L
.12532 .14572 L
.12655 .14683 L
.12771 .14745 L
.12878 .14769 L
.13003 .15049 L
Mistroke
.13135 .15339 L
.13246 .15372 L
.13368 .15453 L
.14252 .16109 L
.16357 .17649 L
.18283 .1874 L
.19234 .19187 L
.19493 .19265 L
.19736 .19359 L
.19802 .19362 L
.19871 .19396 L
.19947 .19473 L
.20017 .19557 L
.20139 .19653 L
.20208 .19665 L
.20272 .19667 L
.20399 .19699 L
.20519 .19745 L
.20628 .19764 L
.20745 .19767 L
.20873 .19823 L
.20937 .19874 L
.21009 .19927 L
.21134 .19971 L
.21252 .19977 L
.21364 .20025 L
.21481 .20093 L
.21581 .20124 L
.2169 .20127 L
.21808 .20152 L
.21935 .20203 L
.22054 .20229 L
.22162 .20232 L
.22281 .20269 L
.22393 .20347 L
.22516 .20408 L
.22647 .20416 L
.22713 .20425 L
.22785 .20446 L
.22916 .20491 L
.23043 .20508 L
.23161 .20513 L
.23282 .20558 L
.23395 .20613 L
.23497 .20637 L
.23607 .20639 L
.23728 .20672 L
.23855 .20734 L
.23963 .20763 L
.24082 .20765 L
Mistroke
.24149 .20774 L
.24222 .20794 L
.24286 .20815 L
.24354 .20834 L
.24483 .20846 L
.24602 .20852 L
.24668 .20873 L
.24739 .20908 L
.24867 .20961 L
.24945 .20971 L
.25019 .20972 L
.25086 .21021 L
.25159 .21184 L
.25288 .21645 L
.2541 .2199 L
.25478 .22074 L
.25551 .22091 L
.25679 .22072 L
.25801 .21987 L
.2593 .21848 L
.26041 .21766 L
.26162 .21743 L
.26413 .19572 L
.26481 .17233 L
.26545 .13108 L
.26612 .16862 L
.26686 .17258 L
.2681 .17963 L
.26879 .18951 L
.26943 .19844 L
.2706 .20994 L
.27182 .21479 L
.27293 .21526 L
.27412 .21724 L
.27524 .22125 L
.27626 .22475 L
.27746 .22682 L
.27876 .22718 L
.27999 .22885 L
.28112 .23168 L
.28233 .23426 L
.28362 .23519 L
.28474 .23545 L
.28596 .23641 L
.2867 .23727 L
.28738 .23806 L
.28804 .23866 L
.28874 .23903 L
.28942 .23918 L
.29007 .23939 L
Mistroke
.29128 .2414 L
.29258 .24543 L
.29379 .24864 L
.29506 .24992 L
.29573 .25004 L
.29645 .25026 L
.29723 .25072 L
.29797 .25134 L
.29869 .25202 L
.29936 .25262 L
.30064 .25336 L
.30132 .25353 L
.30203 .25373 L
.30317 .25437 L
.30442 .25548 L
.30693 .25722 L
.31142 .26153 L
.31631 .2646 L
.32153 .26856 L
.3265 .27361 L
.32885 .27644 L
.33101 .2788 L
.33207 .28021 L
.33319 .28368 L
.33431 .28888 L
.33555 .29467 L
.33661 .29853 L
.33776 .30104 L
.33884 .30212 L
.33982 .30258 L
.341 .30119 L
.3421 .29693 L
.34331 .28868 L
.34462 .27762 L
.34591 .27299 L
.34656 .27489 L
.34727 .27754 L
.34854 .27586 L
.34971 .25638 L
.35091 .25495 L
.35203 .28016 L
.35304 .28646 L
.35414 .2848 L
.35534 .27706 L
.3566 .25939 L
.35768 .21919 L
.35888 .27305 L
.35954 .28334 L
.36026 .2911 L
.36157 .30045 L
Mistroke
.36285 .3067 L
.36404 .31166 L
.36959 .331 L
.37962 .35689 L
.41876 .44099 L
.46035 .52563 L
.50042 .60983 L
Mfstroke
.50042 .60983 m
.50437 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00D03oool0
1@3o_g@00000000000000000M;oo04L0oooo00D0okmd000000000000000007Boo`050?ooo`030;md
0000000007Bo00D0oooo00D0_g@0000000000000000007Boo`160?ooo`030?noM0000000000000<0
000000<007Bo0?ooo`3oool0@`3oool00`3o_g@000000000000300000003001d_`3oool0oooo0080
oooo00<0_g@000000000M;l01@3oool01@2oM0000000000000000000M;oo04D0oooo00<0oono07@0
00000000100000000`1d_ol0oooo0?ooo`040?ooo`00D03oool01P2LB7@0_ooo0?ooo`3ookl0M01d
0;ooodH0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00@0oooo
00L0_g@0001d_`3oool0oooo0?oOW0180000M;oo04P0oooo00<0W4Q809cOo`3oool0B@3oool00`2L
B4P0W=oo0?ooo`050?ooo`030;md0000000007Bo00@0oooo00L0_g@0001d_`3oool0oooo0?oOW018
0000M;oo04D0oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?ooo`050?ooo`00C`3oool0
0`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo04@0oooo00<0okmd001d_`3oool00P3oool0
0`3OW4P0B9cO0?ooo`0?0?ooo`030?noM000M;l0oooo04L0oooo00<0W4Q809cOo`3oool0B@3oool0
0`2LB4P0W=oo0?ooo`0A0?ooo`030?noM000M;l0oooo04D0oooo00<0okmd0000B02Lgol02@3oool0
04l0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`140?ooo`030=nLB018W=l0oooo
0080oooo00<0okmd001d_`3oool03`3oool00`3o_g@007Bo0?ooo`170?ooo`0309a8B02Lgol0oooo
04T0oooo00<0W4Q809cOo`3oool04@3oool00`3o_g@007Bo0?ooo`160?ooo`030?oOW0180000B9cO
00P0oooo001?0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0A03oool00`3OW4P0
B9cO0?ooo`020?ooo`030?noM000M;l0oooo00l0oooo00<0W4P007Boo`3oool0A`3oool00`2LB4P0
W=oo0?ooo`190?ooo`0309a8B02Lgol0oooo0140oooo00<0W4P007Boo`3oool0B03oool00`2LB000
B9cO0?ooo`060?ooo`00C`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo04@0oooo
00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`030?oo_`1d0000000000800000
00<0B9cO0?ooo`3oool0A`3oool00`2LB4P0W=oo0?ooo`190?ooo`0309a8B02Lgol0oooo00`0oooo
00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`190?ooo`0309a8M02oool0oooo00D0oooo
001?0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool0A03oool00`3o_g@0B9cO0?oo
o`020?ooo`030=nLB018W=l0oooo00X0oooo00<0oono07@0M02oool0C03oool00`2LB4P0W=oo0?oo
o`190?ooo`0309a8B02Lgol0oooo00`0oooo00<0oono07@0M02oool0B@3oool00`3OW4P0M;oo0?oo
o`020?ooo`030;md001d_ol0oooo00D0oooo001@0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo
AP3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00<0oono07@0M02oool0B@3oool01@3O
W4P000000018W02LB4P0W=oo04L0oooo00D0gia800000000B9`0W4Q809cOo`0=0?ooo`030?oo_`1d
07@0_ooo04T0oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo00H0oooo001@0?ooo`050?oo
_`1d000000000000B02Lgol0A`3oool01@3ookl0M0000000000004P0W=oo00`0oooo00<0oono07@0
000000000P0000000`0007@0_ooo0?ooo`160?ooo`030=nLB00004P0W=oo04T0oooo00<0gia80000
B02Lgol03@3oool00`3ookl0M00000000002000000030000M02oool0oooo04D0oooo00D0okmd0000
00000000001809cOo`070?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00BP3ooooo000006L00000
001:0?ooo`030000003oool0oooo00D0oooo0`00000>0?ooo`8000000P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00L0oooo001:0?ooo`030000003oool0oooo00D0oooo0P00000?
0?ooo`8000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo001:0?oo
o`030000003oool0oooo00D0oooo0P00000@0?ooo`040000003oool0oooo0?ooo`800000?@3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0DP3oool0
0`000000oooo0?ooo`070?ooo`00BP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00l0oooo0P0000030?ooo`030000003oool0oooo0?l0ooooA@3oool004X0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0?0?ooo`8000000`3oool200000?l0ooooAP3oool004X0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`800000103oool200000?l0oooo
A@3oool004X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`8000001@3o
ool200000440oooo00<000000?ooo`3oool0o`3oool004X0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0?0?ooo`8000001P3oool3000003l0oooo00<000000?ooo`3oool0o`3oool0
04X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`8000001`3oool30000
03h0oooo00<000000?ooo`3oool0o`3oool004X0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0?0?ooo`800000203oool4000003`0oooo00<000000?ooo`3oool0o`3oool004X0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`8000002P3oool3000003/0oooo
00<000000?ooo`3oool0o`3oool004X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0?0?ooo`8000002`3oool4000003T0oooo00<000000?ooo`3oool0o`3oool004X0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`8000003@3oool2000003T0oooo00<00000
0?ooo`3oool0o`3oool004X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?oo
o`8000003`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0?l0oooo001:0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool200000100oooo0P00000f0?ooo`03
0000003oool0oooo0?l0oooo001:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3`3oool200000140oooo0`00000d0?ooo`030000003oool0oooo0?l0oooo001:0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool03`3oool200000180oooo0P00000d0?ooo`800000o`3o
ool10?ooo`00BP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo0P00000D
0?ooo`800000<P3oool200000?l0oooo0@3oool004X0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0?0?ooo`8000005@3oool4000002l0oooo0P00003o0?ooo`40oooo001:0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool2000001L0oooo0`00000^0?ooo`80
0000o`3oool10?ooo`00BP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo
0P00000J0?ooo`030000003oool0oooo02/0oooo0P00003o0?ooo`40oooo001:0?ooo`8000001P3o
ool00`000000oooo0?ooo`0?0?ooo`8000006`3oool00`000000oooo0?ooo`0Z0?ooo`800000o`3o
ool10?ooo`00BP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo0P00000L
0?ooo`800000:P3oool200000?l0oooo0@3oool004X0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0>0?ooo`<000007@3oool00`000000oooo0?ooo`0W0?ooo`800000o`3oool10?oo
o`00BP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo0`00000N0?ooo`03
0000003oool0oooo02H0oooo0P00003o0?ooo`40oooo001:0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool03P3oool3000001l0oooo00<000000?ooo`3oool09@3oool200000?l0oooo
0@3oool004X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`<00000803o
ool2000002D0oooo0P00003o0?ooo`40oooo001:0?ooo`8000001`3oool00`000000oooo0?ooo`0>
0?ooo`<000008P3oool00`000000oooo0?ooo`0R0?ooo`800000o`3oool10?ooo`00BP3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo0`00000S0?ooo`030000003oool0oooo
0240oooo0P00003o0?ooo`40oooo001:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool03P3oool3000002@0oooo0P00000Q0?ooo`800000o`3oool10?ooo`00BP3oool2000000L0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0000000V0?ooo`030000003oool0oooo01h0oooo
0P00003o0?ooo`40oooo001:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3o
ool010000000oooo0?ooo`00000W0?ooo`030000003oool0oooo01d0oooo0P00003o0?ooo`40oooo
001:0?ooo`8000001`3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000002P0oooo
0P00000M0?ooo`800000o`3oool10?ooo`00BP3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00d0oooo00D000000?ooo`3oool0oooo0000000Y0?ooo`030000003oool0oooo01X0oooo
0P00003o0?ooo`40oooo001:0?ooo`8000001`3oool00`000000oooo0?ooo`0=0?ooo`050000003o
ool0oooo0?ooo`000000:P3oool2000001X0oooo0P00003o0?ooo`40oooo001:0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000002`0oooo
0`00000G0?ooo`800000o`3oool10?ooo`00103oool00`3o_g@000000000000300000003001d_`3o
ool0oooo0080oooo00<0_g@000000000M;l01P3oool00`2oM4P0W=oo0?ooo`020?ooo`030?oo_`1d
B9`0gooo00@0oooo00<0okmd0000000000000`0000001@00M;l0oooo0?ooo`3oool0okmd00<00000
00<0M;oo0?ooo`3oool05@3oool2000000L0oooo00<000000?ooo`3oool03@3oool01@000000oooo
0?ooo`3oool0000002l0oooo1000000C0?ooo`030000003oool000000?l0oooo00070?ooo`0309a8
B02Lgol0oooo00D0oooo00<0_g@000000000M;l01P3oool01`3ooml0W4Q809cOo`3oool0oono07@0
M02oool0203oool00`2LB4P0W=oo0?ooo`040?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo5P3o
ool2000000L0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000003<0oooo
0P00000A0?ooo`030000003oool000000?l0oooo00070?ooo`0309a8B02Lgol0oooo00l0oooo00D0
oooO09a8M02ooml0W4Qd0;ooo`090?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd001d_`3oool0
0P3oool00`3OW4P0B9cO0?ooo`0E0?ooo`8000001`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0<`3oool3000000h0oooo00<000000?ooo`000000
o`3oool000L0oooo00<0W4Q809cOo`3oool0403oool00`3ookl0M01809cOo`0:0?ooo`0309a8B02L
gol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0E0?ooo`<000001P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=P3o
ool3000000/0oooo00<000000?ooo`000000o`3oool000L0oooo00<0W4Q809cOo`3oool03`3oool0
1@3ookl0M01d0;oog`2LB4P0W=oo00T0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?oo
o`020?ooo`030?noM000M;l0oooo01D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0>03oool3000000L0oooo00@0
00000?ooo`3oool00000o`3oool000L0oooo00<0W4Q809cOo`3oool03P3oool01`3ookl0M01d0;oo
o`3oool0oooO09a8B02Lgol0203oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080
oooo00<0okmd001d_`3oool05@3oool00`000000oooo0?ooo`060?ooo`800000303oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo03X0oooo100000030?ooo`040000003oool0oooo0000
0?l0oooo00070?ooo`0309a8B02Lgol0oooo00h0oooo00<0_gAd0;ooo`3oool00P3oool00`3ooml0
W7BL0=ooo`070?ooo`0309a8B02Lgol0oooo00<0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0
B9cO0?ooo`070?ooo`050=nLB000000000000000001d_ol02@3oool00`000000oooo0?ooo`060?oo
o`800000303oool00`000000oooo0?ooo`060?ooo`<00000?03oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool0o03oool000@0oooo00D0gia800000000B9`0W4Q809cOo`0K
0?ooo`050=nLB000000004RL09a8B02Lgol01@3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`P0
oooo00D0W7BL0?ooo`3oool0oono07Ad_`090?ooo`030000003oool0oooo00H0oooo0P00000<0?oo
o`030000003oool0oooo00P0oooo0P00000l0?ooo`<00000103oool00`000000oooo0?ooo`3l0?oo
o`001P3oool00`3OW4P0001809cOo`0M0?ooo`030=nLB00004P0W=oo00D0oooo00D0oono07@00000
0000001809cOo`020?ooo`030?oog`2LB00000000080000000L0B9cO0?ooo`2LB7@0_ooo0?ooo`3o
gi`0B7Bo00T0oooo00<000000?ooo`3oool01P3oool3000000X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0j0?ooo`800000103oool00`000000oooo0?ooo`3l0?ooo`00?03oool0
1@3o_g@000000000000004P0W=oo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000
000:0?ooo`030000003oool0oooo00/0oooo0P00000l0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0o03oool003`0oooo00D0_gAd0;ooo`3oool0omnL04Qd_`090?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3k0?ooo`00?03oool0
1@2oM4P0W=oo0?ooo`3o_g@007Bo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`060?ooo`8000003`3oool2000003L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`3k0?ooo`00?03oool01@3ogi`0B0000000000007@0_ooo00T0oooo00<000000?ooo`3oool0203o
ool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`800000=@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?X0oooo001:0?ooo`030000003oool0
oooo00T0oooo2000000D0?ooo`800000=03oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`2^0?ooo`00BP3oool00`00
0000oooo0?ooo`0:0?ooo`<000006@3oool2000003<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0[P3oool004X0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0J0?ooo`800000<@3oool00`000000
oooo0?ooo`090?ooo`8000005`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0:h0
oooo001:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0703oool2000002l0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool0[P3oool004X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`0]0?ooo`8000002`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool0[P3oool004X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0/
0?ooo`8000002`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool0[P3oool004X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0[0?oo
o`8000002`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool0[P3oool004X0oooo00<000000?ooo`3oool0;P3oool2000002/0oooo0P00000<0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`2^0?ooo`00
BP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02P0oooo0P00000<0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`2^0?ooo`00BP3o
ool00`000000oooo0?ooo`0a0?ooo`800000:03oool2000000`0oooo00<000000?ooo`3oool04`3o
ool200000340oooo00<000000?ooo`3oool0[P3oool004X0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0U0?ooo`8000003@3oool00`000000oooo0?ooo`0B0?ooo`800000<@3oool0
0`000000oooo0?ooo`2^0?ooo`00BP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
02@0oooo0P00000>0?ooo`8000004P3oool200000340oooo00<000000?ooo`3oool0[P3oool004X0
oooo0P00000f0?ooo`800000903oool200000100oooo00<000000?ooo`3oool03`3oool200000340
oooo00<000000?ooo`3oool0[P3oool004X0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`0Q0?ooo`8000004@3oool00`000000oooo0?ooo`0>0?ooo`800000<@3oool00`000000oooo
0?ooo`2^0?ooo`00BP3oool00`000000oooo0?ooo`0h0?ooo`8000008@3oool200000140oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0000000`0?ooo`030000003oool0oooo0:h0oooo001:
0?ooo`030000003oool0oooo03X0oooo0P00000O0?ooo`8000004P3oool2000000h0oooo00<00000
0?ooo`000000<03oool00`000000oooo0?ooo`2^0?ooo`00BP3oool00`000000oooo0?ooo`0l0?oo
o`8000007@3oool2000001@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0000000`0?oo
o`030000003oool0oooo0:h0oooo001:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0000000D0?ooo`<000002P3oool00`000000oooo0000000`0?ooo`03
0000003oool0oooo0:h0oooo001:0?ooo`800000@03oool2000001X0oooo00<000000?ooo`000000
5`3oool2000000P0oooo00<000000?ooo`000000<03oool00`000000oooo0?ooo`2^0?ooo`00BP3o
ool00`000000oooo0?ooo`110?ooo`@000005P3oool00`000000oooo0000000H0?ooo`<000001P3o
ool00`000000oooo0000000`0?ooo`800000[`3oool004X0oooo00<000000?ooo`3oool0A03oool2
000001D0oooo00<000000?ooo`0000006P3oool3000000@0oooo00<000000?ooo`000000<03oool2
00000:l0oooo001:0?ooo`800000AP3oool400000180oooo00<000000?ooo`000000703oool20000
00<0oooo00<000000?ooo`000000<03oool200000:l0oooo001:0?ooo`030000003oool0oooo04P0
oooo1@00000>0?ooo`030000003oool0000001d0oooo00L000000?ooo`3oool0oooo0000003oool0
00000300oooo0P00002_0?ooo`00BP3oool00`000000oooo0?ooo`1<0?ooo`@000002`3oool00`00
0000oooo0000000M0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0]
0?ooo`800000[`3oool004X0oooo0P00001A0?ooo`@000001P3oool010000000oooo0?ooo`00000N
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0;@3oool200000:l0oooo001:0?oo
o`800000E03oool4000000<0oooo00@000000?ooo`3oool000007P3oool2000000@0oooo0P00000]
0?ooo`030000003oool000000:l0oooo001:0?ooo`030000003oool0oooo05H0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0000002_0?ooo`00103oool00`3o_g@000000000000300000003001d_`3oool0oooo
0080oooo00<0_g@000000000M;l01P3oool00`2oM4P0W=oo0?ooo`020?ooo`030?oo_`1dB9`0gooo
00@0oooo00<0okmd0000000000000`0000001@00M;l0oooo0?ooo`3oool0okmd00<0000000<0M;oo
0?ooo`3oool05@3oool2000005L0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0:`3oool00`000000oooo0000002_0?ooo`001`3oool0
0`2LB4P0W=oo0?ooo`050?ooo`030;md0000000007Bo00H0oooo00L0oooO09a8B02Lgol0oooo0?oo
_`1d07@0_ooo00P0oooo00<0W4Q809cOo`3oool0103oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;oo
oaH0oooo0P00001H0?ooo`040000003oool00000000000@0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo02/0oooo00<000000?ooo`000000[`3oool0
00L0oooo00<0W4Q809cOo`3oool03`3oool01@3ooml0W4Qd0;oog`2LB7@0_ooo00T0oooo00<0W4Q8
09cOo`3oool00`3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo01D0oooo0P00001H
0?ooo`<000001@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo0P00000[
0?ooo`030000003oool000000:l0oooo00070?ooo`0309a8B02Lgol0oooo0100oooo00<0oono07@0
B02Lgol02P3oool00`2LB4P0W=oo0?ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d
_`3oool05@3oool3000005l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`000000[`3oool000L0oooo00<0W4Q809cOo`3o
ool03`3oool01@3ookl0M01d0;oog`2LB4P0W=oo00T0oooo00<0W4Q809cOo`3oool00`3oool00`3O
W4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo01D0oooo00<000000?ooo`3oool0H03oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0000002_0?ooo`001`3oool00`2LB4P0W=oo0?ooo`0>0?ooo`070?oo_`1d07@0_ooo0?oo
o`3ooml0W4Q809cOo`080?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool00P3oool0
0`3o_g@007Bo0?ooo`0E0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo02H0oooo00<000000?ooo`000000[`3oool0
00L0oooo00<0W4Q809cOo`3oool03P3oool00`2oM7@0_ooo0?ooo`020?ooo`030?oog`2LM9`0gooo
00L0oooo00<0W4Q809cOo`3oool00`3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo
00P0oooo00@0gia800000000000004RL2@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
00000:l0oooo00040?ooo`050=nLB000000004RL09a8B02Lgol06`3oool01@3OW4P000000018W02L
B4P0W=oo00D0oooo00H0W4P007Boo`3oool0omnL04P0M02oool80?ooo`060?oOW018B9`0oooo0?oo
o`3OW7@0W=oo203oool00`000000oooo0?ooo`1Q0?ooo`8000006@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`000000[`3oool000H0oooo00<0gia80000
B02Lgol07@3oool00`3OW4P0001809cOo`050?ooo`050?oo_`1d000000000000B02Lgol00P3oool0
0`3ooml0W4P0000000020000000404RLg`3oool0_g@00018W080oooo00<0W4Q809cOo`3oool01`3o
ool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool000000:l0oooo000l0?ooo`050=nLM01dM4P0
000000000018W=l02@3oool00`000000oooo0?ooo`1T0?ooo`8000005P3oool00`000000oooo0?oo
o`0=0?ooo`8000008`3oool00`000000oooo0000002_0?ooo`00?03oool00`3OW4P0M;oo0?ooo`0;
0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`000000[`3oool003`0oooo00<0oono07@0
0018W=l02`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0O0?ooo`030000003oool000000:l0oooo000n0?ooo`04
09a800000000000007Boo`P0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0C0?oo
o`8000004P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool000000:l0oooo001:0?ooo`03
0000003oool0oooo06H0oooo0`00000C0?ooo`8000004`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool000000:l0oooo001:0?ooo`030000003oool0oooo06P0oooo0P00000@0?ooo`040000
003oool00000000001@0oooo00<000000?ooo`3oool0703oool00`000000oooo0000002_0?ooo`00
BP3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00`0oooo0P0000000`3oool00000
0000000E0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`000000[`3oool004X0oooo00<0
00000?ooo`3oool0J`3oool00`000000oooo0?ooo`0;0?ooo`80000000<0oooo0000000000005P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool000000:l0oooo001:0?ooo`030000003oool0
oooo06`0oooo00<000000?ooo`3oool02P3oool2000000030?ooo`000000000001L0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0000002_0?ooo`00BP3oool00`000000oooo0?ooo`1]0?oo
o`8000002P3oool2000000030?ooo`000000000001P0oooo00<000000?ooo`3oool05`3oool01000
0000oooo0?ooo`00002_0?ooo`00BP3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo
00L0oooo0`0000000`3oool000000?ooo`0G0?ooo`030000003oool0oooo01L0oooo00@000000?oo
o`3oool00000[`3oool004X0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`060?oo
o`<0000000<0oooo0000003oool0603oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo
00000:l0oooo001:0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0103oool40000
00030?ooo`000000oooo01T0oooo00<000000?ooo`3oool05@3oool010000000oooo0?ooo`00002_
0?ooo`00BP3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo00<0oooo100000000`3o
ool000000?ooo`0J0?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo0000002_
0?ooo`00BP3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo00H000000?oo
o`00000000000?ooo`00000L0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo
0000002_0?ooo`00BP3oool00`000000oooo0?ooo`1c0?ooo`050000003oool0oooo0?ooo`000000
0P3oool2000000030?ooo`000000oooo01`0oooo00<000000?ooo`3oool04@3oool01@000000oooo
0?ooo`3oool000000:l0oooo001:0?ooo`800000M@3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0000001h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0:`0oooo001:0?ooo`030000003oool0oooo07@0oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`2/0?ooo`00BP3oool00`000000oooo0?ooo`1d0?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0[03oool004X0oooo00<000000?ooo`3oool0
M03oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0:`0oooo001:0?ooo`030000
003oool0oooo07@0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2/0?ooo`00
BP3oool00`000000oooo0?ooo`1e0?ooo`8000001`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2/0?ooo`00BP3o
ool2000007H0oooo0P0000070?ooo`030000003oool0oooo0200oooo0P00000;0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0[03oool004X0oooo00<000000?ooo`3oool0OP3oool0
0`000000oooo0?ooo`0R0?ooo`<000001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0:`0oooo001:0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0903oool30000
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2/0?ooo`00BP3oool200000800
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`8000001`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo09X0oooo001:0?ooo`030000003oool0oooo07l0oooo
00<000000?ooo`3oool09P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`2J0?ooo`00BP3oool00`000000oooo0?ooo`200?ooo`030000
003oool0oooo02D0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo09X0oooo001:0?ooo`800000P@3oool00`000000oooo0?ooo`0U0?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2J0?ooo`00
BP3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo02H0oooo0P00000<0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0VP3oool004X0oooo0P0000210?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2J0?ooo`00BP3oool2
00000880oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo09X0oooo000>0?ooo`050?noM000000000000000001d_ol01@3oool00`2oM0000000001d_`05
0?ooo`050?noM000000000000000001d_ol0103oool01@3o_g@00000000000000000M;oo00@0oooo
00D0okmd000000000000000007Boo`030?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3o
ool01`3oool200000880oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo09X0oooo000>0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo103oool00`2o
M0000000001d_`050?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo0`3oool01P2LB7@0_ooo0?oo
o`3ookl0M01d0;ooo`<0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool50?ooo`0309a8B02Lgol0
oooo00X0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0VP3oool000d0oooo00<0okmd001d_`3oool00P3oool00`3O
W4P0B9cO0?ooo`0:0?ooo`030?noM000M;l0oooo0080oooo00H0gia804RLg`3oool0oooo0?noM000
M;l30?ooo`060=nLB018W=l0oooo0?ooo`3o_g@007Bo0`3oool00`3OW4P0B9cO0?ooo`040?ooo`03
09a8B02Lgol0oooo00X0oooo0P0000230?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`2J0?ooo`003@3oool00`3OW4P0B9cO0?ooo`020?ooo`030?no
M000M;l0oooo00X0oooo00<0gia804RLg`3oool00P3oool01P3o_g@007Bo0?ooo`3oool0gia804RL
g`<0oooo00H0okmd001d_`3oool0oooo0=nLB018W=l30?ooo`030?noM000M;l0oooo00@0oooo00<0
W4Q809cOo`3oool02P3oool300000880oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo09X0oooo000=0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd
001d_`3oool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`060?noM000M;l0oooo0?ooo`3OW4P0B9cO
0`3oool01P3o_g@007Bo0?ooo`3oool0gia804RLg`<0oooo00<0okmd001d_`3oool0103oool00`2L
B4P0W=oo0?ooo`0:0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo09X0oooo000=0?ooo`030=nLB018W=l0oooo0080
oooo00<0okmd001d_`3oool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`060?noM000M;l0oooo0?oo
o`3OW4P0B9cO0`3oool01P3o_g@007Bo0?ooo`3oool0gia804RLg`<0oooo00<0okmd001d_`3oool0
103oool00`2LB4P0W=oo0?ooo`0:0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09X0oooo000=0?ooo`030?noM018
W=l0oooo0080oooo00<0gia804RLg`3oool02P3oool00`3o_g@0B9cO0?ooo`020?ooo`060=nLB018
W=l0oooo0?ooo`3o_g@0B9cO0`3oool01P3OW4P0B9cO0?ooo`3oool0okmd04RLg`<0oooo00<0gia8
04RLg`3oool0103oool00`2LB4P0W=oo0?ooo`0:0?ooo`030000003oool0oooo08<0oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09X0oooo000>0?oo
o`0609a8001d_ol0oooo0?oOW01807@0_ooo303oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`<0
oooo00H0W4P007Boo`3oool0omnL04P0M02oool30?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo
0P3oool01@3OW4P000000018W02LB4P0W=oo00/0oooo00<000000?ooo`3oool0P`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo00L0oooo0P00002K0?ooo`003P3oool01@3ookl0M000
0000000004P0W=oo00d0oooo00D0oono07@000000000001809cOo`040?ooo`050?oo_`1d00000000
0000B02Lgol0103oool01@3ookl0M0000000000004P0W=oo00D0oooo00<0gia80000B02Lgol02`3o
ool00`000000oooo0?ooo`230?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool01`3o
ool2000009/0oooo001:0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`060?ooo`800000V`3oool004X0oooo00<000000?ooo`3oool0Q03oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo00H0oooo0P00002K0?ooo`00BP3oool00`000000
oooo0?ooo`240?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool01@3oool2000009/0
oooo001:0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`050?ooo`800000V`3oool004X0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo00D0oooo0`00002J0?ooo`00BP3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`00
002I0?ooo`00BP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool01@3oool010000000oooo0?ooo`00002I0?ooo`00BP3oool00`000000oooo0?ooo`27
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3o
ool0000009T0oooo001:0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?oo
o`250?ooo`00BP3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool0Q@3o
ool004X0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`800000Q`3oool0
04X0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00P3oool2000000h0oooo0P0000270?ooo`00BP3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`8000003@3oool2000008L0oooo001:0?ooo`030000003oool0oooo08X0oooo
00<000000?ooo`3oool0<P3oool3000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0;0?ooo`800000Q`3oool004X0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`0d0?ooo`@000001`3oool00`000000oooo0?ooo`0;0?ooo`8000003`3oool00`000000oooo0?oo
o`1e0?ooo`00BP3oool2000008`0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0:
0?ooo`8000003`3oool00`000000oooo0?ooo`1e0?ooo`00BP3oool00`000000oooo0?ooo`2;0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool02P3oool2000000l0oooo00<000000?oo
o`3oool0M@3oool004X0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo00X0oooo0P00000?0?ooo`030000003oool0oooo07D0oooo001:0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0:0?ooo`800000
3`3oool00`000000oooo0?ooo`1e0?ooo`00BP3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool02@3oool3000000l0oooo00<000000?ooo`3oool0M@3o
ool004X0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo00L0oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`1e0?ooo`00BP3oool2
000008h0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`070?ooo`040000003oool0
oooo000000l0oooo00<000000?ooo`3oool0M@3oool004X0oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000003`3o
ool00`000000oooo0?ooo`1e0?ooo`00BP3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000?0?ooo`030000003o
ool0oooo07D0oooo001:0?ooo`800000T03oool00`000000oooo0?ooo`0l0?ooo`800000203oool0
10000000oooo0?ooo`00000?0?ooo`030000003oool0oooo07D0oooo001:0?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`060?ooo`050000003oool0
oooo0?ooo`0000003P3oool00`000000oooo0?ooo`1e0?ooo`00BP3oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo03d0oooo0P0000060?ooo`050000003oool0oooo0?ooo`0000003P3o
ool00`000000oooo0?ooo`1e0?ooo`00BP3oool200000940oooo00<000000?ooo`3oool0?P3oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0?oo
o`1e0?ooo`00BP3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`3oool0M@3o
ool004X0oooo0P00002B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0M@3oool0
04X0oooo0P00002C0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0M@3oool00200
oooo00D0okmd000000000000000007Boo`050?ooo`030;md0000000007Bo00D0oooo00D0okmd0000
00000000000007Boo`030?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool01`3oool2
000009<0oooo00<000000?ooo`3oool0?P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool0303oool2000007H0oooo000P0?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo
103oool00`2oM0000000001d_`050?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo1@3oool00`2L
B4P0W=oo0?ooo`0:0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0?P3oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`000000MP3oool0
01l0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030?noM000M;l0oooo
0080oooo00<0gia804RLg`3oool0103oool00`2LB4P0W=oo0?ooo`0:0?ooo`800000U03oool00`00
0000oooo0?ooo`0m0?ooo`80000000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0000007H0oooo000O0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3o
ool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00@0oooo00<0W4Q809cOo`3o
ool02P3oool3000009<0oooo00<000000?ooo`3oool0?P3oool3000000H0oooo00<000000?ooo`3o
ool02P3oool010000000oooo00000000001e0?ooo`007`3oool00`3OW4P0B9cO0?ooo`020?ooo`03
0?noM000M;l0oooo00X0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`040?ooo`03
09a8B02Lgol0oooo00X0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo00X0oooo00@000000?ooo`3oool00000M@3oool001l0oooo00<0gia804RLg`3o
ool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3o
ool0103oool00`2LB4P0W=oo0?ooo`0:0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3o
ool0A`3oool2000000X0oooo00D000000?ooo`3oool0oooo0000001d0?ooo`007`3oool00`3o_g@0
B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0
B9cO0?ooo`040?ooo`0309a8B02Lgol0oooo00X0oooo00<000000?ooo`3oool0U@3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000E0?oo
o`030000003oool0oooo05`0oooo000P0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo303oool0
1P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`80oooo00D0gia800000000B9`0W4Q809cOo`0;0?ooo`03
0000003oool0oooo09D0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`080?ooo`05
0000003oool0oooo0?ooo`0000005@3oool00`000000oooo0?ooo`1L0?ooo`00803oool01@3ookl0
M0000000000004P0W=oo00d0oooo00D0oono07@000000000001809cOo`050?ooo`030=nLB00004P0
W=oo00/0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo00P0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`800000G@3oool004X0oooo00<00000
0?ooo`3oool0UP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0B0?ooo`800000G@3oool004X0oooo00<000000?oo
o`3oool0U`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0B0?ooo`800000G@3oool004X0oooo00<000000?ooo`3o
ool0U`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00<0oooo0P0000070?ooo`03
0000003oool0oooo0140oooo0P00001M0?ooo`00BP3oool00`000000oooo0?ooo`2H0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0140oooo0P00001M0?ooo`00BP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo04L0oooo00@000000?ooo`00000000002P3oool00`000000oooo0?ooo`0A0?ooo`800000
G@3oool004X0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`160?ooo`800000303o
ool00`000000oooo0?ooo`0A0?ooo`800000G@3oool004X0oooo00<000000?ooo`3oool0V@3oool0
0`000000oooo0?ooo`1E0?ooo`<00000403oool2000005d0oooo001:0?ooo`030000003oool0oooo
09X0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0>0?ooo`800000G@3oool004X0
oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`1G0?ooo`8000003@3oool00`000000
oooo0000001M0?ooo`00BP3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo05L0oooo
1000000:0?ooo`030000003oool0000005d0oooo001:0?ooo`030000003oool0oooo09/0oooo00<0
00000?ooo`3oool0FP3oool2000000T0oooo00<000000?ooo`000000G@3oool004X0oooo00<00000
0?ooo`3oool0W03oool00`000000oooo0?ooo`1K0?ooo`<000001P3oool00`000000oooo0000001M
0?ooo`00BP3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo05h0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`00001M0?ooo`00BP3oool00`000000oooo0?ooo`2M0?oo
o`030000003oool0oooo05h0oooo1@0000020?ooo`030000003oool0oooo05/0oooo001:0?ooo`03
0000003oool0oooo09d0oooo00<000000?ooo`3oool0H03oool2000000<0oooo00<000000?ooo`3o
ool0F`3oool004X0oooo0P00002O0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0
F`3oool004X0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo05/0oooo001:0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0H`3oool0
0`000000oooo0?ooo`1K0?ooo`00BP3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo
06<0oooo00<000000?ooo`3oool0F`3oool004X0oooo00<000000?ooo`3oool0X03oool00`000000
oooo0?ooo`1S0?ooo`030000003oool0oooo05X0oooo001:0?ooo`030000003oool0oooo0:00oooo
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1J0?ooo`00BP3oool200000:80oooo00<0
00000?ooo`3oool0HP3oool00`000000oooo0?ooo`1J0?ooo`00BP3oool00`000000oooo0?ooo`2Q
0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0FP3oool004X0oooo00<000000?oo
o`3oool0XP3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo05X0oooo001:0?ooo`80
0000X`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo05X0oooo001:0?ooo`030000
003oool0oooo0:<0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1I0?ooo`00BP3o
ool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0F@3o
ool004X0oooo0P00002U0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0F@3oool0
04X0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo
05T0oooo001:0?ooo`800000YP3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo05T0
oooo001:0?ooo`800000YP3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo05P0oooo
000j0?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool01`3oool00`000000oooo0?oo
o`2V0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0F03oool003d0oooo00<0W4Q8
09cOo`3oool02P3oool200000:L0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1H
0?ooo`00?@3oool00`2LB4P0W=oo0?ooo`0:0?ooo`800000Z03oool00`000000oooo0?ooo`1O0?oo
o`030000003oool0oooo05L0oooo000m0?ooo`0309a8B02Lgol0oooo00X0oooo0`00002W0?ooo`03
0000003oool0oooo05l0oooo00<000000?ooo`3oool0E`3oool003d0oooo00<0W4Q809cOo`3oool0
2P3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0
E`3oool003d0oooo00<0W4Q809cOo`3oool02P3oool00`000000oooo0?ooo`2X0?ooo`030000003o
ool0oooo05l0oooo00<000000?ooo`3oool0EP3oool003d0oooo00<0W4Q809cOo`3oool02P3oool0
0`000000oooo0?ooo`2X0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0EP3oool0
03X0oooo00D0gia800000000B9`0W4Q809cOo`0;0?ooo`030000003oool0oooo0:T0oooo00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`1F0?ooo`00?03oool00`3OW4P0001809cOo`0;0?oo
o`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1E0?oo
o`00BP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3o
ool0E@3oool004X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`1O0?ooo`030000
003oool0oooo05@0oooo001:0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0GP3o
ool00`000000oooo0?ooo`1D0?ooo`00BP3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0
oooo05h0oooo00<000000?ooo`3oool0E03oool004X0oooo00<000000?ooo`3oool0[03oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo05<0oooo001:0?ooo`030000003oool0oooo0:`0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1C0?ooo`00BP3oool00`000000oooo
0?ooo`2]0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0DP3oool004X0oooo00<0
00000?ooo`3oool0[@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0580oooo001:
0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1A
0?ooo`00BP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo05h0oooo00<000000?oo
o`3oool0D@3oool004X0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`1N0?ooo`03
0000003oool0oooo0500oooo001:0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0
GP3oool00`000000oooo0?ooo`1@0?ooo`00BP3oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo05h0oooo00<000000?ooo`3oool0C`3oool004X0oooo00<000000?ooo`3oool0/03oool0
0`000000oooo0?ooo`1N0?ooo`030000003oool0oooo04l0oooo001:0?ooo`030000003oool0oooo
0;40oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1>0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.486801, -11.5796, \
0.00882882, 0.0748278}}]
}, Closed]],

Cell[TextData[{
  "Although this is a trivial example, nontrivial examples of a less \
contrived nature often present similar problems and require more detailed \
analysis to isolate their causes.  Fortunately, the accuracy options provided \
by ",
  StyleBox["NDSolve", "InlineInput",
    FontWeight->"Bold"],
  " will often suffice where other standard algorithms fail, but it doesn't \
pay to become complacent \[LongDash] it is usually worthwhile to investigate \
more carefully and to gain more insight into the behavior of the system.  \
Sometimes rapid change is an important feature of the system and other times \
it may be an artifact of numerical instability, but it is your responsibility \
to distinguish between these possibilities!"
}], "Text"],

Cell["A stiff equation", "Exercise"],

Cell[TextData[{
  "The equation ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\^\[Prime]\)[t] \[Equal] y[t]\^2 - y[t]\^3\)]],
  " sometimes arises when the growth of some quantity involves competition \
between surface area and volume.  Let ",
  Cell[BoxData[
      \(TraditionalForm\`y\_0 = y[0]\)]],
  " be the initial value and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] = 1/y\_0\)]],
  " be the characteristic time scale.  One finds that ",
  Cell[BoxData[
      \(TraditionalForm\`y[t]\)]],
  " remains small until ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " approaches ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)]],
  ", whereupon there is a rapid change between ",
  Cell[BoxData[
      \(TraditionalForm\`y\_0\)]],
  " and the terminal value ",
  Cell[BoxData[
      \(TraditionalForm\`y[\[Infinity]] = 1\)]],
  ".\na) Obtain a symbolic solution and display for small ",
  Cell[BoxData[
      \(TraditionalForm\`y\_0\)]],
  ".  Solve for ",
  StyleBox["t",
    FontSlant->"Italic"],
  " as a function of ",
  StyleBox["y",
    FontSlant->"Italic"],
  " and explain the behavior of your solution.\nb) Obtain a numerical \
solution and demonstrate qualitative agreement with the symbolic solution.\n\
c) Define ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\[VeryThinSpace]y[t]\)]],
  " to be the difference between numerical and symbolic solutions.  Show that \
the error is localized near \[Tau] and investigate the dependence of the \
error upon the accuracy parameters governing ",
  StyleBox["NDSolve", "InlineInput",
    FontWeight->"Bold"],
  StyleBox[".",
    FontWeight->"Bold"]
}], "ExerciseText"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises", "ExerciseMain"],

Cell[CellGroupData[{

Cell["Terminal velocity", "ExerciseTitle"],

Cell["\<\
a) A small heavy body with large terminal velocity is dropped from rest near \
the earth's surface.  Assuming that the gravitational force is constant and \
that air resistance is proportional to the square of the velocity, find \
expressions for the position and velocity as functions of time in terms of \
the initial position, terminal velocity, and gravitational acceleration.\
\>", "ExerciseText"],

Cell[TextData[{
  "b) Repeat the previous problem for an object thrown vertically upwards \
with initial velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\_0\)]],
  ", taking care to recognize that the resistive force changes direction at \
the top of the trajectory.  Compare the time rising with the time falling."
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Series RLC circuit", "ExerciseTitle"],

Cell["A series RLC circuit is governed by the equation", "ExerciseText"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"L", " ", 
            FractionBox[\(\[PartialD]\^2 q\), \(\[PartialD]t\^2\),
              MultilineFunction->None]}], "+", 
          RowBox[{"R", " ", 
            FractionBox[\(\[PartialD]q\), \(\[PartialD]t\),
              MultilineFunction->None]}], "+", \(q\/C\)}], 
        "\[Equal]", \(V\_0\ \(cos(\[Omega]\ t)\)\)}], 
      TraditionalForm]], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`q[t]\)]],
  " is the the charge stored on the capacitor, ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " is the resistance, ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is the inductance, ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " is the capacitance, and ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)]],
  " is the driving voltage with frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  ".  Let ",
  Cell[BoxData[
      \(TraditionalForm\`q\_0\)]],
  " be the charge and ",
  Cell[BoxData[
      \(TraditionalForm\`I\_0\)]],
  " the current at time zero.  Identify the characteristic frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_0\)]],
  " for unforced vibrations and the damping factor ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " in terms of the parameters ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  ".  Find and simplify the complete symbolic solution.  "
}], "ExerciseText",
  CellDingbat->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Duffing equation", "ExerciseTitle"],

Cell["The Duffing equation", "ExerciseText"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[\(\[PartialD]\^2 x\), \(\[PartialD]t\^2\),
            MultilineFunction->None], "+", 
          RowBox[{"\[Gamma]", " ", 
            FractionBox[\(\[PartialD]x\), \(\[PartialD]t\),
              MultilineFunction->None]}], "+", 
          " ", \(\(\[Omega]\_0\^2\) x\ \((1 - \[Alpha]\ x\^2)\)\)}], " ", 
        "\[Equal]", \(f\ \(cos(\[Omega]\ t)\)\)}], 
      TraditionalForm]], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "describes a driven anharmonic oscillator with linear damping.  The \
anharmonicity parameter is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ", the damping parameter is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  ", the natural frequency for unforced vibrations in the absence of damping \
or anharmonicity is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is the driving amplitude, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " is the driving frequency.  It is convenient to express frequency in units \
of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_0\)]],
  " by setting ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_0 \[Rule] 1\)]],
  " and rescaling the time unit accordingly.   Write functions which solve \
the Duffing equation numerically and which produce phase diagrams.  Examine \
and describe the behavior for the following situations.\na) free, undamped, \
harmonic oscillator: \[Gamma]=0, ",
  Cell[BoxData[
      \(TraditionalForm\`f = 0\)]],
  ", \[Alpha]=0\nb) free, undamped, anharmonic oscillator: \[Gamma]=0, ",
  Cell[BoxData[
      \(TraditionalForm\`f = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \(\[PlusMinus]1\)\)]],
  "\nc) damped oscillator: ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] > 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f = 0\)]],
  "\nd) ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f = 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = {0.5, 1.5, 0.5}\)]],
  "\ne) ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f = 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \[Pi]\)]],
  "\nf) ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \(-1\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f = 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = {0.5, 1.5, 0.5}\)]],
  "\ng) ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 0.1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \(-1\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f = 10\)]],
  ", \[Omega]={0.5,1.5,0.5}"
}], "ExerciseText",
  CellDingbat->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Riccati transformation", "ExerciseTitle"],

Cell[TextData[{
  "A method that sometimes softens a stiff equation is the Riccati \
transformation based upon the logarithmic derivative ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta] = y'/y\)]],
  "."
}], "ExerciseText"],

Cell["\<\
a) Create a set of transformation rules which apply the Riccati \
transformation to a second-order differential equation.\
\>", "ExerciseText"],

Cell[TextData[{
  "b) Apply this transformation to the simple equation ",
  Cell[BoxData[
      \(TraditionalForm\`y\^\[Prime]\[Prime] - \[Lambda]\ y \[Equal] 0\)]],
  " and show that \[Eta] is constant.  Thus, obtain a stable numerical \
solution for ",
  StyleBox["y",
    FontSlant->"Italic"],
  " even when \[Lambda]\[Rule]400 is large."
}], "ExerciseText"],

Cell[TextData[{
  "c) Apply this transformation to a generic second-order differential \
equation of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\^\[Prime]\[Prime]\)[x]\  + \ 
          f[x]\ \(y\^\[Prime]\)[x]\  + \ g[x]\ y[x] \[Equal] 0\)]],
  " and deduce the corresponding equation for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta][x]\)]],
  "."
}], "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Phase shift for one-dimensional Schr\[ODoubleDot]dinger equation", \
"ExerciseTitle"],

Cell["\<\
The one-dimensional Schr\[ODoubleDot]dinger equation can be written in the \
dimensionless form\
\>", "ExerciseText"],

Cell[BoxData[
    \(TraditionalForm\`\(-\(\[Psi]\^\[DoublePrime]\)[x]\)\  + \ \[Nu][
            x]\ \[Psi][x]\  \[Equal] \ \[Psi][x]\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "If the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu][x]\)]],
  " has appreciable values only for small ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", the solutions outside the range of the potential are linear combinations \
of trigonometric functions.  For simplicity, suppose that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \[RightArrow] \ Sin[x]\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[LessLess] 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \[RightArrow] a\ Sin[x + \[Delta]]\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[GreaterGreater] 0\)]],
  ".  Write a function which evaluates ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\)]],
  " given ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\)]],
  ".  As a specific example, plot \[Delta] as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\_0\)]],
  " when ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu][x]\  = \ \[Nu]\_0\ Exp[\(-x\^2\)]\)]],
  ".\n[Hint: compare the logarithmic derivative ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta] = \[Psi]'/\[Psi]\)]],
  " for the numerical solution with the corresponding symbolic solutions for \
large ",
  Cell[BoxData[
      \(TraditionalForm\`x \[RightArrow] \(\[PlusMinus]\[Infinity]\)\)]],
  ".  You might find that the Riccati transformation is helpful.]"
}], "ExerciseText",
  CellDingbat->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Another stiff equation", "ExerciseTitle"],

Cell["Obtain and verify a symbolic solution for", "ExerciseText"],

Cell[BoxData[
    \(TraditionalForm\`\(y\^\[Prime]\)[x]\  + \ x\ y[x]\^2\  \[Equal] \ 
      a, \ \ y[0] \[Equal] 0\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[GreaterEqual] 0\)]],
  " and a generic real parameter ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ".  Plot solutions for ",
  Cell[BoxData[
      \(TraditionalForm\`a > 0\)]],
  " and describe their behavior as ",
  Cell[BoxData[
      \(TraditionalForm\`a \[Rule] \(0\^+\)\)]],
  ".  Next plot symbolic solutions for negative values ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ".  Are those solutions meaningful for large ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "?  Why not?  Compare symbolic and numerical solutions for ",
  Cell[BoxData[
      \(TraditionalForm\`a = \(-1\)\)]],
  "."
}], "ExerciseText"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 952}},
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{1392, 912},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Visible->True,
ShowCellLabel->False,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->PaperWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}, {
        Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {0, 0}},
    CellGroupingRules->"TitleGrouping",
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    ShowCellBracket->True,
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{9, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->0.5,
    CellMargins->{{25, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.700008, 0.4]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{25, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{25, 0}, {6, 6}}],
  
  Cell[StyleData["Input", "Printout"],
    CellFrame->0.5,
    CellMargins->{{25, 0}, {6, 6}},
    Background->None]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->True,
    CellMargins->{{25, 10}, {8, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{25, Inherited}, {12, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{10, 4}, {2, 10}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{12, 10}, {2, 12}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {1, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->9],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{9, 0}, {4, 12}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    CellMargins->{{10, 10}, {40, 2}},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{12, 10}, {50, 2}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Example",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Definition",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Definition", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Theorem",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Theorem", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.4]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caution"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Caution",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.996109, 0, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Caution", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Caution", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Caution", "Printout"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Advice"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Advice",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0, 1, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Advice", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Advice", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Advice", "Printout"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->"NormalGrouping",
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseMain"],
    CellFrame->{{6, 0}, {0, 1}},
    CellMargins->{{12, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseMain", "Presentation"],
    CellMargins->{{18, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["ExerciseMain", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["ExerciseMain", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseTitle"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseTitle", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["ExerciseTitle", "Condensed"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["ExerciseTitle", "Printout"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{32, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExcersiceText",
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{32, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{32, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{32, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Problem"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Problem", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Problem", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Problem", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{12, 10}, {Inherited, 6}},
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{13, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{62, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{74, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    CellMargins->{{52, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"]],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"]],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation package. These \
styles serve to make visible otherwise invisible tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 88, 2, 81, "Title"],
Cell[1867, 57, 455, 15, 85, "Author"],

Cell[CellGroupData[{
Cell[2347, 76, 31, 0, 83, "Section"],
Cell[2381, 78, 1253, 30, 148, "Text"],
Cell[3637, 110, 724, 25, 69, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4398, 140, 33, 0, 51, "Section"],
Cell[4434, 142, 119, 2, 99, "Input"],
Cell[4556, 146, 111, 2, 99, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4704, 153, 36, 0, 51, "Section"],

Cell[CellGroupData[{
Cell[4765, 157, 34, 0, 68, "Subsection"],
Cell[4802, 159, 1220, 36, 122, "Text"],

Cell[CellGroupData[{
Cell[6047, 199, 138, 3, 74, "Input"],
Cell[6188, 204, 155, 4, 59, "Output"]
}, Closed]],
Cell[6358, 211, 617, 13, 94, "Text"],

Cell[CellGroupData[{
Cell[7000, 228, 183, 3, 74, "Input"],
Cell[7186, 233, 155, 3, 79, "Output"]
}, Closed]],
Cell[7356, 239, 86, 2, 41, "Text"],
Cell[7445, 243, 796, 20, 94, "Text"],

Cell[CellGroupData[{
Cell[8266, 267, 128, 2, 73, "Input"],
Cell[8397, 271, 206, 3, 59, "Output"]
}, Closed]],
Cell[8618, 277, 121, 5, 41, "Text"],

Cell[CellGroupData[{
Cell[8764, 286, 144, 2, 73, "Input"],
Cell[8911, 290, 186, 3, 59, "Output"]
}, Closed]],
Cell[9112, 296, 50, 0, 41, "Text"],
Cell[9165, 298, 262, 10, 42, "Text"],

Cell[CellGroupData[{
Cell[9452, 312, 141, 3, 74, "Input"],
Cell[9596, 317, 115, 2, 59, "Output"]
}, Closed]],
Cell[9726, 322, 230, 8, 42, "Text"],

Cell[CellGroupData[{
Cell[9981, 334, 89, 1, 73, "Input"],
Cell[10073, 337, 87, 1, 59, "Output"]
}, Closed]],
Cell[10175, 341, 278, 8, 41, "Text"],

Cell[CellGroupData[{
Cell[10478, 353, 110, 2, 73, "Input"],
Cell[10591, 357, 54, 1, 78, "Output"]
}, Closed]],
Cell[10660, 361, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[10843, 369, 131, 2, 73, "Input"],
Cell[10977, 373, 87, 1, 59, "Output"]
}, Closed]],
Cell[11079, 377, 46, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[11150, 381, 108, 2, 73, "Input"],
Cell[11261, 385, 126, 3, 59, "Output"]
}, Closed]],
Cell[11402, 391, 143, 5, 42, "Text"],

Cell[CellGroupData[{
Cell[11570, 400, 93, 1, 73, "Input"],
Cell[11666, 403, 120, 2, 59, "Output"]
}, Closed]],
Cell[11801, 408, 129, 3, 41, "Text"],
Cell[11933, 413, 118, 3, 71, "Advice"]
}, Closed]],

Cell[CellGroupData[{
Cell[12088, 421, 44, 0, 68, "Subsection"],
Cell[12135, 423, 913, 26, 96, "Text"],

Cell[CellGroupData[{
Cell[13073, 453, 354, 7, 74, "Input"],
Cell[13430, 462, 155, 4, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[13622, 471, 38, 1, 73, "Input"],
Cell[13663, 474, 264, 4, 35, "Message"],
Cell[13930, 480, 35, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[14002, 486, 45, 1, 73, "Input"],
Cell[14050, 489, 278, 4, 35, "Message"],
Cell[14331, 495, 35, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[14403, 501, 45, 1, 73, "Input"],
Cell[14451, 504, 35, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[14523, 510, 47, 1, 73, "Input"],
Cell[14573, 513, 61, 1, 59, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[14683, 520, 52, 0, 68, "Subsection"],
Cell[14738, 522, 742, 19, 95, "Text"],

Cell[CellGroupData[{
Cell[15505, 545, 201, 4, 74, "Input"],
Cell[15709, 551, 85, 1, 59, "Output"]
}, Closed]],
Cell[15809, 555, 426, 14, 67, "Text"],

Cell[CellGroupData[{
Cell[16260, 573, 182, 3, 74, "Input"],
Cell[16445, 578, 289, 4, 35, "Message"],
Cell[16737, 584, 602, 15, 61, "Output"]
}, Closed]],
Cell[17354, 602, 796, 25, 95, "Text"],
Cell[18153, 629, 133, 4, 73, "Input"],

Cell[CellGroupData[{
Cell[18311, 637, 182, 3, 74, "Input"],
Cell[18496, 642, 88, 1, 59, "Output"]
}, Closed]],
Cell[18599, 646, 152, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[18776, 653, 133, 4, 73, "Input"],
Cell[18912, 659, 248, 4, 60, "Message"]
}, Closed]],

Cell[CellGroupData[{
Cell[19197, 668, 204, 4, 74, "Input"],
Cell[19404, 674, 159, 3, 79, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[19600, 682, 115, 2, 73, "Input"],
Cell[19718, 686, 224, 3, 83, "Output"]
}, Closed]],
Cell[19957, 692, 324, 5, 67, "Text"],
Cell[20284, 699, 133, 4, 73, "Input"],

Cell[CellGroupData[{
Cell[20442, 707, 185, 3, 74, "Input"],
Cell[20630, 712, 199, 4, 59, "Output"]
}, Closed]],
Cell[20844, 719, 545, 11, 94, "Text"],

Cell[CellGroupData[{
Cell[21414, 734, 262, 4, 74, "Input"],
Cell[21679, 740, 277, 5, 79, "Output"]
}, Closed]],
Cell[21971, 748, 127, 3, 41, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[22135, 756, 37, 0, 68, "Subsection"],
Cell[22175, 758, 476, 8, 94, "Text"],

Cell[CellGroupData[{
Cell[22676, 770, 106, 2, 73, "Input"],
Cell[22785, 774, 84, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[22906, 780, 416, 10, 74, "Input"],
Cell[23325, 792, 128, 3, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[23490, 800, 121, 2, 92, "Input"],
Cell[23614, 804, 201, 4, 75, "Output"]
}, Closed]],
Cell[23830, 811, 126, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[23981, 818, 108, 2, 73, "Input"],
Cell[24092, 822, 321, 8, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[24450, 835, 121, 2, 92, "Input"],
Cell[24574, 839, 337, 8, 59, "Output"]
}, Closed]],
Cell[24926, 850, 296, 11, 58, "Exercise"],
Cell[25225, 863, 313, 7, 83, "Exercise"],
Cell[25541, 872, 150, 5, 58, "Exercise"],
Cell[25694, 879, 144, 5, 58, "Exercise"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[25887, 890, 37, 0, 51, "Section"],

Cell[CellGroupData[{
Cell[25949, 894, 34, 0, 68, "Subsection"],
Cell[25986, 896, 1323, 33, 148, "Text"],
Cell[27312, 931, 304, 6, 68, "Text"],

Cell[CellGroupData[{
Cell[27641, 941, 271, 5, 96, "Input"],
Cell[27915, 948, 232, 6, 59, "Output"]
}, Closed]],
Cell[28162, 957, 1112, 27, 148, "Text"],

Cell[CellGroupData[{
Cell[29299, 988, 103, 2, 73, "Input"],
Cell[29405, 992, 156, 4, 59, "Output"]
}, Closed]],
Cell[29576, 999, 679, 15, 95, "Text"],

Cell[CellGroupData[{
Cell[30280, 1018, 230, 4, 73, "Input"],
Cell[30513, 1024, 38614, 825, 351, 5755, 415, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[69142, 1852, 35, 0, 58, "Exercise"],
Cell[69180, 1854, 115, 3, 41, "ExerciseText"],
Cell[69298, 1859, 549, 14, 64, "DisplayFormula",
  Evaluatable->False],
Cell[69850, 1875, 1541, 49, 161, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[71428, 1929, 42, 0, 68, "Subsection"],
Cell[71473, 1931, 384, 7, 68, "Text"],

Cell[CellGroupData[{
Cell[71882, 1942, 330, 6, 96, "Input"],
Cell[72215, 1950, 429, 11, 59, "Output"]
}, Closed]],
Cell[72659, 1964, 111, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[72795, 1971, 216, 4, 73, "Input"],
Cell[73014, 1977, 38614, 825, 351, 5755, 415, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[111643, 2805, 231, 4, 67, "Text"],
Cell[111877, 2811, 363, 6, 151, "Input"],
Cell[112243, 2819, 387, 8, 125, "Input"],
Cell[112633, 2829, 112, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[112770, 2836, 198, 3, 96, "Input"],
Cell[112971, 2841, 250410, 11171, 448, 105781, 9381, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[363396, 14015, 53, 0, 58, "Exercise"],
Cell[363452, 14017, 766, 19, 94, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[364255, 14041, 37, 0, 68, "Subsection"],
Cell[364295, 14043, 1541, 22, 224, "Text"],
Cell[365839, 14067, 383, 12, 42, "Text"],

Cell[CellGroupData[{
Cell[366247, 14083, 49, 1, 73, "Input"],
Cell[366299, 14086, 522, 8, 160, "Output"]
}, Closed]],
Cell[366836, 14097, 1916, 47, 202, "Text"],
Cell[368755, 14146, 71, 0, 41, "Text"],
Cell[368829, 14148, 393, 10, 43, "DisplayFormula",
  Evaluatable->False],
Cell[369225, 14160, 367, 8, 67, "Text"],
Cell[369595, 14170, 352, 7, 43, "DisplayFormula",
  Evaluatable->False],
Cell[369950, 14179, 858, 15, 119, "Text"],
Cell[370811, 14196, 146, 3, 41, "Text"],
Cell[370960, 14201, 555, 11, 126, "Input"],
Cell[371518, 14214, 744, 17, 93, "Text"],

Cell[CellGroupData[{
Cell[372287, 14235, 263, 4, 99, "Input"],

Cell[CellGroupData[{
Cell[372575, 14243, 28630, 653, 279, 4896, 355, "GraphicsData", "PostScript", \
"Graphics"],
Cell[401208, 14898, 21040, 492, 279, 3795, 275, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],
Cell[422275, 15394, 120, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[422420, 15401, 374, 7, 125, "Input"],
Cell[422797, 15410, 47512, 1164, 279, 15696, 767, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[470324, 16577, 50, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[470399, 16581, 409, 8, 125, "Input"],
Cell[470811, 16591, 56744, 1668, 279, 26109, 1285, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[527570, 18262, 51, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[527646, 18266, 773, 15, 203, "Input"],
Cell[528422, 18283, 60150, 1820, 279, 25692, 1390, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[588587, 20106, 464, 7, 93, "Text"],

Cell[CellGroupData[{
Cell[589076, 20117, 698, 13, 203, "Input"],
Cell[589777, 20132, 63232, 1832, 279, 24158, 1345, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[653024, 21967, 759, 13, 120, "Text"],
Cell[653786, 21982, 36, 0, 58, "Exercise"],
Cell[653825, 21984, 1648, 47, 222, "ExerciseText"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[655522, 22037, 33, 0, 54, "ExerciseMain"],

Cell[CellGroupData[{
Cell[655580, 22041, 42, 0, 58, "ExerciseTitle"],
Cell[655625, 22043, 412, 6, 93, "ExerciseText"],
Cell[656040, 22051, 341, 7, 67, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[656418, 22063, 43, 0, 35, "ExerciseTitle"],
Cell[656464, 22065, 72, 0, 41, "ExerciseText"],
Cell[656539, 22067, 518, 14, 64, "DisplayFormula",
  Evaluatable->False],
Cell[657060, 22083, 1183, 42, 93, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[658280, 22130, 41, 0, 35, "ExerciseTitle"],
Cell[658324, 22132, 44, 0, 41, "ExerciseText"],
Cell[658371, 22134, 550, 14, 64, "DisplayFormula",
  Evaluatable->False],
Cell[658924, 22150, 2581, 90, 357, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[661542, 22245, 47, 0, 35, "ExerciseTitle"],
Cell[661592, 22247, 226, 6, 41, "ExerciseText"],
Cell[661821, 22255, 153, 3, 41, "ExerciseText"],
Cell[661977, 22260, 361, 9, 41, "ExerciseText"],
Cell[662341, 22271, 386, 10, 41, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[662764, 22286, 91, 1, 35, "ExerciseTitle"],
Cell[662858, 22289, 127, 3, 41, "ExerciseText"],
Cell[662988, 22294, 224, 5, 41, "DisplayFormula",
  Evaluatable->False],
Cell[663215, 22301, 1498, 44, 153, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[664750, 22350, 47, 0, 35, "ExerciseTitle"],
Cell[664800, 22352, 65, 0, 41, "ExerciseText"],
Cell[664868, 22354, 206, 5, 43, "DisplayFormula",
  Evaluatable->False],
Cell[665077, 22361, 709, 23, 67, "ExerciseText"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

